/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSpatialAudio.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSpatialAudio/qaudioroom.sip"
#include <qaudioroom.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSpatialAudio/qaudioengine.sip"
#include <qaudioengine.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioRoom.cpp"


class sipQAudioRoom : public ::QAudioRoom
{
public:
    sipQAudioRoom(::QAudioEngine*);
    virtual ~sipQAudioRoom();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAudioRoom(const sipQAudioRoom &);
    sipQAudioRoom &operator = (const sipQAudioRoom &);

    char sipPyMethods[7];
};

sipQAudioRoom::sipQAudioRoom(::QAudioEngine*a0): ::QAudioRoom(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioRoom::~sipQAudioRoom()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAudioRoom::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtSpatialAudio_qt_metaobject(sipPySelf, sipType_QAudioRoom);

    return ::QAudioRoom::metaObject();
}

int sipQAudioRoom::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAudioRoom::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtSpatialAudio_qt_metacall(sipPySelf, sipType_QAudioRoom, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAudioRoom::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtSpatialAudio_qt_metacast(sipPySelf, sipType_QAudioRoom, _clname, &sipCpp) ? sipCpp : ::QAudioRoom::qt_metacast(_clname));
}

bool sipQAudioRoom::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAudioRoom::event(a0);

    extern bool sipVH_QtSpatialAudio_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtSpatialAudio_5(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAudioRoom::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAudioRoom::eventFilter(a0, a1);

    extern bool sipVH_QtSpatialAudio_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtSpatialAudio_4(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAudioRoom::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAudioRoom::timerEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtSpatialAudio_3(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioRoom::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAudioRoom::childEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtSpatialAudio_2(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioRoom::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAudioRoom::customEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSpatialAudio_1(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioRoom::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAudioRoom::connectNotify(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSpatialAudio_0(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioRoom::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAudioRoom::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSpatialAudio_0(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAudioRoom_setPosition, "setPosition(self, pos: QVector3D)");

extern "C" {static PyObject *meth_QAudioRoom_setPosition(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVector3D* a0;
        ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioRoom, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setPosition(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_setPosition, doc_QAudioRoom_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_position, "position(self) -> QVector3D");

extern "C" {static PyObject *meth_QAudioRoom_position(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioRoom, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->position());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_position, doc_QAudioRoom_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_setDimensions, "setDimensions(self, dim: QVector3D)");

extern "C" {static PyObject *meth_QAudioRoom_setDimensions(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_setDimensions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVector3D* a0;
        ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioRoom, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setDimensions(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_setDimensions, doc_QAudioRoom_setDimensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_dimensions, "dimensions(self) -> QVector3D");

extern "C" {static PyObject *meth_QAudioRoom_dimensions(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_dimensions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioRoom, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->dimensions());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_dimensions, doc_QAudioRoom_dimensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_setRotation, "setRotation(self, q: QQuaternion)");

extern "C" {static PyObject *meth_QAudioRoom_setRotation(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_setRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuaternion* a0;
        ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioRoom, &sipCpp, sipType_QQuaternion, &a0))
        {
            sipCpp->setRotation(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_setRotation, doc_QAudioRoom_setRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_rotation, "rotation(self) -> QQuaternion");

extern "C" {static PyObject *meth_QAudioRoom_rotation(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioRoom, &sipCpp))
        {
            ::QQuaternion*sipRes;

            sipRes = new ::QQuaternion(sipCpp->rotation());

            return sipConvertFromNewType(sipRes, sipType_QQuaternion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_rotation, doc_QAudioRoom_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_setWallMaterial, "setWallMaterial(self, wall: QAudioRoom.Wall, material: QAudioRoom.Material)");

extern "C" {static PyObject *meth_QAudioRoom_setWallMaterial(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_setWallMaterial(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioRoom::Wall a0;
        ::QAudioRoom::Material a1;
        ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEE", &sipSelf, sipType_QAudioRoom, &sipCpp, sipType_QAudioRoom_Wall, &a0, sipType_QAudioRoom_Material, &a1))
        {
            sipCpp->setWallMaterial(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_setWallMaterial, doc_QAudioRoom_setWallMaterial);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_wallMaterial, "wallMaterial(self, wall: QAudioRoom.Wall) -> QAudioRoom.Material");

extern "C" {static PyObject *meth_QAudioRoom_wallMaterial(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_wallMaterial(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioRoom::Wall a0;
        const ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAudioRoom, &sipCpp, sipType_QAudioRoom_Wall, &a0))
        {
            ::QAudioRoom::Material sipRes;

            sipRes = sipCpp->wallMaterial(a0);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAudioRoom_Material);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_wallMaterial, doc_QAudioRoom_wallMaterial);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_setReflectionGain, "setReflectionGain(self, factor: float)");

extern "C" {static PyObject *meth_QAudioRoom_setReflectionGain(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_setReflectionGain(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QAudioRoom, &sipCpp, &a0))
        {
            sipCpp->setReflectionGain(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_setReflectionGain, doc_QAudioRoom_setReflectionGain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_reflectionGain, "reflectionGain(self) -> float");

extern "C" {static PyObject *meth_QAudioRoom_reflectionGain(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_reflectionGain(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioRoom, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->reflectionGain();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_reflectionGain, doc_QAudioRoom_reflectionGain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_setReverbGain, "setReverbGain(self, factor: float)");

extern "C" {static PyObject *meth_QAudioRoom_setReverbGain(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_setReverbGain(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QAudioRoom, &sipCpp, &a0))
        {
            sipCpp->setReverbGain(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_setReverbGain, doc_QAudioRoom_setReverbGain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_reverbGain, "reverbGain(self) -> float");

extern "C" {static PyObject *meth_QAudioRoom_reverbGain(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_reverbGain(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioRoom, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->reverbGain();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_reverbGain, doc_QAudioRoom_reverbGain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_setReverbTime, "setReverbTime(self, factor: float)");

extern "C" {static PyObject *meth_QAudioRoom_setReverbTime(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_setReverbTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QAudioRoom, &sipCpp, &a0))
        {
            sipCpp->setReverbTime(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_setReverbTime, doc_QAudioRoom_setReverbTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_reverbTime, "reverbTime(self) -> float");

extern "C" {static PyObject *meth_QAudioRoom_reverbTime(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_reverbTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioRoom, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->reverbTime();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_reverbTime, doc_QAudioRoom_reverbTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_setReverbBrightness, "setReverbBrightness(self, factor: float)");

extern "C" {static PyObject *meth_QAudioRoom_setReverbBrightness(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_setReverbBrightness(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QAudioRoom, &sipCpp, &a0))
        {
            sipCpp->setReverbBrightness(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_setReverbBrightness, doc_QAudioRoom_setReverbBrightness);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioRoom_reverbBrightness, "reverbBrightness(self) -> float");

extern "C" {static PyObject *meth_QAudioRoom_reverbBrightness(PyObject *, PyObject *);}
static PyObject *meth_QAudioRoom_reverbBrightness(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioRoom *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioRoom, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->reverbBrightness();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioRoom, sipName_reverbBrightness, doc_QAudioRoom_reverbBrightness);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAudioRoom(void *, const sipTypeDef *);}
static void *cast_QAudioRoom(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAudioRoom *sipCpp = reinterpret_cast< ::QAudioRoom *>(sipCppV);

    if (targetType == sipType_QAudioRoom)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAudioRoom(void *, int);}
static void release_QAudioRoom(void *sipCppV, int)
{
    ::QAudioRoom *sipCpp = reinterpret_cast< ::QAudioRoom *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QAudioRoom(sipSimpleWrapper *);}
static void dealloc_QAudioRoom(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAudioRoom *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAudioRoom(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAudioRoom(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAudioRoom(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQAudioRoom *sipCpp = SIP_NULLPTR;

    {
        ::QAudioEngine* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8", sipType_QAudioEngine, &a0))
        {
            sipCpp = new sipQAudioRoom(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAudioRoom[] = {{3, 0, 1}};


static PyMethodDef methods_QAudioRoom[] = {
    {sipName_dimensions, meth_QAudioRoom_dimensions, METH_VARARGS, doc_QAudioRoom_dimensions},
    {sipName_position, meth_QAudioRoom_position, METH_VARARGS, doc_QAudioRoom_position},
    {sipName_reflectionGain, meth_QAudioRoom_reflectionGain, METH_VARARGS, doc_QAudioRoom_reflectionGain},
    {sipName_reverbBrightness, meth_QAudioRoom_reverbBrightness, METH_VARARGS, doc_QAudioRoom_reverbBrightness},
    {sipName_reverbGain, meth_QAudioRoom_reverbGain, METH_VARARGS, doc_QAudioRoom_reverbGain},
    {sipName_reverbTime, meth_QAudioRoom_reverbTime, METH_VARARGS, doc_QAudioRoom_reverbTime},
    {sipName_rotation, meth_QAudioRoom_rotation, METH_VARARGS, doc_QAudioRoom_rotation},
    {sipName_setDimensions, meth_QAudioRoom_setDimensions, METH_VARARGS, doc_QAudioRoom_setDimensions},
    {sipName_setPosition, meth_QAudioRoom_setPosition, METH_VARARGS, doc_QAudioRoom_setPosition},
    {sipName_setReflectionGain, meth_QAudioRoom_setReflectionGain, METH_VARARGS, doc_QAudioRoom_setReflectionGain},
    {sipName_setReverbBrightness, meth_QAudioRoom_setReverbBrightness, METH_VARARGS, doc_QAudioRoom_setReverbBrightness},
    {sipName_setReverbGain, meth_QAudioRoom_setReverbGain, METH_VARARGS, doc_QAudioRoom_setReverbGain},
    {sipName_setReverbTime, meth_QAudioRoom_setReverbTime, METH_VARARGS, doc_QAudioRoom_setReverbTime},
    {sipName_setRotation, meth_QAudioRoom_setRotation, METH_VARARGS, doc_QAudioRoom_setRotation},
    {sipName_setWallMaterial, meth_QAudioRoom_setWallMaterial, METH_VARARGS, doc_QAudioRoom_setWallMaterial},
    {sipName_wallMaterial, meth_QAudioRoom_wallMaterial, METH_VARARGS, doc_QAudioRoom_wallMaterial}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QAudioRoom[] = {
    {sipName_Transparent, static_cast<int>(::QAudioRoom::Transparent)},
    {sipName_AcousticCeilingTiles, static_cast<int>(::QAudioRoom::AcousticCeilingTiles)},
    {sipName_BrickBare, static_cast<int>(::QAudioRoom::BrickBare)},
    {sipName_BrickPainted, static_cast<int>(::QAudioRoom::BrickPainted)},
    {sipName_ConcreteBlockCoarse, static_cast<int>(::QAudioRoom::ConcreteBlockCoarse)},
    {sipName_ConcreteBlockPainted, static_cast<int>(::QAudioRoom::ConcreteBlockPainted)},
    {sipName_CurtainHeavy, static_cast<int>(::QAudioRoom::CurtainHeavy)},
    {sipName_FiberGlassInsulation, static_cast<int>(::QAudioRoom::FiberGlassInsulation)},
    {sipName_GlassThin, static_cast<int>(::QAudioRoom::GlassThin)},
    {sipName_GlassThick, static_cast<int>(::QAudioRoom::GlassThick)},
    {sipName_Grass, static_cast<int>(::QAudioRoom::Grass)},
    {sipName_LinoleumOnConcrete, static_cast<int>(::QAudioRoom::LinoleumOnConcrete)},
    {sipName_Marble, static_cast<int>(::QAudioRoom::Marble)},
    {sipName_Metal, static_cast<int>(::QAudioRoom::Metal)},
    {sipName_ParquetOnConcrete, static_cast<int>(::QAudioRoom::ParquetOnConcrete)},
    {sipName_PlasterRough, static_cast<int>(::QAudioRoom::PlasterRough)},
    {sipName_PlasterSmooth, static_cast<int>(::QAudioRoom::PlasterSmooth)},
    {sipName_PlywoodPanel, static_cast<int>(::QAudioRoom::PlywoodPanel)},
    {sipName_PolishedConcreteOrTile, static_cast<int>(::QAudioRoom::PolishedConcreteOrTile)},
    {sipName_Sheetrock, static_cast<int>(::QAudioRoom::Sheetrock)},
    {sipName_WaterOrIceSurface, static_cast<int>(::QAudioRoom::WaterOrIceSurface)},
    {sipName_WoodCeiling, static_cast<int>(::QAudioRoom::WoodCeiling)},
    {sipName_WoodPanel, static_cast<int>(::QAudioRoom::WoodPanel)},
    {sipName_UniformMaterial, static_cast<int>(::QAudioRoom::UniformMaterial)},
    {sipName_LeftWall, static_cast<int>(::QAudioRoom::LeftWall)},
    {sipName_RightWall, static_cast<int>(::QAudioRoom::RightWall)},
    {sipName_Floor, static_cast<int>(::QAudioRoom::Floor)},
    {sipName_Ceiling, static_cast<int>(::QAudioRoom::Ceiling)},
    {sipName_FrontWall, static_cast<int>(::QAudioRoom::FrontWall)},
    {sipName_BackWall, static_cast<int>(::QAudioRoom::BackWall)},
    {0, 0}
};

PyDoc_STRVAR(doc_QAudioRoom, "\1QAudioRoom(engine: QAudioEngine|None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QAudioRoom[] = {
    {"reverbBrightnessChanged()", "\1reverbBrightnessChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"reverbTimeChanged()", "\1reverbTimeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"reverbGainChanged()", "\1reverbGainChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"reflectionGainChanged()", "\1reflectionGainChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"wallsChanged()", "\1wallsChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"rotationChanged()", "\1rotationChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"dimensionsChanged()", "\1dimensionsChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged()", "\1positionChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QAudioRoom = {
    &::QAudioRoom::staticMetaObject,
    signals_QAudioRoom,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSpatialAudio_QAudioRoom = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAudioRoom,
        SIP_NULLPTR,
        &plugin_QAudioRoom,
    },
    {
        sipNameNr_QAudioRoom,
        {0, 0, 1},
        16, methods_QAudioRoom,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QAudioRoom, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAudioRoom,
    -1,
    -1,
    supers_QAudioRoom,
    SIP_NULLPTR,
    init_type_QAudioRoom,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAudioRoom,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QAudioRoom,
    cast_QAudioRoom,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QAudioRoom),
};
