/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediarecorder.sip"
#include <qmediarecorder.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediacapturesession.sip"
#include <qmediacapturesession.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediametadata.sip"
#include <qmediametadata.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediaformat.sip"
#include <qmediaformat.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaRecorder.cpp"


class sipQMediaRecorder : public ::QMediaRecorder
{
public:
    sipQMediaRecorder(::QObject*);
    virtual ~sipQMediaRecorder();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQMediaRecorder(const sipQMediaRecorder &);
    sipQMediaRecorder &operator = (const sipQMediaRecorder &);

    char sipPyMethods[7];
};

sipQMediaRecorder::sipQMediaRecorder(::QObject*a0): ::QMediaRecorder(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQMediaRecorder::~sipQMediaRecorder()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQMediaRecorder::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QMediaRecorder);

    return ::QMediaRecorder::metaObject();
}

int sipQMediaRecorder::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QMediaRecorder::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QMediaRecorder, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQMediaRecorder::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QMediaRecorder, _clname, &sipCpp) ? sipCpp : ::QMediaRecorder::qt_metacast(_clname));
}

bool sipQMediaRecorder::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QMediaRecorder::event(a0);

    extern bool sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaRecorder::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QMediaRecorder::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_4(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQMediaRecorder::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QMediaRecorder::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_3(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorder::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QMediaRecorder::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorder::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QMediaRecorder::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_1(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorder::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QMediaRecorder::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorder::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QMediaRecorder::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QMediaRecorder_isAvailable, "isAvailable(self) -> bool");

extern "C" {static PyObject *meth_QMediaRecorder_isAvailable(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_isAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_isAvailable, doc_QMediaRecorder_isAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_outputLocation, "outputLocation(self) -> QUrl");

extern "C" {static PyObject *meth_QMediaRecorder_outputLocation(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_outputLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->outputLocation());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_outputLocation, doc_QMediaRecorder_outputLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setOutputLocation, "setOutputLocation(self, location: QUrl)");

extern "C" {static PyObject *meth_QMediaRecorder_setOutputLocation(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setOutputLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setOutputLocation(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setOutputLocation, doc_QMediaRecorder_setOutputLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_actualLocation, "actualLocation(self) -> QUrl");

extern "C" {static PyObject *meth_QMediaRecorder_actualLocation(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_actualLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->actualLocation());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_actualLocation, doc_QMediaRecorder_actualLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_recorderState, "recorderState(self) -> QMediaRecorder.RecorderState");

extern "C" {static PyObject *meth_QMediaRecorder_recorderState(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_recorderState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMediaRecorder::RecorderState sipRes;

            sipRes = sipCpp->recorderState();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaRecorder_RecorderState);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_recorderState, doc_QMediaRecorder_recorderState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_error, "error(self) -> QMediaRecorder.Error");

extern "C" {static PyObject *meth_QMediaRecorder_error(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMediaRecorder::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaRecorder_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_error, doc_QMediaRecorder_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QMediaRecorder_errorString(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_errorString, doc_QMediaRecorder_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_duration, "duration(self) -> int");

extern "C" {static PyObject *meth_QMediaRecorder_duration(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_duration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->duration();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_duration, doc_QMediaRecorder_duration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_mediaFormat, "mediaFormat(self) -> QMediaFormat");

extern "C" {static PyObject *meth_QMediaRecorder_mediaFormat(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_mediaFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMediaFormat*sipRes;

            sipRes = new ::QMediaFormat(sipCpp->mediaFormat());

            return sipConvertFromNewType(sipRes, sipType_QMediaFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_mediaFormat, doc_QMediaRecorder_mediaFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setMediaFormat, "setMediaFormat(self, format: QMediaFormat)");

extern "C" {static PyObject *meth_QMediaRecorder_setMediaFormat(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setMediaFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaFormat* a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QMediaFormat, &a0))
        {
            sipCpp->setMediaFormat(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setMediaFormat, doc_QMediaRecorder_setMediaFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_encodingMode, "encodingMode(self) -> QMediaRecorder.EncodingMode");

extern "C" {static PyObject *meth_QMediaRecorder_encodingMode(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_encodingMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMediaRecorder::EncodingMode sipRes;

            sipRes = sipCpp->encodingMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaRecorder_EncodingMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_encodingMode, doc_QMediaRecorder_encodingMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setEncodingMode, "setEncodingMode(self, a0: QMediaRecorder.EncodingMode)");

extern "C" {static PyObject *meth_QMediaRecorder_setEncodingMode(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setEncodingMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaRecorder::EncodingMode a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QMediaRecorder_EncodingMode, &a0))
        {
            sipCpp->setEncodingMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setEncodingMode, doc_QMediaRecorder_setEncodingMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_quality, "quality(self) -> QMediaRecorder.Quality");

extern "C" {static PyObject *meth_QMediaRecorder_quality(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_quality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMediaRecorder::Quality sipRes;

            sipRes = sipCpp->quality();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaRecorder_Quality);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_quality, doc_QMediaRecorder_quality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setQuality, "setQuality(self, quality: QMediaRecorder.Quality)");

extern "C" {static PyObject *meth_QMediaRecorder_setQuality(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setQuality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaRecorder::Quality a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QMediaRecorder_Quality, &a0))
        {
            sipCpp->setQuality(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setQuality, doc_QMediaRecorder_setQuality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_videoResolution, "videoResolution(self) -> QSize");

extern "C" {static PyObject *meth_QMediaRecorder_videoResolution(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_videoResolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->videoResolution());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_videoResolution, doc_QMediaRecorder_videoResolution);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setVideoResolution, "setVideoResolution(self, a0: QSize)\n"
"setVideoResolution(self, width: int, height: int)");

extern "C" {static PyObject *meth_QMediaRecorder_setVideoResolution(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setVideoResolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setVideoResolution(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        int a1;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QMediaRecorder, &sipCpp, &a0, &a1))
        {
            sipCpp->setVideoResolution(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setVideoResolution, doc_QMediaRecorder_setVideoResolution);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_videoFrameRate, "videoFrameRate(self) -> float");

extern "C" {static PyObject *meth_QMediaRecorder_videoFrameRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_videoFrameRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->videoFrameRate();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_videoFrameRate, doc_QMediaRecorder_videoFrameRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setVideoFrameRate, "setVideoFrameRate(self, frameRate: float)");

extern "C" {static PyObject *meth_QMediaRecorder_setVideoFrameRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setVideoFrameRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QMediaRecorder, &sipCpp, &a0))
        {
            sipCpp->setVideoFrameRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setVideoFrameRate, doc_QMediaRecorder_setVideoFrameRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_videoBitRate, "videoBitRate(self) -> int");

extern "C" {static PyObject *meth_QMediaRecorder_videoBitRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_videoBitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->videoBitRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_videoBitRate, doc_QMediaRecorder_videoBitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setVideoBitRate, "setVideoBitRate(self, bitRate: int)");

extern "C" {static PyObject *meth_QMediaRecorder_setVideoBitRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setVideoBitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaRecorder, &sipCpp, &a0))
        {
            sipCpp->setVideoBitRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setVideoBitRate, doc_QMediaRecorder_setVideoBitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_audioBitRate, "audioBitRate(self) -> int");

extern "C" {static PyObject *meth_QMediaRecorder_audioBitRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_audioBitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->audioBitRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_audioBitRate, doc_QMediaRecorder_audioBitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setAudioBitRate, "setAudioBitRate(self, bitRate: int)");

extern "C" {static PyObject *meth_QMediaRecorder_setAudioBitRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setAudioBitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaRecorder, &sipCpp, &a0))
        {
            sipCpp->setAudioBitRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setAudioBitRate, doc_QMediaRecorder_setAudioBitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_audioChannelCount, "audioChannelCount(self) -> int");

extern "C" {static PyObject *meth_QMediaRecorder_audioChannelCount(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_audioChannelCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->audioChannelCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_audioChannelCount, doc_QMediaRecorder_audioChannelCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setAudioChannelCount, "setAudioChannelCount(self, channels: int)");

extern "C" {static PyObject *meth_QMediaRecorder_setAudioChannelCount(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setAudioChannelCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaRecorder, &sipCpp, &a0))
        {
            sipCpp->setAudioChannelCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setAudioChannelCount, doc_QMediaRecorder_setAudioChannelCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_audioSampleRate, "audioSampleRate(self) -> int");

extern "C" {static PyObject *meth_QMediaRecorder_audioSampleRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_audioSampleRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->audioSampleRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_audioSampleRate, doc_QMediaRecorder_audioSampleRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setAudioSampleRate, "setAudioSampleRate(self, sampleRate: int)");

extern "C" {static PyObject *meth_QMediaRecorder_setAudioSampleRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setAudioSampleRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaRecorder, &sipCpp, &a0))
        {
            sipCpp->setAudioSampleRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setAudioSampleRate, doc_QMediaRecorder_setAudioSampleRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_metaData, "metaData(self) -> QMediaMetaData");

extern "C" {static PyObject *meth_QMediaRecorder_metaData(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_metaData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMediaMetaData*sipRes;

            sipRes = new ::QMediaMetaData(sipCpp->metaData());

            return sipConvertFromNewType(sipRes, sipType_QMediaMetaData, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_metaData, doc_QMediaRecorder_metaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setMetaData, "setMetaData(self, metaData: QMediaMetaData)");

extern "C" {static PyObject *meth_QMediaRecorder_setMetaData(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setMetaData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaMetaData* a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QMediaMetaData, &a0))
        {
            sipCpp->setMetaData(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setMetaData, doc_QMediaRecorder_setMetaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_captureSession, "captureSession(self) -> QMediaCaptureSession|None");

extern "C" {static PyObject *meth_QMediaRecorder_captureSession(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_captureSession(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QMediaCaptureSession*sipRes;

            sipRes = sipCpp->captureSession();

            return sipConvertFromType(sipRes, sipType_QMediaCaptureSession, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_captureSession, doc_QMediaRecorder_captureSession);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_record, "record(self)");

extern "C" {static PyObject *meth_QMediaRecorder_record(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_record(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            sipCpp->record();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_record, doc_QMediaRecorder_record);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_pause, "pause(self)");

extern "C" {static PyObject *meth_QMediaRecorder_pause(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_pause(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            sipCpp->pause();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_pause, doc_QMediaRecorder_pause);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_stop, "stop(self)");

extern "C" {static PyObject *meth_QMediaRecorder_stop(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_stop, doc_QMediaRecorder_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setOutputDevice, "setOutputDevice(self, device: QIODevice|None)");

extern "C" {static PyObject *meth_QMediaRecorder_setOutputDevice(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setOutputDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaRecorder, &sipCpp, sipType_QIODevice, &a0))
        {
            sipCpp->setOutputDevice(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setOutputDevice, doc_QMediaRecorder_setOutputDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_outputDevice, "outputDevice(self) -> QIODevice|None");

extern "C" {static PyObject *meth_QMediaRecorder_outputDevice(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_outputDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            ::QIODevice*sipRes;

            sipRes = sipCpp->outputDevice();

            return sipConvertFromType(sipRes, sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_outputDevice, doc_QMediaRecorder_outputDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_autoStop, "autoStop(self) -> bool");

extern "C" {static PyObject *meth_QMediaRecorder_autoStop(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_autoStop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorder, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoStop();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_autoStop, doc_QMediaRecorder_autoStop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorder_setAutoStop, "setAutoStop(self, autoStop: bool)");

extern "C" {static PyObject *meth_QMediaRecorder_setAutoStop(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorder_setAutoStop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QMediaRecorder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QMediaRecorder, &sipCpp, &a0))
        {
            sipCpp->setAutoStop(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorder, sipName_setAutoStop, doc_QMediaRecorder_setAutoStop);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QMediaRecorder(void *, const sipTypeDef *);}
static void *cast_QMediaRecorder(void *sipCppV, const sipTypeDef *targetType)
{
    ::QMediaRecorder *sipCpp = reinterpret_cast< ::QMediaRecorder *>(sipCppV);

    if (targetType == sipType_QMediaRecorder)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QMediaRecorder(void *, int);}
static void release_QMediaRecorder(void *sipCppV, int)
{
    ::QMediaRecorder *sipCpp = reinterpret_cast< ::QMediaRecorder *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QMediaRecorder(Py_ssize_t);}
static void *array_QMediaRecorder(Py_ssize_t sipNrElem)
{
    return new ::QMediaRecorder[sipNrElem];
}


extern "C" {static void array_delete_QMediaRecorder(void *);}
static void array_delete_QMediaRecorder(void *sipCpp)
{
    delete[] reinterpret_cast< ::QMediaRecorder *>(sipCpp);
}


extern "C" {static void dealloc_QMediaRecorder(sipSimpleWrapper *);}
static void dealloc_QMediaRecorder(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQMediaRecorder *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMediaRecorder(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QMediaRecorder(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMediaRecorder(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQMediaRecorder *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQMediaRecorder(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QMediaRecorder[] = {{7, 0, 1}};


static PyMethodDef methods_QMediaRecorder[] = {
    {sipName_actualLocation, meth_QMediaRecorder_actualLocation, METH_VARARGS, doc_QMediaRecorder_actualLocation},
    {sipName_audioBitRate, meth_QMediaRecorder_audioBitRate, METH_VARARGS, doc_QMediaRecorder_audioBitRate},
    {sipName_audioChannelCount, meth_QMediaRecorder_audioChannelCount, METH_VARARGS, doc_QMediaRecorder_audioChannelCount},
    {sipName_audioSampleRate, meth_QMediaRecorder_audioSampleRate, METH_VARARGS, doc_QMediaRecorder_audioSampleRate},
    {sipName_autoStop, meth_QMediaRecorder_autoStop, METH_VARARGS, doc_QMediaRecorder_autoStop},
    {sipName_captureSession, meth_QMediaRecorder_captureSession, METH_VARARGS, doc_QMediaRecorder_captureSession},
    {sipName_duration, meth_QMediaRecorder_duration, METH_VARARGS, doc_QMediaRecorder_duration},
    {sipName_encodingMode, meth_QMediaRecorder_encodingMode, METH_VARARGS, doc_QMediaRecorder_encodingMode},
    {sipName_error, meth_QMediaRecorder_error, METH_VARARGS, doc_QMediaRecorder_error},
    {sipName_errorString, meth_QMediaRecorder_errorString, METH_VARARGS, doc_QMediaRecorder_errorString},
    {sipName_isAvailable, meth_QMediaRecorder_isAvailable, METH_VARARGS, doc_QMediaRecorder_isAvailable},
    {sipName_mediaFormat, meth_QMediaRecorder_mediaFormat, METH_VARARGS, doc_QMediaRecorder_mediaFormat},
    {sipName_metaData, meth_QMediaRecorder_metaData, METH_VARARGS, doc_QMediaRecorder_metaData},
    {sipName_outputDevice, meth_QMediaRecorder_outputDevice, METH_VARARGS, doc_QMediaRecorder_outputDevice},
    {sipName_outputLocation, meth_QMediaRecorder_outputLocation, METH_VARARGS, doc_QMediaRecorder_outputLocation},
    {sipName_pause, meth_QMediaRecorder_pause, METH_VARARGS, doc_QMediaRecorder_pause},
    {sipName_quality, meth_QMediaRecorder_quality, METH_VARARGS, doc_QMediaRecorder_quality},
    {sipName_record, meth_QMediaRecorder_record, METH_VARARGS, doc_QMediaRecorder_record},
    {sipName_recorderState, meth_QMediaRecorder_recorderState, METH_VARARGS, doc_QMediaRecorder_recorderState},
    {sipName_setAudioBitRate, meth_QMediaRecorder_setAudioBitRate, METH_VARARGS, doc_QMediaRecorder_setAudioBitRate},
    {sipName_setAudioChannelCount, meth_QMediaRecorder_setAudioChannelCount, METH_VARARGS, doc_QMediaRecorder_setAudioChannelCount},
    {sipName_setAudioSampleRate, meth_QMediaRecorder_setAudioSampleRate, METH_VARARGS, doc_QMediaRecorder_setAudioSampleRate},
    {sipName_setAutoStop, meth_QMediaRecorder_setAutoStop, METH_VARARGS, doc_QMediaRecorder_setAutoStop},
    {sipName_setEncodingMode, meth_QMediaRecorder_setEncodingMode, METH_VARARGS, doc_QMediaRecorder_setEncodingMode},
    {sipName_setMediaFormat, meth_QMediaRecorder_setMediaFormat, METH_VARARGS, doc_QMediaRecorder_setMediaFormat},
    {sipName_setMetaData, meth_QMediaRecorder_setMetaData, METH_VARARGS, doc_QMediaRecorder_setMetaData},
    {sipName_setOutputDevice, meth_QMediaRecorder_setOutputDevice, METH_VARARGS, doc_QMediaRecorder_setOutputDevice},
    {sipName_setOutputLocation, meth_QMediaRecorder_setOutputLocation, METH_VARARGS, doc_QMediaRecorder_setOutputLocation},
    {sipName_setQuality, meth_QMediaRecorder_setQuality, METH_VARARGS, doc_QMediaRecorder_setQuality},
    {sipName_setVideoBitRate, meth_QMediaRecorder_setVideoBitRate, METH_VARARGS, doc_QMediaRecorder_setVideoBitRate},
    {sipName_setVideoFrameRate, meth_QMediaRecorder_setVideoFrameRate, METH_VARARGS, doc_QMediaRecorder_setVideoFrameRate},
    {sipName_setVideoResolution, meth_QMediaRecorder_setVideoResolution, METH_VARARGS, doc_QMediaRecorder_setVideoResolution},
    {sipName_stop, meth_QMediaRecorder_stop, METH_VARARGS, doc_QMediaRecorder_stop},
    {sipName_videoBitRate, meth_QMediaRecorder_videoBitRate, METH_VARARGS, doc_QMediaRecorder_videoBitRate},
    {sipName_videoFrameRate, meth_QMediaRecorder_videoFrameRate, METH_VARARGS, doc_QMediaRecorder_videoFrameRate},
    {sipName_videoResolution, meth_QMediaRecorder_videoResolution, METH_VARARGS, doc_QMediaRecorder_videoResolution}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QMediaRecorder[] = {
    {sipName_ConstantQualityEncoding, static_cast<int>(::QMediaRecorder::ConstantQualityEncoding)},
    {sipName_ConstantBitRateEncoding, static_cast<int>(::QMediaRecorder::ConstantBitRateEncoding)},
    {sipName_AverageBitRateEncoding, static_cast<int>(::QMediaRecorder::AverageBitRateEncoding)},
    {sipName_TwoPassEncoding, static_cast<int>(::QMediaRecorder::TwoPassEncoding)},
    {sipName_NoError, static_cast<int>(::QMediaRecorder::NoError)},
    {sipName_ResourceError, static_cast<int>(::QMediaRecorder::ResourceError)},
    {sipName_FormatError, static_cast<int>(::QMediaRecorder::FormatError)},
    {sipName_OutOfSpaceError, static_cast<int>(::QMediaRecorder::OutOfSpaceError)},
    {sipName_LocationNotWritable, static_cast<int>(::QMediaRecorder::LocationNotWritable)},
    {sipName_VeryLowQuality, static_cast<int>(::QMediaRecorder::VeryLowQuality)},
    {sipName_LowQuality, static_cast<int>(::QMediaRecorder::LowQuality)},
    {sipName_NormalQuality, static_cast<int>(::QMediaRecorder::NormalQuality)},
    {sipName_HighQuality, static_cast<int>(::QMediaRecorder::HighQuality)},
    {sipName_VeryHighQuality, static_cast<int>(::QMediaRecorder::VeryHighQuality)},
    {sipName_StoppedState, static_cast<int>(::QMediaRecorder::StoppedState)},
    {sipName_RecordingState, static_cast<int>(::QMediaRecorder::RecordingState)},
    {sipName_PausedState, static_cast<int>(::QMediaRecorder::PausedState)},
    {0, 0}
};

PyDoc_STRVAR(doc_QMediaRecorder, "\1QMediaRecorder(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QMediaRecorder[] = {
    {"autoStopChanged()", "\1autoStopChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"audioSampleRateChanged()", "\1audioSampleRateChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"audioChannelCountChanged()", "\1audioChannelCountChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"audioBitRateChanged()", "\1audioBitRateChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"videoBitRateChanged()", "\1videoBitRateChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"videoFrameRateChanged()", "\1videoFrameRateChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"videoResolutionChanged()", "\1videoResolutionChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"qualityChanged()", "\1qualityChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"encodingModeChanged()", "\1encodingModeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"mediaFormatChanged()", "\1mediaFormatChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"metaDataChanged()", "\1metaDataChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorChanged()", "\1errorChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorOccurred(Error,QString)|(QMediaRecorder::Error,QString)", "\1errorOccurred(self, error: QMediaRecorder.Error, errorString: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"actualLocationChanged(QUrl)", "\1actualLocationChanged(self, location: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"durationChanged(qint64)", "\1durationChanged(self, duration: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"recorderStateChanged(RecorderState)|(QMediaRecorder::RecorderState)", "\1recorderStateChanged(self, state: QMediaRecorder.RecorderState)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QMediaRecorder = {
    &::QMediaRecorder::staticMetaObject,
    signals_QMediaRecorder,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaRecorder = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMediaRecorder,
        SIP_NULLPTR,
        &plugin_QMediaRecorder,
    },
    {
        sipNameNr_QMediaRecorder,
        {0, 0, 1},
        36, methods_QMediaRecorder,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QMediaRecorder, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMediaRecorder,
    -1,
    -1,
    supers_QMediaRecorder,
    SIP_NULLPTR,
    init_type_QMediaRecorder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMediaRecorder,
    SIP_NULLPTR,
    array_QMediaRecorder,
    SIP_NULLPTR,
    release_QMediaRecorder,
    cast_QMediaRecorder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QMediaRecorder,
    sizeof (::QMediaRecorder),
};
