/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtXml.h"

#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 305 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 363 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 455 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 343 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 520 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 479 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 493 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 442 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 508 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 178 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 196 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 331 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 78 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
#line 467 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"


PyDoc_STRVAR(doc_QDomElement_attribute, "attribute(self, name: str|None, defaultValue: str|None = '') -> str");

extern "C" {static PyObject *meth_QDomElement_attribute(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDomElement_attribute(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        const ::QDomElement *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_defaultValue,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->attribute(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_attribute, doc_QDomElement_attribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_setAttribute, "setAttribute(self, name: str|None, value: str|None)\n"
"setAttribute(self, name: str|None, value: int)\n"
"setAttribute(self, name: str|None, value: int)\n"
"setAttribute(self, name: str|None, value: float)\n"
"setAttribute(self, name: str|None, value: int)");

extern "C" {static PyObject *meth_QDomElement_setAttribute(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_setAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            sipCpp->setAttribute(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::qlonglong a1;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1n", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, &a1))
        {
            sipCpp->setAttribute(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::qulonglong a1;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1o", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, &a1))
        {
            sipCpp->setAttribute(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        double a1;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1Xd", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, &a1))
        {
            sipCpp->setAttribute(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        int a1;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1i", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, &a1))
        {
            sipCpp->setAttribute(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_setAttribute, doc_QDomElement_setAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_removeAttribute, "removeAttribute(self, name: str|None)");

extern "C" {static PyObject *meth_QDomElement_removeAttribute(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_removeAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->removeAttribute(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_removeAttribute, doc_QDomElement_removeAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_attributeNode, "attributeNode(self, name: str|None) -> QDomAttr");

extern "C" {static PyObject *meth_QDomElement_attributeNode(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_attributeNode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QDomAttr*sipRes;

            sipRes = new ::QDomAttr(sipCpp->attributeNode(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QDomAttr, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_attributeNode, doc_QDomElement_attributeNode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_setAttributeNode, "setAttributeNode(self, newAttr: QDomAttr) -> QDomAttr");

extern "C" {static PyObject *meth_QDomElement_setAttributeNode(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_setAttributeNode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomAttr* a0;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QDomAttr, &a0))
        {
            ::QDomAttr*sipRes;

            sipRes = new ::QDomAttr(sipCpp->setAttributeNode(*a0));

            return sipConvertFromNewType(sipRes, sipType_QDomAttr, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_setAttributeNode, doc_QDomElement_setAttributeNode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_removeAttributeNode, "removeAttributeNode(self, oldAttr: QDomAttr) -> QDomAttr");

extern "C" {static PyObject *meth_QDomElement_removeAttributeNode(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_removeAttributeNode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomAttr* a0;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QDomAttr, &a0))
        {
            ::QDomAttr*sipRes;

            sipRes = new ::QDomAttr(sipCpp->removeAttributeNode(*a0));

            return sipConvertFromNewType(sipRes, sipType_QDomAttr, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_removeAttributeNode, doc_QDomElement_removeAttributeNode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_elementsByTagName, "elementsByTagName(self, tagname: str|None) -> QDomNodeList");

extern "C" {static PyObject *meth_QDomElement_elementsByTagName(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_elementsByTagName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QDomNodeList*sipRes;

            sipRes = new ::QDomNodeList(sipCpp->elementsByTagName(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QDomNodeList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_elementsByTagName, doc_QDomElement_elementsByTagName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_hasAttribute, "hasAttribute(self, name: str|None) -> bool");

extern "C" {static PyObject *meth_QDomElement_hasAttribute(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_hasAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->hasAttribute(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_hasAttribute, doc_QDomElement_hasAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_attributeNS, "attributeNS(self, nsURI: str|None, localName: str|None, defaultValue: str|None = '') -> str");

extern "C" {static PyObject *meth_QDomElement_attributeNS(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDomElement_attributeNS(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString& a2def = QString();
        const ::QString* a2 = &a2def;
        int a2State = 0;
        const ::QDomElement *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_defaultValue,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J1|J1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->attributeNS(*a0, *a1, *a2));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_attributeNS, doc_QDomElement_attributeNS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_setAttributeNS, "setAttributeNS(self, nsURI: str|None, qName: str|None, value: str|None)\n"
"setAttributeNS(self, nsURI: str|None, qName: str|None, value: float)\n"
"setAttributeNS(self, nsURI: str|None, qName: str|None, value: int)");

extern "C" {static PyObject *meth_QDomElement_setAttributeNS(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_setAttributeNS(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1J1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State))
        {
            sipCpp->setAttributeNS(*a0, *a1, *a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        double a2;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1Xd", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, &a2))
        {
            sipCpp->setAttributeNS(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        PyObject * a2;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1P0", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 403 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
        qlonglong val = sipLong_AsLongLong(a2);
        
        if (!PyErr_Occurred())
        {
            sipCpp->setAttributeNS(*a0, *a1, val);
        }
        else
        {
            // If it is positive then it might fit an unsigned long long.
        
            qulonglong uval = sipLong_AsUnsignedLongLong(a2);
        
            if (!PyErr_Occurred())
            {
                sipCpp->setAttributeNS(*a0, *a1, uval);
            }
            else
            {
                sipError = (PyErr_ExceptionMatches(PyExc_OverflowError)
                        ? sipErrorFail : sipErrorContinue);
            }
        }
#line 516 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomElement.cpp"
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_setAttributeNS, doc_QDomElement_setAttributeNS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_removeAttributeNS, "removeAttributeNS(self, nsURI: str|None, localName: str|None)");

extern "C" {static PyObject *meth_QDomElement_removeAttributeNS(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_removeAttributeNS(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            sipCpp->removeAttributeNS(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_removeAttributeNS, doc_QDomElement_removeAttributeNS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_attributeNodeNS, "attributeNodeNS(self, nsURI: str|None, localName: str|None) -> QDomAttr");

extern "C" {static PyObject *meth_QDomElement_attributeNodeNS(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_attributeNodeNS(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QDomAttr*sipRes;

            sipRes = new ::QDomAttr(sipCpp->attributeNodeNS(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QDomAttr, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_attributeNodeNS, doc_QDomElement_attributeNodeNS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_setAttributeNodeNS, "setAttributeNodeNS(self, newAttr: QDomAttr) -> QDomAttr");

extern "C" {static PyObject *meth_QDomElement_setAttributeNodeNS(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_setAttributeNodeNS(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomAttr* a0;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QDomAttr, &a0))
        {
            ::QDomAttr*sipRes;

            sipRes = new ::QDomAttr(sipCpp->setAttributeNodeNS(*a0));

            return sipConvertFromNewType(sipRes, sipType_QDomAttr, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_setAttributeNodeNS, doc_QDomElement_setAttributeNodeNS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_elementsByTagNameNS, "elementsByTagNameNS(self, nsURI: str|None, localName: str|None) -> QDomNodeList");

extern "C" {static PyObject *meth_QDomElement_elementsByTagNameNS(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_elementsByTagNameNS(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QDomNodeList*sipRes;

            sipRes = new ::QDomNodeList(sipCpp->elementsByTagNameNS(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QDomNodeList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_elementsByTagNameNS, doc_QDomElement_elementsByTagNameNS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_hasAttributeNS, "hasAttributeNS(self, nsURI: str|None, localName: str|None) -> bool");

extern "C" {static PyObject *meth_QDomElement_hasAttributeNS(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_hasAttributeNS(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->hasAttributeNS(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_hasAttributeNS, doc_QDomElement_hasAttributeNS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_tagName, "tagName(self) -> str");

extern "C" {static PyObject *meth_QDomElement_tagName(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_tagName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomElement, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->tagName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_tagName, doc_QDomElement_tagName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_setTagName, "setTagName(self, name: str|None)");

extern "C" {static PyObject *meth_QDomElement_setTagName(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_setTagName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDomElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTagName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_setTagName, doc_QDomElement_setTagName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_attributes, "attributes(self) -> QDomNamedNodeMap");

extern "C" {static PyObject *meth_QDomElement_attributes(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_attributes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomElement, &sipCpp))
        {
            ::QDomNamedNodeMap*sipRes;

            sipRes = new ::QDomNamedNodeMap(sipCpp->attributes());

            return sipConvertFromNewType(sipRes, sipType_QDomNamedNodeMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_attributes, doc_QDomElement_attributes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_nodeType, "nodeType(self) -> QDomNode.NodeType");

extern "C" {static PyObject *meth_QDomElement_nodeType(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_nodeType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomElement, &sipCpp))
        {
            ::QDomNode::NodeType sipRes;

            sipRes = sipCpp->nodeType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QDomNode_NodeType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_nodeType, doc_QDomElement_nodeType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomElement_text, "text(self) -> str");

extern "C" {static PyObject *meth_QDomElement_text(PyObject *, PyObject *);}
static PyObject *meth_QDomElement_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomElement, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomElement, sipName_text, doc_QDomElement_text);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QDomElement(void *, const sipTypeDef *);}
static void *cast_QDomElement(void *sipCppV, const sipTypeDef *targetType)
{
    ::QDomElement *sipCpp = reinterpret_cast< ::QDomElement *>(sipCppV);

    if (targetType == sipType_QDomElement)
        return sipCppV;

    if (targetType == sipType_QDomNode)
        return static_cast< ::QDomNode *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDomElement(void *, int);}
static void release_QDomElement(void *sipCppV, int)
{
    delete reinterpret_cast< ::QDomElement *>(sipCppV);
}


extern "C" {static void *array_QDomElement(Py_ssize_t);}
static void *array_QDomElement(Py_ssize_t sipNrElem)
{
    return new ::QDomElement[sipNrElem];
}


extern "C" {static void array_delete_QDomElement(void *);}
static void array_delete_QDomElement(void *sipCpp)
{
    delete[] reinterpret_cast< ::QDomElement *>(sipCpp);
}


extern "C" {static void assign_QDomElement(void *, Py_ssize_t, void *);}
static void assign_QDomElement(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QDomElement *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QDomElement *>(sipSrc);
}


extern "C" {static void *copy_QDomElement(const void *, Py_ssize_t);}
static void *copy_QDomElement(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QDomElement(reinterpret_cast<const ::QDomElement *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QDomElement(sipSimpleWrapper *);}
static void dealloc_QDomElement(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDomElement(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QDomElement(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDomElement(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QDomElement *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QDomElement();

            return sipCpp;
        }
    }

    {
        const ::QDomElement* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDomElement, &a0))
        {
            sipCpp = new ::QDomElement(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QDomElement[] = {{14, 255, 1}};


static PyMethodDef methods_QDomElement[] = {
    {sipName_attribute, SIP_MLMETH_CAST(meth_QDomElement_attribute), METH_VARARGS|METH_KEYWORDS, doc_QDomElement_attribute},
    {sipName_attributeNS, SIP_MLMETH_CAST(meth_QDomElement_attributeNS), METH_VARARGS|METH_KEYWORDS, doc_QDomElement_attributeNS},
    {sipName_attributeNode, meth_QDomElement_attributeNode, METH_VARARGS, doc_QDomElement_attributeNode},
    {sipName_attributeNodeNS, meth_QDomElement_attributeNodeNS, METH_VARARGS, doc_QDomElement_attributeNodeNS},
    {sipName_attributes, meth_QDomElement_attributes, METH_VARARGS, doc_QDomElement_attributes},
    {sipName_elementsByTagName, meth_QDomElement_elementsByTagName, METH_VARARGS, doc_QDomElement_elementsByTagName},
    {sipName_elementsByTagNameNS, meth_QDomElement_elementsByTagNameNS, METH_VARARGS, doc_QDomElement_elementsByTagNameNS},
    {sipName_hasAttribute, meth_QDomElement_hasAttribute, METH_VARARGS, doc_QDomElement_hasAttribute},
    {sipName_hasAttributeNS, meth_QDomElement_hasAttributeNS, METH_VARARGS, doc_QDomElement_hasAttributeNS},
    {sipName_nodeType, meth_QDomElement_nodeType, METH_VARARGS, doc_QDomElement_nodeType},
    {sipName_removeAttribute, meth_QDomElement_removeAttribute, METH_VARARGS, doc_QDomElement_removeAttribute},
    {sipName_removeAttributeNS, meth_QDomElement_removeAttributeNS, METH_VARARGS, doc_QDomElement_removeAttributeNS},
    {sipName_removeAttributeNode, meth_QDomElement_removeAttributeNode, METH_VARARGS, doc_QDomElement_removeAttributeNode},
    {sipName_setAttribute, meth_QDomElement_setAttribute, METH_VARARGS, doc_QDomElement_setAttribute},
    {sipName_setAttributeNS, meth_QDomElement_setAttributeNS, METH_VARARGS, doc_QDomElement_setAttributeNS},
    {sipName_setAttributeNode, meth_QDomElement_setAttributeNode, METH_VARARGS, doc_QDomElement_setAttributeNode},
    {sipName_setAttributeNodeNS, meth_QDomElement_setAttributeNodeNS, METH_VARARGS, doc_QDomElement_setAttributeNodeNS},
    {sipName_setTagName, meth_QDomElement_setTagName, METH_VARARGS, doc_QDomElement_setTagName},
    {sipName_tagName, meth_QDomElement_tagName, METH_VARARGS, doc_QDomElement_tagName},
    {sipName_text, meth_QDomElement_text, METH_VARARGS, doc_QDomElement_text}
};

PyDoc_STRVAR(doc_QDomElement, "\1QDomElement()\n"
"QDomElement(x: QDomElement)");


sipClassTypeDef sipTypeDef_QtXml_QDomElement = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDomElement,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QDomElement,
        {0, 0, 1},
        20, methods_QDomElement,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDomElement,
    -1,
    -1,
    supers_QDomElement,
    SIP_NULLPTR,
    init_type_QDomElement,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDomElement,
    assign_QDomElement,
    array_QDomElement,
    copy_QDomElement,
    release_QDomElement,
    cast_QDomElement,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QDomElement,
    sizeof (::QDomElement),
};
