/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qsgvertexcolormaterial.sip"
#include <qsgvertexcolormaterial.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGVertexColorMaterial.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qsgmaterialshader.sip"
#include <qsgmaterialshader.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGVertexColorMaterial.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qsgrendererinterface.sip"
#include <qsgrendererinterface.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGVertexColorMaterial.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qsgmaterialtype.sip"
#include <qsgmaterialtype.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGVertexColorMaterial.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGVertexColorMaterial.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGVertexColorMaterial.cpp"


class sipQSGVertexColorMaterial : public ::QSGVertexColorMaterial
{
public:
    sipQSGVertexColorMaterial();
    virtual ~sipQSGVertexColorMaterial();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QSGMaterialType* type() const SIP_OVERRIDE;
    ::QSGMaterialShader* createShader(::QSGRendererInterface::RenderMode) const SIP_OVERRIDE;
    int compare(const ::QSGMaterial*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSGVertexColorMaterial(const sipQSGVertexColorMaterial &);
    sipQSGVertexColorMaterial &operator = (const sipQSGVertexColorMaterial &);

    char sipPyMethods[3];
};

sipQSGVertexColorMaterial::sipQSGVertexColorMaterial(): ::QSGVertexColorMaterial(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSGVertexColorMaterial::~sipQSGVertexColorMaterial()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

::QSGMaterialType* sipQSGVertexColorMaterial::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QSGVertexColorMaterial::type();

    extern ::QSGMaterialType* sipVH_QtQuick_55(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_55(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSGMaterialShader* sipQSGVertexColorMaterial::createShader(::QSGRendererInterface::RenderMode a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_createShader);

    if (!sipMeth)
        return ::QSGVertexColorMaterial::createShader(a0);

    extern ::QSGMaterialShader* sipVH_QtQuick_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QSGRendererInterface::RenderMode);

    return sipVH_QtQuick_56(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQSGVertexColorMaterial::compare(const ::QSGMaterial*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_compare);

    if (!sipMeth)
        return ::QSGVertexColorMaterial::compare(a0);

    extern int sipVH_QtQuick_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QSGMaterial*);

    return sipVH_QtQuick_57(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSGVertexColorMaterial_compare, "compare(self, other: QSGMaterial|None) -> int");

extern "C" {static PyObject *meth_QSGVertexColorMaterial_compare(PyObject *, PyObject *);}
static PyObject *meth_QSGVertexColorMaterial_compare(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSGVertexColorMaterial)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QSGMaterial* a0;
        const ::QSGVertexColorMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QSGVertexColorMaterial, &sipCpp, sipType_QSGMaterial, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSGVertexColorMaterial::compare(a0) : sipCpp->compare(a0));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGVertexColorMaterial, sipName_compare, doc_QSGVertexColorMaterial_compare);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGVertexColorMaterial_type, "type(self) -> QSGMaterialType|None");

extern "C" {static PyObject *meth_QSGVertexColorMaterial_type(PyObject *, PyObject *);}
static PyObject *meth_QSGVertexColorMaterial_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSGVertexColorMaterial)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QSGVertexColorMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QSGVertexColorMaterial, &sipCpp))
        {
            ::QSGMaterialType*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSGVertexColorMaterial::type() : sipCpp->type());

            return sipConvertFromType(sipRes, sipType_QSGMaterialType, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGVertexColorMaterial, sipName_type, doc_QSGVertexColorMaterial_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGVertexColorMaterial_createShader, "createShader(self, renderMode: QSGRendererInterface.RenderMode) -> QSGMaterialShader|None");

extern "C" {static PyObject *meth_QSGVertexColorMaterial_createShader(PyObject *, PyObject *);}
static PyObject *meth_QSGVertexColorMaterial_createShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSGVertexColorMaterial)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QSGRendererInterface::RenderMode a0;
        const ::QSGVertexColorMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QSGVertexColorMaterial, &sipCpp, sipType_QSGRendererInterface_RenderMode, &a0))
        {
            ::QSGMaterialShader*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSGVertexColorMaterial::createShader(a0) : sipCpp->createShader(a0));

            return sipConvertFromType(sipRes, sipType_QSGMaterialShader, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGVertexColorMaterial, sipName_createShader, doc_QSGVertexColorMaterial_createShader);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSGVertexColorMaterial(void *, const sipTypeDef *);}
static void *cast_QSGVertexColorMaterial(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSGVertexColorMaterial *sipCpp = reinterpret_cast< ::QSGVertexColorMaterial *>(sipCppV);

    if (targetType == sipType_QSGVertexColorMaterial)
        return sipCppV;

    if (targetType == sipType_QSGMaterial)
        return static_cast< ::QSGMaterial *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSGVertexColorMaterial(void *, int);}
static void release_QSGVertexColorMaterial(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQSGVertexColorMaterial *>(sipCppV);
    else
        delete reinterpret_cast< ::QSGVertexColorMaterial *>(sipCppV);
}


extern "C" {static void *array_QSGVertexColorMaterial(Py_ssize_t);}
static void *array_QSGVertexColorMaterial(Py_ssize_t sipNrElem)
{
    return new ::QSGVertexColorMaterial[sipNrElem];
}


extern "C" {static void array_delete_QSGVertexColorMaterial(void *);}
static void array_delete_QSGVertexColorMaterial(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSGVertexColorMaterial *>(sipCpp);
}


extern "C" {static void dealloc_QSGVertexColorMaterial(sipSimpleWrapper *);}
static void dealloc_QSGVertexColorMaterial(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSGVertexColorMaterial *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGVertexColorMaterial(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSGVertexColorMaterial(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSGVertexColorMaterial(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQSGVertexColorMaterial *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQSGVertexColorMaterial();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSGVertexColorMaterial[] = {{69, 255, 1}};


static PyMethodDef methods_QSGVertexColorMaterial[] = {
    {sipName_compare, meth_QSGVertexColorMaterial_compare, METH_VARARGS, doc_QSGVertexColorMaterial_compare},
    {sipName_createShader, meth_QSGVertexColorMaterial_createShader, METH_VARARGS, doc_QSGVertexColorMaterial_createShader},
    {sipName_type, meth_QSGVertexColorMaterial_type, METH_VARARGS, doc_QSGVertexColorMaterial_type}
};

PyDoc_STRVAR(doc_QSGVertexColorMaterial, "\1QSGVertexColorMaterial()");


sipClassTypeDef sipTypeDef_QtQuick_QSGVertexColorMaterial = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGVertexColorMaterial,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QSGVertexColorMaterial,
        {0, 0, 1},
        3, methods_QSGVertexColorMaterial,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSGVertexColorMaterial,
    -1,
    -1,
    supers_QSGVertexColorMaterial,
    SIP_NULLPTR,
    init_type_QSGVertexColorMaterial,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSGVertexColorMaterial,
    SIP_NULLPTR,
    array_QSGVertexColorMaterial,
    SIP_NULLPTR,
    release_QSGVertexColorMaterial,
    cast_QSGVertexColorMaterial,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSGVertexColorMaterial,
    sizeof (::QSGVertexColorMaterial),
};
