/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/propertysheet.sip"
#include <propertysheet.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerPropertySheetExtension.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerPropertySheetExtension.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerPropertySheetExtension.cpp"


class sipQDesignerPropertySheetExtension : public ::QDesignerPropertySheetExtension
{
public:
    sipQDesignerPropertySheetExtension();
    virtual ~sipQDesignerPropertySheetExtension();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool isEnabled(int) const SIP_OVERRIDE;
    void setChanged(int, bool) SIP_OVERRIDE;
    bool isChanged(int) const SIP_OVERRIDE;
    void setProperty(int, const ::QVariant&) SIP_OVERRIDE;
    ::QVariant property(int) const SIP_OVERRIDE;
    void setAttribute(int, bool) SIP_OVERRIDE;
    bool isAttribute(int) const SIP_OVERRIDE;
    void setVisible(int, bool) SIP_OVERRIDE;
    bool isVisible(int) const SIP_OVERRIDE;
    bool reset(int) SIP_OVERRIDE;
    bool hasReset(int) const SIP_OVERRIDE;
    void setPropertyGroup(int, const ::QString&) SIP_OVERRIDE;
    ::QString propertyGroup(int) const SIP_OVERRIDE;
    ::QString propertyName(int) const SIP_OVERRIDE;
    int indexOf(const ::QString&) const SIP_OVERRIDE;
    int count() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQDesignerPropertySheetExtension(const sipQDesignerPropertySheetExtension &);
    sipQDesignerPropertySheetExtension &operator = (const sipQDesignerPropertySheetExtension &);

    char sipPyMethods[16];
};

sipQDesignerPropertySheetExtension::sipQDesignerPropertySheetExtension(): ::QDesignerPropertySheetExtension(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQDesignerPropertySheetExtension::~sipQDesignerPropertySheetExtension()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

bool sipQDesignerPropertySheetExtension::isEnabled(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerPropertySheetExtension, sipName_isEnabled);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerPropertySheetExtension::setChanged(int a0, bool a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, sipName_QDesignerPropertySheetExtension, sipName_setChanged);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, bool);

    sipVH_QtDesigner_91(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQDesignerPropertySheetExtension::isChanged(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerPropertySheetExtension, sipName_isChanged);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerPropertySheetExtension::setProperty(int a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, sipName_QDesignerPropertySheetExtension, sipName_setProperty);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_94(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, const ::QVariant&);

    sipVH_QtDesigner_94(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QVariant sipQDesignerPropertySheetExtension::property(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerPropertySheetExtension, sipName_property);

    if (!sipMeth)
        return ::QVariant();

    extern ::QVariant sipVH_QtDesigner_93(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_93(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerPropertySheetExtension::setAttribute(int a0, bool a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, sipName_QDesignerPropertySheetExtension, sipName_setAttribute);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, bool);

    sipVH_QtDesigner_91(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQDesignerPropertySheetExtension::isAttribute(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerPropertySheetExtension, sipName_isAttribute);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerPropertySheetExtension::setVisible(int a0, bool a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, sipName_QDesignerPropertySheetExtension, sipName_setVisible);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, bool);

    sipVH_QtDesigner_91(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQDesignerPropertySheetExtension::isVisible(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerPropertySheetExtension, sipName_isVisible);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQDesignerPropertySheetExtension::reset(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, sipName_QDesignerPropertySheetExtension, sipName_reset);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQDesignerPropertySheetExtension::hasReset(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerPropertySheetExtension, sipName_hasReset);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerPropertySheetExtension::setPropertyGroup(int a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, sipName_QDesignerPropertySheetExtension, sipName_setPropertyGroup);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_90(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, const ::QString&);

    sipVH_QtDesigner_90(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QString sipQDesignerPropertySheetExtension::propertyGroup(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerPropertySheetExtension, sipName_propertyGroup);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_89(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_89(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQDesignerPropertySheetExtension::propertyName(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerPropertySheetExtension, sipName_propertyName);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_89(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_89(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQDesignerPropertySheetExtension::indexOf(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerPropertySheetExtension, sipName_indexOf);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtDesigner_88(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtDesigner_88(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQDesignerPropertySheetExtension::count() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[15]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerPropertySheetExtension, sipName_count);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtDesigner_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_29(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_count, "count(self) -> int");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_count(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_count);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_count, doc_QDesignerPropertySheetExtension_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_indexOf, "indexOf(self, name: str|None) -> int");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_indexOf(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_indexOf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_indexOf);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->indexOf(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_indexOf, doc_QDesignerPropertySheetExtension_indexOf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_propertyName, "propertyName(self, index: int) -> str");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_propertyName(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_propertyName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_propertyName);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->propertyName(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_propertyName, doc_QDesignerPropertySheetExtension_propertyName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_propertyGroup, "propertyGroup(self, index: int) -> str");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_propertyGroup(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_propertyGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_propertyGroup);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->propertyGroup(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_propertyGroup, doc_QDesignerPropertySheetExtension_propertyGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_setPropertyGroup, "setPropertyGroup(self, index: int, group: str|None)");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_setPropertyGroup(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_setPropertyGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QString* a1;
        int a1State = 0;
        ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0, sipType_QString, &a1, &a1State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_setPropertyGroup);
                return SIP_NULLPTR;
            }

            sipCpp->setPropertyGroup(a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_setPropertyGroup, doc_QDesignerPropertySheetExtension_setPropertyGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_hasReset, "hasReset(self, index: int) -> bool");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_hasReset(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_hasReset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_hasReset);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->hasReset(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_hasReset, doc_QDesignerPropertySheetExtension_hasReset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_reset, "reset(self, index: int) -> bool");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_reset(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_reset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_reset);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->reset(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_reset, doc_QDesignerPropertySheetExtension_reset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_isVisible, "isVisible(self, index: int) -> bool");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_isVisible(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_isVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_isVisible);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isVisible(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_isVisible, doc_QDesignerPropertySheetExtension_isVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_setVisible, "setVisible(self, index: int, b: bool)");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_setVisible(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_setVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        bool a1;
        ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bib", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0, &a1))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_setVisible);
                return SIP_NULLPTR;
            }

            sipCpp->setVisible(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_setVisible, doc_QDesignerPropertySheetExtension_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_isAttribute, "isAttribute(self, index: int) -> bool");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_isAttribute(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_isAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_isAttribute);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isAttribute(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_isAttribute, doc_QDesignerPropertySheetExtension_isAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_setAttribute, "setAttribute(self, index: int, b: bool)");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_setAttribute(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_setAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        bool a1;
        ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bib", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0, &a1))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_setAttribute);
                return SIP_NULLPTR;
            }

            sipCpp->setAttribute(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_setAttribute, doc_QDesignerPropertySheetExtension_setAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_property, "property(self, index: int) -> Any");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_property(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_property(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0))
        {
            ::QVariant*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_property);
                return SIP_NULLPTR;
            }

            sipRes = new ::QVariant(sipCpp->property(a0));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_property, doc_QDesignerPropertySheetExtension_property);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_setProperty, "setProperty(self, index: int, value: Any)");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_setProperty(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_setProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0, sipType_QVariant, &a1, &a1State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_setProperty);
                return SIP_NULLPTR;
            }

            sipCpp->setProperty(a0, *a1);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_setProperty, doc_QDesignerPropertySheetExtension_setProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_isChanged, "isChanged(self, index: int) -> bool");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_isChanged(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_isChanged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_isChanged);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isChanged(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_isChanged, doc_QDesignerPropertySheetExtension_isChanged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_setChanged, "setChanged(self, index: int, changed: bool)");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_setChanged(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_setChanged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        bool a1;
        ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bib", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0, &a1))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_setChanged);
                return SIP_NULLPTR;
            }

            sipCpp->setChanged(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_setChanged, doc_QDesignerPropertySheetExtension_setChanged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerPropertySheetExtension_isEnabled, "isEnabled(self, index: int) -> bool");

extern "C" {static PyObject *meth_QDesignerPropertySheetExtension_isEnabled(PyObject *, PyObject *);}
static PyObject *meth_QDesignerPropertySheetExtension_isEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerPropertySheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerPropertySheetExtension, &sipCpp, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerPropertySheetExtension, sipName_isEnabled);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isEnabled(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerPropertySheetExtension, sipName_isEnabled, doc_QDesignerPropertySheetExtension_isEnabled);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QDesignerPropertySheetExtension___len__(PyObject *);}
static Py_ssize_t slot_QDesignerPropertySheetExtension___len__(PyObject *sipSelf)
{
    ::QDesignerPropertySheetExtension *sipCpp = reinterpret_cast< ::QDesignerPropertySheetExtension *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QDesignerPropertySheetExtension));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 892 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerPropertySheetExtension.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDesignerPropertySheetExtension(void *, int);}
static void release_QDesignerPropertySheetExtension(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQDesignerPropertySheetExtension *>(sipCppV);
    else
        delete reinterpret_cast< ::QDesignerPropertySheetExtension *>(sipCppV);
}


extern "C" {static void dealloc_QDesignerPropertySheetExtension(sipSimpleWrapper *);}
static void dealloc_QDesignerPropertySheetExtension(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQDesignerPropertySheetExtension *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDesignerPropertySheetExtension(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QDesignerPropertySheetExtension(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDesignerPropertySheetExtension(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQDesignerPropertySheetExtension *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQDesignerPropertySheetExtension();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QDesignerPropertySheetExtension[] = {
    {(void *)slot_QDesignerPropertySheetExtension___len__, len_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QDesignerPropertySheetExtension[] = {
    {sipName_count, meth_QDesignerPropertySheetExtension_count, METH_VARARGS, doc_QDesignerPropertySheetExtension_count},
    {sipName_hasReset, meth_QDesignerPropertySheetExtension_hasReset, METH_VARARGS, doc_QDesignerPropertySheetExtension_hasReset},
    {sipName_indexOf, meth_QDesignerPropertySheetExtension_indexOf, METH_VARARGS, doc_QDesignerPropertySheetExtension_indexOf},
    {sipName_isAttribute, meth_QDesignerPropertySheetExtension_isAttribute, METH_VARARGS, doc_QDesignerPropertySheetExtension_isAttribute},
    {sipName_isChanged, meth_QDesignerPropertySheetExtension_isChanged, METH_VARARGS, doc_QDesignerPropertySheetExtension_isChanged},
    {sipName_isEnabled, meth_QDesignerPropertySheetExtension_isEnabled, METH_VARARGS, doc_QDesignerPropertySheetExtension_isEnabled},
    {sipName_isVisible, meth_QDesignerPropertySheetExtension_isVisible, METH_VARARGS, doc_QDesignerPropertySheetExtension_isVisible},
    {sipName_property, meth_QDesignerPropertySheetExtension_property, METH_VARARGS, doc_QDesignerPropertySheetExtension_property},
    {sipName_propertyGroup, meth_QDesignerPropertySheetExtension_propertyGroup, METH_VARARGS, doc_QDesignerPropertySheetExtension_propertyGroup},
    {sipName_propertyName, meth_QDesignerPropertySheetExtension_propertyName, METH_VARARGS, doc_QDesignerPropertySheetExtension_propertyName},
    {sipName_reset, meth_QDesignerPropertySheetExtension_reset, METH_VARARGS, doc_QDesignerPropertySheetExtension_reset},
    {sipName_setAttribute, meth_QDesignerPropertySheetExtension_setAttribute, METH_VARARGS, doc_QDesignerPropertySheetExtension_setAttribute},
    {sipName_setChanged, meth_QDesignerPropertySheetExtension_setChanged, METH_VARARGS, doc_QDesignerPropertySheetExtension_setChanged},
    {sipName_setProperty, meth_QDesignerPropertySheetExtension_setProperty, METH_VARARGS, doc_QDesignerPropertySheetExtension_setProperty},
    {sipName_setPropertyGroup, meth_QDesignerPropertySheetExtension_setPropertyGroup, METH_VARARGS, doc_QDesignerPropertySheetExtension_setPropertyGroup},
    {sipName_setVisible, meth_QDesignerPropertySheetExtension_setVisible, METH_VARARGS, doc_QDesignerPropertySheetExtension_setVisible}
};

PyDoc_STRVAR(doc_QDesignerPropertySheetExtension, "\1QDesignerPropertySheetExtension()");


sipClassTypeDef sipTypeDef_QtDesigner_QDesignerPropertySheetExtension = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDesignerPropertySheetExtension,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QDesignerPropertySheetExtension,
        {0, 0, 1},
        16, methods_QDesignerPropertySheetExtension,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDesignerPropertySheetExtension,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QDesignerPropertySheetExtension,
    init_type_QDesignerPropertySheetExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDesignerPropertySheetExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QDesignerPropertySheetExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QDesignerPropertySheetExtension),
};
