/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebSockets.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWebSockets/qwebsocket.sip"
#include <qwebsocket.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWebSockets/qwebsocketprotocol.sip"
#include <qwebsocketprotocol.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qauthenticator.sip"
#include <qauthenticator.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWebSockets/qwebsockethandshakeoptions.sip"
#include <qwebsockethandshakeoptions.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslerror.sip"
#include <qsslerror.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qssl.sip"
#include <qssl.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslpresharedkeyauthenticator.sip"
#include <qsslpresharedkeyauthenticator.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qnetworkproxy.sip"
#include <qnetworkproxy.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslconfiguration.sip"
#include <qsslconfiguration.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 78 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWebSockets/qmaskgenerator.sip"
#include <qmaskgenerator.h>
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qhostaddress.sip"
#include <qhostaddress.h>
#line 84 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 118 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 124 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 127 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 130 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocket.cpp"


class sipQWebSocket : public ::QWebSocket
{
public:
    sipQWebSocket(const ::QString&, ::QWebSocketProtocol::Version, ::QObject*);
    virtual ~sipQWebSocket();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQWebSocket(const sipQWebSocket &);
    sipQWebSocket &operator = (const sipQWebSocket &);

    char sipPyMethods[7];
};

sipQWebSocket::sipQWebSocket(const ::QString& a0, ::QWebSocketProtocol::Version a1, ::QObject*a2): ::QWebSocket(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQWebSocket::~sipQWebSocket()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQWebSocket::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWebSockets_qt_metaobject(sipPySelf, sipType_QWebSocket);

    return ::QWebSocket::metaObject();
}

int sipQWebSocket::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QWebSocket::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWebSockets_qt_metacall(sipPySelf, sipType_QWebSocket, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQWebSocket::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWebSockets_qt_metacast(sipPySelf, sipType_QWebSocket, _clname, &sipCpp) ? sipCpp : ::QWebSocket::qt_metacast(_clname));
}

bool sipQWebSocket::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QWebSocket::event(a0);

    extern bool sipVH_QtWebSockets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWebSockets_5(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebSocket::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QWebSocket::eventFilter(a0, a1);

    extern bool sipVH_QtWebSockets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWebSockets_4(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQWebSocket::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QWebSocket::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWebSockets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWebSockets_3(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebSocket::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QWebSocket::childEvent(a0);
        return;
    }

    extern void sipVH_QtWebSockets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWebSockets_2(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebSocket::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QWebSocket::customEvent(a0);
        return;
    }

    extern void sipVH_QtWebSockets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebSockets_1(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebSocket::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QWebSocket::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWebSockets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebSockets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebSocket::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QWebSocket::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWebSockets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebSockets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QWebSocket_abort, "abort(self)");

extern "C" {static PyObject *meth_QWebSocket_abort(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_abort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            sipCpp->abort();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_abort, doc_QWebSocket_abort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_error, "error(self) -> QAbstractSocket.SocketError");

extern "C" {static PyObject *meth_QWebSocket_error(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QAbstractSocket::SocketError sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractSocket_SocketError);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_error, doc_QWebSocket_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QWebSocket_errorString(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_errorString, doc_QWebSocket_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_flush, "flush(self) -> bool");

extern "C" {static PyObject *meth_QWebSocket_flush(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_flush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->flush();
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_flush, doc_QWebSocket_flush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QWebSocket_isValid(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_isValid, doc_QWebSocket_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_localAddress, "localAddress(self) -> QHostAddress");

extern "C" {static PyObject *meth_QWebSocket_localAddress(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_localAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QHostAddress*sipRes;

            sipRes = new ::QHostAddress(sipCpp->localAddress());

            return sipConvertFromNewType(sipRes, sipType_QHostAddress, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_localAddress, doc_QWebSocket_localAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_localPort, "localPort(self) -> int");

extern "C" {static PyObject *meth_QWebSocket_localPort(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_localPort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::quint16 sipRes;

            sipRes = sipCpp->localPort();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_localPort, doc_QWebSocket_localPort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_pauseMode, "pauseMode(self) -> QAbstractSocket.PauseMode");

extern "C" {static PyObject *meth_QWebSocket_pauseMode(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_pauseMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QAbstractSocket::PauseModes*sipRes;

            sipRes = new ::QAbstractSocket::PauseModes(sipCpp->pauseMode());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QAbstractSocket_PauseMode, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_pauseMode, doc_QWebSocket_pauseMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_peerAddress, "peerAddress(self) -> QHostAddress");

extern "C" {static PyObject *meth_QWebSocket_peerAddress(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_peerAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QHostAddress*sipRes;

            sipRes = new ::QHostAddress(sipCpp->peerAddress());

            return sipConvertFromNewType(sipRes, sipType_QHostAddress, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_peerAddress, doc_QWebSocket_peerAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_peerName, "peerName(self) -> str");

extern "C" {static PyObject *meth_QWebSocket_peerName(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_peerName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->peerName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_peerName, doc_QWebSocket_peerName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_peerPort, "peerPort(self) -> int");

extern "C" {static PyObject *meth_QWebSocket_peerPort(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_peerPort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::quint16 sipRes;

            sipRes = sipCpp->peerPort();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_peerPort, doc_QWebSocket_peerPort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_proxy, "proxy(self) -> QNetworkProxy");

extern "C" {static PyObject *meth_QWebSocket_proxy(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_proxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QNetworkProxy*sipRes;

            sipRes = new ::QNetworkProxy(sipCpp->proxy());

            return sipConvertFromNewType(sipRes, sipType_QNetworkProxy, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_proxy, doc_QWebSocket_proxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_setProxy, "setProxy(self, networkProxy: QNetworkProxy)");

extern "C" {static PyObject *meth_QWebSocket_setProxy(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_setProxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNetworkProxy* a0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QNetworkProxy, &a0))
        {
            sipCpp->setProxy(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_setProxy, doc_QWebSocket_setProxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_setMaskGenerator, "setMaskGenerator(self, maskGenerator: QMaskGenerator|None)");

extern "C" {static PyObject *meth_QWebSocket_setMaskGenerator(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_setMaskGenerator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMaskGenerator* a0;
        PyObject *a0Keep;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QWebSocket, &sipCpp, &a0Keep, sipType_QMaskGenerator, &a0))
        {
            sipCpp->setMaskGenerator(a0);

            sipKeepReference(sipSelf, -1, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_setMaskGenerator, doc_QWebSocket_setMaskGenerator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_maskGenerator, "maskGenerator(self) -> QMaskGenerator|None");

extern "C" {static PyObject *meth_QWebSocket_maskGenerator(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_maskGenerator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            const ::QMaskGenerator*sipRes;

            sipRes = sipCpp->maskGenerator();

            return sipConvertFromType(const_cast< ::QMaskGenerator *>(sipRes), sipType_QMaskGenerator, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_maskGenerator, doc_QWebSocket_maskGenerator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_readBufferSize, "readBufferSize(self) -> int");

extern "C" {static PyObject *meth_QWebSocket_readBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_readBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->readBufferSize();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_readBufferSize, doc_QWebSocket_readBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_setReadBufferSize, "setReadBufferSize(self, size: int)");

extern "C" {static PyObject *meth_QWebSocket_setReadBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_setReadBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QWebSocket, &sipCpp, &a0))
        {
            sipCpp->setReadBufferSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_setReadBufferSize, doc_QWebSocket_setReadBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_resume, "resume(self)");

extern "C" {static PyObject *meth_QWebSocket_resume(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_resume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->resume();
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_resume, doc_QWebSocket_resume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_setPauseMode, "setPauseMode(self, pauseMode: QAbstractSocket.PauseMode)");

extern "C" {static PyObject *meth_QWebSocket_setPauseMode(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_setPauseMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractSocket::PauseModes* a0;
        int a0State = 0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QFlags_0100QAbstractSocket_PauseMode, &a0, &a0State))
        {
            sipCpp->setPauseMode(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QAbstractSocket_PauseMode, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_setPauseMode, doc_QWebSocket_setPauseMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_state, "state(self) -> QAbstractSocket.SocketState");

extern "C" {static PyObject *meth_QWebSocket_state(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QAbstractSocket::SocketState sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractSocket_SocketState);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_state, doc_QWebSocket_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_version, "version(self) -> QWebSocketProtocol.Version");

extern "C" {static PyObject *meth_QWebSocket_version(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_version(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QWebSocketProtocol::Version sipRes;

            sipRes = sipCpp->version();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QWebSocketProtocol_Version);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_version, doc_QWebSocket_version);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_resourceName, "resourceName(self) -> str");

extern "C" {static PyObject *meth_QWebSocket_resourceName(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_resourceName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->resourceName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_resourceName, doc_QWebSocket_resourceName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_requestUrl, "requestUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QWebSocket_requestUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_requestUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->requestUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_requestUrl, doc_QWebSocket_requestUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_origin, "origin(self) -> str");

extern "C" {static PyObject *meth_QWebSocket_origin(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_origin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->origin());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_origin, doc_QWebSocket_origin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_closeCode, "closeCode(self) -> QWebSocketProtocol.CloseCode");

extern "C" {static PyObject *meth_QWebSocket_closeCode(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_closeCode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QWebSocketProtocol::CloseCode sipRes;

            sipRes = sipCpp->closeCode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QWebSocketProtocol_CloseCode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_closeCode, doc_QWebSocket_closeCode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_closeReason, "closeReason(self) -> str");

extern "C" {static PyObject *meth_QWebSocket_closeReason(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_closeReason(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->closeReason());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_closeReason, doc_QWebSocket_closeReason);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_sendTextMessage, "sendTextMessage(self, message: str|None) -> int");

extern "C" {static PyObject *meth_QWebSocket_sendTextMessage(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_sendTextMessage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::qint64 sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->sendTextMessage(*a0);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_sendTextMessage, doc_QWebSocket_sendTextMessage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_sendBinaryMessage, "sendBinaryMessage(self, data: QByteArray|bytes|bytearray|memoryview) -> int");

extern "C" {static PyObject *meth_QWebSocket_sendBinaryMessage(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_sendBinaryMessage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            ::qint64 sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->sendBinaryMessage(*a0);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_sendBinaryMessage, doc_QWebSocket_sendBinaryMessage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_ignoreSslErrors, "ignoreSslErrors(self, errors: Iterable[QSslError])\n"
"ignoreSslErrors(self)");

extern "C" {static PyObject *meth_QWebSocket_ignoreSslErrors(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_ignoreSslErrors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QSslError>* a0;
        int a0State = 0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QList_0100QSslError, &a0, &a0State))
        {
            sipCpp->ignoreSslErrors(*a0);
            sipReleaseType(const_cast<QList< ::QSslError> *>(a0), sipType_QList_0100QSslError, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            sipCpp->ignoreSslErrors();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_ignoreSslErrors, doc_QWebSocket_ignoreSslErrors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_setSslConfiguration, "setSslConfiguration(self, sslConfiguration: QSslConfiguration)");

extern "C" {static PyObject *meth_QWebSocket_setSslConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_setSslConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSslConfiguration* a0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QSslConfiguration, &a0))
        {
            sipCpp->setSslConfiguration(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_setSslConfiguration, doc_QWebSocket_setSslConfiguration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_sslConfiguration, "sslConfiguration(self) -> QSslConfiguration");

extern "C" {static PyObject *meth_QWebSocket_sslConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_sslConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QSslConfiguration*sipRes;

            sipRes = new ::QSslConfiguration(sipCpp->sslConfiguration());

            return sipConvertFromNewType(sipRes, sipType_QSslConfiguration, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_sslConfiguration, doc_QWebSocket_sslConfiguration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_request, "request(self) -> QNetworkRequest");

extern "C" {static PyObject *meth_QWebSocket_request(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_request(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QNetworkRequest*sipRes;

            sipRes = new ::QNetworkRequest(sipCpp->request());

            return sipConvertFromNewType(sipRes, sipType_QNetworkRequest, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_request, doc_QWebSocket_request);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_close, "close(self, closeCode: QWebSocketProtocol.CloseCode = QWebSocketProtocol.CloseCodeNormal, reason: str|None = '')");

extern "C" {static PyObject *meth_QWebSocket_close(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_close(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSocketProtocol::CloseCode a0 = QWebSocketProtocol::CloseCodeNormal;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        ::QWebSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_closeCode,
            sipName_reason,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|EJ1", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QWebSocketProtocol_CloseCode, &a0, sipType_QString, &a1, &a1State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->close(a0, *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_close, doc_QWebSocket_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_open, "open(self, request: QNetworkRequest, options: QWebSocketHandshakeOptions)\n"
"open(self, url: QUrl, options: QWebSocketHandshakeOptions)\n"
"open(self, url: QUrl)\n"
"open(self, request: QNetworkRequest)");

extern "C" {static PyObject *meth_QWebSocket_open(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_open(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNetworkRequest* a0;
        const ::QWebSocketHandshakeOptions* a1;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QWebSocketHandshakeOptions, &a1))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->open(*a0, *a1);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QUrl* a0;
        const ::QWebSocketHandshakeOptions* a1;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QUrl, &a0, sipType_QWebSocketHandshakeOptions, &a1))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->open(*a0, *a1);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QUrl* a0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QUrl, &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->open(*a0);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QNetworkRequest* a0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QNetworkRequest, &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->open(*a0);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_open, doc_QWebSocket_open);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_ping, "ping(self, payload: QByteArray|bytes|bytearray|memoryview = QByteArray())");

extern "C" {static PyObject *meth_QWebSocket_ping(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_ping(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray& a0def = QByteArray();
        const ::QByteArray* a0 = &a0def;
        int a0State = 0;
        ::QWebSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_payload,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QWebSocket, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->ping(*a0);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_ping, doc_QWebSocket_ping);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_bytesToWrite, "bytesToWrite(self) -> int");

extern "C" {static PyObject *meth_QWebSocket_bytesToWrite(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_bytesToWrite(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->bytesToWrite();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_bytesToWrite, doc_QWebSocket_bytesToWrite);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_setMaxAllowedIncomingFrameSize, "setMaxAllowedIncomingFrameSize(self, maxAllowedIncomingFrameSize: int)");

extern "C" {static PyObject *meth_QWebSocket_setMaxAllowedIncomingFrameSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_setMaxAllowedIncomingFrameSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint64 a0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bo", &sipSelf, sipType_QWebSocket, &sipCpp, &a0))
        {
            sipCpp->setMaxAllowedIncomingFrameSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_setMaxAllowedIncomingFrameSize, doc_QWebSocket_setMaxAllowedIncomingFrameSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_maxAllowedIncomingFrameSize, "maxAllowedIncomingFrameSize(self) -> int");

extern "C" {static PyObject *meth_QWebSocket_maxAllowedIncomingFrameSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_maxAllowedIncomingFrameSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::quint64 sipRes;

            sipRes = sipCpp->maxAllowedIncomingFrameSize();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_maxAllowedIncomingFrameSize, doc_QWebSocket_maxAllowedIncomingFrameSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_setMaxAllowedIncomingMessageSize, "setMaxAllowedIncomingMessageSize(self, maxAllowedIncomingMessageSize: int)");

extern "C" {static PyObject *meth_QWebSocket_setMaxAllowedIncomingMessageSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_setMaxAllowedIncomingMessageSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint64 a0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bo", &sipSelf, sipType_QWebSocket, &sipCpp, &a0))
        {
            sipCpp->setMaxAllowedIncomingMessageSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_setMaxAllowedIncomingMessageSize, doc_QWebSocket_setMaxAllowedIncomingMessageSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_maxAllowedIncomingMessageSize, "maxAllowedIncomingMessageSize(self) -> int");

extern "C" {static PyObject *meth_QWebSocket_maxAllowedIncomingMessageSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_maxAllowedIncomingMessageSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::quint64 sipRes;

            sipRes = sipCpp->maxAllowedIncomingMessageSize();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_maxAllowedIncomingMessageSize, doc_QWebSocket_maxAllowedIncomingMessageSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_maxIncomingMessageSize, "maxIncomingMessageSize() -> int");

extern "C" {static PyObject *meth_QWebSocket_maxIncomingMessageSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_maxIncomingMessageSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::quint64 sipRes;

            sipRes = ::QWebSocket::maxIncomingMessageSize();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_maxIncomingMessageSize, doc_QWebSocket_maxIncomingMessageSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_maxIncomingFrameSize, "maxIncomingFrameSize() -> int");

extern "C" {static PyObject *meth_QWebSocket_maxIncomingFrameSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_maxIncomingFrameSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::quint64 sipRes;

            sipRes = ::QWebSocket::maxIncomingFrameSize();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_maxIncomingFrameSize, doc_QWebSocket_maxIncomingFrameSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_setOutgoingFrameSize, "setOutgoingFrameSize(self, outgoingFrameSize: int)");

extern "C" {static PyObject *meth_QWebSocket_setOutgoingFrameSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_setOutgoingFrameSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint64 a0;
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bo", &sipSelf, sipType_QWebSocket, &sipCpp, &a0))
        {
            sipCpp->setOutgoingFrameSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_setOutgoingFrameSize, doc_QWebSocket_setOutgoingFrameSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_outgoingFrameSize, "outgoingFrameSize(self) -> int");

extern "C" {static PyObject *meth_QWebSocket_outgoingFrameSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_outgoingFrameSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::quint64 sipRes;

            sipRes = sipCpp->outgoingFrameSize();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_outgoingFrameSize, doc_QWebSocket_outgoingFrameSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_maxOutgoingFrameSize, "maxOutgoingFrameSize() -> int");

extern "C" {static PyObject *meth_QWebSocket_maxOutgoingFrameSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_maxOutgoingFrameSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::quint64 sipRes;

            sipRes = ::QWebSocket::maxOutgoingFrameSize();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_maxOutgoingFrameSize, doc_QWebSocket_maxOutgoingFrameSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_continueInterruptedHandshake, "continueInterruptedHandshake(self)");

extern "C" {static PyObject *meth_QWebSocket_continueInterruptedHandshake(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_continueInterruptedHandshake(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            sipCpp->continueInterruptedHandshake();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_continueInterruptedHandshake, doc_QWebSocket_continueInterruptedHandshake);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_handshakeOptions, "handshakeOptions(self) -> QWebSocketHandshakeOptions");

extern "C" {static PyObject *meth_QWebSocket_handshakeOptions(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_handshakeOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QWebSocketHandshakeOptions*sipRes;

            sipRes = new ::QWebSocketHandshakeOptions(sipCpp->handshakeOptions());

            return sipConvertFromNewType(sipRes, sipType_QWebSocketHandshakeOptions, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_handshakeOptions, doc_QWebSocket_handshakeOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocket_subprotocol, "subprotocol(self) -> str");

extern "C" {static PyObject *meth_QWebSocket_subprotocol(PyObject *, PyObject *);}
static PyObject *meth_QWebSocket_subprotocol(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocket, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->subprotocol());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocket, sipName_subprotocol, doc_QWebSocket_subprotocol);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWebSocket(void *, const sipTypeDef *);}
static void *cast_QWebSocket(void *sipCppV, const sipTypeDef *targetType)
{
    ::QWebSocket *sipCpp = reinterpret_cast< ::QWebSocket *>(sipCppV);

    if (targetType == sipType_QWebSocket)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebSocket(void *, int);}
static void release_QWebSocket(void *sipCppV, int)
{
    ::QWebSocket *sipCpp = reinterpret_cast< ::QWebSocket *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QWebSocket(Py_ssize_t);}
static void *array_QWebSocket(Py_ssize_t sipNrElem)
{
    return new ::QWebSocket[sipNrElem];
}


extern "C" {static void array_delete_QWebSocket(void *);}
static void array_delete_QWebSocket(void *sipCpp)
{
    delete[] reinterpret_cast< ::QWebSocket *>(sipCpp);
}


extern "C" {static void dealloc_QWebSocket(sipSimpleWrapper *);}
static void dealloc_QWebSocket(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQWebSocket *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebSocket(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QWebSocket(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebSocket(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQWebSocket *sipCpp = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;
        ::QWebSocketProtocol::Version a1 = QWebSocketProtocol::VersionLatest;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            sipName_origin,
            sipName_version,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|J1EJH", sipType_QString, &a0, &a0State, sipType_QWebSocketProtocol_Version, &a1, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQWebSocket(*a0, a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWebSocket[] = {{4, 0, 1}};


static PyMethodDef methods_QWebSocket[] = {
    {sipName_abort, meth_QWebSocket_abort, METH_VARARGS, doc_QWebSocket_abort},
    {sipName_bytesToWrite, meth_QWebSocket_bytesToWrite, METH_VARARGS, doc_QWebSocket_bytesToWrite},
    {sipName_close, SIP_MLMETH_CAST(meth_QWebSocket_close), METH_VARARGS|METH_KEYWORDS, doc_QWebSocket_close},
    {sipName_closeCode, meth_QWebSocket_closeCode, METH_VARARGS, doc_QWebSocket_closeCode},
    {sipName_closeReason, meth_QWebSocket_closeReason, METH_VARARGS, doc_QWebSocket_closeReason},
    {sipName_continueInterruptedHandshake, meth_QWebSocket_continueInterruptedHandshake, METH_VARARGS, doc_QWebSocket_continueInterruptedHandshake},
    {sipName_error, meth_QWebSocket_error, METH_VARARGS, doc_QWebSocket_error},
    {sipName_errorString, meth_QWebSocket_errorString, METH_VARARGS, doc_QWebSocket_errorString},
    {sipName_flush, meth_QWebSocket_flush, METH_VARARGS, doc_QWebSocket_flush},
    {sipName_handshakeOptions, meth_QWebSocket_handshakeOptions, METH_VARARGS, doc_QWebSocket_handshakeOptions},
    {sipName_ignoreSslErrors, meth_QWebSocket_ignoreSslErrors, METH_VARARGS, doc_QWebSocket_ignoreSslErrors},
    {sipName_isValid, meth_QWebSocket_isValid, METH_VARARGS, doc_QWebSocket_isValid},
    {sipName_localAddress, meth_QWebSocket_localAddress, METH_VARARGS, doc_QWebSocket_localAddress},
    {sipName_localPort, meth_QWebSocket_localPort, METH_VARARGS, doc_QWebSocket_localPort},
    {sipName_maskGenerator, meth_QWebSocket_maskGenerator, METH_VARARGS, doc_QWebSocket_maskGenerator},
    {sipName_maxAllowedIncomingFrameSize, meth_QWebSocket_maxAllowedIncomingFrameSize, METH_VARARGS, doc_QWebSocket_maxAllowedIncomingFrameSize},
    {sipName_maxAllowedIncomingMessageSize, meth_QWebSocket_maxAllowedIncomingMessageSize, METH_VARARGS, doc_QWebSocket_maxAllowedIncomingMessageSize},
    {sipName_maxIncomingFrameSize, meth_QWebSocket_maxIncomingFrameSize, METH_VARARGS, doc_QWebSocket_maxIncomingFrameSize},
    {sipName_maxIncomingMessageSize, meth_QWebSocket_maxIncomingMessageSize, METH_VARARGS, doc_QWebSocket_maxIncomingMessageSize},
    {sipName_maxOutgoingFrameSize, meth_QWebSocket_maxOutgoingFrameSize, METH_VARARGS, doc_QWebSocket_maxOutgoingFrameSize},
    {sipName_open, meth_QWebSocket_open, METH_VARARGS, doc_QWebSocket_open},
    {sipName_origin, meth_QWebSocket_origin, METH_VARARGS, doc_QWebSocket_origin},
    {sipName_outgoingFrameSize, meth_QWebSocket_outgoingFrameSize, METH_VARARGS, doc_QWebSocket_outgoingFrameSize},
    {sipName_pauseMode, meth_QWebSocket_pauseMode, METH_VARARGS, doc_QWebSocket_pauseMode},
    {sipName_peerAddress, meth_QWebSocket_peerAddress, METH_VARARGS, doc_QWebSocket_peerAddress},
    {sipName_peerName, meth_QWebSocket_peerName, METH_VARARGS, doc_QWebSocket_peerName},
    {sipName_peerPort, meth_QWebSocket_peerPort, METH_VARARGS, doc_QWebSocket_peerPort},
    {sipName_ping, SIP_MLMETH_CAST(meth_QWebSocket_ping), METH_VARARGS|METH_KEYWORDS, doc_QWebSocket_ping},
    {sipName_proxy, meth_QWebSocket_proxy, METH_VARARGS, doc_QWebSocket_proxy},
    {sipName_readBufferSize, meth_QWebSocket_readBufferSize, METH_VARARGS, doc_QWebSocket_readBufferSize},
    {sipName_request, meth_QWebSocket_request, METH_VARARGS, doc_QWebSocket_request},
    {sipName_requestUrl, meth_QWebSocket_requestUrl, METH_VARARGS, doc_QWebSocket_requestUrl},
    {sipName_resourceName, meth_QWebSocket_resourceName, METH_VARARGS, doc_QWebSocket_resourceName},
    {sipName_resume, meth_QWebSocket_resume, METH_VARARGS, doc_QWebSocket_resume},
    {sipName_sendBinaryMessage, meth_QWebSocket_sendBinaryMessage, METH_VARARGS, doc_QWebSocket_sendBinaryMessage},
    {sipName_sendTextMessage, meth_QWebSocket_sendTextMessage, METH_VARARGS, doc_QWebSocket_sendTextMessage},
    {sipName_setMaskGenerator, meth_QWebSocket_setMaskGenerator, METH_VARARGS, doc_QWebSocket_setMaskGenerator},
    {sipName_setMaxAllowedIncomingFrameSize, meth_QWebSocket_setMaxAllowedIncomingFrameSize, METH_VARARGS, doc_QWebSocket_setMaxAllowedIncomingFrameSize},
    {sipName_setMaxAllowedIncomingMessageSize, meth_QWebSocket_setMaxAllowedIncomingMessageSize, METH_VARARGS, doc_QWebSocket_setMaxAllowedIncomingMessageSize},
    {sipName_setOutgoingFrameSize, meth_QWebSocket_setOutgoingFrameSize, METH_VARARGS, doc_QWebSocket_setOutgoingFrameSize},
    {sipName_setPauseMode, meth_QWebSocket_setPauseMode, METH_VARARGS, doc_QWebSocket_setPauseMode},
    {sipName_setProxy, meth_QWebSocket_setProxy, METH_VARARGS, doc_QWebSocket_setProxy},
    {sipName_setReadBufferSize, meth_QWebSocket_setReadBufferSize, METH_VARARGS, doc_QWebSocket_setReadBufferSize},
    {sipName_setSslConfiguration, meth_QWebSocket_setSslConfiguration, METH_VARARGS, doc_QWebSocket_setSslConfiguration},
    {sipName_sslConfiguration, meth_QWebSocket_sslConfiguration, METH_VARARGS, doc_QWebSocket_sslConfiguration},
    {sipName_state, meth_QWebSocket_state, METH_VARARGS, doc_QWebSocket_state},
    {sipName_subprotocol, meth_QWebSocket_subprotocol, METH_VARARGS, doc_QWebSocket_subprotocol},
    {sipName_version, meth_QWebSocket_version, METH_VARARGS, doc_QWebSocket_version}
};

PyDoc_STRVAR(doc_QWebSocket, "\1QWebSocket(origin: str|None = '', version: QWebSocketProtocol.Version = QWebSocketProtocol.VersionLatest, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QWebSocket[] = {
    {"authenticationRequired(QAuthenticator*)", "\1authenticationRequired(self, authenticator: QAuthenticator|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorOccurred(QAbstractSocket::SocketError)", "\1errorOccurred(self, error: QAbstractSocket.SocketError)", SIP_NULLPTR, SIP_NULLPTR},
    {"handshakeInterruptedOnError(QSslError)", "\1handshakeInterruptedOnError(self, error: QSslError)", SIP_NULLPTR, SIP_NULLPTR},
    {"alertReceived(QSsl::AlertLevel,QSsl::AlertType,QString)", "\1alertReceived(self, level: QSsl.AlertLevel, type: QSsl.AlertType, description: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"alertSent(QSsl::AlertLevel,QSsl::AlertType,QString)", "\1alertSent(self, level: QSsl.AlertLevel, type: QSsl.AlertType, description: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"peerVerifyError(QSslError)", "\1peerVerifyError(self, error: QSslError)", SIP_NULLPTR, SIP_NULLPTR},
    {"preSharedKeyAuthenticationRequired(QSslPreSharedKeyAuthenticator*)", "\1preSharedKeyAuthenticationRequired(self, authenticator: QSslPreSharedKeyAuthenticator|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"sslErrors(QList<QSslError>)", "\1sslErrors(self, errors: Iterable[QSslError])", SIP_NULLPTR, SIP_NULLPTR},
    {"bytesWritten(qint64)", "\1bytesWritten(self, bytes: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"pong(quint64,QByteArray)", "\1pong(self, elapsedTime: int, payload: QByteArray|bytes|bytearray|memoryview)", SIP_NULLPTR, SIP_NULLPTR},
    {"binaryMessageReceived(QByteArray)", "\1binaryMessageReceived(self, message: QByteArray|bytes|bytearray|memoryview)", SIP_NULLPTR, SIP_NULLPTR},
    {"textMessageReceived(QString)", "\1textMessageReceived(self, message: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"binaryFrameReceived(QByteArray,bool)", "\1binaryFrameReceived(self, frame: QByteArray|bytes|bytearray|memoryview, isLastFrame: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"textFrameReceived(QString,bool)", "\1textFrameReceived(self, frame: str|None, isLastFrame: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"readChannelFinished()", "\1readChannelFinished(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)", "\1proxyAuthenticationRequired(self, proxy: QNetworkProxy, pAuthenticator: QAuthenticator|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QAbstractSocket::SocketState)", "\1stateChanged(self, state: QAbstractSocket.SocketState)", SIP_NULLPTR, SIP_NULLPTR},
    {"disconnected()", "\1disconnected(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"connected()", "\1connected(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"aboutToClose()", "\1aboutToClose(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QAbstractSocket::SocketError)", "\1error(self, error: QAbstractSocket.SocketError)", &methods_QWebSocket[6], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QWebSocket = {
    &::QWebSocket::staticMetaObject,
    signals_QWebSocket,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebSockets_QWebSocket = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebSocket,
        SIP_NULLPTR,
        &plugin_QWebSocket,
    },
    {
        sipNameNr_QWebSocket,
        {0, 0, 1},
        48, methods_QWebSocket,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebSocket,
    -1,
    -1,
    supers_QWebSocket,
    SIP_NULLPTR,
    init_type_QWebSocket,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebSocket,
    SIP_NULLPTR,
    array_QWebSocket,
    SIP_NULLPTR,
    release_QWebSocket,
    cast_QWebSocket,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QWebSocket,
    sizeof (::QWebSocket),
};
