/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 164 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 64 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 67 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsOpacityEffect.cpp"


class sipQGraphicsOpacityEffect : public ::QGraphicsOpacityEffect
{
public:
    sipQGraphicsOpacityEffect(::QObject*);
    virtual ~sipQGraphicsOpacityEffect();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QRectF boundingRectFor(const ::QRectF&) const SIP_OVERRIDE;
    void draw(::QPainter*) SIP_OVERRIDE;
    void sourceChanged(::QGraphicsEffect::ChangeFlags) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGraphicsOpacityEffect(const sipQGraphicsOpacityEffect &);
    sipQGraphicsOpacityEffect &operator = (const sipQGraphicsOpacityEffect &);

    char sipPyMethods[10];
};

sipQGraphicsOpacityEffect::sipQGraphicsOpacityEffect(::QObject*a0): ::QGraphicsOpacityEffect(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGraphicsOpacityEffect::~sipQGraphicsOpacityEffect()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGraphicsOpacityEffect::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QGraphicsOpacityEffect);

    return ::QGraphicsOpacityEffect::metaObject();
}

int sipQGraphicsOpacityEffect::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGraphicsOpacityEffect::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QGraphicsOpacityEffect, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGraphicsOpacityEffect::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QGraphicsOpacityEffect, _clname, &sipCpp) ? sipCpp : ::QGraphicsOpacityEffect::qt_metacast(_clname));
}

void sipQGraphicsOpacityEffect::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGraphicsOpacityEffect::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsOpacityEffect::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGraphicsOpacityEffect::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsOpacityEffect::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGraphicsOpacityEffect::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsOpacityEffect::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGraphicsOpacityEffect::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsOpacityEffect::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGraphicsOpacityEffect::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsOpacityEffect::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGraphicsOpacityEffect::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsOpacityEffect::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGraphicsOpacityEffect::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRectF sipQGraphicsOpacityEffect::boundingRectFor(const ::QRectF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_boundingRectFor);

    if (!sipMeth)
        return ::QGraphicsOpacityEffect::boundingRectFor(a0);

    extern ::QRectF sipVH_QtWidgets_136(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRectF&);

    return sipVH_QtWidgets_136(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsOpacityEffect::draw(::QPainter*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_draw);

    if (!sipMeth)
    {
        ::QGraphicsOpacityEffect::draw(a0);
        return;
    }

    extern void sipVH_QtWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsOpacityEffect::sourceChanged(::QGraphicsEffect::ChangeFlags a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_sourceChanged);

    if (!sipMeth)
    {
        ::QGraphicsOpacityEffect::sourceChanged(a0);
        return;
    }

    extern void sipVH_QtWidgets_137(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsEffect::ChangeFlags);

    sipVH_QtWidgets_137(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGraphicsOpacityEffect_opacity, "opacity(self) -> float");

extern "C" {static PyObject *meth_QGraphicsOpacityEffect_opacity(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsOpacityEffect_opacity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsOpacityEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsOpacityEffect, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->opacity();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsOpacityEffect, sipName_opacity, doc_QGraphicsOpacityEffect_opacity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsOpacityEffect_opacityMask, "opacityMask(self) -> QBrush");

extern "C" {static PyObject *meth_QGraphicsOpacityEffect_opacityMask(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsOpacityEffect_opacityMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsOpacityEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsOpacityEffect, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->opacityMask());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsOpacityEffect, sipName_opacityMask, doc_QGraphicsOpacityEffect_opacityMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsOpacityEffect_setOpacity, "setOpacity(self, opacity: float)");

extern "C" {static PyObject *meth_QGraphicsOpacityEffect_setOpacity(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsOpacityEffect_setOpacity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QGraphicsOpacityEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGraphicsOpacityEffect, &sipCpp, &a0))
        {
            sipCpp->setOpacity(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsOpacityEffect, sipName_setOpacity, doc_QGraphicsOpacityEffect_setOpacity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsOpacityEffect_setOpacityMask, "setOpacityMask(self, mask: QBrush|QColor|Qt.GlobalColor|int|QGradient)");

extern "C" {static PyObject *meth_QGraphicsOpacityEffect_setOpacityMask(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsOpacityEffect_setOpacityMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QGraphicsOpacityEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGraphicsOpacityEffect, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setOpacityMask(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsOpacityEffect, sipName_setOpacityMask, doc_QGraphicsOpacityEffect_setOpacityMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsOpacityEffect_draw, "draw(self, painter: QPainter|None)");

extern "C" {static PyObject *meth_QGraphicsOpacityEffect_draw(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsOpacityEffect_draw(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsOpacityEffect)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPainter* a0;
        ::QGraphicsOpacityEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsOpacityEffect, &sipCpp, sipType_QPainter, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsOpacityEffect::draw(a0) : sipCpp->draw(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsOpacityEffect, sipName_draw, doc_QGraphicsOpacityEffect_draw);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGraphicsOpacityEffect(void *, const sipTypeDef *);}
static void *cast_QGraphicsOpacityEffect(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGraphicsOpacityEffect *sipCpp = reinterpret_cast< ::QGraphicsOpacityEffect *>(sipCppV);

    if (targetType == sipType_QGraphicsOpacityEffect)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGraphicsEffect)->ctd_cast(static_cast< ::QGraphicsEffect *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGraphicsOpacityEffect(void *, int);}
static void release_QGraphicsOpacityEffect(void *sipCppV, int)
{
    ::QGraphicsOpacityEffect *sipCpp = reinterpret_cast< ::QGraphicsOpacityEffect *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QGraphicsOpacityEffect(Py_ssize_t);}
static void *array_QGraphicsOpacityEffect(Py_ssize_t sipNrElem)
{
    return new ::QGraphicsOpacityEffect[sipNrElem];
}


extern "C" {static void array_delete_QGraphicsOpacityEffect(void *);}
static void array_delete_QGraphicsOpacityEffect(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGraphicsOpacityEffect *>(sipCpp);
}


extern "C" {static void dealloc_QGraphicsOpacityEffect(sipSimpleWrapper *);}
static void dealloc_QGraphicsOpacityEffect(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGraphicsOpacityEffect *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGraphicsOpacityEffect(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGraphicsOpacityEffect(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGraphicsOpacityEffect(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGraphicsOpacityEffect *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQGraphicsOpacityEffect(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGraphicsOpacityEffect[] = {{130, 255, 1}};


static PyMethodDef methods_QGraphicsOpacityEffect[] = {
    {sipName_draw, meth_QGraphicsOpacityEffect_draw, METH_VARARGS, doc_QGraphicsOpacityEffect_draw},
    {sipName_opacity, meth_QGraphicsOpacityEffect_opacity, METH_VARARGS, doc_QGraphicsOpacityEffect_opacity},
    {sipName_opacityMask, meth_QGraphicsOpacityEffect_opacityMask, METH_VARARGS, doc_QGraphicsOpacityEffect_opacityMask},
    {sipName_setOpacity, meth_QGraphicsOpacityEffect_setOpacity, METH_VARARGS, doc_QGraphicsOpacityEffect_setOpacity},
    {sipName_setOpacityMask, meth_QGraphicsOpacityEffect_setOpacityMask, METH_VARARGS, doc_QGraphicsOpacityEffect_setOpacityMask}
};

PyDoc_STRVAR(doc_QGraphicsOpacityEffect, "\1QGraphicsOpacityEffect(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QGraphicsOpacityEffect[] = {
    {"opacityMaskChanged(QBrush)", "\1opacityMaskChanged(self, mask: QBrush|QColor|Qt.GlobalColor|int|QGradient)", SIP_NULLPTR, SIP_NULLPTR},
    {"opacityChanged(qreal)", "\1opacityChanged(self, opacity: float)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QGraphicsOpacityEffect = {
    &::QGraphicsOpacityEffect::staticMetaObject,
    signals_QGraphicsOpacityEffect,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsOpacityEffect = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGraphicsOpacityEffect,
        SIP_NULLPTR,
        &plugin_QGraphicsOpacityEffect,
    },
    {
        sipNameNr_QGraphicsOpacityEffect,
        {0, 0, 1},
        5, methods_QGraphicsOpacityEffect,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGraphicsOpacityEffect,
    -1,
    -1,
    supers_QGraphicsOpacityEffect,
    SIP_NULLPTR,
    init_type_QGraphicsOpacityEffect,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGraphicsOpacityEffect,
    SIP_NULLPTR,
    array_QGraphicsOpacityEffect,
    SIP_NULLPTR,
    release_QGraphicsOpacityEffect,
    cast_QGraphicsOpacityEffect,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGraphicsOpacityEffect,
    sizeof (::QGraphicsOpacityEffect),
};
