/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeoshape.sip"
#include <qgeoshape.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoShape.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeorectangle.sip"
#include <qgeorectangle.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoShape.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoShape.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeocoordinate.sip"
#include <qgeocoordinate.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoShape.cpp"


PyDoc_STRVAR(doc_QGeoShape_type, "type(self) -> QGeoShape.ShapeType");

extern "C" {static PyObject *meth_QGeoShape_type(PyObject *, PyObject *);}
static PyObject *meth_QGeoShape_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoShape *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoShape, &sipCpp))
        {
            ::QGeoShape::ShapeType sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoShape_ShapeType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoShape, sipName_type, doc_QGeoShape_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoShape_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QGeoShape_isValid(PyObject *, PyObject *);}
static PyObject *meth_QGeoShape_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoShape *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoShape, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoShape, sipName_isValid, doc_QGeoShape_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoShape_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QGeoShape_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QGeoShape_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoShape *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoShape, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoShape, sipName_isEmpty, doc_QGeoShape_isEmpty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoShape_contains, "contains(self, coordinate: QGeoCoordinate) -> bool");

extern "C" {static PyObject *meth_QGeoShape_contains(PyObject *, PyObject *);}
static PyObject *meth_QGeoShape_contains(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        const ::QGeoShape *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoShape, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->contains(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoShape, sipName_contains, doc_QGeoShape_contains);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoShape_center, "center(self) -> QGeoCoordinate");

extern "C" {static PyObject *meth_QGeoShape_center(PyObject *, PyObject *);}
static PyObject *meth_QGeoShape_center(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoShape *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoShape, &sipCpp))
        {
            ::QGeoCoordinate*sipRes;

            sipRes = new ::QGeoCoordinate(sipCpp->center());

            return sipConvertFromNewType(sipRes, sipType_QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoShape, sipName_center, doc_QGeoShape_center);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoShape_toString, "toString(self) -> str");

extern "C" {static PyObject *meth_QGeoShape_toString(PyObject *, PyObject *);}
static PyObject *meth_QGeoShape_toString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoShape *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoShape, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoShape, sipName_toString, doc_QGeoShape_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoShape_boundingGeoRectangle, "boundingGeoRectangle(self) -> QGeoRectangle");

extern "C" {static PyObject *meth_QGeoShape_boundingGeoRectangle(PyObject *, PyObject *);}
static PyObject *meth_QGeoShape_boundingGeoRectangle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoShape *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoShape, &sipCpp))
        {
            ::QGeoRectangle*sipRes;

            sipRes = new ::QGeoRectangle(sipCpp->boundingGeoRectangle());

            return sipConvertFromNewType(sipRes, sipType_QGeoRectangle, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoShape, sipName_boundingGeoRectangle, doc_QGeoShape_boundingGeoRectangle);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QGeoShape___eq__(PyObject *, PyObject *);}
static PyObject *slot_QGeoShape___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoShape *sipCpp = reinterpret_cast< ::QGeoShape *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoShape));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoShape* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoShape, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPositioning, eq_slot, sipType_QGeoShape, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGeoShape___ne__(PyObject *, PyObject *);}
static PyObject *slot_QGeoShape___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoShape *sipCpp = reinterpret_cast< ::QGeoShape *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoShape));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoShape* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoShape, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPositioning, ne_slot, sipType_QGeoShape, sipSelf, sipArg);
}


extern "C" {static Py_hash_t slot_QGeoShape___hash__(PyObject *);}
static Py_hash_t slot_QGeoShape___hash__(PyObject *sipSelf)
{
    ::QGeoShape *sipCpp = reinterpret_cast< ::QGeoShape *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoShape));

    if (!sipCpp)
        return 0;


    {
        {
            Py_hash_t sipRes = 0;

#line 78 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeoshape.sip"
        sipRes = qHash(*sipCpp);
#line 298 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoShape.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoShape(void *, int);}
static void release_QGeoShape(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGeoShape *>(sipCppV);
}


extern "C" {static void *array_QGeoShape(Py_ssize_t);}
static void *array_QGeoShape(Py_ssize_t sipNrElem)
{
    return new ::QGeoShape[sipNrElem];
}


extern "C" {static void array_delete_QGeoShape(void *);}
static void array_delete_QGeoShape(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoShape *>(sipCpp);
}


extern "C" {static void assign_QGeoShape(void *, Py_ssize_t, void *);}
static void assign_QGeoShape(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGeoShape *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGeoShape *>(sipSrc);
}


extern "C" {static void *copy_QGeoShape(const void *, Py_ssize_t);}
static void *copy_QGeoShape(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGeoShape(reinterpret_cast<const ::QGeoShape *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGeoShape(sipSimpleWrapper *);}
static void dealloc_QGeoShape(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoShape(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGeoShape(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoShape(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGeoShape *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QGeoShape();

            return sipCpp;
        }
    }

    {
        const ::QGeoShape* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoShape, &a0))
        {
            sipCpp = new ::QGeoShape(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QGeoShape[] = {
    {(void *)slot_QGeoShape___eq__, eq_slot},
    {(void *)slot_QGeoShape___ne__, ne_slot},
    {(void *)slot_QGeoShape___hash__, hash_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QGeoShape[] = {
    {sipName_boundingGeoRectangle, meth_QGeoShape_boundingGeoRectangle, METH_VARARGS, doc_QGeoShape_boundingGeoRectangle},
    {sipName_center, meth_QGeoShape_center, METH_VARARGS, doc_QGeoShape_center},
    {sipName_contains, meth_QGeoShape_contains, METH_VARARGS, doc_QGeoShape_contains},
    {sipName_isEmpty, meth_QGeoShape_isEmpty, METH_VARARGS, doc_QGeoShape_isEmpty},
    {sipName_isValid, meth_QGeoShape_isValid, METH_VARARGS, doc_QGeoShape_isValid},
    {sipName_toString, meth_QGeoShape_toString, METH_VARARGS, doc_QGeoShape_toString},
    {sipName_type, meth_QGeoShape_type, METH_VARARGS, doc_QGeoShape_type}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QGeoShape[] = {
    {sipName_UnknownType, static_cast<int>(::QGeoShape::UnknownType)},
    {sipName_RectangleType, static_cast<int>(::QGeoShape::RectangleType)},
    {sipName_CircleType, static_cast<int>(::QGeoShape::CircleType)},
    {sipName_PathType, static_cast<int>(::QGeoShape::PathType)},
    {sipName_PolygonType, static_cast<int>(::QGeoShape::PolygonType)},
    {0, 0}
};

PyDoc_STRVAR(doc_QGeoShape, "\1QGeoShape()\n"
"QGeoShape(other: QGeoShape)");


sipClassTypeDef sipTypeDef_QtPositioning_QGeoShape = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoShape,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QGeoShape,
        {0, 0, 1},
        7, methods_QGeoShape,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QGeoShape, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoShape,
    -1,
    -1,
    SIP_NULLPTR,
    slots_QGeoShape,
    init_type_QGeoShape,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoShape,
    assign_QGeoShape,
    array_QGeoShape,
    copy_QGeoShape,
    release_QGeoShape,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoShape,
    sizeof (::QGeoShape),
};
