/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgesture.sip"
#include <qgesture.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 49 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 52 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 55 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 58 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 61 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 64 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 67 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGesture.cpp"


class sipQGesture : public ::QGesture
{
public:
    sipQGesture(::QObject*);
    virtual ~sipQGesture();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGesture(const sipQGesture &);
    sipQGesture &operator = (const sipQGesture &);

    char sipPyMethods[7];
};

sipQGesture::sipQGesture(::QObject*a0): ::QGesture(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGesture::~sipQGesture()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGesture::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QGesture);

    return ::QGesture::metaObject();
}

int sipQGesture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGesture::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QGesture, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGesture::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QGesture, _clname, &sipCpp) ? sipCpp : ::QGesture::qt_metacast(_clname));
}

bool sipQGesture::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGesture::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGesture::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGesture::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGesture::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGesture::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGesture::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGesture::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGesture::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGesture::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGesture::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGesture::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGesture::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGesture::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGesture_gestureType, "gestureType(self) -> Qt.GestureType");

extern "C" {static PyObject *meth_QGesture_gestureType(PyObject *, PyObject *);}
static PyObject *meth_QGesture_gestureType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGesture, &sipCpp))
        {
            ::Qt::GestureType sipRes;

            sipRes = sipCpp->gestureType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_GestureType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGesture, sipName_gestureType, doc_QGesture_gestureType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGesture_state, "state(self) -> Qt.GestureState");

extern "C" {static PyObject *meth_QGesture_state(PyObject *, PyObject *);}
static PyObject *meth_QGesture_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGesture, &sipCpp))
        {
            ::Qt::GestureState sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_GestureState);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGesture, sipName_state, doc_QGesture_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGesture_hotSpot, "hotSpot(self) -> QPointF");

extern "C" {static PyObject *meth_QGesture_hotSpot(PyObject *, PyObject *);}
static PyObject *meth_QGesture_hotSpot(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGesture, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->hotSpot());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGesture, sipName_hotSpot, doc_QGesture_hotSpot);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGesture_setHotSpot, "setHotSpot(self, value: QPointF)");

extern "C" {static PyObject *meth_QGesture_setHotSpot(PyObject *, PyObject *);}
static PyObject *meth_QGesture_setHotSpot(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        ::QGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGesture, &sipCpp, sipType_QPointF, &a0))
        {
            sipCpp->setHotSpot(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGesture, sipName_setHotSpot, doc_QGesture_setHotSpot);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGesture_hasHotSpot, "hasHotSpot(self) -> bool");

extern "C" {static PyObject *meth_QGesture_hasHotSpot(PyObject *, PyObject *);}
static PyObject *meth_QGesture_hasHotSpot(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGesture, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasHotSpot();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGesture, sipName_hasHotSpot, doc_QGesture_hasHotSpot);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGesture_unsetHotSpot, "unsetHotSpot(self)");

extern "C" {static PyObject *meth_QGesture_unsetHotSpot(PyObject *, PyObject *);}
static PyObject *meth_QGesture_unsetHotSpot(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGesture, &sipCpp))
        {
            sipCpp->unsetHotSpot();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGesture, sipName_unsetHotSpot, doc_QGesture_unsetHotSpot);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGesture_setGestureCancelPolicy, "setGestureCancelPolicy(self, policy: QGesture.GestureCancelPolicy)");

extern "C" {static PyObject *meth_QGesture_setGestureCancelPolicy(PyObject *, PyObject *);}
static PyObject *meth_QGesture_setGestureCancelPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGesture::GestureCancelPolicy a0;
        ::QGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGesture, &sipCpp, sipType_QGesture_GestureCancelPolicy, &a0))
        {
            sipCpp->setGestureCancelPolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGesture, sipName_setGestureCancelPolicy, doc_QGesture_setGestureCancelPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGesture_gestureCancelPolicy, "gestureCancelPolicy(self) -> QGesture.GestureCancelPolicy");

extern "C" {static PyObject *meth_QGesture_gestureCancelPolicy(PyObject *, PyObject *);}
static PyObject *meth_QGesture_gestureCancelPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGesture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGesture, &sipCpp))
        {
            ::QGesture::GestureCancelPolicy sipRes;

            sipRes = sipCpp->gestureCancelPolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGesture_GestureCancelPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGesture, sipName_gestureCancelPolicy, doc_QGesture_gestureCancelPolicy);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGesture(void *, const sipTypeDef *);}
static void *cast_QGesture(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGesture *sipCpp = reinterpret_cast< ::QGesture *>(sipCppV);

    if (targetType == sipType_QGesture)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGesture(void *, int);}
static void release_QGesture(void *sipCppV, int)
{
    ::QGesture *sipCpp = reinterpret_cast< ::QGesture *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QGesture(Py_ssize_t);}
static void *array_QGesture(Py_ssize_t sipNrElem)
{
    return new ::QGesture[sipNrElem];
}


extern "C" {static void array_delete_QGesture(void *);}
static void array_delete_QGesture(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGesture *>(sipCpp);
}


extern "C" {static void dealloc_QGesture(sipSimpleWrapper *);}
static void dealloc_QGesture(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGesture *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGesture(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGesture(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGesture(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGesture *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQGesture(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGesture[] = {{44, 0, 1}};


static PyMethodDef methods_QGesture[] = {
    {sipName_gestureCancelPolicy, meth_QGesture_gestureCancelPolicy, METH_VARARGS, doc_QGesture_gestureCancelPolicy},
    {sipName_gestureType, meth_QGesture_gestureType, METH_VARARGS, doc_QGesture_gestureType},
    {sipName_hasHotSpot, meth_QGesture_hasHotSpot, METH_VARARGS, doc_QGesture_hasHotSpot},
    {sipName_hotSpot, meth_QGesture_hotSpot, METH_VARARGS, doc_QGesture_hotSpot},
    {sipName_setGestureCancelPolicy, meth_QGesture_setGestureCancelPolicy, METH_VARARGS, doc_QGesture_setGestureCancelPolicy},
    {sipName_setHotSpot, meth_QGesture_setHotSpot, METH_VARARGS, doc_QGesture_setHotSpot},
    {sipName_state, meth_QGesture_state, METH_VARARGS, doc_QGesture_state},
    {sipName_unsetHotSpot, meth_QGesture_unsetHotSpot, METH_VARARGS, doc_QGesture_unsetHotSpot}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QGesture[] = {
    {sipName_CancelNone, static_cast<int>(::QGesture::CancelNone)},
    {sipName_CancelAllInContext, static_cast<int>(::QGesture::CancelAllInContext)},
    {0, 0}
};

PyDoc_STRVAR(doc_QGesture, "\1QGesture(parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QGesture = {
    &::QGesture::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QGesture = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGesture,
        SIP_NULLPTR,
        &plugin_QGesture,
    },
    {
        sipNameNr_QGesture,
        {0, 0, 1},
        8, methods_QGesture,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QGesture, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGesture,
    -1,
    -1,
    supers_QGesture,
    SIP_NULLPTR,
    init_type_QGesture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGesture,
    SIP_NULLPTR,
    array_QGesture,
    SIP_NULLPTR,
    release_QGesture,
    cast_QGesture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGesture,
    sizeof (::QGesture),
};
