/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeosatelliteinfo.sip"
#include <qgeosatelliteinfo.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfo.cpp"



PyDoc_STRVAR(doc_QGeoSatelliteInfo_setSatelliteSystem, "setSatelliteSystem(self, system: QGeoSatelliteInfo.SatelliteSystem)");

extern "C" {static PyObject *meth_QGeoSatelliteInfo_setSatelliteSystem(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfo_setSatelliteSystem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoSatelliteInfo::SatelliteSystem a0;
        ::QGeoSatelliteInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGeoSatelliteInfo, &sipCpp, sipType_QGeoSatelliteInfo_SatelliteSystem, &a0))
        {
            sipCpp->setSatelliteSystem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfo, sipName_setSatelliteSystem, doc_QGeoSatelliteInfo_setSatelliteSystem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfo_satelliteSystem, "satelliteSystem(self) -> QGeoSatelliteInfo.SatelliteSystem");

extern "C" {static PyObject *meth_QGeoSatelliteInfo_satelliteSystem(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfo_satelliteSystem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoSatelliteInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoSatelliteInfo, &sipCpp))
        {
            ::QGeoSatelliteInfo::SatelliteSystem sipRes;

            sipRes = sipCpp->satelliteSystem();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoSatelliteInfo_SatelliteSystem);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfo, sipName_satelliteSystem, doc_QGeoSatelliteInfo_satelliteSystem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfo_setSatelliteIdentifier, "setSatelliteIdentifier(self, satId: int)");

extern "C" {static PyObject *meth_QGeoSatelliteInfo_setSatelliteIdentifier(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfo_setSatelliteIdentifier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QGeoSatelliteInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QGeoSatelliteInfo, &sipCpp, &a0))
        {
            sipCpp->setSatelliteIdentifier(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfo, sipName_setSatelliteIdentifier, doc_QGeoSatelliteInfo_setSatelliteIdentifier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfo_satelliteIdentifier, "satelliteIdentifier(self) -> int");

extern "C" {static PyObject *meth_QGeoSatelliteInfo_satelliteIdentifier(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfo_satelliteIdentifier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoSatelliteInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoSatelliteInfo, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->satelliteIdentifier();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfo, sipName_satelliteIdentifier, doc_QGeoSatelliteInfo_satelliteIdentifier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfo_setSignalStrength, "setSignalStrength(self, signalStrength: int)");

extern "C" {static PyObject *meth_QGeoSatelliteInfo_setSignalStrength(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfo_setSignalStrength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QGeoSatelliteInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QGeoSatelliteInfo, &sipCpp, &a0))
        {
            sipCpp->setSignalStrength(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfo, sipName_setSignalStrength, doc_QGeoSatelliteInfo_setSignalStrength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfo_signalStrength, "signalStrength(self) -> int");

extern "C" {static PyObject *meth_QGeoSatelliteInfo_signalStrength(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfo_signalStrength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoSatelliteInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoSatelliteInfo, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->signalStrength();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfo, sipName_signalStrength, doc_QGeoSatelliteInfo_signalStrength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfo_setAttribute, "setAttribute(self, attribute: QGeoSatelliteInfo.Attribute, value: float)");

extern "C" {static PyObject *meth_QGeoSatelliteInfo_setAttribute(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfo_setAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoSatelliteInfo::Attribute a0;
        ::qreal a1;
        ::QGeoSatelliteInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEd", &sipSelf, sipType_QGeoSatelliteInfo, &sipCpp, sipType_QGeoSatelliteInfo_Attribute, &a0, &a1))
        {
            sipCpp->setAttribute(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfo, sipName_setAttribute, doc_QGeoSatelliteInfo_setAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfo_attribute, "attribute(self, attribute: QGeoSatelliteInfo.Attribute) -> float");

extern "C" {static PyObject *meth_QGeoSatelliteInfo_attribute(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfo_attribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoSatelliteInfo::Attribute a0;
        const ::QGeoSatelliteInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGeoSatelliteInfo, &sipCpp, sipType_QGeoSatelliteInfo_Attribute, &a0))
        {
            ::qreal sipRes;

            sipRes = sipCpp->attribute(a0);

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfo, sipName_attribute, doc_QGeoSatelliteInfo_attribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfo_removeAttribute, "removeAttribute(self, attribute: QGeoSatelliteInfo.Attribute)");

extern "C" {static PyObject *meth_QGeoSatelliteInfo_removeAttribute(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfo_removeAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoSatelliteInfo::Attribute a0;
        ::QGeoSatelliteInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGeoSatelliteInfo, &sipCpp, sipType_QGeoSatelliteInfo_Attribute, &a0))
        {
            sipCpp->removeAttribute(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfo, sipName_removeAttribute, doc_QGeoSatelliteInfo_removeAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfo_hasAttribute, "hasAttribute(self, attribute: QGeoSatelliteInfo.Attribute) -> bool");

extern "C" {static PyObject *meth_QGeoSatelliteInfo_hasAttribute(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfo_hasAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoSatelliteInfo::Attribute a0;
        const ::QGeoSatelliteInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGeoSatelliteInfo, &sipCpp, sipType_QGeoSatelliteInfo_Attribute, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->hasAttribute(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfo, sipName_hasAttribute, doc_QGeoSatelliteInfo_hasAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfo_swap, "swap(self, other: QGeoSatelliteInfo)");

extern "C" {static PyObject *meth_QGeoSatelliteInfo_swap(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfo_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoSatelliteInfo* a0;
        ::QGeoSatelliteInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoSatelliteInfo, &sipCpp, sipType_QGeoSatelliteInfo, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfo, sipName_swap, doc_QGeoSatelliteInfo_swap);

    return SIP_NULLPTR;
}


extern "C" {static Py_hash_t slot_QGeoSatelliteInfo___hash__(PyObject *);}
static Py_hash_t slot_QGeoSatelliteInfo___hash__(PyObject *sipSelf)
{
    ::QGeoSatelliteInfo *sipCpp = reinterpret_cast< ::QGeoSatelliteInfo *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoSatelliteInfo));

    if (!sipCpp)
        return 0;


    {
        {
            Py_hash_t sipRes = 0;

#line 66 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeosatelliteinfo.sip"
        sipRes = qHash(*sipCpp);
#line 337 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfo.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoSatelliteInfo(void *, int);}
static void release_QGeoSatelliteInfo(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGeoSatelliteInfo *>(sipCppV);
}


extern "C" {static void *array_QGeoSatelliteInfo(Py_ssize_t);}
static void *array_QGeoSatelliteInfo(Py_ssize_t sipNrElem)
{
    return new ::QGeoSatelliteInfo[sipNrElem];
}


extern "C" {static void array_delete_QGeoSatelliteInfo(void *);}
static void array_delete_QGeoSatelliteInfo(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoSatelliteInfo *>(sipCpp);
}


extern "C" {static void assign_QGeoSatelliteInfo(void *, Py_ssize_t, void *);}
static void assign_QGeoSatelliteInfo(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGeoSatelliteInfo *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGeoSatelliteInfo *>(sipSrc);
}


extern "C" {static void *copy_QGeoSatelliteInfo(const void *, Py_ssize_t);}
static void *copy_QGeoSatelliteInfo(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGeoSatelliteInfo(reinterpret_cast<const ::QGeoSatelliteInfo *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGeoSatelliteInfo(sipSimpleWrapper *);}
static void dealloc_QGeoSatelliteInfo(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoSatelliteInfo(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGeoSatelliteInfo(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoSatelliteInfo(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGeoSatelliteInfo *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QGeoSatelliteInfo();

            return sipCpp;
        }
    }

    {
        const ::QGeoSatelliteInfo* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoSatelliteInfo, &a0))
        {
            sipCpp = new ::QGeoSatelliteInfo(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QGeoSatelliteInfo[] = {
    {(void *)slot_QGeoSatelliteInfo___hash__, hash_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QGeoSatelliteInfo[] = {
    {sipName_attribute, meth_QGeoSatelliteInfo_attribute, METH_VARARGS, doc_QGeoSatelliteInfo_attribute},
    {sipName_hasAttribute, meth_QGeoSatelliteInfo_hasAttribute, METH_VARARGS, doc_QGeoSatelliteInfo_hasAttribute},
    {sipName_removeAttribute, meth_QGeoSatelliteInfo_removeAttribute, METH_VARARGS, doc_QGeoSatelliteInfo_removeAttribute},
    {sipName_satelliteIdentifier, meth_QGeoSatelliteInfo_satelliteIdentifier, METH_VARARGS, doc_QGeoSatelliteInfo_satelliteIdentifier},
    {sipName_satelliteSystem, meth_QGeoSatelliteInfo_satelliteSystem, METH_VARARGS, doc_QGeoSatelliteInfo_satelliteSystem},
    {sipName_setAttribute, meth_QGeoSatelliteInfo_setAttribute, METH_VARARGS, doc_QGeoSatelliteInfo_setAttribute},
    {sipName_setSatelliteIdentifier, meth_QGeoSatelliteInfo_setSatelliteIdentifier, METH_VARARGS, doc_QGeoSatelliteInfo_setSatelliteIdentifier},
    {sipName_setSatelliteSystem, meth_QGeoSatelliteInfo_setSatelliteSystem, METH_VARARGS, doc_QGeoSatelliteInfo_setSatelliteSystem},
    {sipName_setSignalStrength, meth_QGeoSatelliteInfo_setSignalStrength, METH_VARARGS, doc_QGeoSatelliteInfo_setSignalStrength},
    {sipName_signalStrength, meth_QGeoSatelliteInfo_signalStrength, METH_VARARGS, doc_QGeoSatelliteInfo_signalStrength},
    {sipName_swap, meth_QGeoSatelliteInfo_swap, METH_VARARGS, doc_QGeoSatelliteInfo_swap}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QGeoSatelliteInfo[] = {
    {sipName_Elevation, static_cast<int>(::QGeoSatelliteInfo::Elevation)},
    {sipName_Azimuth, static_cast<int>(::QGeoSatelliteInfo::Azimuth)},
    {sipName_Undefined, static_cast<int>(::QGeoSatelliteInfo::Undefined)},
    {sipName_GPS, static_cast<int>(::QGeoSatelliteInfo::GPS)},
    {sipName_GLONASS, static_cast<int>(::QGeoSatelliteInfo::GLONASS)},
    {sipName_GALILEO, static_cast<int>(::QGeoSatelliteInfo::GALILEO)},
    {sipName_BEIDOU, static_cast<int>(::QGeoSatelliteInfo::BEIDOU)},
    {sipName_QZSS, static_cast<int>(::QGeoSatelliteInfo::QZSS)},
    {sipName_Multiple, static_cast<int>(::QGeoSatelliteInfo::Multiple)},
    {sipName_CustomType, static_cast<int>(::QGeoSatelliteInfo::CustomType)},
    {0, 0}
};

PyDoc_STRVAR(doc_QGeoSatelliteInfo, "\1QGeoSatelliteInfo()\n"
"QGeoSatelliteInfo(other: QGeoSatelliteInfo)");


sipClassTypeDef sipTypeDef_QtPositioning_QGeoSatelliteInfo = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoSatelliteInfo,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QGeoSatelliteInfo,
        {0, 0, 1},
        11, methods_QGeoSatelliteInfo,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QGeoSatelliteInfo, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoSatelliteInfo,
    -1,
    -1,
    SIP_NULLPTR,
    slots_QGeoSatelliteInfo,
    init_type_QGeoSatelliteInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoSatelliteInfo,
    assign_QGeoSatelliteInfo,
    array_QGeoSatelliteInfo,
    copy_QGeoSatelliteInfo,
    release_QGeoSatelliteInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoSatelliteInfo,
    sizeof (::QGeoSatelliteInfo),
};
