/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSvgWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSvgWidgets/qgraphicssvgitem.sip"
#include <qgraphicssvgitem.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 1066 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSvg/qsvgrenderer.sip"
#include <qsvgrenderer.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 112 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 118 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicstransform.sip"
#include <qgraphicstransform.h>
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 124 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 602 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 127 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 130 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 133 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 136 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 139 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicswidget.sip"
#include <qgraphicswidget.h>
#line 142 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 148 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 151 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 163 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 157 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 160 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 192 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 163 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 141 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 166 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 274 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 169 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 172 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 175 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 178 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 573 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 181 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsscene.sip"
#include <qgraphicsscene.h>
#line 184 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQGraphicsSvgItem.cpp"


class sipQGraphicsSvgItem : public ::QGraphicsSvgItem
{
public:
    sipQGraphicsSvgItem(::QGraphicsItem*);
    sipQGraphicsSvgItem(const ::QString&, ::QGraphicsItem*);
    virtual ~sipQGraphicsSvgItem();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void wheelEvent(::QGraphicsSceneWheelEvent*) SIP_OVERRIDE;
    bool sceneEventFilter(::QGraphicsItem*, ::QEvent*) SIP_OVERRIDE;
    bool sceneEvent(::QEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    ::QVariant itemChange(::QGraphicsItem::GraphicsItemChange, const ::QVariant&) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void hoverMoveEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void hoverEnterEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void dropEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QGraphicsSceneContextMenuEvent*) SIP_OVERRIDE;
    int type() const SIP_OVERRIDE;
    void paint(::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*) SIP_OVERRIDE;
    ::QPainterPath opaqueArea() const SIP_OVERRIDE;
    bool isObscuredBy(const ::QGraphicsItem*) const SIP_OVERRIDE;
    bool collidesWithPath(const ::QPainterPath&, ::Qt::ItemSelectionMode) const SIP_OVERRIDE;
    bool collidesWithItem(const ::QGraphicsItem*, ::Qt::ItemSelectionMode) const SIP_OVERRIDE;
    bool contains(const ::QPointF&) const SIP_OVERRIDE;
    ::QPainterPath shape() const SIP_OVERRIDE;
    ::QRectF boundingRect() const SIP_OVERRIDE;
    void advance(int) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGraphicsSvgItem(const sipQGraphicsSvgItem &);
    sipQGraphicsSvgItem &operator = (const sipQGraphicsSvgItem &);

    char sipPyMethods[39];
};

sipQGraphicsSvgItem::sipQGraphicsSvgItem(::QGraphicsItem*a0): ::QGraphicsSvgItem(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGraphicsSvgItem::sipQGraphicsSvgItem(const ::QString& a0, ::QGraphicsItem*a1): ::QGraphicsSvgItem(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGraphicsSvgItem::~sipQGraphicsSvgItem()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGraphicsSvgItem::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtSvgWidgets_qt_metaobject(sipPySelf, sipType_QGraphicsSvgItem);

    return ::QGraphicsSvgItem::metaObject();
}

int sipQGraphicsSvgItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGraphicsSvgItem::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtSvgWidgets_qt_metacall(sipPySelf, sipType_QGraphicsSvgItem, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGraphicsSvgItem::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtSvgWidgets_qt_metacast(sipPySelf, sipType_QGraphicsSvgItem, _clname, &sipCpp) ? sipCpp : ::QGraphicsSvgItem::qt_metacast(_clname));
}

void sipQGraphicsSvgItem::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSvgWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::connectNotify(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSvgWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::customEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSvgWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::childEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtSvgWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::timerEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtSvgWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsSvgItem::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGraphicsSvgItem::eventFilter(a0, a1);

    extern bool sipVH_QtSvgWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtSvgWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsSvgItem::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGraphicsSvgItem::event(a0);

    extern bool sipVH_QtSvgWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtSvgWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::wheelEvent(::QGraphicsSceneWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneWheelEvent*);

    sipVH_QtSvgWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsSvgItem::sceneEventFilter(::QGraphicsItem*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_sceneEventFilter);

    if (!sipMeth)
        return ::QGraphicsSvgItem::sceneEventFilter(a0, a1);

    extern bool sipVH_QtSvgWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsItem*, ::QEvent*);

    return sipVH_QtSvgWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsSvgItem::sceneEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_sceneEvent);

    if (!sipMeth)
        return ::QGraphicsSvgItem::sceneEvent(a0);

    extern bool sipVH_QtSvgWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtSvgWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::mouseReleaseEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtSvgWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::mousePressEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtSvgWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::mouseMoveEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtSvgWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::mouseDoubleClickEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtSvgWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtSvgWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtSvgWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQGraphicsSvgItem::itemChange(::QGraphicsItem::GraphicsItemChange a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_itemChange);

    if (!sipMeth)
        return ::QGraphicsSvgItem::itemChange(a0, a1);

    extern ::QVariant sipVH_QtSvgWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsItem::GraphicsItemChange, const ::QVariant&);

    return sipVH_QtSvgWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QVariant sipQGraphicsSvgItem::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[17]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QGraphicsSvgItem::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtSvgWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtSvgWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtSvgWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::hoverMoveEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_hoverMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::hoverMoveEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtSvgWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::hoverLeaveEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_hoverLeaveEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::hoverLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtSvgWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::hoverEnterEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_hoverEnterEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::hoverEnterEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtSvgWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtSvgWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtSvgWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::dropEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::dropEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtSvgWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::dragMoveEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtSvgWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::dragLeaveEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtSvgWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::dragEnterEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtSvgWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsSvgItem::contextMenuEvent(::QGraphicsSceneContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneContextMenuEvent*);

    sipVH_QtSvgWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQGraphicsSvgItem::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[29]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QGraphicsSvgItem::type();

    extern int sipVH_QtSvgWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSvgWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsSvgItem::paint(::QPainter*a0, const ::QStyleOptionGraphicsItem*a1, ::QWidget*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_paint);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::paint(a0, a1, a2);
        return;
    }

    extern void sipVH_QtSvgWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*);

    sipVH_QtSvgWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainterPath sipQGraphicsSvgItem::opaqueArea() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[31]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_opaqueArea);

    if (!sipMeth)
        return ::QGraphicsSvgItem::opaqueArea();

    extern ::QPainterPath sipVH_QtSvgWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSvgWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQGraphicsSvgItem::isObscuredBy(const ::QGraphicsItem*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[32]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isObscuredBy);

    if (!sipMeth)
        return ::QGraphicsSvgItem::isObscuredBy(a0);

    extern bool sipVH_QtSvgWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGraphicsItem*);

    return sipVH_QtSvgWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsSvgItem::collidesWithPath(const ::QPainterPath& a0, ::Qt::ItemSelectionMode a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[33]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_collidesWithPath);

    if (!sipMeth)
        return ::QGraphicsSvgItem::collidesWithPath(a0, a1);

    extern bool sipVH_QtSvgWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPainterPath&, ::Qt::ItemSelectionMode);

    return sipVH_QtSvgWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsSvgItem::collidesWithItem(const ::QGraphicsItem*a0, ::Qt::ItemSelectionMode a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[34]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_collidesWithItem);

    if (!sipMeth)
        return ::QGraphicsSvgItem::collidesWithItem(a0, a1);

    extern bool sipVH_QtSvgWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGraphicsItem*, ::Qt::ItemSelectionMode);

    return sipVH_QtSvgWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsSvgItem::contains(const ::QPointF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[35]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_contains);

    if (!sipMeth)
        return ::QGraphicsSvgItem::contains(a0);

    extern bool sipVH_QtSvgWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPointF&);

    return sipVH_QtSvgWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPainterPath sipQGraphicsSvgItem::shape() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[36]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_shape);

    if (!sipMeth)
        return ::QGraphicsSvgItem::shape();

    extern ::QPainterPath sipVH_QtSvgWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSvgWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QRectF sipQGraphicsSvgItem::boundingRect() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[37]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_boundingRect);

    if (!sipMeth)
        return ::QGraphicsSvgItem::boundingRect();

    extern ::QRectF sipVH_QtSvgWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSvgWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsSvgItem::advance(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_advance);

    if (!sipMeth)
    {
        ::QGraphicsSvgItem::advance(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtSvgWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGraphicsSvgItem_setSharedRenderer, "setSharedRenderer(self, renderer: QSvgRenderer|None)");

extern "C" {static PyObject *meth_QGraphicsSvgItem_setSharedRenderer(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSvgItem_setSharedRenderer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSvgRenderer* a0;
        PyObject *a0Keep;
        ::QGraphicsSvgItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QGraphicsSvgItem, &sipCpp, &a0Keep, sipType_QSvgRenderer, &a0))
        {
            sipCpp->setSharedRenderer(a0);

            sipKeepReference(sipSelf, -1, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSvgItem, sipName_setSharedRenderer, doc_QGraphicsSvgItem_setSharedRenderer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSvgItem_renderer, "renderer(self) -> QSvgRenderer|None");

extern "C" {static PyObject *meth_QGraphicsSvgItem_renderer(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSvgItem_renderer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsSvgItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSvgItem, &sipCpp))
        {
            ::QSvgRenderer*sipRes;

            sipRes = sipCpp->renderer();

            return sipConvertFromType(sipRes, sipType_QSvgRenderer, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSvgItem, sipName_renderer, doc_QGraphicsSvgItem_renderer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSvgItem_setElementId, "setElementId(self, id: str|None)");

extern "C" {static PyObject *meth_QGraphicsSvgItem_setElementId(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSvgItem_setElementId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGraphicsSvgItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGraphicsSvgItem, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setElementId(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSvgItem, sipName_setElementId, doc_QGraphicsSvgItem_setElementId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSvgItem_elementId, "elementId(self) -> str");

extern "C" {static PyObject *meth_QGraphicsSvgItem_elementId(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSvgItem_elementId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsSvgItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSvgItem, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->elementId());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSvgItem, sipName_elementId, doc_QGraphicsSvgItem_elementId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSvgItem_setMaximumCacheSize, "setMaximumCacheSize(self, size: QSize)");

extern "C" {static PyObject *meth_QGraphicsSvgItem_setMaximumCacheSize(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSvgItem_setMaximumCacheSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QGraphicsSvgItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGraphicsSvgItem, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setMaximumCacheSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSvgItem, sipName_setMaximumCacheSize, doc_QGraphicsSvgItem_setMaximumCacheSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSvgItem_maximumCacheSize, "maximumCacheSize(self) -> QSize");

extern "C" {static PyObject *meth_QGraphicsSvgItem_maximumCacheSize(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSvgItem_maximumCacheSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsSvgItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSvgItem, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->maximumCacheSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSvgItem, sipName_maximumCacheSize, doc_QGraphicsSvgItem_maximumCacheSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSvgItem_boundingRect, "boundingRect(self) -> QRectF");

extern "C" {static PyObject *meth_QGraphicsSvgItem_boundingRect(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSvgItem_boundingRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsSvgItem)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QGraphicsSvgItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSvgItem, &sipCpp))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF((sipSelfWasArg ? sipCpp->::QGraphicsSvgItem::boundingRect() : sipCpp->boundingRect()));

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSvgItem, sipName_boundingRect, doc_QGraphicsSvgItem_boundingRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSvgItem_paint, "paint(self, painter: QPainter|None, option: QStyleOptionGraphicsItem|None, widget: QWidget|None = None)");

extern "C" {static PyObject *meth_QGraphicsSvgItem_paint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSvgItem_paint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsSvgItem)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPainter* a0;
        const ::QStyleOptionGraphicsItem* a1;
        ::QWidget* a2 = 0;
        ::QGraphicsSvgItem *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J8|J8", &sipSelf, sipType_QGraphicsSvgItem, &sipCpp, sipType_QPainter, &a0, sipType_QStyleOptionGraphicsItem, &a1, sipType_QWidget, &a2))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsSvgItem::paint(a0, a1, a2) : sipCpp->paint(a0, a1, a2));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSvgItem, sipName_paint, doc_QGraphicsSvgItem_paint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSvgItem_type, "type(self) -> int");

extern "C" {static PyObject *meth_QGraphicsSvgItem_type(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSvgItem_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsSvgItem)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QGraphicsSvgItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSvgItem, &sipCpp))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGraphicsSvgItem::type() : sipCpp->type());

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSvgItem, sipName_type, doc_QGraphicsSvgItem_type);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGraphicsSvgItem(void *, const sipTypeDef *);}
static void *cast_QGraphicsSvgItem(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGraphicsSvgItem *sipCpp = reinterpret_cast< ::QGraphicsSvgItem *>(sipCppV);

    if (targetType == sipType_QGraphicsSvgItem)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGraphicsObject)->ctd_cast(static_cast< ::QGraphicsObject *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGraphicsSvgItem(void *, int);}
static void release_QGraphicsSvgItem(void *sipCppV, int)
{
    ::QGraphicsSvgItem *sipCpp = reinterpret_cast< ::QGraphicsSvgItem *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QGraphicsSvgItem(Py_ssize_t);}
static void *array_QGraphicsSvgItem(Py_ssize_t sipNrElem)
{
    return new ::QGraphicsSvgItem[sipNrElem];
}


extern "C" {static void array_delete_QGraphicsSvgItem(void *);}
static void array_delete_QGraphicsSvgItem(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGraphicsSvgItem *>(sipCpp);
}


extern "C" {static void dealloc_QGraphicsSvgItem(sipSimpleWrapper *);}
static void dealloc_QGraphicsSvgItem(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGraphicsSvgItem *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGraphicsSvgItem(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGraphicsSvgItem(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGraphicsSvgItem(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGraphicsSvgItem *sipCpp = SIP_NULLPTR;

    {
        ::QGraphicsItem* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QGraphicsItem, &a0, sipOwner))
        {
            sipCpp = new sipQGraphicsSvgItem(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGraphicsItem* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QString, &a0, &a0State, sipType_QGraphicsItem, &a1, sipOwner))
        {
            sipCpp = new sipQGraphicsSvgItem(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGraphicsSvgItem[] = {{2, 3, 1}};


static PyMethodDef methods_QGraphicsSvgItem[] = {
    {sipName_boundingRect, meth_QGraphicsSvgItem_boundingRect, METH_VARARGS, doc_QGraphicsSvgItem_boundingRect},
    {sipName_elementId, meth_QGraphicsSvgItem_elementId, METH_VARARGS, doc_QGraphicsSvgItem_elementId},
    {sipName_maximumCacheSize, meth_QGraphicsSvgItem_maximumCacheSize, METH_VARARGS, doc_QGraphicsSvgItem_maximumCacheSize},
    {sipName_paint, SIP_MLMETH_CAST(meth_QGraphicsSvgItem_paint), METH_VARARGS|METH_KEYWORDS, doc_QGraphicsSvgItem_paint},
    {sipName_renderer, meth_QGraphicsSvgItem_renderer, METH_VARARGS, doc_QGraphicsSvgItem_renderer},
    {sipName_setElementId, meth_QGraphicsSvgItem_setElementId, METH_VARARGS, doc_QGraphicsSvgItem_setElementId},
    {sipName_setMaximumCacheSize, meth_QGraphicsSvgItem_setMaximumCacheSize, METH_VARARGS, doc_QGraphicsSvgItem_setMaximumCacheSize},
    {sipName_setSharedRenderer, meth_QGraphicsSvgItem_setSharedRenderer, METH_VARARGS, doc_QGraphicsSvgItem_setSharedRenderer},
    {sipName_type, meth_QGraphicsSvgItem_type, METH_VARARGS, doc_QGraphicsSvgItem_type}
};

PyDoc_STRVAR(doc_QGraphicsSvgItem, "\1QGraphicsSvgItem(parent: QGraphicsItem|None = None)\n"
"QGraphicsSvgItem(fileName: str|None, parent: QGraphicsItem|None = None)");


static pyqt6ClassPluginDef plugin_QGraphicsSvgItem = {
    &::QGraphicsSvgItem::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSvgWidgets_QGraphicsSvgItem = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGraphicsSvgItem,
        SIP_NULLPTR,
        &plugin_QGraphicsSvgItem,
    },
    {
        sipNameNr_QGraphicsSvgItem,
        {0, 0, 1},
        9, methods_QGraphicsSvgItem,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGraphicsSvgItem,
    -1,
    -1,
    supers_QGraphicsSvgItem,
    SIP_NULLPTR,
    init_type_QGraphicsSvgItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGraphicsSvgItem,
    SIP_NULLPTR,
    array_QGraphicsSvgItem,
    SIP_NULLPTR,
    release_QGraphicsSvgItem,
    cast_QGraphicsSvgItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGraphicsSvgItem,
    sizeof (::QGraphicsSvgItem),
};
