/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qscroller.sip"
#include <qscroller.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qscrollerproperties.sip"
#include <qscrollerproperties.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 1298 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 58 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 61 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 64 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 67 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQScroller.cpp"


PyDoc_STRVAR(doc_QScroller_hasScroller, "hasScroller(target: QObject|None) -> bool");

extern "C" {static PyObject *meth_QScroller_hasScroller(PyObject *, PyObject *);}
static PyObject *meth_QScroller_hasScroller(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ8", &sipSelf, sipType_QObject, &a0))
        {
            bool sipRes;

            sipRes = ::QScroller::hasScroller(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_hasScroller, doc_QScroller_hasScroller);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_scroller, "scroller(target: QObject|None) -> QScroller|None");

extern "C" {static PyObject *meth_QScroller_scroller(PyObject *, PyObject *);}
static PyObject *meth_QScroller_scroller(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ8", &sipSelf, sipType_QObject, &a0))
        {
            ::QScroller*sipRes;

            sipRes = ::QScroller::scroller(a0);

            return sipConvertFromType(sipRes, sipType_QScroller, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_scroller, doc_QScroller_scroller);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_grabGesture, "grabGesture(target: QObject|None, scrollGestureType: QScroller.ScrollerGestureType = QScroller.TouchGesture) -> Qt.GestureType");

extern "C" {static PyObject *meth_QScroller_grabGesture(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QScroller_grabGesture(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        ::QScroller::ScrollerGestureType a1 = QScroller::TouchGesture;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_scrollGestureType,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "CJ8|E", &sipSelf, sipType_QObject, &a0, sipType_QScroller_ScrollerGestureType, &a1))
        {
            ::Qt::GestureType sipRes;

            sipRes = ::QScroller::grabGesture(a0, a1);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_GestureType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_grabGesture, doc_QScroller_grabGesture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_grabbedGesture, "grabbedGesture(target: QObject|None) -> Qt.GestureType");

extern "C" {static PyObject *meth_QScroller_grabbedGesture(PyObject *, PyObject *);}
static PyObject *meth_QScroller_grabbedGesture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ8", &sipSelf, sipType_QObject, &a0))
        {
            ::Qt::GestureType sipRes;

            sipRes = ::QScroller::grabbedGesture(a0);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_GestureType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_grabbedGesture, doc_QScroller_grabbedGesture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_ungrabGesture, "ungrabGesture(target: QObject|None)");

extern "C" {static PyObject *meth_QScroller_ungrabGesture(PyObject *, PyObject *);}
static PyObject *meth_QScroller_ungrabGesture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ8", &sipSelf, sipType_QObject, &a0))
        {
            ::QScroller::ungrabGesture(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_ungrabGesture, doc_QScroller_ungrabGesture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_activeScrollers, "activeScrollers() -> list[QScroller]");

extern "C" {static PyObject *meth_QScroller_activeScrollers(PyObject *, PyObject *);}
static PyObject *meth_QScroller_activeScrollers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            QList< ::QScroller*>*sipRes;

            sipRes = new QList< ::QScroller*>(::QScroller::activeScrollers());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QScroller, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_activeScrollers, doc_QScroller_activeScrollers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_target, "target(self) -> QObject|None");

extern "C" {static PyObject *meth_QScroller_target(PyObject *, PyObject *);}
static PyObject *meth_QScroller_target(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QScroller, &sipCpp))
        {
            ::QObject*sipRes;

            sipRes = sipCpp->target();

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_target, doc_QScroller_target);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_state, "state(self) -> QScroller.State");

extern "C" {static PyObject *meth_QScroller_state(PyObject *, PyObject *);}
static PyObject *meth_QScroller_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QScroller, &sipCpp))
        {
            ::QScroller::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QScroller_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_state, doc_QScroller_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_handleInput, "handleInput(self, input: QScroller.Input, position: QPointF, timestamp: int = 0) -> bool");

extern "C" {static PyObject *meth_QScroller_handleInput(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QScroller_handleInput(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QScroller::Input a0;
        const ::QPointF* a1;
        ::qint64 a2 = 0;
        ::QScroller *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_timestamp,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ9|n", &sipSelf, sipType_QScroller, &sipCpp, sipType_QScroller_Input, &a0, sipType_QPointF, &a1, &a2))
        {
            bool sipRes;

            sipRes = sipCpp->handleInput(a0, *a1, a2);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_handleInput, doc_QScroller_handleInput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_stop, "stop(self)");

extern "C" {static PyObject *meth_QScroller_stop(PyObject *, PyObject *);}
static PyObject *meth_QScroller_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QScroller, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_stop, doc_QScroller_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_velocity, "velocity(self) -> QPointF");

extern "C" {static PyObject *meth_QScroller_velocity(PyObject *, PyObject *);}
static PyObject *meth_QScroller_velocity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QScroller, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->velocity());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_velocity, doc_QScroller_velocity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_finalPosition, "finalPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QScroller_finalPosition(PyObject *, PyObject *);}
static PyObject *meth_QScroller_finalPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QScroller, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->finalPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_finalPosition, doc_QScroller_finalPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_pixelPerMeter, "pixelPerMeter(self) -> QPointF");

extern "C" {static PyObject *meth_QScroller_pixelPerMeter(PyObject *, PyObject *);}
static PyObject *meth_QScroller_pixelPerMeter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QScroller, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->pixelPerMeter());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_pixelPerMeter, doc_QScroller_pixelPerMeter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_scrollerProperties, "scrollerProperties(self) -> QScrollerProperties");

extern "C" {static PyObject *meth_QScroller_scrollerProperties(PyObject *, PyObject *);}
static PyObject *meth_QScroller_scrollerProperties(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QScroller, &sipCpp))
        {
            ::QScrollerProperties*sipRes;

            sipRes = new ::QScrollerProperties(sipCpp->scrollerProperties());

            return sipConvertFromNewType(sipRes, sipType_QScrollerProperties, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_scrollerProperties, doc_QScroller_scrollerProperties);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_setSnapPositionsX, "setSnapPositionsX(self, positions: Iterable[float])\n"
"setSnapPositionsX(self, first: float, interval: float)");

extern "C" {static PyObject *meth_QScroller_setSnapPositionsX(PyObject *, PyObject *);}
static PyObject *meth_QScroller_setSnapPositionsX(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QList< ::qreal>* a0;
        int a0State = 0;
        ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QScroller, &sipCpp, sipType_QList_2400, &a0, &a0State))
        {
            sipCpp->setSnapPositionsX(*a0);
            sipReleaseType(const_cast< ::QList< ::qreal> *>(a0), sipType_QList_2400, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QScroller, &sipCpp, &a0, &a1))
        {
            sipCpp->setSnapPositionsX(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_setSnapPositionsX, doc_QScroller_setSnapPositionsX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_setSnapPositionsY, "setSnapPositionsY(self, positions: Iterable[float])\n"
"setSnapPositionsY(self, first: float, interval: float)");

extern "C" {static PyObject *meth_QScroller_setSnapPositionsY(PyObject *, PyObject *);}
static PyObject *meth_QScroller_setSnapPositionsY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QList< ::qreal>* a0;
        int a0State = 0;
        ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QScroller, &sipCpp, sipType_QList_2400, &a0, &a0State))
        {
            sipCpp->setSnapPositionsY(*a0);
            sipReleaseType(const_cast< ::QList< ::qreal> *>(a0), sipType_QList_2400, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QScroller, &sipCpp, &a0, &a1))
        {
            sipCpp->setSnapPositionsY(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_setSnapPositionsY, doc_QScroller_setSnapPositionsY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_setScrollerProperties, "setScrollerProperties(self, prop: QScrollerProperties)");

extern "C" {static PyObject *meth_QScroller_setScrollerProperties(PyObject *, PyObject *);}
static PyObject *meth_QScroller_setScrollerProperties(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QScrollerProperties* a0;
        ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QScroller, &sipCpp, sipType_QScrollerProperties, &a0))
        {
            sipCpp->setScrollerProperties(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_setScrollerProperties, doc_QScroller_setScrollerProperties);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_scrollTo, "scrollTo(self, pos: QPointF)\n"
"scrollTo(self, pos: QPointF, scrollTime: int)");

extern "C" {static PyObject *meth_QScroller_scrollTo(PyObject *, PyObject *);}
static PyObject *meth_QScroller_scrollTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QScroller, &sipCpp, sipType_QPointF, &a0))
        {
            sipCpp->scrollTo(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QPointF* a0;
        int a1;
        ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9i", &sipSelf, sipType_QScroller, &sipCpp, sipType_QPointF, &a0, &a1))
        {
            sipCpp->scrollTo(*a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_scrollTo, doc_QScroller_scrollTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_ensureVisible, "ensureVisible(self, rect: QRectF, xmargin: float, ymargin: float)\n"
"ensureVisible(self, rect: QRectF, xmargin: float, ymargin: float, scrollTime: int)");

extern "C" {static PyObject *meth_QScroller_ensureVisible(PyObject *, PyObject *);}
static PyObject *meth_QScroller_ensureVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRectF* a0;
        ::qreal a1;
        ::qreal a2;
        ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9dd", &sipSelf, sipType_QScroller, &sipCpp, sipType_QRectF, &a0, &a1, &a2))
        {
            sipCpp->ensureVisible(*a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QRectF* a0;
        ::qreal a1;
        ::qreal a2;
        int a3;
        ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9ddi", &sipSelf, sipType_QScroller, &sipCpp, sipType_QRectF, &a0, &a1, &a2, &a3))
        {
            sipCpp->ensureVisible(*a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_ensureVisible, doc_QScroller_ensureVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QScroller_resendPrepareEvent, "resendPrepareEvent(self)");

extern "C" {static PyObject *meth_QScroller_resendPrepareEvent(PyObject *, PyObject *);}
static PyObject *meth_QScroller_resendPrepareEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QScroller *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QScroller, &sipCpp))
        {
            sipCpp->resendPrepareEvent();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScroller, sipName_resendPrepareEvent, doc_QScroller_resendPrepareEvent);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QScroller(void *, const sipTypeDef *);}
static void *cast_QScroller(void *sipCppV, const sipTypeDef *targetType)
{
    ::QScroller *sipCpp = reinterpret_cast< ::QScroller *>(sipCppV);

    if (targetType == sipType_QScroller)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QScroller(void *, int);}
static void release_QScroller(void *, int)
{
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QScroller[] = {{44, 0, 1}};


static PyMethodDef methods_QScroller[] = {
    {sipName_activeScrollers, meth_QScroller_activeScrollers, METH_VARARGS, doc_QScroller_activeScrollers},
    {sipName_ensureVisible, meth_QScroller_ensureVisible, METH_VARARGS, doc_QScroller_ensureVisible},
    {sipName_finalPosition, meth_QScroller_finalPosition, METH_VARARGS, doc_QScroller_finalPosition},
    {sipName_grabGesture, SIP_MLMETH_CAST(meth_QScroller_grabGesture), METH_VARARGS|METH_KEYWORDS, doc_QScroller_grabGesture},
    {sipName_grabbedGesture, meth_QScroller_grabbedGesture, METH_VARARGS, doc_QScroller_grabbedGesture},
    {sipName_handleInput, SIP_MLMETH_CAST(meth_QScroller_handleInput), METH_VARARGS|METH_KEYWORDS, doc_QScroller_handleInput},
    {sipName_hasScroller, meth_QScroller_hasScroller, METH_VARARGS, doc_QScroller_hasScroller},
    {sipName_pixelPerMeter, meth_QScroller_pixelPerMeter, METH_VARARGS, doc_QScroller_pixelPerMeter},
    {sipName_resendPrepareEvent, meth_QScroller_resendPrepareEvent, METH_VARARGS, doc_QScroller_resendPrepareEvent},
    {sipName_scrollTo, meth_QScroller_scrollTo, METH_VARARGS, doc_QScroller_scrollTo},
    {sipName_scroller, meth_QScroller_scroller, METH_VARARGS, doc_QScroller_scroller},
    {sipName_scrollerProperties, meth_QScroller_scrollerProperties, METH_VARARGS, doc_QScroller_scrollerProperties},
    {sipName_setScrollerProperties, meth_QScroller_setScrollerProperties, METH_VARARGS, doc_QScroller_setScrollerProperties},
    {sipName_setSnapPositionsX, meth_QScroller_setSnapPositionsX, METH_VARARGS, doc_QScroller_setSnapPositionsX},
    {sipName_setSnapPositionsY, meth_QScroller_setSnapPositionsY, METH_VARARGS, doc_QScroller_setSnapPositionsY},
    {sipName_state, meth_QScroller_state, METH_VARARGS, doc_QScroller_state},
    {sipName_stop, meth_QScroller_stop, METH_VARARGS, doc_QScroller_stop},
    {sipName_target, meth_QScroller_target, METH_VARARGS, doc_QScroller_target},
    {sipName_ungrabGesture, meth_QScroller_ungrabGesture, METH_VARARGS, doc_QScroller_ungrabGesture},
    {sipName_velocity, meth_QScroller_velocity, METH_VARARGS, doc_QScroller_velocity}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QScroller[] = {
    {sipName_InputPress, static_cast<int>(::QScroller::InputPress)},
    {sipName_InputMove, static_cast<int>(::QScroller::InputMove)},
    {sipName_InputRelease, static_cast<int>(::QScroller::InputRelease)},
    {sipName_TouchGesture, static_cast<int>(::QScroller::TouchGesture)},
    {sipName_LeftMouseButtonGesture, static_cast<int>(::QScroller::LeftMouseButtonGesture)},
    {sipName_RightMouseButtonGesture, static_cast<int>(::QScroller::RightMouseButtonGesture)},
    {sipName_MiddleMouseButtonGesture, static_cast<int>(::QScroller::MiddleMouseButtonGesture)},
    {sipName_Inactive, static_cast<int>(::QScroller::Inactive)},
    {sipName_Pressed, static_cast<int>(::QScroller::Pressed)},
    {sipName_Dragging, static_cast<int>(::QScroller::Dragging)},
    {sipName_Scrolling, static_cast<int>(::QScroller::Scrolling)},
    {0, 0}
};


/* Define this type's signals. */
static const pyqt6QtSignal signals_QScroller[] = {
    {"scrollerPropertiesChanged(QScrollerProperties)", "\1scrollerPropertiesChanged(self, a0: QScrollerProperties)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QScroller::State)", "\1stateChanged(self, newstate: QScroller.State)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QScroller = {
    &::QScroller::staticMetaObject,
    signals_QScroller,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QScroller = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QScroller,
        SIP_NULLPTR,
        &plugin_QScroller,
    },
    {
        sipNameNr_QScroller,
        {0, 0, 1},
        20, methods_QScroller,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QScroller, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QScroller,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QScroller,
    cast_QScroller,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
