/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtQmlAPI_H
#define _QtQmlAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_markCurrentFunctionAsTranslationBinding 0
#define sipName_markCurrentFunctionAsTranslationBinding &sipStrings_QtQml[0]
#define sipNameNr_QQmlAbstractUrlInterceptor__DataType 40
#define sipName_QQmlAbstractUrlInterceptor__DataType &sipStrings_QtQml[40]
#define sipNameNr_77 77
#define sipName_77 &sipStrings_QtQml[77]
#define sipNameNr_QJSValue__ObjectConversionBehavior 113
#define sipName_QJSValue__ObjectConversionBehavior &sipStrings_QtQml[113]
#define sipNameNr_148 148
#define sipName_148 &sipStrings_QtQml[148]
#define sipNameNr_QQmlProperty__PropertyTypeCategory 183
#define sipName_QQmlProperty__PropertyTypeCategory &sipStrings_QtQml[183]
#define sipNameNr_218 218
#define sipName_218 &sipStrings_QtQml[218]
#define sipNameNr_QQmlImageProviderBase__ImageType 251
#define sipName_QQmlImageProviderBase__ImageType &sipStrings_QtQml[251]
#define sipNameNr_qmlRegisterUncreatableMetaObject 284
#define sipName_qmlRegisterUncreatableMetaObject &sipStrings_QtQml[284]
#define sipNameNr_setOutputWarningsToStandardError 317
#define sipName_setOutputWarningsToStandardError &sipStrings_QtQml[317]
#define sipNameNr_QQmlNetworkAccessManagerFactory 350
#define sipName_QQmlNetworkAccessManagerFactory &sipStrings_QtQml[350]
#define sipNameNr_QQmlComponent__CompilationMode 382
#define sipName_QQmlComponent__CompilationMode &sipStrings_QtQml[382]
#define sipNameNr_offlineStorageDatabaseFilePath 413
#define sipName_offlineStorageDatabaseFilePath &sipStrings_QtQml[413]
#define sipNameNr_setNetworkAccessManagerFactory 444
#define sipName_setNetworkAccessManagerFactory &sipStrings_QtQml[444]
#define sipNameNr_ForceAsynchronousImageLoading 475
#define sipName_ForceAsynchronousImageLoading &sipStrings_QtQml[475]
#define sipNameNr_QQmlIncubator__IncubationMode 505
#define sipName_QQmlIncubator__IncubationMode &sipStrings_QtQml[505]
#define sipNameNr_outputWarningsToStandardError 535
#define sipName_outputWarningsToStandardError &sipStrings_QtQml[535]
#define sipNameNr_565 565
#define sipName_565 &sipStrings_QtQml[565]
#define sipNameNr_incubatingObjectCountChanged 594
#define sipName_incubatingObjectCountChanged &sipStrings_QtQml[594]
#define sipNameNr_qmlRegisterSingletonInstance 623
#define sipName_qmlRegisterSingletonInstance &sipStrings_QtQml[623]
#define sipNameNr_QQmlImageProviderBase__Flag 652
#define sipName_QQmlImageProviderBase__Flag &sipStrings_QtQml[652]
#define sipNameNr_createWithInitialProperties 680
#define sipName_createWithInitialProperties &sipStrings_QtQml[680]
#define sipNameNr_networkAccessManagerFactory 708
#define sipName_networkAccessManagerFactory &sipStrings_QtQml[708]
#define sipNameNr_qmlAttachedPropertiesObject 736
#define sipName_qmlAttachedPropertiesObject &sipStrings_QtQml[736]
#define sipNameNr_qmlRegisterTypeNotAvailable 764
#define sipName_qmlRegisterTypeNotAvailable &sipStrings_QtQml[764]
#define sipNameNr_GarbageCollectionExtension 792
#define sipName_GarbageCollectionExtension &sipStrings_QtQml[792]
#define sipNameNr_QJSEngine__ObjectOwnership 819
#define sipName_QJSEngine__ObjectOwnership &sipStrings_QtQml[819]
#define sipNameNr_QQmlAbstractUrlInterceptor 846
#define sipName_QQmlAbstractUrlInterceptor &sipStrings_QtQml[846]
#define sipNameNr_qmlRegisterUncreatableType 873
#define sipName_qmlRegisterUncreatableType &sipStrings_QtQml[873]
#define sipNameNr_QQmlContext__PropertyPair 900
#define sipName_QQmlContext__PropertyPair &sipStrings_QtQml[900]
#define sipNameNr_QQmlEngineExtensionPlugin 926
#define sipName_QQmlEngineExtensionPlugin &sipStrings_QtQml[926]
#define sipNameNr_952 952
#define sipName_952 &sipStrings_QtQml[952]
#define sipNameNr_offlineStoragePathChanged 978
#define sipName_offlineStoragePathChanged &sipStrings_QtQml[978]
#define sipNameNr_qmlClearTypeRegistrations 1004
#define sipName_qmlClearTypeRegistrations &sipStrings_QtQml[1004]
#define sipNameNr_ObjectConversionBehavior 123
#define sipName_ObjectConversionBehavior &sipStrings_QtQml[123]
#define sipNameNr_QQmlIncubationController 1030
#define sipName_QQmlIncubationController &sipStrings_QtQml[1030]
#define sipNameNr_qmlRegisterAnonymousType 1055
#define sipName_qmlRegisterAnonymousType &sipStrings_QtQml[1055]
#define sipNameNr_qmlRegisterSingletonType 1080
#define sipName_qmlRegisterSingletonType &sipStrings_QtQml[1080]
#define sipNameNr_PyQt6_sip_simplewrapper 1105
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtQml[1105]
#define sipNameNr_QJSPrimitiveValue__Type 1129
#define sipName_QJSPrimitiveValue__Type &sipStrings_QtQml[1129]
#define sipNameNr_QQmlPropertyValueSource 1153
#define sipName_QQmlPropertyValueSource &sipStrings_QtQml[1153]
#define sipNameNr_setIncubationController 1177
#define sipName_setIncubationController &sipStrings_QtQml[1177]
#define sipNameNr_setNotifyOnValueChanged 1201
#define sipName_setNotifyOnValueChanged &sipStrings_QtQml[1201]
#define sipNameNr_QJSValue__SpecialValue 1225
#define sipName_QJSValue__SpecialValue &sipStrings_QtQml[1225]
#define sipNameNr_findObjectsRecursively 1248
#define sipName_findObjectsRecursively &sipStrings_QtQml[1248]
#define sipNameNr_QJSManagedValue__Type 1271
#define sipName_QJSManagedValue__Type &sipStrings_QtQml[1271]
#define sipNameNr_QJSPrimitiveUndefined 1293
#define sipName_QJSPrimitiveUndefined &sipStrings_QtQml[1293]
#define sipNameNr_QQmlApplicationEngine 1315
#define sipName_QQmlApplicationEngine &sipStrings_QtQml[1315]
#define sipNameNr_QQmlComponent__Status 1337
#define sipName_QQmlComponent__Status &sipStrings_QtQml[1337]
#define sipNameNr_QQmlImageProviderBase 1359
#define sipName_QQmlImageProviderBase &sipStrings_QtQml[1359]
#define sipNameNr_QQmlIncubator__Status 1381
#define sipName_QQmlIncubator__Status &sipStrings_QtQml[1381]
#define sipNameNr_findObjectRecursively 1403
#define sipName_findObjectRecursively &sipStrings_QtQml[1403]
#define sipNameNr_incubatingObjectCount 1425
#define sipName_incubatingObjectCount &sipStrings_QtQml[1425]
#define sipNameNr_setExtraFileSelectors 1447
#define sipName_setExtraFileSelectors &sipStrings_QtQml[1447]
#define sipNameNr_setOfflineStoragePath 1469
#define sipName_setOfflineStoragePath &sipStrings_QtQml[1469]
#define sipNameNr_AsynchronousIfNested 1491
#define sipName_AsynchronousIfNested &sipStrings_QtQml[1491]
#define sipNameNr_PropertyTypeCategory 197
#define sipName_PropertyTypeCategory &sipStrings_QtQml[197]
#define sipNameNr_QJSEngine__Extension 1512
#define sipName_QJSEngine__Extension &sipStrings_QtQml[1512]
#define sipNameNr_TranslationExtension 1533
#define sipName_TranslationExtension &sipStrings_QtQml[1533]
#define sipNameNr_incubationController 1554
#define sipName_incubationController &sipStrings_QtQml[1554]
#define sipNameNr_networkAccessManager 1575
#define sipName_networkAccessManager &sipStrings_QtQml[1575]
#define sipNameNr_notifyOnValueChanged 1596
#define sipName_notifyOnValueChanged &sipStrings_QtQml[1596]
#define sipNameNr_objectCreationFailed 1617
#define sipName_objectCreationFailed &sipStrings_QtQml[1617]
#define sipNameNr_propertyTypeCategory 1638
#define sipName_propertyTypeCategory &sipStrings_QtQml[1638]
#define sipNameNr_removeUrlInterceptor 1659
#define sipName_removeUrlInterceptor &sipStrings_QtQml[1659]
#define sipNameNr_setContextProperties 1680
#define sipName_setContextProperties &sipStrings_QtQml[1680]
#define sipNameNr_setInitialProperties 1701
#define sipName_setInitialProperties &sipStrings_QtQml[1701]
#define sipNameNr_JavaScriptOwnership 1722
#define sipName_JavaScriptOwnership &sipStrings_QtQml[1722]
#define sipNameNr_QJSValue__ErrorType 1742
#define sipName_QJSValue__ErrorType &sipStrings_QtQml[1742]
#define sipNameNr_1762 1762
#define sipName_1762 &sipStrings_QtQml[1762]
#define sipNameNr_1782 1782
#define sipName_1782 &sipStrings_QtQml[1782]
#define sipNameNr_QQmlExtensionPlugin 1802
#define sipName_QQmlExtensionPlugin &sipStrings_QtQml[1802]
#define sipNameNr_clearComponentCache 1822
#define sipName_clearComponentCache &sipStrings_QtQml[1822]
#define sipNameNr_connectNotifySignal 1842
#define sipName_connectNotifySignal &sipStrings_QtQml[1842]
#define sipNameNr_exceptionStackTrace 1862
#define sipName_exceptionStackTrace &sipStrings_QtQml[1862]
#define sipNameNr_isRegularExpression 1882
#define sipName_isRegularExpression &sipStrings_QtQml[1882]
#define sipNameNr_qmlRegisterRevision 1902
#define sipName_qmlRegisterRevision &sipStrings_QtQml[1902]
#define sipNameNr_removeImageProvider 1922
#define sipName_removeImageProvider &sipStrings_QtQml[1922]
#define sipNameNr_setContextForObject 1942
#define sipName_setContextForObject &sipStrings_QtQml[1942]
#define sipNameNr_toRegularExpression 1962
#define sipName_toRegularExpression &sipStrings_QtQml[1962]
#define sipNameNr_QQmlProperty__Type 1982
#define sipName_QQmlProperty__Type &sipStrings_QtQml[1982]
#define sipNameNr_attachedProperties 2001
#define sipName_attachedProperties &sipStrings_QtQml[2001]
#define sipNameNr_isUndefinedLiteral 2020
#define sipName_isUndefinedLiteral &sipStrings_QtQml[2020]
#define sipNameNr_offlineStoragePath 2039
#define sipName_offlineStoragePath &sipStrings_QtQml[2039]
#define sipNameNr_setContextProperty 2058
#define sipName_setContextProperty &sipStrings_QtQml[2058]
#define sipNameNr_setObjectOwnership 2077
#define sipName_setObjectOwnership &sipStrings_QtQml[2077]
#define sipNameNr_trimComponentCache 2096
#define sipName_trimComponentCache &sipStrings_QtQml[2096]
#define sipNameNr_PreferSynchronous 2115
#define sipName_PreferSynchronous &sipStrings_QtQml[2115]
#define sipNameNr_QJSPrimitiveValue 2133
#define sipName_QJSPrimitiveValue &sipStrings_QtQml[2133]
#define sipNameNr_QQmlListReference 2151
#define sipName_QQmlListReference &sipStrings_QtQml[2151]
#define sipNameNr_addUrlInterceptor 2169
#define sipName_addUrlInterceptor &sipStrings_QtQml[2169]
#define sipNameNr_callAsConstructor 2187
#define sipName_callAsConstructor &sipStrings_QtQml[2187]
#define sipNameNr_componentComplete 2205
#define sipName_componentComplete &sipStrings_QtQml[2205]
#define sipNameNr_installExtensions 2223
#define sipName_installExtensions &sipStrings_QtQml[2223]
#define sipNameNr_needsNotifySignal 2241
#define sipName_needsNotifySignal &sipStrings_QtQml[2241]
#define sipNameNr_qmlRegisterModule 2259
#define sipName_qmlRegisterModule &sipStrings_QtQml[2259]
#define sipNameNr_setExtraSelectors 2277
#define sipName_setExtraSelectors &sipStrings_QtQml[2277]
#define sipNameNr_setImportPathList 2295
#define sipName_setImportPathList &sipStrings_QtQml[2295]
#define sipNameNr_setPluginPathList 2313
#define sipName_setPluginPathList &sipStrings_QtQml[2313]
#define sipNameNr_setSourceLocation 2331
#define sipName_setSourceLocation &sipStrings_QtQml[2331]
#define sipNameNr_singletonInstance 2349
#define sipName_singletonInstance &sipStrings_QtQml[2349]
#define sipNameNr_uiLanguageChanged 2367
#define sipName_uiLanguageChanged &sipStrings_QtQml[2367]
#define sipNameNr_ConsoleExtension 2385
#define sipName_ConsoleExtension &sipStrings_QtQml[2385]
#define sipNameNr_ConvertJSObjects 2402
#define sipName_ConvertJSObjects &sipStrings_QtQml[2402]
#define sipNameNr_QJSPrimitiveNull 2419
#define sipName_QJSPrimitiveNull &sipStrings_QtQml[2419]
#define sipNameNr_QJSValueIterator 2436
#define sipName_QJSValueIterator &sipStrings_QtQml[2436]
#define sipNameNr_2453 2453
#define sipName_2453 &sipStrings_QtQml[2453]
#define sipNameNr_QQmlFileSelector 2470
#define sipName_QQmlFileSelector &sipStrings_QtQml[2470]
#define sipNameNr_QQmlParserStatus 2487
#define sipName_QQmlParserStatus &sipStrings_QtQml[2487]
#define sipNameNr_QQmlScriptString 2504
#define sipName_QQmlScriptString &sipStrings_QtQml[2504]
#define sipNameNr_addImageProvider 2521
#define sipName_addImageProvider &sipStrings_QtQml[2521]
#define sipNameNr_callWithInstance 2538
#define sipName_callWithInstance &sipStrings_QtQml[2538]
#define sipNameNr_contextForObject 2555
#define sipName_contextForObject &sipStrings_QtQml[2555]
#define sipNameNr_disconnectNotify 2572
#define sipName_disconnectNotify &sipStrings_QtQml[2572]
#define sipNameNr_initializeEngine 2589
#define sipName_initializeEngine &sipStrings_QtQml[2589]
#define sipNameNr_isSignalProperty 2606
#define sipName_isSignalProperty &sipStrings_QtQml[2606]
#define sipNameNr_propertyMetaType 2623
#define sipName_propertyMetaType &sipStrings_QtQml[2623]
#define sipNameNr_propertyTypeName 2640
#define sipName_propertyTypeName &sipStrings_QtQml[2640]
#define sipNameNr_qmlProtectModule 2657
#define sipName_qmlProtectModule &sipStrings_QtQml[2657]
#define sipNameNr_setContextObject 2674
#define sipName_setContextObject &sipStrings_QtQml[2674]
#define sipNameNr_toPrimitiveValue 2691
#define sipName_toPrimitiveValue &sipStrings_QtQml[2691]
#define sipNameNr_valueIsUndefined 2708
#define sipName_valueIsUndefined &sipStrings_QtQml[2708]
#define sipNameNr_CompilationMode 397
#define sipName_CompilationMode &sipStrings_QtQml[397]
#define sipNameNr_InvalidCategory 2725
#define sipName_InvalidCategory &sipStrings_QtQml[2725]
#define sipNameNr_ObjectOwnership 830
#define sipName_ObjectOwnership &sipStrings_QtQml[830]
#define sipNameNr_QJSManagedValue 2741
#define sipName_QJSManagedValue &sipStrings_QtQml[2741]
#define sipNameNr_2757 2757
#define sipName_2757 &sipStrings_QtQml[2757]
#define sipNameNr_QQmlPropertyMap 2773
#define sipName_QQmlPropertyMap &sipStrings_QtQml[2773]
#define sipNameNr_RetainJSObjects 2789
#define sipName_RetainJSObjects &sipStrings_QtQml[2789]
#define sipNameNr_clearSingletons 2805
#define sipName_clearSingletons &sipStrings_QtQml[2805]
#define sipNameNr_contextProperty 2821
#define sipName_contextProperty &sipStrings_QtQml[2821]
#define sipNameNr_creationContext 2837
#define sipName_creationContext &sipStrings_QtQml[2837]
#define sipNameNr_forceCompletion 2853
#define sipName_forceCompletion &sipStrings_QtQml[2853]
#define sipNameNr_hasNotifySignal 2869
#define sipName_hasNotifySignal &sipStrings_QtQml[2869]
#define sipNameNr_listElementType 2885
#define sipName_listElementType &sipStrings_QtQml[2885]
#define sipNameNr_objectOwnership 2901
#define sipName_objectOwnership &sipStrings_QtQml[2901]
#define sipNameNr_progressChanged 2917
#define sipName_progressChanged &sipStrings_QtQml[2917]
#define sipNameNr_qmlRegisterType 2933
#define sipName_qmlRegisterType &sipStrings_QtQml[2933]
#define sipNameNr_setInitialState 2949
#define sipName_setInitialState &sipStrings_QtQml[2949]
#define sipNameNr_unregisterTypes 2965
#define sipName_unregisterTypes &sipStrings_QtQml[2965]
#define sipNameNr_urlInterceptors 2981
#define sipName_urlInterceptors &sipStrings_QtQml[2981]
#define sipNameNr_IncubationMode 520
#define sipName_IncubationMode &sipStrings_QtQml[520]
#define sipNameNr_JavaScriptFile 2997
#define sipName_JavaScriptFile &sipStrings_QtQml[2997]
#define sipNameNr_QQmlExpression 3012
#define sipName_QQmlExpression &sipStrings_QtQml[3012]
#define sipNameNr_ReferenceError 3027
#define sipName_ReferenceError &sipStrings_QtQml[3027]
#define sipNameNr_SignalProperty 2608
#define sipName_SignalProperty &sipStrings_QtQml[2608]
#define sipNameNr_UndefinedValue 3042
#define sipName_UndefinedValue &sipStrings_QtQml[3042]
#define sipNameNr_booleanLiteral 3057
#define sipName_booleanLiteral &sipStrings_QtQml[3057]
#define sipNameNr_collectGarbage 3072
#define sipName_collectGarbage &sipStrings_QtQml[3072]
#define sipNameNr_completeCreate 3087
#define sipName_completeCreate &sipStrings_QtQml[3087]
#define sipNameNr_deleteProperty 3102
#define sipName_deleteProperty &sipStrings_QtQml[3102]
#define sipNameNr_hasOwnProperty 3117
#define sipName_hasOwnProperty &sipStrings_QtQml[3117]
#define sipNameNr_importPathList 3132
#define sipName_importPathList &sipStrings_QtQml[3132]
#define sipNameNr_incubationMode 3147
#define sipName_incubationMode &sipStrings_QtQml[3147]
#define sipNameNr_loadFromModule 3162
#define sipName_loadFromModule &sipStrings_QtQml[3162]
#define sipNameNr_newErrorObject 3177
#define sipName_newErrorObject &sipStrings_QtQml[3177]
#define sipNameNr_newQMetaObject 3192
#define sipName_newQMetaObject &sipStrings_QtQml[3192]
#define sipNameNr_pluginPathList 3207
#define sipName_pluginPathList &sipStrings_QtQml[3207]
#define sipNameNr_registerModule 3222
#define sipName_registerModule &sipStrings_QtQml[3222]
#define sipNameNr_setDescription 3237
#define sipName_setDescription &sipStrings_QtQml[3237]
#define sipNameNr_setInterrupted 3252
#define sipName_setInterrupted &sipStrings_QtQml[3252]
#define sipNameNr_setMessageType 3267
#define sipName_setMessageType &sipStrings_QtQml[3267]
#define sipNameNr_strictlyEquals 3282
#define sipName_strictlyEquals &sipStrings_QtQml[3282]
#define sipNameNr_toManagedValue 3297
#define sipName_toManagedValue &sipStrings_QtQml[3297]
#define sipNameNr_AllExtensions 3312
#define sipName_AllExtensions &sipStrings_QtQml[3312]
#define sipNameNr_ImageResponse 3326
#define sipName_ImageResponse &sipStrings_QtQml[3326]
#define sipNameNr_QQmlComponent 3340
#define sipName_QQmlComponent &sipStrings_QtQml[3340]
#define sipNameNr_QQmlIncubator 3354
#define sipName_QQmlIncubator &sipStrings_QtQml[3354]
#define sipNameNr_addImportPath 3368
#define sipName_addImportPath &sipStrings_QtQml[3368]
#define sipNameNr_addPluginPath 3382
#define sipName_addPluginPath &sipStrings_QtQml[3382]
#define sipNameNr_canRemoveLast 3396
#define sipName_canRemoveLast &sipStrings_QtQml[3396]
#define sipNameNr_childContexts 3410
#define sipName_childContexts &sipStrings_QtQml[3410]
#define sipNameNr_connectNotify 2575
#define sipName_connectNotify &sipStrings_QtQml[2575]
#define sipNameNr_contextObject 3424
#define sipName_contextObject &sipStrings_QtQml[3424]
#define sipNameNr_imageProvider 3438
#define sipName_imageProvider &sipStrings_QtQml[3438]
#define sipNameNr_isInterrupted 3452
#define sipName_isInterrupted &sipStrings_QtQml[3452]
#define sipNameNr_isManipulable 3466
#define sipName_isManipulable &sipStrings_QtQml[3466]
#define sipNameNr_isNullLiteral 3480
#define sipName_isNullLiteral &sipStrings_QtQml[3480]
#define sipNameNr_isQMetaObject 3494
#define sipName_isQMetaObject &sipStrings_QtQml[3494]
#define sipNameNr_nameForObject 3508
#define sipName_nameForObject &sipStrings_QtQml[3508]
#define sipNameNr_numberLiteral 3522
#define sipName_numberLiteral &sipStrings_QtQml[3522]
#define sipNameNr_objectCreated 3536
#define sipName_objectCreated &sipStrings_QtQml[3536]
#define sipNameNr_objectForName 3550
#define sipName_objectForName &sipStrings_QtQml[3550]
#define sipNameNr_parentContext 3564
#define sipName_parentContext &sipStrings_QtQml[3564]
#define sipNameNr_registerTypes 2967
#define sipName_registerTypes &sipStrings_QtQml[2967]
#define sipNameNr_setExpression 3578
#define sipName_setExpression &sipStrings_QtQml[3578]
#define sipNameNr_setUiLanguage 3592
#define sipName_setUiLanguage &sipStrings_QtQml[3592]
#define sipNameNr_statusChanged 3606
#define sipName_statusChanged &sipStrings_QtQml[3606]
#define sipNameNr_stringLiteral 3620
#define sipName_stringLiteral &sipStrings_QtQml[3620]
#define sipNameNr_toQMetaObject 3634
#define sipName_toQMetaObject &sipStrings_QtQml[3634]
#define sipNameNr_toScriptValue 3648
#define sipName_toScriptValue &sipStrings_QtQml[3648]
#define sipNameNr_Asynchronous 3662
#define sipName_Asynchronous &sipStrings_QtQml[3662]
#define sipNameNr_CppOwnership 3675
#define sipName_CppOwnership &sipStrings_QtQml[3675]
#define sipNameNr_GenericError 3688
#define sipName_GenericError &sipStrings_QtQml[3688]
#define sipNameNr_PropertyPair 913
#define sipName_PropertyPair &sipStrings_QtQml[913]
#define sipNameNr_QQmlProperty 3701
#define sipName_QQmlProperty &sipStrings_QtQml[3701]
#define sipNameNr_SpecialValue 1235
#define sipName_SpecialValue &sipStrings_QtQml[1235]
#define sipNameNr_columnNumber 3714
#define sipName_columnNumber &sipStrings_QtQml[3714]
#define sipNameNr_globalObject 3727
#define sipName_globalObject &sipStrings_QtQml[3727]
#define sipNameNr_importModule 3740
#define sipName_importModule &sipStrings_QtQml[3740]
#define sipNameNr_importPlugin 3753
#define sipName_importPlugin &sipStrings_QtQml[3753]
#define sipNameNr_interceptUrl 3766
#define sipName_interceptUrl &sipStrings_QtQml[3766]
#define sipNameNr_isDesignable 3779
#define sipName_isDesignable &sipStrings_QtQml[3779]
#define sipNameNr_isResettable 3792
#define sipName_isResettable &sipStrings_QtQml[3792]
#define sipNameNr_propertyType 3805
#define sipName_propertyType &sipStrings_QtQml[3805]
#define sipNameNr_setPrototype 3818
#define sipName_setPrototype &sipStrings_QtQml[3818]
#define sipNameNr_valueChanged 3831
#define sipName_valueChanged &sipStrings_QtQml[3831]
#define sipNameNr_PyQt6_QtQml 3844
#define sipName_PyQt6_QtQml &sipStrings_QtQml[3844]
#define sipNameNr_QQmlContext 3856
#define sipName_QQmlContext &sipStrings_QtQml[3856]
#define sipNameNr_Synchronous 2121
#define sipName_Synchronous &sipStrings_QtQml[2121]
#define sipNameNr_SyntaxError 3868
#define sipName_SyntaxError &sipStrings_QtQml[3868]
#define sipNameNr___getitem__ 3880
#define sipName___getitem__ &sipStrings_QtQml[3880]
#define sipNameNr___truediv__ 3892
#define sipName___truediv__ &sipStrings_QtQml[3892]
#define sipNameNr_beginCreate 3904
#define sipName_beginCreate &sipStrings_QtQml[3904]
#define sipNameNr_customEvent 3916
#define sipName_customEvent &sipStrings_QtQml[3916]
#define sipNameNr_description 3928
#define sipName_description &sipStrings_QtQml[3928]
#define sipNameNr_eventFilter 3940
#define sipName_eventFilter &sipStrings_QtQml[3940]
#define sipNameNr_hasProperty 3952
#define sipName_hasProperty &sipStrings_QtQml[3952]
#define sipNameNr_incubateFor 3964
#define sipName_incubateFor &sipStrings_QtQml[3964]
#define sipNameNr_isUndefined 3976
#define sipName_isUndefined &sipStrings_QtQml[3976]
#define sipNameNr_messageType 3988
#define sipName_messageType &sipStrings_QtQml[3988]
#define sipNameNr_resolvedUrl 4000
#define sipName_resolvedUrl &sipStrings_QtQml[4000]
#define sipNameNr_retranslate 4012
#define sipName_retranslate &sipStrings_QtQml[4012]
#define sipNameNr_rootContext 4024
#define sipName_rootContext &sipStrings_QtQml[4024]
#define sipNameNr_rootObjects 4036
#define sipName_rootObjects &sipStrings_QtQml[4036]
#define sipNameNr_scopeObject 4048
#define sipName_scopeObject &sipStrings_QtQml[4048]
#define sipNameNr_setProperty 4060
#define sipName_setProperty &sipStrings_QtQml[4060]
#define sipNameNr_setSelector 4072
#define sipName_setSelector &sipStrings_QtQml[4072]
#define sipNameNr_toPrimitive 4084
#define sipName_toPrimitive &sipStrings_QtQml[4084]
#define sipNameNr_updateValue 4096
#define sipName_updateValue &sipStrings_QtQml[4096]
#define sipNameNr_QQmlEngine 4108
#define sipName_QQmlEngine &sipStrings_QtQml[4108]
#define sipNameNr_QmldirFile 4119
#define sipName_QmldirFile &sipStrings_QtQml[4119]
#define sipNameNr_RangeError 4130
#define sipName_RangeError &sipStrings_QtQml[4130]
#define sipNameNr___lshift__ 4141
#define sipName___lshift__ &sipStrings_QtQml[4141]
#define sipNameNr___rshift__ 4152
#define sipName___rshift__ &sipStrings_QtQml[4152]
#define sipNameNr_canReplace 4163
#define sipName_canReplace &sipStrings_QtQml[4163]
#define sipNameNr_catchError 4174
#define sipName_catchError &sipStrings_QtQml[4174]
#define sipNameNr_childEvent 4185
#define sipName_childEvent &sipStrings_QtQml[4185]
#define sipNameNr_classBegin 4196
#define sipName_classBegin &sipStrings_QtQml[4196]
#define sipNameNr_clearError 4207
#define sipName_clearError &sipStrings_QtQml[4207]
#define sipNameNr_expression 4218
#define sipName_expression &sipStrings_QtQml[4218]
#define sipNameNr_forContext 4229
#define sipName_forContext &sipStrings_QtQml[4229]
#define sipNameNr_isBindable 4240
#define sipName_isBindable &sipStrings_QtQml[4240]
#define sipNameNr_isCallable 4251
#define sipName_isCallable &sipStrings_QtQml[4251]
#define sipNameNr_isFunction 4262
#define sipName_isFunction &sipStrings_QtQml[4262]
#define sipNameNr_isProperty 4273
#define sipName_isProperty &sipStrings_QtQml[4273]
#define sipNameNr_isReadable 4284
#define sipName_isReadable &sipStrings_QtQml[4284]
#define sipNameNr_isWritable 4295
#define sipName_isWritable &sipStrings_QtQml[4295]
#define sipNameNr_lineNumber 4306
#define sipName_lineNumber &sipStrings_QtQml[4306]
#define sipNameNr_newQObject 4317
#define sipName_newQObject &sipStrings_QtQml[4317]
#define sipNameNr_qmlContext 4328
#define sipName_qmlContext &sipStrings_QtQml[4328]
#define sipNameNr_removeLast 4339
#define sipName_removeLast &sipStrings_QtQml[4339]
#define sipNameNr_setBaseUrl 4350
#define sipName_setBaseUrl &sipStrings_QtQml[4350]
#define sipNameNr_sourceFile 4361
#define sipName_sourceFile &sipStrings_QtQml[4361]
#define sipNameNr_throwError 4372
#define sipName_throwError &sipStrings_QtQml[4372]
#define sipNameNr_timerEvent 4383
#define sipName_timerEvent &sipStrings_QtQml[4383]
#define sipNameNr_toDateTime 4394
#define sipName_toDateTime &sipStrings_QtQml[4394]
#define sipNameNr_uiLanguage 4405
#define sipName_uiLanguage &sipStrings_QtQml[4405]
#define sipNameNr_ErrorType 1752
#define sipName_ErrorType &sipStrings_QtQml[1752]
#define sipNameNr_EvalError 4416
#define sipName_EvalError &sipStrings_QtQml[4416]
#define sipNameNr_Extension 809
#define sipName_Extension &sipStrings_QtQml[809]
#define sipNameNr_ImageType 274
#define sipName_ImageType &sipStrings_QtQml[274]
#define sipNameNr_NullValue 4426
#define sipName_NullValue &sipStrings_QtQml[4426]
#define sipNameNr_QJSEngine 4436
#define sipName_QJSEngine &sipStrings_QtQml[4436]
#define sipNameNr_QQmlError 4446
#define sipName_QQmlError &sipStrings_QtQml[4446]
#define sipNameNr_TypeError 4456
#define sipName_TypeError &sipStrings_QtQml[4456]
#define sipNameNr_Undefined 1305
#define sipName_Undefined &sipStrings_QtQml[1305]
#define sipNameNr_UrlString 4466
#define sipName_UrlString &sipStrings_QtQml[4466]
#define sipNameNr_arguments 4476
#define sipName_arguments &sipStrings_QtQml[4476]
#define sipNameNr_canAppend 4486
#define sipName_canAppend &sipStrings_QtQml[4486]
#define sipNameNr_errorType 4496
#define sipName_errorType &sipStrings_QtQml[4496]
#define sipNameNr_imageType 4506
#define sipName_imageType &sipStrings_QtQml[4506]
#define sipNameNr_intercept 4516
#define sipName_intercept &sipStrings_QtQml[4516]
#define sipNameNr_isBoolean 4526
#define sipName_isBoolean &sipStrings_QtQml[4526]
#define sipNameNr_isInteger 4536
#define sipName_isInteger &sipStrings_QtQml[4536]
#define sipNameNr_isLoading 4546
#define sipName_isLoading &sipStrings_QtQml[4546]
#define sipNameNr_isQObject 4556
#define sipName_isQObject &sipStrings_QtQml[4556]
#define sipNameNr_isVariant 4566
#define sipName_isVariant &sipStrings_QtQml[4566]
#define sipNameNr_newObject 4576
#define sipName_newObject &sipStrings_QtQml[4576]
#define sipNameNr_newSymbol 4586
#define sipName_newSymbol &sipStrings_QtQml[4586]
#define sipNameNr_prototype 4596
#define sipName_prototype &sipStrings_QtQml[4596]
#define sipNameNr_qjsEngine 4606
#define sipName_qjsEngine &sipStrings_QtQml[4606]
#define sipNameNr_qmlEngine 4616
#define sipName_qmlEngine &sipStrings_QtQml[4616]
#define sipNameNr_qmlTypeId 4626
#define sipName_qmlTypeId &sipStrings_QtQml[4626]
#define sipNameNr_setColumn 4636
#define sipName_setColumn &sipStrings_QtQml[4636]
#define sipNameNr_setObject 4646
#define sipName_setObject &sipStrings_QtQml[4646]
#define sipNameNr_setTarget 4656
#define sipName_setTarget &sipStrings_QtQml[4656]
#define sipNameNr_toBoolean 4666
#define sipName_toBoolean &sipStrings_QtQml[4666]
#define sipNameNr_toInteger 4676
#define sipName_toInteger &sipStrings_QtQml[4676]
#define sipNameNr_toJSValue 4686
#define sipName_toJSValue &sipStrings_QtQml[4686]
#define sipNameNr_toQObject 4696
#define sipName_toQObject &sipStrings_QtQml[4696]
#define sipNameNr_toVariant 4706
#define sipName_toVariant &sipStrings_QtQml[4706]
#define sipNameNr_DataType 68
#define sipName_DataType &sipStrings_QtQml[68]
#define sipNameNr_Function 4264
#define sipName_Function &sipStrings_QtQml[4264]
#define sipNameNr_Property 2068
#define sipName_Property &sipStrings_QtQml[2068]
#define sipNameNr_QJSValue 4716
#define sipName_QJSValue &sipStrings_QtQml[4716]
#define sipNameNr_URIError 4725
#define sipName_URIError &sipStrings_QtQml[4725]
#define sipNameNr___hash__ 4734
#define sipName___hash__ &sipStrings_QtQml[4734]
#define sipNameNr_canClear 4743
#define sipName_canClear &sipStrings_QtQml[4743]
#define sipNameNr_canCount 4752
#define sipName_canCount &sipStrings_QtQml[4752]
#define sipNameNr_contains 4761
#define sipName_contains &sipStrings_QtQml[4761]
#define sipNameNr_evaluate 4770
#define sipName_evaluate &sipStrings_QtQml[4770]
#define sipNameNr_fileName 4779
#define sipName_fileName &sipStrings_QtQml[4779]
#define sipNameNr_hasError 4788
#define sipName_hasError &sipStrings_QtQml[4788]
#define sipNameNr_isNumber 4797
#define sipName_isNumber &sipStrings_QtQml[4797]
#define sipNameNr_isObject 4806
#define sipName_isObject &sipStrings_QtQml[4806]
#define sipNameNr_isRegExp 4815
#define sipName_isRegExp &sipStrings_QtQml[4815]
#define sipNameNr_isString 4824
#define sipName_isString &sipStrings_QtQml[4824]
#define sipNameNr_isSymbol 4833
#define sipName_isSymbol &sipStrings_QtQml[4833]
#define sipNameNr_loadData 4842
#define sipName_loadData &sipStrings_QtQml[4842]
#define sipNameNr_metaType 4851
#define sipName_metaType &sipStrings_QtQml[4851]
#define sipNameNr_newArray 4860
#define sipName_newArray &sipStrings_QtQml[4860]
#define sipNameNr_progress 4869
#define sipName_progress &sipStrings_QtQml[4869]
#define sipNameNr_property 4878
#define sipName_property &sipStrings_QtQml[4878]
#define sipNameNr_selector 4887
#define sipName_selector &sipStrings_QtQml[4887]
#define sipNameNr_toDouble 4896
#define sipName_toDouble &sipStrings_QtQml[4896]
#define sipNameNr_toNumber 4905
#define sipName_toNumber &sipStrings_QtQml[4905]
#define sipNameNr_toString 4914
#define sipName_toString &sipStrings_QtQml[4914]
#define sipNameNr_warnings 4923
#define sipName_warnings &sipStrings_QtQml[4923]
#define sipNameNr_Boolean 4528
#define sipName_Boolean &sipStrings_QtQml[4528]
#define sipNameNr_Integer 4538
#define sipName_Integer &sipStrings_QtQml[4538]
#define sipNameNr_Invalid 4932
#define sipName_Invalid &sipStrings_QtQml[4932]
#define sipNameNr_Loading 497
#define sipName_Loading &sipStrings_QtQml[497]
#define sipNameNr_QmlFile 4940
#define sipName_QmlFile &sipStrings_QtQml[4940]
#define sipNameNr_Texture 4948
#define sipName_Texture &sipStrings_QtQml[4948]
#define sipNameNr___add__ 4956
#define sipName___add__ &sipStrings_QtQml[4956]
#define sipNameNr___len__ 4964
#define sipName___len__ &sipStrings_QtQml[4964]
#define sipNameNr___mod__ 4972
#define sipName___mod__ &sipStrings_QtQml[4972]
#define sipNameNr___mul__ 4980
#define sipName___mul__ &sipStrings_QtQml[4980]
#define sipNameNr___neg__ 4988
#define sipName___neg__ &sipStrings_QtQml[4988]
#define sipNameNr___pos__ 4996
#define sipName___pos__ &sipStrings_QtQml[4996]
#define sipNameNr___sub__ 5004
#define sipName___sub__ &sipStrings_QtQml[5004]
#define sipNameNr_baseUrl 5012
#define sipName_baseUrl &sipStrings_QtQml[5012]
#define sipNameNr_context 5020
#define sipName_context &sipStrings_QtQml[5020]
#define sipNameNr_hasNext 5028
#define sipName_hasNext &sipStrings_QtQml[5028]
#define sipNameNr_isArray 5036
#define sipName_isArray &sipStrings_QtQml[5036]
#define sipNameNr_isBound 5044
#define sipName_isBound &sipStrings_QtQml[5044]
#define sipNameNr_isEmpty 5052
#define sipName_isEmpty &sipStrings_QtQml[5052]
#define sipNameNr_isError 5060
#define sipName_isError &sipStrings_QtQml[5060]
#define sipNameNr_isReady 5068
#define sipName_isReady &sipStrings_QtQml[5068]
#define sipNameNr_isValid 5076
#define sipName_isValid &sipStrings_QtQml[5076]
#define sipNameNr_loadUrl 5084
#define sipName_loadUrl &sipStrings_QtQml[5084]
#define sipNameNr_message 5092
#define sipName_message &sipStrings_QtQml[5092]
#define sipNameNr_qmlName 5100
#define sipName_qmlName &sipStrings_QtQml[5100]
#define sipNameNr_replace 5108
#define sipName_replace &sipStrings_QtQml[5108]
#define sipNameNr_setData 5116
#define sipName_setData &sipStrings_QtQml[5116]
#define sipNameNr_setLine 5124
#define sipName_setLine &sipStrings_QtQml[5124]
#define sipNameNr_Double 4898
#define sipName_Double &sipStrings_QtQml[4898]
#define sipNameNr_Normal 5132
#define sipName_Normal &sipStrings_QtQml[5132]
#define sipNameNr_Number 3720
#define sipName_Number &sipStrings_QtQml[3720]
#define sipNameNr_Object 310
#define sipName_Object &sipStrings_QtQml[310]
#define sipNameNr_Pixmap 5139
#define sipName_Pixmap &sipStrings_QtQml[5139]
#define sipNameNr_Status 1352
#define sipName_Status &sipStrings_QtQml[1352]
#define sipNameNr_String 2514
#define sipName_String &sipStrings_QtQml[2514]
#define sipNameNr_Symbol 4589
#define sipName_Symbol &sipStrings_QtQml[4589]
#define sipNameNr___eq__ 5146
#define sipName___eq__ &sipStrings_QtQml[5146]
#define sipNameNr___ge__ 5153
#define sipName___ge__ &sipStrings_QtQml[5153]
#define sipNameNr___gt__ 5160
#define sipName___gt__ &sipStrings_QtQml[5160]
#define sipNameNr___le__ 5167
#define sipName___le__ &sipStrings_QtQml[5167]
#define sipNameNr___lt__ 5174
#define sipName___lt__ &sipStrings_QtQml[5174]
#define sipNameNr___ne__ 5181
#define sipName___ne__ &sipStrings_QtQml[5181]
#define sipNameNr_append 5188
#define sipName_append &sipStrings_QtQml[5188]
#define sipNameNr_column 5195
#define sipName_column &sipStrings_QtQml[5195]
#define sipNameNr_create 5202
#define sipName_create &sipStrings_QtQml[5202]
#define sipNameNr_engine 5209
#define sipName_engine &sipStrings_QtQml[5209]
#define sipNameNr_equals 5216
#define sipName_equals &sipStrings_QtQml[5216]
#define sipNameNr_errors 5223
#define sipName_errors &sipStrings_QtQml[5223]
#define sipNameNr_freeze 5230
#define sipName_freeze &sipStrings_QtQml[5230]
#define sipNameNr_insert 5237
#define sipName_insert &sipStrings_QtQml[5237]
#define sipNameNr_isBool 5244
#define sipName_isBool &sipStrings_QtQml[5244]
#define sipNameNr_isDate 5251
#define sipName_isDate &sipStrings_QtQml[5251]
#define sipNameNr_isNull 5258
#define sipName_isNull &sipStrings_QtQml[5258]
#define sipNameNr_length 5265
#define sipName_length &sipStrings_QtQml[5265]
#define sipNameNr_method 5272
#define sipName_method &sipStrings_QtQml[5272]
#define sipNameNr_object 5279
#define sipName_object &sipStrings_QtQml[5279]
#define sipNameNr_parent 5286
#define sipName_parent &sipStrings_QtQml[5286]
#define sipNameNr_setUrl 5293
#define sipName_setUrl &sipStrings_QtQml[5293]
#define sipNameNr_status 5300
#define sipName_status &sipStrings_QtQml[5300]
#define sipNameNr_toBool 5307
#define sipName_toBool &sipStrings_QtQml[5307]
#define sipNameNr_toUInt 5314
#define sipName_toUInt &sipStrings_QtQml[5314]
#define sipNameNr_Error 344
#define sipName_Error &sipStrings_QtQml[344]
#define sipNameNr_Image 5321
#define sipName_Image &sipStrings_QtQml[5321]
#define sipNameNr_Ready 5070
#define sipName_Ready &sipStrings_QtQml[5070]
#define sipNameNr_canAt 5327
#define sipName_canAt &sipStrings_QtQml[5327]
#define sipNameNr_clear 5333
#define sipName_clear &sipStrings_QtQml[5333]
#define sipNameNr_count 5339
#define sipName_count &sipStrings_QtQml[5339]
#define sipNameNr_error 5345
#define sipName_error &sipStrings_QtQml[5345]
#define sipNameNr_event 5351
#define sipName_event &sipStrings_QtQml[5351]
#define sipNameNr_flags 5357
#define sipName_flags &sipStrings_QtQml[5357]
#define sipNameNr_index 5363
#define sipName_index &sipStrings_QtQml[5363]
#define sipNameNr_isUrl 5369
#define sipName_isUrl &sipStrings_QtQml[5369]
#define sipNameNr_reset 5375
#define sipName_reset &sipStrings_QtQml[5375]
#define sipNameNr_scope 5381
#define sipName_scope &sipStrings_QtQml[5381]
#define sipNameNr_toInt 5387
#define sipName_toInt &sipStrings_QtQml[5387]
#define sipNameNr_toUrl 5393
#define sipName_toUrl &sipStrings_QtQml[5393]
#define sipNameNr_value 5399
#define sipName_value &sipStrings_QtQml[5399]
#define sipNameNr_write 5405
#define sipName_write &sipStrings_QtQml[5405]
#define sipNameNr_Flag 675
#define sipName_Flag &sipStrings_QtQml[675]
#define sipNameNr_List 2308
#define sipName_List &sipStrings_QtQml[2308]
#define sipNameNr_Null 2431
#define sipName_Null &sipStrings_QtQml[2431]
#define sipNameNr_Type 72
#define sipName_Type &sipStrings_QtQml[72]
#define sipNameNr_args 5411
#define sipName_args &sipStrings_QtQml[5411]
#define sipNameNr_call 5416
#define sipName_call &sipStrings_QtQml[5416]
#define sipNameNr_data 5421
#define sipName_data &sipStrings_QtQml[5421]
#define sipNameNr_exit 5426
#define sipName_exit &sipStrings_QtQml[5426]
#define sipNameNr_keys 5431
#define sipName_keys &sipStrings_QtQml[5431]
#define sipNameNr_line 5436
#define sipName_line &sipStrings_QtQml[5436]
#define sipNameNr_load 5441
#define sipName_load &sipStrings_QtQml[5441]
#define sipNameNr_mode 5446
#define sipName_mode &sipStrings_QtQml[5446]
#define sipNameNr_name 5451
#define sipName_name &sipStrings_QtQml[5451]
#define sipNameNr_next 5456
#define sipName_next &sipStrings_QtQml[5456]
#define sipNameNr_quit 5461
#define sipName_quit &sipStrings_QtQml[5461]
#define sipNameNr_read 5466
#define sipName_read &sipStrings_QtQml[5466]
#define sipNameNr_size 5471
#define sipName_size &sipStrings_QtQml[5471]
#define sipNameNr_swap 5476
#define sipName_swap &sipStrings_QtQml[5476]
#define sipNameNr_type 3826
#define sipName_type &sipStrings_QtQml[3826]
#define sipNameNr_url 5481
#define sipName_url &sipStrings_QtQml[5481]
#define sipNameNr_at 5485
#define sipName_at &sipStrings_QtQml[5485]

#define sipMalloc                   sipAPI_QtQml->api_malloc
#define sipFree                     sipAPI_QtQml->api_free
#define sipBuildResult              sipAPI_QtQml->api_build_result
#define sipCallMethod               sipAPI_QtQml->api_call_method
#define sipCallProcedureMethod      sipAPI_QtQml->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtQml->api_call_error_handler
#define sipParseResultEx            sipAPI_QtQml->api_parse_result_ex
#define sipParseResult              sipAPI_QtQml->api_parse_result
#define sipParseArgs                sipAPI_QtQml->api_parse_args
#define sipParseKwdArgs             sipAPI_QtQml->api_parse_kwd_args
#define sipParsePair                sipAPI_QtQml->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtQml->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtQml->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtQml->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtQml->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtQml->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtQml->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtQml->api_add_exception
#define sipNoFunction               sipAPI_QtQml->api_no_function
#define sipNoMethod                 sipAPI_QtQml->api_no_method
#define sipAbstractMethod           sipAPI_QtQml->api_abstract_method
#define sipBadClass                 sipAPI_QtQml->api_bad_class
#define sipBadCatcherResult         sipAPI_QtQml->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtQml->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtQml->api_bad_operator_arg
#define sipTrace                    sipAPI_QtQml->api_trace
#define sipTransferBack             sipAPI_QtQml->api_transfer_back
#define sipTransferTo               sipAPI_QtQml->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtQml->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtQml->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtQml->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtQml->api_voidptr_type
#define sipGetPyObject              sipAPI_QtQml->api_get_pyobject
#define sipGetAddress               sipAPI_QtQml->api_get_address
#define sipGetMixinAddress          sipAPI_QtQml->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtQml->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtQml->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtQml->api_call_hook
#define sipEndThread                sipAPI_QtQml->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtQml->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtQml->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtQml->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtQml->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtQml->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtQml->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtQml->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtQml->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtQml->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtQml->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtQml->api_convert_to_bool
#define sipReleaseType              sipAPI_QtQml->api_release_type
#define sipConvertFromType          sipAPI_QtQml->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtQml->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtQml->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtQml->api_convert_from_enum
#define sipGetState                 sipAPI_QtQml->api_get_state
#define sipExportSymbol             sipAPI_QtQml->api_export_symbol
#define sipImportSymbol             sipAPI_QtQml->api_import_symbol
#define sipFindType                 sipAPI_QtQml->api_find_type
#define sipBytes_AsChar             sipAPI_QtQml->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtQml->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtQml->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtQml->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtQml->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtQml->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtQml->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtQml->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtQml->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtQml->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtQml->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtQml->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtQml->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtQml->api_get_reference
#define sipKeepReference            sipAPI_QtQml->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtQml->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtQml->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtQml->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtQml->api_type_scope
#define sipResolveTypedef           sipAPI_QtQml->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtQml->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtQml->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtQml->api_init_mixin
#define sipExportModule             sipAPI_QtQml->api_export_module
#define sipInitModule               sipAPI_QtQml->api_init_module
#define sipGetInterpreter           sipAPI_QtQml->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtQml->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtQml->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtQml->api_py_type_dict
#define sipPyTypeName               sipAPI_QtQml->api_py_type_name
#define sipGetCFunction             sipAPI_QtQml->api_get_c_function
#define sipGetMethod                sipAPI_QtQml->api_get_method
#define sipFromMethod               sipAPI_QtQml->api_from_method
#define sipGetDate                  sipAPI_QtQml->api_get_date
#define sipFromDate                 sipAPI_QtQml->api_from_date
#define sipGetDateTime              sipAPI_QtQml->api_get_datetime
#define sipFromDateTime             sipAPI_QtQml->api_from_datetime
#define sipGetTime                  sipAPI_QtQml->api_get_time
#define sipFromTime                 sipAPI_QtQml->api_from_time
#define sipIsUserType               sipAPI_QtQml->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtQml->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtQml->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtQml->api_unicode_write
#define sipUnicodeData              sipAPI_QtQml->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtQml->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtQml->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtQml->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtQml->api_is_derived_class
#define sipGetUserObject            sipAPI_QtQml->api_get_user_object
#define sipSetUserObject            sipAPI_QtQml->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtQml->api_register_event_handler
#define sipConvertToArray           sipAPI_QtQml->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtQml->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtQml->api_enable_gc
#define sipPrintObject              sipAPI_QtQml->api_print_object
#define sipLong_AsChar              sipAPI_QtQml->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtQml->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtQml->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtQml->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtQml->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtQml->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtQml->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtQml->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtQml->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtQml->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtQml->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtQml->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtQml->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtQml->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtQml->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtQml->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtQml->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtQml->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtQml->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtQml->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtQml->api_release_type_us
#define sipIsPyMethod               sipAPI_QtQml->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtQml[];

#define sipType_QJSEngine sipExportedTypes_QtQml[2]

#define sipType_QJSEngine_ObjectOwnership sipExportedTypes_QtQml[4]

#define sipType_QJSEngine_Extension sipExportedTypes_QtQml[3]

extern sipClassTypeDef sipTypeDef_QtQml_QJSEngine;

#define sipType_QJSManagedValue sipExportedTypes_QtQml[5]

#define sipType_QJSManagedValue_Type sipExportedTypes_QtQml[6]

extern sipClassTypeDef sipTypeDef_QtQml_QJSManagedValue;

#define sipType_QJSPrimitiveUndefined sipExportedTypes_QtQml[8]

extern sipClassTypeDef sipTypeDef_QtQml_QJSPrimitiveUndefined;

#define sipType_QJSPrimitiveNull sipExportedTypes_QtQml[7]

extern sipClassTypeDef sipTypeDef_QtQml_QJSPrimitiveNull;

#define sipType_QJSPrimitiveValue sipExportedTypes_QtQml[9]

#define sipType_QJSPrimitiveValue_Type sipExportedTypes_QtQml[10]

extern sipClassTypeDef sipTypeDef_QtQml_QJSPrimitiveValue;

#define sipType_QJSValue sipExportedTypes_QtQml[11]

#define sipType_QJSValue_ErrorType sipExportedTypes_QtQml[12]

#define sipType_QJSValue_ObjectConversionBehavior sipExportedTypes_QtQml[13]

#define sipType_QJSValue_SpecialValue sipExportedTypes_QtQml[14]

extern sipClassTypeDef sipTypeDef_QtQml_QJSValue;

#define sipType_QJSValueIterator sipExportedTypes_QtQml[15]

extern sipClassTypeDef sipTypeDef_QtQml_QJSValueIterator;

#define sipType_QQmlAbstractUrlInterceptor sipExportedTypes_QtQml[22]

#define sipType_QQmlAbstractUrlInterceptor_DataType sipExportedTypes_QtQml[23]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlAbstractUrlInterceptor;

#define sipType_QQmlEngine sipExportedTypes_QtQml[30]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlEngine;

#define sipType_QQmlApplicationEngine sipExportedTypes_QtQml[24]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlApplicationEngine;

#define sipType_QQmlComponent sipExportedTypes_QtQml[25]

#define sipType_QQmlComponent_Status sipExportedTypes_QtQml[27]

#define sipType_QQmlComponent_CompilationMode sipExportedTypes_QtQml[26]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlComponent;

#define sipType_QQmlContext sipExportedTypes_QtQml[28]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlContext;

#define sipType_QQmlContext_PropertyPair sipExportedTypes_QtQml[29]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlContext_PropertyPair;

#define sipType_QQmlImageProviderBase sipExportedTypes_QtQml[36]

#define sipType_QQmlImageProviderBase_Flag sipExportedTypes_QtQml[37]

#define sipType_QQmlImageProviderBase_ImageType sipExportedTypes_QtQml[38]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlImageProviderBase;

#define sipType_QQmlError sipExportedTypes_QtQml[32]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlError;

#define sipType_QQmlExpression sipExportedTypes_QtQml[33]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlExpression;

#define sipType_QQmlExtensionPlugin sipExportedTypes_QtQml[34]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlExtensionPlugin;

#define sipType_QQmlEngineExtensionPlugin sipExportedTypes_QtQml[31]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlEngineExtensionPlugin;

#define sipType_QQmlFileSelector sipExportedTypes_QtQml[35]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlFileSelector;

#define sipType_QQmlIncubator sipExportedTypes_QtQml[40]

#define sipType_QQmlIncubator_Status sipExportedTypes_QtQml[42]

#define sipType_QQmlIncubator_IncubationMode sipExportedTypes_QtQml[41]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlIncubator;

#define sipType_QQmlIncubationController sipExportedTypes_QtQml[39]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlIncubationController;

#define sipType_QQmlListReference sipExportedTypes_QtQml[44]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlListReference;

#define sipType_QQmlNetworkAccessManagerFactory sipExportedTypes_QtQml[45]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlNetworkAccessManagerFactory;

#define sipType_QQmlParserStatus sipExportedTypes_QtQml[46]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlParserStatus;

#define sipType_QQmlProperty sipExportedTypes_QtQml[47]

#define sipType_QQmlProperty_Type sipExportedTypes_QtQml[49]

#define sipType_QQmlProperty_PropertyTypeCategory sipExportedTypes_QtQml[48]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlProperty;

#define sipType_QQmlPropertyMap sipExportedTypes_QtQml[50]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlPropertyMap;

#define sipType_QQmlPropertyValueSource sipExportedTypes_QtQml[51]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlPropertyValueSource;

#define sipType_QQmlScriptString sipExportedTypes_QtQml[52]

extern sipClassTypeDef sipTypeDef_QtQml_QQmlScriptString;

#define sipType_QList_0101QQmlContext sipExportedTypes_QtQml[18]

extern sipMappedTypeDef sipTypeDef_QtQml_QList_0101QQmlContext;

#define sipType_QList_0100QQmlContext_PropertyPair sipExportedTypes_QtQml[19]

extern sipMappedTypeDef sipTypeDef_QtQml_QList_0100QQmlContext_PropertyPair;

#define sipType_QList_0101QQmlAbstractUrlInterceptor sipExportedTypes_QtQml[17]

extern sipMappedTypeDef sipTypeDef_QtQml_QList_0101QQmlAbstractUrlInterceptor;

#define sipType_QList_0100QQmlError sipExportedTypes_QtQml[20]

extern sipMappedTypeDef sipTypeDef_QtQml_QList_0100QQmlError;

#define sipType_QList_0100QQmlProperty sipExportedTypes_QtQml[21]

extern sipMappedTypeDef sipTypeDef_QtQml_QList_0100QQmlProperty;

#define sipType_QFlags_0100QQmlImageProviderBase_Flag sipExportedTypes_QtQml[1]

extern sipMappedTypeDef sipTypeDef_QtQml_QFlags_0100QQmlImageProviderBase_Flag;

#define sipType_QList_0100QJSValue sipExportedTypes_QtQml[16]

extern sipMappedTypeDef sipTypeDef_QtQml_QList_0100QJSValue;

#define sipType_QFlags_0100QJSEngine_Extension sipExportedTypes_QtQml[0]

extern sipMappedTypeDef sipTypeDef_QtQml_QFlags_0100QJSEngine_Extension;

#define sipType_QQmlListProperty_0100QObject sipExportedTypes_QtQml[43]

extern sipMappedTypeDef sipTypeDef_QtQml_QQmlListProperty_0100QObject;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtQml;
extern sipExportedModuleDef sipModuleAPI_QtQml;
extern sipTypeDef *sipExportedTypes_QtQml[];

#define sipType_QObject sipImportedTypes_QtQml_QtCore[14].it_td

#define sipType_QByteArray sipImportedTypes_QtQml_QtCore[1].it_td

#define sipType_QEvent sipImportedTypes_QtQml_QtCore[5].it_td

#define sipType_QTimerEvent sipImportedTypes_QtQml_QtCore[18].it_td

#define sipType_QChildEvent sipImportedTypes_QtQml_QtCore[2].it_td

#define sipType_QDataStream sipImportedTypes_QtQml_QtCore[3].it_td

#define sipType_QDateTime sipImportedTypes_QtQml_QtCore[4].it_td

#define sipType_QFileSelector sipImportedTypes_QtQml_QtCore[6].it_td

#define sipType_QMetaMethod sipImportedTypes_QtQml_QtCore[10].it_td

#define sipType_QMetaProperty sipImportedTypes_QtQml_QtCore[12].it_td

#define sipType_QMetaType sipImportedTypes_QtQml_QtCore[13].it_td

#define sipType_QMetaObject sipImportedTypes_QtQml_QtCore[11].it_td

#define sipType_QRegularExpression sipImportedTypes_QtQml_QtCore[15].it_td

#define sipType_QUrl sipImportedTypes_QtQml_QtCore[19].it_td

#define sipType_QVariant sipImportedTypes_QtQml_QtCore[20].it_td

#define sipType_QMap_0100QString_0100QVariant sipImportedTypes_QtQml_QtCore[9].it_td

#define sipType_QHash_0100QString_0100QVariant sipImportedTypes_QtQml_QtCore[7].it_td

#define sipType_QList_0101QObject sipImportedTypes_QtQml_QtCore[8].it_td

#define sipType_QStringList sipImportedTypes_QtQml_QtCore[17].it_td

#define sipType_QString sipImportedTypes_QtQml_QtCore[16].it_td

#define sipType_QAnyStringView sipImportedTypes_QtQml_QtCore[0].it_td

#define sipType_QtMsgType sipImportedTypes_QtQml_QtCore[21].it_td
extern sipImportedTypeDef sipImportedTypes_QtQml_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtQml_QtCore[];

#define sipType_QNetworkAccessManager sipImportedTypes_QtQml_QtNetwork[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtQml_QtNetwork[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtQml_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtQml_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtQml_qt_metacast;
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsengine.sip"
#include "qpyqml_api.h"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlproperty.sip"
// Imports from QtCore.
typedef sipErrorState (*pyqt6_qtqml_get_connection_parts_t)(PyObject *, QObject *, const char *, bool, QObject **, QByteArray &);
extern pyqt6_qtqml_get_connection_parts_t pyqt6_qtqml_get_connection_parts;
#line 22 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qmlattachedpropertiesobject.sip"
#include <qqml.h>
#line 23 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qmlregistertype.sip"
#include <qpyqml_api.h>
#line 1294 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipAPIQtQml.h"

#endif
