/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 163 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsSceneHoverEvent.cpp"

#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsSceneHoverEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsSceneHoverEvent.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsSceneHoverEvent.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsSceneHoverEvent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsSceneHoverEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsSceneHoverEvent.cpp"


PyDoc_STRVAR(doc_QGraphicsSceneHoverEvent_pos, "pos(self) -> QPointF");

extern "C" {static PyObject *meth_QGraphicsSceneHoverEvent_pos(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSceneHoverEvent_pos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsSceneHoverEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSceneHoverEvent, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->pos());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSceneHoverEvent, sipName_pos, doc_QGraphicsSceneHoverEvent_pos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSceneHoverEvent_scenePos, "scenePos(self) -> QPointF");

extern "C" {static PyObject *meth_QGraphicsSceneHoverEvent_scenePos(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSceneHoverEvent_scenePos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsSceneHoverEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSceneHoverEvent, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->scenePos());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSceneHoverEvent, sipName_scenePos, doc_QGraphicsSceneHoverEvent_scenePos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSceneHoverEvent_screenPos, "screenPos(self) -> QPoint");

extern "C" {static PyObject *meth_QGraphicsSceneHoverEvent_screenPos(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSceneHoverEvent_screenPos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsSceneHoverEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSceneHoverEvent, &sipCpp))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(sipCpp->screenPos());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSceneHoverEvent, sipName_screenPos, doc_QGraphicsSceneHoverEvent_screenPos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSceneHoverEvent_lastPos, "lastPos(self) -> QPointF");

extern "C" {static PyObject *meth_QGraphicsSceneHoverEvent_lastPos(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSceneHoverEvent_lastPos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsSceneHoverEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSceneHoverEvent, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->lastPos());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSceneHoverEvent, sipName_lastPos, doc_QGraphicsSceneHoverEvent_lastPos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSceneHoverEvent_lastScenePos, "lastScenePos(self) -> QPointF");

extern "C" {static PyObject *meth_QGraphicsSceneHoverEvent_lastScenePos(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSceneHoverEvent_lastScenePos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsSceneHoverEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSceneHoverEvent, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->lastScenePos());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSceneHoverEvent, sipName_lastScenePos, doc_QGraphicsSceneHoverEvent_lastScenePos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSceneHoverEvent_lastScreenPos, "lastScreenPos(self) -> QPoint");

extern "C" {static PyObject *meth_QGraphicsSceneHoverEvent_lastScreenPos(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSceneHoverEvent_lastScreenPos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsSceneHoverEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSceneHoverEvent, &sipCpp))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(sipCpp->lastScreenPos());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSceneHoverEvent, sipName_lastScreenPos, doc_QGraphicsSceneHoverEvent_lastScreenPos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsSceneHoverEvent_modifiers, "modifiers(self) -> Qt.KeyboardModifier");

extern "C" {static PyObject *meth_QGraphicsSceneHoverEvent_modifiers(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsSceneHoverEvent_modifiers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsSceneHoverEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsSceneHoverEvent, &sipCpp))
        {
            ::Qt::KeyboardModifiers*sipRes;

            sipRes = new ::Qt::KeyboardModifiers(sipCpp->modifiers());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_KeyboardModifier, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsSceneHoverEvent, sipName_modifiers, doc_QGraphicsSceneHoverEvent_modifiers);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGraphicsSceneHoverEvent(void *, const sipTypeDef *);}
static void *cast_QGraphicsSceneHoverEvent(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGraphicsSceneHoverEvent *sipCpp = reinterpret_cast< ::QGraphicsSceneHoverEvent *>(sipCppV);

    if (targetType == sipType_QGraphicsSceneHoverEvent)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGraphicsSceneEvent)->ctd_cast(static_cast< ::QGraphicsSceneEvent *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGraphicsSceneHoverEvent(void *, int);}
static void release_QGraphicsSceneHoverEvent(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGraphicsSceneHoverEvent *>(sipCppV);
}


extern "C" {static void dealloc_QGraphicsSceneHoverEvent(sipSimpleWrapper *);}
static void dealloc_QGraphicsSceneHoverEvent(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGraphicsSceneHoverEvent(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGraphicsSceneHoverEvent[] = {{161, 255, 1}};


static PyMethodDef methods_QGraphicsSceneHoverEvent[] = {
    {sipName_lastPos, meth_QGraphicsSceneHoverEvent_lastPos, METH_VARARGS, doc_QGraphicsSceneHoverEvent_lastPos},
    {sipName_lastScenePos, meth_QGraphicsSceneHoverEvent_lastScenePos, METH_VARARGS, doc_QGraphicsSceneHoverEvent_lastScenePos},
    {sipName_lastScreenPos, meth_QGraphicsSceneHoverEvent_lastScreenPos, METH_VARARGS, doc_QGraphicsSceneHoverEvent_lastScreenPos},
    {sipName_modifiers, meth_QGraphicsSceneHoverEvent_modifiers, METH_VARARGS, doc_QGraphicsSceneHoverEvent_modifiers},
    {sipName_pos, meth_QGraphicsSceneHoverEvent_pos, METH_VARARGS, doc_QGraphicsSceneHoverEvent_pos},
    {sipName_scenePos, meth_QGraphicsSceneHoverEvent_scenePos, METH_VARARGS, doc_QGraphicsSceneHoverEvent_scenePos},
    {sipName_screenPos, meth_QGraphicsSceneHoverEvent_screenPos, METH_VARARGS, doc_QGraphicsSceneHoverEvent_screenPos}
};


sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneHoverEvent = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGraphicsSceneHoverEvent,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QGraphicsSceneHoverEvent,
        {0, 0, 1},
        7, methods_QGraphicsSceneHoverEvent,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QGraphicsSceneHoverEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGraphicsSceneHoverEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QGraphicsSceneHoverEvent,
    cast_QGraphicsSceneHoverEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
