/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtQuick3DAPI_H
#define _QtQuick3DAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QQuick3DGeometry__Attribute__ComponentType 0
#define sipName_QQuick3DGeometry__Attribute__ComponentType &sipStrings_QtQuick3D[0]
#define sipNameNr_QQuick3DGeometry__Attribute__Semantic 43
#define sipName_QQuick3DGeometry__Attribute__Semantic &sipStrings_QtQuick3D[43]
#define sipNameNr_QQuick3DGeometry__TargetAttribute 81
#define sipName_QQuick3DGeometry__TargetAttribute &sipStrings_QtQuick3D[81]
#define sipNameNr_QQuick3DGeometry__PrimitiveType 115
#define sipName_QQuick3DGeometry__PrimitiveType &sipStrings_QtQuick3D[115]
#define sipNameNr_QQuick3DGeometry__Attribute 147
#define sipName_QQuick3DGeometry__Attribute &sipStrings_QtQuick3D[147]
#define sipNameNr_QQuick3DTextureData__Format 175
#define sipName_QQuick3DTextureData__Format &sipStrings_QtQuick3D[175]
#define sipNameNr_PyQt6_sip_simplewrapper 203
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtQuick3D[203]
#define sipNameNr_TargetBinormalSemantic 227
#define sipName_TargetBinormalSemantic &sipStrings_QtQuick3D[227]
#define sipNameNr_TargetPositionSemantic 250
#define sipName_TargetPositionSemantic &sipStrings_QtQuick3D[250]
#define sipNameNr_TargetTangentSemantic 273
#define sipName_TargetTangentSemantic &sipStrings_QtQuick3D[273]
#define sipNameNr_TargetNormalSemantic 295
#define sipName_TargetNormalSemantic &sipStrings_QtQuick3D[295]
#define sipNameNr_targetAttributeCount 316
#define sipName_targetAttributeCount &sipStrings_QtQuick3D[316]
#define sipNameNr_QQuick3DTextureData 337
#define sipName_QQuick3DTextureData &sipStrings_QtQuick3D[337]
#define sipNameNr_addTargetAttribute 357
#define sipName_addTargetAttribute &sipStrings_QtQuick3D[357]
#define sipNameNr_idealSurfaceFormat 376
#define sipName_idealSurfaceFormat &sipStrings_QtQuick3D[376]
#define sipNameNr_setHasTransparency 395
#define sipName_setHasTransparency &sipStrings_QtQuick3D[395]
#define sipNameNr_TexCoord0Semantic 414
#define sipName_TexCoord0Semantic &sipStrings_QtQuick3D[414]
#define sipNameNr_TexCoord1Semantic 432
#define sipName_TexCoord1Semantic &sipStrings_QtQuick3D[432]
#define sipNameNr_componentComplete 450
#define sipName_componentComplete &sipStrings_QtQuick3D[450]
#define sipNameNr_BinormalSemantic 233
#define sipName_BinormalSemantic &sipStrings_QtQuick3D[233]
#define sipNameNr_PositionSemantic 256
#define sipName_PositionSemantic &sipStrings_QtQuick3D[256]
#define sipNameNr_QQuick3DGeometry 468
#define sipName_QQuick3DGeometry &sipStrings_QtQuick3D[468]
#define sipNameNr_TexCoordSemantic 485
#define sipName_TexCoordSemantic &sipStrings_QtQuick3D[485]
#define sipNameNr_disconnectNotify 502
#define sipName_disconnectNotify &sipStrings_QtQuick3D[502]
#define sipNameNr_setPrimitiveType 519
#define sipName_setPrimitiveType &sipStrings_QtQuick3D[519]
#define sipNameNr_PyQt6_QtQuick3D 536
#define sipName_PyQt6_QtQuick3D &sipStrings_QtQuick3D[536]
#define sipNameNr_TangentSemantic 279
#define sipName_TangentSemantic &sipStrings_QtQuick3D[279]
#define sipNameNr_TargetAttribute 99
#define sipName_TargetAttribute &sipStrings_QtQuick3D[99]
#define sipNameNr_hasTransparency 552
#define sipName_hasTransparency &sipStrings_QtQuick3D[552]
#define sipNameNr_subsetBoundsMax 568
#define sipName_subsetBoundsMax &sipStrings_QtQuick3D[568]
#define sipNameNr_subsetBoundsMin 584
#define sipName_subsetBoundsMin &sipStrings_QtQuick3D[584]
#define sipNameNr_targetAttribute 600
#define sipName_targetAttribute &sipStrings_QtQuick3D[600]
#define sipNameNr_NormalSemantic 301
#define sipName_NormalSemantic &sipStrings_QtQuick3D[301]
#define sipNameNr_QQuick3DObject 616
#define sipName_QQuick3DObject &sipStrings_QtQuick3D[616]
#define sipNameNr_WeightSemantic 631
#define sipName_WeightSemantic &sipStrings_QtQuick3D[631]
#define sipNameNr_attributeCount 646
#define sipName_attributeCount &sipStrings_QtQuick3D[646]
#define sipNameNr_setTextureData 661
#define sipName_setTextureData &sipStrings_QtQuick3D[661]
#define sipNameNr_ColorSemantic 676
#define sipName_ColorSemantic &sipStrings_QtQuick3D[676]
#define sipNameNr_ComponentType 29
#define sipName_ComponentType &sipStrings_QtQuick3D[29]
#define sipNameNr_IndexSemantic 690
#define sipName_IndexSemantic &sipStrings_QtQuick3D[690]
#define sipNameNr_JointSemantic 704
#define sipName_JointSemantic &sipStrings_QtQuick3D[704]
#define sipNameNr_PrimitiveType 133
#define sipName_PrimitiveType &sipStrings_QtQuick3D[133]
#define sipNameNr_TriangleStrip 718
#define sipName_TriangleStrip &sipStrings_QtQuick3D[718]
#define sipNameNr_componentType 732
#define sipName_componentType &sipStrings_QtQuick3D[732]
#define sipNameNr_connectNotify 505
#define sipName_connectNotify &sipStrings_QtQuick3D[505]
#define sipNameNr_primitiveType 746
#define sipName_primitiveType &sipStrings_QtQuick3D[746]
#define sipNameNr_setParentItem 760
#define sipName_setParentItem &sipStrings_QtQuick3D[760]
#define sipNameNr_setTargetData 774
#define sipName_setTargetData &sipStrings_QtQuick3D[774]
#define sipNameNr_setVertexData 788
#define sipName_setVertexData &sipStrings_QtQuick3D[788]
#define sipNameNr_addAttribute 802
#define sipName_addAttribute &sipStrings_QtQuick3D[802]
#define sipNameNr_setIndexData 815
#define sipName_setIndexData &sipStrings_QtQuick3D[815]
#define sipNameNr_stateChanged 828
#define sipName_stateChanged &sipStrings_QtQuick3D[828]
#define sipNameNr_subsetOffset 841
#define sipName_subsetOffset &sipStrings_QtQuick3D[841]
#define sipNameNr_ETC2_RGB8A1 854
#define sipName_ETC2_RGB8A1 &sipStrings_QtQuick3D[854]
#define sipNameNr_TriangleFan 866
#define sipName_TriangleFan &sipStrings_QtQuick3D[866]
#define sipNameNr_customEvent 878
#define sipName_customEvent &sipStrings_QtQuick3D[878]
#define sipNameNr_eventFilter 890
#define sipName_eventFilter &sipStrings_QtQuick3D[890]
#define sipNameNr_subsetCount 902
#define sipName_subsetCount &sipStrings_QtQuick3D[902]
#define sipNameNr_textureData 914
#define sipName_textureData &sipStrings_QtQuick3D[914]
#define sipNameNr_ASTC_10x10 926
#define sipName_ASTC_10x10 &sipStrings_QtQuick3D[926]
#define sipNameNr_ASTC_12x10 937
#define sipName_ASTC_12x10 &sipStrings_QtQuick3D[937]
#define sipNameNr_ASTC_12x12 948
#define sipName_ASTC_12x12 &sipStrings_QtQuick3D[948]
#define sipNameNr_ETC2_RGBA8 959
#define sipName_ETC2_RGBA8 &sipStrings_QtQuick3D[959]
#define sipNameNr_childEvent 970
#define sipName_childEvent &sipStrings_QtQuick3D[970]
#define sipNameNr_classBegin 981
#define sipName_classBegin &sipStrings_QtQuick3D[981]
#define sipNameNr_parentItem 992
#define sipName_parentItem &sipStrings_QtQuick3D[992]
#define sipNameNr_subsetName 1003
#define sipName_subsetName &sipStrings_QtQuick3D[1003]
#define sipNameNr_targetData 1014
#define sipName_targetData &sipStrings_QtQuick3D[1014]
#define sipNameNr_timerEvent 1025
#define sipName_timerEvent &sipStrings_QtQuick3D[1025]
#define sipNameNr_vertexData 1036
#define sipName_vertexData &sipStrings_QtQuick3D[1036]
#define sipNameNr_ASTC_10x5 1047
#define sipName_ASTC_10x5 &sipStrings_QtQuick3D[1047]
#define sipNameNr_ASTC_10x6 1057
#define sipName_ASTC_10x6 &sipStrings_QtQuick3D[1057]
#define sipNameNr_ASTC_10x8 1067
#define sipName_ASTC_10x8 &sipStrings_QtQuick3D[1067]
#define sipNameNr_Attribute 105
#define sipName_Attribute &sipStrings_QtQuick3D[105]
#define sipNameNr_DXT1_RGBA 1077
#define sipName_DXT1_RGBA &sipStrings_QtQuick3D[1077]
#define sipNameNr_DXT3_RGBA 1087
#define sipName_DXT3_RGBA &sipStrings_QtQuick3D[1087]
#define sipNameNr_DXT5_RGBA 1097
#define sipName_DXT5_RGBA &sipStrings_QtQuick3D[1097]
#define sipNameNr_ETC2_RGB8 1107
#define sipName_ETC2_RGB8 &sipStrings_QtQuick3D[1107]
#define sipNameNr_LineStrip 1117
#define sipName_LineStrip &sipStrings_QtQuick3D[1117]
#define sipNameNr_Triangles 1127
#define sipName_Triangles &sipStrings_QtQuick3D[1127]
#define sipNameNr_addSubset 1137
#define sipName_addSubset &sipStrings_QtQuick3D[1137]
#define sipNameNr_attribute 1147
#define sipName_attribute &sipStrings_QtQuick3D[1147]
#define sipNameNr_boundsMax 1157
#define sipName_boundsMax &sipStrings_QtQuick3D[1157]
#define sipNameNr_boundsMin 1167
#define sipName_boundsMin &sipStrings_QtQuick3D[1167]
#define sipNameNr_indexData 1177
#define sipName_indexData &sipStrings_QtQuick3D[1177]
#define sipNameNr_setBounds 1187
#define sipName_setBounds &sipStrings_QtQuick3D[1187]
#define sipNameNr_setFormat 1197
#define sipName_setFormat &sipStrings_QtQuick3D[1197]
#define sipNameNr_setStride 1207
#define sipName_setStride &sipStrings_QtQuick3D[1207]
#define sipNameNr_ASTC_4x4 1217
#define sipName_ASTC_4x4 &sipStrings_QtQuick3D[1217]
#define sipNameNr_ASTC_5x4 1226
#define sipName_ASTC_5x4 &sipStrings_QtQuick3D[1226]
#define sipNameNr_ASTC_5x5 1235
#define sipName_ASTC_5x5 &sipStrings_QtQuick3D[1235]
#define sipNameNr_ASTC_6x5 1244
#define sipName_ASTC_6x5 &sipStrings_QtQuick3D[1244]
#define sipNameNr_ASTC_6x6 1253
#define sipName_ASTC_6x6 &sipStrings_QtQuick3D[1253]
#define sipNameNr_ASTC_8x5 1262
#define sipName_ASTC_8x5 &sipStrings_QtQuick3D[1262]
#define sipNameNr_ASTC_8x6 1271
#define sipName_ASTC_8x6 &sipStrings_QtQuick3D[1271]
#define sipNameNr_ASTC_8x8 1280
#define sipName_ASTC_8x8 &sipStrings_QtQuick3D[1280]
#define sipNameNr_DXT1_RGB 1289
#define sipName_DXT1_RGB &sipStrings_QtQuick3D[1289]
#define sipNameNr_QQuick3D 1298
#define sipName_QQuick3D &sipStrings_QtQuick3D[1298]
#define sipNameNr_Semantic 72
#define sipName_Semantic &sipStrings_QtQuick3D[72]
#define sipNameNr_semantic 1307
#define sipName_semantic &sipStrings_QtQuick3D[1307]
#define sipNameNr_setDepth 1316
#define sipName_setDepth &sipStrings_QtQuick3D[1316]
#define sipNameNr_setState 1325
#define sipName_setState &sipStrings_QtQuick3D[1325]
#define sipNameNr_targetId 1334
#define sipName_targetId &sipStrings_QtQuick3D[1334]
#define sipNameNr_F32Type 1343
#define sipName_F32Type &sipStrings_QtQuick3D[1343]
#define sipNameNr_I32Type 1351
#define sipName_I32Type &sipStrings_QtQuick3D[1351]
#define sipNameNr_RGBA16F 1359
#define sipName_RGBA16F &sipStrings_QtQuick3D[1359]
#define sipNameNr_RGBA32F 1367
#define sipName_RGBA32F &sipStrings_QtQuick3D[1367]
#define sipNameNr_U16Type 1375
#define sipName_U16Type &sipStrings_QtQuick3D[1375]
#define sipNameNr_U32Type 1383
#define sipName_U32Type &sipStrings_QtQuick3D[1383]
#define sipNameNr_samples 1391
#define sipName_samples &sipStrings_QtQuick3D[1391]
#define sipNameNr_setSize 1399
#define sipName_setSize &sipStrings_QtQuick3D[1399]
#define sipNameNr_Format 196
#define sipName_Format &sipStrings_QtQuick3D[196]
#define sipNameNr_Points 1407
#define sipName_Points &sipStrings_QtQuick3D[1407]
#define sipNameNr_format 1414
#define sipName_format &sipStrings_QtQuick3D[1414]
#define sipNameNr_offset 1421
#define sipName_offset &sipStrings_QtQuick3D[1421]
#define sipNameNr_parent 1428
#define sipName_parent &sipStrings_QtQuick3D[1428]
#define sipNameNr_stride 1435
#define sipName_stride &sipStrings_QtQuick3D[1435]
#define sipNameNr_Lines 1442
#define sipName_Lines &sipStrings_QtQuick3D[1442]
#define sipNameNr_None_ 1448
#define sipName_None_ &sipStrings_QtQuick3D[1448]
#define sipNameNr_RGBA8 964
#define sipName_RGBA8 &sipStrings_QtQuick3D[964]
#define sipNameNr_RGBE8 1454
#define sipName_RGBE8 &sipStrings_QtQuick3D[1454]
#define sipNameNr_clear 1460
#define sipName_clear &sipStrings_QtQuick3D[1460]
#define sipNameNr_depth 1466
#define sipName_depth &sipStrings_QtQuick3D[1466]
#define sipNameNr_event 1472
#define sipName_event &sipStrings_QtQuick3D[1472]
#define sipNameNr_state 1478
#define sipName_state &sipStrings_QtQuick3D[1478]
#define sipNameNr_BC6H 1484
#define sipName_BC6H &sipStrings_QtQuick3D[1484]
#define sipNameNr_R16F 1489
#define sipName_R16F &sipStrings_QtQuick3D[1489]
#define sipNameNr_R32F 1494
#define sipName_R32F &sipStrings_QtQuick3D[1494]
#define sipNameNr_attr 1499
#define sipName_attr &sipStrings_QtQuick3D[1499]
#define sipNameNr_name 1504
#define sipName_name &sipStrings_QtQuick3D[1504]
#define sipNameNr_size 1509
#define sipName_size &sipStrings_QtQuick3D[1509]
#define sipNameNr_BC1 1514
#define sipName_BC1 &sipStrings_QtQuick3D[1514]
#define sipNameNr_BC2 1518
#define sipName_BC2 &sipStrings_QtQuick3D[1518]
#define sipNameNr_BC3 1522
#define sipName_BC3 &sipStrings_QtQuick3D[1522]
#define sipNameNr_BC4 1526
#define sipName_BC4 &sipStrings_QtQuick3D[1526]
#define sipNameNr_BC5 1530
#define sipName_BC5 &sipStrings_QtQuick3D[1530]
#define sipNameNr_BC7 1534
#define sipName_BC7 &sipStrings_QtQuick3D[1534]
#define sipNameNr_R16 1538
#define sipName_R16 &sipStrings_QtQuick3D[1538]
#define sipNameNr_R8 1542
#define sipName_R8 &sipStrings_QtQuick3D[1542]

#define sipMalloc                   sipAPI_QtQuick3D->api_malloc
#define sipFree                     sipAPI_QtQuick3D->api_free
#define sipBuildResult              sipAPI_QtQuick3D->api_build_result
#define sipCallMethod               sipAPI_QtQuick3D->api_call_method
#define sipCallProcedureMethod      sipAPI_QtQuick3D->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtQuick3D->api_call_error_handler
#define sipParseResultEx            sipAPI_QtQuick3D->api_parse_result_ex
#define sipParseResult              sipAPI_QtQuick3D->api_parse_result
#define sipParseArgs                sipAPI_QtQuick3D->api_parse_args
#define sipParseKwdArgs             sipAPI_QtQuick3D->api_parse_kwd_args
#define sipParsePair                sipAPI_QtQuick3D->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtQuick3D->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtQuick3D->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtQuick3D->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtQuick3D->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtQuick3D->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtQuick3D->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtQuick3D->api_add_exception
#define sipNoFunction               sipAPI_QtQuick3D->api_no_function
#define sipNoMethod                 sipAPI_QtQuick3D->api_no_method
#define sipAbstractMethod           sipAPI_QtQuick3D->api_abstract_method
#define sipBadClass                 sipAPI_QtQuick3D->api_bad_class
#define sipBadCatcherResult         sipAPI_QtQuick3D->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtQuick3D->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtQuick3D->api_bad_operator_arg
#define sipTrace                    sipAPI_QtQuick3D->api_trace
#define sipTransferBack             sipAPI_QtQuick3D->api_transfer_back
#define sipTransferTo               sipAPI_QtQuick3D->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtQuick3D->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtQuick3D->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtQuick3D->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtQuick3D->api_voidptr_type
#define sipGetPyObject              sipAPI_QtQuick3D->api_get_pyobject
#define sipGetAddress               sipAPI_QtQuick3D->api_get_address
#define sipGetMixinAddress          sipAPI_QtQuick3D->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtQuick3D->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtQuick3D->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtQuick3D->api_call_hook
#define sipEndThread                sipAPI_QtQuick3D->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtQuick3D->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtQuick3D->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtQuick3D->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtQuick3D->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtQuick3D->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtQuick3D->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtQuick3D->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtQuick3D->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtQuick3D->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtQuick3D->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtQuick3D->api_convert_to_bool
#define sipReleaseType              sipAPI_QtQuick3D->api_release_type
#define sipConvertFromType          sipAPI_QtQuick3D->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtQuick3D->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtQuick3D->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtQuick3D->api_convert_from_enum
#define sipGetState                 sipAPI_QtQuick3D->api_get_state
#define sipExportSymbol             sipAPI_QtQuick3D->api_export_symbol
#define sipImportSymbol             sipAPI_QtQuick3D->api_import_symbol
#define sipFindType                 sipAPI_QtQuick3D->api_find_type
#define sipBytes_AsChar             sipAPI_QtQuick3D->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtQuick3D->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtQuick3D->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtQuick3D->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtQuick3D->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtQuick3D->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtQuick3D->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtQuick3D->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtQuick3D->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtQuick3D->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtQuick3D->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtQuick3D->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtQuick3D->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtQuick3D->api_get_reference
#define sipKeepReference            sipAPI_QtQuick3D->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtQuick3D->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtQuick3D->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtQuick3D->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtQuick3D->api_type_scope
#define sipResolveTypedef           sipAPI_QtQuick3D->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtQuick3D->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtQuick3D->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtQuick3D->api_init_mixin
#define sipExportModule             sipAPI_QtQuick3D->api_export_module
#define sipInitModule               sipAPI_QtQuick3D->api_init_module
#define sipGetInterpreter           sipAPI_QtQuick3D->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtQuick3D->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtQuick3D->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtQuick3D->api_py_type_dict
#define sipPyTypeName               sipAPI_QtQuick3D->api_py_type_name
#define sipGetCFunction             sipAPI_QtQuick3D->api_get_c_function
#define sipGetMethod                sipAPI_QtQuick3D->api_get_method
#define sipFromMethod               sipAPI_QtQuick3D->api_from_method
#define sipGetDate                  sipAPI_QtQuick3D->api_get_date
#define sipFromDate                 sipAPI_QtQuick3D->api_from_date
#define sipGetDateTime              sipAPI_QtQuick3D->api_get_datetime
#define sipFromDateTime             sipAPI_QtQuick3D->api_from_datetime
#define sipGetTime                  sipAPI_QtQuick3D->api_get_time
#define sipFromTime                 sipAPI_QtQuick3D->api_from_time
#define sipIsUserType               sipAPI_QtQuick3D->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtQuick3D->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtQuick3D->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtQuick3D->api_unicode_write
#define sipUnicodeData              sipAPI_QtQuick3D->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtQuick3D->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtQuick3D->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtQuick3D->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtQuick3D->api_is_derived_class
#define sipGetUserObject            sipAPI_QtQuick3D->api_get_user_object
#define sipSetUserObject            sipAPI_QtQuick3D->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtQuick3D->api_register_event_handler
#define sipConvertToArray           sipAPI_QtQuick3D->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtQuick3D->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtQuick3D->api_enable_gc
#define sipPrintObject              sipAPI_QtQuick3D->api_print_object
#define sipLong_AsChar              sipAPI_QtQuick3D->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtQuick3D->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtQuick3D->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtQuick3D->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtQuick3D->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtQuick3D->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtQuick3D->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtQuick3D->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtQuick3D->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtQuick3D->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtQuick3D->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtQuick3D->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtQuick3D->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtQuick3D->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtQuick3D->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtQuick3D->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtQuick3D->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtQuick3D->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtQuick3D->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtQuick3D->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtQuick3D->api_release_type_us
#define sipIsPyMethod               sipAPI_QtQuick3D->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtQuick3D[];

#define sipType_QQuick3D sipExportedTypes_QtQuick3D[0]

extern sipClassTypeDef sipTypeDef_QtQuick3D_QQuick3D;

#define sipType_QQuick3DObject sipExportedTypes_QtQuick3D[7]

extern sipClassTypeDef sipTypeDef_QtQuick3D_QQuick3DObject;

#define sipType_QQuick3DGeometry sipExportedTypes_QtQuick3D[1]

#define sipType_QQuick3DGeometry_PrimitiveType sipExportedTypes_QtQuick3D[5]

extern sipClassTypeDef sipTypeDef_QtQuick3D_QQuick3DGeometry;

#define sipType_QQuick3DGeometry_Attribute sipExportedTypes_QtQuick3D[2]

#define sipType_QQuick3DGeometry_Attribute_ComponentType sipExportedTypes_QtQuick3D[3]

#define sipType_QQuick3DGeometry_Attribute_Semantic sipExportedTypes_QtQuick3D[4]

extern sipClassTypeDef sipTypeDef_QtQuick3D_QQuick3DGeometry_Attribute;

#define sipType_QQuick3DGeometry_TargetAttribute sipExportedTypes_QtQuick3D[6]

extern sipClassTypeDef sipTypeDef_QtQuick3D_QQuick3DGeometry_TargetAttribute;

#define sipType_QQuick3DTextureData sipExportedTypes_QtQuick3D[8]

#define sipType_QQuick3DTextureData_Format sipExportedTypes_QtQuick3D[9]

extern sipClassTypeDef sipTypeDef_QtQuick3D_QQuick3DTextureData;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtQuick3D;
extern sipExportedModuleDef sipModuleAPI_QtQuick3D;
extern sipTypeDef *sipExportedTypes_QtQuick3D[];

#define sipType_QObject sipImportedTypes_QtQuick3D_QtCore[4].it_td

#define sipType_QByteArray sipImportedTypes_QtQuick3D_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtQuick3D_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtQuick3D_QtCore[7].it_td

#define sipType_QChildEvent sipImportedTypes_QtQuick3D_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtQuick3D_QtCore[3].it_td

#define sipType_QSize sipImportedTypes_QtQuick3D_QtCore[5].it_td

#define sipType_QString sipImportedTypes_QtQuick3D_QtCore[6].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuick3D_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtQuick3D_QtCore[];

#define sipType_QSurfaceFormat sipImportedTypes_QtQuick3D_QtGui[0].it_td

#define sipType_QVector3D sipImportedTypes_QtQuick3D_QtGui[1].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuick3D_QtGui[];

#define sipType_QQmlParserStatus sipImportedTypes_QtQuick3D_QtQml[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuick3D_QtQml[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtQuick3D_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtQuick3D_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtQuick3D_qt_metacast;

#endif
