/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtSvgAPI_H
#define _QtSvgAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QSvgGenerator__SvgVersion 0
#define sipName_QSvgGenerator__SvgVersion &sipStrings_QtSvg[0]
#define sipNameNr_DisableSMILAnimations 26
#define sipName_DisableSMILAnimations &sipStrings_QtSvg[26]
#define sipNameNr_48 48
#define sipName_48 &sipStrings_QtSvg[48]
#define sipNameNr_DisableCSSAnimations 70
#define sipName_DisableCSSAnimations &sipStrings_QtSvg[70]
#define sipNameNr_AssumeTrustedSource 91
#define sipName_AssumeTrustedSource &sipStrings_QtSvg[91]
#define sipNameNr_setAnimationEnabled 111
#define sipName_setAnimationEnabled &sipStrings_QtSvg[111]
#define sipNameNr_transformForElement 131
#define sipName_transformForElement &sipStrings_QtSvg[131]
#define sipNameNr_Tiny12FeaturesOnly 151
#define sipName_Tiny12FeaturesOnly &sipStrings_QtSvg[151]
#define sipNameNr_isAnimationEnabled 170
#define sipName_isAnimationEnabled &sipStrings_QtSvg[170]
#define sipNameNr_setAspectRatioMode 189
#define sipName_setAspectRatioMode &sipStrings_QtSvg[189]
#define sipNameNr_setFramesPerSecond 208
#define sipName_setFramesPerSecond &sipStrings_QtSvg[208]
#define sipNameNr_DisableAnimations 227
#define sipName_DisableAnimations &sipStrings_QtSvg[227]
#define sipNameNr_animationDuration 245
#define sipName_animationDuration &sipStrings_QtSvg[245]
#define sipNameNr_setDefaultOptions 263
#define sipName_setDefaultOptions &sipStrings_QtSvg[263]
#define sipNameNr_disconnectNotify 281
#define sipName_disconnectNotify &sipStrings_QtSvg[281]
#define sipNameNr_aspectRatioMode 298
#define sipName_aspectRatioMode &sipStrings_QtSvg[298]
#define sipNameNr_boundsOnElement 314
#define sipName_boundsOnElement &sipStrings_QtSvg[314]
#define sipNameNr_framesPerSecond 330
#define sipName_framesPerSecond &sipStrings_QtSvg[330]
#define sipNameNr_setCurrentFrame 346
#define sipName_setCurrentFrame &sipStrings_QtSvg[346]
#define sipNameNr_setOutputDevice 362
#define sipName_setOutputDevice &sipStrings_QtSvg[362]
#define sipNameNr_setDescription 378
#define sipName_setDescription &sipStrings_QtSvg[378]
#define sipNameNr_QSvgGenerator 393
#define sipName_QSvgGenerator &sipStrings_QtSvg[393]
#define sipNameNr_QtSvg__Option 407
#define sipName_QtSvg__Option &sipStrings_QtSvg[407]
#define sipNameNr_connectNotify 284
#define sipName_connectNotify &sipStrings_QtSvg[284]
#define sipNameNr_elementExists 421
#define sipName_elementExists &sipStrings_QtSvg[421]
#define sipNameNr_repaintNeeded 435
#define sipName_repaintNeeded &sipStrings_QtSvg[435]
#define sipNameNr_setResolution 449
#define sipName_setResolution &sipStrings_QtSvg[449]
#define sipNameNr_QSvgRenderer 463
#define sipName_QSvgRenderer &sipStrings_QtSvg[463]
#define sipNameNr_currentFrame 476
#define sipName_currentFrame &sipStrings_QtSvg[476]
#define sipNameNr_outputDevice 489
#define sipName_outputDevice &sipStrings_QtSvg[489]
#define sipNameNr_PyQt6_QtSvg 502
#define sipName_PyQt6_QtSvg &sipStrings_QtSvg[502]
#define sipNameNr_customEvent 514
#define sipName_customEvent &sipStrings_QtSvg[514]
#define sipNameNr_defaultSize 526
#define sipName_defaultSize &sipStrings_QtSvg[526]
#define sipNameNr_description 538
#define sipName_description &sipStrings_QtSvg[538]
#define sipNameNr_eventFilter 550
#define sipName_eventFilter &sipStrings_QtSvg[550]
#define sipNameNr_initPainter 562
#define sipName_initPainter &sipStrings_QtSvg[562]
#define sipNameNr_paintEngine 574
#define sipName_paintEngine &sipStrings_QtSvg[574]
#define sipNameNr_setFileName 586
#define sipName_setFileName &sipStrings_QtSvg[586]
#define sipNameNr_SvgVersion 15
#define sipName_SvgVersion &sipStrings_QtSvg[15]
#define sipNameNr_childEvent 598
#define sipName_childEvent &sipStrings_QtSvg[598]
#define sipNameNr_resolution 609
#define sipName_resolution &sipStrings_QtSvg[609]
#define sipNameNr_setOptions 620
#define sipName_setOptions &sipStrings_QtSvg[620]
#define sipNameNr_setViewBox 631
#define sipName_setViewBox &sipStrings_QtSvg[631]
#define sipNameNr_svgVersion 642
#define sipName_svgVersion &sipStrings_QtSvg[642]
#define sipNameNr_timerEvent 653
#define sipName_timerEvent &sipStrings_QtSvg[653]
#define sipNameNr_SvgTiny12 664
#define sipName_SvgTiny12 &sipStrings_QtSvg[664]
#define sipNameNr_NoOption 674
#define sipName_NoOption &sipStrings_QtSvg[674]
#define sipNameNr_animated 683
#define sipName_animated &sipStrings_QtSvg[683]
#define sipNameNr_fileName 692
#define sipName_fileName &sipStrings_QtSvg[692]
#define sipNameNr_setTitle 701
#define sipName_setTitle &sipStrings_QtSvg[701]
#define sipNameNr_viewBoxF 710
#define sipName_viewBoxF &sipStrings_QtSvg[710]
#define sipNameNr_isValid 719
#define sipName_isValid &sipStrings_QtSvg[719]
#define sipNameNr_options 727
#define sipName_options &sipStrings_QtSvg[727]
#define sipNameNr_setSize 735
#define sipName_setSize &sipStrings_QtSvg[735]
#define sipNameNr_viewBox 743
#define sipName_viewBox &sipStrings_QtSvg[743]
#define sipNameNr_Option 414
#define sipName_Option &sipStrings_QtSvg[414]
#define sipNameNr_bounds 751
#define sipName_bounds &sipStrings_QtSvg[751]
#define sipNameNr_metric 758
#define sipName_metric &sipStrings_QtSvg[758]
#define sipNameNr_parent 765
#define sipName_parent &sipStrings_QtSvg[765]
#define sipNameNr_render 772
#define sipName_render &sipStrings_QtSvg[772]
#define sipNameNr_QtSvg 508
#define sipName_QtSvg &sipStrings_QtSvg[508]
#define sipNameNr_Svg11 779
#define sipName_Svg11 &sipStrings_QtSvg[779]
#define sipNameNr_event 785
#define sipName_event &sipStrings_QtSvg[785]
#define sipNameNr_title 791
#define sipName_title &sipStrings_QtSvg[791]
#define sipNameNr_load 797
#define sipName_load &sipStrings_QtSvg[797]
#define sipNameNr_size 802
#define sipName_size &sipStrings_QtSvg[802]

#define sipMalloc                   sipAPI_QtSvg->api_malloc
#define sipFree                     sipAPI_QtSvg->api_free
#define sipBuildResult              sipAPI_QtSvg->api_build_result
#define sipCallMethod               sipAPI_QtSvg->api_call_method
#define sipCallProcedureMethod      sipAPI_QtSvg->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtSvg->api_call_error_handler
#define sipParseResultEx            sipAPI_QtSvg->api_parse_result_ex
#define sipParseResult              sipAPI_QtSvg->api_parse_result
#define sipParseArgs                sipAPI_QtSvg->api_parse_args
#define sipParseKwdArgs             sipAPI_QtSvg->api_parse_kwd_args
#define sipParsePair                sipAPI_QtSvg->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtSvg->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtSvg->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtSvg->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtSvg->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtSvg->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtSvg->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtSvg->api_add_exception
#define sipNoFunction               sipAPI_QtSvg->api_no_function
#define sipNoMethod                 sipAPI_QtSvg->api_no_method
#define sipAbstractMethod           sipAPI_QtSvg->api_abstract_method
#define sipBadClass                 sipAPI_QtSvg->api_bad_class
#define sipBadCatcherResult         sipAPI_QtSvg->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtSvg->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtSvg->api_bad_operator_arg
#define sipTrace                    sipAPI_QtSvg->api_trace
#define sipTransferBack             sipAPI_QtSvg->api_transfer_back
#define sipTransferTo               sipAPI_QtSvg->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtSvg->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtSvg->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtSvg->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtSvg->api_voidptr_type
#define sipGetPyObject              sipAPI_QtSvg->api_get_pyobject
#define sipGetAddress               sipAPI_QtSvg->api_get_address
#define sipGetMixinAddress          sipAPI_QtSvg->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtSvg->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtSvg->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtSvg->api_call_hook
#define sipEndThread                sipAPI_QtSvg->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtSvg->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtSvg->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtSvg->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtSvg->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtSvg->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtSvg->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtSvg->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtSvg->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtSvg->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtSvg->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtSvg->api_convert_to_bool
#define sipReleaseType              sipAPI_QtSvg->api_release_type
#define sipConvertFromType          sipAPI_QtSvg->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtSvg->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtSvg->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtSvg->api_convert_from_enum
#define sipGetState                 sipAPI_QtSvg->api_get_state
#define sipExportSymbol             sipAPI_QtSvg->api_export_symbol
#define sipImportSymbol             sipAPI_QtSvg->api_import_symbol
#define sipFindType                 sipAPI_QtSvg->api_find_type
#define sipBytes_AsChar             sipAPI_QtSvg->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtSvg->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtSvg->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtSvg->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtSvg->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtSvg->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtSvg->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtSvg->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtSvg->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtSvg->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtSvg->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtSvg->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtSvg->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtSvg->api_get_reference
#define sipKeepReference            sipAPI_QtSvg->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtSvg->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtSvg->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtSvg->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtSvg->api_type_scope
#define sipResolveTypedef           sipAPI_QtSvg->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtSvg->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtSvg->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtSvg->api_init_mixin
#define sipExportModule             sipAPI_QtSvg->api_export_module
#define sipInitModule               sipAPI_QtSvg->api_init_module
#define sipGetInterpreter           sipAPI_QtSvg->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtSvg->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtSvg->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtSvg->api_py_type_dict
#define sipPyTypeName               sipAPI_QtSvg->api_py_type_name
#define sipGetCFunction             sipAPI_QtSvg->api_get_c_function
#define sipGetMethod                sipAPI_QtSvg->api_get_method
#define sipFromMethod               sipAPI_QtSvg->api_from_method
#define sipGetDate                  sipAPI_QtSvg->api_get_date
#define sipFromDate                 sipAPI_QtSvg->api_from_date
#define sipGetDateTime              sipAPI_QtSvg->api_get_datetime
#define sipFromDateTime             sipAPI_QtSvg->api_from_datetime
#define sipGetTime                  sipAPI_QtSvg->api_get_time
#define sipFromTime                 sipAPI_QtSvg->api_from_time
#define sipIsUserType               sipAPI_QtSvg->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtSvg->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtSvg->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtSvg->api_unicode_write
#define sipUnicodeData              sipAPI_QtSvg->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtSvg->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtSvg->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtSvg->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtSvg->api_is_derived_class
#define sipGetUserObject            sipAPI_QtSvg->api_get_user_object
#define sipSetUserObject            sipAPI_QtSvg->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtSvg->api_register_event_handler
#define sipConvertToArray           sipAPI_QtSvg->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtSvg->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtSvg->api_enable_gc
#define sipPrintObject              sipAPI_QtSvg->api_print_object
#define sipLong_AsChar              sipAPI_QtSvg->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtSvg->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtSvg->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtSvg->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtSvg->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtSvg->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtSvg->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtSvg->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtSvg->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtSvg->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtSvg->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtSvg->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtSvg->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtSvg->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtSvg->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtSvg->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtSvg->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtSvg->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtSvg->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtSvg->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtSvg->api_release_type_us
#define sipIsPyMethod               sipAPI_QtSvg->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtSvg[];

#define sipType_QtSvg sipExportedTypes_QtSvg[4]

#define sipType_QtSvg_Option sipExportedTypes_QtSvg[5]

extern sipClassTypeDef sipTypeDef_QtSvg_QtSvg;

#define sipType_QSvgGenerator sipExportedTypes_QtSvg[1]

#define sipType_QSvgGenerator_SvgVersion sipExportedTypes_QtSvg[2]

extern sipClassTypeDef sipTypeDef_QtSvg_QSvgGenerator;

#define sipType_QSvgRenderer sipExportedTypes_QtSvg[3]

extern sipClassTypeDef sipTypeDef_QtSvg_QSvgRenderer;

#define sipType_QFlags_0100QtSvg_Option sipExportedTypes_QtSvg[0]

extern sipMappedTypeDef sipTypeDef_QtSvg_QFlags_0100QtSvg_Option;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtSvg;
extern sipExportedModuleDef sipModuleAPI_QtSvg;
extern sipTypeDef *sipExportedTypes_QtSvg[];

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtSvg_QtCore[12].it_td

#define sipType_QObject sipImportedTypes_QtSvg_QtCore[5].it_td

#define sipType_QIODevice sipImportedTypes_QtSvg_QtCore[3].it_td

#define sipType_QByteArray sipImportedTypes_QtSvg_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtSvg_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtSvg_QtCore[10].it_td

#define sipType_QChildEvent sipImportedTypes_QtSvg_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtSvg_QtCore[4].it_td

#define sipType_QRect sipImportedTypes_QtSvg_QtCore[6].it_td

#define sipType_QRectF sipImportedTypes_QtSvg_QtCore[7].it_td

#define sipType_QSize sipImportedTypes_QtSvg_QtCore[8].it_td

#define sipType_QXmlStreamReader sipImportedTypes_QtSvg_QtCore[11].it_td

#define sipType_QString sipImportedTypes_QtSvg_QtCore[9].it_td
extern sipImportedTypeDef sipImportedTypes_QtSvg_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtSvg_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtSvg_QtGui[0].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtSvg_QtGui[1].it_td

#define sipType_QPaintEngine sipImportedTypes_QtSvg_QtGui[2].it_td

#define sipType_QPainter sipImportedTypes_QtSvg_QtGui[3].it_td

#define sipType_QTransform sipImportedTypes_QtSvg_QtGui[4].it_td
extern sipImportedTypeDef sipImportedTypes_QtSvg_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtSvg_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtSvg_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtSvg_qt_metacast;

#endif
