/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsmanagedvalue.sip"
#include <qjsmanagedvalue.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsvalue.sip"
#include <qjsvalue.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsengine.sip"
#include <qjsengine.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsprimitivevalue.sip"
#include <qjsprimitivevalue.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"
#line 262 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSManagedValue.cpp"


PyDoc_STRVAR(doc_QJSManagedValue_equals, "equals(self, other: QJSManagedValue) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_equals(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_equals(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue* a0;
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QJSManagedValue, &sipCpp, sipType_QJSManagedValue, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->equals(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_equals, doc_QJSManagedValue_equals);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_strictlyEquals, "strictlyEquals(self, other: QJSManagedValue) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_strictlyEquals(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_strictlyEquals(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue* a0;
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QJSManagedValue, &sipCpp, sipType_QJSManagedValue, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->strictlyEquals(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_strictlyEquals, doc_QJSManagedValue_strictlyEquals);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_engine, "engine(self) -> QJSEngine|None");

extern "C" {static PyObject *meth_QJSManagedValue_engine(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_engine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            ::QJSEngine*sipRes;

            sipRes = sipCpp->engine();

            return sipConvertFromType(sipRes, sipType_QJSEngine, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_engine, doc_QJSManagedValue_engine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_prototype, "prototype(self) -> QJSManagedValue");

extern "C" {static PyObject *meth_QJSManagedValue_prototype(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_prototype(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            ::QJSManagedValue*sipRes;

            sipRes = new ::QJSManagedValue(sipCpp->prototype());

            return sipConvertFromNewType(sipRes, sipType_QJSManagedValue, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_prototype, doc_QJSManagedValue_prototype);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_setPrototype, "setPrototype(self, prototype: QJSManagedValue)");

extern "C" {static PyObject *meth_QJSManagedValue_setPrototype(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_setPrototype(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue* a0;
        ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QJSManagedValue, &sipCpp, sipType_QJSManagedValue, &a0))
        {
            sipCpp->setPrototype(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_setPrototype, doc_QJSManagedValue_setPrototype);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_type, "type(self) -> QJSManagedValue.Type");

extern "C" {static PyObject *meth_QJSManagedValue_type(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            ::QJSManagedValue::Type sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QJSManagedValue_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_type, doc_QJSManagedValue_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isUndefined, "isUndefined(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isUndefined(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isUndefined(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isUndefined();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isUndefined, doc_QJSManagedValue_isUndefined);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isBoolean, "isBoolean(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isBoolean(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isBoolean(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isBoolean();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isBoolean, doc_QJSManagedValue_isBoolean);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isNumber, "isNumber(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isNumber(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isNumber(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNumber();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isNumber, doc_QJSManagedValue_isNumber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isString, "isString(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isString(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isString();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isString, doc_QJSManagedValue_isString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isObject, "isObject(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isObject(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isObject();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isObject, doc_QJSManagedValue_isObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isSymbol, "isSymbol(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isSymbol(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isSymbol(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSymbol();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isSymbol, doc_QJSManagedValue_isSymbol);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isFunction, "isFunction(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isFunction(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFunction();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isFunction, doc_QJSManagedValue_isFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isInteger, "isInteger(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isInteger(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isInteger(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isInteger();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isInteger, doc_QJSManagedValue_isInteger);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isNull(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isNull, doc_QJSManagedValue_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isRegularExpression, "isRegularExpression(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isRegularExpression(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isRegularExpression(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isRegularExpression();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isRegularExpression, doc_QJSManagedValue_isRegularExpression);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isArray, "isArray(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isArray(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isArray(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isArray();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isArray, doc_QJSManagedValue_isArray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isUrl, "isUrl(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isUrl(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isUrl();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isUrl, doc_QJSManagedValue_isUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isVariant, "isVariant(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isVariant(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isVariant(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isVariant();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isVariant, doc_QJSManagedValue_isVariant);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isQObject, "isQObject(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isQObject(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isQObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isQObject();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isQObject, doc_QJSManagedValue_isQObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isQMetaObject, "isQMetaObject(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isQMetaObject(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isQMetaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isQMetaObject();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isQMetaObject, doc_QJSManagedValue_isQMetaObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isDate, "isDate(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isDate(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isDate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDate();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isDate, doc_QJSManagedValue_isDate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_isError, "isError(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_isError(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_isError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isError();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_isError, doc_QJSManagedValue_isError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toString, "toString(self) -> str");

extern "C" {static PyObject *meth_QJSManagedValue_toString(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toString, doc_QJSManagedValue_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toNumber, "toNumber(self) -> float");

extern "C" {static PyObject *meth_QJSManagedValue_toNumber(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toNumber(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->toNumber();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toNumber, doc_QJSManagedValue_toNumber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toBoolean, "toBoolean(self) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_toBoolean(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toBoolean(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->toBoolean();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toBoolean, doc_QJSManagedValue_toBoolean);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toPrimitive, "toPrimitive(self) -> QJSPrimitiveValue");

extern "C" {static PyObject *meth_QJSManagedValue_toPrimitive(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toPrimitive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            ::QJSPrimitiveValue*sipRes;

            sipRes = new ::QJSPrimitiveValue(sipCpp->toPrimitive());

            return sipConvertFromNewType(sipRes, sipType_QJSPrimitiveValue, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toPrimitive, doc_QJSManagedValue_toPrimitive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toJSValue, "toJSValue(self) -> QJSValue");

extern "C" {static PyObject *meth_QJSManagedValue_toJSValue(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toJSValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            ::QJSValue*sipRes;

            sipRes = new ::QJSValue(sipCpp->toJSValue());

            return sipConvertFromNewType(sipRes, sipType_QJSValue, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toJSValue, doc_QJSManagedValue_toJSValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toVariant, "toVariant(self) -> Any");

extern "C" {static PyObject *meth_QJSManagedValue_toVariant(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toVariant(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->toVariant());

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toVariant, doc_QJSManagedValue_toVariant);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toInteger, "toInteger(self) -> int");

extern "C" {static PyObject *meth_QJSManagedValue_toInteger(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toInteger(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->toInteger();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toInteger, doc_QJSManagedValue_toInteger);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toRegularExpression, "toRegularExpression(self) -> QRegularExpression");

extern "C" {static PyObject *meth_QJSManagedValue_toRegularExpression(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toRegularExpression(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            ::QRegularExpression*sipRes;

            sipRes = new ::QRegularExpression(sipCpp->toRegularExpression());

            return sipConvertFromNewType(sipRes, sipType_QRegularExpression, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toRegularExpression, doc_QJSManagedValue_toRegularExpression);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toUrl, "toUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QJSManagedValue_toUrl(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->toUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toUrl, doc_QJSManagedValue_toUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toQObject, "toQObject(self) -> QObject|None");

extern "C" {static PyObject *meth_QJSManagedValue_toQObject(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toQObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            ::QObject*sipRes;

            sipRes = sipCpp->toQObject();

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toQObject, doc_QJSManagedValue_toQObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toQMetaObject, "toQMetaObject(self) -> QMetaObject|None");

extern "C" {static PyObject *meth_QJSManagedValue_toQMetaObject(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toQMetaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            const ::QMetaObject*sipRes;

            sipRes = sipCpp->toQMetaObject();

            return sipConvertFromType(const_cast< ::QMetaObject *>(sipRes), sipType_QMetaObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toQMetaObject, doc_QJSManagedValue_toQMetaObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_toDateTime, "toDateTime(self) -> QDateTime");

extern "C" {static PyObject *meth_QJSManagedValue_toDateTime(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_toDateTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSManagedValue, &sipCpp))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->toDateTime());

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_toDateTime, doc_QJSManagedValue_toDateTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_hasProperty, "hasProperty(self, name: str|None) -> bool\n"
"hasProperty(self, arrayIndex: int) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_hasProperty(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_hasProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QJSManagedValue, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->hasProperty(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::quint32 a0;
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QJSManagedValue, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->hasProperty(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_hasProperty, doc_QJSManagedValue_hasProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_hasOwnProperty, "hasOwnProperty(self, name: str|None) -> bool\n"
"hasOwnProperty(self, arrayIndex: int) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_hasOwnProperty(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_hasOwnProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QJSManagedValue, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->hasOwnProperty(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::quint32 a0;
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QJSManagedValue, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->hasOwnProperty(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_hasOwnProperty, doc_QJSManagedValue_hasOwnProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_property, "property(self, name: str|None) -> QJSValue\n"
"property(self, arrayIndex: int) -> QJSValue");

extern "C" {static PyObject *meth_QJSManagedValue_property(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_property(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QJSManagedValue, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QJSValue*sipRes;

            sipRes = new ::QJSValue(sipCpp->property(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QJSValue, SIP_NULLPTR);
        }
    }

    {
        ::quint32 a0;
        const ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QJSManagedValue, &sipCpp, &a0))
        {
            ::QJSValue*sipRes;

            sipRes = new ::QJSValue(sipCpp->property(a0));

            return sipConvertFromNewType(sipRes, sipType_QJSValue, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_property, doc_QJSManagedValue_property);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_setProperty, "setProperty(self, name: str|None, value: QJSValue|QJSValue.SpecialValue|bool|int|float|str|None)\n"
"setProperty(self, arrayIndex: int, value: QJSValue|QJSValue.SpecialValue|bool|int|float|str|None)");

extern "C" {static PyObject *meth_QJSManagedValue_setProperty(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_setProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QJSValue* a1;
        int a1State = 0;
        ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QJSManagedValue, &sipCpp, sipType_QString, &a0, &a0State, sipType_QJSValue, &a1, &a1State))
        {
            sipCpp->setProperty(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QJSValue *>(a1), sipType_QJSValue, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::quint32 a0;
        const ::QJSValue* a1;
        int a1State = 0;
        ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuJ1", &sipSelf, sipType_QJSManagedValue, &sipCpp, &a0, sipType_QJSValue, &a1, &a1State))
        {
            sipCpp->setProperty(a0, *a1);
            sipReleaseType(const_cast< ::QJSValue *>(a1), sipType_QJSValue, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_setProperty, doc_QJSManagedValue_setProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_deleteProperty, "deleteProperty(self, name: str|None) -> bool\n"
"deleteProperty(self, arrayIndex: int) -> bool");

extern "C" {static PyObject *meth_QJSManagedValue_deleteProperty(PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_deleteProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QJSManagedValue, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->deleteProperty(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::quint32 a0;
        ::QJSManagedValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QJSManagedValue, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->deleteProperty(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_deleteProperty, doc_QJSManagedValue_deleteProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_call, "call(self, arguments: Iterable[QJSValue|QJSValue.SpecialValue|bool|int|float|str|None] = []) -> QJSValue");

extern "C" {static PyObject *meth_QJSManagedValue_call(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_call(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSValueList& a0def = {};
        const ::QJSValueList* a0 = &a0def;
        int a0State = 0;
        const ::QJSManagedValue *sipCpp;

        static const char *sipKwdList[] = {
            sipName_arguments,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QJSManagedValue, &sipCpp, sipType_QList_0100QJSValue, &a0, &a0State))
        {
            ::QJSValue*sipRes;

            sipRes = new ::QJSValue(sipCpp->call(*a0));
            sipReleaseType(const_cast< ::QJSValueList *>(a0), sipType_QList_0100QJSValue, a0State);

            return sipConvertFromNewType(sipRes, sipType_QJSValue, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_call, doc_QJSManagedValue_call);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_callWithInstance, "callWithInstance(self, instance: QJSValue|QJSValue.SpecialValue|bool|int|float|str|None, arguments: Iterable[QJSValue|QJSValue.SpecialValue|bool|int|float|str|None] = []) -> QJSValue");

extern "C" {static PyObject *meth_QJSManagedValue_callWithInstance(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_callWithInstance(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSValue* a0;
        int a0State = 0;
        const ::QJSValueList& a1def = {};
        const ::QJSValueList* a1 = &a1def;
        int a1State = 0;
        const ::QJSManagedValue *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_arguments,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QJSManagedValue, &sipCpp, sipType_QJSValue, &a0, &a0State, sipType_QList_0100QJSValue, &a1, &a1State))
        {
            ::QJSValue*sipRes;

            sipRes = new ::QJSValue(sipCpp->callWithInstance(*a0, *a1));
            sipReleaseType(const_cast< ::QJSValue *>(a0), sipType_QJSValue, a0State);
            sipReleaseType(const_cast< ::QJSValueList *>(a1), sipType_QList_0100QJSValue, a1State);

            return sipConvertFromNewType(sipRes, sipType_QJSValue, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_callWithInstance, doc_QJSManagedValue_callWithInstance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSManagedValue_callAsConstructor, "callAsConstructor(self, arguments: Iterable[QJSValue|QJSValue.SpecialValue|bool|int|float|str|None] = []) -> QJSValue");

extern "C" {static PyObject *meth_QJSManagedValue_callAsConstructor(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QJSManagedValue_callAsConstructor(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSValueList& a0def = {};
        const ::QJSValueList* a0 = &a0def;
        int a0State = 0;
        const ::QJSManagedValue *sipCpp;

        static const char *sipKwdList[] = {
            sipName_arguments,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QJSManagedValue, &sipCpp, sipType_QList_0100QJSValue, &a0, &a0State))
        {
            ::QJSValue*sipRes;

            sipRes = new ::QJSValue(sipCpp->callAsConstructor(*a0));
            sipReleaseType(const_cast< ::QJSValueList *>(a0), sipType_QList_0100QJSValue, a0State);

            return sipConvertFromNewType(sipRes, sipType_QJSValue, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSManagedValue, sipName_callAsConstructor, doc_QJSManagedValue_callAsConstructor);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QJSManagedValue(void *, int);}
static void release_QJSManagedValue(void *sipCppV, int)
{
    delete reinterpret_cast< ::QJSManagedValue *>(sipCppV);
}


extern "C" {static void *array_QJSManagedValue(Py_ssize_t);}
static void *array_QJSManagedValue(Py_ssize_t sipNrElem)
{
    return new ::QJSManagedValue[sipNrElem];
}


extern "C" {static void array_delete_QJSManagedValue(void *);}
static void array_delete_QJSManagedValue(void *sipCpp)
{
    delete[] reinterpret_cast< ::QJSManagedValue *>(sipCpp);
}


extern "C" {static void dealloc_QJSManagedValue(sipSimpleWrapper *);}
static void dealloc_QJSManagedValue(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QJSManagedValue(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QJSManagedValue(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QJSManagedValue(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QJSManagedValue *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QJSManagedValue();

            return sipCpp;
        }
    }

    {
        ::QJSValue* a0;
        int a0State = 0;
        ::QJSEngine* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1J8", sipType_QJSValue, &a0, &a0State, sipType_QJSEngine, &a1))
        {
            sipCpp = new ::QJSManagedValue(*a0, a1);
            sipReleaseType(a0, sipType_QJSValue, a0State);

            return sipCpp;
        }
    }

    {
        const ::QJSPrimitiveValue* a0;
        ::QJSEngine* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9J8", sipType_QJSPrimitiveValue, &a0, sipType_QJSEngine, &a1))
        {
            sipCpp = new ::QJSManagedValue(*a0, a1);

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QJSEngine* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1J8", sipType_QString, &a0, &a0State, sipType_QJSEngine, &a1))
        {
            sipCpp = new ::QJSManagedValue(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipCpp;
        }
    }

    {
        const ::QVariant* a0;
        int a0State = 0;
        ::QJSEngine* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1J8", sipType_QVariant, &a0, &a0State, sipType_QJSEngine, &a1))
        {
            sipCpp = new ::QJSManagedValue(*a0, a1);
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QJSManagedValue[] = {
    {sipName_call, SIP_MLMETH_CAST(meth_QJSManagedValue_call), METH_VARARGS|METH_KEYWORDS, doc_QJSManagedValue_call},
    {sipName_callAsConstructor, SIP_MLMETH_CAST(meth_QJSManagedValue_callAsConstructor), METH_VARARGS|METH_KEYWORDS, doc_QJSManagedValue_callAsConstructor},
    {sipName_callWithInstance, SIP_MLMETH_CAST(meth_QJSManagedValue_callWithInstance), METH_VARARGS|METH_KEYWORDS, doc_QJSManagedValue_callWithInstance},
    {sipName_deleteProperty, meth_QJSManagedValue_deleteProperty, METH_VARARGS, doc_QJSManagedValue_deleteProperty},
    {sipName_engine, meth_QJSManagedValue_engine, METH_VARARGS, doc_QJSManagedValue_engine},
    {sipName_equals, meth_QJSManagedValue_equals, METH_VARARGS, doc_QJSManagedValue_equals},
    {sipName_hasOwnProperty, meth_QJSManagedValue_hasOwnProperty, METH_VARARGS, doc_QJSManagedValue_hasOwnProperty},
    {sipName_hasProperty, meth_QJSManagedValue_hasProperty, METH_VARARGS, doc_QJSManagedValue_hasProperty},
    {sipName_isArray, meth_QJSManagedValue_isArray, METH_VARARGS, doc_QJSManagedValue_isArray},
    {sipName_isBoolean, meth_QJSManagedValue_isBoolean, METH_VARARGS, doc_QJSManagedValue_isBoolean},
    {sipName_isDate, meth_QJSManagedValue_isDate, METH_VARARGS, doc_QJSManagedValue_isDate},
    {sipName_isError, meth_QJSManagedValue_isError, METH_VARARGS, doc_QJSManagedValue_isError},
    {sipName_isFunction, meth_QJSManagedValue_isFunction, METH_VARARGS, doc_QJSManagedValue_isFunction},
    {sipName_isInteger, meth_QJSManagedValue_isInteger, METH_VARARGS, doc_QJSManagedValue_isInteger},
    {sipName_isNull, meth_QJSManagedValue_isNull, METH_VARARGS, doc_QJSManagedValue_isNull},
    {sipName_isNumber, meth_QJSManagedValue_isNumber, METH_VARARGS, doc_QJSManagedValue_isNumber},
    {sipName_isObject, meth_QJSManagedValue_isObject, METH_VARARGS, doc_QJSManagedValue_isObject},
    {sipName_isQMetaObject, meth_QJSManagedValue_isQMetaObject, METH_VARARGS, doc_QJSManagedValue_isQMetaObject},
    {sipName_isQObject, meth_QJSManagedValue_isQObject, METH_VARARGS, doc_QJSManagedValue_isQObject},
    {sipName_isRegularExpression, meth_QJSManagedValue_isRegularExpression, METH_VARARGS, doc_QJSManagedValue_isRegularExpression},
    {sipName_isString, meth_QJSManagedValue_isString, METH_VARARGS, doc_QJSManagedValue_isString},
    {sipName_isSymbol, meth_QJSManagedValue_isSymbol, METH_VARARGS, doc_QJSManagedValue_isSymbol},
    {sipName_isUndefined, meth_QJSManagedValue_isUndefined, METH_VARARGS, doc_QJSManagedValue_isUndefined},
    {sipName_isUrl, meth_QJSManagedValue_isUrl, METH_VARARGS, doc_QJSManagedValue_isUrl},
    {sipName_isVariant, meth_QJSManagedValue_isVariant, METH_VARARGS, doc_QJSManagedValue_isVariant},
    {sipName_property, meth_QJSManagedValue_property, METH_VARARGS, doc_QJSManagedValue_property},
    {sipName_prototype, meth_QJSManagedValue_prototype, METH_VARARGS, doc_QJSManagedValue_prototype},
    {sipName_setProperty, meth_QJSManagedValue_setProperty, METH_VARARGS, doc_QJSManagedValue_setProperty},
    {sipName_setPrototype, meth_QJSManagedValue_setPrototype, METH_VARARGS, doc_QJSManagedValue_setPrototype},
    {sipName_strictlyEquals, meth_QJSManagedValue_strictlyEquals, METH_VARARGS, doc_QJSManagedValue_strictlyEquals},
    {sipName_toBoolean, meth_QJSManagedValue_toBoolean, METH_VARARGS, doc_QJSManagedValue_toBoolean},
    {sipName_toDateTime, meth_QJSManagedValue_toDateTime, METH_VARARGS, doc_QJSManagedValue_toDateTime},
    {sipName_toInteger, meth_QJSManagedValue_toInteger, METH_VARARGS, doc_QJSManagedValue_toInteger},
    {sipName_toJSValue, meth_QJSManagedValue_toJSValue, METH_VARARGS, doc_QJSManagedValue_toJSValue},
    {sipName_toNumber, meth_QJSManagedValue_toNumber, METH_VARARGS, doc_QJSManagedValue_toNumber},
    {sipName_toPrimitive, meth_QJSManagedValue_toPrimitive, METH_VARARGS, doc_QJSManagedValue_toPrimitive},
    {sipName_toQMetaObject, meth_QJSManagedValue_toQMetaObject, METH_VARARGS, doc_QJSManagedValue_toQMetaObject},
    {sipName_toQObject, meth_QJSManagedValue_toQObject, METH_VARARGS, doc_QJSManagedValue_toQObject},
    {sipName_toRegularExpression, meth_QJSManagedValue_toRegularExpression, METH_VARARGS, doc_QJSManagedValue_toRegularExpression},
    {sipName_toString, meth_QJSManagedValue_toString, METH_VARARGS, doc_QJSManagedValue_toString},
    {sipName_toUrl, meth_QJSManagedValue_toUrl, METH_VARARGS, doc_QJSManagedValue_toUrl},
    {sipName_toVariant, meth_QJSManagedValue_toVariant, METH_VARARGS, doc_QJSManagedValue_toVariant},
    {sipName_type, meth_QJSManagedValue_type, METH_VARARGS, doc_QJSManagedValue_type}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QJSManagedValue[] = {
    {sipName_Undefined, static_cast<int>(::QJSManagedValue::Undefined)},
    {sipName_Boolean, static_cast<int>(::QJSManagedValue::Boolean)},
    {sipName_Number, static_cast<int>(::QJSManagedValue::Number)},
    {sipName_String, static_cast<int>(::QJSManagedValue::String)},
    {sipName_Object, static_cast<int>(::QJSManagedValue::Object)},
    {sipName_Symbol, static_cast<int>(::QJSManagedValue::Symbol)},
    {sipName_Function, static_cast<int>(::QJSManagedValue::Function)},
    {0, 0}
};

PyDoc_STRVAR(doc_QJSManagedValue, "\1QJSManagedValue()\n"
"QJSManagedValue(value: QJSValue|QJSValue.SpecialValue|bool|int|float|str|None, engine: QJSEngine|None)\n"
"QJSManagedValue(value: QJSPrimitiveValue, engine: QJSEngine|None)\n"
"QJSManagedValue(string: str|None, engine: QJSEngine|None)\n"
"QJSManagedValue(variant: Any, engine: QJSEngine|None)");


sipClassTypeDef sipTypeDef_QtQml_QJSManagedValue = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QJSManagedValue,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QJSManagedValue,
        {0, 0, 1},
        43, methods_QJSManagedValue,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QJSManagedValue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QJSManagedValue,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QJSManagedValue,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QJSManagedValue,
    SIP_NULLPTR,
    array_QJSManagedValue,
    SIP_NULLPTR,
    release_QJSManagedValue,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QJSManagedValue,
    sizeof (::QJSManagedValue),
};
