/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 259 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQXmlStreamWriter.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQXmlStreamWriter.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQXmlStreamWriter.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQXmlStreamWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQXmlStreamWriter.cpp"
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQXmlStreamWriter.cpp"
#line 423 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQXmlStreamWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQXmlStreamWriter.cpp"


PyDoc_STRVAR(doc_QXmlStreamWriter_setDevice, "setDevice(self, device: QIODevice|None)");

extern "C" {static PyObject *meth_QXmlStreamWriter_setDevice(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_setDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QIODevice, &a0))
        {
            sipCpp->setDevice(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_setDevice, doc_QXmlStreamWriter_setDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_device, "device(self) -> QIODevice|None");

extern "C" {static PyObject *meth_QXmlStreamWriter_device(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_device(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamWriter, &sipCpp))
        {
            ::QIODevice*sipRes;

            sipRes = sipCpp->device();

            return sipConvertFromType(sipRes, sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_device, doc_QXmlStreamWriter_device);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_setAutoFormatting, "setAutoFormatting(self, a0: bool)");

extern "C" {static PyObject *meth_QXmlStreamWriter_setAutoFormatting(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_setAutoFormatting(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, &a0))
        {
            sipCpp->setAutoFormatting(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_setAutoFormatting, doc_QXmlStreamWriter_setAutoFormatting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_autoFormatting, "autoFormatting(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamWriter_autoFormatting(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_autoFormatting(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamWriter, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoFormatting();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_autoFormatting, doc_QXmlStreamWriter_autoFormatting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_setAutoFormattingIndent, "setAutoFormattingIndent(self, spaces: int)");

extern "C" {static PyObject *meth_QXmlStreamWriter_setAutoFormattingIndent(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_setAutoFormattingIndent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, &a0))
        {
            sipCpp->setAutoFormattingIndent(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_setAutoFormattingIndent, doc_QXmlStreamWriter_setAutoFormattingIndent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_autoFormattingIndent, "autoFormattingIndent(self) -> int");

extern "C" {static PyObject *meth_QXmlStreamWriter_autoFormattingIndent(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_autoFormattingIndent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamWriter, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->autoFormattingIndent();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_autoFormattingIndent, doc_QXmlStreamWriter_autoFormattingIndent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeAttribute, "writeAttribute(self, namespaceUri: QByteArray|bytes|bytearray|memoryview|str|None, name: QByteArray|bytes|bytearray|memoryview|str|None, value: QByteArray|bytes|bytearray|memoryview|str|None)\n"
"writeAttribute(self, qualifiedName: QByteArray|bytes|bytearray|memoryview|str|None, value: QByteArray|bytes|bytearray|memoryview|str|None)\n"
"writeAttribute(self, attribute: QXmlStreamAttribute)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeAttribute(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QAnyStringView* a2;
        int a2State = 0;
        void *a2UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1J1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QAnyStringView, &a1, &a1State, &a1UserState, sipType_QAnyStringView, &a2, &a2State, &a2UserState))
        {
            sipCpp->writeAttribute(*a0, *a1, *a2);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);
            sipReleaseTypeUS(a2, sipType_QAnyStringView, a2State, a2UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QAnyStringView, &a1, &a1State, &a1UserState))
        {
            sipCpp->writeAttribute(*a0, *a1);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QXmlStreamAttribute* a0;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QXmlStreamAttribute, &a0))
        {
            sipCpp->writeAttribute(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeAttribute, doc_QXmlStreamWriter_writeAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeAttributes, "writeAttributes(self, attributes: QXmlStreamAttributes)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeAttributes(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeAttributes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamAttributes* a0;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QXmlStreamAttributes, &a0))
        {
            sipCpp->writeAttributes(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeAttributes, doc_QXmlStreamWriter_writeAttributes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeCDATA, "writeCDATA(self, text: QByteArray|bytes|bytearray|memoryview|str|None)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeCDATA(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeCDATA(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            sipCpp->writeCDATA(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeCDATA, doc_QXmlStreamWriter_writeCDATA);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeCharacters, "writeCharacters(self, text: QByteArray|bytes|bytearray|memoryview|str|None)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeCharacters(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeCharacters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            sipCpp->writeCharacters(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeCharacters, doc_QXmlStreamWriter_writeCharacters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeComment, "writeComment(self, text: QByteArray|bytes|bytearray|memoryview|str|None)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeComment(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeComment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            sipCpp->writeComment(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeComment, doc_QXmlStreamWriter_writeComment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeDTD, "writeDTD(self, dtd: QByteArray|bytes|bytearray|memoryview|str|None)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeDTD(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeDTD(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            sipCpp->writeDTD(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeDTD, doc_QXmlStreamWriter_writeDTD);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeEmptyElement, "writeEmptyElement(self, namespaceUri: QByteArray|bytes|bytearray|memoryview|str|None, name: QByteArray|bytes|bytearray|memoryview|str|None)\n"
"writeEmptyElement(self, qualifiedName: QByteArray|bytes|bytearray|memoryview|str|None)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeEmptyElement(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeEmptyElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QAnyStringView, &a1, &a1State, &a1UserState))
        {
            sipCpp->writeEmptyElement(*a0, *a1);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            sipCpp->writeEmptyElement(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeEmptyElement, doc_QXmlStreamWriter_writeEmptyElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeTextElement, "writeTextElement(self, namespaceUri: QByteArray|bytes|bytearray|memoryview|str|None, name: QByteArray|bytes|bytearray|memoryview|str|None, text: QByteArray|bytes|bytearray|memoryview|str|None)\n"
"writeTextElement(self, qualifiedName: QByteArray|bytes|bytearray|memoryview|str|None, text: QByteArray|bytes|bytearray|memoryview|str|None)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeTextElement(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeTextElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QAnyStringView* a2;
        int a2State = 0;
        void *a2UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1J1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QAnyStringView, &a1, &a1State, &a1UserState, sipType_QAnyStringView, &a2, &a2State, &a2UserState))
        {
            sipCpp->writeTextElement(*a0, *a1, *a2);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);
            sipReleaseTypeUS(a2, sipType_QAnyStringView, a2State, a2UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QAnyStringView, &a1, &a1State, &a1UserState))
        {
            sipCpp->writeTextElement(*a0, *a1);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeTextElement, doc_QXmlStreamWriter_writeTextElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeEndDocument, "writeEndDocument(self)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeEndDocument(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeEndDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamWriter, &sipCpp))
        {
            sipCpp->writeEndDocument();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeEndDocument, doc_QXmlStreamWriter_writeEndDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeEndElement, "writeEndElement(self)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeEndElement(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeEndElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamWriter, &sipCpp))
        {
            sipCpp->writeEndElement();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeEndElement, doc_QXmlStreamWriter_writeEndElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeEntityReference, "writeEntityReference(self, name: QByteArray|bytes|bytearray|memoryview|str|None)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeEntityReference(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeEntityReference(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            sipCpp->writeEntityReference(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeEntityReference, doc_QXmlStreamWriter_writeEntityReference);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeNamespace, "writeNamespace(self, namespaceUri: QByteArray|bytes|bytearray|memoryview|str|None, prefix: QByteArray|bytes|bytearray|memoryview|str|None = '')");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeNamespace(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeNamespace(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QAnyStringView a1def = {};
        ::QAnyStringView* a1 = &a1def;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_prefix,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QAnyStringView, &a1, &a1State, &a1UserState))
        {
            sipCpp->writeNamespace(*a0, *a1);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeNamespace, doc_QXmlStreamWriter_writeNamespace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeDefaultNamespace, "writeDefaultNamespace(self, namespaceUri: QByteArray|bytes|bytearray|memoryview|str|None)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeDefaultNamespace(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeDefaultNamespace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            sipCpp->writeDefaultNamespace(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeDefaultNamespace, doc_QXmlStreamWriter_writeDefaultNamespace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeProcessingInstruction, "writeProcessingInstruction(self, target: QByteArray|bytes|bytearray|memoryview|str|None, data: QByteArray|bytes|bytearray|memoryview|str|None = '')");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeProcessingInstruction(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeProcessingInstruction(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QAnyStringView a1def = {};
        ::QAnyStringView* a1 = &a1def;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_data,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QAnyStringView, &a1, &a1State, &a1UserState))
        {
            sipCpp->writeProcessingInstruction(*a0, *a1);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeProcessingInstruction, doc_QXmlStreamWriter_writeProcessingInstruction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeStartDocument, "writeStartDocument(self, version: QByteArray|bytes|bytearray|memoryview|str|None, standalone: bool)\n"
"writeStartDocument(self, version: QByteArray|bytes|bytearray|memoryview|str|None)\n"
"writeStartDocument(self)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeStartDocument(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeStartDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        bool a1;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1b", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, &a1))
        {
            sipCpp->writeStartDocument(*a0, a1);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            sipCpp->writeStartDocument(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamWriter, &sipCpp))
        {
            sipCpp->writeStartDocument();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeStartDocument, doc_QXmlStreamWriter_writeStartDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeStartElement, "writeStartElement(self, namespaceUri: QByteArray|bytes|bytearray|memoryview|str|None, name: QByteArray|bytes|bytearray|memoryview|str|None)\n"
"writeStartElement(self, qualifiedName: QByteArray|bytes|bytearray|memoryview|str|None)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeStartElement(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeStartElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QAnyStringView, &a1, &a1State, &a1UserState))
        {
            sipCpp->writeStartElement(*a0, *a1);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            sipCpp->writeStartElement(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeStartElement, doc_QXmlStreamWriter_writeStartElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_writeCurrentToken, "writeCurrentToken(self, reader: QXmlStreamReader)");

extern "C" {static PyObject *meth_QXmlStreamWriter_writeCurrentToken(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_writeCurrentToken(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamReader* a0;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QXmlStreamReader, &a0))
        {
            sipCpp->writeCurrentToken(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_writeCurrentToken, doc_QXmlStreamWriter_writeCurrentToken);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_hasError, "hasError(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamWriter_hasError(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_hasError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamWriter, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasError();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_hasError, doc_QXmlStreamWriter_hasError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_setStopWritingOnError, "setStopWritingOnError(self, stop: bool)");

extern "C" {static PyObject *meth_QXmlStreamWriter_setStopWritingOnError(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_setStopWritingOnError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, &a0))
        {
            sipCpp->setStopWritingOnError(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_setStopWritingOnError, doc_QXmlStreamWriter_setStopWritingOnError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_stopWritingOnError, "stopWritingOnError(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamWriter_stopWritingOnError(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_stopWritingOnError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamWriter, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->stopWritingOnError();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_stopWritingOnError, doc_QXmlStreamWriter_stopWritingOnError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_raiseError, "raiseError(self, message: QByteArray|bytes|bytearray|memoryview|str|None)");

extern "C" {static PyObject *meth_QXmlStreamWriter_raiseError(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_raiseError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamWriter, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            sipCpp->raiseError(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_raiseError, doc_QXmlStreamWriter_raiseError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamWriter_errorString(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamWriter, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_errorString, doc_QXmlStreamWriter_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamWriter_error, "error(self) -> QXmlStreamWriter.Error");

extern "C" {static PyObject *meth_QXmlStreamWriter_error(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamWriter_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamWriter, &sipCpp))
        {
            ::QXmlStreamWriter::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QXmlStreamWriter_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamWriter, sipName_error, doc_QXmlStreamWriter_error);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QXmlStreamWriter(void *, int);}
static void release_QXmlStreamWriter(void *sipCppV, int)
{
    delete reinterpret_cast< ::QXmlStreamWriter *>(sipCppV);
}


extern "C" {static void *array_QXmlStreamWriter(Py_ssize_t);}
static void *array_QXmlStreamWriter(Py_ssize_t sipNrElem)
{
    return new ::QXmlStreamWriter[sipNrElem];
}


extern "C" {static void array_delete_QXmlStreamWriter(void *);}
static void array_delete_QXmlStreamWriter(void *sipCpp)
{
    delete[] reinterpret_cast< ::QXmlStreamWriter *>(sipCpp);
}


extern "C" {static void dealloc_QXmlStreamWriter(sipSimpleWrapper *);}
static void dealloc_QXmlStreamWriter(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QXmlStreamWriter(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QXmlStreamWriter(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QXmlStreamWriter(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QXmlStreamWriter *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QXmlStreamWriter();

            return sipCpp;
        }
    }

    {
        ::QIODevice* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8", sipType_QIODevice, &a0))
        {
            sipCpp = new ::QXmlStreamWriter(a0);

            return sipCpp;
        }
    }

    {
        ::QByteArray* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J0", sipType_QByteArray, &a0, &a0State))
        {
            sipCpp = new ::QXmlStreamWriter(a0);
            sipReleaseType(a0, sipType_QByteArray, a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QXmlStreamWriter[] = {
    {sipName_autoFormatting, meth_QXmlStreamWriter_autoFormatting, METH_VARARGS, doc_QXmlStreamWriter_autoFormatting},
    {sipName_autoFormattingIndent, meth_QXmlStreamWriter_autoFormattingIndent, METH_VARARGS, doc_QXmlStreamWriter_autoFormattingIndent},
    {sipName_device, meth_QXmlStreamWriter_device, METH_VARARGS, doc_QXmlStreamWriter_device},
    {sipName_error, meth_QXmlStreamWriter_error, METH_VARARGS, doc_QXmlStreamWriter_error},
    {sipName_errorString, meth_QXmlStreamWriter_errorString, METH_VARARGS, doc_QXmlStreamWriter_errorString},
    {sipName_hasError, meth_QXmlStreamWriter_hasError, METH_VARARGS, doc_QXmlStreamWriter_hasError},
    {sipName_raiseError, meth_QXmlStreamWriter_raiseError, METH_VARARGS, doc_QXmlStreamWriter_raiseError},
    {sipName_setAutoFormatting, meth_QXmlStreamWriter_setAutoFormatting, METH_VARARGS, doc_QXmlStreamWriter_setAutoFormatting},
    {sipName_setAutoFormattingIndent, meth_QXmlStreamWriter_setAutoFormattingIndent, METH_VARARGS, doc_QXmlStreamWriter_setAutoFormattingIndent},
    {sipName_setDevice, meth_QXmlStreamWriter_setDevice, METH_VARARGS, doc_QXmlStreamWriter_setDevice},
    {sipName_setStopWritingOnError, meth_QXmlStreamWriter_setStopWritingOnError, METH_VARARGS, doc_QXmlStreamWriter_setStopWritingOnError},
    {sipName_stopWritingOnError, meth_QXmlStreamWriter_stopWritingOnError, METH_VARARGS, doc_QXmlStreamWriter_stopWritingOnError},
    {sipName_writeAttribute, meth_QXmlStreamWriter_writeAttribute, METH_VARARGS, doc_QXmlStreamWriter_writeAttribute},
    {sipName_writeAttributes, meth_QXmlStreamWriter_writeAttributes, METH_VARARGS, doc_QXmlStreamWriter_writeAttributes},
    {sipName_writeCDATA, meth_QXmlStreamWriter_writeCDATA, METH_VARARGS, doc_QXmlStreamWriter_writeCDATA},
    {sipName_writeCharacters, meth_QXmlStreamWriter_writeCharacters, METH_VARARGS, doc_QXmlStreamWriter_writeCharacters},
    {sipName_writeComment, meth_QXmlStreamWriter_writeComment, METH_VARARGS, doc_QXmlStreamWriter_writeComment},
    {sipName_writeCurrentToken, meth_QXmlStreamWriter_writeCurrentToken, METH_VARARGS, doc_QXmlStreamWriter_writeCurrentToken},
    {sipName_writeDTD, meth_QXmlStreamWriter_writeDTD, METH_VARARGS, doc_QXmlStreamWriter_writeDTD},
    {sipName_writeDefaultNamespace, meth_QXmlStreamWriter_writeDefaultNamespace, METH_VARARGS, doc_QXmlStreamWriter_writeDefaultNamespace},
    {sipName_writeEmptyElement, meth_QXmlStreamWriter_writeEmptyElement, METH_VARARGS, doc_QXmlStreamWriter_writeEmptyElement},
    {sipName_writeEndDocument, meth_QXmlStreamWriter_writeEndDocument, METH_VARARGS, doc_QXmlStreamWriter_writeEndDocument},
    {sipName_writeEndElement, meth_QXmlStreamWriter_writeEndElement, METH_VARARGS, doc_QXmlStreamWriter_writeEndElement},
    {sipName_writeEntityReference, meth_QXmlStreamWriter_writeEntityReference, METH_VARARGS, doc_QXmlStreamWriter_writeEntityReference},
    {sipName_writeNamespace, SIP_MLMETH_CAST(meth_QXmlStreamWriter_writeNamespace), METH_VARARGS|METH_KEYWORDS, doc_QXmlStreamWriter_writeNamespace},
    {sipName_writeProcessingInstruction, SIP_MLMETH_CAST(meth_QXmlStreamWriter_writeProcessingInstruction), METH_VARARGS|METH_KEYWORDS, doc_QXmlStreamWriter_writeProcessingInstruction},
    {sipName_writeStartDocument, meth_QXmlStreamWriter_writeStartDocument, METH_VARARGS, doc_QXmlStreamWriter_writeStartDocument},
    {sipName_writeStartElement, meth_QXmlStreamWriter_writeStartElement, METH_VARARGS, doc_QXmlStreamWriter_writeStartElement},
    {sipName_writeTextElement, meth_QXmlStreamWriter_writeTextElement, METH_VARARGS, doc_QXmlStreamWriter_writeTextElement}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QXmlStreamWriter[] = {
    {sipName_None_, static_cast<int>(::QXmlStreamWriter::Error::None)},
    {sipName_IO, static_cast<int>(::QXmlStreamWriter::Error::IO)},
    {sipName_Encoding, static_cast<int>(::QXmlStreamWriter::Error::Encoding)},
    {sipName_InvalidCharacter, static_cast<int>(::QXmlStreamWriter::Error::InvalidCharacter)},
    {sipName_Custom, static_cast<int>(::QXmlStreamWriter::Error::Custom)},
    {0, 0}
};

PyDoc_STRVAR(doc_QXmlStreamWriter, "\1QXmlStreamWriter()\n"
"QXmlStreamWriter(device: QIODevice|None)\n"
"QXmlStreamWriter(array: QByteArray|bytes|bytearray|memoryview)");


sipClassTypeDef sipTypeDef_QtCore_QXmlStreamWriter = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QXmlStreamWriter,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QXmlStreamWriter,
        {0, 0, 1},
        29, methods_QXmlStreamWriter,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QXmlStreamWriter, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QXmlStreamWriter,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QXmlStreamWriter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QXmlStreamWriter,
    SIP_NULLPTR,
    array_QXmlStreamWriter,
    SIP_NULLPTR,
    release_QXmlStreamWriter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QXmlStreamWriter,
    sizeof (::QXmlStreamWriter),
};
