/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNfc.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefrecord.sip"
#include <qndefrecord.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 32 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndeffilter.sip"
#include <qndeffilter.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndeffilter.sip"
#include <qndeffilter.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndeffilter.sip"
#include <qndeffilter.h>
#line 52 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefmessage.sip"
#include <qndefmessage.h>
#line 55 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefnfcsmartposterrecord.sip"
#include <qndefnfcsmartposterrecord.h>
#line 58 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefnfcsmartposterrecord.sip"
#include <qndefnfcsmartposterrecord.h>
#line 61 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefnfctextrecord.sip"
#include <qndefnfctextrecord.h>
#line 64 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefnfcurirecord.sip"
#include <qndefnfcurirecord.h>
#line 67 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldmanager.sip"
#include <qnearfieldmanager.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldtarget.sip"
#include <qnearfieldtarget.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldtarget.sip"
#include <qnearfieldtarget.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldtarget.sip"
#include <qnearfieldtarget.h>
#line 78 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtNfc[] = {
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'N', 'e', 'a', 'r', 'F', 'i', 'e', 'l', 'd', 'T', 'a', 'r', 'g', 'e', 't', ':', ':', 'A', 'c', 'c', 'e', 's', 's', 'M', 'e', 't', 'h', 'o', 'd', '>', 0,
    'Q', 'N', 'd', 'e', 'f', 'N', 'f', 'c', 'S', 'm', 'a', 'r', 't', 'P', 'o', 's', 't', 'e', 'r', 'R', 'e', 'c', 'o', 'r', 'd', ':', ':', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'N', 'e', 'a', 'r', 'F', 'i', 'e', 'l', 'd', 'M', 'a', 'n', 'a', 'g', 'e', 'r', ':', ':', 'A', 'd', 'a', 'p', 't', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'N', 'e', 'a', 'r', 'F', 'i', 'e', 'l', 'd', 'T', 'a', 'r', 'g', 'e', 't', ':', ':', 'A', 'c', 'c', 'e', 's', 's', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'Q', 'N', 'd', 'e', 'f', 'N', 'f', 'c', 'T', 'e', 'x', 't', 'R', 'e', 'c', 'o', 'r', 'd', ':', ':', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    'Q', 'N', 'd', 'e', 'f', 'R', 'e', 'c', 'o', 'r', 'd', ':', ':', 'T', 'y', 'p', 'e', 'N', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'N', 'e', 'a', 'r', 'F', 'i', 'e', 'l', 'd', 'T', 'a', 'r', 'g', 'e', 't', ':', ':', 'R', 'e', 'q', 'u', 'e', 's', 't', 'I', 'd', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'N', 'd', 'e', 'f', 'N', 'f', 'c', 'I', 'c', 'o', 'n', 'R', 'e', 'c', 'o', 'r', 'd', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'N', 'd', 'e', 'f', 'N', 'f', 'c', 'T', 'e', 'x', 't', 'R', 'e', 'c', 'o', 'r', 'd', '>', 0,
    'Q', 'N', 'd', 'e', 'f', 'N', 'f', 'c', 'S', 'm', 'a', 'r', 't', 'P', 'o', 's', 't', 'e', 'r', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'P', 'y', 'Q', 't', '6', '.', 's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 'N', 'e', 'a', 'r', 'F', 'i', 'e', 'l', 'd', 'T', 'a', 'r', 'g', 'e', 't', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'w', 'a', 'i', 't', 'F', 'o', 'r', 'R', 'e', 'q', 'u', 'e', 's', 't', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'd', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'N', 'e', 'a', 'r', 'F', 'i', 'e', 'l', 'd', 'T', 'a', 'r', 'g', 'e', 't', ':', ':', 'T', 'y', 'p', 'e', 0,
    'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'T', 'a', 'r', 'g', 'e', 't', 'E', 'r', 'r', 'o', 'r', 0,
    't', 'a', 'r', 'g', 'e', 't', 'D', 'e', 't', 'e', 'c', 't', 'i', 'o', 'n', 'S', 't', 'o', 'p', 'p', 'e', 'd', 0,
    'C', 'h', 'e', 'c', 'k', 's', 'u', 'm', 'M', 'i', 's', 'm', 'a', 't', 'c', 'h', 'E', 'r', 'r', 'o', 'r', 0,
    'T', 'a', 'g', 'T', 'y', 'p', 'e', 'S', 'p', 'e', 'c', 'i', 'f', 'i', 'c', 'A', 'c', 'c', 'e', 's', 's', 0,
    'T', 'a', 'r', 'g', 'e', 't', 'O', 'u', 't', 'O', 'f', 'R', 'a', 'n', 'g', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    's', 't', 'a', 'r', 't', 'T', 'a', 'r', 'g', 'e', 't', 'D', 'e', 't', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'N', 'd', 'e', 'f', 'M', 'e', 's', 's', 'a', 'g', 'e', '>', 0,
    'Q', 'N', 'd', 'e', 'f', 'F', 'i', 'l', 't', 'e', 'r', ':', ':', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'a', 'd', 'a', 'p', 't', 'e', 'r', 'S', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 't', 'o', 'p', 'T', 'a', 'r', 'g', 'e', 't', 'D', 'e', 't', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'N', 'd', 'e', 'f', 'R', 'e', 'c', 'o', 'r', 'd', '>', 0,
    'Q', 'N', 'd', 'e', 'f', 'N', 'f', 'c', 'I', 'c', 'o', 'n', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'Q', 'N', 'd', 'e', 'f', 'N', 'f', 'c', 'T', 'e', 'x', 't', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'I', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'N', 'd', 'e', 'f', 'N', 'f', 'c', 'U', 'r', 'i', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'Q', 'N', 'e', 'a', 'r', 'F', 'i', 'e', 'l', 'd', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'U', 'n', 's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', 'A', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'T', 'y', 'p', 'e', 'N', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'w', 'r', 'i', 't', 'e', 'N', 'd', 'e', 'f', 'M', 'e', 's', 's', 'a', 'g', 'e', 's', 0,
    'Q', 'N', 'e', 'a', 'r', 'F', 'i', 'e', 'l', 'd', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'm', 'a', 'x', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'r', 'e', 'a', 'd', 'N', 'd', 'e', 'f', 'M', 'e', 's', 's', 'a', 'g', 'e', 's', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'd', 0,
    'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'N', 'o', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'n', 'd', 'e', 'f', 'M', 'e', 's', 's', 'a', 'g', 'e', 'R', 'e', 'a', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 0,
    'N', 'd', 'e', 'f', 'W', 'r', 'i', 't', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'a', 'r', 'y', 'T', 'a', 'g', 0,
    'h', 'a', 's', 'N', 'd', 'e', 'f', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    't', 'a', 'r', 'g', 'e', 't', 'D', 'e', 't', 'e', 'c', 't', 'e', 'd', 0,
    't', 'y', 'p', 'e', 'N', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'N', 'd', 'e', 'f', 'R', 'e', 'a', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'A', 'c', 'c', 'e', 's', 's', 0,
    'a', 'c', 'c', 'e', 's', 's', 'M', 'e', 't', 'h', 'o', 'd', 's', 0,
    'f', 'r', 'o', 'm', 'B', 'y', 't', 'e', 'A', 'r', 'r', 'a', 'y', 0,
    's', 'e', 't', 'O', 'r', 'd', 'e', 'r', 'M', 'a', 't', 'c', 'h', 0,
    'C', 'o', 'm', 'm', 'a', 'n', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'N', 'f', 'c', 'T', 'a', 'g', 'T', 'y', 'p', 'e', '4', 'A', 0,
    'N', 'f', 'c', 'T', 'a', 'g', 'T', 'y', 'p', 'e', '4', 'B', 0,
    'Q', 'N', 'd', 'e', 'f', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    'T', 'i', 'm', 'e', 'o', 'u', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'a', 'c', 'c', 'e', 's', 's', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 0,
    'e', 'r', 'r', 'o', 'r', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    't', 'i', 't', 'l', 'e', 'R', 'e', 'c', 'o', 'r', 'd', 's', 0,
    'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'R', 't', 'd', 0,
    'N', 'f', 'c', 'T', 'a', 'g', 'T', 'y', 'p', 'e', '1', 0,
    'N', 'f', 'c', 'T', 'a', 'g', 'T', 'y', 'p', 'e', '2', 0,
    'N', 'f', 'c', 'T', 'a', 'g', 'T', 'y', 'p', 'e', '3', 0,
    'N', 'f', 'c', 'T', 'a', 'g', 'T', 'y', 'p', 'e', '4', 0,
    'P', 'y', 'Q', 't', '6', '.', 'Q', 't', 'N', 'f', 'c', 0,
    'Q', 'N', 'd', 'e', 'f', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'N', 'd', 'e', 'f', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    '_', '_', 'd', 'e', 'l', 'i', 't', 'e', 'm', '_', '_', 0,
    '_', '_', 'g', 'e', 't', 'i', 't', 'e', 'm', '_', '_', 0,
    '_', '_', 's', 'e', 't', 'i', 't', 'e', 'm', '_', '_', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'h', 'a', 's', 'T', 'y', 'p', 'e', 'I', 'n', 'f', 'o', 0,
    'i', 'c', 'o', 'n', 'R', 'e', 'c', 'o', 'r', 'd', 's', 0,
    'i', 's', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'r', 'e', 'c', 'o', 'r', 'd', 'C', 'o', 'u', 'n', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'T', 'i', 't', 'l', 'e', 0,
    's', 'e', 'n', 'd', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    's', 'e', 't', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'T', 'y', 'p', 'e', 'I', 'n', 'f', 'o', 0,
    't', 'i', 't', 'l', 'e', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    't', 'o', 'B', 'y', 't', 'e', 'A', 'r', 'r', 'a', 'y', 0,
    'E', 'd', 'i', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'N', 'd', 'e', 'f', 'A', 'c', 'c', 'e', 's', 's', 0,
    'S', 'a', 'v', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'T', 'u', 'r', 'n', 'i', 'n', 'g', 'O', 'f', 'f', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 0,
    'i', 'c', 'o', 'n', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'o', 'r', 'd', 'e', 'r', 'M', 'a', 't', 'c', 'h', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'I', 'c', 'o', 'n', 0,
    's', 'e', 't', 'P', 'a', 'y', 'l', 'o', 'a', 'd', 0,
    't', 'a', 'r', 'g', 'e', 't', 'L', 'o', 's', 't', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    't', 'i', 't', 'l', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'A', 'n', 'y', 'A', 'c', 'c', 'e', 's', 's', 0,
    'M', 'i', 'f', 'a', 'r', 'e', 'T', 'a', 'g', 0,
    'T', 'u', 'r', 'n', 'i', 'n', 'g', 'O', 'n', 0,
    'h', 'a', 's', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'i', 'c', 'o', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'i', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'e', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 's', 0,
    'u', 'r', 'i', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'D', 'o', 'A', 'c', 't', 'i', 'o', 'n', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    'a', 'd', 'd', 'T', 'i', 't', 'l', 'e', 0,
    'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    'h', 'a', 's', 'T', 'i', 't', 'l', 'e', 0,
    'm', 'i', 'm', 'e', 't', 'y', 'p', 'e', 0,
    'r', 'e', 'c', 'o', 'r', 'd', 'A', 't', 0,
    'r', 'e', 'f', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'I', 'c', 'o', 'n', 's', 0,
    't', 'y', 'p', 'e', 'I', 'n', 'f', 'o', 0,
    'N', 'o', 'E', 'r', 'r', 'o', 'r', 0,
    'O', 'f', 'f', 'l', 'i', 'n', 'e', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    '_', '_', 'l', 'e', 'n', '_', '_', 0,
    'a', 'd', 'd', 'I', 'c', 'o', 'n', 0,
    'h', 'a', 's', 'I', 'c', 'o', 'n', 0,
    'h', 'a', 's', 'S', 'i', 'z', 'e', 0,
    'i', 's', 'E', 'm', 'p', 't', 'y', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 0,
    'p', 'a', 'y', 'l', 'o', 'a', 'd', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'T', 'y', 'p', 'e', 0,
    'N', 'f', 'c', 'R', 't', 'd', 0,
    'O', 'n', 'l', 'i', 'n', 'e', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'g', 'e', '_', '_', 0,
    '_', '_', 'l', 't', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    'a', 'c', 't', 'i', 'o', 'n', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    's', 'e', 't', 'U', 'r', 'i', 0,
    'U', 't', 'f', '1', '6', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'm', 'a', 't', 'c', 'h', 0,
    'm', 's', 'e', 'c', 's', 0,
    's', 'e', 't', 'I', 'd', 0,
    't', 'i', 't', 'l', 'e', 0,
    'M', 'i', 'm', 'e', 0,
    'U', 't', 'f', '8', 0,
    'd', 'a', 't', 'a', 0,
    'i', 'c', 'o', 'n', 0,
    's', 'i', 'z', 'e', 0,
    't', 'e', 'x', 't', 0,
    'm', 'a', 'x', 0,
    'm', 'i', 'n', 0,
    'u', 'i', 'd', 0,
    'u', 'r', 'i', 0,
};
#line 99 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldmanager.sip"
// Imports from QtCore.
pyqt6_qtnfc_get_pyqtslot_parts_t pyqt6_qtnfc_get_pyqtslot_parts;
#line 251 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"

bool sipVH_QtNfc_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtNfc_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtNfc_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtNfc_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtNfc_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtNfc_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QNdefRecord(void **);}
static const sipTypeDef *sipSubClass_QNdefRecord(void **sipCppRet)
{
    ::QNdefRecord *sipCpp = reinterpret_cast< ::QNdefRecord *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 32 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefrecord.sip"
    QByteArray ndef_type = sipCpp->type();
    
    switch (sipCpp->typeNameFormat())
    {
    case QNdefRecord::NfcRtd:
        if (ndef_type == "Sp")
            sipType = sipType_QNdefNfcSmartPosterRecord;
        else if (ndef_type == "T")
            sipType = sipType_QNdefNfcTextRecord;
        else if (ndef_type == "U")
            sipType = sipType_QNdefNfcUriRecord;
        else
            sipType = 0;
    
        break;
    
    case QNdefRecord::Mime:
        if (ndef_type == "")
            sipType = sipType_QNdefNfcIconRecord;
        else
            sipType = 0;
    
        break;
    
    default:
        sipType = 0;
    }
#line 329 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"

    return sipType;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QNearFieldManager(void **);}
static const sipTypeDef *sipSubClass_QNearFieldManager(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 32 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldmanager.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QNearFieldManager, &sipType_QNearFieldManager, -1, 1},
        {sipName_QNearFieldTarget, &sipType_QNearFieldTarget, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 369 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"

    return sipType;
}
static sipEnumTypeDef enumTypes[] = {
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QNdefNfcSmartPosterRecord__Action, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Action, 9, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QNdefNfcTextRecord__Encoding, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Encoding, 11, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QNdefRecord__TypeNameFormat, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_TypeNameFormat, 14, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QNearFieldManager__AdapterState, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_AdapterState, 16, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QNearFieldTarget__AccessMethod, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_AccessMethod, 18, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QNearFieldTarget__Error, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Error, 18, 13, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QNearFieldTarget__Type, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Type, 18, 8, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtNfc[] = {
    &sipTypeDef_QtNfc_QFlags_0100QNearFieldTarget_AccessMethod.mtd_base,
    &sipTypeDef_QtNfc_QList_0100QNdefMessage.mtd_base,
    &sipTypeDef_QtNfc_QList_0100QNdefNfcIconRecord.mtd_base,
    &sipTypeDef_QtNfc_QList_0100QNdefNfcTextRecord.mtd_base,
    &sipTypeDef_QtNfc_QList_0100QNdefRecord.mtd_base,
    &sipTypeDef_QtNfc_QNdefFilter.ctd_base,
    &sipTypeDef_QtNfc_QNdefFilter_Record.ctd_base,
    &sipTypeDef_QtNfc_QNdefMessage.ctd_base,
    &sipTypeDef_QtNfc_QNdefNfcIconRecord.ctd_base,
    &sipTypeDef_QtNfc_QNdefNfcSmartPosterRecord.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtNfc_QNdefNfcTextRecord.ctd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtNfc_QNdefNfcUriRecord.ctd_base,
    &sipTypeDef_QtNfc_QNdefRecord.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtNfc_QNearFieldManager.ctd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_QtNfc_QNearFieldTarget.ctd_base,
    &enumTypes[4].etd_base,
    &enumTypes[5].etd_base,
    &sipTypeDef_QtNfc_QNearFieldTarget_RequestId.ctd_base,
    &enumTypes[6].etd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"QNearFieldTarget::AccessMethods", "QFlags<QNearFieldTarget::AccessMethod>"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtNfc_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QEvent"},
    {"QMetaMethod"},
    {"QObject"},
    {"QString"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtNfc_QtCore[] = {
    {"PyQt6"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt6.QtCore", sipImportedTypes_QtNfc_QtCore, sipImportedVirtErrorHandlers_QtNfc_QtCore, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QNdefRecord, {14, 255, 0}, SIP_NULLPTR},
    {sipSubClass_QNearFieldManager, {4, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtNfc = {
    SIP_NULLPTR,
    8,
    sipNameNr_PyQt6_QtNfc,
    0,
    sipStrings_QtNfc,
    importsTable,
    23,
    sipExportedTypes_QtNfc,
    SIP_NULLPTR,
    1,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtNfc;

sip_qt_metaobject_func sip_QtNfc_qt_metaobject;
sip_qt_metacall_func sip_QtNfc_qt_metacall;
sip_qt_metacast_func sip_QtNfc_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtNfc()
#else
PyMODINIT_FUNC PyInit_QtNfc()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt6.QtNfc",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt6.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt6.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtNfc = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt6.sip._C_API"));

    if (sipAPI_QtNfc == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtNfc, 13, 8, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtNfc_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtNfc_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtNfc_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtNfc_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtNfc, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }
    qMetaTypeId<::QNearFieldTarget::Error>();
    qMetaTypeId<::QNearFieldTarget::AccessMethod>();
    qMetaTypeId<::QNearFieldTarget::Type>();
    qMetaTypeId<::QNearFieldManager::AdapterState>();
    qMetaTypeId<::QNdefRecord::TypeNameFormat>();
    qMetaTypeId<::QNdefNfcTextRecord::Encoding>();
    qMetaTypeId<::QNdefNfcSmartPosterRecord::Action>();
    qMetaTypeId<QFlags< ::QNearFieldTarget::AccessMethod>>();
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldmanager.sip"
// Imports from QtCore.
pyqt6_qtnfc_get_pyqtslot_parts = (pyqt6_qtnfc_get_pyqtslot_parts_t)sipImportSymbol("pyqt6_get_pyqtslot_parts");
Q_ASSERT(pyqt6_qtnfc_get_pyqtslot_parts);
#line 585 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfccmodule.cpp"

    return sipModule;
}
