/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 46 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpointingdevice.sip"
#include <qpointingdevice.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qinputdevice.sip"
#include <qinputdevice.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpointingdevice.sip"
#include <qpointingdevice.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointingDevice.cpp"


class sipQPointingDevice : public ::QPointingDevice
{
public:
    sipQPointingDevice(const ::QString&, ::qint64, ::QInputDevice::DeviceType, ::QPointingDevice::PointerType, ::QInputDevice::Capabilities, int, int, const ::QString&, ::QPointingDeviceUniqueId, ::QObject*);
    sipQPointingDevice(::QObject*);
    virtual ~sipQPointingDevice();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPointingDevice(const sipQPointingDevice &);
    sipQPointingDevice &operator = (const sipQPointingDevice &);

    char sipPyMethods[7];
};

sipQPointingDevice::sipQPointingDevice(const ::QString& a0, ::qint64 a1, ::QInputDevice::DeviceType a2, ::QPointingDevice::PointerType a3, ::QInputDevice::Capabilities a4, int a5, int a6, const ::QString& a7, ::QPointingDeviceUniqueId a8, ::QObject*a9): ::QPointingDevice(a0, a1, a2, a3, a4, a5, a6, a7, a8, a9), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPointingDevice::sipQPointingDevice(::QObject*a0): ::QPointingDevice(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPointingDevice::~sipQPointingDevice()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQPointingDevice::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtGui_qt_metaobject(sipPySelf, sipType_QPointingDevice);

    return ::QPointingDevice::metaObject();
}

int sipQPointingDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QPointingDevice::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtGui_qt_metacall(sipPySelf, sipType_QPointingDevice, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQPointingDevice::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtGui_qt_metacast(sipPySelf, sipType_QPointingDevice, _clname, &sipCpp) ? sipCpp : ::QPointingDevice::qt_metacast(_clname));
}

void sipQPointingDevice::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QPointingDevice::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPointingDevice::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QPointingDevice::connectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPointingDevice::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QPointingDevice::customEvent(a0);
        return;
    }

    extern void sipVH_QtGui_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtGui_6(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPointingDevice::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QPointingDevice::childEvent(a0);
        return;
    }

    extern void sipVH_QtGui_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtGui_7(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPointingDevice::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QPointingDevice::timerEvent(a0);
        return;
    }

    extern void sipVH_QtGui_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtGui_8(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPointingDevice::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QPointingDevice::eventFilter(a0, a1);

    extern bool sipVH_QtGui_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtGui_9(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQPointingDevice::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QPointingDevice::event(a0);

    extern bool sipVH_QtGui_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtGui_10(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QPointingDevice_pointerType, "pointerType(self) -> QPointingDevice.PointerType");

extern "C" {static PyObject *meth_QPointingDevice_pointerType(PyObject *, PyObject *);}
static PyObject *meth_QPointingDevice_pointerType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointingDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointingDevice, &sipCpp))
        {
            ::QPointingDevice::PointerType sipRes;

            sipRes = sipCpp->pointerType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPointingDevice_PointerType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointingDevice, sipName_pointerType, doc_QPointingDevice_pointerType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointingDevice_maximumPoints, "maximumPoints(self) -> int");

extern "C" {static PyObject *meth_QPointingDevice_maximumPoints(PyObject *, PyObject *);}
static PyObject *meth_QPointingDevice_maximumPoints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointingDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointingDevice, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maximumPoints();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointingDevice, sipName_maximumPoints, doc_QPointingDevice_maximumPoints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointingDevice_buttonCount, "buttonCount(self) -> int");

extern "C" {static PyObject *meth_QPointingDevice_buttonCount(PyObject *, PyObject *);}
static PyObject *meth_QPointingDevice_buttonCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointingDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointingDevice, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->buttonCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointingDevice, sipName_buttonCount, doc_QPointingDevice_buttonCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointingDevice_uniqueId, "uniqueId(self) -> QPointingDeviceUniqueId");

extern "C" {static PyObject *meth_QPointingDevice_uniqueId(PyObject *, PyObject *);}
static PyObject *meth_QPointingDevice_uniqueId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointingDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointingDevice, &sipCpp))
        {
            ::QPointingDeviceUniqueId*sipRes;

            sipRes = new ::QPointingDeviceUniqueId(sipCpp->uniqueId());

            return sipConvertFromNewType(sipRes, sipType_QPointingDeviceUniqueId, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointingDevice, sipName_uniqueId, doc_QPointingDevice_uniqueId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointingDevice_primaryPointingDevice, "primaryPointingDevice(seatName: str|None = '') -> QPointingDevice|None");

extern "C" {static PyObject *meth_QPointingDevice_primaryPointingDevice(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPointingDevice_primaryPointingDevice(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;

        static const char *sipKwdList[] = {
            sipName_seatName,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "C|J1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            const ::QPointingDevice*sipRes;

            sipRes = ::QPointingDevice::primaryPointingDevice(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(const_cast< ::QPointingDevice *>(sipRes), sipType_QPointingDevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointingDevice, sipName_primaryPointingDevice, doc_QPointingDevice_primaryPointingDevice);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QPointingDevice___ne__(PyObject *, PyObject *);}
static PyObject *slot_QPointingDevice___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPointingDevice *sipCpp = reinterpret_cast< ::QPointingDevice *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPointingDevice));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointingDevice* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPointingDevice, &a0))
        {
            bool sipRes;

            sipRes = !sipCpp->::QPointingDevice::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, ne_slot, sipType_QPointingDevice, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPointingDevice___eq__(PyObject *, PyObject *);}
static PyObject *slot_QPointingDevice___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPointingDevice *sipCpp = reinterpret_cast< ::QPointingDevice *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPointingDevice));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointingDevice* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPointingDevice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPointingDevice::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, eq_slot, sipType_QPointingDevice, sipSelf, sipArg);
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPointingDevice(void *, const sipTypeDef *);}
static void *cast_QPointingDevice(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPointingDevice *sipCpp = reinterpret_cast< ::QPointingDevice *>(sipCppV);

    if (targetType == sipType_QPointingDevice)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QInputDevice)->ctd_cast(static_cast< ::QInputDevice *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPointingDevice(void *, int);}
static void release_QPointingDevice(void *sipCppV, int)
{
    ::QPointingDevice *sipCpp = reinterpret_cast< ::QPointingDevice *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QPointingDevice(Py_ssize_t);}
static void *array_QPointingDevice(Py_ssize_t sipNrElem)
{
    return new ::QPointingDevice[sipNrElem];
}


extern "C" {static void array_delete_QPointingDevice(void *);}
static void array_delete_QPointingDevice(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPointingDevice *>(sipCpp);
}


extern "C" {static void dealloc_QPointingDevice(sipSimpleWrapper *);}
static void dealloc_QPointingDevice(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPointingDevice *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPointingDevice(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPointingDevice(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPointingDevice(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQPointingDevice *sipCpp = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::qint64 a1;
        ::QInputDevice::DeviceType a2;
        ::QPointingDevice::PointerType a3;
        ::QInputDevice::Capabilities* a4;
        int a4State = 0;
        int a5;
        int a6;
        const ::QString& a7def = QString();
        const ::QString* a7 = &a7def;
        int a7State = 0;
        ::QPointingDeviceUniqueId a8def = QPointingDeviceUniqueId();
        ::QPointingDeviceUniqueId* a8 = &a8def;
        ::QObject* a9 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_seatName,
            sipName_uniqueId,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1nEEJ1ii|J1J9JH", sipType_QString, &a0, &a0State, &a1, sipType_QInputDevice_DeviceType, &a2, sipType_QPointingDevice_PointerType, &a3, sipType_QFlags_0100QInputDevice_Capability, &a4, &a4State, &a5, &a6, sipType_QString, &a7, &a7State, sipType_QPointingDeviceUniqueId, &a8, sipType_QObject, &a9, sipOwner))
        {
            sipCpp = new sipQPointingDevice(*a0, a1, a2, a3, *a4, a5, a6, *a7, *a8, a9);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(a4, sipType_QFlags_0100QInputDevice_Capability, a4State);
            sipReleaseType(const_cast< ::QString *>(a7), sipType_QString, a7State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQPointingDevice(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPointingDevice[] = {{121, 255, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QPointingDevice[] = {
    {(void *)slot_QPointingDevice___ne__, ne_slot},
    {(void *)slot_QPointingDevice___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QPointingDevice[] = {
    {sipName_buttonCount, meth_QPointingDevice_buttonCount, METH_VARARGS, doc_QPointingDevice_buttonCount},
    {sipName_maximumPoints, meth_QPointingDevice_maximumPoints, METH_VARARGS, doc_QPointingDevice_maximumPoints},
    {sipName_pointerType, meth_QPointingDevice_pointerType, METH_VARARGS, doc_QPointingDevice_pointerType},
    {sipName_primaryPointingDevice, SIP_MLMETH_CAST(meth_QPointingDevice_primaryPointingDevice), METH_VARARGS|METH_KEYWORDS, doc_QPointingDevice_primaryPointingDevice},
    {sipName_uniqueId, meth_QPointingDevice_uniqueId, METH_VARARGS, doc_QPointingDevice_uniqueId}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QPointingDevice[] = {
    {sipName_Unknown, static_cast<int>(::QPointingDevice::PointerType::Unknown)},
    {sipName_Generic, static_cast<int>(::QPointingDevice::PointerType::Generic)},
    {sipName_Finger, static_cast<int>(::QPointingDevice::PointerType::Finger)},
    {sipName_Pen, static_cast<int>(::QPointingDevice::PointerType::Pen)},
    {sipName_Eraser, static_cast<int>(::QPointingDevice::PointerType::Eraser)},
    {sipName_Cursor, static_cast<int>(::QPointingDevice::PointerType::Cursor)},
    {sipName_AllPointerTypes, static_cast<int>(::QPointingDevice::PointerType::AllPointerTypes)},
    {0, 0}
};

PyDoc_STRVAR(doc_QPointingDevice, "\1QPointingDevice(name: str|None, systemId: int, devType: QInputDevice.DeviceType, pType: QPointingDevice.PointerType, caps: QInputDevice.Capability, maxPoints: int, buttonCount: int, seatName: str|None = '', uniqueId: QPointingDeviceUniqueId = QPointingDeviceUniqueId(), parent: QObject|None = None)\n"
"QPointingDevice(parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QPointingDevice = {
    &::QPointingDevice::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QPointingDevice = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPointingDevice,
        SIP_NULLPTR,
        &plugin_QPointingDevice,
    },
    {
        sipNameNr_QPointingDevice,
        {0, 0, 1},
        5, methods_QPointingDevice,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QPointingDevice, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPointingDevice,
    -1,
    -1,
    supers_QPointingDevice,
    slots_QPointingDevice,
    init_type_QPointingDevice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPointingDevice,
    SIP_NULLPTR,
    array_QPointingDevice,
    SIP_NULLPTR,
    release_QPointingDevice,
    cast_QPointingDevice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPointingDevice,
    sizeof (::QPointingDevice),
};
