/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPdf.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfdocumentrenderoptions.sip"
#include <qpdfdocumentrenderoptions.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfDocumentRenderOptions.cpp"

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfDocumentRenderOptions.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfDocumentRenderOptions.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfDocumentRenderOptions.cpp"


PyDoc_STRVAR(doc_QPdfDocumentRenderOptions_rotation, "rotation(self) -> QPdfDocumentRenderOptions.Rotation");

extern "C" {static PyObject *meth_QPdfDocumentRenderOptions_rotation(PyObject *, PyObject *);}
static PyObject *meth_QPdfDocumentRenderOptions_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfDocumentRenderOptions *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfDocumentRenderOptions, &sipCpp))
        {
            ::QPdfDocumentRenderOptions::Rotation sipRes;

            sipRes = sipCpp->rotation();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPdfDocumentRenderOptions_Rotation);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfDocumentRenderOptions, sipName_rotation, doc_QPdfDocumentRenderOptions_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfDocumentRenderOptions_setRotation, "setRotation(self, r: QPdfDocumentRenderOptions.Rotation)");

extern "C" {static PyObject *meth_QPdfDocumentRenderOptions_setRotation(PyObject *, PyObject *);}
static PyObject *meth_QPdfDocumentRenderOptions_setRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfDocumentRenderOptions::Rotation a0;
        ::QPdfDocumentRenderOptions *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPdfDocumentRenderOptions, &sipCpp, sipType_QPdfDocumentRenderOptions_Rotation, &a0))
        {
            sipCpp->setRotation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfDocumentRenderOptions, sipName_setRotation, doc_QPdfDocumentRenderOptions_setRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfDocumentRenderOptions_renderFlags, "renderFlags(self) -> QPdfDocumentRenderOptions.RenderFlag");

extern "C" {static PyObject *meth_QPdfDocumentRenderOptions_renderFlags(PyObject *, PyObject *);}
static PyObject *meth_QPdfDocumentRenderOptions_renderFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfDocumentRenderOptions *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfDocumentRenderOptions, &sipCpp))
        {
            ::QPdfDocumentRenderOptions::RenderFlags*sipRes;

            sipRes = new ::QPdfDocumentRenderOptions::RenderFlags(sipCpp->renderFlags());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QPdfDocumentRenderOptions_RenderFlag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfDocumentRenderOptions, sipName_renderFlags, doc_QPdfDocumentRenderOptions_renderFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfDocumentRenderOptions_setRenderFlags, "setRenderFlags(self, r: QPdfDocumentRenderOptions.RenderFlag)");

extern "C" {static PyObject *meth_QPdfDocumentRenderOptions_setRenderFlags(PyObject *, PyObject *);}
static PyObject *meth_QPdfDocumentRenderOptions_setRenderFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfDocumentRenderOptions::RenderFlags* a0;
        int a0State = 0;
        ::QPdfDocumentRenderOptions *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPdfDocumentRenderOptions, &sipCpp, sipType_QFlags_0100QPdfDocumentRenderOptions_RenderFlag, &a0, &a0State))
        {
            sipCpp->setRenderFlags(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QPdfDocumentRenderOptions_RenderFlag, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfDocumentRenderOptions, sipName_setRenderFlags, doc_QPdfDocumentRenderOptions_setRenderFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfDocumentRenderOptions_scaledClipRect, "scaledClipRect(self) -> QRect");

extern "C" {static PyObject *meth_QPdfDocumentRenderOptions_scaledClipRect(PyObject *, PyObject *);}
static PyObject *meth_QPdfDocumentRenderOptions_scaledClipRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfDocumentRenderOptions *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfDocumentRenderOptions, &sipCpp))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->scaledClipRect());

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfDocumentRenderOptions, sipName_scaledClipRect, doc_QPdfDocumentRenderOptions_scaledClipRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfDocumentRenderOptions_setScaledClipRect, "setScaledClipRect(self, r: QRect)");

extern "C" {static PyObject *meth_QPdfDocumentRenderOptions_setScaledClipRect(PyObject *, PyObject *);}
static PyObject *meth_QPdfDocumentRenderOptions_setScaledClipRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRect* a0;
        ::QPdfDocumentRenderOptions *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPdfDocumentRenderOptions, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->setScaledClipRect(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfDocumentRenderOptions, sipName_setScaledClipRect, doc_QPdfDocumentRenderOptions_setScaledClipRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfDocumentRenderOptions_scaledSize, "scaledSize(self) -> QSize");

extern "C" {static PyObject *meth_QPdfDocumentRenderOptions_scaledSize(PyObject *, PyObject *);}
static PyObject *meth_QPdfDocumentRenderOptions_scaledSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfDocumentRenderOptions *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfDocumentRenderOptions, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->scaledSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfDocumentRenderOptions, sipName_scaledSize, doc_QPdfDocumentRenderOptions_scaledSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfDocumentRenderOptions_setScaledSize, "setScaledSize(self, s: QSize)");

extern "C" {static PyObject *meth_QPdfDocumentRenderOptions_setScaledSize(PyObject *, PyObject *);}
static PyObject *meth_QPdfDocumentRenderOptions_setScaledSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QPdfDocumentRenderOptions *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPdfDocumentRenderOptions, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setScaledSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfDocumentRenderOptions, sipName_setScaledSize, doc_QPdfDocumentRenderOptions_setScaledSize);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QPdfDocumentRenderOptions___eq__(PyObject *, PyObject *);}
static PyObject *slot_QPdfDocumentRenderOptions___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPdfDocumentRenderOptions *sipCpp = reinterpret_cast< ::QPdfDocumentRenderOptions *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPdfDocumentRenderOptions));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfDocumentRenderOptions* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPdfDocumentRenderOptions, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPdf, eq_slot, sipType_QPdfDocumentRenderOptions, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPdfDocumentRenderOptions___ne__(PyObject *, PyObject *);}
static PyObject *slot_QPdfDocumentRenderOptions___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPdfDocumentRenderOptions *sipCpp = reinterpret_cast< ::QPdfDocumentRenderOptions *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPdfDocumentRenderOptions));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfDocumentRenderOptions* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPdfDocumentRenderOptions, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPdf, ne_slot, sipType_QPdfDocumentRenderOptions, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QPdfDocumentRenderOptions(void *, int);}
static void release_QPdfDocumentRenderOptions(void *sipCppV, int)
{
    delete reinterpret_cast< ::QPdfDocumentRenderOptions *>(sipCppV);
}


extern "C" {static void *array_QPdfDocumentRenderOptions(Py_ssize_t);}
static void *array_QPdfDocumentRenderOptions(Py_ssize_t sipNrElem)
{
    return new ::QPdfDocumentRenderOptions[sipNrElem];
}


extern "C" {static void array_delete_QPdfDocumentRenderOptions(void *);}
static void array_delete_QPdfDocumentRenderOptions(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPdfDocumentRenderOptions *>(sipCpp);
}


extern "C" {static void assign_QPdfDocumentRenderOptions(void *, Py_ssize_t, void *);}
static void assign_QPdfDocumentRenderOptions(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPdfDocumentRenderOptions *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPdfDocumentRenderOptions *>(sipSrc);
}


extern "C" {static void *copy_QPdfDocumentRenderOptions(const void *, Py_ssize_t);}
static void *copy_QPdfDocumentRenderOptions(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPdfDocumentRenderOptions(reinterpret_cast<const ::QPdfDocumentRenderOptions *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPdfDocumentRenderOptions(sipSimpleWrapper *);}
static void dealloc_QPdfDocumentRenderOptions(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPdfDocumentRenderOptions(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QPdfDocumentRenderOptions(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPdfDocumentRenderOptions(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QPdfDocumentRenderOptions *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QPdfDocumentRenderOptions();

            return sipCpp;
        }
    }

    {
        const ::QPdfDocumentRenderOptions* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPdfDocumentRenderOptions, &a0))
        {
            sipCpp = new ::QPdfDocumentRenderOptions(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QPdfDocumentRenderOptions[] = {
    {(void *)slot_QPdfDocumentRenderOptions___eq__, eq_slot},
    {(void *)slot_QPdfDocumentRenderOptions___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QPdfDocumentRenderOptions[] = {
    {sipName_renderFlags, meth_QPdfDocumentRenderOptions_renderFlags, METH_VARARGS, doc_QPdfDocumentRenderOptions_renderFlags},
    {sipName_rotation, meth_QPdfDocumentRenderOptions_rotation, METH_VARARGS, doc_QPdfDocumentRenderOptions_rotation},
    {sipName_scaledClipRect, meth_QPdfDocumentRenderOptions_scaledClipRect, METH_VARARGS, doc_QPdfDocumentRenderOptions_scaledClipRect},
    {sipName_scaledSize, meth_QPdfDocumentRenderOptions_scaledSize, METH_VARARGS, doc_QPdfDocumentRenderOptions_scaledSize},
    {sipName_setRenderFlags, meth_QPdfDocumentRenderOptions_setRenderFlags, METH_VARARGS, doc_QPdfDocumentRenderOptions_setRenderFlags},
    {sipName_setRotation, meth_QPdfDocumentRenderOptions_setRotation, METH_VARARGS, doc_QPdfDocumentRenderOptions_setRotation},
    {sipName_setScaledClipRect, meth_QPdfDocumentRenderOptions_setScaledClipRect, METH_VARARGS, doc_QPdfDocumentRenderOptions_setScaledClipRect},
    {sipName_setScaledSize, meth_QPdfDocumentRenderOptions_setScaledSize, METH_VARARGS, doc_QPdfDocumentRenderOptions_setScaledSize}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QPdfDocumentRenderOptions[] = {
    {sipName_None_, static_cast<int>(::QPdfDocumentRenderOptions::RenderFlag::None)},
    {sipName_Annotations, static_cast<int>(::QPdfDocumentRenderOptions::RenderFlag::Annotations)},
    {sipName_OptimizedForLcd, static_cast<int>(::QPdfDocumentRenderOptions::RenderFlag::OptimizedForLcd)},
    {sipName_Grayscale, static_cast<int>(::QPdfDocumentRenderOptions::RenderFlag::Grayscale)},
    {sipName_ForceHalftone, static_cast<int>(::QPdfDocumentRenderOptions::RenderFlag::ForceHalftone)},
    {sipName_TextAliased, static_cast<int>(::QPdfDocumentRenderOptions::RenderFlag::TextAliased)},
    {sipName_ImageAliased, static_cast<int>(::QPdfDocumentRenderOptions::RenderFlag::ImageAliased)},
    {sipName_PathAliased, static_cast<int>(::QPdfDocumentRenderOptions::RenderFlag::PathAliased)},
    {sipName_None_, static_cast<int>(::QPdfDocumentRenderOptions::Rotation::None)},
    {sipName_Clockwise90, static_cast<int>(::QPdfDocumentRenderOptions::Rotation::Clockwise90)},
    {sipName_Clockwise180, static_cast<int>(::QPdfDocumentRenderOptions::Rotation::Clockwise180)},
    {sipName_Clockwise270, static_cast<int>(::QPdfDocumentRenderOptions::Rotation::Clockwise270)},
    {0, 0}
};

PyDoc_STRVAR(doc_QPdfDocumentRenderOptions, "\1QPdfDocumentRenderOptions()\n"
"QPdfDocumentRenderOptions(a0: QPdfDocumentRenderOptions)");


sipClassTypeDef sipTypeDef_QtPdf_QPdfDocumentRenderOptions = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPdfDocumentRenderOptions,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QPdfDocumentRenderOptions,
        {0, 0, 1},
        8, methods_QPdfDocumentRenderOptions,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QPdfDocumentRenderOptions, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPdfDocumentRenderOptions,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QPdfDocumentRenderOptions,
    init_type_QPdfDocumentRenderOptions,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPdfDocumentRenderOptions,
    assign_QPdfDocumentRenderOptions,
    array_QPdfDocumentRenderOptions,
    copy_QPdfDocumentRenderOptions,
    release_QPdfDocumentRenderOptions,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPdfDocumentRenderOptions,
    sizeof (::QPdfDocumentRenderOptions),
};
