/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleditemdelegate.sip"
#include <qstyleditemdelegate.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 612 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qitemeditorfactory.sip"
#include <qitemeditorfactory.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractitemdelegate.sip"
#include <qabstractitemdelegate.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 511 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractitemview.sip"
#include <qabstractitemview.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 112 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 118 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQStyledItemDelegate.cpp"


class sipQStyledItemDelegate : public ::QStyledItemDelegate
{
public:
    sipQStyledItemDelegate(::QObject*);
    virtual ~sipQStyledItemDelegate();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void initStyleOption(::QStyleOptionViewItem*, const ::QModelIndex&) const SIP_OVERRIDE;
    ::QString displayText(const ::QVariant&, const ::QLocale&) const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void paint(::QPainter*, const ::QStyleOptionViewItem&, const ::QModelIndex&) const SIP_OVERRIDE;
    ::QSize sizeHint(const ::QStyleOptionViewItem&, const ::QModelIndex&) const SIP_OVERRIDE;
    ::QWidget* createEditor(::QWidget*, const ::QStyleOptionViewItem&, const ::QModelIndex&) const SIP_OVERRIDE;
    void setEditorData(::QWidget*, const ::QModelIndex&) const SIP_OVERRIDE;
    void setModelData(::QWidget*, ::QAbstractItemModel*, const ::QModelIndex&) const SIP_OVERRIDE;
    void updateEditorGeometry(::QWidget*, const ::QStyleOptionViewItem&, const ::QModelIndex&) const SIP_OVERRIDE;
    void destroyEditor(::QWidget*, const ::QModelIndex&) const SIP_OVERRIDE;
    bool editorEvent(::QEvent*, ::QAbstractItemModel*, const ::QStyleOptionViewItem&, const ::QModelIndex&) SIP_OVERRIDE;
    bool helpEvent(::QHelpEvent*, ::QAbstractItemView*, const ::QStyleOptionViewItem&, const ::QModelIndex&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQStyledItemDelegate(const sipQStyledItemDelegate &);
    sipQStyledItemDelegate &operator = (const sipQStyledItemDelegate &);

    char sipPyMethods[18];
};

sipQStyledItemDelegate::sipQStyledItemDelegate(::QObject*a0): ::QStyledItemDelegate(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQStyledItemDelegate::~sipQStyledItemDelegate()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQStyledItemDelegate::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QStyledItemDelegate);

    return ::QStyledItemDelegate::metaObject();
}

int sipQStyledItemDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QStyledItemDelegate::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QStyledItemDelegate, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQStyledItemDelegate::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QStyledItemDelegate, _clname, &sipCpp) ? sipCpp : ::QStyledItemDelegate::qt_metacast(_clname));
}

void sipQStyledItemDelegate::initStyleOption(::QStyleOptionViewItem*a0, const ::QModelIndex& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initStyleOption);

    if (!sipMeth)
    {
        ::QStyledItemDelegate::initStyleOption(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_203(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyleOptionViewItem*, const ::QModelIndex&);

    sipVH_QtWidgets_203(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QString sipQStyledItemDelegate::displayText(const ::QVariant& a0, const ::QLocale& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_displayText);

    if (!sipMeth)
        return ::QStyledItemDelegate::displayText(a0, a1);

    extern ::QString sipVH_QtWidgets_202(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QVariant&, const ::QLocale&);

    return sipVH_QtWidgets_202(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQStyledItemDelegate::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QStyledItemDelegate::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyledItemDelegate::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QStyledItemDelegate::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyledItemDelegate::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QStyledItemDelegate::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyledItemDelegate::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QStyledItemDelegate::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyledItemDelegate::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QStyledItemDelegate::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQStyledItemDelegate::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QStyledItemDelegate::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQStyledItemDelegate::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QStyledItemDelegate::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyledItemDelegate::paint(::QPainter*a0, const ::QStyleOptionViewItem& a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paint);

    if (!sipMeth)
    {
        ::QStyledItemDelegate::paint(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QStyleOptionViewItem&, const ::QModelIndex&);

    sipVH_QtWidgets_39(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QSize sipQStyledItemDelegate::sizeHint(const ::QStyleOptionViewItem& a0, const ::QModelIndex& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QStyledItemDelegate::sizeHint(a0, a1);

    extern ::QSize sipVH_QtWidgets_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QStyleOptionViewItem&, const ::QModelIndex&);

    return sipVH_QtWidgets_40(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QWidget* sipQStyledItemDelegate::createEditor(::QWidget*a0, const ::QStyleOptionViewItem& a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_createEditor);

    if (!sipMeth)
        return ::QStyledItemDelegate::createEditor(a0, a1, a2);

    extern ::QWidget* sipVH_QtWidgets_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*, const ::QStyleOptionViewItem&, const ::QModelIndex&);

    return sipVH_QtWidgets_41(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQStyledItemDelegate::setEditorData(::QWidget*a0, const ::QModelIndex& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_setEditorData);

    if (!sipMeth)
    {
        ::QStyledItemDelegate::setEditorData(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_42(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*, const ::QModelIndex&);

    sipVH_QtWidgets_42(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQStyledItemDelegate::setModelData(::QWidget*a0, ::QAbstractItemModel*a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_setModelData);

    if (!sipMeth)
    {
        ::QStyledItemDelegate::setModelData(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_43(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*, ::QAbstractItemModel*, const ::QModelIndex&);

    sipVH_QtWidgets_43(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQStyledItemDelegate::updateEditorGeometry(::QWidget*a0, const ::QStyleOptionViewItem& a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_updateEditorGeometry);

    if (!sipMeth)
    {
        ::QStyledItemDelegate::updateEditorGeometry(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_44(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*, const ::QStyleOptionViewItem&, const ::QModelIndex&);

    sipVH_QtWidgets_44(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQStyledItemDelegate::destroyEditor(::QWidget*a0, const ::QModelIndex& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[15]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_destroyEditor);

    if (!sipMeth)
    {
        ::QStyledItemDelegate::destroyEditor(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_42(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*, const ::QModelIndex&);

    sipVH_QtWidgets_42(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQStyledItemDelegate::editorEvent(::QEvent*a0, ::QAbstractItemModel*a1, const ::QStyleOptionViewItem& a2, const ::QModelIndex& a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_editorEvent);

    if (!sipMeth)
        return ::QStyledItemDelegate::editorEvent(a0, a1, a2, a3);

    extern bool sipVH_QtWidgets_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*, ::QAbstractItemModel*, const ::QStyleOptionViewItem&, const ::QModelIndex&);

    return sipVH_QtWidgets_45(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

bool sipQStyledItemDelegate::helpEvent(::QHelpEvent*a0, ::QAbstractItemView*a1, const ::QStyleOptionViewItem& a2, const ::QModelIndex& a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_helpEvent);

    if (!sipMeth)
        return ::QStyledItemDelegate::helpEvent(a0, a1, a2, a3);

    extern bool sipVH_QtWidgets_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHelpEvent*, ::QAbstractItemView*, const ::QStyleOptionViewItem&, const ::QModelIndex&);

    return sipVH_QtWidgets_46(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}


PyDoc_STRVAR(doc_QStyledItemDelegate_paint, "paint(self, painter: QPainter|None, option: QStyleOptionViewItem, index: QModelIndex)");

extern "C" {static PyObject *meth_QStyledItemDelegate_paint(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_paint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStyledItemDelegate)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPainter* a0;
        const ::QStyleOptionViewItem* a1;
        const ::QModelIndex* a2;
        const ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J9J9", &sipSelf, sipType_QStyledItemDelegate, &sipCpp, sipType_QPainter, &a0, sipType_QStyleOptionViewItem, &a1, sipType_QModelIndex, &a2))
        {
            (sipSelfWasArg ? sipCpp->::QStyledItemDelegate::paint(a0, *a1, *a2) : sipCpp->paint(a0, *a1, *a2));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_paint, doc_QStyledItemDelegate_paint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyledItemDelegate_sizeHint, "sizeHint(self, option: QStyleOptionViewItem, index: QModelIndex) -> QSize");

extern "C" {static PyObject *meth_QStyledItemDelegate_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStyledItemDelegate)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QStyleOptionViewItem* a0;
        const ::QModelIndex* a1;
        const ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QStyledItemDelegate, &sipCpp, sipType_QStyleOptionViewItem, &a0, sipType_QModelIndex, &a1))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QStyledItemDelegate::sizeHint(*a0, *a1) : sipCpp->sizeHint(*a0, *a1)));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_sizeHint, doc_QStyledItemDelegate_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyledItemDelegate_createEditor, "createEditor(self, parent: QWidget|None, option: QStyleOptionViewItem, index: QModelIndex) -> QWidget|None");

extern "C" {static PyObject *meth_QStyledItemDelegate_createEditor(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_createEditor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStyledItemDelegate)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWidget* a0;
        const ::QStyleOptionViewItem* a1;
        const ::QModelIndex* a2;
        sipWrapper *sipOwner = SIP_NULLPTR;
        const ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJHJ9J9", &sipSelf, sipType_QStyledItemDelegate, &sipCpp, sipType_QWidget, &a0, &sipOwner, sipType_QStyleOptionViewItem, &a1, sipType_QModelIndex, &a2))
        {
            ::QWidget*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QStyledItemDelegate::createEditor(a0, *a1, *a2) : sipCpp->createEditor(a0, *a1, *a2));

            return sipConvertFromType(sipRes, sipType_QWidget, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_createEditor, doc_QStyledItemDelegate_createEditor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyledItemDelegate_setEditorData, "setEditorData(self, editor: QWidget|None, index: QModelIndex)");

extern "C" {static PyObject *meth_QStyledItemDelegate_setEditorData(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_setEditorData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStyledItemDelegate)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWidget* a0;
        const ::QModelIndex* a1;
        const ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J9", &sipSelf, sipType_QStyledItemDelegate, &sipCpp, sipType_QWidget, &a0, sipType_QModelIndex, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QStyledItemDelegate::setEditorData(a0, *a1) : sipCpp->setEditorData(a0, *a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_setEditorData, doc_QStyledItemDelegate_setEditorData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyledItemDelegate_setModelData, "setModelData(self, editor: QWidget|None, model: QAbstractItemModel|None, index: QModelIndex)");

extern "C" {static PyObject *meth_QStyledItemDelegate_setModelData(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_setModelData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStyledItemDelegate)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWidget* a0;
        ::QAbstractItemModel* a1;
        PyObject *a1Keep;
        const ::QModelIndex* a2;
        const ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8@J8J9", &sipSelf, sipType_QStyledItemDelegate, &sipCpp, sipType_QWidget, &a0, &a1Keep, sipType_QAbstractItemModel, &a1, sipType_QModelIndex, &a2))
        {
            (sipSelfWasArg ? sipCpp->::QStyledItemDelegate::setModelData(a0, a1, *a2) : sipCpp->setModelData(a0, a1, *a2));

            sipKeepReference(sipSelf, -38, a1Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_setModelData, doc_QStyledItemDelegate_setModelData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyledItemDelegate_updateEditorGeometry, "updateEditorGeometry(self, editor: QWidget|None, option: QStyleOptionViewItem, index: QModelIndex)");

extern "C" {static PyObject *meth_QStyledItemDelegate_updateEditorGeometry(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_updateEditorGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStyledItemDelegate)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWidget* a0;
        const ::QStyleOptionViewItem* a1;
        const ::QModelIndex* a2;
        const ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J9J9", &sipSelf, sipType_QStyledItemDelegate, &sipCpp, sipType_QWidget, &a0, sipType_QStyleOptionViewItem, &a1, sipType_QModelIndex, &a2))
        {
            (sipSelfWasArg ? sipCpp->::QStyledItemDelegate::updateEditorGeometry(a0, *a1, *a2) : sipCpp->updateEditorGeometry(a0, *a1, *a2));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_updateEditorGeometry, doc_QStyledItemDelegate_updateEditorGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyledItemDelegate_itemEditorFactory, "itemEditorFactory(self) -> QItemEditorFactory|None");

extern "C" {static PyObject *meth_QStyledItemDelegate_itemEditorFactory(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_itemEditorFactory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyledItemDelegate, &sipCpp))
        {
            ::QItemEditorFactory*sipRes;

            sipRes = sipCpp->itemEditorFactory();

            return sipConvertFromType(sipRes, sipType_QItemEditorFactory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_itemEditorFactory, doc_QStyledItemDelegate_itemEditorFactory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyledItemDelegate_setItemEditorFactory, "setItemEditorFactory(self, factory: QItemEditorFactory|None)");

extern "C" {static PyObject *meth_QStyledItemDelegate_setItemEditorFactory(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_setItemEditorFactory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QItemEditorFactory* a0;
        PyObject *a0Keep;
        ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QStyledItemDelegate, &sipCpp, &a0Keep, sipType_QItemEditorFactory, &a0))
        {
            sipCpp->setItemEditorFactory(a0);

            sipKeepReference(sipSelf, -39, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_setItemEditorFactory, doc_QStyledItemDelegate_setItemEditorFactory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyledItemDelegate_displayText, "displayText(self, value: Any, locale: QLocale) -> str");

extern "C" {static PyObject *meth_QStyledItemDelegate_displayText(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_displayText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStyledItemDelegate)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QVariant* a0;
        int a0State = 0;
        const ::QLocale* a1;
        const ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9", &sipSelf, sipType_QStyledItemDelegate, &sipCpp, sipType_QVariant, &a0, &a0State, sipType_QLocale, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QStyledItemDelegate::displayText(*a0, *a1) : sipCpp->displayText(*a0, *a1)));
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_displayText, doc_QStyledItemDelegate_displayText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyledItemDelegate_initStyleOption, "initStyleOption(self, option: QStyleOptionViewItem|None, index: QModelIndex)");

extern "C" {static PyObject *meth_QStyledItemDelegate_initStyleOption(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_initStyleOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStyledItemDelegate)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QStyleOptionViewItem* a0;
        const ::QModelIndex* a1;
        const ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J9", &sipSelf, sipType_QStyledItemDelegate, &sipCpp, sipType_QStyleOptionViewItem, &a0, sipType_QModelIndex, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QStyledItemDelegate::initStyleOption(a0, *a1) : sipCpp->initStyleOption(a0, *a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_initStyleOption, doc_QStyledItemDelegate_initStyleOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyledItemDelegate_eventFilter, "eventFilter(self, object: QObject|None, event: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QStyledItemDelegate_eventFilter(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_eventFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStyledItemDelegate)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QObject* a0;
        ::QEvent* a1;
        ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J8", &sipSelf, sipType_QStyledItemDelegate, &sipCpp, sipType_QObject, &a0, sipType_QEvent, &a1))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QStyledItemDelegate::eventFilter(a0, a1) : sipCpp->eventFilter(a0, a1));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_eventFilter, doc_QStyledItemDelegate_eventFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyledItemDelegate_editorEvent, "editorEvent(self, event: QEvent|None, model: QAbstractItemModel|None, option: QStyleOptionViewItem, index: QModelIndex) -> bool");

extern "C" {static PyObject *meth_QStyledItemDelegate_editorEvent(PyObject *, PyObject *);}
static PyObject *meth_QStyledItemDelegate_editorEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStyledItemDelegate)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QAbstractItemModel* a1;
        const ::QStyleOptionViewItem* a2;
        const ::QModelIndex* a3;
        ::QStyledItemDelegate *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J8J9J9", &sipSelf, sipType_QStyledItemDelegate, &sipCpp, sipType_QEvent, &a0, sipType_QAbstractItemModel, &a1, sipType_QStyleOptionViewItem, &a2, sipType_QModelIndex, &a3))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QStyledItemDelegate::editorEvent(a0, a1, *a2, *a3) : sipCpp->editorEvent(a0, a1, *a2, *a3));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyledItemDelegate, sipName_editorEvent, doc_QStyledItemDelegate_editorEvent);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QStyledItemDelegate(void *, const sipTypeDef *);}
static void *cast_QStyledItemDelegate(void *sipCppV, const sipTypeDef *targetType)
{
    ::QStyledItemDelegate *sipCpp = reinterpret_cast< ::QStyledItemDelegate *>(sipCppV);

    if (targetType == sipType_QStyledItemDelegate)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstractItemDelegate)->ctd_cast(static_cast< ::QAbstractItemDelegate *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QStyledItemDelegate(void *, int);}
static void release_QStyledItemDelegate(void *sipCppV, int)
{
    ::QStyledItemDelegate *sipCpp = reinterpret_cast< ::QStyledItemDelegate *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QStyledItemDelegate(Py_ssize_t);}
static void *array_QStyledItemDelegate(Py_ssize_t sipNrElem)
{
    return new ::QStyledItemDelegate[sipNrElem];
}


extern "C" {static void array_delete_QStyledItemDelegate(void *);}
static void array_delete_QStyledItemDelegate(void *sipCpp)
{
    delete[] reinterpret_cast< ::QStyledItemDelegate *>(sipCpp);
}


extern "C" {static void dealloc_QStyledItemDelegate(sipSimpleWrapper *);}
static void dealloc_QStyledItemDelegate(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQStyledItemDelegate *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QStyledItemDelegate(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QStyledItemDelegate(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QStyledItemDelegate(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQStyledItemDelegate *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQStyledItemDelegate(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QStyledItemDelegate[] = {{2, 255, 1}};


static PyMethodDef methods_QStyledItemDelegate[] = {
    {sipName_createEditor, meth_QStyledItemDelegate_createEditor, METH_VARARGS, doc_QStyledItemDelegate_createEditor},
    {sipName_displayText, meth_QStyledItemDelegate_displayText, METH_VARARGS, doc_QStyledItemDelegate_displayText},
    {sipName_editorEvent, meth_QStyledItemDelegate_editorEvent, METH_VARARGS, doc_QStyledItemDelegate_editorEvent},
    {sipName_eventFilter, meth_QStyledItemDelegate_eventFilter, METH_VARARGS, doc_QStyledItemDelegate_eventFilter},
    {sipName_initStyleOption, meth_QStyledItemDelegate_initStyleOption, METH_VARARGS, doc_QStyledItemDelegate_initStyleOption},
    {sipName_itemEditorFactory, meth_QStyledItemDelegate_itemEditorFactory, METH_VARARGS, doc_QStyledItemDelegate_itemEditorFactory},
    {sipName_paint, meth_QStyledItemDelegate_paint, METH_VARARGS, doc_QStyledItemDelegate_paint},
    {sipName_setEditorData, meth_QStyledItemDelegate_setEditorData, METH_VARARGS, doc_QStyledItemDelegate_setEditorData},
    {sipName_setItemEditorFactory, meth_QStyledItemDelegate_setItemEditorFactory, METH_VARARGS, doc_QStyledItemDelegate_setItemEditorFactory},
    {sipName_setModelData, meth_QStyledItemDelegate_setModelData, METH_VARARGS, doc_QStyledItemDelegate_setModelData},
    {sipName_sizeHint, meth_QStyledItemDelegate_sizeHint, METH_VARARGS, doc_QStyledItemDelegate_sizeHint},
    {sipName_updateEditorGeometry, meth_QStyledItemDelegate_updateEditorGeometry, METH_VARARGS, doc_QStyledItemDelegate_updateEditorGeometry}
};

PyDoc_STRVAR(doc_QStyledItemDelegate, "\1QStyledItemDelegate(parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QStyledItemDelegate = {
    &::QStyledItemDelegate::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QStyledItemDelegate = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStyledItemDelegate,
        SIP_NULLPTR,
        &plugin_QStyledItemDelegate,
    },
    {
        sipNameNr_QStyledItemDelegate,
        {0, 0, 1},
        12, methods_QStyledItemDelegate,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QStyledItemDelegate,
    -1,
    -1,
    supers_QStyledItemDelegate,
    SIP_NULLPTR,
    init_type_QStyledItemDelegate,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QStyledItemDelegate,
    SIP_NULLPTR,
    array_QStyledItemDelegate,
    SIP_NULLPTR,
    release_QStyledItemDelegate,
    cast_QStyledItemDelegate,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QStyledItemDelegate,
    sizeof (::QStyledItemDelegate),
};
