/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtSerialPortAPI_H
#define _QtSerialPortAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtSerialPort[0]
#define sipNameNr_34 34
#define sipName_34 &sipStrings_QtSerialPort[34]
#define sipNameNr_SecondaryTransmittedDataSignal 65
#define sipName_SecondaryTransmittedDataSignal &sipStrings_QtSerialPort[65]
#define sipNameNr_settingsRestoredOnCloseChanged 96
#define sipName_settingsRestoredOnCloseChanged &sipStrings_QtSerialPort[96]
#define sipNameNr_QSerialPort__SerialPortError 127
#define sipName_QSerialPort__SerialPortError &sipStrings_QtSerialPort[127]
#define sipNameNr_SecondaryReceivedDataSignal 156
#define sipName_SecondaryReceivedDataSignal &sipStrings_QtSerialPort[156]
#define sipNameNr_setSettingsRestoredOnClose 184
#define sipName_setSettingsRestoredOnClose &sipStrings_QtSerialPort[184]
#define sipNameNr_QSerialPort__PinoutSignal 211
#define sipName_QSerialPort__PinoutSignal &sipStrings_QtSerialPort[211]
#define sipNameNr_UnsupportedOperationError 237
#define sipName_UnsupportedOperationError &sipStrings_QtSerialPort[237]
#define sipNameNr_QSerialPort__FlowControl 263
#define sipName_QSerialPort__FlowControl &sipStrings_QtSerialPort[263]
#define sipNameNr_dataTerminalReadyChanged 288
#define sipName_dataTerminalReadyChanged &sipStrings_QtSerialPort[288]
#define sipNameNr_DataCarrierDetectSignal 313
#define sipName_DataCarrierDetectSignal &sipStrings_QtSerialPort[313]
#define sipNameNr_DataTerminalReadySignal 337
#define sipName_DataTerminalReadySignal &sipStrings_QtSerialPort[337]
#define sipNameNr_PyQt6_sip_simplewrapper 361
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtSerialPort[361]
#define sipNameNr_settingsRestoredOnClose 385
#define sipName_settingsRestoredOnClose &sipStrings_QtSerialPort[385]
#define sipNameNr_409 409
#define sipName_409 &sipStrings_QtSerialPort[409]
#define sipNameNr_QSerialPort__Direction 432
#define sipName_QSerialPort__Direction &sipStrings_QtSerialPort[432]
#define sipNameNr_QSerialPort__BaudRate 455
#define sipName_QSerialPort__BaudRate &sipStrings_QtSerialPort[455]
#define sipNameNr_QSerialPort__DataBits 477
#define sipName_QSerialPort__DataBits &sipStrings_QtSerialPort[477]
#define sipNameNr_QSerialPort__StopBits 499
#define sipName_QSerialPort__StopBits &sipStrings_QtSerialPort[499]
#define sipNameNr_hasProductIdentifier 521
#define sipName_hasProductIdentifier &sipStrings_QtSerialPort[521]
#define sipNameNr_requestToSendChanged 542
#define sipName_requestToSendChanged &sipStrings_QtSerialPort[542]
#define sipNameNr_setDataTerminalReady 563
#define sipName_setDataTerminalReady &sipStrings_QtSerialPort[563]
#define sipNameNr_DeviceNotFoundError 584
#define sipName_DeviceNotFoundError &sipStrings_QtSerialPort[584]
#define sipNameNr_QSerialPort__Parity 604
#define sipName_QSerialPort__Parity &sipStrings_QtSerialPort[604]
#define sipNameNr_RequestToSendSignal 624
#define sipName_RequestToSendSignal &sipStrings_QtSerialPort[624]
#define sipNameNr_RingIndicatorSignal 644
#define sipName_RingIndicatorSignal &sipStrings_QtSerialPort[644]
#define sipNameNr_breakEnabledChanged 664
#define sipName_breakEnabledChanged &sipStrings_QtSerialPort[664]
#define sipNameNr_hasVendorIdentifier 684
#define sipName_hasVendorIdentifier &sipStrings_QtSerialPort[684]
#define sipNameNr_isDataTerminalReady 704
#define sipName_isDataTerminalReady &sipStrings_QtSerialPort[704]
#define sipNameNr_waitForBytesWritten 724
#define sipName_waitForBytesWritten &sipStrings_QtSerialPort[724]
#define sipNameNr_DataSetReadySignal 744
#define sipName_DataSetReadySignal &sipStrings_QtSerialPort[744]
#define sipNameNr_PyQt6_QtSerialPort 763
#define sipName_PyQt6_QtSerialPort &sipStrings_QtSerialPort[763]
#define sipNameNr_flowControlChanged 782
#define sipName_flowControlChanged &sipStrings_QtSerialPort[782]
#define sipNameNr_setWriteBufferSize 801
#define sipName_setWriteBufferSize &sipStrings_QtSerialPort[801]
#define sipNameNr_ClearToSendSignal 820
#define sipName_ClearToSendSignal &sipStrings_QtSerialPort[820]
#define sipNameNr_productIdentifier 838
#define sipName_productIdentifier &sipStrings_QtSerialPort[838]
#define sipNameNr_setReadBufferSize 856
#define sipName_setReadBufferSize &sipStrings_QtSerialPort[856]
#define sipNameNr_standardBaudRates 874
#define sipName_standardBaudRates &sipStrings_QtSerialPort[874]
#define sipNameNr_disconnectNotify 892
#define sipName_disconnectNotify &sipStrings_QtSerialPort[892]
#define sipNameNr_setRequestToSend 909
#define sipName_setRequestToSend &sipStrings_QtSerialPort[909]
#define sipNameNr_vendorIdentifier 926
#define sipName_vendorIdentifier &sipStrings_QtSerialPort[926]
#define sipNameNr_waitForReadyRead 943
#define sipName_waitForReadyRead &sipStrings_QtSerialPort[943]
#define sipNameNr_HardwareControl 960
#define sipName_HardwareControl &sipStrings_QtSerialPort[960]
#define sipNameNr_PermissionError 976
#define sipName_PermissionError &sipStrings_QtSerialPort[976]
#define sipNameNr_QSerialPortInfo 992
#define sipName_QSerialPortInfo &sipStrings_QtSerialPort[992]
#define sipNameNr_SerialPortError 140
#define sipName_SerialPortError &sipStrings_QtSerialPort[140]
#define sipNameNr_SoftwareControl 1008
#define sipName_SoftwareControl &sipStrings_QtSerialPort[1008]
#define sipNameNr_baudRateChanged 1024
#define sipName_baudRateChanged &sipStrings_QtSerialPort[1024]
#define sipNameNr_dataBitsChanged 1040
#define sipName_dataBitsChanged &sipStrings_QtSerialPort[1040]
#define sipNameNr_isRequestToSend 1056
#define sipName_isRequestToSend &sipStrings_QtSerialPort[1056]
#define sipNameNr_setBreakEnabled 1072
#define sipName_setBreakEnabled &sipStrings_QtSerialPort[1072]
#define sipNameNr_stopBitsChanged 1088
#define sipName_stopBitsChanged &sipStrings_QtSerialPort[1088]
#define sipNameNr_writeBufferSize 1104
#define sipName_writeBufferSize &sipStrings_QtSerialPort[1104]
#define sipNameNr_OneAndHalfStop 1120
#define sipName_OneAndHalfStop &sipStrings_QtSerialPort[1120]
#define sipNameNr_availablePorts 1135
#define sipName_availablePorts &sipStrings_QtSerialPort[1135]
#define sipNameNr_bytesAvailable 1150
#define sipName_bytesAvailable &sipStrings_QtSerialPort[1150]
#define sipNameNr_isBreakEnabled 1165
#define sipName_isBreakEnabled &sipStrings_QtSerialPort[1165]
#define sipNameNr_readBufferSize 1180
#define sipName_readBufferSize &sipStrings_QtSerialPort[1180]
#define sipNameNr_setFlowControl 1195
#define sipName_setFlowControl &sipStrings_QtSerialPort[1195]
#define sipNameNr_systemLocation 1210
#define sipName_systemLocation &sipStrings_QtSerialPort[1210]
#define sipNameNr_AllDirections 1225
#define sipName_AllDirections &sipStrings_QtSerialPort[1225]
#define sipNameNr_NoFlowControl 1239
#define sipName_NoFlowControl &sipStrings_QtSerialPort[1239]
#define sipNameNr_ResourceError 1253
#define sipName_ResourceError &sipStrings_QtSerialPort[1253]
#define sipNameNr_connectNotify 895
#define sipName_connectNotify &sipStrings_QtSerialPort[895]
#define sipNameNr_errorOccurred 1267
#define sipName_errorOccurred &sipStrings_QtSerialPort[1267]
#define sipNameNr_parityChanged 1281
#define sipName_parityChanged &sipStrings_QtSerialPort[1281]
#define sipNameNr_pinoutSignals 1295
#define sipName_pinoutSignals &sipStrings_QtSerialPort[1295]
#define sipNameNr_NotOpenError 1309
#define sipName_NotOpenError &sipStrings_QtSerialPort[1309]
#define sipNameNr_PinoutSignal 224
#define sipName_PinoutSignal &sipStrings_QtSerialPort[224]
#define sipNameNr_TimeoutError 1322
#define sipName_TimeoutError &sipStrings_QtSerialPort[1322]
#define sipNameNr_UnknownError 1335
#define sipName_UnknownError &sipStrings_QtSerialPort[1335]
#define sipNameNr_bytesToWrite 1348
#define sipName_bytesToWrite &sipStrings_QtSerialPort[1348]
#define sipNameNr_isSequential 1361
#define sipName_isSequential &sipStrings_QtSerialPort[1361]
#define sipNameNr_manufacturer 1374
#define sipName_manufacturer &sipStrings_QtSerialPort[1374]
#define sipNameNr_readLineData 1387
#define sipName_readLineData &sipStrings_QtSerialPort[1387]
#define sipNameNr_serialNumber 1400
#define sipName_serialNumber &sipStrings_QtSerialPort[1400]
#define sipNameNr_FlowControl 276
#define sipName_FlowControl &sipStrings_QtSerialPort[276]
#define sipNameNr_QSerialPort 1413
#define sipName_QSerialPort &sipStrings_QtSerialPort[1413]
#define sipNameNr_SpaceParity 1425
#define sipName_SpaceParity &sipStrings_QtSerialPort[1425]
#define sipNameNr_canReadLine 1437
#define sipName_canReadLine &sipStrings_QtSerialPort[1437]
#define sipNameNr_customEvent 1449
#define sipName_customEvent &sipStrings_QtSerialPort[1449]
#define sipNameNr_description 1461
#define sipName_description &sipStrings_QtSerialPort[1461]
#define sipNameNr_eventFilter 1473
#define sipName_eventFilter &sipStrings_QtSerialPort[1473]
#define sipNameNr_flowControl 1485
#define sipName_flowControl &sipStrings_QtSerialPort[1485]
#define sipNameNr_setBaudRate 1497
#define sipName_setBaudRate &sipStrings_QtSerialPort[1497]
#define sipNameNr_setDataBits 1509
#define sipName_setDataBits &sipStrings_QtSerialPort[1509]
#define sipNameNr_setPortName 1521
#define sipName_setPortName &sipStrings_QtSerialPort[1521]
#define sipNameNr_setStopBits 1533
#define sipName_setStopBits &sipStrings_QtSerialPort[1533]
#define sipNameNr_Baud115200 1545
#define sipName_Baud115200 &sipStrings_QtSerialPort[1545]
#define sipNameNr_EvenParity 1556
#define sipName_EvenParity &sipStrings_QtSerialPort[1556]
#define sipNameNr_MarkParity 1567
#define sipName_MarkParity &sipStrings_QtSerialPort[1567]
#define sipNameNr_WriteError 1578
#define sipName_WriteError &sipStrings_QtSerialPort[1578]
#define sipNameNr_childEvent 1589
#define sipName_childEvent &sipStrings_QtSerialPort[1589]
#define sipNameNr_clearError 1600
#define sipName_clearError &sipStrings_QtSerialPort[1600]
#define sipNameNr_timerEvent 1611
#define sipName_timerEvent &sipStrings_QtSerialPort[1611]
#define sipNameNr_Baud19200 1622
#define sipName_Baud19200 &sipStrings_QtSerialPort[1622]
#define sipNameNr_Baud38400 1632
#define sipName_Baud38400 &sipStrings_QtSerialPort[1632]
#define sipNameNr_Baud57600 1642
#define sipName_Baud57600 &sipStrings_QtSerialPort[1642]
#define sipNameNr_Direction 445
#define sipName_Direction &sipStrings_QtSerialPort[445]
#define sipNameNr_OddParity 1652
#define sipName_OddParity &sipStrings_QtSerialPort[1652]
#define sipNameNr_OpenError 1312
#define sipName_OpenError &sipStrings_QtSerialPort[1312]
#define sipNameNr_ReadError 1662
#define sipName_ReadError &sipStrings_QtSerialPort[1662]
#define sipNameNr_setParity 1672
#define sipName_setParity &sipStrings_QtSerialPort[1672]
#define sipNameNr_writeData 1682
#define sipName_writeData &sipStrings_QtSerialPort[1682]
#define sipNameNr_Baud1200 1692
#define sipName_Baud1200 &sipStrings_QtSerialPort[1692]
#define sipNameNr_Baud2400 1701
#define sipName_Baud2400 &sipStrings_QtSerialPort[1701]
#define sipNameNr_Baud4800 1710
#define sipName_Baud4800 &sipStrings_QtSerialPort[1710]
#define sipNameNr_Baud9600 1719
#define sipName_Baud9600 &sipStrings_QtSerialPort[1719]
#define sipNameNr_BaudRate 468
#define sipName_BaudRate &sipStrings_QtSerialPort[468]
#define sipNameNr_DataBits 490
#define sipName_DataBits &sipStrings_QtSerialPort[490]
#define sipNameNr_NoParity 1728
#define sipName_NoParity &sipStrings_QtSerialPort[1728]
#define sipNameNr_NoSignal 1737
#define sipName_NoSignal &sipStrings_QtSerialPort[1737]
#define sipNameNr_StopBits 512
#define sipName_StopBits &sipStrings_QtSerialPort[512]
#define sipNameNr_baudRate 1746
#define sipName_baudRate &sipStrings_QtSerialPort[1746]
#define sipNameNr_dataBits 1755
#define sipName_dataBits &sipStrings_QtSerialPort[1755]
#define sipNameNr_portName 1764
#define sipName_portName &sipStrings_QtSerialPort[1764]
#define sipNameNr_readData 1773
#define sipName_readData &sipStrings_QtSerialPort[1773]
#define sipNameNr_skipData 1782
#define sipName_skipData &sipStrings_QtSerialPort[1782]
#define sipNameNr_stopBits 1791
#define sipName_stopBits &sipStrings_QtSerialPort[1791]
#define sipNameNr_NoError 1800
#define sipName_NoError &sipStrings_QtSerialPort[1800]
#define sipNameNr_OneStop 1808
#define sipName_OneStop &sipStrings_QtSerialPort[1808]
#define sipNameNr_TwoStop 1816
#define sipName_TwoStop &sipStrings_QtSerialPort[1816]
#define sipNameNr_enabled 1824
#define sipName_enabled &sipStrings_QtSerialPort[1824]
#define sipNameNr_setPort 1832
#define sipName_setPort &sipStrings_QtSerialPort[1832]
#define sipNameNr_Output 1840
#define sipName_Output &sipStrings_QtSerialPort[1840]
#define sipNameNr_Parity 617
#define sipName_Parity &sipStrings_QtSerialPort[617]
#define sipNameNr_handle 1847
#define sipName_handle &sipStrings_QtSerialPort[1847]
#define sipNameNr_isNull 1854
#define sipName_isNull &sipStrings_QtSerialPort[1854]
#define sipNameNr_parent 1861
#define sipName_parent &sipStrings_QtSerialPort[1861]
#define sipNameNr_parity 1868
#define sipName_parity &sipStrings_QtSerialPort[1868]
#define sipNameNr_Data5 1875
#define sipName_Data5 &sipStrings_QtSerialPort[1875]
#define sipNameNr_Data6 1881
#define sipName_Data6 &sipStrings_QtSerialPort[1881]
#define sipNameNr_Data7 1887
#define sipName_Data7 &sipStrings_QtSerialPort[1887]
#define sipNameNr_Data8 1893
#define sipName_Data8 &sipStrings_QtSerialPort[1893]
#define sipNameNr_Input 1899
#define sipName_Input &sipStrings_QtSerialPort[1899]
#define sipNameNr_atEnd 1905
#define sipName_atEnd &sipStrings_QtSerialPort[1905]
#define sipNameNr_clear 1911
#define sipName_clear &sipStrings_QtSerialPort[1911]
#define sipNameNr_close 1917
#define sipName_close &sipStrings_QtSerialPort[1917]
#define sipNameNr_error 1923
#define sipName_error &sipStrings_QtSerialPort[1923]
#define sipNameNr_event 1929
#define sipName_event &sipStrings_QtSerialPort[1929]
#define sipNameNr_flush 1935
#define sipName_flush &sipStrings_QtSerialPort[1935]
#define sipNameNr_msecs 1941
#define sipName_msecs &sipStrings_QtSerialPort[1941]
#define sipNameNr_reset 1947
#define sipName_reset &sipStrings_QtSerialPort[1947]
#define sipNameNr_open 1953
#define sipName_open &sipStrings_QtSerialPort[1953]
#define sipNameNr_seek 1958
#define sipName_seek &sipStrings_QtSerialPort[1958]
#define sipNameNr_size 1963
#define sipName_size &sipStrings_QtSerialPort[1963]
#define sipNameNr_swap 1968
#define sipName_swap &sipStrings_QtSerialPort[1968]
#define sipNameNr_dir 1973
#define sipName_dir &sipStrings_QtSerialPort[1973]
#define sipNameNr_pos 1977
#define sipName_pos &sipStrings_QtSerialPort[1977]

#define sipMalloc                   sipAPI_QtSerialPort->api_malloc
#define sipFree                     sipAPI_QtSerialPort->api_free
#define sipBuildResult              sipAPI_QtSerialPort->api_build_result
#define sipCallMethod               sipAPI_QtSerialPort->api_call_method
#define sipCallProcedureMethod      sipAPI_QtSerialPort->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtSerialPort->api_call_error_handler
#define sipParseResultEx            sipAPI_QtSerialPort->api_parse_result_ex
#define sipParseResult              sipAPI_QtSerialPort->api_parse_result
#define sipParseArgs                sipAPI_QtSerialPort->api_parse_args
#define sipParseKwdArgs             sipAPI_QtSerialPort->api_parse_kwd_args
#define sipParsePair                sipAPI_QtSerialPort->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtSerialPort->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtSerialPort->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtSerialPort->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtSerialPort->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtSerialPort->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtSerialPort->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtSerialPort->api_add_exception
#define sipNoFunction               sipAPI_QtSerialPort->api_no_function
#define sipNoMethod                 sipAPI_QtSerialPort->api_no_method
#define sipAbstractMethod           sipAPI_QtSerialPort->api_abstract_method
#define sipBadClass                 sipAPI_QtSerialPort->api_bad_class
#define sipBadCatcherResult         sipAPI_QtSerialPort->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtSerialPort->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtSerialPort->api_bad_operator_arg
#define sipTrace                    sipAPI_QtSerialPort->api_trace
#define sipTransferBack             sipAPI_QtSerialPort->api_transfer_back
#define sipTransferTo               sipAPI_QtSerialPort->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtSerialPort->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtSerialPort->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtSerialPort->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtSerialPort->api_voidptr_type
#define sipGetPyObject              sipAPI_QtSerialPort->api_get_pyobject
#define sipGetAddress               sipAPI_QtSerialPort->api_get_address
#define sipGetMixinAddress          sipAPI_QtSerialPort->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtSerialPort->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtSerialPort->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtSerialPort->api_call_hook
#define sipEndThread                sipAPI_QtSerialPort->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtSerialPort->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtSerialPort->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtSerialPort->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtSerialPort->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtSerialPort->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtSerialPort->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtSerialPort->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtSerialPort->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtSerialPort->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtSerialPort->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtSerialPort->api_convert_to_bool
#define sipReleaseType              sipAPI_QtSerialPort->api_release_type
#define sipConvertFromType          sipAPI_QtSerialPort->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtSerialPort->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtSerialPort->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtSerialPort->api_convert_from_enum
#define sipGetState                 sipAPI_QtSerialPort->api_get_state
#define sipExportSymbol             sipAPI_QtSerialPort->api_export_symbol
#define sipImportSymbol             sipAPI_QtSerialPort->api_import_symbol
#define sipFindType                 sipAPI_QtSerialPort->api_find_type
#define sipBytes_AsChar             sipAPI_QtSerialPort->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtSerialPort->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtSerialPort->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtSerialPort->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtSerialPort->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtSerialPort->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtSerialPort->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtSerialPort->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtSerialPort->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtSerialPort->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtSerialPort->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtSerialPort->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtSerialPort->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtSerialPort->api_get_reference
#define sipKeepReference            sipAPI_QtSerialPort->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtSerialPort->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtSerialPort->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtSerialPort->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtSerialPort->api_type_scope
#define sipResolveTypedef           sipAPI_QtSerialPort->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtSerialPort->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtSerialPort->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtSerialPort->api_init_mixin
#define sipExportModule             sipAPI_QtSerialPort->api_export_module
#define sipInitModule               sipAPI_QtSerialPort->api_init_module
#define sipGetInterpreter           sipAPI_QtSerialPort->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtSerialPort->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtSerialPort->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtSerialPort->api_py_type_dict
#define sipPyTypeName               sipAPI_QtSerialPort->api_py_type_name
#define sipGetCFunction             sipAPI_QtSerialPort->api_get_c_function
#define sipGetMethod                sipAPI_QtSerialPort->api_get_method
#define sipFromMethod               sipAPI_QtSerialPort->api_from_method
#define sipGetDate                  sipAPI_QtSerialPort->api_get_date
#define sipFromDate                 sipAPI_QtSerialPort->api_from_date
#define sipGetDateTime              sipAPI_QtSerialPort->api_get_datetime
#define sipFromDateTime             sipAPI_QtSerialPort->api_from_datetime
#define sipGetTime                  sipAPI_QtSerialPort->api_get_time
#define sipFromTime                 sipAPI_QtSerialPort->api_from_time
#define sipIsUserType               sipAPI_QtSerialPort->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtSerialPort->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtSerialPort->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtSerialPort->api_unicode_write
#define sipUnicodeData              sipAPI_QtSerialPort->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtSerialPort->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtSerialPort->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtSerialPort->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtSerialPort->api_is_derived_class
#define sipGetUserObject            sipAPI_QtSerialPort->api_get_user_object
#define sipSetUserObject            sipAPI_QtSerialPort->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtSerialPort->api_register_event_handler
#define sipConvertToArray           sipAPI_QtSerialPort->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtSerialPort->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtSerialPort->api_enable_gc
#define sipPrintObject              sipAPI_QtSerialPort->api_print_object
#define sipLong_AsChar              sipAPI_QtSerialPort->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtSerialPort->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtSerialPort->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtSerialPort->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtSerialPort->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtSerialPort->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtSerialPort->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtSerialPort->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtSerialPort->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtSerialPort->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtSerialPort->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtSerialPort->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtSerialPort->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtSerialPort->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtSerialPort->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtSerialPort->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtSerialPort->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtSerialPort->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtSerialPort->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtSerialPort->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtSerialPort->api_release_type_us
#define sipIsPyMethod               sipAPI_QtSerialPort->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtSerialPort[];

#define sipType_QSerialPort sipExportedTypes_QtSerialPort[3]

#define sipType_QSerialPort_SerialPortError sipExportedTypes_QtSerialPort[10]

#define sipType_QSerialPort_PinoutSignal sipExportedTypes_QtSerialPort[9]

#define sipType_QSerialPort_FlowControl sipExportedTypes_QtSerialPort[7]

#define sipType_QSerialPort_StopBits sipExportedTypes_QtSerialPort[11]

#define sipType_QSerialPort_Parity sipExportedTypes_QtSerialPort[8]

#define sipType_QSerialPort_DataBits sipExportedTypes_QtSerialPort[5]

#define sipType_QSerialPort_BaudRate sipExportedTypes_QtSerialPort[4]

#define sipType_QSerialPort_Direction sipExportedTypes_QtSerialPort[6]

extern sipClassTypeDef sipTypeDef_QtSerialPort_QSerialPort;

#define sipType_QSerialPortInfo sipExportedTypes_QtSerialPort[12]

extern sipClassTypeDef sipTypeDef_QtSerialPort_QSerialPortInfo;

#define sipType_QList_0100QSerialPortInfo sipExportedTypes_QtSerialPort[2]

extern sipMappedTypeDef sipTypeDef_QtSerialPort_QList_0100QSerialPortInfo;

#define sipType_QFlags_0100QSerialPort_PinoutSignal sipExportedTypes_QtSerialPort[1]

extern sipMappedTypeDef sipTypeDef_QtSerialPort_QFlags_0100QSerialPort_PinoutSignal;

#define sipType_QFlags_0100QSerialPort_Direction sipExportedTypes_QtSerialPort[0]

extern sipMappedTypeDef sipTypeDef_QtSerialPort_QFlags_0100QSerialPort_Direction;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtSerialPort;
extern sipExportedModuleDef sipModuleAPI_QtSerialPort;
extern sipTypeDef *sipExportedTypes_QtSerialPort[];

#define sipType_QObject sipImportedTypes_QtSerialPort_QtCore[7].it_td

#define sipType_QIODeviceBase sipImportedTypes_QtSerialPort_QtCore[4].it_td

#define sipType_QIODevice sipImportedTypes_QtSerialPort_QtCore[3].it_td

#define sipType_QEvent sipImportedTypes_QtSerialPort_QtCore[1].it_td

#define sipType_QTimerEvent sipImportedTypes_QtSerialPort_QtCore[9].it_td

#define sipType_QChildEvent sipImportedTypes_QtSerialPort_QtCore[0].it_td

#define sipType_QMetaMethod sipImportedTypes_QtSerialPort_QtCore[6].it_td

#define sipType_QFlags_0100QIODeviceBase_OpenModeFlag sipImportedTypes_QtSerialPort_QtCore[2].it_td

#define sipType_QList_1800 sipImportedTypes_QtSerialPort_QtCore[5].it_td

#define sipType_QString sipImportedTypes_QtSerialPort_QtCore[8].it_td
extern sipImportedTypeDef sipImportedTypes_QtSerialPort_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtSerialPort_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtSerialPort_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtSerialPort_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtSerialPort_qt_metacast;

#endif
