/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSvgWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSvgWidgets/qsvgwidget.sip"
#include <qsvgwidget.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSvg/qtsvgglobal.sip"
#include <qtsvgglobal.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSvg/qsvgrenderer.sip"
#include <qsvgrenderer.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 215 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 221 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 226 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 229 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 232 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 235 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 238 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 241 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 244 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 247 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 250 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 253 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 256 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 259 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvgWidgets/sipQtSvgWidgetsQSvgWidget.cpp"


class sipQSvgWidget : public ::QSvgWidget
{
public:
    sipQSvgWidget(::QWidget*);
    sipQSvgWidget(const ::QString&, ::QWidget*);
    virtual ~sipQSvgWidget();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEnterEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSvgWidget(const sipQSvgWidget &);
    sipQSvgWidget &operator = (const sipQSvgWidget &);

    char sipPyMethods[46];
};

sipQSvgWidget::sipQSvgWidget(::QWidget*a0): ::QSvgWidget(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSvgWidget::sipQSvgWidget(const ::QString& a0, ::QWidget*a1): ::QSvgWidget(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSvgWidget::~sipQSvgWidget()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQSvgWidget::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtSvgWidgets_qt_metaobject(sipPySelf, sipType_QSvgWidget);

    return ::QSvgWidget::metaObject();
}

int sipQSvgWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QSvgWidget::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtSvgWidgets_qt_metacall(sipPySelf, sipType_QSvgWidget, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQSvgWidget::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtSvgWidgets_qt_metacast(sipPySelf, sipType_QSvgWidget, _clname, &sipCpp) ? sipCpp : ::QSvgWidget::qt_metacast(_clname));
}

void sipQSvgWidget::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QSvgWidget::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSvgWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QSvgWidget::connectNotify(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSvgWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::customEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSvgWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::childEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtSvgWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::timerEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtSvgWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSvgWidget::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QSvgWidget::eventFilter(a0, a1);

    extern bool sipVH_QtSvgWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtSvgWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQSvgWidget::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QSvgWidget::event(a0);

    extern bool sipVH_QtSvgWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtSvgWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQSvgWidget::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QSvgWidget::metric(a0);

    extern int sipVH_QtSvgWidgets_51(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtSvgWidgets_51(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQSvgWidget::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QSvgWidget::paintEngine();

    extern ::QPaintEngine* sipVH_QtSvgWidgets_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSvgWidgets_50(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQSvgWidget::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QSvgWidget::devType();

    extern int sipVH_QtSvgWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSvgWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSvgWidget::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QSvgWidget::setVisible(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtSvgWidgets_49(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQSvgWidget::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QSvgWidget::sizeHint();

    extern ::QSize sipVH_QtSvgWidgets_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSvgWidgets_48(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQSvgWidget::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QSvgWidget::minimumSizeHint();

    extern ::QSize sipVH_QtSvgWidgets_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSvgWidgets_48(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQSvgWidget::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QSvgWidget::heightForWidth(a0);

    extern int sipVH_QtSvgWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtSvgWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtSvgWidgets_46(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtSvgWidgets_46(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtSvgWidgets_46(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtSvgWidgets_46(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtSvgWidgets_45(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtSvgWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtSvgWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtSvgWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtSvgWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::enterEvent(::QEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::enterEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_44(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEnterEvent*);

    sipVH_QtSvgWidgets_44(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSvgWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::paintEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_43(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtSvgWidgets_43(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::moveEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_42(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtSvgWidgets_42(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtSvgWidgets_41(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::closeEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtSvgWidgets_40(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtSvgWidgets_39(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtSvgWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::actionEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtSvgWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtSvgWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtSvgWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtSvgWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::dropEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtSvgWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::showEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtSvgWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::hideEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtSvgWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::changeEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSvgWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgWidget::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QSvgWidget::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtSvgWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQSvgWidget::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[40]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QSvgWidget::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtSvgWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtSvgWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSvgWidget::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[41], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QSvgWidget::focusNextPrevChild(a0);

    extern bool sipVH_QtSvgWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtSvgWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSvgWidget::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[42]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QSvgWidget::hasHeightForWidth();

    extern bool sipVH_QtSvgWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSvgWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSvgWidget::nativeEvent(const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QSvgWidget::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtSvgWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, ::qintptr*);

    return sipVH_QtSvgWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipQSvgWidget::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[44]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QSvgWidget::sharedPainter();

    extern ::QPainter* sipVH_QtSvgWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSvgWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSvgWidget::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[45]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QSvgWidget::initPainter(a0);
        return;
    }

    extern void sipVH_QtSvgWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtSvgWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSvgWidget_renderer, "renderer(self) -> QSvgRenderer|None");

extern "C" {static PyObject *meth_QSvgWidget_renderer(PyObject *, PyObject *);}
static PyObject *meth_QSvgWidget_renderer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgWidget, &sipCpp))
        {
            ::QSvgRenderer*sipRes;

            sipRes = sipCpp->renderer();

            return sipConvertFromType(sipRes, sipType_QSvgRenderer, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgWidget, sipName_renderer, doc_QSvgWidget_renderer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgWidget_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QSvgWidget_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QSvgWidget_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSvgWidget)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QSvgWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgWidget, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QSvgWidget::sizeHint() : sipCpp->sizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgWidget, sipName_sizeHint, doc_QSvgWidget_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgWidget_load, "load(self, file: str|None)\n"
"load(self, contents: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QSvgWidget_load(PyObject *, PyObject *);}
static PyObject *meth_QSvgWidget_load(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QSvgWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgWidget, &sipCpp, sipType_QString, &a0, &a0State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->load(*a0);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QSvgWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgWidget, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->load(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgWidget, sipName_load, doc_QSvgWidget_load);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgWidget_paintEvent, "paintEvent(self, event: QPaintEvent|None)");

extern "C" {static PyObject *meth_QSvgWidget_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QSvgWidget_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSvgWidget)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::QSvgWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QSvgWidget, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QSvgWidget::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgWidget, sipName_paintEvent, doc_QSvgWidget_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgWidget_options, "options(self) -> QtSvg.Option");

extern "C" {static PyObject *meth_QSvgWidget_options(PyObject *, PyObject *);}
static PyObject *meth_QSvgWidget_options(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgWidget, &sipCpp))
        {
            ::QtSvg::Options*sipRes;

            sipRes = new ::QtSvg::Options(sipCpp->options());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QtSvg_Option, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgWidget, sipName_options, doc_QSvgWidget_options);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgWidget_setOptions, "setOptions(self, options: QtSvg.Option)");

extern "C" {static PyObject *meth_QSvgWidget_setOptions(PyObject *, PyObject *);}
static PyObject *meth_QSvgWidget_setOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtSvg::Options* a0;
        int a0State = 0;
        ::QSvgWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgWidget, &sipCpp, sipType_QFlags_0100QtSvg_Option, &a0, &a0State))
        {
            sipCpp->setOptions(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QtSvg_Option, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgWidget, sipName_setOptions, doc_QSvgWidget_setOptions);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSvgWidget(void *, const sipTypeDef *);}
static void *cast_QSvgWidget(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSvgWidget *sipCpp = reinterpret_cast< ::QSvgWidget *>(sipCppV);

    if (targetType == sipType_QSvgWidget)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWidget)->ctd_cast(static_cast< ::QWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSvgWidget(void *, int);}
static void release_QSvgWidget(void *sipCppV, int)
{
    ::QSvgWidget *sipCpp = reinterpret_cast< ::QSvgWidget *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QSvgWidget(Py_ssize_t);}
static void *array_QSvgWidget(Py_ssize_t sipNrElem)
{
    return new ::QSvgWidget[sipNrElem];
}


extern "C" {static void array_delete_QSvgWidget(void *);}
static void array_delete_QSvgWidget(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSvgWidget *>(sipCpp);
}


extern "C" {static void dealloc_QSvgWidget(sipSimpleWrapper *);}
static void dealloc_QSvgWidget(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSvgWidget *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSvgWidget(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSvgWidget(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSvgWidget(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQSvgWidget *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQSvgWidget(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWidget* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QString, &a0, &a0State, sipType_QWidget, &a1, sipOwner))
        {
            sipCpp = new sipQSvgWidget(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSvgWidget[] = {{9, 3, 1}};


static PyMethodDef methods_QSvgWidget[] = {
    {sipName_load, meth_QSvgWidget_load, METH_VARARGS, doc_QSvgWidget_load},
    {sipName_options, meth_QSvgWidget_options, METH_VARARGS, doc_QSvgWidget_options},
    {sipName_paintEvent, meth_QSvgWidget_paintEvent, METH_VARARGS, doc_QSvgWidget_paintEvent},
    {sipName_renderer, meth_QSvgWidget_renderer, METH_VARARGS, doc_QSvgWidget_renderer},
    {sipName_setOptions, meth_QSvgWidget_setOptions, METH_VARARGS, doc_QSvgWidget_setOptions},
    {sipName_sizeHint, meth_QSvgWidget_sizeHint, METH_VARARGS, doc_QSvgWidget_sizeHint}
};

PyDoc_STRVAR(doc_QSvgWidget, "\1QSvgWidget(parent: QWidget|None = None)\n"
"QSvgWidget(file: str|None, parent: QWidget|None = None)");


static pyqt6ClassPluginDef plugin_QSvgWidget = {
    &::QSvgWidget::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSvgWidgets_QSvgWidget = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSvgWidget,
        SIP_NULLPTR,
        &plugin_QSvgWidget,
    },
    {
        sipNameNr_QSvgWidget,
        {0, 0, 1},
        6, methods_QSvgWidget,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSvgWidget,
    -1,
    -1,
    supers_QSvgWidget,
    SIP_NULLPTR,
    init_type_QSvgWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSvgWidget,
    SIP_NULLPTR,
    array_QSvgWidget,
    SIP_NULLPTR,
    release_QSvgWidget,
    cast_QSvgWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSvgWidget,
    sizeof (::QSvgWidget),
};
