/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick3D.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3dobject.sip"
#include <qquick3dobject.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DObject.cpp"


PyDoc_STRVAR(doc_QQuick3DObject_state, "state(self) -> str");

extern "C" {static PyObject *meth_QQuick3DObject_state(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DObject_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DObject, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->state());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DObject, sipName_state, doc_QQuick3DObject_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DObject_setState, "setState(self, state: str|None)");

extern "C" {static PyObject *meth_QQuick3DObject_setState(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DObject_setState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QQuick3DObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQuick3DObject, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setState(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DObject, sipName_setState, doc_QQuick3DObject_setState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DObject_parentItem, "parentItem(self) -> QQuick3DObject|None");

extern "C" {static PyObject *meth_QQuick3DObject_parentItem(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DObject_parentItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DObject, &sipCpp))
        {
            ::QQuick3DObject*sipRes;

            sipRes = sipCpp->parentItem();

            return sipConvertFromType(sipRes, sipType_QQuick3DObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DObject, sipName_parentItem, doc_QQuick3DObject_parentItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DObject_setParentItem, "setParentItem(self, parentItem: QQuick3DObject|None)");

extern "C" {static PyObject *meth_QQuick3DObject_setParentItem(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DObject_setParentItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QQuick3DObject* a0;
        ::QQuick3DObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QQuick3DObject, &sipCpp, sipType_QQuick3DObject, &a0))
        {
            sipCpp->setParentItem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DObject, sipName_setParentItem, doc_QQuick3DObject_setParentItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DObject_classBegin, "classBegin(self)");

extern "C" {static PyObject *meth_QQuick3DObject_classBegin(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DObject_classBegin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QQuick3DObject)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QQuick3DObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QQuick3DObject, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QQuick3DObject::classBegin() : sipCpp->classBegin());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DObject, sipName_classBegin, doc_QQuick3DObject_classBegin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DObject_componentComplete, "componentComplete(self)");

extern "C" {static PyObject *meth_QQuick3DObject_componentComplete(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DObject_componentComplete(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QQuick3DObject)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QQuick3DObject *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QQuick3DObject, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QQuick3DObject::componentComplete() : sipCpp->componentComplete());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DObject, sipName_componentComplete, doc_QQuick3DObject_componentComplete);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQuick3DObject(void *, const sipTypeDef *);}
static void *cast_QQuick3DObject(void *sipCppV, const sipTypeDef *targetType)
{
    ::QQuick3DObject *sipCpp = reinterpret_cast< ::QQuick3DObject *>(sipCppV);

    if (targetType == sipType_QQuick3DObject)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    if (targetType == sipType_QQmlParserStatus)
        return static_cast< ::QQmlParserStatus *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQuick3DObject(void *, int);}
static void release_QQuick3DObject(void *sipCppV, int)
{
    ::QQuick3DObject *sipCpp = reinterpret_cast< ::QQuick3DObject *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QQuick3DObject(sipSimpleWrapper *);}
static void dealloc_QQuick3DObject(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuick3DObject(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQuick3DObject[] = {{4, 0, 0}, {0, 3, 1}};


static PyMethodDef methods_QQuick3DObject[] = {
    {sipName_classBegin, meth_QQuick3DObject_classBegin, METH_VARARGS, doc_QQuick3DObject_classBegin},
    {sipName_componentComplete, meth_QQuick3DObject_componentComplete, METH_VARARGS, doc_QQuick3DObject_componentComplete},
    {sipName_parentItem, meth_QQuick3DObject_parentItem, METH_VARARGS, doc_QQuick3DObject_parentItem},
    {sipName_setParentItem, meth_QQuick3DObject_setParentItem, METH_VARARGS, doc_QQuick3DObject_setParentItem},
    {sipName_setState, meth_QQuick3DObject_setState, METH_VARARGS, doc_QQuick3DObject_setState},
    {sipName_state, meth_QQuick3DObject_state, METH_VARARGS, doc_QQuick3DObject_state}
};


/* Define this type's signals. */
static const pyqt6QtSignal signals_QQuick3DObject[] = {
    {"stateChanged()", "\1stateChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QQuick3DObject = {
    &::QQuick3DObject::staticMetaObject,
    signals_QQuick3DObject,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick3D_QQuick3DObject = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuick3DObject,
        SIP_NULLPTR,
        &plugin_QQuick3DObject,
    },
    {
        sipNameNr_QQuick3DObject,
        {0, 0, 1},
        6, methods_QQuick3DObject,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QQuick3DObject,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuick3DObject,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQuick3DObject,
    cast_QQuick3DObject,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
