/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlibrary.sip"
#include <qlibrary.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLibrary.cpp"


class sipQLibrary : public ::QLibrary
{
public:
    sipQLibrary(::QObject*);
    sipQLibrary(const ::QString&, ::QObject*);
    sipQLibrary(const ::QString&, int, ::QObject*);
    sipQLibrary(const ::QString&, const ::QString&, ::QObject*);
    virtual ~sipQLibrary();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQLibrary(const sipQLibrary &);
    sipQLibrary &operator = (const sipQLibrary &);

    char sipPyMethods[7];
};

sipQLibrary::sipQLibrary(::QObject*a0): ::QLibrary(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQLibrary::sipQLibrary(const ::QString& a0, ::QObject*a1): ::QLibrary(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQLibrary::sipQLibrary(const ::QString& a0, int a1, ::QObject*a2): ::QLibrary(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQLibrary::sipQLibrary(const ::QString& a0, const ::QString& a1, ::QObject*a2): ::QLibrary(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQLibrary::~sipQLibrary()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQLibrary::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtCore_qt_metaobject(sipPySelf, sipType_QLibrary);

    return ::QLibrary::metaObject();
}

int sipQLibrary::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QLibrary::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtCore_qt_metacall(sipPySelf, sipType_QLibrary, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQLibrary::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtCore_qt_metacast(sipPySelf, sipType_QLibrary, _clname, &sipCpp) ? sipCpp : ::QLibrary::qt_metacast(_clname));
}

bool sipQLibrary::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QLibrary::event(a0);

    extern bool sipVH_QtCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtCore_0(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

bool sipQLibrary::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QLibrary::eventFilter(a0, a1);

    extern bool sipVH_QtCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtCore_1(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1);
}

void sipQLibrary::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QLibrary::timerEvent(a0);
        return;
    }

    extern void sipVH_QtCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtCore_2(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQLibrary::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QLibrary::childEvent(a0);
        return;
    }

    extern void sipVH_QtCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtCore_3(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQLibrary::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QLibrary::customEvent(a0);
        return;
    }

    extern void sipVH_QtCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtCore_4(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQLibrary::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QLibrary::connectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQLibrary::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QLibrary::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QLibrary_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QLibrary_errorString(PyObject *, PyObject *);}
static PyObject *meth_QLibrary_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLibrary, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLibrary, sipName_errorString, doc_QLibrary_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLibrary_fileName, "fileName(self) -> str");

extern "C" {static PyObject *meth_QLibrary_fileName(PyObject *, PyObject *);}
static PyObject *meth_QLibrary_fileName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLibrary, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->fileName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLibrary, sipName_fileName, doc_QLibrary_fileName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLibrary_isLoaded, "isLoaded(self) -> bool");

extern "C" {static PyObject *meth_QLibrary_isLoaded(PyObject *, PyObject *);}
static PyObject *meth_QLibrary_isLoaded(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLibrary, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLoaded();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLibrary, sipName_isLoaded, doc_QLibrary_isLoaded);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLibrary_load, "load(self) -> bool");

extern "C" {static PyObject *meth_QLibrary_load(PyObject *, PyObject *);}
static PyObject *meth_QLibrary_load(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLibrary, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->load();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLibrary, sipName_load, doc_QLibrary_load);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLibrary_loadHints, "loadHints(self) -> QLibrary.LoadHint");

extern "C" {static PyObject *meth_QLibrary_loadHints(PyObject *, PyObject *);}
static PyObject *meth_QLibrary_loadHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLibrary, &sipCpp))
        {
            ::QLibrary::LoadHints*sipRes;

            sipRes = new ::QLibrary::LoadHints(sipCpp->loadHints());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QLibrary_LoadHint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLibrary, sipName_loadHints, doc_QLibrary_loadHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLibrary_resolve, "resolve(self, symbol: str) -> PyQt6.sip.voidptr\n"
"resolve(fileName: str|None, symbol: str) -> PyQt6.sip.voidptr\n"
"resolve(fileName: str|None, verNum: int, symbol: str) -> PyQt6.sip.voidptr\n"
"resolve(fileName: str|None, version: str|None, symbol: str) -> PyQt6.sip.voidptr");

extern "C" {static PyObject *meth_QLibrary_resolve(PyObject *, PyObject *);}
static PyObject *meth_QLibrary_resolve(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const char* a0;
        PyObject *a0Keep;
        ::QLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BAA", &sipSelf, sipType_QLibrary, &sipCpp, &a0Keep, &a0))
        {
            ::QFunctionPointer sipRes;

            sipRes = sipCpp->resolve(a0);
            Py_DECREF(a0Keep);

            return sipConvertFromVoidPtr((void *)sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const char* a1;
        PyObject *a1Keep;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1AA", &sipSelf, sipType_QString, &a0, &a0State, &a1Keep, &a1))
        {
            ::QFunctionPointer sipRes;

            sipRes = ::QLibrary::resolve(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            Py_DECREF(a1Keep);

            return sipConvertFromVoidPtr((void *)sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        int a1;
        const char* a2;
        PyObject *a2Keep;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1iAA", &sipSelf, sipType_QString, &a0, &a0State, &a1, &a2Keep, &a2))
        {
            ::QFunctionPointer sipRes;

            sipRes = ::QLibrary::resolve(*a0, a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            Py_DECREF(a2Keep);

            return sipConvertFromVoidPtr((void *)sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const char* a2;
        PyObject *a2Keep;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1J1AA", &sipSelf, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, &a2Keep, &a2))
        {
            ::QFunctionPointer sipRes;

            sipRes = ::QLibrary::resolve(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            Py_DECREF(a2Keep);

            return sipConvertFromVoidPtr((void *)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLibrary, sipName_resolve, doc_QLibrary_resolve);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLibrary_unload, "unload(self) -> bool");

extern "C" {static PyObject *meth_QLibrary_unload(PyObject *, PyObject *);}
static PyObject *meth_QLibrary_unload(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLibrary, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->unload();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLibrary, sipName_unload, doc_QLibrary_unload);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLibrary_isLibrary, "isLibrary(fileName: str|None) -> bool");

extern "C" {static PyObject *meth_QLibrary_isLibrary(PyObject *, PyObject *);}
static PyObject *meth_QLibrary_isLibrary(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = ::QLibrary::isLibrary(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLibrary, sipName_isLibrary, doc_QLibrary_isLibrary);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLibrary_setFileName, "setFileName(self, fileName: str|None)");

extern "C" {static PyObject *meth_QLibrary_setFileName(PyObject *, PyObject *);}
static PyObject *meth_QLibrary_setFileName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLibrary, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setFileName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLibrary, sipName_setFileName, doc_QLibrary_setFileName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLibrary_setFileNameAndVersion, "setFileNameAndVersion(self, fileName: str|None, verNum: int)\n"
"setFileNameAndVersion(self, fileName: str|None, version: str|None)");

extern "C" {static PyObject *meth_QLibrary_setFileNameAndVersion(PyObject *, PyObject *);}
static PyObject *meth_QLibrary_setFileNameAndVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        int a1;
        ::QLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1i", &sipSelf, sipType_QLibrary, &sipCpp, sipType_QString, &a0, &a0State, &a1))
        {
            sipCpp->setFileNameAndVersion(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QLibrary, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            sipCpp->setFileNameAndVersion(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLibrary, sipName_setFileNameAndVersion, doc_QLibrary_setFileNameAndVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLibrary_setLoadHints, "setLoadHints(self, hints: QLibrary.LoadHint)");

extern "C" {static PyObject *meth_QLibrary_setLoadHints(PyObject *, PyObject *);}
static PyObject *meth_QLibrary_setLoadHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLibrary::LoadHints* a0;
        int a0State = 0;
        ::QLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLibrary, &sipCpp, sipType_QFlags_0100QLibrary_LoadHint, &a0, &a0State))
        {
            sipCpp->setLoadHints(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QLibrary_LoadHint, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLibrary, sipName_setLoadHints, doc_QLibrary_setLoadHints);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QLibrary(void *, const sipTypeDef *);}
static void *cast_QLibrary(void *sipCppV, const sipTypeDef *targetType)
{
    ::QLibrary *sipCpp = reinterpret_cast< ::QLibrary *>(sipCppV);

    if (targetType == sipType_QLibrary)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QLibrary(void *, int);}
static void release_QLibrary(void *sipCppV, int)
{
    ::QLibrary *sipCpp = reinterpret_cast< ::QLibrary *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QLibrary(Py_ssize_t);}
static void *array_QLibrary(Py_ssize_t sipNrElem)
{
    return new ::QLibrary[sipNrElem];
}


extern "C" {static void array_delete_QLibrary(void *);}
static void array_delete_QLibrary(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLibrary *>(sipCpp);
}


extern "C" {static void dealloc_QLibrary(sipSimpleWrapper *);}
static void dealloc_QLibrary(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQLibrary *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLibrary(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QLibrary(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLibrary(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQLibrary *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQLibrary(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QString, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQLibrary(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        int a1;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1i|JH", sipType_QString, &a0, &a0State, &a1, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQLibrary(*a0, a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1J1|JH", sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQLibrary(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QLibrary[] = {{255, 255, 1}};


static PyMethodDef methods_QLibrary[] = {
    {sipName_errorString, meth_QLibrary_errorString, METH_VARARGS, doc_QLibrary_errorString},
    {sipName_fileName, meth_QLibrary_fileName, METH_VARARGS, doc_QLibrary_fileName},
    {sipName_isLibrary, meth_QLibrary_isLibrary, METH_VARARGS, doc_QLibrary_isLibrary},
    {sipName_isLoaded, meth_QLibrary_isLoaded, METH_VARARGS, doc_QLibrary_isLoaded},
    {sipName_load, meth_QLibrary_load, METH_VARARGS, doc_QLibrary_load},
    {sipName_loadHints, meth_QLibrary_loadHints, METH_VARARGS, doc_QLibrary_loadHints},
    {sipName_resolve, meth_QLibrary_resolve, METH_VARARGS, doc_QLibrary_resolve},
    {sipName_setFileName, meth_QLibrary_setFileName, METH_VARARGS, doc_QLibrary_setFileName},
    {sipName_setFileNameAndVersion, meth_QLibrary_setFileNameAndVersion, METH_VARARGS, doc_QLibrary_setFileNameAndVersion},
    {sipName_setLoadHints, meth_QLibrary_setLoadHints, METH_VARARGS, doc_QLibrary_setLoadHints},
    {sipName_unload, meth_QLibrary_unload, METH_VARARGS, doc_QLibrary_unload}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QLibrary[] = {
    {sipName_ResolveAllSymbolsHint, static_cast<int>(::QLibrary::ResolveAllSymbolsHint)},
    {sipName_ExportExternalSymbolsHint, static_cast<int>(::QLibrary::ExportExternalSymbolsHint)},
    {sipName_LoadArchiveMemberHint, static_cast<int>(::QLibrary::LoadArchiveMemberHint)},
    {sipName_PreventUnloadHint, static_cast<int>(::QLibrary::PreventUnloadHint)},
    {sipName_DeepBindHint, static_cast<int>(::QLibrary::DeepBindHint)},
    {0, 0}
};

PyDoc_STRVAR(doc_QLibrary, "\1QLibrary(parent: QObject|None = None)\n"
"QLibrary(fileName: str|None, parent: QObject|None = None)\n"
"QLibrary(fileName: str|None, verNum: int, parent: QObject|None = None)\n"
"QLibrary(fileName: str|None, version: str|None, parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QLibrary = {
    &::QLibrary::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QLibrary = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLibrary,
        SIP_NULLPTR,
        &plugin_QLibrary,
    },
    {
        sipNameNr_QLibrary,
        {0, 0, 1},
        11, methods_QLibrary,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QLibrary, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLibrary,
    -1,
    -1,
    supers_QLibrary,
    SIP_NULLPTR,
    init_type_QLibrary,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLibrary,
    SIP_NULLPTR,
    array_QLibrary,
    SIP_NULLPTR,
    release_QLibrary,
    cast_QLibrary,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLibrary,
    sizeof (::QLibrary),
};
