/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qformdatabuilder.sip"
#include <qformdatabuilder.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQFormDataPartBuilder.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qhttpheaders.sip"
#include <qhttpheaders.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQFormDataPartBuilder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQFormDataPartBuilder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQFormDataPartBuilder.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearrayview.sip"
#include <qbytearrayview.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQFormDataPartBuilder.cpp"


PyDoc_STRVAR(doc_QFormDataPartBuilder_setBody, "setBody(self, data: QByteArray|bytes|bytearray|memoryview, fileName: QByteArray|bytes|bytearray|memoryview|str|None = '', mimeType: QByteArray|bytes|bytearray|memoryview|str|None = '') -> QFormDataPartBuilder");

extern "C" {static PyObject *meth_QFormDataPartBuilder_setBody(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QFormDataPartBuilder_setBody(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QByteArrayView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QAnyStringView a1def = {};
        ::QAnyStringView* a1 = &a1def;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QAnyStringView a2def = {};
        ::QAnyStringView* a2 = &a2def;
        int a2State = 0;
        void *a2UserState = SIP_NULLPTR;
        ::QFormDataPartBuilder *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_fileName,
            sipName_mimeType,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1J1", &sipSelf, sipType_QFormDataPartBuilder, &sipCpp, sipType_QByteArrayView, &a0, &a0State, &a0UserState, sipType_QAnyStringView, &a1, &a1State, &a1UserState, sipType_QAnyStringView, &a2, &a2State, &a2UserState))
        {
            ::QFormDataPartBuilder*sipRes;

            sipRes = new ::QFormDataPartBuilder(sipCpp->setBody(*a0, *a1, *a2));
            sipReleaseTypeUS(a0, sipType_QByteArrayView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);
            sipReleaseTypeUS(a2, sipType_QAnyStringView, a2State, a2UserState);

            return sipConvertFromNewType(sipRes, sipType_QFormDataPartBuilder, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFormDataPartBuilder, sipName_setBody, doc_QFormDataPartBuilder_setBody);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFormDataPartBuilder_setBodyDevice, "setBodyDevice(self, body: QIODevice|None, fileName: QByteArray|bytes|bytearray|memoryview|str|None = '', mimeType: QByteArray|bytes|bytearray|memoryview|str|None = '') -> QFormDataPartBuilder");

extern "C" {static PyObject *meth_QFormDataPartBuilder_setBodyDevice(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QFormDataPartBuilder_setBodyDevice(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QAnyStringView a1def = {};
        ::QAnyStringView* a1 = &a1def;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QAnyStringView a2def = {};
        ::QAnyStringView* a2 = &a2def;
        int a2State = 0;
        void *a2UserState = SIP_NULLPTR;
        ::QFormDataPartBuilder *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_fileName,
            sipName_mimeType,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|J1J1", &sipSelf, sipType_QFormDataPartBuilder, &sipCpp, sipType_QIODevice, &a0, sipType_QAnyStringView, &a1, &a1State, &a1UserState, sipType_QAnyStringView, &a2, &a2State, &a2UserState))
        {
            ::QFormDataPartBuilder*sipRes;

            sipRes = new ::QFormDataPartBuilder(sipCpp->setBodyDevice(a0, *a1, *a2));
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);
            sipReleaseTypeUS(a2, sipType_QAnyStringView, a2State, a2UserState);

            return sipConvertFromNewType(sipRes, sipType_QFormDataPartBuilder, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFormDataPartBuilder, sipName_setBodyDevice, doc_QFormDataPartBuilder_setBodyDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFormDataPartBuilder_setHeaders, "setHeaders(self, headers: QHttpHeaders) -> QFormDataPartBuilder");

extern "C" {static PyObject *meth_QFormDataPartBuilder_setHeaders(PyObject *, PyObject *);}
static PyObject *meth_QFormDataPartBuilder_setHeaders(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHttpHeaders* a0;
        ::QFormDataPartBuilder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QFormDataPartBuilder, &sipCpp, sipType_QHttpHeaders, &a0))
        {
            ::QFormDataPartBuilder*sipRes;

            sipRes = new ::QFormDataPartBuilder(sipCpp->setHeaders(*a0));

            return sipConvertFromNewType(sipRes, sipType_QFormDataPartBuilder, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFormDataPartBuilder, sipName_setHeaders, doc_QFormDataPartBuilder_setHeaders);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFormDataPartBuilder_swap, "swap(self, other: QFormDataPartBuilder)");

extern "C" {static PyObject *meth_QFormDataPartBuilder_swap(PyObject *, PyObject *);}
static PyObject *meth_QFormDataPartBuilder_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QFormDataPartBuilder* a0;
        ::QFormDataPartBuilder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QFormDataPartBuilder, &sipCpp, sipType_QFormDataPartBuilder, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QFormDataPartBuilder, sipName_swap, doc_QFormDataPartBuilder_swap);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QFormDataPartBuilder(void *, int);}
static void release_QFormDataPartBuilder(void *sipCppV, int)
{
    delete reinterpret_cast< ::QFormDataPartBuilder *>(sipCppV);
}


extern "C" {static void *array_QFormDataPartBuilder(Py_ssize_t);}
static void *array_QFormDataPartBuilder(Py_ssize_t sipNrElem)
{
    return new ::QFormDataPartBuilder[sipNrElem];
}


extern "C" {static void array_delete_QFormDataPartBuilder(void *);}
static void array_delete_QFormDataPartBuilder(void *sipCpp)
{
    delete[] reinterpret_cast< ::QFormDataPartBuilder *>(sipCpp);
}


extern "C" {static void assign_QFormDataPartBuilder(void *, Py_ssize_t, void *);}
static void assign_QFormDataPartBuilder(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QFormDataPartBuilder *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QFormDataPartBuilder *>(sipSrc);
}


extern "C" {static void *copy_QFormDataPartBuilder(const void *, Py_ssize_t);}
static void *copy_QFormDataPartBuilder(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QFormDataPartBuilder(reinterpret_cast<const ::QFormDataPartBuilder *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QFormDataPartBuilder(sipSimpleWrapper *);}
static void dealloc_QFormDataPartBuilder(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QFormDataPartBuilder(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QFormDataPartBuilder(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QFormDataPartBuilder(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QFormDataPartBuilder *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QFormDataPartBuilder();

            return sipCpp;
        }
    }

    {
        const ::QFormDataPartBuilder* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QFormDataPartBuilder, &a0))
        {
            sipCpp = new ::QFormDataPartBuilder(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QFormDataPartBuilder[] = {
    {sipName_setBody, SIP_MLMETH_CAST(meth_QFormDataPartBuilder_setBody), METH_VARARGS|METH_KEYWORDS, doc_QFormDataPartBuilder_setBody},
    {sipName_setBodyDevice, SIP_MLMETH_CAST(meth_QFormDataPartBuilder_setBodyDevice), METH_VARARGS|METH_KEYWORDS, doc_QFormDataPartBuilder_setBodyDevice},
    {sipName_setHeaders, meth_QFormDataPartBuilder_setHeaders, METH_VARARGS, doc_QFormDataPartBuilder_setHeaders},
    {sipName_swap, meth_QFormDataPartBuilder_swap, METH_VARARGS, doc_QFormDataPartBuilder_swap}
};

PyDoc_STRVAR(doc_QFormDataPartBuilder, "\1QFormDataPartBuilder()\n"
"QFormDataPartBuilder(a0: QFormDataPartBuilder)");


sipClassTypeDef sipTypeDef_QtNetwork_QFormDataPartBuilder = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QFormDataPartBuilder,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QFormDataPartBuilder,
        {0, 0, 1},
        4, methods_QFormDataPartBuilder,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QFormDataPartBuilder,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QFormDataPartBuilder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QFormDataPartBuilder,
    assign_QFormDataPartBuilder,
    array_QFormDataPartBuilder,
    copy_QFormDataPartBuilder,
    release_QFormDataPartBuilder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QFormDataPartBuilder,
    sizeof (::QFormDataPartBuilder),
};
