/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeosatelliteinfosource.sip"
#include <qgeosatelliteinfosource.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeosatelliteinfo.sip"
#include <qgeosatelliteinfo.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 27 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoSatelliteInfoSource.cpp"


class sipQGeoSatelliteInfoSource : public ::QGeoSatelliteInfoSource
{
public:
    sipQGeoSatelliteInfoSource(::QObject*);
    virtual ~sipQGeoSatelliteInfoSource();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QVariant backendProperty(const ::QString&) const SIP_OVERRIDE;
    bool setBackendProperty(const ::QString&, const ::QVariant&) SIP_OVERRIDE;
    void requestUpdate(int) SIP_OVERRIDE;
    void stopUpdates() SIP_OVERRIDE;
    void startUpdates() SIP_OVERRIDE;
    ::QGeoSatelliteInfoSource::Error error() const SIP_OVERRIDE;
    int minimumUpdateInterval() const SIP_OVERRIDE;
    void setUpdateInterval(int) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGeoSatelliteInfoSource(const sipQGeoSatelliteInfoSource &);
    sipQGeoSatelliteInfoSource &operator = (const sipQGeoSatelliteInfoSource &);

    char sipPyMethods[15];
};

sipQGeoSatelliteInfoSource::sipQGeoSatelliteInfoSource(::QObject*a0): ::QGeoSatelliteInfoSource(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGeoSatelliteInfoSource::~sipQGeoSatelliteInfoSource()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGeoSatelliteInfoSource::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtPositioning_qt_metaobject(sipPySelf, sipType_QGeoSatelliteInfoSource);

    return ::QGeoSatelliteInfoSource::metaObject();
}

int sipQGeoSatelliteInfoSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGeoSatelliteInfoSource::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtPositioning_qt_metacall(sipPySelf, sipType_QGeoSatelliteInfoSource, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGeoSatelliteInfoSource::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtPositioning_qt_metacast(sipPySelf, sipType_QGeoSatelliteInfoSource, _clname, &sipCpp) ? sipCpp : ::QGeoSatelliteInfoSource::qt_metacast(_clname));
}

::QVariant sipQGeoSatelliteInfoSource::backendProperty(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_backendProperty);

    if (!sipMeth)
        return ::QGeoSatelliteInfoSource::backendProperty(a0);

    extern ::QVariant sipVH_QtPositioning_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtPositioning_15(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoSatelliteInfoSource::setBackendProperty(const ::QString& a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_setBackendProperty);

    if (!sipMeth)
        return ::QGeoSatelliteInfoSource::setBackendProperty(a0, a1);

    extern bool sipVH_QtPositioning_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, const ::QVariant&);

    return sipVH_QtPositioning_14(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGeoSatelliteInfoSource::requestUpdate(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, sipName_QGeoSatelliteInfoSource, sipName_requestUpdate);

    if (!sipMeth)
        return;

    extern void sipVH_QtPositioning_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtPositioning_16(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoSatelliteInfoSource::stopUpdates()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, sipName_QGeoSatelliteInfoSource, sipName_stopUpdates);

    if (!sipMeth)
        return;

    extern void sipVH_QtPositioning_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtPositioning_22(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGeoSatelliteInfoSource::startUpdates()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, sipName_QGeoSatelliteInfoSource, sipName_startUpdates);

    if (!sipMeth)
        return;

    extern void sipVH_QtPositioning_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtPositioning_22(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QGeoSatelliteInfoSource::Error sipQGeoSatelliteInfoSource::error() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QGeoSatelliteInfoSource, sipName_error);

    if (!sipMeth)
        return ::QGeoSatelliteInfoSource::AccessError;

    extern ::QGeoSatelliteInfoSource::Error sipVH_QtPositioning_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPositioning_23(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQGeoSatelliteInfoSource::minimumUpdateInterval() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QGeoSatelliteInfoSource, sipName_minimumUpdateInterval);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtPositioning_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPositioning_20(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGeoSatelliteInfoSource::setUpdateInterval(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_setUpdateInterval);

    if (!sipMeth)
    {
        ::QGeoSatelliteInfoSource::setUpdateInterval(a0);
        return;
    }

    extern void sipVH_QtPositioning_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtPositioning_16(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoSatelliteInfoSource::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGeoSatelliteInfoSource::event(a0);

    extern bool sipVH_QtPositioning_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtPositioning_5(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoSatelliteInfoSource::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGeoSatelliteInfoSource::eventFilter(a0, a1);

    extern bool sipVH_QtPositioning_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtPositioning_4(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGeoSatelliteInfoSource::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGeoSatelliteInfoSource::timerEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtPositioning_3(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoSatelliteInfoSource::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGeoSatelliteInfoSource::childEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtPositioning_2(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoSatelliteInfoSource::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGeoSatelliteInfoSource::customEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPositioning_1(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoSatelliteInfoSource::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGeoSatelliteInfoSource::connectNotify(a0);
        return;
    }

    extern void sipVH_QtPositioning_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPositioning_0(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoSatelliteInfoSource::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGeoSatelliteInfoSource::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtPositioning_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPositioning_0(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_createDefaultSource, "createDefaultSource(parent: QObject|None) -> QGeoSatelliteInfoSource|None\n"
"createDefaultSource(parameters: dict[str|None, Any], parent: QObject|None) -> QGeoSatelliteInfoSource|None");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_createDefaultSource(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_createDefaultSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        sipWrapper *sipOwner = SIP_NULLPTR;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJH", &sipSelf, sipType_QObject, &a0, &sipOwner))
        {
            ::QGeoSatelliteInfoSource*sipRes;

            sipRes = ::QGeoSatelliteInfoSource::createDefaultSource(a0);

            return sipConvertFromType(sipRes, sipType_QGeoSatelliteInfoSource, Py_None);
        }
    }

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QObject* a1;
        sipWrapper *sipOwner = SIP_NULLPTR;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1JH", &sipSelf, sipType_QMap_0100QString_0100QVariant, &a0, &a0State, sipType_QObject, &a1, &sipOwner))
        {
            ::QGeoSatelliteInfoSource*sipRes;

            sipRes = ::QGeoSatelliteInfoSource::createDefaultSource(*a0, a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QMap_0100QString_0100QVariant, a0State);

            return sipConvertFromType(sipRes, sipType_QGeoSatelliteInfoSource, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_createDefaultSource, doc_QGeoSatelliteInfoSource_createDefaultSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_createSource, "createSource(sourceName: str|None, parent: QObject|None) -> QGeoSatelliteInfoSource|None\n"
"createSource(sourceName: str|None, parameters: dict[str|None, Any], parent: QObject|None) -> QGeoSatelliteInfoSource|None");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_createSource(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_createSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1;
        sipWrapper *sipOwner = SIP_NULLPTR;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1JH", &sipSelf, sipType_QString, &a0, &a0State, sipType_QObject, &a1, &sipOwner))
        {
            ::QGeoSatelliteInfoSource*sipRes;

            sipRes = ::QGeoSatelliteInfoSource::createSource(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(sipRes, sipType_QGeoSatelliteInfoSource, Py_None);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariantMap* a1;
        int a1State = 0;
        ::QObject* a2;
        sipWrapper *sipOwner = SIP_NULLPTR;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1J1JH", &sipSelf, sipType_QString, &a0, &a0State, sipType_QMap_0100QString_0100QVariant, &a1, &a1State, sipType_QObject, &a2, &sipOwner))
        {
            ::QGeoSatelliteInfoSource*sipRes;

            sipRes = ::QGeoSatelliteInfoSource::createSource(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariantMap *>(a1), sipType_QMap_0100QString_0100QVariant, a1State);

            return sipConvertFromType(sipRes, sipType_QGeoSatelliteInfoSource, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_createSource, doc_QGeoSatelliteInfoSource_createSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_availableSources, "availableSources() -> list[str]");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_availableSources(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_availableSources(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QGeoSatelliteInfoSource::availableSources());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_availableSources, doc_QGeoSatelliteInfoSource_availableSources);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_sourceName, "sourceName(self) -> str");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_sourceName(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_sourceName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoSatelliteInfoSource, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->sourceName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_sourceName, doc_QGeoSatelliteInfoSource_sourceName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_setUpdateInterval, "setUpdateInterval(self, msec: int)");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_setUpdateInterval(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_setUpdateInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGeoSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::QGeoSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QGeoSatelliteInfoSource, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGeoSatelliteInfoSource::setUpdateInterval(a0) : sipCpp->setUpdateInterval(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_setUpdateInterval, doc_QGeoSatelliteInfoSource_setUpdateInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_updateInterval, "updateInterval(self) -> int");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_updateInterval(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_updateInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoSatelliteInfoSource, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->updateInterval();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_updateInterval, doc_QGeoSatelliteInfoSource_updateInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_minimumUpdateInterval, "minimumUpdateInterval(self) -> int");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_minimumUpdateInterval(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_minimumUpdateInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QGeoSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoSatelliteInfoSource, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoSatelliteInfoSource, sipName_minimumUpdateInterval);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->minimumUpdateInterval();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_minimumUpdateInterval, doc_QGeoSatelliteInfoSource_minimumUpdateInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_error, "error(self) -> QGeoSatelliteInfoSource.Error");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_error(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QGeoSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoSatelliteInfoSource, &sipCpp))
        {
            ::QGeoSatelliteInfoSource::Error sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoSatelliteInfoSource, sipName_error);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoSatelliteInfoSource_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_error, doc_QGeoSatelliteInfoSource_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_startUpdates, "startUpdates(self)");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_startUpdates(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_startUpdates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QGeoSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoSatelliteInfoSource, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoSatelliteInfoSource, sipName_startUpdates);
                return SIP_NULLPTR;
            }

            sipCpp->startUpdates();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_startUpdates, doc_QGeoSatelliteInfoSource_startUpdates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_stopUpdates, "stopUpdates(self)");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_stopUpdates(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_stopUpdates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QGeoSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoSatelliteInfoSource, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoSatelliteInfoSource, sipName_stopUpdates);
                return SIP_NULLPTR;
            }

            sipCpp->stopUpdates();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_stopUpdates, doc_QGeoSatelliteInfoSource_stopUpdates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_requestUpdate, "requestUpdate(self, timeout: int = 0)");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_requestUpdate(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_requestUpdate(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0 = 0;
        ::QGeoSatelliteInfoSource *sipCpp;

        static const char *sipKwdList[] = {
            sipName_timeout,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QGeoSatelliteInfoSource, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoSatelliteInfoSource, sipName_requestUpdate);
                return SIP_NULLPTR;
            }

            sipCpp->requestUpdate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_requestUpdate, doc_QGeoSatelliteInfoSource_requestUpdate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_setBackendProperty, "setBackendProperty(self, name: str|None, value: Any) -> bool");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_setBackendProperty(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_setBackendProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGeoSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QGeoSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QGeoSatelliteInfoSource, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGeoSatelliteInfoSource::setBackendProperty(*a0, *a1) : sipCpp->setBackendProperty(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_setBackendProperty, doc_QGeoSatelliteInfoSource_setBackendProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoSatelliteInfoSource_backendProperty, "backendProperty(self, name: str|None) -> Any");

extern "C" {static PyObject *meth_QGeoSatelliteInfoSource_backendProperty(PyObject *, PyObject *);}
static PyObject *meth_QGeoSatelliteInfoSource_backendProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGeoSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QGeoSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoSatelliteInfoSource, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QGeoSatelliteInfoSource::backendProperty(*a0) : sipCpp->backendProperty(*a0)));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoSatelliteInfoSource, sipName_backendProperty, doc_QGeoSatelliteInfoSource_backendProperty);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGeoSatelliteInfoSource(void *, const sipTypeDef *);}
static void *cast_QGeoSatelliteInfoSource(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGeoSatelliteInfoSource *sipCpp = reinterpret_cast< ::QGeoSatelliteInfoSource *>(sipCppV);

    if (targetType == sipType_QGeoSatelliteInfoSource)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoSatelliteInfoSource(void *, int);}
static void release_QGeoSatelliteInfoSource(void *sipCppV, int)
{
    ::QGeoSatelliteInfoSource *sipCpp = reinterpret_cast< ::QGeoSatelliteInfoSource *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QGeoSatelliteInfoSource(sipSimpleWrapper *);}
static void dealloc_QGeoSatelliteInfoSource(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGeoSatelliteInfoSource *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoSatelliteInfoSource(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGeoSatelliteInfoSource(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoSatelliteInfoSource(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGeoSatelliteInfoSource *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQGeoSatelliteInfoSource(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGeoSatelliteInfoSource[] = {{9, 0, 1}};


static PyMethodDef methods_QGeoSatelliteInfoSource[] = {
    {sipName_availableSources, meth_QGeoSatelliteInfoSource_availableSources, METH_VARARGS, doc_QGeoSatelliteInfoSource_availableSources},
    {sipName_backendProperty, meth_QGeoSatelliteInfoSource_backendProperty, METH_VARARGS, doc_QGeoSatelliteInfoSource_backendProperty},
    {sipName_createDefaultSource, meth_QGeoSatelliteInfoSource_createDefaultSource, METH_VARARGS, doc_QGeoSatelliteInfoSource_createDefaultSource},
    {sipName_createSource, meth_QGeoSatelliteInfoSource_createSource, METH_VARARGS, doc_QGeoSatelliteInfoSource_createSource},
    {sipName_error, meth_QGeoSatelliteInfoSource_error, METH_VARARGS, doc_QGeoSatelliteInfoSource_error},
    {sipName_minimumUpdateInterval, meth_QGeoSatelliteInfoSource_minimumUpdateInterval, METH_VARARGS, doc_QGeoSatelliteInfoSource_minimumUpdateInterval},
    {sipName_requestUpdate, SIP_MLMETH_CAST(meth_QGeoSatelliteInfoSource_requestUpdate), METH_VARARGS|METH_KEYWORDS, doc_QGeoSatelliteInfoSource_requestUpdate},
    {sipName_setBackendProperty, meth_QGeoSatelliteInfoSource_setBackendProperty, METH_VARARGS, doc_QGeoSatelliteInfoSource_setBackendProperty},
    {sipName_setUpdateInterval, meth_QGeoSatelliteInfoSource_setUpdateInterval, METH_VARARGS, doc_QGeoSatelliteInfoSource_setUpdateInterval},
    {sipName_sourceName, meth_QGeoSatelliteInfoSource_sourceName, METH_VARARGS, doc_QGeoSatelliteInfoSource_sourceName},
    {sipName_startUpdates, meth_QGeoSatelliteInfoSource_startUpdates, METH_VARARGS, doc_QGeoSatelliteInfoSource_startUpdates},
    {sipName_stopUpdates, meth_QGeoSatelliteInfoSource_stopUpdates, METH_VARARGS, doc_QGeoSatelliteInfoSource_stopUpdates},
    {sipName_updateInterval, meth_QGeoSatelliteInfoSource_updateInterval, METH_VARARGS, doc_QGeoSatelliteInfoSource_updateInterval}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QGeoSatelliteInfoSource[] = {
    {sipName_AccessError, static_cast<int>(::QGeoSatelliteInfoSource::AccessError)},
    {sipName_ClosedError, static_cast<int>(::QGeoSatelliteInfoSource::ClosedError)},
    {sipName_NoError, static_cast<int>(::QGeoSatelliteInfoSource::NoError)},
    {sipName_UnknownSourceError, static_cast<int>(::QGeoSatelliteInfoSource::UnknownSourceError)},
    {sipName_UpdateTimeoutError, static_cast<int>(::QGeoSatelliteInfoSource::UpdateTimeoutError)},
    {0, 0}
};

PyDoc_STRVAR(doc_QGeoSatelliteInfoSource, "\1QGeoSatelliteInfoSource(parent: QObject|None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QGeoSatelliteInfoSource[] = {
    {"errorOccurred(QGeoSatelliteInfoSource::Error)", "\1errorOccurred(self, a0: QGeoSatelliteInfoSource.Error)", SIP_NULLPTR, SIP_NULLPTR},
    {"satellitesInUseUpdated(QList<QGeoSatelliteInfo>)", "\1satellitesInUseUpdated(self, satellites: Iterable[QGeoSatelliteInfo])", SIP_NULLPTR, SIP_NULLPTR},
    {"satellitesInViewUpdated(QList<QGeoSatelliteInfo>)", "\1satellitesInViewUpdated(self, satellites: Iterable[QGeoSatelliteInfo])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QGeoSatelliteInfoSource = {
    &::QGeoSatelliteInfoSource::staticMetaObject,
    signals_QGeoSatelliteInfoSource,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPositioning_QGeoSatelliteInfoSource = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoSatelliteInfoSource,
        SIP_NULLPTR,
        &plugin_QGeoSatelliteInfoSource,
    },
    {
        sipNameNr_QGeoSatelliteInfoSource,
        {0, 0, 1},
        13, methods_QGeoSatelliteInfoSource,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QGeoSatelliteInfoSource, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoSatelliteInfoSource,
    -1,
    -1,
    supers_QGeoSatelliteInfoSource,
    SIP_NULLPTR,
    init_type_QGeoSatelliteInfoSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoSatelliteInfoSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QGeoSatelliteInfoSource,
    cast_QGeoSatelliteInfoSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QGeoSatelliteInfoSource),
};
