/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtRemoteObjects.h"

#line 44 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectnode.sip"
#include <qremoteobjectnode.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_std_pair.sip"
#include <utility>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qtremoteobjectglobal.sip"
#include <qtremoteobjectglobal.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectnode.sip"
#include <qremoteobjectnode.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectregistry.sip"
#include <qremoteobjectregistry.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectabstractitemmodelreplica.sip"
#include <qremoteobjectabstractitemmodelreplica.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qtremoteobjectglobal.sip"
#include <qtremoteobjectglobal.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 789 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectdynamicreplica.sip"
#include <qremoteobjectdynamicreplica.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringview.sip"
#include <qstringview.h>
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 112 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 118 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectNode.cpp"


class sipQRemoteObjectNode : public ::QRemoteObjectNode
{
public:
    sipQRemoteObjectNode(::QObject*);
    sipQRemoteObjectNode(const ::QUrl&, ::QObject*);
    virtual ~sipQRemoteObjectNode();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool setRegistryUrl(const ::QUrl&) SIP_OVERRIDE;
    void setName(const ::QString&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQRemoteObjectNode(const sipQRemoteObjectNode &);
    sipQRemoteObjectNode &operator = (const sipQRemoteObjectNode &);

    char sipPyMethods[9];
};

sipQRemoteObjectNode::sipQRemoteObjectNode(::QObject*a0): ::QRemoteObjectNode(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQRemoteObjectNode::sipQRemoteObjectNode(const ::QUrl& a0, ::QObject*a1): ::QRemoteObjectNode(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQRemoteObjectNode::~sipQRemoteObjectNode()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQRemoteObjectNode::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtRemoteObjects_qt_metaobject(sipPySelf, sipType_QRemoteObjectNode);

    return ::QRemoteObjectNode::metaObject();
}

int sipQRemoteObjectNode::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QRemoteObjectNode::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtRemoteObjects_qt_metacall(sipPySelf, sipType_QRemoteObjectNode, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQRemoteObjectNode::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtRemoteObjects_qt_metacast(sipPySelf, sipType_QRemoteObjectNode, _clname, &sipCpp) ? sipCpp : ::QRemoteObjectNode::qt_metacast(_clname));
}

bool sipQRemoteObjectNode::setRegistryUrl(const ::QUrl& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_setRegistryUrl);

    if (!sipMeth)
        return ::QRemoteObjectNode::setRegistryUrl(a0);

    extern bool sipVH_QtRemoteObjects_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QUrl&);

    return sipVH_QtRemoteObjects_35(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectNode::setName(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_setName);

    if (!sipMeth)
    {
        ::QRemoteObjectNode::setName(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    sipVH_QtRemoteObjects_34(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRemoteObjectNode::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QRemoteObjectNode::event(a0);

    extern bool sipVH_QtRemoteObjects_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtRemoteObjects_25(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRemoteObjectNode::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QRemoteObjectNode::eventFilter(a0, a1);

    extern bool sipVH_QtRemoteObjects_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtRemoteObjects_26(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQRemoteObjectNode::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QRemoteObjectNode::timerEvent(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtRemoteObjects_27(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectNode::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QRemoteObjectNode::childEvent(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtRemoteObjects_28(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectNode::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QRemoteObjectNode::customEvent(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtRemoteObjects_29(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectNode::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QRemoteObjectNode::connectNotify(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtRemoteObjects_30(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectNode::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QRemoteObjectNode::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtRemoteObjects_30(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QRemoteObjectNode_connectToNode, "connectToNode(self, address: QUrl) -> bool");

extern "C" {static PyObject *meth_QRemoteObjectNode_connectToNode(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_connectToNode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRemoteObjectNode, &sipCpp, sipType_QUrl, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->connectToNode(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_connectToNode, doc_QRemoteObjectNode_connectToNode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_addClientSideConnection, "addClientSideConnection(self, ioDevice: QIODevice|None)");

extern "C" {static PyObject *meth_QRemoteObjectNode_addClientSideConnection(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_addClientSideConnection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QRemoteObjectNode, &sipCpp, sipType_QIODevice, &a0))
        {
            sipCpp->addClientSideConnection(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_addClientSideConnection, doc_QRemoteObjectNode_addClientSideConnection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_setName, "setName(self, name: str|None)");

extern "C" {static PyObject *meth_QRemoteObjectNode_setName(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRemoteObjectNode)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QRemoteObjectNode, &sipCpp, sipType_QString, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QRemoteObjectNode::setName(*a0) : sipCpp->setName(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_setName, doc_QRemoteObjectNode_setName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_instances, "instances(self, typeName: str) -> list[str]");

extern "C" {static PyObject *meth_QRemoteObjectNode_instances(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_instances(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        const ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QRemoteObjectNode, &sipCpp, sipType_QStringView, &a0, &a0State, &a0UserState))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->instances(*a0));
            sipReleaseTypeUS(a0, sipType_QStringView, a0State, a0UserState);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_instances, doc_QRemoteObjectNode_instances);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_acquireDynamic, "acquireDynamic(self, name: str|None) -> QRemoteObjectDynamicReplica|None");

extern "C" {static PyObject *meth_QRemoteObjectNode_acquireDynamic(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_acquireDynamic(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QRemoteObjectNode, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QRemoteObjectDynamicReplica*sipRes;

            sipRes = sipCpp->acquireDynamic(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(sipRes, sipType_QRemoteObjectDynamicReplica, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_acquireDynamic, doc_QRemoteObjectNode_acquireDynamic);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_acquireModel, "acquireModel(self, name: str|None, action: QtRemoteObjects.InitialAction = QtRemoteObjects.FetchRootSize, rolesHint: Iterable[int] = []) -> QAbstractItemModelReplica|None");

extern "C" {static PyObject *meth_QRemoteObjectNode_acquireModel(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_acquireModel(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtRemoteObjects::InitialAction a1 = QtRemoteObjects::FetchRootSize;
        const ::QList<int>& a2def = {};
        const ::QList<int>* a2 = &a2def;
        int a2State = 0;
        ::QRemoteObjectNode *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_action,
            sipName_rolesHint,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|EJ1", &sipSelf, sipType_QRemoteObjectNode, &sipCpp, sipType_QString, &a0, &a0State, sipType_QtRemoteObjects_InitialAction, &a1, sipType_QList_1800, &a2, &a2State))
        {
            ::QAbstractItemModelReplica*sipRes;

            sipRes = sipCpp->acquireModel(*a0, a1, *a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QList<int> *>(a2), sipType_QList_1800, a2State);

            return sipConvertFromType(sipRes, sipType_QAbstractItemModelReplica, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_acquireModel, doc_QRemoteObjectNode_acquireModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_registryUrl, "registryUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QRemoteObjectNode_registryUrl(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_registryUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRemoteObjectNode, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->registryUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_registryUrl, doc_QRemoteObjectNode_registryUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_setRegistryUrl, "setRegistryUrl(self, registryAddress: QUrl) -> bool");

extern "C" {static PyObject *meth_QRemoteObjectNode_setRegistryUrl(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_setRegistryUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRemoteObjectNode)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QUrl* a0;
        ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRemoteObjectNode, &sipCpp, sipType_QUrl, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRemoteObjectNode::setRegistryUrl(*a0) : sipCpp->setRegistryUrl(*a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_setRegistryUrl, doc_QRemoteObjectNode_setRegistryUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_waitForRegistry, "waitForRegistry(self, timeout: int = 30000) -> bool");

extern "C" {static PyObject *meth_QRemoteObjectNode_waitForRegistry(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_waitForRegistry(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = 30000;
        ::QRemoteObjectNode *sipCpp;

        static const char *sipKwdList[] = {
            sipName_timeout,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QRemoteObjectNode, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->waitForRegistry(a0);
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_waitForRegistry, doc_QRemoteObjectNode_waitForRegistry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_registry, "registry(self) -> QRemoteObjectRegistry|None");

extern "C" {static PyObject *meth_QRemoteObjectNode_registry(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_registry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRemoteObjectNode, &sipCpp))
        {
            const ::QRemoteObjectRegistry*sipRes;

            sipRes = sipCpp->registry();

            return sipConvertFromType(const_cast< ::QRemoteObjectRegistry *>(sipRes), sipType_QRemoteObjectRegistry, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_registry, doc_QRemoteObjectNode_registry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_persistedStore, "persistedStore(self) -> QRemoteObjectAbstractPersistedStore|None");

extern "C" {static PyObject *meth_QRemoteObjectNode_persistedStore(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_persistedStore(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRemoteObjectNode, &sipCpp))
        {
            ::QRemoteObjectAbstractPersistedStore*sipRes;

            sipRes = sipCpp->persistedStore();

            return sipConvertFromType(sipRes, sipType_QRemoteObjectAbstractPersistedStore, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_persistedStore, doc_QRemoteObjectNode_persistedStore);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_setPersistedStore, "setPersistedStore(self, persistedStore: QRemoteObjectAbstractPersistedStore|None)");

extern "C" {static PyObject *meth_QRemoteObjectNode_setPersistedStore(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_setPersistedStore(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRemoteObjectAbstractPersistedStore* a0;
        ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QRemoteObjectNode, &sipCpp, sipType_QRemoteObjectAbstractPersistedStore, &a0))
        {
            sipCpp->setPersistedStore(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_setPersistedStore, doc_QRemoteObjectNode_setPersistedStore);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_lastError, "lastError(self) -> QRemoteObjectNode.ErrorCode");

extern "C" {static PyObject *meth_QRemoteObjectNode_lastError(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_lastError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRemoteObjectNode, &sipCpp))
        {
            ::QRemoteObjectNode::ErrorCode sipRes;

            sipRes = sipCpp->lastError();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRemoteObjectNode_ErrorCode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_lastError, doc_QRemoteObjectNode_lastError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_heartbeatInterval, "heartbeatInterval(self) -> int");

extern "C" {static PyObject *meth_QRemoteObjectNode_heartbeatInterval(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_heartbeatInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRemoteObjectNode, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->heartbeatInterval();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_heartbeatInterval, doc_QRemoteObjectNode_heartbeatInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_setHeartbeatInterval, "setHeartbeatInterval(self, interval: int)");

extern "C" {static PyObject *meth_QRemoteObjectNode_setHeartbeatInterval(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_setHeartbeatInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QRemoteObjectNode, &sipCpp, &a0))
        {
            sipCpp->setHeartbeatInterval(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_setHeartbeatInterval, doc_QRemoteObjectNode_setHeartbeatInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectNode_timerEvent, "timerEvent(self, a0: QTimerEvent|None)");

extern "C" {static PyObject *meth_QRemoteObjectNode_timerEvent(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectNode_timerEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRemoteObjectNode)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QTimerEvent* a0;
        ::QRemoteObjectNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QRemoteObjectNode, &sipCpp, sipType_QTimerEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QRemoteObjectNode::timerEvent(a0) : sipCpp->timerEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectNode, sipName_timerEvent, doc_QRemoteObjectNode_timerEvent);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRemoteObjectNode(void *, const sipTypeDef *);}
static void *cast_QRemoteObjectNode(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRemoteObjectNode *sipCpp = reinterpret_cast< ::QRemoteObjectNode *>(sipCppV);

    if (targetType == sipType_QRemoteObjectNode)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRemoteObjectNode(void *, int);}
static void release_QRemoteObjectNode(void *sipCppV, int)
{
    ::QRemoteObjectNode *sipCpp = reinterpret_cast< ::QRemoteObjectNode *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QRemoteObjectNode(Py_ssize_t);}
static void *array_QRemoteObjectNode(Py_ssize_t sipNrElem)
{
    return new ::QRemoteObjectNode[sipNrElem];
}


extern "C" {static void array_delete_QRemoteObjectNode(void *);}
static void array_delete_QRemoteObjectNode(void *sipCpp)
{
    delete[] reinterpret_cast< ::QRemoteObjectNode *>(sipCpp);
}


extern "C" {static void dealloc_QRemoteObjectNode(sipSimpleWrapper *);}
static void dealloc_QRemoteObjectNode(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQRemoteObjectNode *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRemoteObjectNode(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QRemoteObjectNode(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QRemoteObjectNode(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQRemoteObjectNode *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQRemoteObjectNode(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QUrl* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|JH", sipType_QUrl, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQRemoteObjectNode(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRemoteObjectNode[] = {{19, 0, 1}};


static PyMethodDef methods_QRemoteObjectNode[] = {
    {sipName_acquireDynamic, meth_QRemoteObjectNode_acquireDynamic, METH_VARARGS, doc_QRemoteObjectNode_acquireDynamic},
    {sipName_acquireModel, SIP_MLMETH_CAST(meth_QRemoteObjectNode_acquireModel), METH_VARARGS|METH_KEYWORDS, doc_QRemoteObjectNode_acquireModel},
    {sipName_addClientSideConnection, meth_QRemoteObjectNode_addClientSideConnection, METH_VARARGS, doc_QRemoteObjectNode_addClientSideConnection},
    {sipName_connectToNode, meth_QRemoteObjectNode_connectToNode, METH_VARARGS, doc_QRemoteObjectNode_connectToNode},
    {sipName_heartbeatInterval, meth_QRemoteObjectNode_heartbeatInterval, METH_VARARGS, doc_QRemoteObjectNode_heartbeatInterval},
    {sipName_instances, meth_QRemoteObjectNode_instances, METH_VARARGS, doc_QRemoteObjectNode_instances},
    {sipName_lastError, meth_QRemoteObjectNode_lastError, METH_VARARGS, doc_QRemoteObjectNode_lastError},
    {sipName_persistedStore, meth_QRemoteObjectNode_persistedStore, METH_VARARGS, doc_QRemoteObjectNode_persistedStore},
    {sipName_registry, meth_QRemoteObjectNode_registry, METH_VARARGS, doc_QRemoteObjectNode_registry},
    {sipName_registryUrl, meth_QRemoteObjectNode_registryUrl, METH_VARARGS, doc_QRemoteObjectNode_registryUrl},
    {sipName_setHeartbeatInterval, meth_QRemoteObjectNode_setHeartbeatInterval, METH_VARARGS, doc_QRemoteObjectNode_setHeartbeatInterval},
    {sipName_setName, meth_QRemoteObjectNode_setName, METH_VARARGS, doc_QRemoteObjectNode_setName},
    {sipName_setPersistedStore, meth_QRemoteObjectNode_setPersistedStore, METH_VARARGS, doc_QRemoteObjectNode_setPersistedStore},
    {sipName_setRegistryUrl, meth_QRemoteObjectNode_setRegistryUrl, METH_VARARGS, doc_QRemoteObjectNode_setRegistryUrl},
    {sipName_timerEvent, meth_QRemoteObjectNode_timerEvent, METH_VARARGS, doc_QRemoteObjectNode_timerEvent},
    {sipName_waitForRegistry, SIP_MLMETH_CAST(meth_QRemoteObjectNode_waitForRegistry), METH_VARARGS|METH_KEYWORDS, doc_QRemoteObjectNode_waitForRegistry}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QRemoteObjectNode[] = {
    {sipName_NoError, static_cast<int>(::QRemoteObjectNode::NoError)},
    {sipName_RegistryNotAcquired, static_cast<int>(::QRemoteObjectNode::RegistryNotAcquired)},
    {sipName_RegistryAlreadyHosted, static_cast<int>(::QRemoteObjectNode::RegistryAlreadyHosted)},
    {sipName_NodeIsNoServer, static_cast<int>(::QRemoteObjectNode::NodeIsNoServer)},
    {sipName_ServerAlreadyCreated, static_cast<int>(::QRemoteObjectNode::ServerAlreadyCreated)},
    {sipName_UnintendedRegistryHosting, static_cast<int>(::QRemoteObjectNode::UnintendedRegistryHosting)},
    {sipName_OperationNotValidOnClientNode, static_cast<int>(::QRemoteObjectNode::OperationNotValidOnClientNode)},
    {sipName_SourceNotRegistered, static_cast<int>(::QRemoteObjectNode::SourceNotRegistered)},
    {sipName_MissingObjectName, static_cast<int>(::QRemoteObjectNode::MissingObjectName)},
    {sipName_HostUrlInvalid, static_cast<int>(::QRemoteObjectNode::HostUrlInvalid)},
    {sipName_ProtocolMismatch, static_cast<int>(::QRemoteObjectNode::ProtocolMismatch)},
    {sipName_ListenFailed, static_cast<int>(::QRemoteObjectNode::ListenFailed)},
    {sipName_SocketAccessError, static_cast<int>(::QRemoteObjectNode::SocketAccessError)},
    {0, 0}
};

PyDoc_STRVAR(doc_QRemoteObjectNode, "\1QRemoteObjectNode(parent: QObject|None = None)\n"
"QRemoteObjectNode(registryAddress: QUrl, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QRemoteObjectNode[] = {
    {"heartbeatIntervalChanged(int)", "\1heartbeatIntervalChanged(self, heartbeatInterval: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QRemoteObjectNode::ErrorCode)", "\1error(self, errorCode: QRemoteObjectNode.ErrorCode)", SIP_NULLPTR, SIP_NULLPTR},
    {"remoteObjectRemoved(QRemoteObjectSourceLocation)", "\1remoteObjectRemoved(self, a0: tuple[str|None, QRemoteObjectSourceLocationInfo])", SIP_NULLPTR, SIP_NULLPTR},
    {"remoteObjectAdded(QRemoteObjectSourceLocation)", "\1remoteObjectAdded(self, a0: tuple[str|None, QRemoteObjectSourceLocationInfo])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QRemoteObjectNode = {
    &::QRemoteObjectNode::staticMetaObject,
    signals_QRemoteObjectNode,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectNode = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRemoteObjectNode,
        SIP_NULLPTR,
        &plugin_QRemoteObjectNode,
    },
    {
        sipNameNr_QRemoteObjectNode,
        {0, 0, 1},
        16, methods_QRemoteObjectNode,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QRemoteObjectNode, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QRemoteObjectNode,
    -1,
    -1,
    supers_QRemoteObjectNode,
    SIP_NULLPTR,
    init_type_QRemoteObjectNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRemoteObjectNode,
    SIP_NULLPTR,
    array_QRemoteObjectNode,
    SIP_NULLPTR,
    release_QRemoteObjectNode,
    cast_QRemoteObjectNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QRemoteObjectNode,
    sizeof (::QRemoteObjectNode),
};
