/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qinputdevice.sip"
#include <qinputdevice.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQInputDevice.cpp"


class sipQInputDevice : public ::QInputDevice
{
public:
    sipQInputDevice(const ::QString&, ::qint64, ::QInputDevice::DeviceType, const ::QString&, ::QObject*);
    sipQInputDevice(::QObject*);
    virtual ~sipQInputDevice();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQInputDevice(const sipQInputDevice &);
    sipQInputDevice &operator = (const sipQInputDevice &);

    char sipPyMethods[7];
};

sipQInputDevice::sipQInputDevice(const ::QString& a0, ::qint64 a1, ::QInputDevice::DeviceType a2, const ::QString& a3, ::QObject*a4): ::QInputDevice(a0, a1, a2, a3, a4), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQInputDevice::sipQInputDevice(::QObject*a0): ::QInputDevice(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQInputDevice::~sipQInputDevice()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQInputDevice::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtGui_qt_metaobject(sipPySelf, sipType_QInputDevice);

    return ::QInputDevice::metaObject();
}

int sipQInputDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QInputDevice::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtGui_qt_metacall(sipPySelf, sipType_QInputDevice, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQInputDevice::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtGui_qt_metacast(sipPySelf, sipType_QInputDevice, _clname, &sipCpp) ? sipCpp : ::QInputDevice::qt_metacast(_clname));
}

bool sipQInputDevice::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QInputDevice::event(a0);

    extern bool sipVH_QtGui_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtGui_10(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQInputDevice::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QInputDevice::eventFilter(a0, a1);

    extern bool sipVH_QtGui_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtGui_9(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQInputDevice::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QInputDevice::timerEvent(a0);
        return;
    }

    extern void sipVH_QtGui_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtGui_8(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDevice::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QInputDevice::childEvent(a0);
        return;
    }

    extern void sipVH_QtGui_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtGui_7(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDevice::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QInputDevice::customEvent(a0);
        return;
    }

    extern void sipVH_QtGui_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtGui_6(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDevice::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QInputDevice::connectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQInputDevice::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QInputDevice::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QInputDevice_name, "name(self) -> str");

extern "C" {static PyObject *meth_QInputDevice_name(PyObject *, PyObject *);}
static PyObject *meth_QInputDevice_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDevice, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDevice, sipName_name, doc_QInputDevice_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDevice_type, "type(self) -> QInputDevice.DeviceType");

extern "C" {static PyObject *meth_QInputDevice_type(PyObject *, PyObject *);}
static PyObject *meth_QInputDevice_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDevice, &sipCpp))
        {
            ::QInputDevice::DeviceType sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QInputDevice_DeviceType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDevice, sipName_type, doc_QInputDevice_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDevice_capabilities, "capabilities(self) -> QInputDevice.Capability");

extern "C" {static PyObject *meth_QInputDevice_capabilities(PyObject *, PyObject *);}
static PyObject *meth_QInputDevice_capabilities(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDevice, &sipCpp))
        {
            ::QInputDevice::Capabilities*sipRes;

            sipRes = new ::QInputDevice::Capabilities(sipCpp->capabilities());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QInputDevice_Capability, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDevice, sipName_capabilities, doc_QInputDevice_capabilities);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDevice_hasCapability, "hasCapability(self, cap: QInputDevice.Capability) -> bool");

extern "C" {static PyObject *meth_QInputDevice_hasCapability(PyObject *, PyObject *);}
static PyObject *meth_QInputDevice_hasCapability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QInputDevice::Capability a0;
        const ::QInputDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QInputDevice, &sipCpp, sipType_QInputDevice_Capability, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->hasCapability(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDevice, sipName_hasCapability, doc_QInputDevice_hasCapability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDevice_systemId, "systemId(self) -> int");

extern "C" {static PyObject *meth_QInputDevice_systemId(PyObject *, PyObject *);}
static PyObject *meth_QInputDevice_systemId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDevice, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->systemId();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDevice, sipName_systemId, doc_QInputDevice_systemId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDevice_seatName, "seatName(self) -> str");

extern "C" {static PyObject *meth_QInputDevice_seatName(PyObject *, PyObject *);}
static PyObject *meth_QInputDevice_seatName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDevice, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->seatName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDevice, sipName_seatName, doc_QInputDevice_seatName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDevice_availableVirtualGeometry, "availableVirtualGeometry(self) -> QRect");

extern "C" {static PyObject *meth_QInputDevice_availableVirtualGeometry(PyObject *, PyObject *);}
static PyObject *meth_QInputDevice_availableVirtualGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QInputDevice, &sipCpp))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->availableVirtualGeometry());

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDevice, sipName_availableVirtualGeometry, doc_QInputDevice_availableVirtualGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDevice_devices, "devices() -> list[QInputDevice]");

extern "C" {static PyObject *meth_QInputDevice_devices(PyObject *, PyObject *);}
static PyObject *meth_QInputDevice_devices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            QList<const ::QInputDevice*>*sipRes;

            sipRes = new QList<const ::QInputDevice*>(::QInputDevice::devices());

            return sipConvertFromNewType(sipRes, sipType_QList_0111QInputDevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDevice, sipName_devices, doc_QInputDevice_devices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDevice_primaryKeyboard, "primaryKeyboard(seatName: str|None = '') -> QInputDevice|None");

extern "C" {static PyObject *meth_QInputDevice_primaryKeyboard(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QInputDevice_primaryKeyboard(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;

        static const char *sipKwdList[] = {
            sipName_seatName,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "C|J1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            const ::QInputDevice*sipRes;

            sipRes = ::QInputDevice::primaryKeyboard(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(const_cast< ::QInputDevice *>(sipRes), sipType_QInputDevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDevice, sipName_primaryKeyboard, doc_QInputDevice_primaryKeyboard);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QInputDevice_seatNames, "seatNames() -> list[str]");

extern "C" {static PyObject *meth_QInputDevice_seatNames(PyObject *, PyObject *);}
static PyObject *meth_QInputDevice_seatNames(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QInputDevice::seatNames());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QInputDevice, sipName_seatNames, doc_QInputDevice_seatNames);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QInputDevice___ne__(PyObject *, PyObject *);}
static PyObject *slot_QInputDevice___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QInputDevice *sipCpp = reinterpret_cast< ::QInputDevice *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QInputDevice));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDevice* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QInputDevice, &a0))
        {
            bool sipRes;

            sipRes = !sipCpp->::QInputDevice::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, ne_slot, sipType_QInputDevice, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QInputDevice___eq__(PyObject *, PyObject *);}
static PyObject *slot_QInputDevice___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QInputDevice *sipCpp = reinterpret_cast< ::QInputDevice *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QInputDevice));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QInputDevice* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QInputDevice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QInputDevice::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, eq_slot, sipType_QInputDevice, sipSelf, sipArg);
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QInputDevice(void *, const sipTypeDef *);}
static void *cast_QInputDevice(void *sipCppV, const sipTypeDef *targetType)
{
    ::QInputDevice *sipCpp = reinterpret_cast< ::QInputDevice *>(sipCppV);

    if (targetType == sipType_QInputDevice)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QInputDevice(void *, int);}
static void release_QInputDevice(void *sipCppV, int)
{
    ::QInputDevice *sipCpp = reinterpret_cast< ::QInputDevice *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QInputDevice(Py_ssize_t);}
static void *array_QInputDevice(Py_ssize_t sipNrElem)
{
    return new ::QInputDevice[sipNrElem];
}


extern "C" {static void array_delete_QInputDevice(void *);}
static void array_delete_QInputDevice(void *sipCpp)
{
    delete[] reinterpret_cast< ::QInputDevice *>(sipCpp);
}


extern "C" {static void dealloc_QInputDevice(sipSimpleWrapper *);}
static void dealloc_QInputDevice(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQInputDevice *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QInputDevice(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QInputDevice(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QInputDevice(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQInputDevice *sipCpp = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::qint64 a1;
        ::QInputDevice::DeviceType a2;
        const ::QString& a3def = QString();
        const ::QString* a3 = &a3def;
        int a3State = 0;
        ::QObject* a4 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_seatName,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1nE|J1JH", sipType_QString, &a0, &a0State, &a1, sipType_QInputDevice_DeviceType, &a2, sipType_QString, &a3, &a3State, sipType_QObject, &a4, sipOwner))
        {
            sipCpp = new sipQInputDevice(*a0, a1, a2, *a3, a4);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQInputDevice(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QInputDevice[] = {{53, 0, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QInputDevice[] = {
    {(void *)slot_QInputDevice___ne__, ne_slot},
    {(void *)slot_QInputDevice___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QInputDevice[] = {
    {sipName_availableVirtualGeometry, meth_QInputDevice_availableVirtualGeometry, METH_VARARGS, doc_QInputDevice_availableVirtualGeometry},
    {sipName_capabilities, meth_QInputDevice_capabilities, METH_VARARGS, doc_QInputDevice_capabilities},
    {sipName_devices, meth_QInputDevice_devices, METH_VARARGS, doc_QInputDevice_devices},
    {sipName_hasCapability, meth_QInputDevice_hasCapability, METH_VARARGS, doc_QInputDevice_hasCapability},
    {sipName_name, meth_QInputDevice_name, METH_VARARGS, doc_QInputDevice_name},
    {sipName_primaryKeyboard, SIP_MLMETH_CAST(meth_QInputDevice_primaryKeyboard), METH_VARARGS|METH_KEYWORDS, doc_QInputDevice_primaryKeyboard},
    {sipName_seatName, meth_QInputDevice_seatName, METH_VARARGS, doc_QInputDevice_seatName},
    {sipName_seatNames, meth_QInputDevice_seatNames, METH_VARARGS, doc_QInputDevice_seatNames},
    {sipName_systemId, meth_QInputDevice_systemId, METH_VARARGS, doc_QInputDevice_systemId},
    {sipName_type, meth_QInputDevice_type, METH_VARARGS, doc_QInputDevice_type}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QInputDevice[] = {
    {sipName_None_, static_cast<int>(::QInputDevice::Capability::None)},
    {sipName_Position, static_cast<int>(::QInputDevice::Capability::Position)},
    {sipName_Area, static_cast<int>(::QInputDevice::Capability::Area)},
    {sipName_Pressure, static_cast<int>(::QInputDevice::Capability::Pressure)},
    {sipName_Velocity, static_cast<int>(::QInputDevice::Capability::Velocity)},
    {sipName_NormalizedPosition, static_cast<int>(::QInputDevice::Capability::NormalizedPosition)},
    {sipName_MouseEmulation, static_cast<int>(::QInputDevice::Capability::MouseEmulation)},
    {sipName_PixelScroll, static_cast<int>(::QInputDevice::Capability::PixelScroll)},
    {sipName_Scroll, static_cast<int>(::QInputDevice::Capability::Scroll)},
    {sipName_Hover, static_cast<int>(::QInputDevice::Capability::Hover)},
    {sipName_Rotation, static_cast<int>(::QInputDevice::Capability::Rotation)},
    {sipName_XTilt, static_cast<int>(::QInputDevice::Capability::XTilt)},
    {sipName_YTilt, static_cast<int>(::QInputDevice::Capability::YTilt)},
    {sipName_TangentialPressure, static_cast<int>(::QInputDevice::Capability::TangentialPressure)},
    {sipName_ZPosition, static_cast<int>(::QInputDevice::Capability::ZPosition)},
    {sipName_All, static_cast<int>(::QInputDevice::Capability::All)},
    {sipName_Unknown, static_cast<int>(::QInputDevice::DeviceType::Unknown)},
    {sipName_Mouse, static_cast<int>(::QInputDevice::DeviceType::Mouse)},
    {sipName_TouchScreen, static_cast<int>(::QInputDevice::DeviceType::TouchScreen)},
    {sipName_TouchPad, static_cast<int>(::QInputDevice::DeviceType::TouchPad)},
    {sipName_Puck, static_cast<int>(::QInputDevice::DeviceType::Puck)},
    {sipName_Stylus, static_cast<int>(::QInputDevice::DeviceType::Stylus)},
    {sipName_Airbrush, static_cast<int>(::QInputDevice::DeviceType::Airbrush)},
    {sipName_Keyboard, static_cast<int>(::QInputDevice::DeviceType::Keyboard)},
    {sipName_AllDevices, static_cast<int>(::QInputDevice::DeviceType::AllDevices)},
    {0, 0}
};

PyDoc_STRVAR(doc_QInputDevice, "\1QInputDevice(name: str|None, systemId: int, type: QInputDevice.DeviceType, seatName: str|None = '', parent: QObject|None = None)\n"
"QInputDevice(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QInputDevice[] = {
    {"capabilitiesChanged(QInputDevice::Capabilities)", "\1capabilitiesChanged(self, capabilities: QInputDevice.Capability)", SIP_NULLPTR, SIP_NULLPTR},
    {"availableVirtualGeometryChanged(QRect)", "\1availableVirtualGeometryChanged(self, area: QRect)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QInputDevice = {
    &::QInputDevice::staticMetaObject,
    signals_QInputDevice,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QInputDevice = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QInputDevice,
        SIP_NULLPTR,
        &plugin_QInputDevice,
    },
    {
        sipNameNr_QInputDevice,
        {0, 0, 1},
        10, methods_QInputDevice,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QInputDevice, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QInputDevice,
    -1,
    -1,
    supers_QInputDevice,
    slots_QInputDevice,
    init_type_QInputDevice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QInputDevice,
    SIP_NULLPTR,
    array_QInputDevice,
    SIP_NULLPTR,
    release_QInputDevice,
    cast_QInputDevice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QInputDevice,
    sizeof (::QInputDevice),
};
