/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 1634 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQKeyCombination.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQKeyCombination.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQKeyCombination.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQKeyCombination.cpp"


PyDoc_STRVAR(doc_QKeyCombination_keyboardModifiers, "keyboardModifiers(self) -> Qt.KeyboardModifier");

extern "C" {static PyObject *meth_QKeyCombination_keyboardModifiers(PyObject *, PyObject *);}
static PyObject *meth_QKeyCombination_keyboardModifiers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QKeyCombination *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QKeyCombination, &sipCpp))
        {
            ::Qt::KeyboardModifiers*sipRes;

            sipRes = new ::Qt::KeyboardModifiers(sipCpp->keyboardModifiers());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_KeyboardModifier, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyCombination, sipName_keyboardModifiers, doc_QKeyCombination_keyboardModifiers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QKeyCombination_key, "key(self) -> Qt.Key");

extern "C" {static PyObject *meth_QKeyCombination_key(PyObject *, PyObject *);}
static PyObject *meth_QKeyCombination_key(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QKeyCombination *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QKeyCombination, &sipCpp))
        {
            ::Qt::Key sipRes;

            sipRes = sipCpp->key();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_Key);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyCombination, sipName_key, doc_QKeyCombination_key);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QKeyCombination_fromCombined, "fromCombined(combined: int) -> QKeyCombination");

extern "C" {static PyObject *meth_QKeyCombination_fromCombined(PyObject *, PyObject *);}
static PyObject *meth_QKeyCombination_fromCombined(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "Ci", &sipSelf, &a0))
        {
            ::QKeyCombination*sipRes;

            sipRes = new ::QKeyCombination(::QKeyCombination::fromCombined(a0));

            return sipConvertFromNewType(sipRes, sipType_QKeyCombination, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyCombination, sipName_fromCombined, doc_QKeyCombination_fromCombined);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QKeyCombination_toCombined, "toCombined(self) -> int");

extern "C" {static PyObject *meth_QKeyCombination_toCombined(PyObject *, PyObject *);}
static PyObject *meth_QKeyCombination_toCombined(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QKeyCombination *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QKeyCombination, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->toCombined();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyCombination, sipName_toCombined, doc_QKeyCombination_toCombined);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QKeyCombination___eq__(PyObject *, PyObject *);}
static PyObject *slot_QKeyCombination___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QKeyCombination *sipCpp = reinterpret_cast< ::QKeyCombination *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QKeyCombination));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QKeyCombination* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QKeyCombination, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QKeyCombination, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QKeyCombination___ne__(PyObject *, PyObject *);}
static PyObject *slot_QKeyCombination___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QKeyCombination *sipCpp = reinterpret_cast< ::QKeyCombination *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QKeyCombination));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QKeyCombination* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QKeyCombination, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QKeyCombination, sipSelf, sipArg);
}


extern "C" {static Py_hash_t slot_QKeyCombination___hash__(PyObject *);}
static Py_hash_t slot_QKeyCombination___hash__(PyObject *sipSelf)
{
    ::QKeyCombination *sipCpp = reinterpret_cast< ::QKeyCombination *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QKeyCombination));

    if (!sipCpp)
        return 0;


    {
        {
            Py_hash_t sipRes = 0;

#line 1647 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
        sipRes = qHash(*sipCpp);
#line 221 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQKeyCombination.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QKeyCombination(void *, int);}
static void release_QKeyCombination(void *sipCppV, int)
{
    delete reinterpret_cast< ::QKeyCombination *>(sipCppV);
}


extern "C" {static void *array_QKeyCombination(Py_ssize_t);}
static void *array_QKeyCombination(Py_ssize_t sipNrElem)
{
    return new ::QKeyCombination[sipNrElem];
}


extern "C" {static void array_delete_QKeyCombination(void *);}
static void array_delete_QKeyCombination(void *sipCpp)
{
    delete[] reinterpret_cast< ::QKeyCombination *>(sipCpp);
}


extern "C" {static void assign_QKeyCombination(void *, Py_ssize_t, void *);}
static void assign_QKeyCombination(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QKeyCombination *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QKeyCombination *>(sipSrc);
}


extern "C" {static void *copy_QKeyCombination(const void *, Py_ssize_t);}
static void *copy_QKeyCombination(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QKeyCombination(reinterpret_cast<const ::QKeyCombination *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QKeyCombination(sipSimpleWrapper *);}
static void dealloc_QKeyCombination(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QKeyCombination(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QKeyCombination(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QKeyCombination(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QKeyCombination *sipCpp = SIP_NULLPTR;

    {
        ::Qt::Key a0 = Qt::Key_unknown;

        static const char *sipKwdList[] = {
            sipName_key,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|E", sipType_Qt_Key, &a0))
        {
            sipCpp = new ::QKeyCombination(a0);

            return sipCpp;
        }
    }

    {
        ::Qt::Modifiers* a0;
        int a0State = 0;
        ::Qt::Key a1 = Qt::Key_unknown;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_key,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|E", sipType_QFlags_0100Qt_Modifier, &a0, &a0State, sipType_Qt_Key, &a1))
        {
            sipCpp = new ::QKeyCombination(*a0, a1);
            sipReleaseType(a0, sipType_QFlags_0100Qt_Modifier, a0State);

            return sipCpp;
        }
    }

    {
        ::Qt::KeyboardModifiers* a0;
        int a0State = 0;
        ::Qt::Key a1 = Qt::Key_unknown;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_key,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|E", sipType_QFlags_0100Qt_KeyboardModifier, &a0, &a0State, sipType_Qt_Key, &a1))
        {
            sipCpp = new ::QKeyCombination(*a0, a1);
            sipReleaseType(a0, sipType_QFlags_0100Qt_KeyboardModifier, a0State);

            return sipCpp;
        }
    }

    {
        const ::QKeyCombination* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QKeyCombination, &a0))
        {
            sipCpp = new ::QKeyCombination(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QKeyCombination[] = {
    {(void *)slot_QKeyCombination___eq__, eq_slot},
    {(void *)slot_QKeyCombination___ne__, ne_slot},
    {(void *)slot_QKeyCombination___hash__, hash_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QKeyCombination[] = {
    {sipName_fromCombined, meth_QKeyCombination_fromCombined, METH_VARARGS, doc_QKeyCombination_fromCombined},
    {sipName_key, meth_QKeyCombination_key, METH_VARARGS, doc_QKeyCombination_key},
    {sipName_keyboardModifiers, meth_QKeyCombination_keyboardModifiers, METH_VARARGS, doc_QKeyCombination_keyboardModifiers},
    {sipName_toCombined, meth_QKeyCombination_toCombined, METH_VARARGS, doc_QKeyCombination_toCombined}
};

PyDoc_STRVAR(doc_QKeyCombination, "\1QKeyCombination(key: Qt.Key = Qt.Key_unknown)\n"
"QKeyCombination(modifiers: Qt.Modifier, key: Qt.Key = Qt.Key_unknown)\n"
"QKeyCombination(modifiers: Qt.KeyboardModifier, key: Qt.Key = Qt.Key_unknown)\n"
"QKeyCombination(a0: QKeyCombination)");


sipClassTypeDef sipTypeDef_QtCore_QKeyCombination = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QKeyCombination,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QKeyCombination,
        {0, 0, 1},
        4, methods_QKeyCombination,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QKeyCombination,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QKeyCombination,
    init_type_QKeyCombination,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QKeyCombination,
    assign_QKeyCombination,
    array_QKeyCombination,
    copy_QKeyCombination,
    release_QKeyCombination,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QKeyCombination,
    sizeof (::QKeyCombination),
};
