/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtXmlAPI_H
#define _QtXmlAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QDomImplementation__InvalidDataPolicy 0
#define sipName_QDomImplementation__InvalidDataPolicy &sipStrings_QtXml[0]
#define sipNameNr_38 38
#define sipName_38 &sipStrings_QtXml[38]
#define sipNameNr_createProcessingInstruction 72
#define sipName_createProcessingInstruction &sipStrings_QtXml[72]
#define sipNameNr_ProcessingInstructionNode 100
#define sipName_ProcessingInstructionNode &sipStrings_QtXml[100]
#define sipNameNr_QDomDocument__ParseOption 126
#define sipName_QDomDocument__ParseOption &sipStrings_QtXml[126]
#define sipNameNr_QDomProcessingInstruction 152
#define sipName_QDomProcessingInstruction &sipStrings_QtXml[152]
#define sipNameNr_PreserveSpacingOnlyNodes 178
#define sipName_PreserveSpacingOnlyNodes &sipStrings_QtXml[178]
#define sipNameNr_QDomNode__EncodingPolicy 203
#define sipName_QDomNode__EncodingPolicy &sipStrings_QtXml[203]
#define sipNameNr_PyQt6_sip_simplewrapper 228
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtXml[228]
#define sipNameNr_isProcessingInstruction 252
#define sipName_isProcessingInstruction &sipStrings_QtXml[252]
#define sipNameNr_toProcessingInstruction 276
#define sipName_toProcessingInstruction &sipStrings_QtXml[276]
#define sipNameNr_EncodingFromTextStream 300
#define sipName_EncodingFromTextStream &sipStrings_QtXml[300]
#define sipNameNr_UseNamespaceProcessing 323
#define sipName_UseNamespaceProcessing &sipStrings_QtXml[323]
#define sipNameNr_createDocumentFragment 346
#define sipName_createDocumentFragment &sipStrings_QtXml[346]
#define sipNameNr_previousSiblingElement 369
#define sipName_previousSiblingElement &sipStrings_QtXml[369]
#define sipNameNr_createEntityReference 392
#define sipName_createEntityReference &sipStrings_QtXml[392]
#define sipNameNr_DocumentFragmentNode 414
#define sipName_DocumentFragmentNode &sipStrings_QtXml[414]
#define sipNameNr_EncodingFromDocument 435
#define sipName_EncodingFromDocument &sipStrings_QtXml[435]
#define sipNameNr_QDomDocumentFragment 456
#define sipName_QDomDocumentFragment &sipStrings_QtXml[456]
#define sipNameNr_setInvalidDataPolicy 477
#define sipName_setInvalidDataPolicy &sipStrings_QtXml[477]
#define sipNameNr_EntityReferenceNode 498
#define sipName_EntityReferenceNode &sipStrings_QtXml[498]
#define sipNameNr_QDomEntityReference 518
#define sipName_QDomEntityReference &sipStrings_QtXml[518]
#define sipNameNr_elementsByTagNameNS 538
#define sipName_elementsByTagNameNS &sipStrings_QtXml[538]
#define sipNameNr_removeAttributeNode 558
#define sipName_removeAttributeNode &sipStrings_QtXml[558]
#define sipNameNr_AcceptInvalidChars 578
#define sipName_AcceptInvalidChars &sipStrings_QtXml[578]
#define sipNameNr_QDomImplementation 597
#define sipName_QDomImplementation &sipStrings_QtXml[597]
#define sipNameNr_QDomNode__NodeType 616
#define sipName_QDomNode__NodeType &sipStrings_QtXml[616]
#define sipNameNr_createCDATASection 635
#define sipName_createCDATASection &sipStrings_QtXml[635]
#define sipNameNr_createDocumentType 654
#define sipName_createDocumentType &sipStrings_QtXml[654]
#define sipNameNr_isDocumentFragment 673
#define sipName_isDocumentFragment &sipStrings_QtXml[673]
#define sipNameNr_nextSiblingElement 692
#define sipName_nextSiblingElement &sipStrings_QtXml[692]
#define sipNameNr_setAttributeNodeNS 711
#define sipName_setAttributeNodeNS &sipStrings_QtXml[711]
#define sipNameNr_toDocumentFragment 730
#define sipName_toDocumentFragment &sipStrings_QtXml[730]
#define sipNameNr_CharacterDataNode 749
#define sipName_CharacterDataNode &sipStrings_QtXml[749]
#define sipNameNr_InvalidDataPolicy 20
#define sipName_InvalidDataPolicy &sipStrings_QtXml[20]
#define sipNameNr_QDomCharacterData 767
#define sipName_QDomCharacterData &sipStrings_QtXml[767]
#define sipNameNr_createAttributeNS 785
#define sipName_createAttributeNS &sipStrings_QtXml[785]
#define sipNameNr_elementsByTagName 803
#define sipName_elementsByTagName &sipStrings_QtXml[803]
#define sipNameNr_firstChildElement 821
#define sipName_firstChildElement &sipStrings_QtXml[821]
#define sipNameNr_invalidDataPolicy 839
#define sipName_invalidDataPolicy &sipStrings_QtXml[839]
#define sipNameNr_isEntityReference 857
#define sipName_isEntityReference &sipStrings_QtXml[857]
#define sipNameNr_removeAttributeNS 875
#define sipName_removeAttributeNS &sipStrings_QtXml[875]
#define sipNameNr_removeNamedItemNS 893
#define sipName_removeNamedItemNS &sipStrings_QtXml[893]
#define sipNameNr_toEntityReference 911
#define sipName_toEntityReference &sipStrings_QtXml[911]
#define sipNameNr_CDATASectionNode 929
#define sipName_CDATASectionNode &sipStrings_QtXml[929]
#define sipNameNr_DocumentTypeNode 946
#define sipName_DocumentTypeNode &sipStrings_QtXml[946]
#define sipNameNr_DropInvalidChars 963
#define sipName_DropInvalidChars &sipStrings_QtXml[963]
#define sipNameNr_QDomCDATASection 980
#define sipName_QDomCDATASection &sipStrings_QtXml[980]
#define sipNameNr_QDomDocumentType 997
#define sipName_QDomDocumentType &sipStrings_QtXml[997]
#define sipNameNr_QDomNamedNodeMap 1014
#define sipName_QDomNamedNodeMap &sipStrings_QtXml[1014]
#define sipNameNr_lastChildElement 1031
#define sipName_lastChildElement &sipStrings_QtXml[1031]
#define sipNameNr_setAttributeNode 1048
#define sipName_setAttributeNode &sipStrings_QtXml[1048]
#define sipNameNr_attributeNodeNS 1065
#define sipName_attributeNodeNS &sipStrings_QtXml[1065]
#define sipNameNr_createAttribute 1081
#define sipName_createAttribute &sipStrings_QtXml[1081]
#define sipNameNr_createElementNS 1097
#define sipName_createElementNS &sipStrings_QtXml[1097]
#define sipNameNr_documentElement 1113
#define sipName_documentElement &sipStrings_QtXml[1113]
#define sipNameNr_isCharacterData 1129
#define sipName_isCharacterData &sipStrings_QtXml[1129]
#define sipNameNr_previousSibling 1145
#define sipName_previousSibling &sipStrings_QtXml[1145]
#define sipNameNr_removeAttribute 1161
#define sipName_removeAttribute &sipStrings_QtXml[1161]
#define sipNameNr_removeNamedItem 1177
#define sipName_removeNamedItem &sipStrings_QtXml[1177]
#define sipNameNr_toCharacterData 1193
#define sipName_toCharacterData &sipStrings_QtXml[1193]
#define sipNameNr_EncodingPolicy 213
#define sipName_EncodingPolicy &sipStrings_QtXml[213]
#define sipNameNr_ReturnNullNode 1209
#define sipName_ReturnNullNode &sipStrings_QtXml[1209]
#define sipNameNr_createDocument 1224
#define sipName_createDocument &sipStrings_QtXml[1224]
#define sipNameNr_createTextNode 1239
#define sipName_createTextNode &sipStrings_QtXml[1239]
#define sipNameNr_hasAttributeNS 1254
#define sipName_hasAttributeNS &sipStrings_QtXml[1254]
#define sipNameNr_implementation 1269
#define sipName_implementation &sipStrings_QtXml[1269]
#define sipNameNr_internalSubset 1284
#define sipName_internalSubset &sipStrings_QtXml[1284]
#define sipNameNr_isCDATASection 1299
#define sipName_isCDATASection &sipStrings_QtXml[1299]
#define sipNameNr_isDocumentType 1314
#define sipName_isDocumentType &sipStrings_QtXml[1314]
#define sipNameNr_setAttributeNS 1329
#define sipName_setAttributeNS &sipStrings_QtXml[1329]
#define sipNameNr_setNamedItemNS 1344
#define sipName_setNamedItemNS &sipStrings_QtXml[1344]
#define sipNameNr_toCDATASection 1359
#define sipName_toCDATASection &sipStrings_QtXml[1359]
#define sipNameNr_toDocumentType 1374
#define sipName_toDocumentType &sipStrings_QtXml[1374]
#define sipNameNr_AttributeNode 564
#define sipName_AttributeNode &sipStrings_QtXml[564]
#define sipNameNr_attributeNode 1389
#define sipName_attributeNode &sipStrings_QtXml[1389]
#define sipNameNr_createComment 1403
#define sipName_createComment &sipStrings_QtXml[1403]
#define sipNameNr_createElement 1417
#define sipName_createElement &sipStrings_QtXml[1417]
#define sipNameNr_hasAttributes 1431
#define sipName_hasAttributes &sipStrings_QtXml[1431]
#define sipNameNr_hasChildNodes 1445
#define sipName_hasChildNodes &sipStrings_QtXml[1445]
#define sipNameNr_ownerDocument 1459
#define sipName_ownerDocument &sipStrings_QtXml[1459]
#define sipNameNr_substringData 1473
#define sipName_substringData &sipStrings_QtXml[1473]
#define sipNameNr_DocumentNode 1487
#define sipName_DocumentNode &sipStrings_QtXml[1487]
#define sipNameNr_NotationNode 1500
#define sipName_NotationNode &sipStrings_QtXml[1500]
#define sipNameNr_QDomDocument 1513
#define sipName_QDomDocument &sipStrings_QtXml[1513]
#define sipNameNr_QDomNodeList 1526
#define sipName_QDomNodeList &sipStrings_QtXml[1526]
#define sipNameNr_QDomNotation 1539
#define sipName_QDomNotation &sipStrings_QtXml[1539]
#define sipNameNr_columnNumber 1552
#define sipName_columnNumber &sipStrings_QtXml[1552]
#define sipNameNr_defaultValue 1565
#define sipName_defaultValue &sipStrings_QtXml[1565]
#define sipNameNr_hasAttribute 1578
#define sipName_hasAttribute &sipStrings_QtXml[1578]
#define sipNameNr_insertBefore 1591
#define sipName_insertBefore &sipStrings_QtXml[1591]
#define sipNameNr_namespaceURI 1604
#define sipName_namespaceURI &sipStrings_QtXml[1604]
#define sipNameNr_notationName 1617
#define sipName_notationName &sipStrings_QtXml[1617]
#define sipNameNr_ownerElement 1630
#define sipName_ownerElement &sipStrings_QtXml[1630]
#define sipNameNr_replaceChild 1643
#define sipName_replaceChild &sipStrings_QtXml[1643]
#define sipNameNr_setAttribute 1656
#define sipName_setAttribute &sipStrings_QtXml[1656]
#define sipNameNr_setNamedItem 1669
#define sipName_setNamedItem &sipStrings_QtXml[1669]
#define sipNameNr_setNodeValue 1682
#define sipName_setNodeValue &sipStrings_QtXml[1682]
#define sipNameNr_CommentNode 1695
#define sipName_CommentNode &sipStrings_QtXml[1695]
#define sipNameNr_ElementNode 1707
#define sipName_ElementNode &sipStrings_QtXml[1707]
#define sipNameNr_ParseOption 140
#define sipName_ParseOption &sipStrings_QtXml[140]
#define sipNameNr_PyQt6_QtXml 1719
#define sipName_PyQt6_QtXml &sipStrings_QtXml[1719]
#define sipNameNr_QDomComment 1731
#define sipName_QDomComment &sipStrings_QtXml[1731]
#define sipNameNr_QDomElement 1743
#define sipName_QDomElement &sipStrings_QtXml[1743]
#define sipNameNr_appendChild 1755
#define sipName_appendChild &sipStrings_QtXml[1755]
#define sipNameNr_attributeNS 1767
#define sipName_attributeNS &sipStrings_QtXml[1767]
#define sipNameNr_elementById 1779
#define sipName_elementById &sipStrings_QtXml[1779]
#define sipNameNr_errorColumn 1791
#define sipName_errorColumn &sipStrings_QtXml[1791]
#define sipNameNr_insertAfter 1803
#define sipName_insertAfter &sipStrings_QtXml[1803]
#define sipNameNr_isSupported 1815
#define sipName_isSupported &sipStrings_QtXml[1815]
#define sipNameNr_namedItemNS 1827
#define sipName_namedItemNS &sipStrings_QtXml[1827]
#define sipNameNr_nextSibling 1839
#define sipName_nextSibling &sipStrings_QtXml[1839]
#define sipNameNr_removeChild 1851
#define sipName_removeChild &sipStrings_QtXml[1851]
#define sipNameNr_replaceData 1863
#define sipName_replaceData &sipStrings_QtXml[1863]
#define sipNameNr_toByteArray 1875
#define sipName_toByteArray &sipStrings_QtXml[1875]
#define sipNameNr_EntityNode 1887
#define sipName_EntityNode &sipStrings_QtXml[1887]
#define sipNameNr_QDomEntity 1898
#define sipName_QDomEntity &sipStrings_QtXml[1898]
#define sipNameNr___lshift__ 1909
#define sipName___lshift__ &sipStrings_QtXml[1909]
#define sipNameNr_appendData 1920
#define sipName_appendData &sipStrings_QtXml[1920]
#define sipNameNr_attributes 1931
#define sipName_attributes &sipStrings_QtXml[1931]
#define sipNameNr_childNodes 1942
#define sipName_childNodes &sipStrings_QtXml[1942]
#define sipNameNr_deleteData 1953
#define sipName_deleteData &sipStrings_QtXml[1953]
#define sipNameNr_firstChild 1964
#define sipName_firstChild &sipStrings_QtXml[1964]
#define sipNameNr_hasFeature 1975
#define sipName_hasFeature &sipStrings_QtXml[1975]
#define sipNameNr_importNode 1986
#define sipName_importNode &sipStrings_QtXml[1986]
#define sipNameNr_insertData 1997
#define sipName_insertData &sipStrings_QtXml[1997]
#define sipNameNr_isDocument 2008
#define sipName_isDocument &sipStrings_QtXml[2008]
#define sipNameNr_isNotation 2019
#define sipName_isNotation &sipStrings_QtXml[2019]
#define sipNameNr_lineNumber 2030
#define sipName_lineNumber &sipStrings_QtXml[2030]
#define sipNameNr_parentNode 2041
#define sipName_parentNode &sipStrings_QtXml[2041]
#define sipNameNr_setContent 2052
#define sipName_setContent &sipStrings_QtXml[2052]
#define sipNameNr_setTagName 2063
#define sipName_setTagName &sipStrings_QtXml[2063]
#define sipNameNr_toDocument 2074
#define sipName_toDocument &sipStrings_QtXml[2074]
#define sipNameNr_toNotation 2085
#define sipName_toNotation &sipStrings_QtXml[2085]
#define sipNameNr_attribute 2096
#define sipName_attribute &sipStrings_QtXml[2096]
#define sipNameNr_cloneNode 2106
#define sipName_cloneNode &sipStrings_QtXml[2106]
#define sipNameNr_errorLine 2116
#define sipName_errorLine &sipStrings_QtXml[2116]
#define sipNameNr_isComment 2126
#define sipName_isComment &sipStrings_QtXml[2126]
#define sipNameNr_isElement 2136
#define sipName_isElement &sipStrings_QtXml[2136]
#define sipNameNr_lastChild 2146
#define sipName_lastChild &sipStrings_QtXml[2146]
#define sipNameNr_localName 2156
#define sipName_localName &sipStrings_QtXml[2156]
#define sipNameNr_namedItem 2166
#define sipName_namedItem &sipStrings_QtXml[2166]
#define sipNameNr_nodeValue 2176
#define sipName_nodeValue &sipStrings_QtXml[2176]
#define sipNameNr_normalize 2186
#define sipName_normalize &sipStrings_QtXml[2186]
#define sipNameNr_notations 2196
#define sipName_notations &sipStrings_QtXml[2196]
#define sipNameNr_setPrefix 2206
#define sipName_setPrefix &sipStrings_QtXml[2206]
#define sipNameNr_specified 2216
#define sipName_specified &sipStrings_QtXml[2216]
#define sipNameNr_splitText 2226
#define sipName_splitText &sipStrings_QtXml[2226]
#define sipNameNr_toComment 2236
#define sipName_toComment &sipStrings_QtXml[2236]
#define sipNameNr_toElement 2246
#define sipName_toElement &sipStrings_QtXml[2246]
#define sipNameNr_BaseNode 2256
#define sipName_BaseNode &sipStrings_QtXml[2256]
#define sipNameNr_NodeType 626
#define sipName_NodeType &sipStrings_QtXml[626]
#define sipNameNr_QDomAttr 2265
#define sipName_QDomAttr &sipStrings_QtXml[2265]
#define sipNameNr_QDomNode 2274
#define sipName_QDomNode &sipStrings_QtXml[2274]
#define sipNameNr_QDomText 2283
#define sipName_QDomText &sipStrings_QtXml[2283]
#define sipNameNr_TextNode 1245
#define sipName_TextNode &sipStrings_QtXml[1245]
#define sipNameNr_contains 2292
#define sipName_contains &sipStrings_QtXml[2292]
#define sipNameNr_entities 2301
#define sipName_entities &sipStrings_QtXml[2301]
#define sipNameNr_errorMsg 2310
#define sipName_errorMsg &sipStrings_QtXml[2310]
#define sipNameNr_isEntity 2319
#define sipName_isEntity &sipStrings_QtXml[2319]
#define sipNameNr_nodeName 2328
#define sipName_nodeName &sipStrings_QtXml[2328]
#define sipNameNr_nodeType 2337
#define sipName_nodeType &sipStrings_QtXml[2337]
#define sipNameNr_publicId 2346
#define sipName_publicId &sipStrings_QtXml[2346]
#define sipNameNr_setValue 2355
#define sipName_setValue &sipStrings_QtXml[2355]
#define sipNameNr_systemId 2364
#define sipName_systemId &sipStrings_QtXml[2364]
#define sipNameNr_toEntity 2373
#define sipName_toEntity &sipStrings_QtXml[2373]
#define sipNameNr_toString 2382
#define sipName_toString &sipStrings_QtXml[2382]
#define sipNameNr_Default 2391
#define sipName_Default &sipStrings_QtXml[2391]
#define sipNameNr___len__ 2399
#define sipName___len__ &sipStrings_QtXml[2399]
#define sipNameNr_doctype 2407
#define sipName_doctype &sipStrings_QtXml[2407]
#define sipNameNr_isEmpty 2415
#define sipName_isEmpty &sipStrings_QtXml[2415]
#define sipNameNr_options 2423
#define sipName_options &sipStrings_QtXml[2423]
#define sipNameNr_setData 2431
#define sipName_setData &sipStrings_QtXml[2431]
#define sipNameNr_tagName 2439
#define sipName_tagName &sipStrings_QtXml[2439]
#define sipNameNr___eq__ 2447
#define sipName___eq__ &sipStrings_QtXml[2447]
#define sipNameNr___ne__ 2454
#define sipName___ne__ &sipStrings_QtXml[2454]
#define sipNameNr_indent 2461
#define sipName_indent &sipStrings_QtXml[2461]
#define sipNameNr_isAttr 2468
#define sipName_isAttr &sipStrings_QtXml[2468]
#define sipNameNr_isNull 2475
#define sipName_isNull &sipStrings_QtXml[2475]
#define sipNameNr_isText 2482
#define sipName_isText &sipStrings_QtXml[2482]
#define sipNameNr_length 2489
#define sipName_length &sipStrings_QtXml[2489]
#define sipNameNr_prefix 2496
#define sipName_prefix &sipStrings_QtXml[2496]
#define sipNameNr_taName 2503
#define sipName_taName &sipStrings_QtXml[2503]
#define sipNameNr_target 2510
#define sipName_target &sipStrings_QtXml[2510]
#define sipNameNr_toAttr 2517
#define sipName_toAttr &sipStrings_QtXml[2517]
#define sipNameNr_toText 2524
#define sipName_toText &sipStrings_QtXml[2524]
#define sipNameNr_clear 2531
#define sipName_clear &sipStrings_QtXml[2531]
#define sipNameNr_count 2537
#define sipName_count &sipStrings_QtXml[2537]
#define sipNameNr_value 2543
#define sipName_value &sipStrings_QtXml[2543]
#define sipNameNr_data 2549
#define sipName_data &sipStrings_QtXml[2549]
#define sipNameNr_deep 2554
#define sipName_deep &sipStrings_QtXml[2554]
#define sipNameNr_item 2559
#define sipName_item &sipStrings_QtXml[2559]
#define sipNameNr_name 2564
#define sipName_name &sipStrings_QtXml[2564]
#define sipNameNr_save 2569
#define sipName_save &sipStrings_QtXml[2569]
#define sipNameNr_size 2574
#define sipName_size &sipStrings_QtXml[2574]
#define sipNameNr_text 2579
#define sipName_text &sipStrings_QtXml[2579]
#define sipNameNr_at 2584
#define sipName_at &sipStrings_QtXml[2584]

#define sipMalloc                   sipAPI_QtXml->api_malloc
#define sipFree                     sipAPI_QtXml->api_free
#define sipBuildResult              sipAPI_QtXml->api_build_result
#define sipCallMethod               sipAPI_QtXml->api_call_method
#define sipCallProcedureMethod      sipAPI_QtXml->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtXml->api_call_error_handler
#define sipParseResultEx            sipAPI_QtXml->api_parse_result_ex
#define sipParseResult              sipAPI_QtXml->api_parse_result
#define sipParseArgs                sipAPI_QtXml->api_parse_args
#define sipParseKwdArgs             sipAPI_QtXml->api_parse_kwd_args
#define sipParsePair                sipAPI_QtXml->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtXml->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtXml->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtXml->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtXml->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtXml->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtXml->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtXml->api_add_exception
#define sipNoFunction               sipAPI_QtXml->api_no_function
#define sipNoMethod                 sipAPI_QtXml->api_no_method
#define sipAbstractMethod           sipAPI_QtXml->api_abstract_method
#define sipBadClass                 sipAPI_QtXml->api_bad_class
#define sipBadCatcherResult         sipAPI_QtXml->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtXml->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtXml->api_bad_operator_arg
#define sipTrace                    sipAPI_QtXml->api_trace
#define sipTransferBack             sipAPI_QtXml->api_transfer_back
#define sipTransferTo               sipAPI_QtXml->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtXml->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtXml->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtXml->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtXml->api_voidptr_type
#define sipGetPyObject              sipAPI_QtXml->api_get_pyobject
#define sipGetAddress               sipAPI_QtXml->api_get_address
#define sipGetMixinAddress          sipAPI_QtXml->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtXml->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtXml->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtXml->api_call_hook
#define sipEndThread                sipAPI_QtXml->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtXml->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtXml->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtXml->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtXml->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtXml->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtXml->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtXml->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtXml->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtXml->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtXml->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtXml->api_convert_to_bool
#define sipReleaseType              sipAPI_QtXml->api_release_type
#define sipConvertFromType          sipAPI_QtXml->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtXml->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtXml->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtXml->api_convert_from_enum
#define sipGetState                 sipAPI_QtXml->api_get_state
#define sipExportSymbol             sipAPI_QtXml->api_export_symbol
#define sipImportSymbol             sipAPI_QtXml->api_import_symbol
#define sipFindType                 sipAPI_QtXml->api_find_type
#define sipBytes_AsChar             sipAPI_QtXml->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtXml->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtXml->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtXml->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtXml->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtXml->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtXml->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtXml->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtXml->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtXml->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtXml->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtXml->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtXml->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtXml->api_get_reference
#define sipKeepReference            sipAPI_QtXml->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtXml->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtXml->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtXml->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtXml->api_type_scope
#define sipResolveTypedef           sipAPI_QtXml->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtXml->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtXml->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtXml->api_init_mixin
#define sipExportModule             sipAPI_QtXml->api_export_module
#define sipInitModule               sipAPI_QtXml->api_init_module
#define sipGetInterpreter           sipAPI_QtXml->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtXml->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtXml->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtXml->api_py_type_dict
#define sipPyTypeName               sipAPI_QtXml->api_py_type_name
#define sipGetCFunction             sipAPI_QtXml->api_get_c_function
#define sipGetMethod                sipAPI_QtXml->api_get_method
#define sipFromMethod               sipAPI_QtXml->api_from_method
#define sipGetDate                  sipAPI_QtXml->api_get_date
#define sipFromDate                 sipAPI_QtXml->api_from_date
#define sipGetDateTime              sipAPI_QtXml->api_get_datetime
#define sipFromDateTime             sipAPI_QtXml->api_from_datetime
#define sipGetTime                  sipAPI_QtXml->api_get_time
#define sipFromTime                 sipAPI_QtXml->api_from_time
#define sipIsUserType               sipAPI_QtXml->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtXml->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtXml->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtXml->api_unicode_write
#define sipUnicodeData              sipAPI_QtXml->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtXml->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtXml->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtXml->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtXml->api_is_derived_class
#define sipGetUserObject            sipAPI_QtXml->api_get_user_object
#define sipSetUserObject            sipAPI_QtXml->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtXml->api_register_event_handler
#define sipConvertToArray           sipAPI_QtXml->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtXml->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtXml->api_enable_gc
#define sipPrintObject              sipAPI_QtXml->api_print_object
#define sipLong_AsChar              sipAPI_QtXml->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtXml->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtXml->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtXml->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtXml->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtXml->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtXml->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtXml->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtXml->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtXml->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtXml->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtXml->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtXml->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtXml->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtXml->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtXml->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtXml->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtXml->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtXml->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtXml->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtXml->api_release_type_us
#define sipIsPyMethod               sipAPI_QtXml->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtXml[];

#define sipType_QDomImplementation sipExportedTypes_QtXml[11]

#define sipType_QDomImplementation_InvalidDataPolicy sipExportedTypes_QtXml[12]

extern sipClassTypeDef sipTypeDef_QtXml_QDomImplementation;

#define sipType_QDomNode sipExportedTypes_QtXml[14]

#define sipType_QDomNode_EncodingPolicy sipExportedTypes_QtXml[15]

#define sipType_QDomNode_NodeType sipExportedTypes_QtXml[16]

extern sipClassTypeDef sipTypeDef_QtXml_QDomNode;

#define sipType_QDomNodeList sipExportedTypes_QtXml[17]

extern sipClassTypeDef sipTypeDef_QtXml_QDomNodeList;

#define sipType_QDomDocumentType sipExportedTypes_QtXml[7]

extern sipClassTypeDef sipTypeDef_QtXml_QDomDocumentType;

#define sipType_QDomDocument sipExportedTypes_QtXml[4]

#define sipType_QDomDocument_ParseOption sipExportedTypes_QtXml[5]

extern sipClassTypeDef sipTypeDef_QtXml_QDomDocument;

#define sipType_QDomNamedNodeMap sipExportedTypes_QtXml[13]

extern sipClassTypeDef sipTypeDef_QtXml_QDomNamedNodeMap;

#define sipType_QDomDocumentFragment sipExportedTypes_QtXml[6]

extern sipClassTypeDef sipTypeDef_QtXml_QDomDocumentFragment;

#define sipType_QDomCharacterData sipExportedTypes_QtXml[2]

extern sipClassTypeDef sipTypeDef_QtXml_QDomCharacterData;

#define sipType_QDomAttr sipExportedTypes_QtXml[0]

extern sipClassTypeDef sipTypeDef_QtXml_QDomAttr;

#define sipType_QDomElement sipExportedTypes_QtXml[8]

extern sipClassTypeDef sipTypeDef_QtXml_QDomElement;

#define sipType_QDomText sipExportedTypes_QtXml[20]

extern sipClassTypeDef sipTypeDef_QtXml_QDomText;

#define sipType_QDomComment sipExportedTypes_QtXml[3]

extern sipClassTypeDef sipTypeDef_QtXml_QDomComment;

#define sipType_QDomCDATASection sipExportedTypes_QtXml[1]

extern sipClassTypeDef sipTypeDef_QtXml_QDomCDATASection;

#define sipType_QDomNotation sipExportedTypes_QtXml[18]

extern sipClassTypeDef sipTypeDef_QtXml_QDomNotation;

#define sipType_QDomEntity sipExportedTypes_QtXml[9]

extern sipClassTypeDef sipTypeDef_QtXml_QDomEntity;

#define sipType_QDomEntityReference sipExportedTypes_QtXml[10]

extern sipClassTypeDef sipTypeDef_QtXml_QDomEntityReference;

#define sipType_QDomProcessingInstruction sipExportedTypes_QtXml[19]

extern sipClassTypeDef sipTypeDef_QtXml_QDomProcessingInstruction;

#define sipType_QFlags_0100QDomDocument_ParseOption sipExportedTypes_QtXml[21]

extern sipMappedTypeDef sipTypeDef_QtXml_QFlags_0100QDomDocument_ParseOption;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtXml;
extern sipExportedModuleDef sipModuleAPI_QtXml;
extern sipTypeDef *sipExportedTypes_QtXml[];

#define sipType_QIODevice sipImportedTypes_QtXml_QtCore[2].it_td

#define sipType_QByteArray sipImportedTypes_QtXml_QtCore[1].it_td

#define sipType_QTextStream sipImportedTypes_QtXml_QtCore[4].it_td

#define sipType_QXmlStreamReader sipImportedTypes_QtXml_QtCore[5].it_td

#define sipType_QString sipImportedTypes_QtXml_QtCore[3].it_td

#define sipType_QAnyStringView sipImportedTypes_QtXml_QtCore[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtXml_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtXml_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtXml_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtXml_qt_metacast;

#endif
