/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpygui_native_interface.sip"
#include <QGuiApplication>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeInterfaceQX11Application.cpp"



PyDoc_STRVAR(doc_QNativeInterface_QX11Application_connection, "connection(self) -> PyQt6.sip.voidptr");

extern "C" {static PyObject *meth_QNativeInterface_QX11Application_connection(PyObject *, PyObject *);}
static PyObject *meth_QNativeInterface_QX11Application_connection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QNativeInterface::QX11Application *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNativeInterface_QX11Application, &sipCpp))
        {
            void*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QX11Application, sipName_connection);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->connection();

            return sipConvertFromVoidPtr(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Application, sipName_connection, doc_QNativeInterface_QX11Application_connection);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNativeInterface_QX11Application(void *, int);}
static void release_QNativeInterface_QX11Application(void *sipCppV, int)
{
    delete reinterpret_cast< ::QNativeInterface::QX11Application *>(sipCppV);
}


extern "C" {static void dealloc_QNativeInterface_QX11Application(sipSimpleWrapper *);}
static void dealloc_QNativeInterface_QX11Application(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNativeInterface_QX11Application(sipGetAddress(sipSelf), 0);
    }
}


static PyMethodDef methods_QNativeInterface_QX11Application[] = {
    {sipName_connection, meth_QNativeInterface_QX11Application_connection, METH_VARARGS, doc_QNativeInterface_QX11Application_connection}
};


sipClassTypeDef sipTypeDef_QtGui_QNativeInterface_QX11Application = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNativeInterface__QX11Application,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QX11Application,
        {183, 255, 0},
        1, methods_QNativeInterface_QX11Application,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QNativeInterface_QX11Application,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QNativeInterface_QX11Application,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
