/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtSpatialAudioAPI_H
#define _QtSpatialAudioAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QSpatialSound__DistanceModel 0
#define sipName_QSpatialSound__DistanceModel &sipStrings_QtSpatialAudio[0]
#define sipNameNr_occlusionIntensityChanged 29
#define sipName_occlusionIntensityChanged &sipStrings_QtSpatialAudio[29]
#define sipNameNr_QAudioEngine__OutputMode 55
#define sipName_QAudioEngine__OutputMode &sipStrings_QtSpatialAudio[55]
#define sipNameNr_manualAttenuationChanged 80
#define sipName_manualAttenuationChanged &sipStrings_QtSpatialAudio[80]
#define sipNameNr_DistanceScaleCentimeter 105
#define sipName_DistanceScaleCentimeter &sipStrings_QtSpatialAudio[105]
#define sipNameNr_directivityOrderChanged 129
#define sipName_directivityOrderChanged &sipStrings_QtSpatialAudio[129]
#define sipNameNr_reverbBrightnessChanged 153
#define sipName_reverbBrightnessChanged &sipStrings_QtSpatialAudio[153]
#define sipNameNr_PolishedConcreteOrTile 177
#define sipName_PolishedConcreteOrTile &sipStrings_QtSpatialAudio[177]
#define sipNameNr_distanceCutoffChanged 200
#define sipName_distanceCutoffChanged &sipStrings_QtSpatialAudio[200]
#define sipNameNr_reflectionGainChanged 222
#define sipName_reflectionGainChanged &sipStrings_QtSpatialAudio[222]
#define sipNameNr_setOcclusionIntensity 244
#define sipName_setOcclusionIntensity &sipStrings_QtSpatialAudio[244]
#define sipNameNr_setRoomEffectsEnabled 266
#define sipName_setRoomEffectsEnabled &sipStrings_QtSpatialAudio[266]
#define sipNameNr_AcousticCeilingTiles 288
#define sipName_AcousticCeilingTiles &sipStrings_QtSpatialAudio[288]
#define sipNameNr_ConcreteBlockPainted 309
#define sipName_ConcreteBlockPainted &sipStrings_QtSpatialAudio[309]
#define sipNameNr_FiberGlassInsulation 330
#define sipName_FiberGlassInsulation &sipStrings_QtSpatialAudio[330]
#define sipNameNr_PyQt6_QtSpatialAudio 351
#define sipName_PyQt6_QtSpatialAudio &sipStrings_QtSpatialAudio[351]
#define sipNameNr_QAmbientSound__Loops 372
#define sipName_QAmbientSound__Loops &sipStrings_QtSpatialAudio[372]
#define sipNameNr_QAudioRoom__Material 393
#define sipName_QAudioRoom__Material &sipStrings_QtSpatialAudio[393]
#define sipNameNr_QSpatialSound__Loops 414
#define sipName_QSpatialSound__Loops &sipStrings_QtSpatialAudio[414]
#define sipNameNr_distanceModelChanged 435
#define sipName_distanceModelChanged &sipStrings_QtSpatialAudio[435]
#define sipNameNr_distanceScaleChanged 456
#define sipName_distanceScaleChanged &sipStrings_QtSpatialAudio[456]
#define sipNameNr_nearFieldGainChanged 477
#define sipName_nearFieldGainChanged &sipStrings_QtSpatialAudio[477]
#define sipNameNr_setManualAttenuation 498
#define sipName_setManualAttenuation &sipStrings_QtSpatialAudio[498]
#define sipNameNr_ConcreteBlockCoarse 519
#define sipName_ConcreteBlockCoarse &sipStrings_QtSpatialAudio[519]
#define sipNameNr_masterVolumeChanged 539
#define sipName_masterVolumeChanged &sipStrings_QtSpatialAudio[539]
#define sipNameNr_outputDeviceChanged 559
#define sipName_outputDeviceChanged &sipStrings_QtSpatialAudio[559]
#define sipNameNr_setDirectivityOrder 579
#define sipName_setDirectivityOrder &sipStrings_QtSpatialAudio[579]
#define sipNameNr_setReverbBrightness 599
#define sipName_setReverbBrightness &sipStrings_QtSpatialAudio[599]
#define sipNameNr_DistanceScaleMeter 619
#define sipName_DistanceScaleMeter &sipStrings_QtSpatialAudio[619]
#define sipNameNr_LinoleumOnConcrete 638
#define sipName_LinoleumOnConcrete &sipStrings_QtSpatialAudio[638]
#define sipNameNr_directivityChanged 657
#define sipName_directivityChanged &sipStrings_QtSpatialAudio[657]
#define sipNameNr_occlusionIntensity 676
#define sipName_occlusionIntensity &sipStrings_QtSpatialAudio[676]
#define sipNameNr_roomEffectsEnabled 695
#define sipName_roomEffectsEnabled &sipStrings_QtSpatialAudio[695]
#define sipNameNr_ManualAttenuation 501
#define sipName_ManualAttenuation &sipStrings_QtSpatialAudio[501]
#define sipNameNr_ParquetOnConcrete 714
#define sipName_ParquetOnConcrete &sipStrings_QtSpatialAudio[714]
#define sipNameNr_WaterOrIceSurface 732
#define sipName_WaterOrIceSurface &sipStrings_QtSpatialAudio[732]
#define sipNameNr_dimensionsChanged 750
#define sipName_dimensionsChanged &sipStrings_QtSpatialAudio[750]
#define sipNameNr_manualAttenuation 768
#define sipName_manualAttenuation &sipStrings_QtSpatialAudio[768]
#define sipNameNr_outputModeChanged 786
#define sipName_outputModeChanged &sipStrings_QtSpatialAudio[786]
#define sipNameNr_reverbGainChanged 804
#define sipName_reverbGainChanged &sipStrings_QtSpatialAudio[804]
#define sipNameNr_reverbTimeChanged 822
#define sipName_reverbTimeChanged &sipStrings_QtSpatialAudio[822]
#define sipNameNr_setDistanceCutoff 840
#define sipName_setDistanceCutoff &sipStrings_QtSpatialAudio[840]
#define sipNameNr_setReflectionGain 858
#define sipName_setReflectionGain &sipStrings_QtSpatialAudio[858]
#define sipNameNr_QAudioRoom__Wall 876
#define sipName_QAudioRoom__Wall &sipStrings_QtSpatialAudio[876]
#define sipNameNr_directivityOrder 893
#define sipName_directivityOrder &sipStrings_QtSpatialAudio[893]
#define sipNameNr_disconnectNotify 910
#define sipName_disconnectNotify &sipStrings_QtSpatialAudio[910]
#define sipNameNr_reverbBrightness 927
#define sipName_reverbBrightness &sipStrings_QtSpatialAudio[927]
#define sipNameNr_setDistanceModel 944
#define sipName_setDistanceModel &sipStrings_QtSpatialAudio[944]
#define sipNameNr_setDistanceScale 961
#define sipName_setDistanceScale &sipStrings_QtSpatialAudio[961]
#define sipNameNr_setNearFieldGain 978
#define sipName_setNearFieldGain &sipStrings_QtSpatialAudio[978]
#define sipNameNr_UniformMaterial 995
#define sipName_UniformMaterial &sipStrings_QtSpatialAudio[995]
#define sipNameNr_autoPlayChanged 1011
#define sipName_autoPlayChanged &sipStrings_QtSpatialAudio[1011]
#define sipNameNr_positionChanged 1027
#define sipName_positionChanged &sipStrings_QtSpatialAudio[1027]
#define sipNameNr_rotationChanged 1043
#define sipName_rotationChanged &sipStrings_QtSpatialAudio[1043]
#define sipNameNr_setMasterVolume 1059
#define sipName_setMasterVolume &sipStrings_QtSpatialAudio[1059]
#define sipNameNr_setOutputDevice 1075
#define sipName_setOutputDevice &sipStrings_QtSpatialAudio[1075]
#define sipNameNr_setWallMaterial 1091
#define sipName_setWallMaterial &sipStrings_QtSpatialAudio[1091]
#define sipNameNr_QAudioListener 1107
#define sipName_QAudioListener &sipStrings_QtSpatialAudio[1107]
#define sipNameNr_distanceCutoff 1122
#define sipName_distanceCutoff &sipStrings_QtSpatialAudio[1122]
#define sipNameNr_reflectionGain 1137
#define sipName_reflectionGain &sipStrings_QtSpatialAudio[1137]
#define sipNameNr_setDirectivity 1152
#define sipName_setDirectivity &sipStrings_QtSpatialAudio[1152]
#define sipNameNr_DistanceModel 15
#define sipName_DistanceModel &sipStrings_QtSpatialAudio[15]
#define sipNameNr_PlasterSmooth 1167
#define sipName_PlasterSmooth &sipStrings_QtSpatialAudio[1167]
#define sipNameNr_QAmbientSound 1181
#define sipName_QAmbientSound &sipStrings_QtSpatialAudio[1181]
#define sipNameNr_QSpatialSound 1195
#define sipName_QSpatialSound &sipStrings_QtSpatialAudio[1195]
#define sipNameNr_connectNotify 913
#define sipName_connectNotify &sipStrings_QtSpatialAudio[913]
#define sipNameNr_distanceModel 1209
#define sipName_distanceModel &sipStrings_QtSpatialAudio[1209]
#define sipNameNr_distanceScale 1223
#define sipName_distanceScale &sipStrings_QtSpatialAudio[1223]
#define sipNameNr_nearFieldGain 1237
#define sipName_nearFieldGain &sipStrings_QtSpatialAudio[1237]
#define sipNameNr_pausedChanged 1251
#define sipName_pausedChanged &sipStrings_QtSpatialAudio[1251]
#define sipNameNr_setDimensions 1265
#define sipName_setDimensions &sipStrings_QtSpatialAudio[1265]
#define sipNameNr_setOutputMode 1279
#define sipName_setOutputMode &sipStrings_QtSpatialAudio[1279]
#define sipNameNr_setReverbGain 1293
#define sipName_setReverbGain &sipStrings_QtSpatialAudio[1293]
#define sipNameNr_setReverbTime 1307
#define sipName_setReverbTime &sipStrings_QtSpatialAudio[1307]
#define sipNameNr_sourceChanged 1321
#define sipName_sourceChanged &sipStrings_QtSpatialAudio[1321]
#define sipNameNr_volumeChanged 1335
#define sipName_volumeChanged &sipStrings_QtSpatialAudio[1335]
#define sipNameNr_BrickPainted 1349
#define sipName_BrickPainted &sipStrings_QtSpatialAudio[1349]
#define sipNameNr_CurtainHeavy 1362
#define sipName_CurtainHeavy &sipStrings_QtSpatialAudio[1362]
#define sipNameNr_PlasterRough 1375
#define sipName_PlasterRough &sipStrings_QtSpatialAudio[1375]
#define sipNameNr_PlywoodPanel 1388
#define sipName_PlywoodPanel &sipStrings_QtSpatialAudio[1388]
#define sipNameNr_QAudioEngine 1401
#define sipName_QAudioEngine &sipStrings_QtSpatialAudio[1401]
#define sipNameNr_loopsChanged 1414
#define sipName_loopsChanged &sipStrings_QtSpatialAudio[1414]
#define sipNameNr_masterVolume 1427
#define sipName_masterVolume &sipStrings_QtSpatialAudio[1427]
#define sipNameNr_outputDevice 1440
#define sipName_outputDevice &sipStrings_QtSpatialAudio[1440]
#define sipNameNr_wallMaterial 1453
#define sipName_wallMaterial &sipStrings_QtSpatialAudio[1453]
#define sipNameNr_wallsChanged 1466
#define sipName_wallsChanged &sipStrings_QtSpatialAudio[1466]
#define sipNameNr_Logarithmic 1479
#define sipName_Logarithmic &sipStrings_QtSpatialAudio[1479]
#define sipNameNr_Transparent 1491
#define sipName_Transparent &sipStrings_QtSpatialAudio[1491]
#define sipNameNr_WoodCeiling 1503
#define sipName_WoodCeiling &sipStrings_QtSpatialAudio[1503]
#define sipNameNr_customEvent 1515
#define sipName_customEvent &sipStrings_QtSpatialAudio[1515]
#define sipNameNr_directivity 1527
#define sipName_directivity &sipStrings_QtSpatialAudio[1527]
#define sipNameNr_eventFilter 1539
#define sipName_eventFilter &sipStrings_QtSpatialAudio[1539]
#define sipNameNr_setAutoPlay 1551
#define sipName_setAutoPlay &sipStrings_QtSpatialAudio[1551]
#define sipNameNr_setPosition 1563
#define sipName_setPosition &sipStrings_QtSpatialAudio[1563]
#define sipNameNr_setRotation 1575
#define sipName_setRotation &sipStrings_QtSpatialAudio[1575]
#define sipNameNr_sizeChanged 1587
#define sipName_sizeChanged &sipStrings_QtSpatialAudio[1587]
#define sipNameNr_GlassThick 1599
#define sipName_GlassThick &sipStrings_QtSpatialAudio[1599]
#define sipNameNr_OutputMode 69
#define sipName_OutputMode &sipStrings_QtSpatialAudio[69]
#define sipNameNr_QAudioRoom 1610
#define sipName_QAudioRoom &sipStrings_QtSpatialAudio[1610]
#define sipNameNr_childEvent 1621
#define sipName_childEvent &sipStrings_QtSpatialAudio[1621]
#define sipNameNr_dimensions 1632
#define sipName_dimensions &sipStrings_QtSpatialAudio[1632]
#define sipNameNr_outputMode 1643
#define sipName_outputMode &sipStrings_QtSpatialAudio[1643]
#define sipNameNr_reverbGain 1654
#define sipName_reverbGain &sipStrings_QtSpatialAudio[1654]
#define sipNameNr_reverbTime 1665
#define sipName_reverbTime &sipStrings_QtSpatialAudio[1665]
#define sipNameNr_sampleRate 1676
#define sipName_sampleRate &sipStrings_QtSpatialAudio[1676]
#define sipNameNr_timerEvent 1687
#define sipName_timerEvent &sipStrings_QtSpatialAudio[1687]
#define sipNameNr_BrickBare 1698
#define sipName_BrickBare &sipStrings_QtSpatialAudio[1698]
#define sipNameNr_FrontWall 1708
#define sipName_FrontWall &sipStrings_QtSpatialAudio[1708]
#define sipNameNr_GlassThin 1718
#define sipName_GlassThin &sipStrings_QtSpatialAudio[1718]
#define sipNameNr_Headphone 1728
#define sipName_Headphone &sipStrings_QtSpatialAudio[1728]
#define sipNameNr_RightWall 1738
#define sipName_RightWall &sipStrings_QtSpatialAudio[1738]
#define sipNameNr_Sheetrock 1748
#define sipName_Sheetrock &sipStrings_QtSpatialAudio[1748]
#define sipNameNr_WoodPanel 1758
#define sipName_WoodPanel &sipStrings_QtSpatialAudio[1758]
#define sipNameNr_setPaused 1768
#define sipName_setPaused &sipStrings_QtSpatialAudio[1768]
#define sipNameNr_setSource 1778
#define sipName_setSource &sipStrings_QtSpatialAudio[1778]
#define sipNameNr_setVolume 1788
#define sipName_setVolume &sipStrings_QtSpatialAudio[1788]
#define sipNameNr_BackWall 1798
#define sipName_BackWall &sipStrings_QtSpatialAudio[1798]
#define sipNameNr_Infinite 1807
#define sipName_Infinite &sipStrings_QtSpatialAudio[1807]
#define sipNameNr_LeftWall 1816
#define sipName_LeftWall &sipStrings_QtSpatialAudio[1816]
#define sipNameNr_Material 405
#define sipName_Material &sipStrings_QtSpatialAudio[405]
#define sipNameNr_Surround 1825
#define sipName_Surround &sipStrings_QtSpatialAudio[1825]
#define sipNameNr_autoPlay 1834
#define sipName_autoPlay &sipStrings_QtSpatialAudio[1834]
#define sipNameNr_position 1843
#define sipName_position &sipStrings_QtSpatialAudio[1843]
#define sipNameNr_rotation 1852
#define sipName_rotation &sipStrings_QtSpatialAudio[1852]
#define sipNameNr_setLoops 1861
#define sipName_setLoops &sipStrings_QtSpatialAudio[1861]
#define sipNameNr_Ceiling 1507
#define sipName_Ceiling &sipStrings_QtSpatialAudio[1507]
#define sipNameNr_setSize 1870
#define sipName_setSize &sipStrings_QtSpatialAudio[1870]
#define sipNameNr_Linear 1878
#define sipName_Linear &sipStrings_QtSpatialAudio[1878]
#define sipNameNr_Marble 1885
#define sipName_Marble &sipStrings_QtSpatialAudio[1885]
#define sipNameNr_Stereo 1892
#define sipName_Stereo &sipStrings_QtSpatialAudio[1892]
#define sipNameNr_engine 1899
#define sipName_engine &sipStrings_QtSpatialAudio[1899]
#define sipNameNr_parent 1496
#define sipName_parent &sipStrings_QtSpatialAudio[1496]
#define sipNameNr_paused 1906
#define sipName_paused &sipStrings_QtSpatialAudio[1906]
#define sipNameNr_resume 1913
#define sipName_resume &sipStrings_QtSpatialAudio[1913]
#define sipNameNr_source 1920
#define sipName_source &sipStrings_QtSpatialAudio[1920]
#define sipNameNr_volume 1927
#define sipName_volume &sipStrings_QtSpatialAudio[1927]
#define sipNameNr_Floor 1934
#define sipName_Floor &sipStrings_QtSpatialAudio[1934]
#define sipNameNr_Grass 1940
#define sipName_Grass &sipStrings_QtSpatialAudio[1940]
#define sipNameNr_Loops 387
#define sipName_Loops &sipStrings_QtSpatialAudio[387]
#define sipNameNr_Metal 1946
#define sipName_Metal &sipStrings_QtSpatialAudio[1946]
#define sipNameNr_event 1952
#define sipName_event &sipStrings_QtSpatialAudio[1952]
#define sipNameNr_loops 1958
#define sipName_loops &sipStrings_QtSpatialAudio[1958]
#define sipNameNr_pause 1964
#define sipName_pause &sipStrings_QtSpatialAudio[1964]
#define sipNameNr_start 1970
#define sipName_start &sipStrings_QtSpatialAudio[1970]
#define sipNameNr_Once 1976
#define sipName_Once &sipStrings_QtSpatialAudio[1976]
#define sipNameNr_Wall 888
#define sipName_Wall &sipStrings_QtSpatialAudio[888]
#define sipNameNr_play 1981
#define sipName_play &sipStrings_QtSpatialAudio[1981]
#define sipNameNr_size 1986
#define sipName_size &sipStrings_QtSpatialAudio[1986]
#define sipNameNr_stop 1991
#define sipName_stop &sipStrings_QtSpatialAudio[1991]

#define sipMalloc                   sipAPI_QtSpatialAudio->api_malloc
#define sipFree                     sipAPI_QtSpatialAudio->api_free
#define sipBuildResult              sipAPI_QtSpatialAudio->api_build_result
#define sipCallMethod               sipAPI_QtSpatialAudio->api_call_method
#define sipCallProcedureMethod      sipAPI_QtSpatialAudio->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtSpatialAudio->api_call_error_handler
#define sipParseResultEx            sipAPI_QtSpatialAudio->api_parse_result_ex
#define sipParseResult              sipAPI_QtSpatialAudio->api_parse_result
#define sipParseArgs                sipAPI_QtSpatialAudio->api_parse_args
#define sipParseKwdArgs             sipAPI_QtSpatialAudio->api_parse_kwd_args
#define sipParsePair                sipAPI_QtSpatialAudio->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtSpatialAudio->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtSpatialAudio->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtSpatialAudio->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtSpatialAudio->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtSpatialAudio->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtSpatialAudio->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtSpatialAudio->api_add_exception
#define sipNoFunction               sipAPI_QtSpatialAudio->api_no_function
#define sipNoMethod                 sipAPI_QtSpatialAudio->api_no_method
#define sipAbstractMethod           sipAPI_QtSpatialAudio->api_abstract_method
#define sipBadClass                 sipAPI_QtSpatialAudio->api_bad_class
#define sipBadCatcherResult         sipAPI_QtSpatialAudio->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtSpatialAudio->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtSpatialAudio->api_bad_operator_arg
#define sipTrace                    sipAPI_QtSpatialAudio->api_trace
#define sipTransferBack             sipAPI_QtSpatialAudio->api_transfer_back
#define sipTransferTo               sipAPI_QtSpatialAudio->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtSpatialAudio->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtSpatialAudio->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtSpatialAudio->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtSpatialAudio->api_voidptr_type
#define sipGetPyObject              sipAPI_QtSpatialAudio->api_get_pyobject
#define sipGetAddress               sipAPI_QtSpatialAudio->api_get_address
#define sipGetMixinAddress          sipAPI_QtSpatialAudio->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtSpatialAudio->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtSpatialAudio->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtSpatialAudio->api_call_hook
#define sipEndThread                sipAPI_QtSpatialAudio->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtSpatialAudio->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtSpatialAudio->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtSpatialAudio->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtSpatialAudio->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtSpatialAudio->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtSpatialAudio->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtSpatialAudio->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtSpatialAudio->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtSpatialAudio->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtSpatialAudio->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtSpatialAudio->api_convert_to_bool
#define sipReleaseType              sipAPI_QtSpatialAudio->api_release_type
#define sipConvertFromType          sipAPI_QtSpatialAudio->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtSpatialAudio->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtSpatialAudio->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtSpatialAudio->api_convert_from_enum
#define sipGetState                 sipAPI_QtSpatialAudio->api_get_state
#define sipExportSymbol             sipAPI_QtSpatialAudio->api_export_symbol
#define sipImportSymbol             sipAPI_QtSpatialAudio->api_import_symbol
#define sipFindType                 sipAPI_QtSpatialAudio->api_find_type
#define sipBytes_AsChar             sipAPI_QtSpatialAudio->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtSpatialAudio->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtSpatialAudio->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtSpatialAudio->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtSpatialAudio->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtSpatialAudio->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtSpatialAudio->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtSpatialAudio->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtSpatialAudio->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtSpatialAudio->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtSpatialAudio->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtSpatialAudio->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtSpatialAudio->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtSpatialAudio->api_get_reference
#define sipKeepReference            sipAPI_QtSpatialAudio->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtSpatialAudio->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtSpatialAudio->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtSpatialAudio->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtSpatialAudio->api_type_scope
#define sipResolveTypedef           sipAPI_QtSpatialAudio->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtSpatialAudio->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtSpatialAudio->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtSpatialAudio->api_init_mixin
#define sipExportModule             sipAPI_QtSpatialAudio->api_export_module
#define sipInitModule               sipAPI_QtSpatialAudio->api_init_module
#define sipGetInterpreter           sipAPI_QtSpatialAudio->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtSpatialAudio->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtSpatialAudio->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtSpatialAudio->api_py_type_dict
#define sipPyTypeName               sipAPI_QtSpatialAudio->api_py_type_name
#define sipGetCFunction             sipAPI_QtSpatialAudio->api_get_c_function
#define sipGetMethod                sipAPI_QtSpatialAudio->api_get_method
#define sipFromMethod               sipAPI_QtSpatialAudio->api_from_method
#define sipGetDate                  sipAPI_QtSpatialAudio->api_get_date
#define sipFromDate                 sipAPI_QtSpatialAudio->api_from_date
#define sipGetDateTime              sipAPI_QtSpatialAudio->api_get_datetime
#define sipFromDateTime             sipAPI_QtSpatialAudio->api_from_datetime
#define sipGetTime                  sipAPI_QtSpatialAudio->api_get_time
#define sipFromTime                 sipAPI_QtSpatialAudio->api_from_time
#define sipIsUserType               sipAPI_QtSpatialAudio->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtSpatialAudio->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtSpatialAudio->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtSpatialAudio->api_unicode_write
#define sipUnicodeData              sipAPI_QtSpatialAudio->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtSpatialAudio->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtSpatialAudio->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtSpatialAudio->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtSpatialAudio->api_is_derived_class
#define sipGetUserObject            sipAPI_QtSpatialAudio->api_get_user_object
#define sipSetUserObject            sipAPI_QtSpatialAudio->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtSpatialAudio->api_register_event_handler
#define sipConvertToArray           sipAPI_QtSpatialAudio->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtSpatialAudio->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtSpatialAudio->api_enable_gc
#define sipPrintObject              sipAPI_QtSpatialAudio->api_print_object
#define sipLong_AsChar              sipAPI_QtSpatialAudio->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtSpatialAudio->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtSpatialAudio->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtSpatialAudio->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtSpatialAudio->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtSpatialAudio->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtSpatialAudio->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtSpatialAudio->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtSpatialAudio->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtSpatialAudio->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtSpatialAudio->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtSpatialAudio->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtSpatialAudio->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtSpatialAudio->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtSpatialAudio->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtSpatialAudio->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtSpatialAudio->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtSpatialAudio->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtSpatialAudio->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtSpatialAudio->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtSpatialAudio->api_release_type_us
#define sipIsPyMethod               sipAPI_QtSpatialAudio->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtSpatialAudio[];

#define sipType_QAmbientSound sipExportedTypes_QtSpatialAudio[0]

#define sipType_QAmbientSound_Loops sipExportedTypes_QtSpatialAudio[1]

extern sipClassTypeDef sipTypeDef_QtSpatialAudio_QAmbientSound;

#define sipType_QAudioEngine sipExportedTypes_QtSpatialAudio[2]

#define sipType_QAudioEngine_OutputMode sipExportedTypes_QtSpatialAudio[3]

extern sipClassTypeDef sipTypeDef_QtSpatialAudio_QAudioEngine;

#define sipType_QAudioListener sipExportedTypes_QtSpatialAudio[4]

extern sipClassTypeDef sipTypeDef_QtSpatialAudio_QAudioListener;

#define sipType_QAudioRoom sipExportedTypes_QtSpatialAudio[5]

#define sipType_QAudioRoom_Wall sipExportedTypes_QtSpatialAudio[7]

#define sipType_QAudioRoom_Material sipExportedTypes_QtSpatialAudio[6]

extern sipClassTypeDef sipTypeDef_QtSpatialAudio_QAudioRoom;

#define sipType_QSpatialSound sipExportedTypes_QtSpatialAudio[8]

#define sipType_QSpatialSound_Loops sipExportedTypes_QtSpatialAudio[10]

#define sipType_QSpatialSound_DistanceModel sipExportedTypes_QtSpatialAudio[9]

extern sipClassTypeDef sipTypeDef_QtSpatialAudio_QSpatialSound;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtSpatialAudio;
extern sipExportedModuleDef sipModuleAPI_QtSpatialAudio;
extern sipTypeDef *sipExportedTypes_QtSpatialAudio[];

#define sipType_QObject sipImportedTypes_QtSpatialAudio_QtCore[3].it_td

#define sipType_QEvent sipImportedTypes_QtSpatialAudio_QtCore[1].it_td

#define sipType_QTimerEvent sipImportedTypes_QtSpatialAudio_QtCore[4].it_td

#define sipType_QChildEvent sipImportedTypes_QtSpatialAudio_QtCore[0].it_td

#define sipType_QMetaMethod sipImportedTypes_QtSpatialAudio_QtCore[2].it_td

#define sipType_QUrl sipImportedTypes_QtSpatialAudio_QtCore[5].it_td
extern sipImportedTypeDef sipImportedTypes_QtSpatialAudio_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[];

#define sipType_QQuaternion sipImportedTypes_QtSpatialAudio_QtGui[0].it_td

#define sipType_QVector3D sipImportedTypes_QtSpatialAudio_QtGui[1].it_td
extern sipImportedTypeDef sipImportedTypes_QtSpatialAudio_QtGui[];

#define sipType_QAudioDevice sipImportedTypes_QtSpatialAudio_QtMultimedia[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtSpatialAudio_QtMultimedia[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtSpatialAudio_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtSpatialAudio_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtSpatialAudio_qt_metacast;

#endif
