/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringconverter_base.sip"
#include <qstringconverter_base.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQStringConverterBase.cpp"



/* Call the instance's destructor. */
extern "C" {static void release_QStringConverterBase(void *, int);}
static void release_QStringConverterBase(void *, int)
{
}


extern "C" {static void *init_type_QStringConverterBase(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QStringConverterBase(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QStringConverterBase *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QStringConverterBase();

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QStringConverterBase[] = {
    {sipName_Default, static_cast<int>(::QStringConverterBase::Flag::Default)},
    {sipName_Stateless, static_cast<int>(::QStringConverterBase::Flag::Stateless)},
    {sipName_ConvertInvalidToNull, static_cast<int>(::QStringConverterBase::Flag::ConvertInvalidToNull)},
    {sipName_WriteBom, static_cast<int>(::QStringConverterBase::Flag::WriteBom)},
    {sipName_ConvertInitialBom, static_cast<int>(::QStringConverterBase::Flag::ConvertInitialBom)},
    {sipName_UsesIcu, static_cast<int>(::QStringConverterBase::Flag::UsesIcu)},
    {0, 0}
};

PyDoc_STRVAR(doc_QStringConverterBase, "\1QStringConverterBase()");


sipClassTypeDef sipTypeDef_QtCore_QStringConverterBase = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStringConverterBase,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QStringConverterBase,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QStringConverterBase, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QStringConverterBase,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QStringConverterBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QStringConverterBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QStringConverterBase),
};
