/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetatype.sip"
#include <qmetatype.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQMetaType.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearrayview.sip"
#include <qbytearrayview.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQMetaType.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQMetaType.cpp"


PyDoc_STRVAR(doc_QMetaType_isRegistered, "isRegistered(type: int) -> bool\n"
"isRegistered(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_isRegistered(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_isRegistered(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "Ci", &sipSelf, &a0))
        {
            bool sipRes;

            sipRes = ::QMetaType::isRegistered(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isRegistered();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_isRegistered, doc_QMetaType_isRegistered);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_sizeOf, "sizeOf(self) -> int");

extern "C" {static PyObject *meth_QMetaType_sizeOf(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_sizeOf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            ::qsizetype sipRes;

            sipRes = sipCpp->sizeOf();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_sizeOf, doc_QMetaType_sizeOf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_flags, "flags(self) -> QMetaType.TypeFlag");

extern "C" {static PyObject *meth_QMetaType_flags(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            ::QMetaType::TypeFlags*sipRes;

            sipRes = new ::QMetaType::TypeFlags(sipCpp->flags());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QMetaType_TypeFlag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_flags, doc_QMetaType_flags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_isValid(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_isValid, doc_QMetaType_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_id, "id(self) -> int");

extern "C" {static PyObject *meth_QMetaType_id(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_id(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->id();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_id, doc_QMetaType_id);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_hasRegisteredDataStreamOperators, "hasRegisteredDataStreamOperators(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_hasRegisteredDataStreamOperators(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_hasRegisteredDataStreamOperators(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasRegisteredDataStreamOperators();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_hasRegisteredDataStreamOperators, doc_QMetaType_hasRegisteredDataStreamOperators);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_hasRegisteredDebugStreamOperator, "hasRegisteredDebugStreamOperator(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_hasRegisteredDebugStreamOperator(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_hasRegisteredDebugStreamOperator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasRegisteredDebugStreamOperator();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_hasRegisteredDebugStreamOperator, doc_QMetaType_hasRegisteredDebugStreamOperator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_name, "name(self) -> bytes");

extern "C" {static PyObject *meth_QMetaType_name(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            const char*sipRes;

            sipRes = sipCpp->name();

            if (sipRes == SIP_NULLPTR)
            {
                Py_INCREF(Py_None);
                return Py_None;
            }

            return PyBytes_FromString(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_name, doc_QMetaType_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_alignOf, "alignOf(self) -> int");

extern "C" {static PyObject *meth_QMetaType_alignOf(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_alignOf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            ::qsizetype sipRes;

            sipRes = sipCpp->alignOf();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_alignOf, doc_QMetaType_alignOf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_isEqualityComparable, "isEqualityComparable(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_isEqualityComparable(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_isEqualityComparable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEqualityComparable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_isEqualityComparable, doc_QMetaType_isEqualityComparable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_isOrdered, "isOrdered(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_isOrdered(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_isOrdered(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isOrdered();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_isOrdered, doc_QMetaType_isOrdered);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_fromName, "fromName(name: QByteArray|bytes|bytearray|memoryview) -> QMetaType");

extern "C" {static PyObject *meth_QMetaType_fromName(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_fromName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QByteArrayView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QByteArrayView, &a0, &a0State, &a0UserState))
        {
            ::QMetaType*sipRes;

            sipRes = reinterpret_cast< ::QMetaType *>(::operator new(sizeof (::QMetaType)));
            *sipRes = ::QMetaType::fromName(*a0);
            sipReleaseTypeUS(a0, sipType_QByteArrayView, a0State, a0UserState);

            return sipConvertFromNewType(sipRes, sipType_QMetaType, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_fromName, doc_QMetaType_fromName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_canConvert, "canConvert(fromType: QMetaType, toType: QMetaType) -> bool");

extern "C" {static PyObject *meth_QMetaType_canConvert(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_canConvert(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMetaType* a0;
        ::QMetaType* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ9J9", &sipSelf, sipType_QMetaType, &a0, sipType_QMetaType, &a1))
        {
            bool sipRes;

            sipRes = ::QMetaType::canConvert(*a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_canConvert, doc_QMetaType_canConvert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_canView, "canView(fromType: QMetaType, toType: QMetaType) -> bool");

extern "C" {static PyObject *meth_QMetaType_canView(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_canView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMetaType* a0;
        ::QMetaType* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ9J9", &sipSelf, sipType_QMetaType, &a0, sipType_QMetaType, &a1))
        {
            bool sipRes;

            sipRes = ::QMetaType::canView(*a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_canView, doc_QMetaType_canView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_registerType, "registerType(self)");

extern "C" {static PyObject *meth_QMetaType_registerType(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_registerType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            sipCpp->registerType();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_registerType, doc_QMetaType_registerType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_isDefaultConstructible, "isDefaultConstructible(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_isDefaultConstructible(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_isDefaultConstructible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDefaultConstructible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_isDefaultConstructible, doc_QMetaType_isDefaultConstructible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_isCopyConstructible, "isCopyConstructible(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_isCopyConstructible(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_isCopyConstructible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isCopyConstructible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_isCopyConstructible, doc_QMetaType_isCopyConstructible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_isMoveConstructible, "isMoveConstructible(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_isMoveConstructible(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_isMoveConstructible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMoveConstructible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_isMoveConstructible, doc_QMetaType_isMoveConstructible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_isDestructible, "isDestructible(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_isDestructible(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_isDestructible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDestructible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_isDestructible, doc_QMetaType_isDestructible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_underlyingType, "underlyingType(self) -> QMetaType");

extern "C" {static PyObject *meth_QMetaType_underlyingType(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_underlyingType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            ::QMetaType*sipRes;

            sipRes = reinterpret_cast< ::QMetaType *>(::operator new(sizeof (::QMetaType)));
            *sipRes = sipCpp->underlyingType();

            return sipConvertFromNewType(sipRes, sipType_QMetaType, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_underlyingType, doc_QMetaType_underlyingType);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QMetaType___eq__(PyObject *, PyObject *);}
static PyObject *slot_QMetaType___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QMetaType *sipCpp = reinterpret_cast< ::QMetaType *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QMetaType));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QMetaType, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QMetaType, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QMetaType___ne__(PyObject *, PyObject *);}
static PyObject *slot_QMetaType___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QMetaType *sipCpp = reinterpret_cast< ::QMetaType *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QMetaType));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QMetaType, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QMetaType, sipSelf, sipArg);
}


extern "C" {static Py_hash_t slot_QMetaType___hash__(PyObject *);}
static Py_hash_t slot_QMetaType___hash__(PyObject *sipSelf)
{
    ::QMetaType *sipCpp = reinterpret_cast< ::QMetaType *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QMetaType));

    if (!sipCpp)
        return 0;


    {
        {
            Py_hash_t sipRes = 0;

#line 166 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetatype.sip"
        sipRes = qHash(*sipCpp);
#line 658 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQMetaType.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QMetaType(void *, int);}
static void release_QMetaType(void *sipCppV, int)
{
    delete reinterpret_cast< ::QMetaType *>(sipCppV);
}


extern "C" {static void *array_QMetaType(Py_ssize_t);}
static void *array_QMetaType(Py_ssize_t sipNrElem)
{
    return new ::QMetaType[sipNrElem];
}


extern "C" {static void array_delete_QMetaType(void *);}
static void array_delete_QMetaType(void *sipCpp)
{
    delete[] reinterpret_cast< ::QMetaType *>(sipCpp);
}


extern "C" {static void dealloc_QMetaType(sipSimpleWrapper *);}
static void dealloc_QMetaType(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMetaType(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QMetaType(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMetaType(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QMetaType *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QMetaType();

            return sipCpp;
        }
    }

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "i", &a0))
        {
            sipCpp = new ::QMetaType(a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QMetaType[] = {
    {(void *)slot_QMetaType___eq__, eq_slot},
    {(void *)slot_QMetaType___ne__, ne_slot},
    {(void *)slot_QMetaType___hash__, hash_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QMetaType[] = {
    {sipName_alignOf, meth_QMetaType_alignOf, METH_VARARGS, doc_QMetaType_alignOf},
    {sipName_canConvert, meth_QMetaType_canConvert, METH_VARARGS, doc_QMetaType_canConvert},
    {sipName_canView, meth_QMetaType_canView, METH_VARARGS, doc_QMetaType_canView},
    {sipName_flags, meth_QMetaType_flags, METH_VARARGS, doc_QMetaType_flags},
    {sipName_fromName, meth_QMetaType_fromName, METH_VARARGS, doc_QMetaType_fromName},
    {sipName_hasRegisteredDataStreamOperators, meth_QMetaType_hasRegisteredDataStreamOperators, METH_VARARGS, doc_QMetaType_hasRegisteredDataStreamOperators},
    {sipName_hasRegisteredDebugStreamOperator, meth_QMetaType_hasRegisteredDebugStreamOperator, METH_VARARGS, doc_QMetaType_hasRegisteredDebugStreamOperator},
    {sipName_id, meth_QMetaType_id, METH_VARARGS, doc_QMetaType_id},
    {sipName_isCopyConstructible, meth_QMetaType_isCopyConstructible, METH_VARARGS, doc_QMetaType_isCopyConstructible},
    {sipName_isDefaultConstructible, meth_QMetaType_isDefaultConstructible, METH_VARARGS, doc_QMetaType_isDefaultConstructible},
    {sipName_isDestructible, meth_QMetaType_isDestructible, METH_VARARGS, doc_QMetaType_isDestructible},
    {sipName_isEqualityComparable, meth_QMetaType_isEqualityComparable, METH_VARARGS, doc_QMetaType_isEqualityComparable},
    {sipName_isMoveConstructible, meth_QMetaType_isMoveConstructible, METH_VARARGS, doc_QMetaType_isMoveConstructible},
    {sipName_isOrdered, meth_QMetaType_isOrdered, METH_VARARGS, doc_QMetaType_isOrdered},
    {sipName_isRegistered, meth_QMetaType_isRegistered, METH_VARARGS, doc_QMetaType_isRegistered},
    {sipName_isValid, meth_QMetaType_isValid, METH_VARARGS, doc_QMetaType_isValid},
    {sipName_name, meth_QMetaType_name, METH_VARARGS, doc_QMetaType_name},
    {sipName_registerType, meth_QMetaType_registerType, METH_VARARGS, doc_QMetaType_registerType},
    {sipName_sizeOf, meth_QMetaType_sizeOf, METH_VARARGS, doc_QMetaType_sizeOf},
    {sipName_underlyingType, meth_QMetaType_underlyingType, METH_VARARGS, doc_QMetaType_underlyingType}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QMetaType[] = {
    {sipName_UnknownType, static_cast<int>(::QMetaType::UnknownType)},
    {sipName_Void, static_cast<int>(::QMetaType::Void)},
    {sipName_Bool, static_cast<int>(::QMetaType::Bool)},
    {sipName_Int, static_cast<int>(::QMetaType::Int)},
    {sipName_UInt, static_cast<int>(::QMetaType::UInt)},
    {sipName_LongLong, static_cast<int>(::QMetaType::LongLong)},
    {sipName_ULongLong, static_cast<int>(::QMetaType::ULongLong)},
    {sipName_Double, static_cast<int>(::QMetaType::Double)},
    {sipName_QChar, static_cast<int>(::QMetaType::QChar)},
    {sipName_QVariantMap, static_cast<int>(::QMetaType::QVariantMap)},
    {sipName_QVariantList, static_cast<int>(::QMetaType::QVariantList)},
    {sipName_QVariantHash, static_cast<int>(::QMetaType::QVariantHash)},
    {sipName_QString, static_cast<int>(::QMetaType::QString)},
    {sipName_QStringList, static_cast<int>(::QMetaType::QStringList)},
    {sipName_QByteArray, static_cast<int>(::QMetaType::QByteArray)},
    {sipName_QBitArray, static_cast<int>(::QMetaType::QBitArray)},
    {sipName_QDate, static_cast<int>(::QMetaType::QDate)},
    {sipName_QTime, static_cast<int>(::QMetaType::QTime)},
    {sipName_QDateTime, static_cast<int>(::QMetaType::QDateTime)},
    {sipName_QUrl, static_cast<int>(::QMetaType::QUrl)},
    {sipName_QLocale, static_cast<int>(::QMetaType::QLocale)},
    {sipName_QRect, static_cast<int>(::QMetaType::QRect)},
    {sipName_QRectF, static_cast<int>(::QMetaType::QRectF)},
    {sipName_QSize, static_cast<int>(::QMetaType::QSize)},
    {sipName_QSizeF, static_cast<int>(::QMetaType::QSizeF)},
    {sipName_QLine, static_cast<int>(::QMetaType::QLine)},
    {sipName_QLineF, static_cast<int>(::QMetaType::QLineF)},
    {sipName_QPoint, static_cast<int>(::QMetaType::QPoint)},
    {sipName_QPointF, static_cast<int>(::QMetaType::QPointF)},
    {sipName_LastCoreType, static_cast<int>(::QMetaType::LastCoreType)},
    {sipName_FirstGuiType, static_cast<int>(::QMetaType::FirstGuiType)},
    {sipName_QFont, static_cast<int>(::QMetaType::QFont)},
    {sipName_QPixmap, static_cast<int>(::QMetaType::QPixmap)},
    {sipName_QBrush, static_cast<int>(::QMetaType::QBrush)},
    {sipName_QColor, static_cast<int>(::QMetaType::QColor)},
    {sipName_QPalette, static_cast<int>(::QMetaType::QPalette)},
    {sipName_QIcon, static_cast<int>(::QMetaType::QIcon)},
    {sipName_QImage, static_cast<int>(::QMetaType::QImage)},
    {sipName_QPolygon, static_cast<int>(::QMetaType::QPolygon)},
    {sipName_QRegion, static_cast<int>(::QMetaType::QRegion)},
    {sipName_QBitmap, static_cast<int>(::QMetaType::QBitmap)},
    {sipName_QCursor, static_cast<int>(::QMetaType::QCursor)},
    {sipName_QSizePolicy, static_cast<int>(::QMetaType::QSizePolicy)},
    {sipName_QKeySequence, static_cast<int>(::QMetaType::QKeySequence)},
    {sipName_QPen, static_cast<int>(::QMetaType::QPen)},
    {sipName_QTextLength, static_cast<int>(::QMetaType::QTextLength)},
    {sipName_QTextFormat, static_cast<int>(::QMetaType::QTextFormat)},
    {sipName_QTransform, static_cast<int>(::QMetaType::QTransform)},
    {sipName_VoidStar, static_cast<int>(::QMetaType::VoidStar)},
    {sipName_Long, static_cast<int>(::QMetaType::Long)},
    {sipName_Short, static_cast<int>(::QMetaType::Short)},
    {sipName_Char, static_cast<int>(::QMetaType::Char)},
    {sipName_Char16, static_cast<int>(::QMetaType::Char16)},
    {sipName_Char32, static_cast<int>(::QMetaType::Char32)},
    {sipName_ULong, static_cast<int>(::QMetaType::ULong)},
    {sipName_UShort, static_cast<int>(::QMetaType::UShort)},
    {sipName_UChar, static_cast<int>(::QMetaType::UChar)},
    {sipName_Float, static_cast<int>(::QMetaType::Float)},
    {sipName_Float16, static_cast<int>(::QMetaType::Float16)},
    {sipName_QObjectStar, static_cast<int>(::QMetaType::QObjectStar)},
    {sipName_QMatrix4x4, static_cast<int>(::QMetaType::QMatrix4x4)},
    {sipName_QVector2D, static_cast<int>(::QMetaType::QVector2D)},
    {sipName_QVector3D, static_cast<int>(::QMetaType::QVector3D)},
    {sipName_QVector4D, static_cast<int>(::QMetaType::QVector4D)},
    {sipName_QQuaternion, static_cast<int>(::QMetaType::QQuaternion)},
    {sipName_QEasingCurve, static_cast<int>(::QMetaType::QEasingCurve)},
    {sipName_QVariant, static_cast<int>(::QMetaType::QVariant)},
    {sipName_QUuid, static_cast<int>(::QMetaType::QUuid)},
    {sipName_QModelIndex, static_cast<int>(::QMetaType::QModelIndex)},
    {sipName_QPolygonF, static_cast<int>(::QMetaType::QPolygonF)},
    {sipName_SChar, static_cast<int>(::QMetaType::SChar)},
    {sipName_QRegularExpression, static_cast<int>(::QMetaType::QRegularExpression)},
    {sipName_QJsonValue, static_cast<int>(::QMetaType::QJsonValue)},
    {sipName_QJsonObject, static_cast<int>(::QMetaType::QJsonObject)},
    {sipName_QJsonArray, static_cast<int>(::QMetaType::QJsonArray)},
    {sipName_QJsonDocument, static_cast<int>(::QMetaType::QJsonDocument)},
    {sipName_QByteArrayList, static_cast<int>(::QMetaType::QByteArrayList)},
    {sipName_QPersistentModelIndex, static_cast<int>(::QMetaType::QPersistentModelIndex)},
    {sipName_QCborSimpleType, static_cast<int>(::QMetaType::QCborSimpleType)},
    {sipName_QCborValue, static_cast<int>(::QMetaType::QCborValue)},
    {sipName_QCborArray, static_cast<int>(::QMetaType::QCborArray)},
    {sipName_QCborMap, static_cast<int>(::QMetaType::QCborMap)},
    {sipName_QColorSpace, static_cast<int>(::QMetaType::QColorSpace)},
    {sipName_QVariantPair, static_cast<int>(::QMetaType::QVariantPair)},
    {sipName_User, static_cast<int>(::QMetaType::User)},
    {sipName_NeedsConstruction, static_cast<int>(::QMetaType::NeedsConstruction)},
    {sipName_NeedsDestruction, static_cast<int>(::QMetaType::NeedsDestruction)},
    {sipName_PointerToQObject, static_cast<int>(::QMetaType::PointerToQObject)},
    {sipName_IsEnumeration, static_cast<int>(::QMetaType::IsEnumeration)},
    {sipName_IsUnsignedEnumeration, static_cast<int>(::QMetaType::IsUnsignedEnumeration)},
    {sipName_IsPointer, static_cast<int>(::QMetaType::IsPointer)},
    {sipName_RelocatableType, static_cast<int>(::QMetaType::RelocatableType)},
    {sipName_IsQmlList, static_cast<int>(::QMetaType::IsQmlList)},
    {sipName_IsConst, static_cast<int>(::QMetaType::IsConst)},
    {sipName_NeedsCopyConstruction, static_cast<int>(::QMetaType::NeedsCopyConstruction)},
    {sipName_NeedsMoveConstruction, static_cast<int>(::QMetaType::NeedsMoveConstruction)},
    {0, 0}
};

PyDoc_STRVAR(doc_QMetaType, "\1QMetaType()\n"
"QMetaType(type: int)");


sipClassTypeDef sipTypeDef_QtCore_QMetaType = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMetaType,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QMetaType,
        {0, 0, 1},
        20, methods_QMetaType,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QMetaType, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMetaType,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QMetaType,
    init_type_QMetaType,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMetaType,
    SIP_NULLPTR,
    array_QMetaType,
    SIP_NULLPTR,
    release_QMetaType,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QMetaType,
    sizeof (::QMetaType),
};
