/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontvariableaxis.sip"
#include <qfontvariableaxis.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontVariableAxis.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontVariableAxis.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 267 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontVariableAxis.cpp"


PyDoc_STRVAR(doc_QFontVariableAxis_swap, "swap(self, other: QFontVariableAxis)");

extern "C" {static PyObject *meth_QFontVariableAxis_swap(PyObject *, PyObject *);}
static PyObject *meth_QFontVariableAxis_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QFontVariableAxis* a0;
        ::QFontVariableAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QFontVariableAxis, &sipCpp, sipType_QFontVariableAxis, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontVariableAxis, sipName_swap, doc_QFontVariableAxis_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontVariableAxis_tag, "tag(self) -> QFont.Tag");

extern "C" {static PyObject *meth_QFontVariableAxis_tag(PyObject *, PyObject *);}
static PyObject *meth_QFontVariableAxis_tag(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontVariableAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontVariableAxis, &sipCpp))
        {
            ::QFont::Tag*sipRes;

            sipRes = new ::QFont::Tag(sipCpp->tag());

            return sipConvertFromNewType(sipRes, sipType_QFont_Tag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontVariableAxis, sipName_tag, doc_QFontVariableAxis_tag);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontVariableAxis_setTag, "setTag(self, tag: QFont.Tag)");

extern "C" {static PyObject *meth_QFontVariableAxis_setTag(PyObject *, PyObject *);}
static PyObject *meth_QFontVariableAxis_setTag(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QFont::Tag* a0;
        ::QFontVariableAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QFontVariableAxis, &sipCpp, sipType_QFont_Tag, &a0))
        {
            sipCpp->setTag(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontVariableAxis, sipName_setTag, doc_QFontVariableAxis_setTag);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontVariableAxis_name, "name(self) -> str");

extern "C" {static PyObject *meth_QFontVariableAxis_name(PyObject *, PyObject *);}
static PyObject *meth_QFontVariableAxis_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontVariableAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontVariableAxis, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontVariableAxis, sipName_name, doc_QFontVariableAxis_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontVariableAxis_setName, "setName(self, name: str|None)");

extern "C" {static PyObject *meth_QFontVariableAxis_setName(PyObject *, PyObject *);}
static PyObject *meth_QFontVariableAxis_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QFontVariableAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFontVariableAxis, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontVariableAxis, sipName_setName, doc_QFontVariableAxis_setName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontVariableAxis_minimumValue, "minimumValue(self) -> float");

extern "C" {static PyObject *meth_QFontVariableAxis_minimumValue(PyObject *, PyObject *);}
static PyObject *meth_QFontVariableAxis_minimumValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontVariableAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontVariableAxis, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->minimumValue();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontVariableAxis, sipName_minimumValue, doc_QFontVariableAxis_minimumValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontVariableAxis_setMinimumValue, "setMinimumValue(self, minimumValue: float)");

extern "C" {static PyObject *meth_QFontVariableAxis_setMinimumValue(PyObject *, PyObject *);}
static PyObject *meth_QFontVariableAxis_setMinimumValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QFontVariableAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QFontVariableAxis, &sipCpp, &a0))
        {
            sipCpp->setMinimumValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontVariableAxis, sipName_setMinimumValue, doc_QFontVariableAxis_setMinimumValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontVariableAxis_maximumValue, "maximumValue(self) -> float");

extern "C" {static PyObject *meth_QFontVariableAxis_maximumValue(PyObject *, PyObject *);}
static PyObject *meth_QFontVariableAxis_maximumValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontVariableAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontVariableAxis, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->maximumValue();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontVariableAxis, sipName_maximumValue, doc_QFontVariableAxis_maximumValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontVariableAxis_setMaximumValue, "setMaximumValue(self, maximumValue: float)");

extern "C" {static PyObject *meth_QFontVariableAxis_setMaximumValue(PyObject *, PyObject *);}
static PyObject *meth_QFontVariableAxis_setMaximumValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QFontVariableAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QFontVariableAxis, &sipCpp, &a0))
        {
            sipCpp->setMaximumValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontVariableAxis, sipName_setMaximumValue, doc_QFontVariableAxis_setMaximumValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontVariableAxis_defaultValue, "defaultValue(self) -> float");

extern "C" {static PyObject *meth_QFontVariableAxis_defaultValue(PyObject *, PyObject *);}
static PyObject *meth_QFontVariableAxis_defaultValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontVariableAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontVariableAxis, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->defaultValue();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontVariableAxis, sipName_defaultValue, doc_QFontVariableAxis_defaultValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontVariableAxis_setDefaultValue, "setDefaultValue(self, defaultValue: float)");

extern "C" {static PyObject *meth_QFontVariableAxis_setDefaultValue(PyObject *, PyObject *);}
static PyObject *meth_QFontVariableAxis_setDefaultValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QFontVariableAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QFontVariableAxis, &sipCpp, &a0))
        {
            sipCpp->setDefaultValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontVariableAxis, sipName_setDefaultValue, doc_QFontVariableAxis_setDefaultValue);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QFontVariableAxis(void *, int);}
static void release_QFontVariableAxis(void *sipCppV, int)
{
    delete reinterpret_cast< ::QFontVariableAxis *>(sipCppV);
}


extern "C" {static void *array_QFontVariableAxis(Py_ssize_t);}
static void *array_QFontVariableAxis(Py_ssize_t sipNrElem)
{
    return new ::QFontVariableAxis[sipNrElem];
}


extern "C" {static void array_delete_QFontVariableAxis(void *);}
static void array_delete_QFontVariableAxis(void *sipCpp)
{
    delete[] reinterpret_cast< ::QFontVariableAxis *>(sipCpp);
}


extern "C" {static void assign_QFontVariableAxis(void *, Py_ssize_t, void *);}
static void assign_QFontVariableAxis(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QFontVariableAxis *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QFontVariableAxis *>(sipSrc);
}


extern "C" {static void *copy_QFontVariableAxis(const void *, Py_ssize_t);}
static void *copy_QFontVariableAxis(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QFontVariableAxis(reinterpret_cast<const ::QFontVariableAxis *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QFontVariableAxis(sipSimpleWrapper *);}
static void dealloc_QFontVariableAxis(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QFontVariableAxis(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QFontVariableAxis(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QFontVariableAxis(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QFontVariableAxis *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QFontVariableAxis();

            return sipCpp;
        }
    }

    {
        const ::QFontVariableAxis* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QFontVariableAxis, &a0))
        {
            sipCpp = new ::QFontVariableAxis(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QFontVariableAxis[] = {
    {sipName_defaultValue, meth_QFontVariableAxis_defaultValue, METH_VARARGS, doc_QFontVariableAxis_defaultValue},
    {sipName_maximumValue, meth_QFontVariableAxis_maximumValue, METH_VARARGS, doc_QFontVariableAxis_maximumValue},
    {sipName_minimumValue, meth_QFontVariableAxis_minimumValue, METH_VARARGS, doc_QFontVariableAxis_minimumValue},
    {sipName_name, meth_QFontVariableAxis_name, METH_VARARGS, doc_QFontVariableAxis_name},
    {sipName_setDefaultValue, meth_QFontVariableAxis_setDefaultValue, METH_VARARGS, doc_QFontVariableAxis_setDefaultValue},
    {sipName_setMaximumValue, meth_QFontVariableAxis_setMaximumValue, METH_VARARGS, doc_QFontVariableAxis_setMaximumValue},
    {sipName_setMinimumValue, meth_QFontVariableAxis_setMinimumValue, METH_VARARGS, doc_QFontVariableAxis_setMinimumValue},
    {sipName_setName, meth_QFontVariableAxis_setName, METH_VARARGS, doc_QFontVariableAxis_setName},
    {sipName_setTag, meth_QFontVariableAxis_setTag, METH_VARARGS, doc_QFontVariableAxis_setTag},
    {sipName_swap, meth_QFontVariableAxis_swap, METH_VARARGS, doc_QFontVariableAxis_swap},
    {sipName_tag, meth_QFontVariableAxis_tag, METH_VARARGS, doc_QFontVariableAxis_tag}
};

PyDoc_STRVAR(doc_QFontVariableAxis, "\1QFontVariableAxis()\n"
"QFontVariableAxis(axis: QFontVariableAxis)");


sipClassTypeDef sipTypeDef_QtGui_QFontVariableAxis = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QFontVariableAxis,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QFontVariableAxis,
        {0, 0, 1},
        11, methods_QFontVariableAxis,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QFontVariableAxis,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QFontVariableAxis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QFontVariableAxis,
    assign_QFontVariableAxis,
    array_QFontVariableAxis,
    copy_QFontVariableAxis,
    release_QFontVariableAxis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QFontVariableAxis,
    sizeof (::QFontVariableAxis),
};
