/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtRemoteObjectsAPI_H
#define _QtRemoteObjectsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtRemoteObjects[0]
#define sipNameNr_51 51
#define sipName_51 &sipStrings_QtRemoteObjects[51]
#define sipNameNr_QRemoteObjectHostBase__AllowedSchemas 98
#define sipName_QRemoteObjectHostBase__AllowedSchemas &sipStrings_QtRemoteObjects[98]
#define sipNameNr_QRemoteObjectAbstractPersistedStore 136
#define sipName_QRemoteObjectAbstractPersistedStore &sipStrings_QtRemoteObjects[136]
#define sipNameNr_QRemoteObjectSourceLocationInfo 172
#define sipName_QRemoteObjectSourceLocationInfo &sipStrings_QtRemoteObjects[172]
#define sipNameNr_QtRemoteObjects__InitialAction 204
#define sipName_QtRemoteObjects__InitialAction &sipStrings_QtRemoteObjects[204]
#define sipNameNr_OperationNotValidOnClientNode 235
#define sipName_OperationNotValidOnClientNode &sipStrings_QtRemoteObjects[235]
#define sipNameNr_QRemoteObjectNode__ErrorCode 265
#define sipName_QRemoteObjectNode__ErrorCode &sipStrings_QtRemoteObjects[265]
#define sipNameNr_QRemoteObjectDynamicReplica 294
#define sipName_QRemoteObjectDynamicReplica &sipStrings_QtRemoteObjects[294]
#define sipNameNr_QRemoteObjectReplica__State 322
#define sipName_QRemoteObjectReplica__State &sipStrings_QtRemoteObjects[322]
#define sipNameNr_AllowExternalRegistration 350
#define sipName_AllowExternalRegistration &sipStrings_QtRemoteObjects[350]
#define sipNameNr_QAbstractItemModelReplica 376
#define sipName_QAbstractItemModelReplica &sipStrings_QtRemoteObjects[376]
#define sipNameNr_QRemoteObjectRegistryHost 402
#define sipName_QRemoteObjectRegistryHost &sipStrings_QtRemoteObjects[402]
#define sipNameNr_UnintendedRegistryHosting 428
#define sipName_UnintendedRegistryHosting &sipStrings_QtRemoteObjects[428]
#define sipNameNr_heartbeatIntervalChanged 454
#define sipName_heartbeatIntervalChanged &sipStrings_QtRemoteObjects[454]
#define sipNameNr_PyQt6_sip_simplewrapper 479
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtRemoteObjects[479]
#define sipNameNr_addClientSideConnection 503
#define sipName_addClientSideConnection &sipStrings_QtRemoteObjects[503]
#define sipNameNr_PyQt6_QtRemoteObjects 527
#define sipName_PyQt6_QtRemoteObjects &sipStrings_QtRemoteObjects[527]
#define sipNameNr_QRemoteObjectHostBase 549
#define sipName_QRemoteObjectHostBase &sipStrings_QtRemoteObjects[549]
#define sipNameNr_QRemoteObjectRegistry 571
#define sipName_QRemoteObjectRegistry &sipStrings_QtRemoteObjects[571]
#define sipNameNr_RegistryAlreadyHosted 593
#define sipName_RegistryAlreadyHosted &sipStrings_QtRemoteObjects[593]
#define sipNameNr_addHostSideConnection 615
#define sipName_addHostSideConnection &sipStrings_QtRemoteObjects[615]
#define sipNameNr_setLocalServerOptions 637
#define sipName_setLocalServerOptions &sipStrings_QtRemoteObjects[637]
#define sipNameNr_QRemoteObjectReplica 659
#define sipName_QRemoteObjectReplica &sipStrings_QtRemoteObjects[659]
#define sipNameNr_ServerAlreadyCreated 680
#define sipName_ServerAlreadyCreated &sipStrings_QtRemoteObjects[680]
#define sipNameNr_setHeartbeatInterval 701
#define sipName_setHeartbeatInterval &sipStrings_QtRemoteObjects[701]
#define sipNameNr_supportedDragActions 722
#define sipName_supportedDragActions &sipStrings_QtRemoteObjects[722]
#define sipNameNr_supportedDropActions 743
#define sipName_supportedDropActions &sipStrings_QtRemoteObjects[743]
#define sipNameNr_RegistryNotAcquired 764
#define sipName_RegistryNotAcquired &sipStrings_QtRemoteObjects[764]
#define sipNameNr_SourceNotRegistered 784
#define sipName_SourceNotRegistered &sipStrings_QtRemoteObjects[784]
#define sipNameNr_remoteObjectRemoved 804
#define sipName_remoteObjectRemoved &sipStrings_QtRemoteObjects[804]
#define sipNameNr_BuiltInSchemasOnly 824
#define sipName_BuiltInSchemasOnly &sipStrings_QtRemoteObjects[824]
#define sipNameNr_MissingObjectName 843
#define sipName_MissingObjectName &sipStrings_QtRemoteObjects[843]
#define sipNameNr_QRemoteObjectHost 861
#define sipName_QRemoteObjectHost &sipStrings_QtRemoteObjects[861]
#define sipNameNr_QRemoteObjectNode 879
#define sipName_QRemoteObjectNode &sipStrings_QtRemoteObjects[879]
#define sipNameNr_SignatureMismatch 897
#define sipName_SignatureMismatch &sipStrings_QtRemoteObjects[897]
#define sipNameNr_SocketAccessError 915
#define sipName_SocketAccessError &sipStrings_QtRemoteObjects[915]
#define sipNameNr_heartbeatInterval 933
#define sipName_heartbeatInterval &sipStrings_QtRemoteObjects[933]
#define sipNameNr_remoteObjectAdded 951
#define sipName_remoteObjectAdded &sipStrings_QtRemoteObjects[951]
#define sipNameNr_resetInternalData 969
#define sipName_resetInternalData &sipStrings_QtRemoteObjects[969]
#define sipNameNr_restoreProperties 987
#define sipName_restoreProperties &sipStrings_QtRemoteObjects[987]
#define sipNameNr_setPersistedStore 1005
#define sipName_setPersistedStore &sipStrings_QtRemoteObjects[1005]
#define sipNameNr_ProtocolMismatch 1023
#define sipName_ProtocolMismatch &sipStrings_QtRemoteObjects[1023]
#define sipNameNr_disconnectNotify 1040
#define sipName_disconnectNotify &sipStrings_QtRemoteObjects[1040]
#define sipNameNr_setRootCacheSize 1057
#define sipName_setRootCacheSize &sipStrings_QtRemoteObjects[1057]
#define sipNameNr_QtRemoteObjects 533
#define sipName_QtRemoteObjects &sipStrings_QtRemoteObjects[533]
#define sipNameNr_canDropMimeData 1074
#define sipName_canDropMimeData &sipStrings_QtRemoteObjects[1074]
#define sipNameNr_disableRemoting 1090
#define sipName_disableRemoting &sipStrings_QtRemoteObjects[1090]
#define sipNameNr_registryAddress 1106
#define sipName_registryAddress &sipStrings_QtRemoteObjects[1106]
#define sipNameNr_sourceLocations 1122
#define sipName_sourceLocations &sipStrings_QtRemoteObjects[1122]
#define sipNameNr_waitForRegistry 1138
#define sipName_waitForRegistry &sipStrings_QtRemoteObjects[1138]
#define sipNameNr_AllowedSchemas 121
#define sipName_AllowedSchemas &sipStrings_QtRemoteObjects[121]
#define sipNameNr_HostUrlInvalid 1154
#define sipName_HostUrlInvalid &sipStrings_QtRemoteObjects[1154]
#define sipNameNr_NodeIsNoServer 1169
#define sipName_NodeIsNoServer &sipStrings_QtRemoteObjects[1169]
#define sipNameNr_acquireDynamic 1184
#define sipName_acquireDynamic &sipStrings_QtRemoteObjects[1184]
#define sipNameNr_allowedSchemas 1199
#define sipName_allowedSchemas &sipStrings_QtRemoteObjects[1199]
#define sipNameNr_availableRoles 1214
#define sipName_availableRoles &sipStrings_QtRemoteObjects[1214]
#define sipNameNr_enableRemoting 1229
#define sipName_enableRemoting &sipStrings_QtRemoteObjects[1229]
#define sipNameNr_hostUrlChanged 1244
#define sipName_hostUrlChanged &sipStrings_QtRemoteObjects[1244]
#define sipNameNr_isReplicaValid 1259
#define sipName_isReplicaValid &sipStrings_QtRemoteObjects[1259]
#define sipNameNr_persistedStore 1274
#define sipName_persistedStore &sipStrings_QtRemoteObjects[1274]
#define sipNameNr_saveProperties 1289
#define sipName_saveProperties &sipStrings_QtRemoteObjects[1289]
#define sipNameNr_selectionModel 1304
#define sipName_selectionModel &sipStrings_QtRemoteObjects[1304]
#define sipNameNr_setRegistryUrl 1319
#define sipName_setRegistryUrl &sipStrings_QtRemoteObjects[1319]
#define sipNameNr_FetchRootSize 1334
#define sipName_FetchRootSize &sipStrings_QtRemoteObjects[1334]
#define sipNameNr_InitialAction 221
#define sipName_InitialAction &sipStrings_QtRemoteObjects[221]
#define sipNameNr_Uninitialized 1348
#define sipName_Uninitialized &sipStrings_QtRemoteObjects[1348]
#define sipNameNr_clearItemData 1362
#define sipName_clearItemData &sipStrings_QtRemoteObjects[1362]
#define sipNameNr_connectNotify 1043
#define sipName_connectNotify &sipStrings_QtRemoteObjects[1043]
#define sipNameNr_connectToNode 1376
#define sipName_connectToNode &sipStrings_QtRemoteObjects[1376]
#define sipNameNr_insertColumns 1390
#define sipName_insertColumns &sipStrings_QtRemoteObjects[1390]
#define sipNameNr_isInitialized 1404
#define sipName_isInitialized &sipStrings_QtRemoteObjects[1404]
#define sipNameNr_removeColumns 1418
#define sipName_removeColumns &sipStrings_QtRemoteObjects[1418]
#define sipNameNr_rootCacheSize 1432
#define sipName_rootCacheSize &sipStrings_QtRemoteObjects[1432]
#define sipNameNr_setHeaderData 1446
#define sipName_setHeaderData &sipStrings_QtRemoteObjects[1446]
#define sipNameNr_waitForSource 1460
#define sipName_waitForSource &sipStrings_QtRemoteObjects[1460]
#define sipNameNr_ListenFailed 1474
#define sipName_ListenFailed &sipStrings_QtRemoteObjects[1474]
#define sipNameNr_PrefetchData 1487
#define sipName_PrefetchData &sipStrings_QtRemoteObjects[1487]
#define sipNameNr_acquireModel 1500
#define sipName_acquireModel &sipStrings_QtRemoteObjects[1500]
#define sipNameNr_canFetchMore 1513
#define sipName_canFetchMore &sipStrings_QtRemoteObjects[1513]
#define sipNameNr_dropMimeData 1526
#define sipName_dropMimeData &sipStrings_QtRemoteObjects[1526]
#define sipNameNr_reverseProxy 1539
#define sipName_reverseProxy &sipStrings_QtRemoteObjects[1539]
#define sipNameNr_stateChanged 1552
#define sipName_stateChanged &sipStrings_QtRemoteObjects[1552]
#define sipNameNr_columnCount 1565
#define sipName_columnCount &sipStrings_QtRemoteObjects[1565]
#define sipNameNr_customEvent 1577
#define sipName_customEvent &sipStrings_QtRemoteObjects[1577]
#define sipNameNr_eventFilter 1589
#define sipName_eventFilter &sipStrings_QtRemoteObjects[1589]
#define sipNameNr_hasChildren 1601
#define sipName_hasChildren &sipStrings_QtRemoteObjects[1601]
#define sipNameNr_initialized 1350
#define sipName_initialized &sipStrings_QtRemoteObjects[1350]
#define sipNameNr_moveColumns 1420
#define sipName_moveColumns &sipStrings_QtRemoteObjects[1420]
#define sipNameNr_registryUrl 1613
#define sipName_registryUrl &sipStrings_QtRemoteObjects[1613]
#define sipNameNr_setItemData 1625
#define sipName_setItemData &sipStrings_QtRemoteObjects[1625]
#define sipNameNr___lshift__ 1637
#define sipName___lshift__ &sipStrings_QtRemoteObjects[1637]
#define sipNameNr___rshift__ 1648
#define sipName___rshift__ &sipStrings_QtRemoteObjects[1648]
#define sipNameNr_childEvent 1659
#define sipName_childEvent &sipStrings_QtRemoteObjects[1659]
#define sipNameNr_headerData 1670
#define sipName_headerData &sipStrings_QtRemoteObjects[1670]
#define sipNameNr_insertRows 1681
#define sipName_insertRows &sipStrings_QtRemoteObjects[1681]
#define sipNameNr_removeRows 1692
#define sipName_removeRows &sipStrings_QtRemoteObjects[1692]
#define sipNameNr_setHostUrl 1703
#define sipName_setHostUrl &sipStrings_QtRemoteObjects[1703]
#define sipNameNr_timerEvent 1714
#define sipName_timerEvent &sipStrings_QtRemoteObjects[1714]
#define sipNameNr_ErrorCode 284
#define sipName_ErrorCode &sipStrings_QtRemoteObjects[284]
#define sipNameNr_fetchMore 1725
#define sipName_fetchMore &sipStrings_QtRemoteObjects[1725]
#define sipNameNr_instances 1735
#define sipName_instances &sipStrings_QtRemoteObjects[1735]
#define sipNameNr_lastError 1745
#define sipName_lastError &sipStrings_QtRemoteObjects[1745]
#define sipNameNr_mimeTypes 1755
#define sipName_mimeTypes &sipStrings_QtRemoteObjects[1755]
#define sipNameNr_multiData 1765
#define sipName_multiData &sipStrings_QtRemoteObjects[1765]
#define sipNameNr_roleNames 1775
#define sipName_roleNames &sipStrings_QtRemoteObjects[1775]
#define sipNameNr_rolesHint 1785
#define sipName_rolesHint &sipStrings_QtRemoteObjects[1785]
#define sipNameNr_itemData 1795
#define sipName_itemData &sipStrings_QtRemoteObjects[1795]
#define sipNameNr_mimeData 1804
#define sipName_mimeData &sipStrings_QtRemoteObjects[1804]
#define sipNameNr_moveRows 1694
#define sipName_moveRows &sipStrings_QtRemoteObjects[1694]
#define sipNameNr_notified 1813
#define sipName_notified &sipStrings_QtRemoteObjects[1813]
#define sipNameNr_registry 1822
#define sipName_registry &sipStrings_QtRemoteObjects[1822]
#define sipNameNr_rowCount 1831
#define sipName_rowCount &sipStrings_QtRemoteObjects[1831]
#define sipNameNr_typeName 1840
#define sipName_typeName &sipStrings_QtRemoteObjects[1840]
#define sipNameNr_Default 1849
#define sipName_Default &sipStrings_QtRemoteObjects[1849]
#define sipNameNr_NoError 1857
#define sipName_NoError &sipStrings_QtRemoteObjects[1857]
#define sipNameNr_Suspect 1865
#define sipName_Suspect &sipStrings_QtRemoteObjects[1865]
#define sipNameNr_hasData 1873
#define sipName_hasData &sipStrings_QtRemoteObjects[1873]
#define sipNameNr_hostUrl 1881
#define sipName_hostUrl &sipStrings_QtRemoteObjects[1881]
#define sipNameNr_setData 1889
#define sipName_setData &sipStrings_QtRemoteObjects[1889]
#define sipNameNr_setName 1897
#define sipName_setName &sipStrings_QtRemoteObjects[1897]
#define sipNameNr_setNode 1905
#define sipName_setNode &sipStrings_QtRemoteObjects[1905]
#define sipNameNr_sibling 1913
#define sipName_sibling &sipStrings_QtRemoteObjects[1913]
#define sipNameNr_timeout 1921
#define sipName_timeout &sipStrings_QtRemoteObjects[1921]
#define sipNameNr___eq__ 1929
#define sipName___eq__ &sipStrings_QtRemoteObjects[1929]
#define sipNameNr___ne__ 1936
#define sipName___ne__ &sipStrings_QtRemoteObjects[1936]
#define sipNameNr_action 1943
#define sipName_action &sipStrings_QtRemoteObjects[1943]
#define sipNameNr_parent 1950
#define sipName_parent &sipStrings_QtRemoteObjects[1950]
#define sipNameNr_revert 1957
#define sipName_revert &sipStrings_QtRemoteObjects[1957]
#define sipNameNr_submit 1964
#define sipName_submit &sipStrings_QtRemoteObjects[1964]
#define sipNameNr_State 344
#define sipName_State &sipStrings_QtRemoteObjects[344]
#define sipNameNr_Valid 1268
#define sipName_Valid &sipStrings_QtRemoteObjects[1268]
#define sipNameNr_buddy 1971
#define sipName_buddy &sipStrings_QtRemoteObjects[1971]
#define sipNameNr_error 1977
#define sipName_error &sipStrings_QtRemoteObjects[1977]
#define sipNameNr_event 1983
#define sipName_event &sipStrings_QtRemoteObjects[1983]
#define sipNameNr_flags 1989
#define sipName_flags &sipStrings_QtRemoteObjects[1989]
#define sipNameNr_index 1995
#define sipName_index &sipStrings_QtRemoteObjects[1995]
#define sipNameNr_match 909
#define sipName_match &sipStrings_QtRemoteObjects[909]
#define sipNameNr_proxy 2001
#define sipName_proxy &sipStrings_QtRemoteObjects[2001]
#define sipNameNr_state 2007
#define sipName_state &sipStrings_QtRemoteObjects[2007]
#define sipNameNr_data 2013
#define sipName_data &sipStrings_QtRemoteObjects[2013]
#define sipNameNr_name 2018
#define sipName_name &sipStrings_QtRemoteObjects[2018]
#define sipNameNr_node 2023
#define sipName_node &sipStrings_QtRemoteObjects[2023]
#define sipNameNr_role 2028
#define sipName_role &sipStrings_QtRemoteObjects[2028]
#define sipNameNr_sort 2033
#define sipName_sort &sipStrings_QtRemoteObjects[2033]
#define sipNameNr_span 2038
#define sipName_span &sipStrings_QtRemoteObjects[2038]

#define sipMalloc                   sipAPI_QtRemoteObjects->api_malloc
#define sipFree                     sipAPI_QtRemoteObjects->api_free
#define sipBuildResult              sipAPI_QtRemoteObjects->api_build_result
#define sipCallMethod               sipAPI_QtRemoteObjects->api_call_method
#define sipCallProcedureMethod      sipAPI_QtRemoteObjects->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtRemoteObjects->api_call_error_handler
#define sipParseResultEx            sipAPI_QtRemoteObjects->api_parse_result_ex
#define sipParseResult              sipAPI_QtRemoteObjects->api_parse_result
#define sipParseArgs                sipAPI_QtRemoteObjects->api_parse_args
#define sipParseKwdArgs             sipAPI_QtRemoteObjects->api_parse_kwd_args
#define sipParsePair                sipAPI_QtRemoteObjects->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtRemoteObjects->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtRemoteObjects->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtRemoteObjects->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtRemoteObjects->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtRemoteObjects->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtRemoteObjects->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtRemoteObjects->api_add_exception
#define sipNoFunction               sipAPI_QtRemoteObjects->api_no_function
#define sipNoMethod                 sipAPI_QtRemoteObjects->api_no_method
#define sipAbstractMethod           sipAPI_QtRemoteObjects->api_abstract_method
#define sipBadClass                 sipAPI_QtRemoteObjects->api_bad_class
#define sipBadCatcherResult         sipAPI_QtRemoteObjects->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtRemoteObjects->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtRemoteObjects->api_bad_operator_arg
#define sipTrace                    sipAPI_QtRemoteObjects->api_trace
#define sipTransferBack             sipAPI_QtRemoteObjects->api_transfer_back
#define sipTransferTo               sipAPI_QtRemoteObjects->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtRemoteObjects->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtRemoteObjects->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtRemoteObjects->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtRemoteObjects->api_voidptr_type
#define sipGetPyObject              sipAPI_QtRemoteObjects->api_get_pyobject
#define sipGetAddress               sipAPI_QtRemoteObjects->api_get_address
#define sipGetMixinAddress          sipAPI_QtRemoteObjects->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtRemoteObjects->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtRemoteObjects->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtRemoteObjects->api_call_hook
#define sipEndThread                sipAPI_QtRemoteObjects->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtRemoteObjects->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtRemoteObjects->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtRemoteObjects->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtRemoteObjects->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtRemoteObjects->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtRemoteObjects->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtRemoteObjects->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtRemoteObjects->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtRemoteObjects->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtRemoteObjects->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtRemoteObjects->api_convert_to_bool
#define sipReleaseType              sipAPI_QtRemoteObjects->api_release_type
#define sipConvertFromType          sipAPI_QtRemoteObjects->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtRemoteObjects->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtRemoteObjects->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtRemoteObjects->api_convert_from_enum
#define sipGetState                 sipAPI_QtRemoteObjects->api_get_state
#define sipExportSymbol             sipAPI_QtRemoteObjects->api_export_symbol
#define sipImportSymbol             sipAPI_QtRemoteObjects->api_import_symbol
#define sipFindType                 sipAPI_QtRemoteObjects->api_find_type
#define sipBytes_AsChar             sipAPI_QtRemoteObjects->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtRemoteObjects->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtRemoteObjects->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtRemoteObjects->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtRemoteObjects->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtRemoteObjects->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtRemoteObjects->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtRemoteObjects->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtRemoteObjects->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtRemoteObjects->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtRemoteObjects->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtRemoteObjects->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtRemoteObjects->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtRemoteObjects->api_get_reference
#define sipKeepReference            sipAPI_QtRemoteObjects->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtRemoteObjects->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtRemoteObjects->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtRemoteObjects->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtRemoteObjects->api_type_scope
#define sipResolveTypedef           sipAPI_QtRemoteObjects->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtRemoteObjects->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtRemoteObjects->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtRemoteObjects->api_init_mixin
#define sipExportModule             sipAPI_QtRemoteObjects->api_export_module
#define sipInitModule               sipAPI_QtRemoteObjects->api_init_module
#define sipGetInterpreter           sipAPI_QtRemoteObjects->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtRemoteObjects->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtRemoteObjects->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtRemoteObjects->api_py_type_dict
#define sipPyTypeName               sipAPI_QtRemoteObjects->api_py_type_name
#define sipGetCFunction             sipAPI_QtRemoteObjects->api_get_c_function
#define sipGetMethod                sipAPI_QtRemoteObjects->api_get_method
#define sipFromMethod               sipAPI_QtRemoteObjects->api_from_method
#define sipGetDate                  sipAPI_QtRemoteObjects->api_get_date
#define sipFromDate                 sipAPI_QtRemoteObjects->api_from_date
#define sipGetDateTime              sipAPI_QtRemoteObjects->api_get_datetime
#define sipFromDateTime             sipAPI_QtRemoteObjects->api_from_datetime
#define sipGetTime                  sipAPI_QtRemoteObjects->api_get_time
#define sipFromTime                 sipAPI_QtRemoteObjects->api_from_time
#define sipIsUserType               sipAPI_QtRemoteObjects->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtRemoteObjects->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtRemoteObjects->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtRemoteObjects->api_unicode_write
#define sipUnicodeData              sipAPI_QtRemoteObjects->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtRemoteObjects->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtRemoteObjects->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtRemoteObjects->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtRemoteObjects->api_is_derived_class
#define sipGetUserObject            sipAPI_QtRemoteObjects->api_get_user_object
#define sipSetUserObject            sipAPI_QtRemoteObjects->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtRemoteObjects->api_register_event_handler
#define sipConvertToArray           sipAPI_QtRemoteObjects->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtRemoteObjects->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtRemoteObjects->api_enable_gc
#define sipPrintObject              sipAPI_QtRemoteObjects->api_print_object
#define sipLong_AsChar              sipAPI_QtRemoteObjects->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtRemoteObjects->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtRemoteObjects->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtRemoteObjects->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtRemoteObjects->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtRemoteObjects->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtRemoteObjects->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtRemoteObjects->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtRemoteObjects->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtRemoteObjects->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtRemoteObjects->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtRemoteObjects->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtRemoteObjects->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtRemoteObjects->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtRemoteObjects->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtRemoteObjects->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtRemoteObjects->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtRemoteObjects->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtRemoteObjects->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtRemoteObjects->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtRemoteObjects->api_release_type_us
#define sipIsPyMethod               sipAPI_QtRemoteObjects->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtRemoteObjects[];

#define sipType_QRemoteObjectSourceLocationInfo sipExportedTypes_QtRemoteObjects[13]

extern sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectSourceLocationInfo;

#define sipType_QtRemoteObjects sipExportedTypes_QtRemoteObjects[14]

#define sipType_QtRemoteObjects_InitialAction sipExportedTypes_QtRemoteObjects[15]

extern sipClassTypeDef sipTypeDef_QtRemoteObjects_QtRemoteObjects;

#define sipType_QAbstractItemModelReplica sipExportedTypes_QtRemoteObjects[0]

extern sipClassTypeDef sipTypeDef_QtRemoteObjects_QAbstractItemModelReplica;

#define sipType_QRemoteObjectReplica sipExportedTypes_QtRemoteObjects[11]

#define sipType_QRemoteObjectReplica_State sipExportedTypes_QtRemoteObjects[12]

extern sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectReplica;

#define sipType_QRemoteObjectDynamicReplica sipExportedTypes_QtRemoteObjects[3]

extern sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectDynamicReplica;

#define sipType_QRemoteObjectAbstractPersistedStore sipExportedTypes_QtRemoteObjects[2]

extern sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectAbstractPersistedStore;

#define sipType_QRemoteObjectNode sipExportedTypes_QtRemoteObjects[7]

#define sipType_QRemoteObjectNode_ErrorCode sipExportedTypes_QtRemoteObjects[8]

extern sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectNode;

#define sipType_QRemoteObjectHostBase sipExportedTypes_QtRemoteObjects[5]

#define sipType_QRemoteObjectHostBase_AllowedSchemas sipExportedTypes_QtRemoteObjects[6]

extern sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectHostBase;

#define sipType_QRemoteObjectHost sipExportedTypes_QtRemoteObjects[4]

extern sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectHost;

#define sipType_QRemoteObjectRegistryHost sipExportedTypes_QtRemoteObjects[10]

extern sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectRegistryHost;

#define sipType_QRemoteObjectRegistry sipExportedTypes_QtRemoteObjects[9]

extern sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectRegistry;

#define sipType_QHash_0100QString_0100QRemoteObjectSourceLocationInfo sipExportedTypes_QtRemoteObjects[1]

extern sipMappedTypeDef sipTypeDef_QtRemoteObjects_QHash_0100QString_0100QRemoteObjectSourceLocationInfo;

#define sipType_std_pair_0100QString_0100QRemoteObjectSourceLocationInfo sipExportedTypes_QtRemoteObjects[16]

extern sipMappedTypeDef sipTypeDef_QtRemoteObjects_std_pair_0100QString_0100QRemoteObjectSourceLocationInfo;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtRemoteObjects;
extern sipExportedModuleDef sipModuleAPI_QtRemoteObjects;
extern sipTypeDef *sipExportedTypes_QtRemoteObjects[];

#define sipType_Qt_DropAction sipImportedTypes_QtRemoteObjects_QtCore[27].it_td

#define sipType_Qt_SortOrder sipImportedTypes_QtRemoteObjects_QtCore[29].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtRemoteObjects_QtCore[28].it_td

#define sipType_QObject sipImportedTypes_QtRemoteObjects_QtCore[19].it_td

#define sipType_QModelIndex sipImportedTypes_QtRemoteObjects_QtCore[17].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtRemoteObjects_QtCore[0].it_td

#define sipType_QModelRoleDataSpan sipImportedTypes_QtRemoteObjects_QtCore[18].it_td

#define sipType_QIODevice sipImportedTypes_QtRemoteObjects_QtCore[9].it_td

#define sipType_QByteArray sipImportedTypes_QtRemoteObjects_QtCore[1].it_td

#define sipType_QEvent sipImportedTypes_QtRemoteObjects_QtCore[4].it_td

#define sipType_QTimerEvent sipImportedTypes_QtRemoteObjects_QtCore[24].it_td

#define sipType_QChildEvent sipImportedTypes_QtRemoteObjects_QtCore[2].it_td

#define sipType_QDataStream sipImportedTypes_QtRemoteObjects_QtCore[3].it_td

#define sipType_QItemSelectionModel sipImportedTypes_QtRemoteObjects_QtCore[10].it_td

#define sipType_QMetaMethod sipImportedTypes_QtRemoteObjects_QtCore[15].it_td

#define sipType_QMimeData sipImportedTypes_QtRemoteObjects_QtCore[16].it_td

#define sipType_QSize sipImportedTypes_QtRemoteObjects_QtCore[20].it_td

#define sipType_QUrl sipImportedTypes_QtRemoteObjects_QtCore[25].it_td

#define sipType_QVariant sipImportedTypes_QtRemoteObjects_QtCore[26].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtRemoteObjects_QtCore[8].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtRemoteObjects_QtCore[14].it_td

#define sipType_QFlags_0100Qt_MatchFlag sipImportedTypes_QtRemoteObjects_QtCore[7].it_td

#define sipType_QFlags_0100Qt_ItemFlag sipImportedTypes_QtRemoteObjects_QtCore[6].it_td

#define sipType_QFlags_0100Qt_DropAction sipImportedTypes_QtRemoteObjects_QtCore[5].it_td

#define sipType_QList_0100QVariant sipImportedTypes_QtRemoteObjects_QtCore[12].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtRemoteObjects_QtCore[11].it_td

#define sipType_QStringList sipImportedTypes_QtRemoteObjects_QtCore[22].it_td

#define sipType_QList_1800 sipImportedTypes_QtRemoteObjects_QtCore[13].it_td

#define sipType_QStringView sipImportedTypes_QtRemoteObjects_QtCore[23].it_td

#define sipType_QString sipImportedTypes_QtRemoteObjects_QtCore[21].it_td
extern sipImportedTypeDef sipImportedTypes_QtRemoteObjects_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[];

#define sipType_QFlags_0100QLocalServer_SocketOption sipImportedTypes_QtRemoteObjects_QtNetwork[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtRemoteObjects_QtNetwork[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtRemoteObjects_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtRemoteObjects_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtRemoteObjects_qt_metacast;

#endif
