/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"


PyDoc_STRVAR(doc_QIcon_pixmap, "pixmap(self, size: QSize, devicePixelRatio: float, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> QPixmap\n"
"pixmap(self, size: QSize, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> QPixmap\n"
"pixmap(self, w: int, h: int, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> QPixmap\n"
"pixmap(self, extent: int, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> QPixmap");

extern "C" {static PyObject *meth_QIcon_pixmap(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_pixmap(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::qreal a1;
        ::QIcon::Mode a2 = QIcon::Normal;
        ::QIcon::State a3 = QIcon::Off;
        const ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9d|EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QSize, &a0, &a1, sipType_QIcon_Mode, &a2, sipType_QIcon_State, &a3))
        {
            ::QPixmap*sipRes;

            sipRes = new ::QPixmap(sipCpp->pixmap(*a0, a1, a2, a3));

            return sipConvertFromNewType(sipRes, sipType_QPixmap, SIP_NULLPTR);
        }
    }

    {
        const ::QSize* a0;
        ::QIcon::Mode a1 = QIcon::Normal;
        ::QIcon::State a2 = QIcon::Off;
        const ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QSize, &a0, sipType_QIcon_Mode, &a1, sipType_QIcon_State, &a2))
        {
            ::QPixmap*sipRes;

            sipRes = new ::QPixmap(sipCpp->pixmap(*a0, a1, a2));

            return sipConvertFromNewType(sipRes, sipType_QPixmap, SIP_NULLPTR);
        }
    }

    {
        int a0;
        int a1;
        ::QIcon::Mode a2 = QIcon::Normal;
        ::QIcon::State a3 = QIcon::Off;
        const ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|EE", &sipSelf, sipType_QIcon, &sipCpp, &a0, &a1, sipType_QIcon_Mode, &a2, sipType_QIcon_State, &a3))
        {
            ::QPixmap*sipRes;

            sipRes = new ::QPixmap(sipCpp->pixmap(a0, a1, a2, a3));

            return sipConvertFromNewType(sipRes, sipType_QPixmap, SIP_NULLPTR);
        }
    }

    {
        int a0;
        ::QIcon::Mode a1 = QIcon::Normal;
        ::QIcon::State a2 = QIcon::Off;
        const ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|EE", &sipSelf, sipType_QIcon, &sipCpp, &a0, sipType_QIcon_Mode, &a1, sipType_QIcon_State, &a2))
        {
            ::QPixmap*sipRes;

            sipRes = new ::QPixmap(sipCpp->pixmap(a0, a1, a2));

            return sipConvertFromNewType(sipRes, sipType_QPixmap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_pixmap, doc_QIcon_pixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_actualSize, "actualSize(self, size: QSize, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> QSize");

extern "C" {static PyObject *meth_QIcon_actualSize(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_actualSize(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QIcon::Mode a1 = QIcon::Normal;
        ::QIcon::State a2 = QIcon::Off;
        const ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QSize, &a0, sipType_QIcon_Mode, &a1, sipType_QIcon_State, &a2))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->actualSize(*a0, a1, a2));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_actualSize, doc_QIcon_actualSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_availableSizes, "availableSizes(self, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> list[QSize]");

extern "C" {static PyObject *meth_QIcon_availableSizes(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_availableSizes(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIcon::Mode a0 = QIcon::Normal;
        ::QIcon::State a1 = QIcon::Off;
        const ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QIcon_Mode, &a0, sipType_QIcon_State, &a1))
        {
            QList< ::QSize>*sipRes;

            sipRes = new QList< ::QSize>(sipCpp->availableSizes(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_availableSizes, doc_QIcon_availableSizes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_paint, "paint(self, painter: QPainter|None, rect: QRect, alignment: Qt.AlignmentFlag = Qt.AlignCenter, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off)\n"
"paint(self, painter: QPainter|None, x: int, y: int, w: int, h: int, alignment: Qt.AlignmentFlag = Qt.AlignCenter, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off)");

extern "C" {static PyObject *meth_QIcon_paint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_paint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter* a0;
        const ::QRect* a1;
        ::Qt::Alignment a2def = Qt::AlignCenter;
        ::Qt::Alignment* a2 = &a2def;
        int a2State = 0;
        ::QIcon::Mode a3 = QIcon::Normal;
        ::QIcon::State a4 = QIcon::Off;
        const ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_alignment,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J9|J1EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QPainter, &a0, sipType_QRect, &a1, sipType_QFlags_0100Qt_AlignmentFlag, &a2, &a2State, sipType_QIcon_Mode, &a3, sipType_QIcon_State, &a4))
        {
            sipCpp->paint(a0, *a1, *a2, a3, a4);
            sipReleaseType(a2, sipType_QFlags_0100Qt_AlignmentFlag, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QPainter* a0;
        int a1;
        int a2;
        int a3;
        int a4;
        ::Qt::Alignment a5def = Qt::AlignCenter;
        ::Qt::Alignment* a5 = &a5def;
        int a5State = 0;
        ::QIcon::Mode a6 = QIcon::Normal;
        ::QIcon::State a7 = QIcon::Off;
        const ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_alignment,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8iiii|J1EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QPainter, &a0, &a1, &a2, &a3, &a4, sipType_QFlags_0100Qt_AlignmentFlag, &a5, &a5State, sipType_QIcon_Mode, &a6, sipType_QIcon_State, &a7))
        {
            sipCpp->paint(a0, a1, a2, a3, a4, *a5, a6, a7);
            sipReleaseType(a5, sipType_QFlags_0100Qt_AlignmentFlag, a5State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_paint, doc_QIcon_paint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QIcon_isNull(PyObject *, PyObject *);}
static PyObject *meth_QIcon_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QIcon, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_isNull, doc_QIcon_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_isDetached, "isDetached(self) -> bool");

extern "C" {static PyObject *meth_QIcon_isDetached(PyObject *, PyObject *);}
static PyObject *meth_QIcon_isDetached(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QIcon, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDetached();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_isDetached, doc_QIcon_isDetached);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_addPixmap, "addPixmap(self, pixmap: QPixmap, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off)");

extern "C" {static PyObject *meth_QIcon_addPixmap(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_addPixmap(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPixmap* a0;
        ::QIcon::Mode a1 = QIcon::Normal;
        ::QIcon::State a2 = QIcon::Off;
        ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QPixmap, &a0, sipType_QIcon_Mode, &a1, sipType_QIcon_State, &a2))
        {
            sipCpp->addPixmap(*a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_addPixmap, doc_QIcon_addPixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_addFile, "addFile(self, fileName: str|None, size: QSize = QSize(), mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off)");

extern "C" {static PyObject *meth_QIcon_addFile(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_addFile(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QSize& a1def = QSize();
        const ::QSize* a1 = &a1def;
        ::QIcon::Mode a2 = QIcon::Normal;
        ::QIcon::State a3 = QIcon::Off;
        ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_size,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J9EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QString, &a0, &a0State, sipType_QSize, &a1, sipType_QIcon_Mode, &a2, sipType_QIcon_State, &a3))
        {
            sipCpp->addFile(*a0, *a1, a2, a3);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_addFile, doc_QIcon_addFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_cacheKey, "cacheKey(self) -> int");

extern "C" {static PyObject *meth_QIcon_cacheKey(PyObject *, PyObject *);}
static PyObject *meth_QIcon_cacheKey(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QIcon, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->cacheKey();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_cacheKey, doc_QIcon_cacheKey);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_fromTheme, "fromTheme(name: str|None) -> QIcon\n"
"fromTheme(name: str|None, fallback: QIcon) -> QIcon\n"
"fromTheme(icon: QIcon.ThemeIcon) -> QIcon\n"
"fromTheme(icon: QIcon.ThemeIcon, fallback: QIcon) -> QIcon");

extern "C" {static PyObject *meth_QIcon_fromTheme(PyObject *, PyObject *);}
static PyObject *meth_QIcon_fromTheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon(::QIcon::fromTheme(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QIcon* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1J9", &sipSelf, sipType_QString, &a0, &a0State, sipType_QIcon, &a1))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon(::QIcon::fromTheme(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    {
        ::QIcon::ThemeIcon a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QIcon_ThemeIcon, &a0))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon(::QIcon::fromTheme(a0));

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    {
        ::QIcon::ThemeIcon a0;
        const ::QIcon* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "CEJ9", &sipSelf, sipType_QIcon_ThemeIcon, &a0, sipType_QIcon, &a1))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon(::QIcon::fromTheme(a0, *a1));

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_fromTheme, doc_QIcon_fromTheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_hasThemeIcon, "hasThemeIcon(name: str|None) -> bool\n"
"hasThemeIcon(icon: QIcon.ThemeIcon) -> bool");

extern "C" {static PyObject *meth_QIcon_hasThemeIcon(PyObject *, PyObject *);}
static PyObject *meth_QIcon_hasThemeIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = ::QIcon::hasThemeIcon(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QIcon::ThemeIcon a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QIcon_ThemeIcon, &a0))
        {
            bool sipRes;

            sipRes = ::QIcon::hasThemeIcon(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_hasThemeIcon, doc_QIcon_hasThemeIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_themeSearchPaths, "themeSearchPaths() -> list[str]");

extern "C" {static PyObject *meth_QIcon_themeSearchPaths(PyObject *, PyObject *);}
static PyObject *meth_QIcon_themeSearchPaths(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QIcon::themeSearchPaths());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_themeSearchPaths, doc_QIcon_themeSearchPaths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_setThemeSearchPaths, "setThemeSearchPaths(searchpath: Iterable[str|None])");

extern "C" {static PyObject *meth_QIcon_setThemeSearchPaths(PyObject *, PyObject *);}
static PyObject *meth_QIcon_setThemeSearchPaths(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QStringList, &a0, &a0State))
        {
            ::QIcon::setThemeSearchPaths(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_setThemeSearchPaths, doc_QIcon_setThemeSearchPaths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_themeName, "themeName() -> str");

extern "C" {static PyObject *meth_QIcon_themeName(PyObject *, PyObject *);}
static PyObject *meth_QIcon_themeName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QIcon::themeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_themeName, doc_QIcon_themeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_setThemeName, "setThemeName(path: str|None)");

extern "C" {static PyObject *meth_QIcon_setThemeName(PyObject *, PyObject *);}
static PyObject *meth_QIcon_setThemeName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QIcon::setThemeName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_setThemeName, doc_QIcon_setThemeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_name, "name(self) -> str");

extern "C" {static PyObject *meth_QIcon_name(PyObject *, PyObject *);}
static PyObject *meth_QIcon_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QIcon, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_name, doc_QIcon_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_swap, "swap(self, other: QIcon)");

extern "C" {static PyObject *meth_QIcon_swap(PyObject *, PyObject *);}
static PyObject *meth_QIcon_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIcon* a0;
        ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QIcon, &sipCpp, sipType_QIcon, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_swap, doc_QIcon_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_setIsMask, "setIsMask(self, isMask: bool)");

extern "C" {static PyObject *meth_QIcon_setIsMask(PyObject *, PyObject *);}
static PyObject *meth_QIcon_setIsMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QIcon, &sipCpp, &a0))
        {
            sipCpp->setIsMask(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_setIsMask, doc_QIcon_setIsMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_isMask, "isMask(self) -> bool");

extern "C" {static PyObject *meth_QIcon_isMask(PyObject *, PyObject *);}
static PyObject *meth_QIcon_isMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QIcon, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMask();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_isMask, doc_QIcon_isMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_fallbackSearchPaths, "fallbackSearchPaths() -> list[str]");

extern "C" {static PyObject *meth_QIcon_fallbackSearchPaths(PyObject *, PyObject *);}
static PyObject *meth_QIcon_fallbackSearchPaths(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QIcon::fallbackSearchPaths());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_fallbackSearchPaths, doc_QIcon_fallbackSearchPaths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_setFallbackSearchPaths, "setFallbackSearchPaths(paths: Iterable[str|None])");

extern "C" {static PyObject *meth_QIcon_setFallbackSearchPaths(PyObject *, PyObject *);}
static PyObject *meth_QIcon_setFallbackSearchPaths(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QStringList, &a0, &a0State))
        {
            ::QIcon::setFallbackSearchPaths(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_setFallbackSearchPaths, doc_QIcon_setFallbackSearchPaths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_fallbackThemeName, "fallbackThemeName() -> str");

extern "C" {static PyObject *meth_QIcon_fallbackThemeName(PyObject *, PyObject *);}
static PyObject *meth_QIcon_fallbackThemeName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QIcon::fallbackThemeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_fallbackThemeName, doc_QIcon_fallbackThemeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_setFallbackThemeName, "setFallbackThemeName(name: str|None)");

extern "C" {static PyObject *meth_QIcon_setFallbackThemeName(PyObject *, PyObject *);}
static PyObject *meth_QIcon_setFallbackThemeName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QIcon::setFallbackThemeName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_setFallbackThemeName, doc_QIcon_setFallbackThemeName);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QIcon(void *, int);}
static void release_QIcon(void *sipCppV, int)
{
    delete reinterpret_cast< ::QIcon *>(sipCppV);
}


extern "C" {static void *array_QIcon(Py_ssize_t);}
static void *array_QIcon(Py_ssize_t sipNrElem)
{
    return new ::QIcon[sipNrElem];
}


extern "C" {static void array_delete_QIcon(void *);}
static void array_delete_QIcon(void *sipCpp)
{
    delete[] reinterpret_cast< ::QIcon *>(sipCpp);
}


extern "C" {static void assign_QIcon(void *, Py_ssize_t, void *);}
static void assign_QIcon(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QIcon *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QIcon *>(sipSrc);
}


extern "C" {static void *copy_QIcon(const void *, Py_ssize_t);}
static void *copy_QIcon(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QIcon(reinterpret_cast<const ::QIcon *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QIcon(sipSimpleWrapper *);}
static void dealloc_QIcon(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QIcon(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QIcon(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QIcon(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QIcon *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QIcon();

            return sipCpp;
        }
    }

    {
        const ::QPixmap* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPixmap, &a0))
        {
            sipCpp = new ::QIcon(*a0);

            return sipCpp;
        }
    }

    {
        const ::QIcon* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QIcon, &a0))
        {
            sipCpp = new ::QIcon(*a0);

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QString, &a0, &a0State))
        {
            sipCpp = new ::QIcon(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipCpp;
        }
    }

    {
        ::QIconEngine* a0;
        PyObject *a0Wrapper;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "@J8", &a0Wrapper, sipType_QIconEngine, &a0))
        {
#line 207 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
        sipCpp = new QIcon(a0);
        
        // The QIconEngine is implicitly shared by copies of the QIcon and is destroyed
        // by C++ when the last copy is destroyed.  Therefore we need to transfer
        // ownership but not to associate it with this QIcon.  The Python object will
        // get tidied up when the virtual dtor gets called.
        sipTransferTo(a0Wrapper, Py_None);
#line 1004 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"

            return sipCpp;
        }
    }

    {
        const ::QVariant* a0;
        PyObject *a0Wrapper;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "@J1", &a0Wrapper, sipType_QVariant, &a0, &a0State))
        {
            sipErrorState sipError = sipErrorNone;

#line 218 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
        if (a0->canConvert<QIcon>())
            sipCpp = new QIcon(a0->value<QIcon>());
        else
            sipError = sipBadCallableArg(0, a0Wrapper);
#line 1024 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQIcon.cpp"
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            if (sipError == sipErrorNone)
                return sipCpp;

            if (sipUnused)
            {
                Py_XDECREF(*sipUnused);
            }

            sipAddException(sipError, sipParseErr);

            if (sipError == sipErrorFail)
                return SIP_NULLPTR;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QIcon[] = {
    {sipName_actualSize, SIP_MLMETH_CAST(meth_QIcon_actualSize), METH_VARARGS|METH_KEYWORDS, doc_QIcon_actualSize},
    {sipName_addFile, SIP_MLMETH_CAST(meth_QIcon_addFile), METH_VARARGS|METH_KEYWORDS, doc_QIcon_addFile},
    {sipName_addPixmap, SIP_MLMETH_CAST(meth_QIcon_addPixmap), METH_VARARGS|METH_KEYWORDS, doc_QIcon_addPixmap},
    {sipName_availableSizes, SIP_MLMETH_CAST(meth_QIcon_availableSizes), METH_VARARGS|METH_KEYWORDS, doc_QIcon_availableSizes},
    {sipName_cacheKey, meth_QIcon_cacheKey, METH_VARARGS, doc_QIcon_cacheKey},
    {sipName_fallbackSearchPaths, meth_QIcon_fallbackSearchPaths, METH_VARARGS, doc_QIcon_fallbackSearchPaths},
    {sipName_fallbackThemeName, meth_QIcon_fallbackThemeName, METH_VARARGS, doc_QIcon_fallbackThemeName},
    {sipName_fromTheme, meth_QIcon_fromTheme, METH_VARARGS, doc_QIcon_fromTheme},
    {sipName_hasThemeIcon, meth_QIcon_hasThemeIcon, METH_VARARGS, doc_QIcon_hasThemeIcon},
    {sipName_isDetached, meth_QIcon_isDetached, METH_VARARGS, doc_QIcon_isDetached},
    {sipName_isMask, meth_QIcon_isMask, METH_VARARGS, doc_QIcon_isMask},
    {sipName_isNull, meth_QIcon_isNull, METH_VARARGS, doc_QIcon_isNull},
    {sipName_name, meth_QIcon_name, METH_VARARGS, doc_QIcon_name},
    {sipName_paint, SIP_MLMETH_CAST(meth_QIcon_paint), METH_VARARGS|METH_KEYWORDS, doc_QIcon_paint},
    {sipName_pixmap, SIP_MLMETH_CAST(meth_QIcon_pixmap), METH_VARARGS|METH_KEYWORDS, doc_QIcon_pixmap},
    {sipName_setFallbackSearchPaths, meth_QIcon_setFallbackSearchPaths, METH_VARARGS, doc_QIcon_setFallbackSearchPaths},
    {sipName_setFallbackThemeName, meth_QIcon_setFallbackThemeName, METH_VARARGS, doc_QIcon_setFallbackThemeName},
    {sipName_setIsMask, meth_QIcon_setIsMask, METH_VARARGS, doc_QIcon_setIsMask},
    {sipName_setThemeName, meth_QIcon_setThemeName, METH_VARARGS, doc_QIcon_setThemeName},
    {sipName_setThemeSearchPaths, meth_QIcon_setThemeSearchPaths, METH_VARARGS, doc_QIcon_setThemeSearchPaths},
    {sipName_swap, meth_QIcon_swap, METH_VARARGS, doc_QIcon_swap},
    {sipName_themeName, meth_QIcon_themeName, METH_VARARGS, doc_QIcon_themeName},
    {sipName_themeSearchPaths, meth_QIcon_themeSearchPaths, METH_VARARGS, doc_QIcon_themeSearchPaths}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QIcon[] = {
    {sipName_Normal, static_cast<int>(::QIcon::Normal)},
    {sipName_Disabled, static_cast<int>(::QIcon::Disabled)},
    {sipName_Active, static_cast<int>(::QIcon::Active)},
    {sipName_Selected, static_cast<int>(::QIcon::Selected)},
    {sipName_On, static_cast<int>(::QIcon::On)},
    {sipName_Off, static_cast<int>(::QIcon::Off)},
    {sipName_AddressBookNew, static_cast<int>(::QIcon::ThemeIcon::AddressBookNew)},
    {sipName_ApplicationExit, static_cast<int>(::QIcon::ThemeIcon::ApplicationExit)},
    {sipName_AppointmentNew, static_cast<int>(::QIcon::ThemeIcon::AppointmentNew)},
    {sipName_CallStart, static_cast<int>(::QIcon::ThemeIcon::CallStart)},
    {sipName_CallStop, static_cast<int>(::QIcon::ThemeIcon::CallStop)},
    {sipName_ContactNew, static_cast<int>(::QIcon::ThemeIcon::ContactNew)},
    {sipName_DocumentNew, static_cast<int>(::QIcon::ThemeIcon::DocumentNew)},
    {sipName_DocumentOpen, static_cast<int>(::QIcon::ThemeIcon::DocumentOpen)},
    {sipName_DocumentOpenRecent, static_cast<int>(::QIcon::ThemeIcon::DocumentOpenRecent)},
    {sipName_DocumentPageSetup, static_cast<int>(::QIcon::ThemeIcon::DocumentPageSetup)},
    {sipName_DocumentPrint, static_cast<int>(::QIcon::ThemeIcon::DocumentPrint)},
    {sipName_DocumentPrintPreview, static_cast<int>(::QIcon::ThemeIcon::DocumentPrintPreview)},
    {sipName_DocumentProperties, static_cast<int>(::QIcon::ThemeIcon::DocumentProperties)},
    {sipName_DocumentRevert, static_cast<int>(::QIcon::ThemeIcon::DocumentRevert)},
    {sipName_DocumentSave, static_cast<int>(::QIcon::ThemeIcon::DocumentSave)},
    {sipName_DocumentSaveAs, static_cast<int>(::QIcon::ThemeIcon::DocumentSaveAs)},
    {sipName_DocumentSend, static_cast<int>(::QIcon::ThemeIcon::DocumentSend)},
    {sipName_EditClear, static_cast<int>(::QIcon::ThemeIcon::EditClear)},
    {sipName_EditCopy, static_cast<int>(::QIcon::ThemeIcon::EditCopy)},
    {sipName_EditCut, static_cast<int>(::QIcon::ThemeIcon::EditCut)},
    {sipName_EditDelete, static_cast<int>(::QIcon::ThemeIcon::EditDelete)},
    {sipName_EditFind, static_cast<int>(::QIcon::ThemeIcon::EditFind)},
    {sipName_EditPaste, static_cast<int>(::QIcon::ThemeIcon::EditPaste)},
    {sipName_EditRedo, static_cast<int>(::QIcon::ThemeIcon::EditRedo)},
    {sipName_EditSelectAll, static_cast<int>(::QIcon::ThemeIcon::EditSelectAll)},
    {sipName_EditUndo, static_cast<int>(::QIcon::ThemeIcon::EditUndo)},
    {sipName_FolderNew, static_cast<int>(::QIcon::ThemeIcon::FolderNew)},
    {sipName_FormatIndentLess, static_cast<int>(::QIcon::ThemeIcon::FormatIndentLess)},
    {sipName_FormatIndentMore, static_cast<int>(::QIcon::ThemeIcon::FormatIndentMore)},
    {sipName_FormatJustifyCenter, static_cast<int>(::QIcon::ThemeIcon::FormatJustifyCenter)},
    {sipName_FormatJustifyFill, static_cast<int>(::QIcon::ThemeIcon::FormatJustifyFill)},
    {sipName_FormatJustifyLeft, static_cast<int>(::QIcon::ThemeIcon::FormatJustifyLeft)},
    {sipName_FormatJustifyRight, static_cast<int>(::QIcon::ThemeIcon::FormatJustifyRight)},
    {sipName_FormatTextDirectionLtr, static_cast<int>(::QIcon::ThemeIcon::FormatTextDirectionLtr)},
    {sipName_FormatTextDirectionRtl, static_cast<int>(::QIcon::ThemeIcon::FormatTextDirectionRtl)},
    {sipName_FormatTextBold, static_cast<int>(::QIcon::ThemeIcon::FormatTextBold)},
    {sipName_FormatTextItalic, static_cast<int>(::QIcon::ThemeIcon::FormatTextItalic)},
    {sipName_FormatTextUnderline, static_cast<int>(::QIcon::ThemeIcon::FormatTextUnderline)},
    {sipName_FormatTextStrikethrough, static_cast<int>(::QIcon::ThemeIcon::FormatTextStrikethrough)},
    {sipName_GoDown, static_cast<int>(::QIcon::ThemeIcon::GoDown)},
    {sipName_GoHome, static_cast<int>(::QIcon::ThemeIcon::GoHome)},
    {sipName_GoNext, static_cast<int>(::QIcon::ThemeIcon::GoNext)},
    {sipName_GoPrevious, static_cast<int>(::QIcon::ThemeIcon::GoPrevious)},
    {sipName_GoUp, static_cast<int>(::QIcon::ThemeIcon::GoUp)},
    {sipName_HelpAbout, static_cast<int>(::QIcon::ThemeIcon::HelpAbout)},
    {sipName_HelpFaq, static_cast<int>(::QIcon::ThemeIcon::HelpFaq)},
    {sipName_InsertImage, static_cast<int>(::QIcon::ThemeIcon::InsertImage)},
    {sipName_InsertLink, static_cast<int>(::QIcon::ThemeIcon::InsertLink)},
    {sipName_InsertText, static_cast<int>(::QIcon::ThemeIcon::InsertText)},
    {sipName_ListAdd, static_cast<int>(::QIcon::ThemeIcon::ListAdd)},
    {sipName_ListRemove, static_cast<int>(::QIcon::ThemeIcon::ListRemove)},
    {sipName_MailForward, static_cast<int>(::QIcon::ThemeIcon::MailForward)},
    {sipName_MailMarkImportant, static_cast<int>(::QIcon::ThemeIcon::MailMarkImportant)},
    {sipName_MailMarkRead, static_cast<int>(::QIcon::ThemeIcon::MailMarkRead)},
    {sipName_MailMarkUnread, static_cast<int>(::QIcon::ThemeIcon::MailMarkUnread)},
    {sipName_MailMessageNew, static_cast<int>(::QIcon::ThemeIcon::MailMessageNew)},
    {sipName_MailReplyAll, static_cast<int>(::QIcon::ThemeIcon::MailReplyAll)},
    {sipName_MailReplySender, static_cast<int>(::QIcon::ThemeIcon::MailReplySender)},
    {sipName_MailSend, static_cast<int>(::QIcon::ThemeIcon::MailSend)},
    {sipName_MediaEject, static_cast<int>(::QIcon::ThemeIcon::MediaEject)},
    {sipName_MediaPlaybackPause, static_cast<int>(::QIcon::ThemeIcon::MediaPlaybackPause)},
    {sipName_MediaPlaybackStart, static_cast<int>(::QIcon::ThemeIcon::MediaPlaybackStart)},
    {sipName_MediaPlaybackStop, static_cast<int>(::QIcon::ThemeIcon::MediaPlaybackStop)},
    {sipName_MediaRecord, static_cast<int>(::QIcon::ThemeIcon::MediaRecord)},
    {sipName_MediaSeekBackward, static_cast<int>(::QIcon::ThemeIcon::MediaSeekBackward)},
    {sipName_MediaSeekForward, static_cast<int>(::QIcon::ThemeIcon::MediaSeekForward)},
    {sipName_MediaSkipBackward, static_cast<int>(::QIcon::ThemeIcon::MediaSkipBackward)},
    {sipName_MediaSkipForward, static_cast<int>(::QIcon::ThemeIcon::MediaSkipForward)},
    {sipName_ObjectRotateLeft, static_cast<int>(::QIcon::ThemeIcon::ObjectRotateLeft)},
    {sipName_ObjectRotateRight, static_cast<int>(::QIcon::ThemeIcon::ObjectRotateRight)},
    {sipName_ProcessStop, static_cast<int>(::QIcon::ThemeIcon::ProcessStop)},
    {sipName_SystemLockScreen, static_cast<int>(::QIcon::ThemeIcon::SystemLockScreen)},
    {sipName_SystemLogOut, static_cast<int>(::QIcon::ThemeIcon::SystemLogOut)},
    {sipName_SystemSearch, static_cast<int>(::QIcon::ThemeIcon::SystemSearch)},
    {sipName_SystemReboot, static_cast<int>(::QIcon::ThemeIcon::SystemReboot)},
    {sipName_SystemShutdown, static_cast<int>(::QIcon::ThemeIcon::SystemShutdown)},
    {sipName_ToolsCheckSpelling, static_cast<int>(::QIcon::ThemeIcon::ToolsCheckSpelling)},
    {sipName_ViewFullscreen, static_cast<int>(::QIcon::ThemeIcon::ViewFullscreen)},
    {sipName_ViewRefresh, static_cast<int>(::QIcon::ThemeIcon::ViewRefresh)},
    {sipName_ViewRestore, static_cast<int>(::QIcon::ThemeIcon::ViewRestore)},
    {sipName_WindowClose, static_cast<int>(::QIcon::ThemeIcon::WindowClose)},
    {sipName_WindowNew, static_cast<int>(::QIcon::ThemeIcon::WindowNew)},
    {sipName_ZoomFitBest, static_cast<int>(::QIcon::ThemeIcon::ZoomFitBest)},
    {sipName_ZoomIn, static_cast<int>(::QIcon::ThemeIcon::ZoomIn)},
    {sipName_ZoomOut, static_cast<int>(::QIcon::ThemeIcon::ZoomOut)},
    {sipName_AudioCard, static_cast<int>(::QIcon::ThemeIcon::AudioCard)},
    {sipName_AudioInputMicrophone, static_cast<int>(::QIcon::ThemeIcon::AudioInputMicrophone)},
    {sipName_Battery, static_cast<int>(::QIcon::ThemeIcon::Battery)},
    {sipName_CameraPhoto, static_cast<int>(::QIcon::ThemeIcon::CameraPhoto)},
    {sipName_CameraVideo, static_cast<int>(::QIcon::ThemeIcon::CameraVideo)},
    {sipName_CameraWeb, static_cast<int>(::QIcon::ThemeIcon::CameraWeb)},
    {sipName_Computer, static_cast<int>(::QIcon::ThemeIcon::Computer)},
    {sipName_DriveHarddisk, static_cast<int>(::QIcon::ThemeIcon::DriveHarddisk)},
    {sipName_DriveOptical, static_cast<int>(::QIcon::ThemeIcon::DriveOptical)},
    {sipName_InputGaming, static_cast<int>(::QIcon::ThemeIcon::InputGaming)},
    {sipName_InputKeyboard, static_cast<int>(::QIcon::ThemeIcon::InputKeyboard)},
    {sipName_InputMouse, static_cast<int>(::QIcon::ThemeIcon::InputMouse)},
    {sipName_InputTablet, static_cast<int>(::QIcon::ThemeIcon::InputTablet)},
    {sipName_MediaFlash, static_cast<int>(::QIcon::ThemeIcon::MediaFlash)},
    {sipName_MediaOptical, static_cast<int>(::QIcon::ThemeIcon::MediaOptical)},
    {sipName_MediaTape, static_cast<int>(::QIcon::ThemeIcon::MediaTape)},
    {sipName_MultimediaPlayer, static_cast<int>(::QIcon::ThemeIcon::MultimediaPlayer)},
    {sipName_NetworkWired, static_cast<int>(::QIcon::ThemeIcon::NetworkWired)},
    {sipName_NetworkWireless, static_cast<int>(::QIcon::ThemeIcon::NetworkWireless)},
    {sipName_Phone, static_cast<int>(::QIcon::ThemeIcon::Phone)},
    {sipName_Printer, static_cast<int>(::QIcon::ThemeIcon::Printer)},
    {sipName_Scanner, static_cast<int>(::QIcon::ThemeIcon::Scanner)},
    {sipName_VideoDisplay, static_cast<int>(::QIcon::ThemeIcon::VideoDisplay)},
    {sipName_AppointmentMissed, static_cast<int>(::QIcon::ThemeIcon::AppointmentMissed)},
    {sipName_AppointmentSoon, static_cast<int>(::QIcon::ThemeIcon::AppointmentSoon)},
    {sipName_AudioVolumeHigh, static_cast<int>(::QIcon::ThemeIcon::AudioVolumeHigh)},
    {sipName_AudioVolumeLow, static_cast<int>(::QIcon::ThemeIcon::AudioVolumeLow)},
    {sipName_AudioVolumeMedium, static_cast<int>(::QIcon::ThemeIcon::AudioVolumeMedium)},
    {sipName_AudioVolumeMuted, static_cast<int>(::QIcon::ThemeIcon::AudioVolumeMuted)},
    {sipName_BatteryCaution, static_cast<int>(::QIcon::ThemeIcon::BatteryCaution)},
    {sipName_BatteryLow, static_cast<int>(::QIcon::ThemeIcon::BatteryLow)},
    {sipName_DialogError, static_cast<int>(::QIcon::ThemeIcon::DialogError)},
    {sipName_DialogInformation, static_cast<int>(::QIcon::ThemeIcon::DialogInformation)},
    {sipName_DialogPassword, static_cast<int>(::QIcon::ThemeIcon::DialogPassword)},
    {sipName_DialogQuestion, static_cast<int>(::QIcon::ThemeIcon::DialogQuestion)},
    {sipName_DialogWarning, static_cast<int>(::QIcon::ThemeIcon::DialogWarning)},
    {sipName_FolderDragAccept, static_cast<int>(::QIcon::ThemeIcon::FolderDragAccept)},
    {sipName_FolderOpen, static_cast<int>(::QIcon::ThemeIcon::FolderOpen)},
    {sipName_FolderVisiting, static_cast<int>(::QIcon::ThemeIcon::FolderVisiting)},
    {sipName_ImageLoading, static_cast<int>(::QIcon::ThemeIcon::ImageLoading)},
    {sipName_ImageMissing, static_cast<int>(::QIcon::ThemeIcon::ImageMissing)},
    {sipName_MailAttachment, static_cast<int>(::QIcon::ThemeIcon::MailAttachment)},
    {sipName_MailUnread, static_cast<int>(::QIcon::ThemeIcon::MailUnread)},
    {sipName_MailRead, static_cast<int>(::QIcon::ThemeIcon::MailRead)},
    {sipName_MailReplied, static_cast<int>(::QIcon::ThemeIcon::MailReplied)},
    {sipName_MediaPlaylistRepeat, static_cast<int>(::QIcon::ThemeIcon::MediaPlaylistRepeat)},
    {sipName_MediaPlaylistShuffle, static_cast<int>(::QIcon::ThemeIcon::MediaPlaylistShuffle)},
    {sipName_NetworkOffline, static_cast<int>(::QIcon::ThemeIcon::NetworkOffline)},
    {sipName_PrinterPrinting, static_cast<int>(::QIcon::ThemeIcon::PrinterPrinting)},
    {sipName_SecurityHigh, static_cast<int>(::QIcon::ThemeIcon::SecurityHigh)},
    {sipName_SecurityLow, static_cast<int>(::QIcon::ThemeIcon::SecurityLow)},
    {sipName_SoftwareUpdateAvailable, static_cast<int>(::QIcon::ThemeIcon::SoftwareUpdateAvailable)},
    {sipName_SoftwareUpdateUrgent, static_cast<int>(::QIcon::ThemeIcon::SoftwareUpdateUrgent)},
    {sipName_SyncError, static_cast<int>(::QIcon::ThemeIcon::SyncError)},
    {sipName_SyncSynchronizing, static_cast<int>(::QIcon::ThemeIcon::SyncSynchronizing)},
    {sipName_UserAvailable, static_cast<int>(::QIcon::ThemeIcon::UserAvailable)},
    {sipName_UserOffline, static_cast<int>(::QIcon::ThemeIcon::UserOffline)},
    {sipName_WeatherClear, static_cast<int>(::QIcon::ThemeIcon::WeatherClear)},
    {sipName_WeatherClearNight, static_cast<int>(::QIcon::ThemeIcon::WeatherClearNight)},
    {sipName_WeatherFewClouds, static_cast<int>(::QIcon::ThemeIcon::WeatherFewClouds)},
    {sipName_WeatherFewCloudsNight, static_cast<int>(::QIcon::ThemeIcon::WeatherFewCloudsNight)},
    {sipName_WeatherFog, static_cast<int>(::QIcon::ThemeIcon::WeatherFog)},
    {sipName_WeatherShowers, static_cast<int>(::QIcon::ThemeIcon::WeatherShowers)},
    {sipName_WeatherSnow, static_cast<int>(::QIcon::ThemeIcon::WeatherSnow)},
    {sipName_WeatherStorm, static_cast<int>(::QIcon::ThemeIcon::WeatherStorm)},
    {0, 0}
};

PyDoc_STRVAR(doc_QIcon, "\1QIcon()\n"
"QIcon(pixmap: QPixmap)\n"
"QIcon(other: QIcon)\n"
"QIcon(fileName: str|None)\n"
"QIcon(engine: QIconEngine|None)\n"
"QIcon(variant: Any)");


sipClassTypeDef sipTypeDef_QtGui_QIcon = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QIcon,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QIcon,
        {0, 0, 1},
        23, methods_QIcon,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QIcon, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QIcon,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QIcon,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QIcon,
    assign_QIcon,
    array_QIcon,
    copy_QIcon,
    release_QIcon,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QIcon,
    sizeof (::QIcon),
};
