/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qrestaccessmanager.sip"
#include <qrestaccessmanager.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qnetworkaccessmanager.sip"
#include <qnetworkaccessmanager.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qnetworkreply.sip"
#include <qnetworkreply.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qhttpmultipart.sip"
#include <qhttpmultipart.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qjsondocument.sip"
#include <qjsondocument.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 27 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQRestAccessManager.cpp"


class sipQRestAccessManager : public ::QRestAccessManager
{
public:
    sipQRestAccessManager(::QNetworkAccessManager*, ::QObject*);
    virtual ~sipQRestAccessManager();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQRestAccessManager(const sipQRestAccessManager &);
    sipQRestAccessManager &operator = (const sipQRestAccessManager &);

    char sipPyMethods[7];
};

sipQRestAccessManager::sipQRestAccessManager(::QNetworkAccessManager*a0, ::QObject*a1): ::QRestAccessManager(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQRestAccessManager::~sipQRestAccessManager()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQRestAccessManager::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtNetwork_qt_metaobject(sipPySelf, sipType_QRestAccessManager);

    return ::QRestAccessManager::metaObject();
}

int sipQRestAccessManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QRestAccessManager::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtNetwork_qt_metacall(sipPySelf, sipType_QRestAccessManager, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQRestAccessManager::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtNetwork_qt_metacast(sipPySelf, sipType_QRestAccessManager, _clname, &sipCpp) ? sipCpp : ::QRestAccessManager::qt_metacast(_clname));
}

bool sipQRestAccessManager::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QRestAccessManager::event(a0);

    extern bool sipVH_QtNetwork_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtNetwork_5(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRestAccessManager::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QRestAccessManager::eventFilter(a0, a1);

    extern bool sipVH_QtNetwork_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtNetwork_4(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQRestAccessManager::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QRestAccessManager::timerEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtNetwork_3(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRestAccessManager::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QRestAccessManager::childEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtNetwork_2(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRestAccessManager::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QRestAccessManager::customEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtNetwork_1(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRestAccessManager::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QRestAccessManager::connectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRestAccessManager::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QRestAccessManager::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QRestAccessManager_networkAccessManager, "networkAccessManager(self) -> QNetworkAccessManager|None");

extern "C" {static PyObject *meth_QRestAccessManager_networkAccessManager(PyObject *, PyObject *);}
static PyObject *meth_QRestAccessManager_networkAccessManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRestAccessManager, &sipCpp))
        {
            ::QNetworkAccessManager*sipRes;

            sipRes = sipCpp->networkAccessManager();

            return sipConvertFromType(sipRes, sipType_QNetworkAccessManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRestAccessManager, sipName_networkAccessManager, doc_QRestAccessManager_networkAccessManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRestAccessManager_deleteResource, "deleteResource(self, request: QNetworkRequest) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QRestAccessManager_deleteResource(PyObject *, PyObject *);}
static PyObject *meth_QRestAccessManager_deleteResource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNetworkRequest* a0;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->deleteResource(*a0);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRestAccessManager, sipName_deleteResource, doc_QRestAccessManager_deleteResource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRestAccessManager_head, "head(self, request: QNetworkRequest) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QRestAccessManager_head(PyObject *, PyObject *);}
static PyObject *meth_QRestAccessManager_head(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNetworkRequest* a0;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->head(*a0);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRestAccessManager, sipName_head, doc_QRestAccessManager_head);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRestAccessManager_get, "get(self, request: QNetworkRequest) -> QNetworkReply|None\n"
"get(self, request: QNetworkRequest, data: QByteArray|bytes|bytearray|memoryview) -> QNetworkReply|None\n"
"get(self, request: QNetworkRequest, data: QJsonDocument) -> QNetworkReply|None\n"
"get(self, request: QNetworkRequest, data: QIODevice|None) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QRestAccessManager_get(PyObject *, PyObject *);}
static PyObject *meth_QRestAccessManager_get(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNetworkRequest* a0;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->get(*a0);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QByteArray, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->get(*a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        const ::QJsonDocument* a1;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QJsonDocument, &a1))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->get(*a0, *a1);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        ::QIODevice* a1;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J8", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QIODevice, &a1))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->get(*a0, a1);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRestAccessManager, sipName_get, doc_QRestAccessManager_get);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRestAccessManager_post, "post(self, request: QNetworkRequest, data: QJsonDocument) -> QNetworkReply|None\n"
"post(self, request: QNetworkRequest, data: dict[str|None, Any]) -> QNetworkReply|None\n"
"post(self, request: QNetworkRequest, data: QByteArray|bytes|bytearray|memoryview) -> QNetworkReply|None\n"
"post(self, request: QNetworkRequest, data: QHttpMultiPart|None) -> QNetworkReply|None\n"
"post(self, request: QNetworkRequest, data: QIODevice|None) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QRestAccessManager_post(PyObject *, PyObject *);}
static PyObject *meth_QRestAccessManager_post(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNetworkRequest* a0;
        const ::QJsonDocument* a1;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QJsonDocument, &a1))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->post(*a0, *a1);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        const ::QVariantMap* a1;
        int a1State = 0;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QMap_0100QString_0100QVariant, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->post(*a0, *a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a1), sipType_QMap_0100QString_0100QVariant, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QByteArray, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->post(*a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        ::QHttpMultiPart* a1;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J8", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QHttpMultiPart, &a1))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->post(*a0, a1);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        ::QIODevice* a1;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J8", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QIODevice, &a1))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->post(*a0, a1);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRestAccessManager, sipName_post, doc_QRestAccessManager_post);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRestAccessManager_put, "put(self, request: QNetworkRequest, data: QJsonDocument) -> QNetworkReply|None\n"
"put(self, request: QNetworkRequest, data: dict[str|None, Any]) -> QNetworkReply|None\n"
"put(self, request: QNetworkRequest, data: QByteArray|bytes|bytearray|memoryview) -> QNetworkReply|None\n"
"put(self, request: QNetworkRequest, data: QHttpMultiPart|None) -> QNetworkReply|None\n"
"put(self, request: QNetworkRequest, data: QIODevice|None) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QRestAccessManager_put(PyObject *, PyObject *);}
static PyObject *meth_QRestAccessManager_put(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNetworkRequest* a0;
        const ::QJsonDocument* a1;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QJsonDocument, &a1))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->put(*a0, *a1);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        const ::QVariantMap* a1;
        int a1State = 0;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QMap_0100QString_0100QVariant, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->put(*a0, *a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a1), sipType_QMap_0100QString_0100QVariant, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QByteArray, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->put(*a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        ::QHttpMultiPart* a1;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J8", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QHttpMultiPart, &a1))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->put(*a0, a1);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        ::QIODevice* a1;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J8", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QIODevice, &a1))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->put(*a0, a1);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRestAccessManager, sipName_put, doc_QRestAccessManager_put);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRestAccessManager_patch, "patch(self, request: QNetworkRequest, data: QJsonDocument) -> QNetworkReply|None\n"
"patch(self, request: QNetworkRequest, data: dict[str|None, Any]) -> QNetworkReply|None\n"
"patch(self, request: QNetworkRequest, data: QByteArray|bytes|bytearray|memoryview) -> QNetworkReply|None\n"
"patch(self, request: QNetworkRequest, data: QIODevice|None) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QRestAccessManager_patch(PyObject *, PyObject *);}
static PyObject *meth_QRestAccessManager_patch(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNetworkRequest* a0;
        const ::QJsonDocument* a1;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QJsonDocument, &a1))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->patch(*a0, *a1);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        const ::QVariantMap* a1;
        int a1State = 0;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QMap_0100QString_0100QVariant, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->patch(*a0, *a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a1), sipType_QMap_0100QString_0100QVariant, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QByteArray, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->patch(*a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        ::QIODevice* a1;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J8", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QIODevice, &a1))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->patch(*a0, a1);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRestAccessManager, sipName_patch, doc_QRestAccessManager_patch);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRestAccessManager_sendCustomRequest, "sendCustomRequest(self, request: QNetworkRequest, method: QByteArray|bytes|bytearray|memoryview, data: QByteArray|bytes|bytearray|memoryview) -> QNetworkReply|None\n"
"sendCustomRequest(self, request: QNetworkRequest, method: QByteArray|bytes|bytearray|memoryview, data: QIODevice|None) -> QNetworkReply|None\n"
"sendCustomRequest(self, request: QNetworkRequest, method: QByteArray|bytes|bytearray|memoryview, data: QHttpMultiPart|None) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QRestAccessManager_sendCustomRequest(PyObject *, PyObject *);}
static PyObject *meth_QRestAccessManager_sendCustomRequest(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNetworkRequest* a0;
        const ::QByteArray* a1;
        int a1State = 0;
        const ::QByteArray* a2;
        int a2State = 0;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1J1", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QByteArray, &a1, &a1State, sipType_QByteArray, &a2, &a2State))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->sendCustomRequest(*a0, *a1, *a2);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);
            sipReleaseType(const_cast< ::QByteArray *>(a2), sipType_QByteArray, a2State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QIODevice* a2;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1J8", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QByteArray, &a1, &a1State, sipType_QIODevice, &a2))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->sendCustomRequest(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    {
        const ::QNetworkRequest* a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QHttpMultiPart* a2;
        ::QRestAccessManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1J8", &sipSelf, sipType_QRestAccessManager, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QByteArray, &a1, &a1State, sipType_QHttpMultiPart, &a2))
        {
            ::QNetworkReply*sipRes;

            sipRes = sipCpp->sendCustomRequest(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRestAccessManager, sipName_sendCustomRequest, doc_QRestAccessManager_sendCustomRequest);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRestAccessManager(void *, const sipTypeDef *);}
static void *cast_QRestAccessManager(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRestAccessManager *sipCpp = reinterpret_cast< ::QRestAccessManager *>(sipCppV);

    if (targetType == sipType_QRestAccessManager)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRestAccessManager(void *, int);}
static void release_QRestAccessManager(void *sipCppV, int)
{
    ::QRestAccessManager *sipCpp = reinterpret_cast< ::QRestAccessManager *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QRestAccessManager(sipSimpleWrapper *);}
static void dealloc_QRestAccessManager(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQRestAccessManager *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRestAccessManager(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QRestAccessManager(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QRestAccessManager(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQRestAccessManager *sipCpp = SIP_NULLPTR;

    {
        ::QNetworkAccessManager* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QNetworkAccessManager, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQRestAccessManager(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRestAccessManager[] = {{19, 0, 1}};


static PyMethodDef methods_QRestAccessManager[] = {
    {sipName_deleteResource, meth_QRestAccessManager_deleteResource, METH_VARARGS, doc_QRestAccessManager_deleteResource},
    {sipName_get, meth_QRestAccessManager_get, METH_VARARGS, doc_QRestAccessManager_get},
    {sipName_head, meth_QRestAccessManager_head, METH_VARARGS, doc_QRestAccessManager_head},
    {sipName_networkAccessManager, meth_QRestAccessManager_networkAccessManager, METH_VARARGS, doc_QRestAccessManager_networkAccessManager},
    {sipName_patch, meth_QRestAccessManager_patch, METH_VARARGS, doc_QRestAccessManager_patch},
    {sipName_post, meth_QRestAccessManager_post, METH_VARARGS, doc_QRestAccessManager_post},
    {sipName_put, meth_QRestAccessManager_put, METH_VARARGS, doc_QRestAccessManager_put},
    {sipName_sendCustomRequest, meth_QRestAccessManager_sendCustomRequest, METH_VARARGS, doc_QRestAccessManager_sendCustomRequest}
};

PyDoc_STRVAR(doc_QRestAccessManager, "\1QRestAccessManager(manager: QNetworkAccessManager|None, parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QRestAccessManager = {
    &::QRestAccessManager::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QRestAccessManager = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRestAccessManager,
        SIP_NULLPTR,
        &plugin_QRestAccessManager,
    },
    {
        sipNameNr_QRestAccessManager,
        {0, 0, 1},
        8, methods_QRestAccessManager,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QRestAccessManager,
    -1,
    -1,
    supers_QRestAccessManager,
    SIP_NULLPTR,
    init_type_QRestAccessManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRestAccessManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QRestAccessManager,
    cast_QRestAccessManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QRestAccessManager),
};
