/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiobufferinput.sip"
#include <qaudiobufferinput.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudioformat.sip"
#include <qaudioformat.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiobuffer.sip"
#include <qaudiobuffer.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediacapturesession.sip"
#include <qmediacapturesession.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioBufferInput.cpp"


class sipQAudioBufferInput : public ::QAudioBufferInput
{
public:
    sipQAudioBufferInput(::QObject*);
    sipQAudioBufferInput(const ::QAudioFormat&, ::QObject*);
    virtual ~sipQAudioBufferInput();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAudioBufferInput(const sipQAudioBufferInput &);
    sipQAudioBufferInput &operator = (const sipQAudioBufferInput &);

    char sipPyMethods[7];
};

sipQAudioBufferInput::sipQAudioBufferInput(::QObject*a0): ::QAudioBufferInput(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioBufferInput::sipQAudioBufferInput(const ::QAudioFormat& a0, ::QObject*a1): ::QAudioBufferInput(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioBufferInput::~sipQAudioBufferInput()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAudioBufferInput::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QAudioBufferInput);

    return ::QAudioBufferInput::metaObject();
}

int sipQAudioBufferInput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAudioBufferInput::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QAudioBufferInput, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAudioBufferInput::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QAudioBufferInput, _clname, &sipCpp) ? sipCpp : ::QAudioBufferInput::qt_metacast(_clname));
}

bool sipQAudioBufferInput::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAudioBufferInput::event(a0);

    extern bool sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAudioBufferInput::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAudioBufferInput::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_4(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAudioBufferInput::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAudioBufferInput::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_3(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioBufferInput::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAudioBufferInput::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioBufferInput::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAudioBufferInput::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_1(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioBufferInput::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAudioBufferInput::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioBufferInput::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAudioBufferInput::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAudioBufferInput_captureSession, "captureSession(self) -> QMediaCaptureSession|None");

extern "C" {static PyObject *meth_QAudioBufferInput_captureSession(PyObject *, PyObject *);}
static PyObject *meth_QAudioBufferInput_captureSession(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioBufferInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioBufferInput, &sipCpp))
        {
            ::QMediaCaptureSession*sipRes;

            sipRes = sipCpp->captureSession();

            return sipConvertFromType(sipRes, sipType_QMediaCaptureSession, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioBufferInput, sipName_captureSession, doc_QAudioBufferInput_captureSession);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioBufferInput_format, "format(self) -> QAudioFormat");

extern "C" {static PyObject *meth_QAudioBufferInput_format(PyObject *, PyObject *);}
static PyObject *meth_QAudioBufferInput_format(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioBufferInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioBufferInput, &sipCpp))
        {
            ::QAudioFormat*sipRes;

            sipRes = new ::QAudioFormat(sipCpp->format());

            return sipConvertFromNewType(sipRes, sipType_QAudioFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioBufferInput, sipName_format, doc_QAudioBufferInput_format);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioBufferInput_sendAudioBuffer, "sendAudioBuffer(self, audioBuffer: QAudioBuffer) -> bool");

extern "C" {static PyObject *meth_QAudioBufferInput_sendAudioBuffer(PyObject *, PyObject *);}
static PyObject *meth_QAudioBufferInput_sendAudioBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioBuffer* a0;
        ::QAudioBufferInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioBufferInput, &sipCpp, sipType_QAudioBuffer, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->sendAudioBuffer(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioBufferInput, sipName_sendAudioBuffer, doc_QAudioBufferInput_sendAudioBuffer);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAudioBufferInput(void *, const sipTypeDef *);}
static void *cast_QAudioBufferInput(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAudioBufferInput *sipCpp = reinterpret_cast< ::QAudioBufferInput *>(sipCppV);

    if (targetType == sipType_QAudioBufferInput)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAudioBufferInput(void *, int);}
static void release_QAudioBufferInput(void *sipCppV, int)
{
    ::QAudioBufferInput *sipCpp = reinterpret_cast< ::QAudioBufferInput *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QAudioBufferInput(Py_ssize_t);}
static void *array_QAudioBufferInput(Py_ssize_t sipNrElem)
{
    return new ::QAudioBufferInput[sipNrElem];
}


extern "C" {static void array_delete_QAudioBufferInput(void *);}
static void array_delete_QAudioBufferInput(void *sipCpp)
{
    delete[] reinterpret_cast< ::QAudioBufferInput *>(sipCpp);
}


extern "C" {static void dealloc_QAudioBufferInput(sipSimpleWrapper *);}
static void dealloc_QAudioBufferInput(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAudioBufferInput *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAudioBufferInput(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAudioBufferInput(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAudioBufferInput(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAudioBufferInput *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQAudioBufferInput(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QAudioFormat* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|JH", sipType_QAudioFormat, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQAudioBufferInput(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAudioBufferInput[] = {{7, 0, 1}};


static PyMethodDef methods_QAudioBufferInput[] = {
    {sipName_captureSession, meth_QAudioBufferInput_captureSession, METH_VARARGS, doc_QAudioBufferInput_captureSession},
    {sipName_format, meth_QAudioBufferInput_format, METH_VARARGS, doc_QAudioBufferInput_format},
    {sipName_sendAudioBuffer, meth_QAudioBufferInput_sendAudioBuffer, METH_VARARGS, doc_QAudioBufferInput_sendAudioBuffer}
};

PyDoc_STRVAR(doc_QAudioBufferInput, "\1QAudioBufferInput(parent: QObject|None = None)\n"
"QAudioBufferInput(format: QAudioFormat, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QAudioBufferInput[] = {
    {"readyToSendAudioBuffer()", "\1readyToSendAudioBuffer(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QAudioBufferInput = {
    &::QAudioBufferInput::staticMetaObject,
    signals_QAudioBufferInput,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QAudioBufferInput = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAudioBufferInput,
        SIP_NULLPTR,
        &plugin_QAudioBufferInput,
    },
    {
        sipNameNr_QAudioBufferInput,
        {0, 0, 1},
        3, methods_QAudioBufferInput,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAudioBufferInput,
    -1,
    -1,
    supers_QAudioBufferInput,
    SIP_NULLPTR,
    init_type_QAudioBufferInput,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAudioBufferInput,
    SIP_NULLPTR,
    array_QAudioBufferInput,
    SIP_NULLPTR,
    release_QAudioBufferInput,
    cast_QAudioBufferInput,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAudioBufferInput,
    sizeof (::QAudioBufferInput),
};
