/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQRadialGradient.cpp"

#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQRadialGradient.cpp"
#line 123 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQRadialGradient.cpp"
#line 433 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQRadialGradient.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQRadialGradient.cpp"


PyDoc_STRVAR(doc_QRadialGradient_center, "center(self) -> QPointF");

extern "C" {static PyObject *meth_QRadialGradient_center(PyObject *, PyObject *);}
static PyObject *meth_QRadialGradient_center(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadialGradient, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->center());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadialGradient, sipName_center, doc_QRadialGradient_center);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadialGradient_focalPoint, "focalPoint(self) -> QPointF");

extern "C" {static PyObject *meth_QRadialGradient_focalPoint(PyObject *, PyObject *);}
static PyObject *meth_QRadialGradient_focalPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadialGradient, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->focalPoint());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadialGradient, sipName_focalPoint, doc_QRadialGradient_focalPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadialGradient_radius, "radius(self) -> float");

extern "C" {static PyObject *meth_QRadialGradient_radius(PyObject *, PyObject *);}
static PyObject *meth_QRadialGradient_radius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadialGradient, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->radius();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadialGradient, sipName_radius, doc_QRadialGradient_radius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadialGradient_setCenter, "setCenter(self, center: QPointF)\n"
"setCenter(self, x: float, y: float)");

extern "C" {static PyObject *meth_QRadialGradient_setCenter(PyObject *, PyObject *);}
static PyObject *meth_QRadialGradient_setCenter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRadialGradient, &sipCpp, sipType_QPointF, &a0))
        {
            sipCpp->setCenter(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QRadialGradient, &sipCpp, &a0, &a1))
        {
            sipCpp->setCenter(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadialGradient, sipName_setCenter, doc_QRadialGradient_setCenter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadialGradient_setFocalPoint, "setFocalPoint(self, focalPoint: QPointF)\n"
"setFocalPoint(self, x: float, y: float)");

extern "C" {static PyObject *meth_QRadialGradient_setFocalPoint(PyObject *, PyObject *);}
static PyObject *meth_QRadialGradient_setFocalPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRadialGradient, &sipCpp, sipType_QPointF, &a0))
        {
            sipCpp->setFocalPoint(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QRadialGradient, &sipCpp, &a0, &a1))
        {
            sipCpp->setFocalPoint(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadialGradient, sipName_setFocalPoint, doc_QRadialGradient_setFocalPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadialGradient_setRadius, "setRadius(self, radius: float)");

extern "C" {static PyObject *meth_QRadialGradient_setRadius(PyObject *, PyObject *);}
static PyObject *meth_QRadialGradient_setRadius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QRadialGradient, &sipCpp, &a0))
        {
            sipCpp->setRadius(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadialGradient, sipName_setRadius, doc_QRadialGradient_setRadius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadialGradient_centerRadius, "centerRadius(self) -> float");

extern "C" {static PyObject *meth_QRadialGradient_centerRadius(PyObject *, PyObject *);}
static PyObject *meth_QRadialGradient_centerRadius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadialGradient, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->centerRadius();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadialGradient, sipName_centerRadius, doc_QRadialGradient_centerRadius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadialGradient_setCenterRadius, "setCenterRadius(self, radius: float)");

extern "C" {static PyObject *meth_QRadialGradient_setCenterRadius(PyObject *, PyObject *);}
static PyObject *meth_QRadialGradient_setCenterRadius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QRadialGradient, &sipCpp, &a0))
        {
            sipCpp->setCenterRadius(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadialGradient, sipName_setCenterRadius, doc_QRadialGradient_setCenterRadius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadialGradient_focalRadius, "focalRadius(self) -> float");

extern "C" {static PyObject *meth_QRadialGradient_focalRadius(PyObject *, PyObject *);}
static PyObject *meth_QRadialGradient_focalRadius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadialGradient, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->focalRadius();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadialGradient, sipName_focalRadius, doc_QRadialGradient_focalRadius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadialGradient_setFocalRadius, "setFocalRadius(self, radius: float)");

extern "C" {static PyObject *meth_QRadialGradient_setFocalRadius(PyObject *, PyObject *);}
static PyObject *meth_QRadialGradient_setFocalRadius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QRadialGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QRadialGradient, &sipCpp, &a0))
        {
            sipCpp->setFocalRadius(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadialGradient, sipName_setFocalRadius, doc_QRadialGradient_setFocalRadius);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRadialGradient(void *, const sipTypeDef *);}
static void *cast_QRadialGradient(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRadialGradient *sipCpp = reinterpret_cast< ::QRadialGradient *>(sipCppV);

    if (targetType == sipType_QRadialGradient)
        return sipCppV;

    if (targetType == sipType_QGradient)
        return static_cast< ::QGradient *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRadialGradient(void *, int);}
static void release_QRadialGradient(void *sipCppV, int)
{
    delete reinterpret_cast< ::QRadialGradient *>(sipCppV);
}


extern "C" {static void *array_QRadialGradient(Py_ssize_t);}
static void *array_QRadialGradient(Py_ssize_t sipNrElem)
{
    return new ::QRadialGradient[sipNrElem];
}


extern "C" {static void array_delete_QRadialGradient(void *);}
static void array_delete_QRadialGradient(void *sipCpp)
{
    delete[] reinterpret_cast< ::QRadialGradient *>(sipCpp);
}


extern "C" {static void assign_QRadialGradient(void *, Py_ssize_t, void *);}
static void assign_QRadialGradient(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QRadialGradient *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QRadialGradient *>(sipSrc);
}


extern "C" {static void *copy_QRadialGradient(const void *, Py_ssize_t);}
static void *copy_QRadialGradient(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QRadialGradient(reinterpret_cast<const ::QRadialGradient *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QRadialGradient(sipSimpleWrapper *);}
static void dealloc_QRadialGradient(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRadialGradient(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QRadialGradient(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QRadialGradient(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QRadialGradient *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QRadialGradient();

            return sipCpp;
        }
    }

    {
        const ::QPointF* a0;
        ::qreal a1;
        const ::QPointF* a2;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9dJ9", sipType_QPointF, &a0, &a1, sipType_QPointF, &a2))
        {
            sipCpp = new ::QRadialGradient(*a0, a1, *a2);

            return sipCpp;
        }
    }

    {
        const ::QPointF* a0;
        ::qreal a1;
        const ::QPointF* a2;
        ::qreal a3;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9dJ9d", sipType_QPointF, &a0, &a1, sipType_QPointF, &a2, &a3))
        {
            sipCpp = new ::QRadialGradient(*a0, a1, *a2, a3);

            return sipCpp;
        }
    }

    {
        const ::QPointF* a0;
        ::qreal a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9d", sipType_QPointF, &a0, &a1))
        {
            sipCpp = new ::QRadialGradient(*a0, a1);

            return sipCpp;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::qreal a2;
        ::qreal a3;
        ::qreal a4;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "ddddd", &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp = new ::QRadialGradient(a0, a1, a2, a3, a4);

            return sipCpp;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::qreal a2;
        ::qreal a3;
        ::qreal a4;
        ::qreal a5;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "dddddd", &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp = new ::QRadialGradient(a0, a1, a2, a3, a4, a5);

            return sipCpp;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::qreal a2;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "ddd", &a0, &a1, &a2))
        {
            sipCpp = new ::QRadialGradient(a0, a1, a2);

            return sipCpp;
        }
    }

    {
        const ::QRadialGradient* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QRadialGradient, &a0))
        {
            sipCpp = new ::QRadialGradient(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRadialGradient[] = {{94, 255, 1}};


static PyMethodDef methods_QRadialGradient[] = {
    {sipName_center, meth_QRadialGradient_center, METH_VARARGS, doc_QRadialGradient_center},
    {sipName_centerRadius, meth_QRadialGradient_centerRadius, METH_VARARGS, doc_QRadialGradient_centerRadius},
    {sipName_focalPoint, meth_QRadialGradient_focalPoint, METH_VARARGS, doc_QRadialGradient_focalPoint},
    {sipName_focalRadius, meth_QRadialGradient_focalRadius, METH_VARARGS, doc_QRadialGradient_focalRadius},
    {sipName_radius, meth_QRadialGradient_radius, METH_VARARGS, doc_QRadialGradient_radius},
    {sipName_setCenter, meth_QRadialGradient_setCenter, METH_VARARGS, doc_QRadialGradient_setCenter},
    {sipName_setCenterRadius, meth_QRadialGradient_setCenterRadius, METH_VARARGS, doc_QRadialGradient_setCenterRadius},
    {sipName_setFocalPoint, meth_QRadialGradient_setFocalPoint, METH_VARARGS, doc_QRadialGradient_setFocalPoint},
    {sipName_setFocalRadius, meth_QRadialGradient_setFocalRadius, METH_VARARGS, doc_QRadialGradient_setFocalRadius},
    {sipName_setRadius, meth_QRadialGradient_setRadius, METH_VARARGS, doc_QRadialGradient_setRadius}
};

PyDoc_STRVAR(doc_QRadialGradient, "\1QRadialGradient()\n"
"QRadialGradient(center: QPointF, radius: float, focalPoint: QPointF)\n"
"QRadialGradient(center: QPointF, centerRadius: float, focalPoint: QPointF, focalRadius: float)\n"
"QRadialGradient(center: QPointF, radius: float)\n"
"QRadialGradient(cx: float, cy: float, radius: float, fx: float, fy: float)\n"
"QRadialGradient(cx: float, cy: float, centerRadius: float, fx: float, fy: float, focalRadius: float)\n"
"QRadialGradient(cx: float, cy: float, radius: float)\n"
"QRadialGradient(a0: QRadialGradient)");


sipClassTypeDef sipTypeDef_QtGui_QRadialGradient = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRadialGradient,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QRadialGradient,
        {0, 0, 1},
        10, methods_QRadialGradient,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QRadialGradient,
    -1,
    -1,
    supers_QRadialGradient,
    SIP_NULLPTR,
    init_type_QRadialGradient,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRadialGradient,
    assign_QRadialGradient,
    array_QRadialGradient,
    copy_QRadialGradient,
    release_QRadialGradient,
    cast_QRadialGradient,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QRadialGradient,
    sizeof (::QRadialGradient),
};
