/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtPdfAPI_H
#define _QtPdfAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtPdf[0]
#define sipNameNr_QPdfDocumentRenderOptions__RenderFlag 46
#define sipName_QPdfDocumentRenderOptions__RenderFlag &sipStrings_QtPdf[46]
#define sipNameNr_QPdfDocumentRenderOptions__Rotation 84
#define sipName_QPdfDocumentRenderOptions__Rotation &sipStrings_QtPdf[84]
#define sipNameNr_QPdfPageRenderer__RenderMode 120
#define sipName_QPdfPageRenderer__RenderMode &sipStrings_QtPdf[120]
#define sipNameNr_QPdfDocument__MetaDataField 149
#define sipName_QPdfDocument__MetaDataField &sipStrings_QtPdf[149]
#define sipNameNr_QPdfDocument__PageModelRole 177
#define sipName_QPdfDocument__PageModelRole &sipStrings_QtPdf[177]
#define sipNameNr_QPdfDocumentRenderOptions 205
#define sipName_QPdfDocumentRenderOptions &sipStrings_QtPdf[205]
#define sipNameNr_UnsupportedSecurityScheme 231
#define sipName_UnsupportedSecurityScheme &sipStrings_QtPdf[231]
#define sipNameNr_PyQt6_sip_simplewrapper 257
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtPdf[257]
#define sipNameNr_QPdfBookmarkModel__Role 281
#define sipName_QPdfBookmarkModel__Role &sipStrings_QtPdf[281]
#define sipNameNr_forwardAvailableChanged 305
#define sipName_forwardAvailableChanged &sipStrings_QtPdf[305]
#define sipNameNr_currentLocationChanged 329
#define sipName_currentLocationChanged &sipStrings_QtPdf[329]
#define sipNameNr_QPdfSearchModel__Role 352
#define sipName_QPdfSearchModel__Role &sipStrings_QtPdf[352]
#define sipNameNr_QPdfDocument__Status 374
#define sipName_QPdfDocument__Status &sipStrings_QtPdf[374]
#define sipNameNr_backAvailableChanged 395
#define sipName_backAvailableChanged &sipStrings_QtPdf[395]
#define sipNameNr_supportedDragActions 416
#define sipName_supportedDragActions &sipStrings_QtPdf[416]
#define sipNameNr_supportedDropActions 437
#define sipName_supportedDropActions &sipStrings_QtPdf[437]
#define sipNameNr_DataNotYetAvailable 458
#define sipName_DataNotYetAvailable &sipStrings_QtPdf[458]
#define sipNameNr_QPdfDocument__Error 478
#define sipName_QPdfDocument__Error &sipStrings_QtPdf[478]
#define sipNameNr_QPdfLinkModel__Role 498
#define sipName_QPdfLinkModel__Role &sipStrings_QtPdf[498]
#define sipNameNr_getSelectionAtIndex 518
#define sipName_getSelectionAtIndex &sipStrings_QtPdf[518]
#define sipNameNr_searchStringChanged 538
#define sipName_searchStringChanged &sipStrings_QtPdf[538]
#define sipNameNr_currentPageChanged 558
#define sipName_currentPageChanged &sipStrings_QtPdf[558]
#define sipNameNr_currentZoomChanged 577
#define sipName_currentZoomChanged &sipStrings_QtPdf[577]
#define sipNameNr_IncorrectPassword 596
#define sipName_IncorrectPassword &sipStrings_QtPdf[596]
#define sipNameNr_InvalidFileFormat 614
#define sipName_InvalidFileFormat &sipStrings_QtPdf[614]
#define sipNameNr_QPdfBookmarkModel 632
#define sipName_QPdfBookmarkModel &sipStrings_QtPdf[632]
#define sipNameNr_QPdfPageNavigator 650
#define sipName_QPdfPageNavigator &sipStrings_QtPdf[650]
#define sipNameNr_boundingRectangle 668
#define sipName_boundingRectangle &sipStrings_QtPdf[668]
#define sipNameNr_pageIndexForLabel 686
#define sipName_pageIndexForLabel &sipStrings_QtPdf[686]
#define sipNameNr_renderModeChanged 704
#define sipName_renderModeChanged &sipStrings_QtPdf[704]
#define sipNameNr_resetInternalData 722
#define sipName_resetInternalData &sipStrings_QtPdf[722]
#define sipNameNr_setScaledClipRect 740
#define sipName_setScaledClipRect &sipStrings_QtPdf[740]
#define sipNameNr_ModificationDate 758
#define sipName_ModificationDate &sipStrings_QtPdf[758]
#define sipNameNr_QPdfPageRenderer 775
#define sipName_QPdfPageRenderer &sipStrings_QtPdf[775]
#define sipNameNr_disconnectNotify 792
#define sipName_disconnectNotify &sipStrings_QtPdf[792]
#define sipNameNr_forwardAvailable 809
#define sipName_forwardAvailable &sipStrings_QtPdf[809]
#define sipNameNr_pageCountChanged 826
#define sipName_pageCountChanged &sipStrings_QtPdf[826]
#define sipNameNr_pageModelChanged 843
#define sipName_pageModelChanged &sipStrings_QtPdf[843]
#define sipNameNr_OptimizedForLcd 860
#define sipName_OptimizedForLcd &sipStrings_QtPdf[860]
#define sipNameNr_876 876
#define sipName_876 &sipStrings_QtPdf[876]
#define sipNameNr_QPdfSearchModel 892
#define sipName_QPdfSearchModel &sipStrings_QtPdf[892]
#define sipNameNr_canDropMimeData 908
#define sipName_canDropMimeData &sipStrings_QtPdf[908]
#define sipNameNr_copyToClipboard 924
#define sipName_copyToClipboard &sipStrings_QtPdf[924]
#define sipNameNr_currentLocation 940
#define sipName_currentLocation &sipStrings_QtPdf[940]
#define sipNameNr_documentChanged 956
#define sipName_documentChanged &sipStrings_QtPdf[956]
#define sipNameNr_passwordChanged 972
#define sipName_passwordChanged &sipStrings_QtPdf[972]
#define sipNameNr_setSearchString 988
#define sipName_setSearchString &sipStrings_QtPdf[988]
#define sipNameNr_SingleThreaded 1004
#define sipName_SingleThreaded &sipStrings_QtPdf[1004]
#define sipNameNr_scaledClipRect 1019
#define sipName_scaledClipRect &sipStrings_QtPdf[1019]
#define sipNameNr_setRenderFlags 1034
#define sipName_setRenderFlags &sipStrings_QtPdf[1034]
#define sipNameNr_ContextBefore 1049
#define sipName_ContextBefore &sipStrings_QtPdf[1049]
#define sipNameNr_ForceHalftone 1063
#define sipName_ForceHalftone &sipStrings_QtPdf[1063]
#define sipNameNr_MetaDataField 163
#define sipName_MetaDataField &sipStrings_QtPdf[163]
#define sipNameNr_MultiThreaded 1077
#define sipName_MultiThreaded &sipStrings_QtPdf[1077]
#define sipNameNr_PageModelRole 191
#define sipName_PageModelRole &sipStrings_QtPdf[191]
#define sipNameNr_1091 1091
#define sipName_1091 &sipStrings_QtPdf[1091]
#define sipNameNr_QPdfLinkModel 1105
#define sipName_QPdfLinkModel &sipStrings_QtPdf[1105]
#define sipNameNr_QPdfSelection 1119
#define sipName_QPdfSelection &sipStrings_QtPdf[1119]
#define sipNameNr_backAvailable 1133
#define sipName_backAvailable &sipStrings_QtPdf[1133]
#define sipNameNr_clearItemData 1147
#define sipName_clearItemData &sipStrings_QtPdf[1147]
#define sipNameNr_connectNotify 795
#define sipName_connectNotify &sipStrings_QtPdf[795]
#define sipNameNr_contextBefore 1161
#define sipName_contextBefore &sipStrings_QtPdf[1161]
#define sipNameNr_insertColumns 1175
#define sipName_insertColumns &sipStrings_QtPdf[1175]
#define sipNameNr_pagePointSize 1189
#define sipName_pagePointSize &sipStrings_QtPdf[1189]
#define sipNameNr_removeColumns 1203
#define sipName_removeColumns &sipStrings_QtPdf[1203]
#define sipNameNr_resultAtIndex 1217
#define sipName_resultAtIndex &sipStrings_QtPdf[1217]
#define sipNameNr_resultsOnPage 1231
#define sipName_resultsOnPage &sipStrings_QtPdf[1231]
#define sipNameNr_setHeaderData 1245
#define sipName_setHeaderData &sipStrings_QtPdf[1245]
#define sipNameNr_setRenderMode 1259
#define sipName_setRenderMode &sipStrings_QtPdf[1259]
#define sipNameNr_setScaledSize 1273
#define sipName_setScaledSize &sipStrings_QtPdf[1273]
#define sipNameNr_statusChanged 1287
#define sipName_statusChanged &sipStrings_QtPdf[1287]
#define sipNameNr_Clockwise180 1301
#define sipName_Clockwise180 &sipStrings_QtPdf[1301]
#define sipNameNr_Clockwise270 1314
#define sipName_Clockwise270 &sipStrings_QtPdf[1314]
#define sipNameNr_ContextAfter 1327
#define sipName_ContextAfter &sipStrings_QtPdf[1327]
#define sipNameNr_CreationDate 1340
#define sipName_CreationDate &sipStrings_QtPdf[1340]
#define sipNameNr_FileNotFound 1353
#define sipName_FileNotFound &sipStrings_QtPdf[1353]
#define sipNameNr_ImageAliased 1366
#define sipName_ImageAliased &sipStrings_QtPdf[1366]
#define sipNameNr_QPdfDocument 1379
#define sipName_QPdfDocument &sipStrings_QtPdf[1379]
#define sipNameNr_canFetchMore 1392
#define sipName_canFetchMore &sipStrings_QtPdf[1392]
#define sipNameNr_contextAfter 1405
#define sipName_contextAfter &sipStrings_QtPdf[1405]
#define sipNameNr_countChanged 1418
#define sipName_countChanged &sipStrings_QtPdf[1418]
#define sipNameNr_dropMimeData 1431
#define sipName_dropMimeData &sipStrings_QtPdf[1431]
#define sipNameNr_getSelection 1444
#define sipName_getSelection &sipStrings_QtPdf[1444]
#define sipNameNr_searchString 1457
#define sipName_searchString &sipStrings_QtPdf[1457]
#define sipNameNr_Annotations 1470
#define sipName_Annotations &sipStrings_QtPdf[1470]
#define sipNameNr_Clockwise90 1482
#define sipName_Clockwise90 &sipStrings_QtPdf[1482]
#define sipNameNr_IndexOnPage 1494
#define sipName_IndexOnPage &sipStrings_QtPdf[1494]
#define sipNameNr_PathAliased 1506
#define sipName_PathAliased &sipStrings_QtPdf[1506]
#define sipNameNr_PyQt6_QtPdf 1518
#define sipName_PyQt6_QtPdf &sipStrings_QtPdf[1518]
#define sipNameNr_TextAliased 1530
#define sipName_TextAliased &sipStrings_QtPdf[1530]
#define sipNameNr_columnCount 1542
#define sipName_columnCount &sipStrings_QtPdf[1542]
#define sipNameNr_currentPage 1554
#define sipName_currentPage &sipStrings_QtPdf[1554]
#define sipNameNr_currentZoom 1566
#define sipName_currentZoom &sipStrings_QtPdf[1566]
#define sipNameNr_customEvent 1578
#define sipName_customEvent &sipStrings_QtPdf[1578]
#define sipNameNr_eventFilter 1590
#define sipName_eventFilter &sipStrings_QtPdf[1590]
#define sipNameNr_hasChildren 1602
#define sipName_hasChildren &sipStrings_QtPdf[1602]
#define sipNameNr_moveColumns 1205
#define sipName_moveColumns &sipStrings_QtPdf[1205]
#define sipNameNr_pageChanged 1614
#define sipName_pageChanged &sipStrings_QtPdf[1614]
#define sipNameNr_renderFlags 1626
#define sipName_renderFlags &sipStrings_QtPdf[1626]
#define sipNameNr_requestPage 1638
#define sipName_requestPage &sipStrings_QtPdf[1638]
#define sipNameNr_setDocument 1650
#define sipName_setDocument &sipStrings_QtPdf[1650]
#define sipNameNr_setItemData 1662
#define sipName_setItemData &sipStrings_QtPdf[1662]
#define sipNameNr_setPassword 1674
#define sipName_setPassword &sipStrings_QtPdf[1674]
#define sipNameNr_setRotation 1686
#define sipName_setRotation &sipStrings_QtPdf[1686]
#define sipNameNr_RenderFlag 73
#define sipName_RenderFlag &sipStrings_QtPdf[73]
#define sipNameNr_RenderMode 138
#define sipName_RenderMode &sipStrings_QtPdf[138]
#define sipNameNr_childEvent 1698
#define sipName_childEvent &sipStrings_QtPdf[1698]
#define sipNameNr_getAllText 1709
#define sipName_getAllText &sipStrings_QtPdf[1709]
#define sipNameNr_headerData 1720
#define sipName_headerData &sipStrings_QtPdf[1720]
#define sipNameNr_insertRows 1731
#define sipName_insertRows &sipStrings_QtPdf[1731]
#define sipNameNr_rectangles 1742
#define sipName_rectangles &sipStrings_QtPdf[1742]
#define sipNameNr_removeRows 1753
#define sipName_removeRows &sipStrings_QtPdf[1753]
#define sipNameNr_renderMode 1764
#define sipName_renderMode &sipStrings_QtPdf[1764]
#define sipNameNr_scaledSize 1775
#define sipName_scaledSize &sipStrings_QtPdf[1775]
#define sipNameNr_startIndex 1786
#define sipName_startIndex &sipStrings_QtPdf[1786]
#define sipNameNr_timerEvent 1797
#define sipName_timerEvent &sipStrings_QtPdf[1797]
#define sipNameNr_Grayscale 1808
#define sipName_Grayscale &sipStrings_QtPdf[1808]
#define sipNameNr_PointSize 1193
#define sipName_PointSize &sipStrings_QtPdf[1193]
#define sipNameNr_Rectangle 676
#define sipName_Rectangle &sipStrings_QtPdf[676]
#define sipNameNr_Unloading 1818
#define sipName_Unloading &sipStrings_QtPdf[1818]
#define sipNameNr_fetchMore 1828
#define sipName_fetchMore &sipStrings_QtPdf[1828]
#define sipNameNr_mimeTypes 1838
#define sipName_mimeTypes &sipStrings_QtPdf[1838]
#define sipNameNr_multiData 1848
#define sipName_multiData &sipStrings_QtPdf[1848]
#define sipNameNr_pageCount 1858
#define sipName_pageCount &sipStrings_QtPdf[1858]
#define sipNameNr_pageLabel 1868
#define sipName_pageLabel &sipStrings_QtPdf[1868]
#define sipNameNr_pageModel 1878
#define sipName_pageModel &sipStrings_QtPdf[1878]
#define sipNameNr_roleNames 1888
#define sipName_roleNames &sipStrings_QtPdf[1888]
#define sipNameNr_Keywords 1898
#define sipName_Keywords &sipStrings_QtPdf[1898]
#define sipNameNr_Location 947
#define sipName_Location &sipStrings_QtPdf[947]
#define sipNameNr_Producer 1907
#define sipName_Producer &sipStrings_QtPdf[1907]
#define sipNameNr_QPdfLink 1916
#define sipName_QPdfLink &sipStrings_QtPdf[1916]
#define sipNameNr_Rotation 111
#define sipName_Rotation &sipStrings_QtPdf[111]
#define sipNameNr_document 1925
#define sipName_document &sipStrings_QtPdf[1925]
#define sipNameNr_endIndex 1934
#define sipName_endIndex &sipStrings_QtPdf[1934]
#define sipNameNr_itemData 1943
#define sipName_itemData &sipStrings_QtPdf[1943]
#define sipNameNr_location 1952
#define sipName_location &sipStrings_QtPdf[1952]
#define sipNameNr_metaData 1961
#define sipName_metaData &sipStrings_QtPdf[1961]
#define sipNameNr_mimeData 1970
#define sipName_mimeData &sipStrings_QtPdf[1970]
#define sipNameNr_moveRows 1755
#define sipName_moveRows &sipStrings_QtPdf[1755]
#define sipNameNr_password 1979
#define sipName_password &sipStrings_QtPdf[1979]
#define sipNameNr_rotation 1988
#define sipName_rotation &sipStrings_QtPdf[1988]
#define sipNameNr_rowCount 1997
#define sipName_rowCount &sipStrings_QtPdf[1997]
#define sipNameNr_toString 2006
#define sipName_toString &sipStrings_QtPdf[2006]
#define sipNameNr_Creator 2015
#define sipName_Creator &sipStrings_QtPdf[2015]
#define sipNameNr_Loading 2023
#define sipName_Loading &sipStrings_QtPdf[2023]
#define sipNameNr_Subject 2031
#define sipName_Subject &sipStrings_QtPdf[2031]
#define sipNameNr_Unknown 2039
#define sipName_Unknown &sipStrings_QtPdf[2039]
#define sipNameNr___len__ 2047
#define sipName___len__ &sipStrings_QtPdf[2047]
#define sipNameNr_forward 2055
#define sipName_forward &sipStrings_QtPdf[2055]
#define sipNameNr_isValid 2063
#define sipName_isValid &sipStrings_QtPdf[2063]
#define sipNameNr_options 2071
#define sipName_options &sipStrings_QtPdf[2071]
#define sipNameNr_setData 2079
#define sipName_setData &sipStrings_QtPdf[2079]
#define sipNameNr_setPage 2087
#define sipName_setPage &sipStrings_QtPdf[2087]
#define sipNameNr_sibling 2095
#define sipName_sibling &sipStrings_QtPdf[2095]
#define sipNameNr_Author 2103
#define sipName_Author &sipStrings_QtPdf[2103]
#define sipNameNr_Status 388
#define sipName_Status &sipStrings_QtPdf[388]
#define sipNameNr___eq__ 2110
#define sipName___eq__ &sipStrings_QtPdf[2110]
#define sipNameNr___ne__ 2117
#define sipName___ne__ &sipStrings_QtPdf[2117]
#define sipNameNr_bounds 2124
#define sipName_bounds &sipStrings_QtPdf[2124]
#define sipNameNr_jumped 2131
#define sipName_jumped &sipStrings_QtPdf[2131]
#define sipNameNr_linkAt 2138
#define sipName_linkAt &sipStrings_QtPdf[2138]
#define sipNameNr_parent 2145
#define sipName_parent &sipStrings_QtPdf[2145]
#define sipNameNr_render 2152
#define sipName_render &sipStrings_QtPdf[2152]
#define sipNameNr_revert 2159
#define sipName_revert &sipStrings_QtPdf[2159]
#define sipNameNr_status 2166
#define sipName_status &sipStrings_QtPdf[2166]
#define sipNameNr_submit 2173
#define sipName_submit &sipStrings_QtPdf[2173]
#define sipNameNr_update 2180
#define sipName_update &sipStrings_QtPdf[2180]
#define sipNameNr_Error 492
#define sipName_Error &sipStrings_QtPdf[492]
#define sipNameNr_Label 698
#define sipName_Label &sipStrings_QtPdf[698]
#define sipNameNr_Level 2187
#define sipName_Level &sipStrings_QtPdf[2187]
#define sipNameNr_None_ 2193
#define sipName_None_ &sipStrings_QtPdf[2193]
#define sipNameNr_Ready 2199
#define sipName_Ready &sipStrings_QtPdf[2199]
#define sipNameNr_Title 2205
#define sipName_Title &sipStrings_QtPdf[2205]
#define sipNameNr_buddy 2211
#define sipName_buddy &sipStrings_QtPdf[2211]
#define sipNameNr_clear 2217
#define sipName_clear &sipStrings_QtPdf[2217]
#define sipNameNr_close 2223
#define sipName_close &sipStrings_QtPdf[2223]
#define sipNameNr_count 2229
#define sipName_count &sipStrings_QtPdf[2229]
#define sipNameNr_error 2235
#define sipName_error &sipStrings_QtPdf[2235]
#define sipNameNr_event 2241
#define sipName_event &sipStrings_QtPdf[2241]
#define sipNameNr_flags 2247
#define sipName_flags &sipStrings_QtPdf[2247]
#define sipNameNr_index 2253
#define sipName_index &sipStrings_QtPdf[2253]
#define sipNameNr_match 2259
#define sipName_match &sipStrings_QtPdf[2259]
#define sipNameNr_Link 1920
#define sipName_Link &sipStrings_QtPdf[1920]
#define sipNameNr_Null 2265
#define sipName_Null &sipStrings_QtPdf[2265]
#define sipNameNr_Page 1240
#define sipName_Page &sipStrings_QtPdf[1240]
#define sipNameNr_Role 200
#define sipName_Role &sipStrings_QtPdf[200]
#define sipNameNr_Zoom 1573
#define sipName_Zoom &sipStrings_QtPdf[1573]
#define sipNameNr_back 2270
#define sipName_back &sipStrings_QtPdf[2270]
#define sipNameNr_data 2275
#define sipName_data &sipStrings_QtPdf[2275]
#define sipNameNr_jump 2280
#define sipName_jump &sipStrings_QtPdf[2280]
#define sipNameNr_load 2285
#define sipName_load &sipStrings_QtPdf[2285]
#define sipNameNr_mode 2290
#define sipName_mode &sipStrings_QtPdf[2290]
#define sipNameNr_page 2295
#define sipName_page &sipStrings_QtPdf[2295]
#define sipNameNr_sort 2300
#define sipName_sort &sipStrings_QtPdf[2300]
#define sipNameNr_span 2305
#define sipName_span &sipStrings_QtPdf[2305]
#define sipNameNr_swap 2310
#define sipName_swap &sipStrings_QtPdf[2310]
#define sipNameNr_text 2315
#define sipName_text &sipStrings_QtPdf[2315]
#define sipNameNr_zoom 2320
#define sipName_zoom &sipStrings_QtPdf[2320]
#define sipNameNr_Url 2325
#define sipName_Url &sipStrings_QtPdf[2325]
#define sipNameNr_url 2329
#define sipName_url &sipStrings_QtPdf[2329]

#define sipMalloc                   sipAPI_QtPdf->api_malloc
#define sipFree                     sipAPI_QtPdf->api_free
#define sipBuildResult              sipAPI_QtPdf->api_build_result
#define sipCallMethod               sipAPI_QtPdf->api_call_method
#define sipCallProcedureMethod      sipAPI_QtPdf->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtPdf->api_call_error_handler
#define sipParseResultEx            sipAPI_QtPdf->api_parse_result_ex
#define sipParseResult              sipAPI_QtPdf->api_parse_result
#define sipParseArgs                sipAPI_QtPdf->api_parse_args
#define sipParseKwdArgs             sipAPI_QtPdf->api_parse_kwd_args
#define sipParsePair                sipAPI_QtPdf->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtPdf->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtPdf->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtPdf->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtPdf->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtPdf->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtPdf->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtPdf->api_add_exception
#define sipNoFunction               sipAPI_QtPdf->api_no_function
#define sipNoMethod                 sipAPI_QtPdf->api_no_method
#define sipAbstractMethod           sipAPI_QtPdf->api_abstract_method
#define sipBadClass                 sipAPI_QtPdf->api_bad_class
#define sipBadCatcherResult         sipAPI_QtPdf->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtPdf->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtPdf->api_bad_operator_arg
#define sipTrace                    sipAPI_QtPdf->api_trace
#define sipTransferBack             sipAPI_QtPdf->api_transfer_back
#define sipTransferTo               sipAPI_QtPdf->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtPdf->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtPdf->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtPdf->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtPdf->api_voidptr_type
#define sipGetPyObject              sipAPI_QtPdf->api_get_pyobject
#define sipGetAddress               sipAPI_QtPdf->api_get_address
#define sipGetMixinAddress          sipAPI_QtPdf->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtPdf->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtPdf->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtPdf->api_call_hook
#define sipEndThread                sipAPI_QtPdf->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtPdf->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtPdf->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtPdf->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtPdf->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtPdf->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtPdf->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtPdf->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtPdf->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtPdf->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtPdf->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtPdf->api_convert_to_bool
#define sipReleaseType              sipAPI_QtPdf->api_release_type
#define sipConvertFromType          sipAPI_QtPdf->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtPdf->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtPdf->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtPdf->api_convert_from_enum
#define sipGetState                 sipAPI_QtPdf->api_get_state
#define sipExportSymbol             sipAPI_QtPdf->api_export_symbol
#define sipImportSymbol             sipAPI_QtPdf->api_import_symbol
#define sipFindType                 sipAPI_QtPdf->api_find_type
#define sipBytes_AsChar             sipAPI_QtPdf->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtPdf->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtPdf->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtPdf->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtPdf->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtPdf->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtPdf->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtPdf->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtPdf->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtPdf->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtPdf->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtPdf->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtPdf->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtPdf->api_get_reference
#define sipKeepReference            sipAPI_QtPdf->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtPdf->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtPdf->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtPdf->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtPdf->api_type_scope
#define sipResolveTypedef           sipAPI_QtPdf->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtPdf->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtPdf->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtPdf->api_init_mixin
#define sipExportModule             sipAPI_QtPdf->api_export_module
#define sipInitModule               sipAPI_QtPdf->api_init_module
#define sipGetInterpreter           sipAPI_QtPdf->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtPdf->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtPdf->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtPdf->api_py_type_dict
#define sipPyTypeName               sipAPI_QtPdf->api_py_type_name
#define sipGetCFunction             sipAPI_QtPdf->api_get_c_function
#define sipGetMethod                sipAPI_QtPdf->api_get_method
#define sipFromMethod               sipAPI_QtPdf->api_from_method
#define sipGetDate                  sipAPI_QtPdf->api_get_date
#define sipFromDate                 sipAPI_QtPdf->api_from_date
#define sipGetDateTime              sipAPI_QtPdf->api_get_datetime
#define sipFromDateTime             sipAPI_QtPdf->api_from_datetime
#define sipGetTime                  sipAPI_QtPdf->api_get_time
#define sipFromTime                 sipAPI_QtPdf->api_from_time
#define sipIsUserType               sipAPI_QtPdf->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtPdf->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtPdf->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtPdf->api_unicode_write
#define sipUnicodeData              sipAPI_QtPdf->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtPdf->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtPdf->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtPdf->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtPdf->api_is_derived_class
#define sipGetUserObject            sipAPI_QtPdf->api_get_user_object
#define sipSetUserObject            sipAPI_QtPdf->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtPdf->api_register_event_handler
#define sipConvertToArray           sipAPI_QtPdf->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtPdf->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtPdf->api_enable_gc
#define sipPrintObject              sipAPI_QtPdf->api_print_object
#define sipLong_AsChar              sipAPI_QtPdf->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtPdf->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtPdf->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtPdf->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtPdf->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtPdf->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtPdf->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtPdf->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtPdf->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtPdf->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtPdf->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtPdf->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtPdf->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtPdf->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtPdf->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtPdf->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtPdf->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtPdf->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtPdf->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtPdf->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtPdf->api_release_type_us
#define sipIsPyMethod               sipAPI_QtPdf->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtPdf[];

#define sipType_QPdfBookmarkModel sipExportedTypes_QtPdf[3]

#define sipType_QPdfBookmarkModel_Role sipExportedTypes_QtPdf[4]

extern sipClassTypeDef sipTypeDef_QtPdf_QPdfBookmarkModel;

#define sipType_QPdfDocument sipExportedTypes_QtPdf[5]

#define sipType_QPdfDocument_PageModelRole sipExportedTypes_QtPdf[8]

#define sipType_QPdfDocument_MetaDataField sipExportedTypes_QtPdf[7]

#define sipType_QPdfDocument_Error sipExportedTypes_QtPdf[6]

#define sipType_QPdfDocument_Status sipExportedTypes_QtPdf[9]

extern sipClassTypeDef sipTypeDef_QtPdf_QPdfDocument;

#define sipType_QPdfDocumentRenderOptions sipExportedTypes_QtPdf[10]

#define sipType_QPdfDocumentRenderOptions_RenderFlag sipExportedTypes_QtPdf[11]

#define sipType_QPdfDocumentRenderOptions_Rotation sipExportedTypes_QtPdf[12]

extern sipClassTypeDef sipTypeDef_QtPdf_QPdfDocumentRenderOptions;

#define sipType_QPdfLink sipExportedTypes_QtPdf[13]

extern sipClassTypeDef sipTypeDef_QtPdf_QPdfLink;

#define sipType_QPdfLinkModel sipExportedTypes_QtPdf[14]

#define sipType_QPdfLinkModel_Role sipExportedTypes_QtPdf[15]

extern sipClassTypeDef sipTypeDef_QtPdf_QPdfLinkModel;

#define sipType_QPdfPageNavigator sipExportedTypes_QtPdf[16]

extern sipClassTypeDef sipTypeDef_QtPdf_QPdfPageNavigator;

#define sipType_QPdfPageRenderer sipExportedTypes_QtPdf[17]

#define sipType_QPdfPageRenderer_RenderMode sipExportedTypes_QtPdf[18]

extern sipClassTypeDef sipTypeDef_QtPdf_QPdfPageRenderer;

#define sipType_QPdfSearchModel sipExportedTypes_QtPdf[19]

#define sipType_QPdfSearchModel_Role sipExportedTypes_QtPdf[20]

extern sipClassTypeDef sipTypeDef_QtPdf_QPdfSearchModel;

#define sipType_QPdfSelection sipExportedTypes_QtPdf[21]

extern sipClassTypeDef sipTypeDef_QtPdf_QPdfSelection;

#define sipType_QList_0100QPdfLink sipExportedTypes_QtPdf[1]

extern sipMappedTypeDef sipTypeDef_QtPdf_QList_0100QPdfLink;

#define sipType_QList_0100QRectF sipExportedTypes_QtPdf[2]

extern sipMappedTypeDef sipTypeDef_QtPdf_QList_0100QRectF;

#define sipType_QFlags_0100QPdfDocumentRenderOptions_RenderFlag sipExportedTypes_QtPdf[0]

extern sipMappedTypeDef sipTypeDef_QtPdf_QFlags_0100QPdfDocumentRenderOptions_RenderFlag;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtPdf;
extern sipExportedModuleDef sipModuleAPI_QtPdf;
extern sipTypeDef *sipExportedTypes_QtPdf[];

#define sipType_Qt_DropAction sipImportedTypes_QtPdf_QtCore[26].it_td

#define sipType_Qt_SortOrder sipImportedTypes_QtPdf_QtCore[28].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtPdf_QtCore[27].it_td

#define sipType_QObject sipImportedTypes_QtPdf_QtCore[15].it_td

#define sipType_QModelIndex sipImportedTypes_QtPdf_QtCore[13].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtPdf_QtCore[0].it_td

#define sipType_QAbstractListModel sipImportedTypes_QtPdf_QtCore[1].it_td

#define sipType_QModelRoleDataSpan sipImportedTypes_QtPdf_QtCore[14].it_td

#define sipType_QIODevice sipImportedTypes_QtPdf_QtCore[8].it_td

#define sipType_QEvent sipImportedTypes_QtPdf_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtPdf_QtCore[23].it_td

#define sipType_QChildEvent sipImportedTypes_QtPdf_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtPdf_QtCore[11].it_td

#define sipType_QMimeData sipImportedTypes_QtPdf_QtCore[12].it_td

#define sipType_QPointF sipImportedTypes_QtPdf_QtCore[16].it_td

#define sipType_QRect sipImportedTypes_QtPdf_QtCore[17].it_td

#define sipType_QRectF sipImportedTypes_QtPdf_QtCore[18].it_td

#define sipType_QSize sipImportedTypes_QtPdf_QtCore[19].it_td

#define sipType_QSizeF sipImportedTypes_QtPdf_QtCore[20].it_td

#define sipType_QUrl sipImportedTypes_QtPdf_QtCore[24].it_td

#define sipType_QVariant sipImportedTypes_QtPdf_QtCore[25].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtPdf_QtCore[7].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtPdf_QtCore[10].it_td

#define sipType_QFlags_0100Qt_MatchFlag sipImportedTypes_QtPdf_QtCore[6].it_td

#define sipType_QFlags_0100Qt_ItemFlag sipImportedTypes_QtPdf_QtCore[5].it_td

#define sipType_QFlags_0100Qt_DropAction sipImportedTypes_QtPdf_QtCore[4].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtPdf_QtCore[9].it_td

#define sipType_QStringList sipImportedTypes_QtPdf_QtCore[22].it_td

#define sipType_QString sipImportedTypes_QtPdf_QtCore[21].it_td
extern sipImportedTypeDef sipImportedTypes_QtPdf_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtPdf_QtCore[];

#define sipType_QClipboard_Mode sipImportedTypes_QtPdf_QtGui[0].it_td

#define sipType_QImage sipImportedTypes_QtPdf_QtGui[1].it_td

#define sipType_QList_0100QPolygonF sipImportedTypes_QtPdf_QtGui[2].it_td
extern sipImportedTypeDef sipImportedTypes_QtPdf_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtPdf_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtPdf_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtPdf_qt_metacast;

#endif
