/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebSockets.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWebSockets/qwebsocketprotocol.sip"
#include <qwebsocketprotocol.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketProtocol.cpp"



/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QWebSocketProtocol[] = {
    {sipName_CloseCodeNormal, static_cast<int>(::QWebSocketProtocol::CloseCodeNormal)},
    {sipName_CloseCodeGoingAway, static_cast<int>(::QWebSocketProtocol::CloseCodeGoingAway)},
    {sipName_CloseCodeProtocolError, static_cast<int>(::QWebSocketProtocol::CloseCodeProtocolError)},
    {sipName_CloseCodeDatatypeNotSupported, static_cast<int>(::QWebSocketProtocol::CloseCodeDatatypeNotSupported)},
    {sipName_CloseCodeReserved1004, static_cast<int>(::QWebSocketProtocol::CloseCodeReserved1004)},
    {sipName_CloseCodeMissingStatusCode, static_cast<int>(::QWebSocketProtocol::CloseCodeMissingStatusCode)},
    {sipName_CloseCodeAbnormalDisconnection, static_cast<int>(::QWebSocketProtocol::CloseCodeAbnormalDisconnection)},
    {sipName_CloseCodeWrongDatatype, static_cast<int>(::QWebSocketProtocol::CloseCodeWrongDatatype)},
    {sipName_CloseCodePolicyViolated, static_cast<int>(::QWebSocketProtocol::CloseCodePolicyViolated)},
    {sipName_CloseCodeTooMuchData, static_cast<int>(::QWebSocketProtocol::CloseCodeTooMuchData)},
    {sipName_CloseCodeMissingExtension, static_cast<int>(::QWebSocketProtocol::CloseCodeMissingExtension)},
    {sipName_CloseCodeBadOperation, static_cast<int>(::QWebSocketProtocol::CloseCodeBadOperation)},
    {sipName_CloseCodeTlsHandshakeFailed, static_cast<int>(::QWebSocketProtocol::CloseCodeTlsHandshakeFailed)},
    {sipName_VersionUnknown, static_cast<int>(::QWebSocketProtocol::VersionUnknown)},
    {sipName_Version0, static_cast<int>(::QWebSocketProtocol::Version0)},
    {sipName_Version4, static_cast<int>(::QWebSocketProtocol::Version4)},
    {sipName_Version5, static_cast<int>(::QWebSocketProtocol::Version5)},
    {sipName_Version6, static_cast<int>(::QWebSocketProtocol::Version6)},
    {sipName_Version7, static_cast<int>(::QWebSocketProtocol::Version7)},
    {sipName_Version8, static_cast<int>(::QWebSocketProtocol::Version8)},
    {sipName_Version13, static_cast<int>(::QWebSocketProtocol::Version13)},
    {sipName_VersionLatest, static_cast<int>(::QWebSocketProtocol::VersionLatest)},
    {0, 0}
};


sipClassTypeDef sipTypeDef_QtWebSockets_QWebSocketProtocol = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_NAMESPACE,
        sipNameNr_QWebSocketProtocol,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QWebSocketProtocol,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QWebSocketProtocol, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
