/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick3D.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3dgeometry.sip"
#include <qquick3dgeometry.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3dobject.sip"
#include <qquick3dobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3dgeometry.sip"
#include <qquick3dgeometry.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3dgeometry.sip"
#include <qquick3dgeometry.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3dgeometry.sip"
#include <qquick3dgeometry.h>
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3dgeometry.sip"
#include <qquick3dgeometry.h>
#line 43 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 49 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 52 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 78 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometry.cpp"


class sipQQuick3DGeometry : public ::QQuick3DGeometry
{
public:
    sipQQuick3DGeometry(::QQuick3DObject*);
    virtual ~sipQQuick3DGeometry();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void componentComplete() SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuick3DGeometry(const sipQQuick3DGeometry &);
    sipQQuick3DGeometry &operator = (const sipQQuick3DGeometry &);

    char sipPyMethods[9];
};

sipQQuick3DGeometry::sipQQuick3DGeometry(::QQuick3DObject*a0): ::QQuick3DGeometry(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQuick3DGeometry::~sipQQuick3DGeometry()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQQuick3DGeometry::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtQuick3D_qt_metaobject(sipPySelf, sipType_QQuick3DGeometry);

    return ::QQuick3DGeometry::metaObject();
}

int sipQQuick3DGeometry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QQuick3DGeometry::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtQuick3D_qt_metacall(sipPySelf, sipType_QQuick3DGeometry, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQQuick3DGeometry::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtQuick3D_qt_metacast(sipPySelf, sipType_QQuick3DGeometry, _clname, &sipCpp) ? sipCpp : ::QQuick3DGeometry::qt_metacast(_clname));
}

void sipQQuick3DGeometry::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QQuick3DGeometry::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick3D_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQuick3D_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuick3DGeometry::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QQuick3DGeometry::connectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick3D_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQuick3D_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuick3DGeometry::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QQuick3DGeometry::customEvent(a0);
        return;
    }

    extern void sipVH_QtQuick3D_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtQuick3D_1(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuick3DGeometry::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QQuick3DGeometry::childEvent(a0);
        return;
    }

    extern void sipVH_QtQuick3D_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtQuick3D_2(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuick3DGeometry::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QQuick3DGeometry::timerEvent(a0);
        return;
    }

    extern void sipVH_QtQuick3D_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtQuick3D_3(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQuick3DGeometry::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QQuick3DGeometry::eventFilter(a0, a1);

    extern bool sipVH_QtQuick3D_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtQuick3D_4(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQQuick3DGeometry::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QQuick3DGeometry::event(a0);

    extern bool sipVH_QtQuick3D_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtQuick3D_5(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuick3DGeometry::componentComplete()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_componentComplete);

    if (!sipMeth)
    {
        ::QQuick3DGeometry::componentComplete();
        return;
    }

    extern void sipVH_QtQuick3D_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick3D_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQQuick3DGeometry::classBegin()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_classBegin);

    if (!sipMeth)
    {
        ::QQuick3DGeometry::classBegin();
        return;
    }

    extern void sipVH_QtQuick3D_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick3D_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QQuick3DGeometry_attributeCount, "attributeCount(self) -> int");

extern "C" {static PyObject *meth_QQuick3DGeometry_attributeCount(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_attributeCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DGeometry, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->attributeCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_attributeCount, doc_QQuick3DGeometry_attributeCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_attribute, "attribute(self, index: int) -> QQuick3DGeometry.Attribute");

extern "C" {static PyObject *meth_QQuick3DGeometry_attribute(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_attribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0))
        {
            ::QQuick3DGeometry::Attribute*sipRes;

            sipRes = new ::QQuick3DGeometry::Attribute(sipCpp->attribute(a0));

            return sipConvertFromNewType(sipRes, sipType_QQuick3DGeometry_Attribute, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_attribute, doc_QQuick3DGeometry_attribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_primitiveType, "primitiveType(self) -> QQuick3DGeometry.PrimitiveType");

extern "C" {static PyObject *meth_QQuick3DGeometry_primitiveType(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_primitiveType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DGeometry, &sipCpp))
        {
            ::QQuick3DGeometry::PrimitiveType sipRes;

            sipRes = sipCpp->primitiveType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QQuick3DGeometry_PrimitiveType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_primitiveType, doc_QQuick3DGeometry_primitiveType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_boundsMin, "boundsMin(self) -> QVector3D");

extern "C" {static PyObject *meth_QQuick3DGeometry_boundsMin(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_boundsMin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DGeometry, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->boundsMin());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_boundsMin, doc_QQuick3DGeometry_boundsMin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_boundsMax, "boundsMax(self) -> QVector3D");

extern "C" {static PyObject *meth_QQuick3DGeometry_boundsMax(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_boundsMax(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DGeometry, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->boundsMax());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_boundsMax, doc_QQuick3DGeometry_boundsMax);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_stride, "stride(self) -> int");

extern "C" {static PyObject *meth_QQuick3DGeometry_stride(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_stride(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DGeometry, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->stride();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_stride, doc_QQuick3DGeometry_stride);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_setVertexData, "setVertexData(self, data: QByteArray|bytes|bytearray|memoryview)\n"
"setVertexData(self, offset: int, data: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QQuick3DGeometry_setVertexData(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_setVertexData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setVertexData(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0, sipType_QByteArray, &a1, &a1State))
        {
            sipCpp->setVertexData(a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_setVertexData, doc_QQuick3DGeometry_setVertexData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_setIndexData, "setIndexData(self, data: QByteArray|bytes|bytearray|memoryview)\n"
"setIndexData(self, offset: int, data: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QQuick3DGeometry_setIndexData(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_setIndexData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setIndexData(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0, sipType_QByteArray, &a1, &a1State))
        {
            sipCpp->setIndexData(a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_setIndexData, doc_QQuick3DGeometry_setIndexData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_setStride, "setStride(self, stride: int)");

extern "C" {static PyObject *meth_QQuick3DGeometry_setStride(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_setStride(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0))
        {
            sipCpp->setStride(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_setStride, doc_QQuick3DGeometry_setStride);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_setBounds, "setBounds(self, min: QVector3D, max: QVector3D)");

extern "C" {static PyObject *meth_QQuick3DGeometry_setBounds(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_setBounds(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        const ::QVector3D* a1;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, sipType_QVector3D, &a0, sipType_QVector3D, &a1))
        {
            sipCpp->setBounds(*a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_setBounds, doc_QQuick3DGeometry_setBounds);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_setPrimitiveType, "setPrimitiveType(self, type: QQuick3DGeometry.PrimitiveType)");

extern "C" {static PyObject *meth_QQuick3DGeometry_setPrimitiveType(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_setPrimitiveType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QQuick3DGeometry::PrimitiveType a0;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, sipType_QQuick3DGeometry_PrimitiveType, &a0))
        {
            sipCpp->setPrimitiveType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_setPrimitiveType, doc_QQuick3DGeometry_setPrimitiveType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_addAttribute, "addAttribute(self, semantic: QQuick3DGeometry.Attribute.Semantic, offset: int, componentType: QQuick3DGeometry.Attribute.ComponentType)\n"
"addAttribute(self, att: QQuick3DGeometry.Attribute)");

extern "C" {static PyObject *meth_QQuick3DGeometry_addAttribute(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_addAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QQuick3DGeometry::Attribute::Semantic a0;
        int a1;
        ::QQuick3DGeometry::Attribute::ComponentType a2;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEiE", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, sipType_QQuick3DGeometry_Attribute_Semantic, &a0, &a1, sipType_QQuick3DGeometry_Attribute_ComponentType, &a2))
        {
            sipCpp->addAttribute(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QQuick3DGeometry::Attribute* a0;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, sipType_QQuick3DGeometry_Attribute, &a0))
        {
            sipCpp->addAttribute(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_addAttribute, doc_QQuick3DGeometry_addAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_clear, "clear(self)");

extern "C" {static PyObject *meth_QQuick3DGeometry_clear(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DGeometry, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_clear, doc_QQuick3DGeometry_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_vertexData, "vertexData(self) -> QByteArray");

extern "C" {static PyObject *meth_QQuick3DGeometry_vertexData(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_vertexData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DGeometry, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->vertexData());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_vertexData, doc_QQuick3DGeometry_vertexData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_indexData, "indexData(self) -> QByteArray");

extern "C" {static PyObject *meth_QQuick3DGeometry_indexData(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_indexData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DGeometry, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->indexData());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_indexData, doc_QQuick3DGeometry_indexData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_subsetCount, "subsetCount(self, subset: int) -> int\n"
"subsetCount(self) -> int");

extern "C" {static PyObject *meth_QQuick3DGeometry_subsetCount(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_subsetCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0))
        {
            int sipRes;

            sipRes = sipCpp->subsetCount(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    {
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DGeometry, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->subsetCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_subsetCount, doc_QQuick3DGeometry_subsetCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_subsetBoundsMin, "subsetBoundsMin(self, subset: int) -> QVector3D");

extern "C" {static PyObject *meth_QQuick3DGeometry_subsetBoundsMin(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_subsetBoundsMin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->subsetBoundsMin(a0));

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_subsetBoundsMin, doc_QQuick3DGeometry_subsetBoundsMin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_subsetBoundsMax, "subsetBoundsMax(self, subset: int) -> QVector3D");

extern "C" {static PyObject *meth_QQuick3DGeometry_subsetBoundsMax(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_subsetBoundsMax(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->subsetBoundsMax(a0));

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_subsetBoundsMax, doc_QQuick3DGeometry_subsetBoundsMax);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_subsetOffset, "subsetOffset(self, subset: int) -> int");

extern "C" {static PyObject *meth_QQuick3DGeometry_subsetOffset(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_subsetOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0))
        {
            int sipRes;

            sipRes = sipCpp->subsetOffset(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_subsetOffset, doc_QQuick3DGeometry_subsetOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_subsetName, "subsetName(self, subset: int) -> str");

extern "C" {static PyObject *meth_QQuick3DGeometry_subsetName(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_subsetName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->subsetName(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_subsetName, doc_QQuick3DGeometry_subsetName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_addSubset, "addSubset(self, offset: int, count: int, boundsMin: QVector3D, boundsMax: QVector3D, name: str|None = '')");

extern "C" {static PyObject *meth_QQuick3DGeometry_addSubset(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_addSubset(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QVector3D* a2;
        const ::QVector3D* a3;
        const ::QString& a4def = {};
        const ::QString* a4 = &a4def;
        int a4State = 0;
        ::QQuick3DGeometry *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_name,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiiJ9J9|J1", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0, &a1, sipType_QVector3D, &a2, sipType_QVector3D, &a3, sipType_QString, &a4, &a4State))
        {
            sipCpp->addSubset(a0, a1, *a2, *a3, *a4);
            sipReleaseType(const_cast< ::QString *>(a4), sipType_QString, a4State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_addSubset, doc_QQuick3DGeometry_addSubset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_targetData, "targetData(self) -> QByteArray");

extern "C" {static PyObject *meth_QQuick3DGeometry_targetData(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_targetData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DGeometry, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->targetData());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_targetData, doc_QQuick3DGeometry_targetData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_setTargetData, "setTargetData(self, offset: int, data: QByteArray|bytes|bytearray|memoryview)\n"
"setTargetData(self, data: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QQuick3DGeometry_setTargetData(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_setTargetData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0, sipType_QByteArray, &a1, &a1State))
        {
            sipCpp->setTargetData(a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setTargetData(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_setTargetData, doc_QQuick3DGeometry_setTargetData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_targetAttribute, "targetAttribute(self, index: int) -> QQuick3DGeometry.TargetAttribute");

extern "C" {static PyObject *meth_QQuick3DGeometry_targetAttribute(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_targetAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0))
        {
            ::QQuick3DGeometry::TargetAttribute*sipRes;

            sipRes = new ::QQuick3DGeometry::TargetAttribute(sipCpp->targetAttribute(a0));

            return sipConvertFromNewType(sipRes, sipType_QQuick3DGeometry_TargetAttribute, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_targetAttribute, doc_QQuick3DGeometry_targetAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_targetAttributeCount, "targetAttributeCount(self) -> int");

extern "C" {static PyObject *meth_QQuick3DGeometry_targetAttributeCount(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_targetAttributeCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DGeometry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DGeometry, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->targetAttributeCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_targetAttributeCount, doc_QQuick3DGeometry_targetAttributeCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DGeometry_addTargetAttribute, "addTargetAttribute(self, att: QQuick3DGeometry.TargetAttribute)\n"
"addTargetAttribute(self, targetId: int, semantic: QQuick3DGeometry.Attribute.Semantic, offset: int, stride: int = 0)");

extern "C" {static PyObject *meth_QQuick3DGeometry_addTargetAttribute(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QQuick3DGeometry_addTargetAttribute(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DGeometry::TargetAttribute* a0;
        ::QQuick3DGeometry *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ9", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, sipType_QQuick3DGeometry_TargetAttribute, &a0))
        {
            sipCpp->addTargetAttribute(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::quint32 a0;
        ::QQuick3DGeometry::Attribute::Semantic a1;
        int a2;
        int a3 = 0;
        ::QQuick3DGeometry *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_stride,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BuEi|i", &sipSelf, sipType_QQuick3DGeometry, &sipCpp, &a0, sipType_QQuick3DGeometry_Attribute_Semantic, &a1, &a2, &a3))
        {
            sipCpp->addTargetAttribute(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DGeometry, sipName_addTargetAttribute, doc_QQuick3DGeometry_addTargetAttribute);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQuick3DGeometry(void *, const sipTypeDef *);}
static void *cast_QQuick3DGeometry(void *sipCppV, const sipTypeDef *targetType)
{
    ::QQuick3DGeometry *sipCpp = reinterpret_cast< ::QQuick3DGeometry *>(sipCppV);

    if (targetType == sipType_QQuick3DGeometry)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QQuick3DObject)->ctd_cast(static_cast< ::QQuick3DObject *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQuick3DGeometry(void *, int);}
static void release_QQuick3DGeometry(void *sipCppV, int)
{
    ::QQuick3DGeometry *sipCpp = reinterpret_cast< ::QQuick3DGeometry *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QQuick3DGeometry(Py_ssize_t);}
static void *array_QQuick3DGeometry(Py_ssize_t sipNrElem)
{
    return new ::QQuick3DGeometry[sipNrElem];
}


extern "C" {static void array_delete_QQuick3DGeometry(void *);}
static void array_delete_QQuick3DGeometry(void *sipCpp)
{
    delete[] reinterpret_cast< ::QQuick3DGeometry *>(sipCpp);
}


extern "C" {static void dealloc_QQuick3DGeometry(sipSimpleWrapper *);}
static void dealloc_QQuick3DGeometry(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQuick3DGeometry *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuick3DGeometry(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQuick3DGeometry(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuick3DGeometry(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQQuick3DGeometry *sipCpp = SIP_NULLPTR;

    {
        ::QQuick3DObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QQuick3DObject, &a0, sipOwner))
        {
            sipCpp = new sipQQuick3DGeometry(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQuick3DGeometry[] = {{7, 255, 1}};


static PyMethodDef methods_QQuick3DGeometry[] = {
    {sipName_addAttribute, meth_QQuick3DGeometry_addAttribute, METH_VARARGS, doc_QQuick3DGeometry_addAttribute},
    {sipName_addSubset, SIP_MLMETH_CAST(meth_QQuick3DGeometry_addSubset), METH_VARARGS|METH_KEYWORDS, doc_QQuick3DGeometry_addSubset},
    {sipName_addTargetAttribute, SIP_MLMETH_CAST(meth_QQuick3DGeometry_addTargetAttribute), METH_VARARGS|METH_KEYWORDS, doc_QQuick3DGeometry_addTargetAttribute},
    {sipName_attribute, meth_QQuick3DGeometry_attribute, METH_VARARGS, doc_QQuick3DGeometry_attribute},
    {sipName_attributeCount, meth_QQuick3DGeometry_attributeCount, METH_VARARGS, doc_QQuick3DGeometry_attributeCount},
    {sipName_boundsMax, meth_QQuick3DGeometry_boundsMax, METH_VARARGS, doc_QQuick3DGeometry_boundsMax},
    {sipName_boundsMin, meth_QQuick3DGeometry_boundsMin, METH_VARARGS, doc_QQuick3DGeometry_boundsMin},
    {sipName_clear, meth_QQuick3DGeometry_clear, METH_VARARGS, doc_QQuick3DGeometry_clear},
    {sipName_indexData, meth_QQuick3DGeometry_indexData, METH_VARARGS, doc_QQuick3DGeometry_indexData},
    {sipName_primitiveType, meth_QQuick3DGeometry_primitiveType, METH_VARARGS, doc_QQuick3DGeometry_primitiveType},
    {sipName_setBounds, meth_QQuick3DGeometry_setBounds, METH_VARARGS, doc_QQuick3DGeometry_setBounds},
    {sipName_setIndexData, meth_QQuick3DGeometry_setIndexData, METH_VARARGS, doc_QQuick3DGeometry_setIndexData},
    {sipName_setPrimitiveType, meth_QQuick3DGeometry_setPrimitiveType, METH_VARARGS, doc_QQuick3DGeometry_setPrimitiveType},
    {sipName_setStride, meth_QQuick3DGeometry_setStride, METH_VARARGS, doc_QQuick3DGeometry_setStride},
    {sipName_setTargetData, meth_QQuick3DGeometry_setTargetData, METH_VARARGS, doc_QQuick3DGeometry_setTargetData},
    {sipName_setVertexData, meth_QQuick3DGeometry_setVertexData, METH_VARARGS, doc_QQuick3DGeometry_setVertexData},
    {sipName_stride, meth_QQuick3DGeometry_stride, METH_VARARGS, doc_QQuick3DGeometry_stride},
    {sipName_subsetBoundsMax, meth_QQuick3DGeometry_subsetBoundsMax, METH_VARARGS, doc_QQuick3DGeometry_subsetBoundsMax},
    {sipName_subsetBoundsMin, meth_QQuick3DGeometry_subsetBoundsMin, METH_VARARGS, doc_QQuick3DGeometry_subsetBoundsMin},
    {sipName_subsetCount, meth_QQuick3DGeometry_subsetCount, METH_VARARGS, doc_QQuick3DGeometry_subsetCount},
    {sipName_subsetName, meth_QQuick3DGeometry_subsetName, METH_VARARGS, doc_QQuick3DGeometry_subsetName},
    {sipName_subsetOffset, meth_QQuick3DGeometry_subsetOffset, METH_VARARGS, doc_QQuick3DGeometry_subsetOffset},
    {sipName_targetAttribute, meth_QQuick3DGeometry_targetAttribute, METH_VARARGS, doc_QQuick3DGeometry_targetAttribute},
    {sipName_targetAttributeCount, meth_QQuick3DGeometry_targetAttributeCount, METH_VARARGS, doc_QQuick3DGeometry_targetAttributeCount},
    {sipName_targetData, meth_QQuick3DGeometry_targetData, METH_VARARGS, doc_QQuick3DGeometry_targetData},
    {sipName_vertexData, meth_QQuick3DGeometry_vertexData, METH_VARARGS, doc_QQuick3DGeometry_vertexData}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QQuick3DGeometry[] = {
    {sipName_Points, static_cast<int>(::QQuick3DGeometry::PrimitiveType::Points)},
    {sipName_LineStrip, static_cast<int>(::QQuick3DGeometry::PrimitiveType::LineStrip)},
    {sipName_Lines, static_cast<int>(::QQuick3DGeometry::PrimitiveType::Lines)},
    {sipName_TriangleStrip, static_cast<int>(::QQuick3DGeometry::PrimitiveType::TriangleStrip)},
    {sipName_TriangleFan, static_cast<int>(::QQuick3DGeometry::PrimitiveType::TriangleFan)},
    {sipName_Triangles, static_cast<int>(::QQuick3DGeometry::PrimitiveType::Triangles)},
    {0, 0}
};

PyDoc_STRVAR(doc_QQuick3DGeometry, "\1QQuick3DGeometry(parent: QQuick3DObject|None = None)");


static pyqt6ClassPluginDef plugin_QQuick3DGeometry = {
    &::QQuick3DGeometry::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick3D_QQuick3DGeometry = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuick3DGeometry,
        SIP_NULLPTR,
        &plugin_QQuick3DGeometry,
    },
    {
        sipNameNr_QQuick3DGeometry,
        {0, 0, 1},
        26, methods_QQuick3DGeometry,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QQuick3DGeometry, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuick3DGeometry,
    -1,
    -1,
    supers_QQuick3DGeometry,
    SIP_NULLPTR,
    init_type_QQuick3DGeometry,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuick3DGeometry,
    SIP_NULLPTR,
    array_QQuick3DGeometry,
    SIP_NULLPTR,
    release_QQuick3DGeometry,
    cast_QQuick3DGeometry,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QQuick3DGeometry,
    sizeof (::QQuick3DGeometry),
};
