/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediacapturesession.sip"
#include <qmediacapturesession.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qvideoframeinput.sip"
#include <qvideoframeinput.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiobufferinput.sip"
#include <qaudiobufferinput.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qwindowcapture.sip"
#include <qwindowcapture.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qscreencapture.sip"
#include <qscreencapture.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiooutput.sip"
#include <qaudiooutput.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qvideosink.sip"
#include <qvideosink.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediarecorder.sip"
#include <qmediarecorder.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qimagecapture.sip"
#include <qimagecapture.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudioinput.sip"
#include <qaudioinput.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 112 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaCaptureSession.cpp"


class sipQMediaCaptureSession : public ::QMediaCaptureSession
{
public:
    sipQMediaCaptureSession(::QObject*);
    virtual ~sipQMediaCaptureSession();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQMediaCaptureSession(const sipQMediaCaptureSession &);
    sipQMediaCaptureSession &operator = (const sipQMediaCaptureSession &);

    char sipPyMethods[7];
};

sipQMediaCaptureSession::sipQMediaCaptureSession(::QObject*a0): ::QMediaCaptureSession(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQMediaCaptureSession::~sipQMediaCaptureSession()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQMediaCaptureSession::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QMediaCaptureSession);

    return ::QMediaCaptureSession::metaObject();
}

int sipQMediaCaptureSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QMediaCaptureSession::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QMediaCaptureSession, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQMediaCaptureSession::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QMediaCaptureSession, _clname, &sipCpp) ? sipCpp : ::QMediaCaptureSession::qt_metacast(_clname));
}

bool sipQMediaCaptureSession::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QMediaCaptureSession::event(a0);

    extern bool sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaCaptureSession::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QMediaCaptureSession::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_4(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQMediaCaptureSession::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QMediaCaptureSession::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_3(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaCaptureSession::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QMediaCaptureSession::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaCaptureSession::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QMediaCaptureSession::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_1(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaCaptureSession::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QMediaCaptureSession::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaCaptureSession::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QMediaCaptureSession::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QMediaCaptureSession_audioInput, "audioInput(self) -> QAudioInput|None");

extern "C" {static PyObject *meth_QMediaCaptureSession_audioInput(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_audioInput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaCaptureSession, &sipCpp))
        {
            ::QAudioInput*sipRes;

            sipRes = sipCpp->audioInput();

            return sipConvertFromType(sipRes, sipType_QAudioInput, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_audioInput, doc_QMediaCaptureSession_audioInput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_setAudioInput, "setAudioInput(self, device: QAudioInput|None)");

extern "C" {static PyObject *meth_QMediaCaptureSession_setAudioInput(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_setAudioInput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioInput* a0;
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaCaptureSession, &sipCpp, sipType_QAudioInput, &a0))
        {
            sipCpp->setAudioInput(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_setAudioInput, doc_QMediaCaptureSession_setAudioInput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_camera, "camera(self) -> QCamera|None");

extern "C" {static PyObject *meth_QMediaCaptureSession_camera(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_camera(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaCaptureSession, &sipCpp))
        {
            ::QCamera*sipRes;

            sipRes = sipCpp->camera();

            return sipConvertFromType(sipRes, sipType_QCamera, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_camera, doc_QMediaCaptureSession_camera);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_setCamera, "setCamera(self, camera: QCamera|None)");

extern "C" {static PyObject *meth_QMediaCaptureSession_setCamera(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_setCamera(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera* a0;
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaCaptureSession, &sipCpp, sipType_QCamera, &a0))
        {
            sipCpp->setCamera(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_setCamera, doc_QMediaCaptureSession_setCamera);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_imageCapture, "imageCapture(self) -> QImageCapture|None");

extern "C" {static PyObject *meth_QMediaCaptureSession_imageCapture(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_imageCapture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaCaptureSession, &sipCpp))
        {
            ::QImageCapture*sipRes;

            sipRes = sipCpp->imageCapture();

            return sipConvertFromType(sipRes, sipType_QImageCapture, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_imageCapture, doc_QMediaCaptureSession_imageCapture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_setImageCapture, "setImageCapture(self, imageCapture: QImageCapture|None)");

extern "C" {static PyObject *meth_QMediaCaptureSession_setImageCapture(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_setImageCapture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QImageCapture* a0;
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaCaptureSession, &sipCpp, sipType_QImageCapture, &a0))
        {
            sipCpp->setImageCapture(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_setImageCapture, doc_QMediaCaptureSession_setImageCapture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_recorder, "recorder(self) -> QMediaRecorder|None");

extern "C" {static PyObject *meth_QMediaCaptureSession_recorder(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_recorder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaCaptureSession, &sipCpp))
        {
            ::QMediaRecorder*sipRes;

            sipRes = sipCpp->recorder();

            return sipConvertFromType(sipRes, sipType_QMediaRecorder, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_recorder, doc_QMediaCaptureSession_recorder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_setRecorder, "setRecorder(self, recorder: QMediaRecorder|None)");

extern "C" {static PyObject *meth_QMediaCaptureSession_setRecorder(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_setRecorder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaRecorder* a0;
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaCaptureSession, &sipCpp, sipType_QMediaRecorder, &a0))
        {
            sipCpp->setRecorder(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_setRecorder, doc_QMediaCaptureSession_setRecorder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_setVideoOutput, "setVideoOutput(self, output: QObject|None)");

extern "C" {static PyObject *meth_QMediaCaptureSession_setVideoOutput(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_setVideoOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaCaptureSession, &sipCpp, sipType_QObject, &a0))
        {
            sipCpp->setVideoOutput(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_setVideoOutput, doc_QMediaCaptureSession_setVideoOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_videoOutput, "videoOutput(self) -> QObject|None");

extern "C" {static PyObject *meth_QMediaCaptureSession_videoOutput(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_videoOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaCaptureSession, &sipCpp))
        {
            ::QObject*sipRes;

            sipRes = sipCpp->videoOutput();

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_videoOutput, doc_QMediaCaptureSession_videoOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_setVideoSink, "setVideoSink(self, sink: QVideoSink|None)");

extern "C" {static PyObject *meth_QMediaCaptureSession_setVideoSink(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_setVideoSink(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVideoSink* a0;
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaCaptureSession, &sipCpp, sipType_QVideoSink, &a0))
        {
            sipCpp->setVideoSink(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_setVideoSink, doc_QMediaCaptureSession_setVideoSink);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_videoSink, "videoSink(self) -> QVideoSink|None");

extern "C" {static PyObject *meth_QMediaCaptureSession_videoSink(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_videoSink(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaCaptureSession, &sipCpp))
        {
            ::QVideoSink*sipRes;

            sipRes = sipCpp->videoSink();

            return sipConvertFromType(sipRes, sipType_QVideoSink, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_videoSink, doc_QMediaCaptureSession_videoSink);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_setAudioOutput, "setAudioOutput(self, output: QAudioOutput|None)");

extern "C" {static PyObject *meth_QMediaCaptureSession_setAudioOutput(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_setAudioOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioOutput* a0;
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaCaptureSession, &sipCpp, sipType_QAudioOutput, &a0))
        {
            sipCpp->setAudioOutput(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_setAudioOutput, doc_QMediaCaptureSession_setAudioOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_audioOutput, "audioOutput(self) -> QAudioOutput|None");

extern "C" {static PyObject *meth_QMediaCaptureSession_audioOutput(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_audioOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaCaptureSession, &sipCpp))
        {
            ::QAudioOutput*sipRes;

            sipRes = sipCpp->audioOutput();

            return sipConvertFromType(sipRes, sipType_QAudioOutput, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_audioOutput, doc_QMediaCaptureSession_audioOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_screenCapture, "screenCapture(self) -> QScreenCapture|None");

extern "C" {static PyObject *meth_QMediaCaptureSession_screenCapture(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_screenCapture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaCaptureSession, &sipCpp))
        {
            ::QScreenCapture*sipRes;

            sipRes = sipCpp->screenCapture();

            return sipConvertFromType(sipRes, sipType_QScreenCapture, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_screenCapture, doc_QMediaCaptureSession_screenCapture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_setScreenCapture, "setScreenCapture(self, screenCapture: QScreenCapture|None)");

extern "C" {static PyObject *meth_QMediaCaptureSession_setScreenCapture(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_setScreenCapture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QScreenCapture* a0;
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaCaptureSession, &sipCpp, sipType_QScreenCapture, &a0))
        {
            sipCpp->setScreenCapture(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_setScreenCapture, doc_QMediaCaptureSession_setScreenCapture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_windowCapture, "windowCapture(self) -> QWindowCapture|None");

extern "C" {static PyObject *meth_QMediaCaptureSession_windowCapture(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_windowCapture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaCaptureSession, &sipCpp))
        {
            ::QWindowCapture*sipRes;

            sipRes = sipCpp->windowCapture();

            return sipConvertFromType(sipRes, sipType_QWindowCapture, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_windowCapture, doc_QMediaCaptureSession_windowCapture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_setWindowCapture, "setWindowCapture(self, windowCapture: QWindowCapture|None)");

extern "C" {static PyObject *meth_QMediaCaptureSession_setWindowCapture(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_setWindowCapture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWindowCapture* a0;
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaCaptureSession, &sipCpp, sipType_QWindowCapture, &a0))
        {
            sipCpp->setWindowCapture(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_setWindowCapture, doc_QMediaCaptureSession_setWindowCapture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_audioBufferInput, "audioBufferInput(self) -> QAudioBufferInput|None");

extern "C" {static PyObject *meth_QMediaCaptureSession_audioBufferInput(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_audioBufferInput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaCaptureSession, &sipCpp))
        {
            ::QAudioBufferInput*sipRes;

            sipRes = sipCpp->audioBufferInput();

            return sipConvertFromType(sipRes, sipType_QAudioBufferInput, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_audioBufferInput, doc_QMediaCaptureSession_audioBufferInput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_setAudioBufferInput, "setAudioBufferInput(self, input: QAudioBufferInput|None)");

extern "C" {static PyObject *meth_QMediaCaptureSession_setAudioBufferInput(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_setAudioBufferInput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioBufferInput* a0;
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaCaptureSession, &sipCpp, sipType_QAudioBufferInput, &a0))
        {
            sipCpp->setAudioBufferInput(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_setAudioBufferInput, doc_QMediaCaptureSession_setAudioBufferInput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_videoFrameInput, "videoFrameInput(self) -> QVideoFrameInput|None");

extern "C" {static PyObject *meth_QMediaCaptureSession_videoFrameInput(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_videoFrameInput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaCaptureSession, &sipCpp))
        {
            ::QVideoFrameInput*sipRes;

            sipRes = sipCpp->videoFrameInput();

            return sipConvertFromType(sipRes, sipType_QVideoFrameInput, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_videoFrameInput, doc_QMediaCaptureSession_videoFrameInput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaCaptureSession_setVideoFrameInput, "setVideoFrameInput(self, input: QVideoFrameInput|None)");

extern "C" {static PyObject *meth_QMediaCaptureSession_setVideoFrameInput(PyObject *, PyObject *);}
static PyObject *meth_QMediaCaptureSession_setVideoFrameInput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVideoFrameInput* a0;
        ::QMediaCaptureSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaCaptureSession, &sipCpp, sipType_QVideoFrameInput, &a0))
        {
            sipCpp->setVideoFrameInput(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaCaptureSession, sipName_setVideoFrameInput, doc_QMediaCaptureSession_setVideoFrameInput);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QMediaCaptureSession(void *, const sipTypeDef *);}
static void *cast_QMediaCaptureSession(void *sipCppV, const sipTypeDef *targetType)
{
    ::QMediaCaptureSession *sipCpp = reinterpret_cast< ::QMediaCaptureSession *>(sipCppV);

    if (targetType == sipType_QMediaCaptureSession)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QMediaCaptureSession(void *, int);}
static void release_QMediaCaptureSession(void *sipCppV, int)
{
    ::QMediaCaptureSession *sipCpp = reinterpret_cast< ::QMediaCaptureSession *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QMediaCaptureSession(Py_ssize_t);}
static void *array_QMediaCaptureSession(Py_ssize_t sipNrElem)
{
    return new ::QMediaCaptureSession[sipNrElem];
}


extern "C" {static void array_delete_QMediaCaptureSession(void *);}
static void array_delete_QMediaCaptureSession(void *sipCpp)
{
    delete[] reinterpret_cast< ::QMediaCaptureSession *>(sipCpp);
}


extern "C" {static void dealloc_QMediaCaptureSession(sipSimpleWrapper *);}
static void dealloc_QMediaCaptureSession(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQMediaCaptureSession *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMediaCaptureSession(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QMediaCaptureSession(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMediaCaptureSession(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQMediaCaptureSession *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQMediaCaptureSession(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QMediaCaptureSession[] = {{7, 0, 1}};


static PyMethodDef methods_QMediaCaptureSession[] = {
    {sipName_audioBufferInput, meth_QMediaCaptureSession_audioBufferInput, METH_VARARGS, doc_QMediaCaptureSession_audioBufferInput},
    {sipName_audioInput, meth_QMediaCaptureSession_audioInput, METH_VARARGS, doc_QMediaCaptureSession_audioInput},
    {sipName_audioOutput, meth_QMediaCaptureSession_audioOutput, METH_VARARGS, doc_QMediaCaptureSession_audioOutput},
    {sipName_camera, meth_QMediaCaptureSession_camera, METH_VARARGS, doc_QMediaCaptureSession_camera},
    {sipName_imageCapture, meth_QMediaCaptureSession_imageCapture, METH_VARARGS, doc_QMediaCaptureSession_imageCapture},
    {sipName_recorder, meth_QMediaCaptureSession_recorder, METH_VARARGS, doc_QMediaCaptureSession_recorder},
    {sipName_screenCapture, meth_QMediaCaptureSession_screenCapture, METH_VARARGS, doc_QMediaCaptureSession_screenCapture},
    {sipName_setAudioBufferInput, meth_QMediaCaptureSession_setAudioBufferInput, METH_VARARGS, doc_QMediaCaptureSession_setAudioBufferInput},
    {sipName_setAudioInput, meth_QMediaCaptureSession_setAudioInput, METH_VARARGS, doc_QMediaCaptureSession_setAudioInput},
    {sipName_setAudioOutput, meth_QMediaCaptureSession_setAudioOutput, METH_VARARGS, doc_QMediaCaptureSession_setAudioOutput},
    {sipName_setCamera, meth_QMediaCaptureSession_setCamera, METH_VARARGS, doc_QMediaCaptureSession_setCamera},
    {sipName_setImageCapture, meth_QMediaCaptureSession_setImageCapture, METH_VARARGS, doc_QMediaCaptureSession_setImageCapture},
    {sipName_setRecorder, meth_QMediaCaptureSession_setRecorder, METH_VARARGS, doc_QMediaCaptureSession_setRecorder},
    {sipName_setScreenCapture, meth_QMediaCaptureSession_setScreenCapture, METH_VARARGS, doc_QMediaCaptureSession_setScreenCapture},
    {sipName_setVideoFrameInput, meth_QMediaCaptureSession_setVideoFrameInput, METH_VARARGS, doc_QMediaCaptureSession_setVideoFrameInput},
    {sipName_setVideoOutput, meth_QMediaCaptureSession_setVideoOutput, METH_VARARGS, doc_QMediaCaptureSession_setVideoOutput},
    {sipName_setVideoSink, meth_QMediaCaptureSession_setVideoSink, METH_VARARGS, doc_QMediaCaptureSession_setVideoSink},
    {sipName_setWindowCapture, meth_QMediaCaptureSession_setWindowCapture, METH_VARARGS, doc_QMediaCaptureSession_setWindowCapture},
    {sipName_videoFrameInput, meth_QMediaCaptureSession_videoFrameInput, METH_VARARGS, doc_QMediaCaptureSession_videoFrameInput},
    {sipName_videoOutput, meth_QMediaCaptureSession_videoOutput, METH_VARARGS, doc_QMediaCaptureSession_videoOutput},
    {sipName_videoSink, meth_QMediaCaptureSession_videoSink, METH_VARARGS, doc_QMediaCaptureSession_videoSink},
    {sipName_windowCapture, meth_QMediaCaptureSession_windowCapture, METH_VARARGS, doc_QMediaCaptureSession_windowCapture}
};

PyDoc_STRVAR(doc_QMediaCaptureSession, "\1QMediaCaptureSession(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QMediaCaptureSession[] = {
    {"videoFrameInputChanged()", "\1videoFrameInputChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"audioBufferInputChanged()", "\1audioBufferInputChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"windowCaptureChanged()", "\1windowCaptureChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"screenCaptureChanged()", "\1screenCaptureChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"audioOutputChanged()", "\1audioOutputChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"videoOutputChanged()", "\1videoOutputChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"recorderChanged()", "\1recorderChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"imageCaptureChanged()", "\1imageCaptureChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"cameraChanged()", "\1cameraChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"audioInputChanged()", "\1audioInputChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QMediaCaptureSession = {
    &::QMediaCaptureSession::staticMetaObject,
    signals_QMediaCaptureSession,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaCaptureSession = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMediaCaptureSession,
        SIP_NULLPTR,
        &plugin_QMediaCaptureSession,
    },
    {
        sipNameNr_QMediaCaptureSession,
        {0, 0, 1},
        22, methods_QMediaCaptureSession,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMediaCaptureSession,
    -1,
    -1,
    supers_QMediaCaptureSession,
    SIP_NULLPTR,
    init_type_QMediaCaptureSession,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMediaCaptureSession,
    SIP_NULLPTR,
    array_QMediaCaptureSession,
    SIP_NULLPTR,
    release_QMediaCaptureSession,
    cast_QMediaCaptureSession,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QMediaCaptureSession,
    sizeof (::QMediaCaptureSession),
};
