/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPdf.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfpagenavigator.sip"
#include <qpdfpagenavigator.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdflink.sip"
#include <qpdflink.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageNavigator.cpp"


class sipQPdfPageNavigator : public ::QPdfPageNavigator
{
public:
    sipQPdfPageNavigator(::QObject*);
    virtual ~sipQPdfPageNavigator();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPdfPageNavigator(const sipQPdfPageNavigator &);
    sipQPdfPageNavigator &operator = (const sipQPdfPageNavigator &);

    char sipPyMethods[7];
};

sipQPdfPageNavigator::sipQPdfPageNavigator(::QObject*a0): ::QPdfPageNavigator(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPdfPageNavigator::~sipQPdfPageNavigator()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQPdfPageNavigator::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtPdf_qt_metaobject(sipPySelf, sipType_QPdfPageNavigator);

    return ::QPdfPageNavigator::metaObject();
}

int sipQPdfPageNavigator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QPdfPageNavigator::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtPdf_qt_metacall(sipPySelf, sipType_QPdfPageNavigator, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQPdfPageNavigator::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtPdf_qt_metacast(sipPySelf, sipType_QPdfPageNavigator, _clname, &sipCpp) ? sipCpp : ::QPdfPageNavigator::qt_metacast(_clname));
}

bool sipQPdfPageNavigator::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QPdfPageNavigator::event(a0);

    extern bool sipVH_QtPdf_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtPdf_25(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPdfPageNavigator::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QPdfPageNavigator::eventFilter(a0, a1);

    extern bool sipVH_QtPdf_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtPdf_26(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQPdfPageNavigator::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QPdfPageNavigator::timerEvent(a0);
        return;
    }

    extern void sipVH_QtPdf_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtPdf_27(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfPageNavigator::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QPdfPageNavigator::childEvent(a0);
        return;
    }

    extern void sipVH_QtPdf_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtPdf_28(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfPageNavigator::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QPdfPageNavigator::customEvent(a0);
        return;
    }

    extern void sipVH_QtPdf_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPdf_29(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfPageNavigator::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QPdfPageNavigator::connectNotify(a0);
        return;
    }

    extern void sipVH_QtPdf_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPdf_30(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfPageNavigator::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QPdfPageNavigator::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtPdf_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPdf_30(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QPdfPageNavigator_currentPage, "currentPage(self) -> int");

extern "C" {static PyObject *meth_QPdfPageNavigator_currentPage(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageNavigator_currentPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfPageNavigator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfPageNavigator, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentPage();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageNavigator, sipName_currentPage, doc_QPdfPageNavigator_currentPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageNavigator_currentLocation, "currentLocation(self) -> QPointF");

extern "C" {static PyObject *meth_QPdfPageNavigator_currentLocation(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageNavigator_currentLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfPageNavigator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfPageNavigator, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->currentLocation());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageNavigator, sipName_currentLocation, doc_QPdfPageNavigator_currentLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageNavigator_currentZoom, "currentZoom(self) -> float");

extern "C" {static PyObject *meth_QPdfPageNavigator_currentZoom(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageNavigator_currentZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfPageNavigator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfPageNavigator, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->currentZoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageNavigator, sipName_currentZoom, doc_QPdfPageNavigator_currentZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageNavigator_backAvailable, "backAvailable(self) -> bool");

extern "C" {static PyObject *meth_QPdfPageNavigator_backAvailable(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageNavigator_backAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfPageNavigator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfPageNavigator, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->backAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageNavigator, sipName_backAvailable, doc_QPdfPageNavigator_backAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageNavigator_forwardAvailable, "forwardAvailable(self) -> bool");

extern "C" {static PyObject *meth_QPdfPageNavigator_forwardAvailable(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageNavigator_forwardAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfPageNavigator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfPageNavigator, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->forwardAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageNavigator, sipName_forwardAvailable, doc_QPdfPageNavigator_forwardAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageNavigator_clear, "clear(self)");

extern "C" {static PyObject *meth_QPdfPageNavigator_clear(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageNavigator_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfPageNavigator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfPageNavigator, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageNavigator, sipName_clear, doc_QPdfPageNavigator_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageNavigator_jump, "jump(self, destination: QPdfLink)\n"
"jump(self, page: int, location: QPointF, zoom: float = 0)");

extern "C" {static PyObject *meth_QPdfPageNavigator_jump(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPdfPageNavigator_jump(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfLink* a0;
        ::QPdfPageNavigator *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ9", &sipSelf, sipType_QPdfPageNavigator, &sipCpp, sipType_QPdfLink, &a0))
        {
            sipCpp->jump(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        const ::QPointF* a1;
        ::qreal a2 = 0;
        ::QPdfPageNavigator *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_zoom,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiJ9|d", &sipSelf, sipType_QPdfPageNavigator, &sipCpp, &a0, sipType_QPointF, &a1, &a2))
        {
            sipCpp->jump(a0, *a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageNavigator, sipName_jump, doc_QPdfPageNavigator_jump);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageNavigator_update, "update(self, page: int, location: QPointF, zoom: float)");

extern "C" {static PyObject *meth_QPdfPageNavigator_update(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageNavigator_update(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QPointF* a1;
        ::qreal a2;
        ::QPdfPageNavigator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ9d", &sipSelf, sipType_QPdfPageNavigator, &sipCpp, &a0, sipType_QPointF, &a1, &a2))
        {
            sipCpp->update(a0, *a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageNavigator, sipName_update, doc_QPdfPageNavigator_update);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageNavigator_forward, "forward(self)");

extern "C" {static PyObject *meth_QPdfPageNavigator_forward(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageNavigator_forward(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfPageNavigator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfPageNavigator, &sipCpp))
        {
            sipCpp->forward();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageNavigator, sipName_forward, doc_QPdfPageNavigator_forward);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageNavigator_back, "back(self)");

extern "C" {static PyObject *meth_QPdfPageNavigator_back(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageNavigator_back(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfPageNavigator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfPageNavigator, &sipCpp))
        {
            sipCpp->back();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageNavigator, sipName_back, doc_QPdfPageNavigator_back);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPdfPageNavigator(void *, const sipTypeDef *);}
static void *cast_QPdfPageNavigator(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPdfPageNavigator *sipCpp = reinterpret_cast< ::QPdfPageNavigator *>(sipCppV);

    if (targetType == sipType_QPdfPageNavigator)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPdfPageNavigator(void *, int);}
static void release_QPdfPageNavigator(void *sipCppV, int)
{
    ::QPdfPageNavigator *sipCpp = reinterpret_cast< ::QPdfPageNavigator *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QPdfPageNavigator(sipSimpleWrapper *);}
static void dealloc_QPdfPageNavigator(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPdfPageNavigator *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPdfPageNavigator(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPdfPageNavigator(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPdfPageNavigator(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQPdfPageNavigator *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQPdfPageNavigator(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPdfPageNavigator[] = {{15, 0, 1}};


static PyMethodDef methods_QPdfPageNavigator[] = {
    {sipName_back, meth_QPdfPageNavigator_back, METH_VARARGS, doc_QPdfPageNavigator_back},
    {sipName_backAvailable, meth_QPdfPageNavigator_backAvailable, METH_VARARGS, doc_QPdfPageNavigator_backAvailable},
    {sipName_clear, meth_QPdfPageNavigator_clear, METH_VARARGS, doc_QPdfPageNavigator_clear},
    {sipName_currentLocation, meth_QPdfPageNavigator_currentLocation, METH_VARARGS, doc_QPdfPageNavigator_currentLocation},
    {sipName_currentPage, meth_QPdfPageNavigator_currentPage, METH_VARARGS, doc_QPdfPageNavigator_currentPage},
    {sipName_currentZoom, meth_QPdfPageNavigator_currentZoom, METH_VARARGS, doc_QPdfPageNavigator_currentZoom},
    {sipName_forward, meth_QPdfPageNavigator_forward, METH_VARARGS, doc_QPdfPageNavigator_forward},
    {sipName_forwardAvailable, meth_QPdfPageNavigator_forwardAvailable, METH_VARARGS, doc_QPdfPageNavigator_forwardAvailable},
    {sipName_jump, SIP_MLMETH_CAST(meth_QPdfPageNavigator_jump), METH_VARARGS|METH_KEYWORDS, doc_QPdfPageNavigator_jump},
    {sipName_update, meth_QPdfPageNavigator_update, METH_VARARGS, doc_QPdfPageNavigator_update}
};

PyDoc_STRVAR(doc_QPdfPageNavigator, "\1QPdfPageNavigator(parent: QObject|None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QPdfPageNavigator[] = {
    {"jumped(QPdfLink)", "\1jumped(self, current: QPdfLink)", SIP_NULLPTR, SIP_NULLPTR},
    {"forwardAvailableChanged(bool)", "\1forwardAvailableChanged(self, available: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"backAvailableChanged(bool)", "\1backAvailableChanged(self, available: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentZoomChanged(qreal)", "\1currentZoomChanged(self, zoom: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentLocationChanged(QPointF)", "\1currentLocationChanged(self, location: QPointF)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentPageChanged(int)", "\1currentPageChanged(self, page: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QPdfPageNavigator = {
    &::QPdfPageNavigator::staticMetaObject,
    signals_QPdfPageNavigator,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPdf_QPdfPageNavigator = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPdfPageNavigator,
        SIP_NULLPTR,
        &plugin_QPdfPageNavigator,
    },
    {
        sipNameNr_QPdfPageNavigator,
        {0, 0, 1},
        10, methods_QPdfPageNavigator,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPdfPageNavigator,
    -1,
    -1,
    supers_QPdfPageNavigator,
    SIP_NULLPTR,
    init_type_QPdfPageNavigator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPdfPageNavigator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QPdfPageNavigator,
    cast_QPdfPageNavigator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QPdfPageNavigator),
};
