/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNfc.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldtarget.sip"
#include <qnearfieldtarget.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldtarget.sip"
#include <qnearfieldtarget.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldtarget.sip"
#include <qnearfieldtarget.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefmessage.sip"
#include <qndefmessage.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldTarget.cpp"


class sipQNearFieldTarget : public ::QNearFieldTarget
{
public:
    sipQNearFieldTarget(::QObject*);
    virtual ~sipQNearFieldTarget();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQNearFieldTarget(const sipQNearFieldTarget &);
    sipQNearFieldTarget &operator = (const sipQNearFieldTarget &);

    char sipPyMethods[7];
};

sipQNearFieldTarget::sipQNearFieldTarget(::QObject*a0): ::QNearFieldTarget(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQNearFieldTarget::~sipQNearFieldTarget()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQNearFieldTarget::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtNfc_qt_metaobject(sipPySelf, sipType_QNearFieldTarget);

    return ::QNearFieldTarget::metaObject();
}

int sipQNearFieldTarget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QNearFieldTarget::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtNfc_qt_metacall(sipPySelf, sipType_QNearFieldTarget, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQNearFieldTarget::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtNfc_qt_metacast(sipPySelf, sipType_QNearFieldTarget, _clname, &sipCpp) ? sipCpp : ::QNearFieldTarget::qt_metacast(_clname));
}

bool sipQNearFieldTarget::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QNearFieldTarget::event(a0);

    extern bool sipVH_QtNfc_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtNfc_5(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQNearFieldTarget::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QNearFieldTarget::eventFilter(a0, a1);

    extern bool sipVH_QtNfc_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtNfc_4(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQNearFieldTarget::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QNearFieldTarget::timerEvent(a0);
        return;
    }

    extern void sipVH_QtNfc_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtNfc_3(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNearFieldTarget::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QNearFieldTarget::childEvent(a0);
        return;
    }

    extern void sipVH_QtNfc_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtNfc_2(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNearFieldTarget::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QNearFieldTarget::customEvent(a0);
        return;
    }

    extern void sipVH_QtNfc_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtNfc_1(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNearFieldTarget::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QNearFieldTarget::connectNotify(a0);
        return;
    }

    extern void sipVH_QtNfc_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNfc_0(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNearFieldTarget::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QNearFieldTarget::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtNfc_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNfc_0(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QNearFieldTarget_uid, "uid(self) -> QByteArray");

extern "C" {static PyObject *meth_QNearFieldTarget_uid(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldTarget_uid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNearFieldTarget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNearFieldTarget, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->uid());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldTarget, sipName_uid, doc_QNearFieldTarget_uid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldTarget_type, "type(self) -> QNearFieldTarget.Type");

extern "C" {static PyObject *meth_QNearFieldTarget_type(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldTarget_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNearFieldTarget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNearFieldTarget, &sipCpp))
        {
            ::QNearFieldTarget::Type sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QNearFieldTarget_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldTarget, sipName_type, doc_QNearFieldTarget_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldTarget_accessMethods, "accessMethods(self) -> QNearFieldTarget.AccessMethod");

extern "C" {static PyObject *meth_QNearFieldTarget_accessMethods(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldTarget_accessMethods(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNearFieldTarget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNearFieldTarget, &sipCpp))
        {
            ::QNearFieldTarget::AccessMethods*sipRes;

            sipRes = new ::QNearFieldTarget::AccessMethods(sipCpp->accessMethods());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QNearFieldTarget_AccessMethod, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldTarget, sipName_accessMethods, doc_QNearFieldTarget_accessMethods);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldTarget_hasNdefMessage, "hasNdefMessage(self) -> bool");

extern "C" {static PyObject *meth_QNearFieldTarget_hasNdefMessage(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldTarget_hasNdefMessage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNearFieldTarget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNearFieldTarget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasNdefMessage();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldTarget, sipName_hasNdefMessage, doc_QNearFieldTarget_hasNdefMessage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldTarget_readNdefMessages, "readNdefMessages(self) -> QNearFieldTarget.RequestId");

extern "C" {static PyObject *meth_QNearFieldTarget_readNdefMessages(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldTarget_readNdefMessages(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNearFieldTarget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNearFieldTarget, &sipCpp))
        {
            ::QNearFieldTarget::RequestId*sipRes;

            sipRes = new ::QNearFieldTarget::RequestId(sipCpp->readNdefMessages());

            return sipConvertFromNewType(sipRes, sipType_QNearFieldTarget_RequestId, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldTarget, sipName_readNdefMessages, doc_QNearFieldTarget_readNdefMessages);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldTarget_writeNdefMessages, "writeNdefMessages(self, messages: Iterable[QNdefMessage]) -> QNearFieldTarget.RequestId");

extern "C" {static PyObject *meth_QNearFieldTarget_writeNdefMessages(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldTarget_writeNdefMessages(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QNdefMessage>* a0;
        int a0State = 0;
        ::QNearFieldTarget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNearFieldTarget, &sipCpp, sipType_QList_0100QNdefMessage, &a0, &a0State))
        {
            ::QNearFieldTarget::RequestId*sipRes;

            sipRes = new ::QNearFieldTarget::RequestId(sipCpp->writeNdefMessages(*a0));
            sipReleaseType(const_cast<QList< ::QNdefMessage> *>(a0), sipType_QList_0100QNdefMessage, a0State);

            return sipConvertFromNewType(sipRes, sipType_QNearFieldTarget_RequestId, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldTarget, sipName_writeNdefMessages, doc_QNearFieldTarget_writeNdefMessages);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldTarget_sendCommand, "sendCommand(self, command: QByteArray|bytes|bytearray|memoryview) -> QNearFieldTarget.RequestId");

extern "C" {static PyObject *meth_QNearFieldTarget_sendCommand(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldTarget_sendCommand(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QNearFieldTarget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNearFieldTarget, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            ::QNearFieldTarget::RequestId*sipRes;

            sipRes = new ::QNearFieldTarget::RequestId(sipCpp->sendCommand(*a0));
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            return sipConvertFromNewType(sipRes, sipType_QNearFieldTarget_RequestId, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldTarget, sipName_sendCommand, doc_QNearFieldTarget_sendCommand);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldTarget_waitForRequestCompleted, "waitForRequestCompleted(self, id: QNearFieldTarget.RequestId, msecs: int = 5000) -> bool");

extern "C" {static PyObject *meth_QNearFieldTarget_waitForRequestCompleted(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QNearFieldTarget_waitForRequestCompleted(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNearFieldTarget::RequestId* a0;
        int a1 = 5000;
        ::QNearFieldTarget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|i", &sipSelf, sipType_QNearFieldTarget, &sipCpp, sipType_QNearFieldTarget_RequestId, &a0, &a1))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->waitForRequestCompleted(*a0, a1);
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldTarget, sipName_waitForRequestCompleted, doc_QNearFieldTarget_waitForRequestCompleted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldTarget_requestResponse, "requestResponse(self, id: QNearFieldTarget.RequestId) -> Any");

extern "C" {static PyObject *meth_QNearFieldTarget_requestResponse(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldTarget_requestResponse(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNearFieldTarget::RequestId* a0;
        const ::QNearFieldTarget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QNearFieldTarget, &sipCpp, sipType_QNearFieldTarget_RequestId, &a0))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->requestResponse(*a0));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldTarget, sipName_requestResponse, doc_QNearFieldTarget_requestResponse);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldTarget_disconnect, "disconnect(self) -> bool");

extern "C" {static PyObject *meth_QNearFieldTarget_disconnect(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldTarget_disconnect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNearFieldTarget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNearFieldTarget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->disconnect();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldTarget, sipName_disconnect, doc_QNearFieldTarget_disconnect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldTarget_maxCommandLength, "maxCommandLength(self) -> int");

extern "C" {static PyObject *meth_QNearFieldTarget_maxCommandLength(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldTarget_maxCommandLength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNearFieldTarget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNearFieldTarget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxCommandLength();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldTarget, sipName_maxCommandLength, doc_QNearFieldTarget_maxCommandLength);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QNearFieldTarget(void *, const sipTypeDef *);}
static void *cast_QNearFieldTarget(void *sipCppV, const sipTypeDef *targetType)
{
    ::QNearFieldTarget *sipCpp = reinterpret_cast< ::QNearFieldTarget *>(sipCppV);

    if (targetType == sipType_QNearFieldTarget)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNearFieldTarget(void *, int);}
static void release_QNearFieldTarget(void *sipCppV, int)
{
    ::QNearFieldTarget *sipCpp = reinterpret_cast< ::QNearFieldTarget *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QNearFieldTarget(Py_ssize_t);}
static void *array_QNearFieldTarget(Py_ssize_t sipNrElem)
{
    return new ::QNearFieldTarget[sipNrElem];
}


extern "C" {static void array_delete_QNearFieldTarget(void *);}
static void array_delete_QNearFieldTarget(void *sipCpp)
{
    delete[] reinterpret_cast< ::QNearFieldTarget *>(sipCpp);
}


extern "C" {static void dealloc_QNearFieldTarget(sipSimpleWrapper *);}
static void dealloc_QNearFieldTarget(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQNearFieldTarget *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNearFieldTarget(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QNearFieldTarget(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QNearFieldTarget(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQNearFieldTarget *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQNearFieldTarget(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QNearFieldTarget[] = {{4, 0, 1}};


static PyMethodDef methods_QNearFieldTarget[] = {
    {sipName_accessMethods, meth_QNearFieldTarget_accessMethods, METH_VARARGS, doc_QNearFieldTarget_accessMethods},
    {sipName_disconnect, meth_QNearFieldTarget_disconnect, METH_VARARGS, doc_QNearFieldTarget_disconnect},
    {sipName_hasNdefMessage, meth_QNearFieldTarget_hasNdefMessage, METH_VARARGS, doc_QNearFieldTarget_hasNdefMessage},
    {sipName_maxCommandLength, meth_QNearFieldTarget_maxCommandLength, METH_VARARGS, doc_QNearFieldTarget_maxCommandLength},
    {sipName_readNdefMessages, meth_QNearFieldTarget_readNdefMessages, METH_VARARGS, doc_QNearFieldTarget_readNdefMessages},
    {sipName_requestResponse, meth_QNearFieldTarget_requestResponse, METH_VARARGS, doc_QNearFieldTarget_requestResponse},
    {sipName_sendCommand, meth_QNearFieldTarget_sendCommand, METH_VARARGS, doc_QNearFieldTarget_sendCommand},
    {sipName_type, meth_QNearFieldTarget_type, METH_VARARGS, doc_QNearFieldTarget_type},
    {sipName_uid, meth_QNearFieldTarget_uid, METH_VARARGS, doc_QNearFieldTarget_uid},
    {sipName_waitForRequestCompleted, SIP_MLMETH_CAST(meth_QNearFieldTarget_waitForRequestCompleted), METH_VARARGS|METH_KEYWORDS, doc_QNearFieldTarget_waitForRequestCompleted},
    {sipName_writeNdefMessages, meth_QNearFieldTarget_writeNdefMessages, METH_VARARGS, doc_QNearFieldTarget_writeNdefMessages}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QNearFieldTarget[] = {
    {sipName_UnknownAccess, static_cast<int>(::QNearFieldTarget::UnknownAccess)},
    {sipName_NdefAccess, static_cast<int>(::QNearFieldTarget::NdefAccess)},
    {sipName_TagTypeSpecificAccess, static_cast<int>(::QNearFieldTarget::TagTypeSpecificAccess)},
    {sipName_AnyAccess, static_cast<int>(::QNearFieldTarget::AnyAccess)},
    {sipName_NoError, static_cast<int>(::QNearFieldTarget::NoError)},
    {sipName_UnknownError, static_cast<int>(::QNearFieldTarget::UnknownError)},
    {sipName_UnsupportedError, static_cast<int>(::QNearFieldTarget::UnsupportedError)},
    {sipName_TargetOutOfRangeError, static_cast<int>(::QNearFieldTarget::TargetOutOfRangeError)},
    {sipName_NoResponseError, static_cast<int>(::QNearFieldTarget::NoResponseError)},
    {sipName_ChecksumMismatchError, static_cast<int>(::QNearFieldTarget::ChecksumMismatchError)},
    {sipName_InvalidParametersError, static_cast<int>(::QNearFieldTarget::InvalidParametersError)},
    {sipName_NdefReadError, static_cast<int>(::QNearFieldTarget::NdefReadError)},
    {sipName_NdefWriteError, static_cast<int>(::QNearFieldTarget::NdefWriteError)},
    {sipName_CommandError, static_cast<int>(::QNearFieldTarget::CommandError)},
    {sipName_ConnectionError, static_cast<int>(::QNearFieldTarget::ConnectionError)},
    {sipName_TimeoutError, static_cast<int>(::QNearFieldTarget::TimeoutError)},
    {sipName_UnsupportedTargetError, static_cast<int>(::QNearFieldTarget::UnsupportedTargetError)},
    {sipName_ProprietaryTag, static_cast<int>(::QNearFieldTarget::ProprietaryTag)},
    {sipName_NfcTagType1, static_cast<int>(::QNearFieldTarget::NfcTagType1)},
    {sipName_NfcTagType2, static_cast<int>(::QNearFieldTarget::NfcTagType2)},
    {sipName_NfcTagType3, static_cast<int>(::QNearFieldTarget::NfcTagType3)},
    {sipName_NfcTagType4, static_cast<int>(::QNearFieldTarget::NfcTagType4)},
    {sipName_NfcTagType4A, static_cast<int>(::QNearFieldTarget::NfcTagType4A)},
    {sipName_NfcTagType4B, static_cast<int>(::QNearFieldTarget::NfcTagType4B)},
    {sipName_MifareTag, static_cast<int>(::QNearFieldTarget::MifareTag)},
    {0, 0}
};

PyDoc_STRVAR(doc_QNearFieldTarget, "\1QNearFieldTarget(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QNearFieldTarget[] = {
    {"error(QNearFieldTarget::Error,QNearFieldTarget::RequestId)", "\1error(self, error: QNearFieldTarget.Error, id: QNearFieldTarget.RequestId)", SIP_NULLPTR, SIP_NULLPTR},
    {"requestCompleted(QNearFieldTarget::RequestId)", "\1requestCompleted(self, id: QNearFieldTarget.RequestId)", SIP_NULLPTR, SIP_NULLPTR},
    {"ndefMessageRead(QNdefMessage)", "\1ndefMessageRead(self, message: QNdefMessage)", SIP_NULLPTR, SIP_NULLPTR},
    {"disconnected()", "\1disconnected(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QNearFieldTarget = {
    &::QNearFieldTarget::staticMetaObject,
    signals_QNearFieldTarget,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNfc_QNearFieldTarget = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNearFieldTarget,
        SIP_NULLPTR,
        &plugin_QNearFieldTarget,
    },
    {
        sipNameNr_QNearFieldTarget,
        {0, 0, 1},
        11, methods_QNearFieldTarget,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QNearFieldTarget, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QNearFieldTarget,
    -1,
    -1,
    supers_QNearFieldTarget,
    SIP_NULLPTR,
    init_type_QNearFieldTarget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QNearFieldTarget,
    SIP_NULLPTR,
    array_QNearFieldTarget,
    SIP_NULLPTR,
    release_QNearFieldTarget,
    cast_QNearFieldTarget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QNearFieldTarget,
    sizeof (::QNearFieldTarget),
};
