/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpdfoutputintent.sip"
#include <qpdfoutputintent.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfOutputIntent.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolorspace.sip"
#include <qcolorspace.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfOutputIntent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfOutputIntent.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfOutputIntent.cpp"


PyDoc_STRVAR(doc_QPdfOutputIntent_swap, "swap(self, other: QPdfOutputIntent)");

extern "C" {static PyObject *meth_QPdfOutputIntent_swap(PyObject *, PyObject *);}
static PyObject *meth_QPdfOutputIntent_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfOutputIntent* a0;
        ::QPdfOutputIntent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPdfOutputIntent, &sipCpp, sipType_QPdfOutputIntent, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfOutputIntent, sipName_swap, doc_QPdfOutputIntent_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfOutputIntent_outputConditionIdentifier, "outputConditionIdentifier(self) -> str");

extern "C" {static PyObject *meth_QPdfOutputIntent_outputConditionIdentifier(PyObject *, PyObject *);}
static PyObject *meth_QPdfOutputIntent_outputConditionIdentifier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfOutputIntent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfOutputIntent, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->outputConditionIdentifier());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfOutputIntent, sipName_outputConditionIdentifier, doc_QPdfOutputIntent_outputConditionIdentifier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfOutputIntent_setOutputConditionIdentifier, "setOutputConditionIdentifier(self, identifier: str|None)");

extern "C" {static PyObject *meth_QPdfOutputIntent_setOutputConditionIdentifier(PyObject *, PyObject *);}
static PyObject *meth_QPdfOutputIntent_setOutputConditionIdentifier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPdfOutputIntent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPdfOutputIntent, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setOutputConditionIdentifier(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfOutputIntent, sipName_setOutputConditionIdentifier, doc_QPdfOutputIntent_setOutputConditionIdentifier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfOutputIntent_outputCondition, "outputCondition(self) -> str");

extern "C" {static PyObject *meth_QPdfOutputIntent_outputCondition(PyObject *, PyObject *);}
static PyObject *meth_QPdfOutputIntent_outputCondition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfOutputIntent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfOutputIntent, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->outputCondition());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfOutputIntent, sipName_outputCondition, doc_QPdfOutputIntent_outputCondition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfOutputIntent_setOutputCondition, "setOutputCondition(self, condition: str|None)");

extern "C" {static PyObject *meth_QPdfOutputIntent_setOutputCondition(PyObject *, PyObject *);}
static PyObject *meth_QPdfOutputIntent_setOutputCondition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPdfOutputIntent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPdfOutputIntent, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setOutputCondition(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfOutputIntent, sipName_setOutputCondition, doc_QPdfOutputIntent_setOutputCondition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfOutputIntent_registryName, "registryName(self) -> QUrl");

extern "C" {static PyObject *meth_QPdfOutputIntent_registryName(PyObject *, PyObject *);}
static PyObject *meth_QPdfOutputIntent_registryName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfOutputIntent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfOutputIntent, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->registryName());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfOutputIntent, sipName_registryName, doc_QPdfOutputIntent_registryName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfOutputIntent_setRegistryName, "setRegistryName(self, name: QUrl)");

extern "C" {static PyObject *meth_QPdfOutputIntent_setRegistryName(PyObject *, PyObject *);}
static PyObject *meth_QPdfOutputIntent_setRegistryName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QPdfOutputIntent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPdfOutputIntent, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setRegistryName(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfOutputIntent, sipName_setRegistryName, doc_QPdfOutputIntent_setRegistryName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfOutputIntent_outputProfile, "outputProfile(self) -> QColorSpace");

extern "C" {static PyObject *meth_QPdfOutputIntent_outputProfile(PyObject *, PyObject *);}
static PyObject *meth_QPdfOutputIntent_outputProfile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfOutputIntent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfOutputIntent, &sipCpp))
        {
            ::QColorSpace*sipRes;

            sipRes = new ::QColorSpace(sipCpp->outputProfile());

            return sipConvertFromNewType(sipRes, sipType_QColorSpace, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfOutputIntent, sipName_outputProfile, doc_QPdfOutputIntent_outputProfile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfOutputIntent_setOutputProfile, "setOutputProfile(self, profile: QColorSpace)");

extern "C" {static PyObject *meth_QPdfOutputIntent_setOutputProfile(PyObject *, PyObject *);}
static PyObject *meth_QPdfOutputIntent_setOutputProfile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColorSpace* a0;
        ::QPdfOutputIntent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPdfOutputIntent, &sipCpp, sipType_QColorSpace, &a0))
        {
            sipCpp->setOutputProfile(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfOutputIntent, sipName_setOutputProfile, doc_QPdfOutputIntent_setOutputProfile);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPdfOutputIntent(void *, int);}
static void release_QPdfOutputIntent(void *sipCppV, int)
{
    delete reinterpret_cast< ::QPdfOutputIntent *>(sipCppV);
}


extern "C" {static void *array_QPdfOutputIntent(Py_ssize_t);}
static void *array_QPdfOutputIntent(Py_ssize_t sipNrElem)
{
    return new ::QPdfOutputIntent[sipNrElem];
}


extern "C" {static void array_delete_QPdfOutputIntent(void *);}
static void array_delete_QPdfOutputIntent(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPdfOutputIntent *>(sipCpp);
}


extern "C" {static void assign_QPdfOutputIntent(void *, Py_ssize_t, void *);}
static void assign_QPdfOutputIntent(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPdfOutputIntent *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPdfOutputIntent *>(sipSrc);
}


extern "C" {static void *copy_QPdfOutputIntent(const void *, Py_ssize_t);}
static void *copy_QPdfOutputIntent(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPdfOutputIntent(reinterpret_cast<const ::QPdfOutputIntent *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPdfOutputIntent(sipSimpleWrapper *);}
static void dealloc_QPdfOutputIntent(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPdfOutputIntent(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QPdfOutputIntent(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPdfOutputIntent(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QPdfOutputIntent *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QPdfOutputIntent();

            return sipCpp;
        }
    }

    {
        const ::QPdfOutputIntent* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPdfOutputIntent, &a0))
        {
            sipCpp = new ::QPdfOutputIntent(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QPdfOutputIntent[] = {
    {sipName_outputCondition, meth_QPdfOutputIntent_outputCondition, METH_VARARGS, doc_QPdfOutputIntent_outputCondition},
    {sipName_outputConditionIdentifier, meth_QPdfOutputIntent_outputConditionIdentifier, METH_VARARGS, doc_QPdfOutputIntent_outputConditionIdentifier},
    {sipName_outputProfile, meth_QPdfOutputIntent_outputProfile, METH_VARARGS, doc_QPdfOutputIntent_outputProfile},
    {sipName_registryName, meth_QPdfOutputIntent_registryName, METH_VARARGS, doc_QPdfOutputIntent_registryName},
    {sipName_setOutputCondition, meth_QPdfOutputIntent_setOutputCondition, METH_VARARGS, doc_QPdfOutputIntent_setOutputCondition},
    {sipName_setOutputConditionIdentifier, meth_QPdfOutputIntent_setOutputConditionIdentifier, METH_VARARGS, doc_QPdfOutputIntent_setOutputConditionIdentifier},
    {sipName_setOutputProfile, meth_QPdfOutputIntent_setOutputProfile, METH_VARARGS, doc_QPdfOutputIntent_setOutputProfile},
    {sipName_setRegistryName, meth_QPdfOutputIntent_setRegistryName, METH_VARARGS, doc_QPdfOutputIntent_setRegistryName},
    {sipName_swap, meth_QPdfOutputIntent_swap, METH_VARARGS, doc_QPdfOutputIntent_swap}
};

PyDoc_STRVAR(doc_QPdfOutputIntent, "\1QPdfOutputIntent()\n"
"QPdfOutputIntent(other: QPdfOutputIntent)");


sipClassTypeDef sipTypeDef_QtGui_QPdfOutputIntent = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPdfOutputIntent,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QPdfOutputIntent,
        {0, 0, 1},
        9, methods_QPdfOutputIntent,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPdfOutputIntent,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QPdfOutputIntent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPdfOutputIntent,
    assign_QPdfOutputIntent,
    array_QPdfOutputIntent,
    copy_QPdfOutputIntent,
    release_QPdfOutputIntent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPdfOutputIntent,
    sizeof (::QPdfOutputIntent),
};
