/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 196 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpermissions.sip"
#include <qpermissions.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQCalendarPermission.cpp"



PyDoc_STRVAR(doc_QCalendarPermission_setAccessMode, "setAccessMode(self, mode: QCalendarPermission.AccessMode)");

extern "C" {static PyObject *meth_QCalendarPermission_setAccessMode(PyObject *, PyObject *);}
static PyObject *meth_QCalendarPermission_setAccessMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCalendarPermission::AccessMode a0;
        ::QCalendarPermission *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCalendarPermission, &sipCpp, sipType_QCalendarPermission_AccessMode, &a0))
        {
            sipCpp->setAccessMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarPermission, sipName_setAccessMode, doc_QCalendarPermission_setAccessMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCalendarPermission_accessMode, "accessMode(self) -> QCalendarPermission.AccessMode");

extern "C" {static PyObject *meth_QCalendarPermission_accessMode(PyObject *, PyObject *);}
static PyObject *meth_QCalendarPermission_accessMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCalendarPermission *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCalendarPermission, &sipCpp))
        {
            ::QCalendarPermission::AccessMode sipRes;

            sipRes = sipCpp->accessMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCalendarPermission_AccessMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCalendarPermission, sipName_accessMode, doc_QCalendarPermission_accessMode);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCalendarPermission(void *, int);}
static void release_QCalendarPermission(void *sipCppV, int)
{
    delete reinterpret_cast< ::QCalendarPermission *>(sipCppV);
}


extern "C" {static void *array_QCalendarPermission(Py_ssize_t);}
static void *array_QCalendarPermission(Py_ssize_t sipNrElem)
{
    return new ::QCalendarPermission[sipNrElem];
}


extern "C" {static void array_delete_QCalendarPermission(void *);}
static void array_delete_QCalendarPermission(void *sipCpp)
{
    delete[] reinterpret_cast< ::QCalendarPermission *>(sipCpp);
}


extern "C" {static void assign_QCalendarPermission(void *, Py_ssize_t, void *);}
static void assign_QCalendarPermission(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QCalendarPermission *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QCalendarPermission *>(sipSrc);
}


extern "C" {static void *copy_QCalendarPermission(const void *, Py_ssize_t);}
static void *copy_QCalendarPermission(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QCalendarPermission(reinterpret_cast<const ::QCalendarPermission *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QCalendarPermission(sipSimpleWrapper *);}
static void dealloc_QCalendarPermission(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCalendarPermission(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QCalendarPermission(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCalendarPermission(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QCalendarPermission *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QCalendarPermission();

            return sipCpp;
        }
    }

    {
        const ::QCalendarPermission* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QCalendarPermission, &a0))
        {
            sipCpp = new ::QCalendarPermission(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QCalendarPermission[] = {
    {sipName_accessMode, meth_QCalendarPermission_accessMode, METH_VARARGS, doc_QCalendarPermission_accessMode},
    {sipName_setAccessMode, meth_QCalendarPermission_setAccessMode, METH_VARARGS, doc_QCalendarPermission_setAccessMode}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QCalendarPermission[] = {
    {sipName_ReadOnly, static_cast<int>(::QCalendarPermission::ReadOnly)},
    {sipName_ReadWrite, static_cast<int>(::QCalendarPermission::ReadWrite)},
    {0, 0}
};

PyDoc_STRVAR(doc_QCalendarPermission, "\1QCalendarPermission()\n"
"QCalendarPermission(other: QCalendarPermission)");


sipClassTypeDef sipTypeDef_QtCore_QCalendarPermission = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCalendarPermission,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QCalendarPermission,
        {0, 0, 1},
        2, methods_QCalendarPermission,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QCalendarPermission, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCalendarPermission,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QCalendarPermission,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCalendarPermission,
    assign_QCalendarPermission,
    array_QCalendarPermission,
    copy_QCalendarPermission,
    release_QCalendarPermission,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QCalendarPermission,
    sizeof (::QCalendarPermission),
};
