/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolorspace.sip"
#include <qcolorspace.h>
#line 174 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolorspace.sip"
#include <qcolorspace.h>
#line 31 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQColorSpacePrimaryPoints.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolorspace.sip"
#include <qcolorspace.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQColorSpacePrimaryPoints.cpp"


PyDoc_STRVAR(doc_QColorSpace_PrimaryPoints_fromPrimaries, "fromPrimaries(primaries: QColorSpace.Primaries) -> QColorSpace.PrimaryPoints");

extern "C" {static PyObject *meth_QColorSpace_PrimaryPoints_fromPrimaries(PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_PrimaryPoints_fromPrimaries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColorSpace::Primaries a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QColorSpace_Primaries, &a0))
        {
            ::QColorSpace::PrimaryPoints*sipRes;

            sipRes = new ::QColorSpace::PrimaryPoints(::QColorSpace::PrimaryPoints::fromPrimaries(a0));

            return sipConvertFromNewType(sipRes, sipType_QColorSpace_PrimaryPoints, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_PrimaryPoints, sipName_fromPrimaries, doc_QColorSpace_PrimaryPoints_fromPrimaries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QColorSpace_PrimaryPoints_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QColorSpace_PrimaryPoints_isValid(PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_PrimaryPoints_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColorSpace::PrimaryPoints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QColorSpace_PrimaryPoints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_PrimaryPoints, sipName_isValid, doc_QColorSpace_PrimaryPoints_isValid);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QColorSpace_PrimaryPoints(void *, int);}
static void release_QColorSpace_PrimaryPoints(void *sipCppV, int)
{
    delete reinterpret_cast< ::QColorSpace::PrimaryPoints *>(sipCppV);
}


extern "C" {static void *array_QColorSpace_PrimaryPoints(Py_ssize_t);}
static void *array_QColorSpace_PrimaryPoints(Py_ssize_t sipNrElem)
{
    return new ::QColorSpace::PrimaryPoints[sipNrElem];
}


extern "C" {static void array_delete_QColorSpace_PrimaryPoints(void *);}
static void array_delete_QColorSpace_PrimaryPoints(void *sipCpp)
{
    delete[] reinterpret_cast< ::QColorSpace::PrimaryPoints *>(sipCpp);
}


extern "C" {static void assign_QColorSpace_PrimaryPoints(void *, Py_ssize_t, void *);}
static void assign_QColorSpace_PrimaryPoints(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QColorSpace::PrimaryPoints *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QColorSpace::PrimaryPoints *>(sipSrc);
}


extern "C" {static void *copy_QColorSpace_PrimaryPoints(const void *, Py_ssize_t);}
static void *copy_QColorSpace_PrimaryPoints(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QColorSpace::PrimaryPoints(reinterpret_cast<const ::QColorSpace::PrimaryPoints *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QColorSpace_PrimaryPoints(sipSimpleWrapper *);}
static void dealloc_QColorSpace_PrimaryPoints(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QColorSpace_PrimaryPoints(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QColorSpace_PrimaryPoints(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QColorSpace_PrimaryPoints(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QColorSpace::PrimaryPoints *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QColorSpace::PrimaryPoints();

            return sipCpp;
        }
    }

    {
        const ::QColorSpace::PrimaryPoints* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QColorSpace_PrimaryPoints, &a0))
        {
            sipCpp = new ::QColorSpace::PrimaryPoints(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QColorSpace_PrimaryPoints[] = {
    {sipName_fromPrimaries, meth_QColorSpace_PrimaryPoints_fromPrimaries, METH_VARARGS, doc_QColorSpace_PrimaryPoints_fromPrimaries},
    {sipName_isValid, meth_QColorSpace_PrimaryPoints_isValid, METH_VARARGS, doc_QColorSpace_PrimaryPoints_isValid}
};

PyDoc_STRVAR(doc_QColorSpace_PrimaryPoints, "\1QColorSpace.PrimaryPoints()\n"
"QColorSpace.PrimaryPoints(a0: QColorSpace.PrimaryPoints)");


sipClassTypeDef sipTypeDef_QtGui_QColorSpace_PrimaryPoints = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QColorSpace__PrimaryPoints,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_PrimaryPoints,
        {26, 255, 0},
        2, methods_QColorSpace_PrimaryPoints,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QColorSpace_PrimaryPoints,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QColorSpace_PrimaryPoints,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QColorSpace_PrimaryPoints,
    assign_QColorSpace_PrimaryPoints,
    array_QColorSpace_PrimaryPoints,
    copy_QColorSpace_PrimaryPoints,
    release_QColorSpace_PrimaryPoints,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QColorSpace_PrimaryPoints,
    sizeof (::QColorSpace::PrimaryPoints),
};
