/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDBus.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 32 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusargument.sip"
#include <qdbusargument.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusconnection.sip"
#include <qdbusconnection.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbuserror.sip"
#include <qdbuserror.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusextratypes.sip"
#include <qdbusextratypes.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 49 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusextratypes.sip"
#include <qdbusextratypes.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusextratypes.sip"
#include <qdbusextratypes.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusmessage.sip"
#include <qdbusmessage.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbuspendingcall.sip"
#include <qdbuspendingcall.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusservicewatcher.sip"
#include <qdbusservicewatcher.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusunixfiledescriptor.sip"
#include <qdbusunixfiledescriptor.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qpydbusreply.sip"
#include <qpydbusreply.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qpydbuspendingreply.sip"
#include <qpydbuspendingreply.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusconnectioninterface.sip"
#include <qdbusconnectioninterface.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusconnection.sip"
#include <qdbusconnection.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtDBus[] = {
    'Q', 'D', 'B', 'u', 's', 'R', 'e', 'p', 'l', 'y', '<', 'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'R', 'e', 'p', 'l', 'y', '>', 0,
    'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'R', 'e', 'p', 'l', 'y', 0,
    'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'Q', 'u', 'e', 'u', 'e', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', ':', ':', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'D', 'B', 'u', 's', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'W', 'a', 't', 'c', 'h', 'e', 'r', ':', ':', 'W', 'a', 't', 'c', 'h', 'M', 'o', 'd', 'e', 'F', 'l', 'a', 'g', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', ':', ':', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'O', 'p', 't', 'i', 'o', 'n', '>', 0,
    'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', ':', ':', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'Q', 'D', 'B', 'u', 's', 'R', 'e', 'p', 'l', 'y', '<', 'Q', 'M', 'a', 'p', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', ',', 'Q', 'V', 'a', 'r', 'i', 'a', 'n', 't', '>', ' ', '>', 0,
    'Q', 'D', 'B', 'u', 's', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'W', 'a', 't', 'c', 'h', 'e', 'r', ':', ':', 'W', 'a', 't', 'c', 'h', 'M', 'o', 'd', 'e', 'F', 'l', 'a', 'g', 0,
    's', 'e', 't', 'I', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'v', 'e', 'A', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'A', 'l', 'l', 'o', 'w', 'e', 'd', 0,
    'i', 's', 'I', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'v', 'e', 'A', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'A', 'l', 'l', 'o', 'w', 'e', 'd', 0,
    'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', ':', ':', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', ':', ':', 'U', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'N', 'o', 'n', 'S', 'c', 'r', 'i', 'p', 't', 'a', 'b', 'l', 'e', 'I', 'n', 'v', 'o', 'k', 'a', 'b', 'l', 'e', 's', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'N', 'o', 'n', 'S', 'c', 'r', 'i', 'p', 't', 'a', 'b', 'l', 'e', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'N', 'o', 'n', 'S', 'c', 'r', 'i', 'p', 't', 'a', 'b', 'l', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'N', 'o', 'n', 'S', 'c', 'r', 'i', 'p', 't', 'a', 'b', 'l', 'e', 'S', 'i', 'g', 'n', 'a', 'l', 's', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'S', 'c', 'r', 'i', 'p', 't', 'a', 'b', 'l', 'e', 'I', 'n', 'v', 'o', 'k', 'a', 'b', 'l', 'e', 's', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'S', 'c', 'r', 'i', 'p', 't', 'a', 'b', 'l', 'e', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 0,
    'Q', 'D', 'B', 'u', 's', 'M', 'e', 's', 's', 'a', 'g', 'e', ':', ':', 'M', 'e', 's', 's', 'a', 'g', 'e', 'T', 'y', 'p', 'e', 0,
    'U', 'n', 'i', 'x', 'F', 'i', 'l', 'e', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'o', 'r', 'P', 'a', 's', 's', 'i', 'n', 'g', 0,
    'a', 's', 'y', 'n', 'c', 'C', 'a', 'l', 'l', 'W', 'i', 't', 'h', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 'L', 'i', 's', 't', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'N', 'o', 'n', 'S', 'c', 'r', 'i', 'p', 't', 'a', 'b', 'l', 'e', 'S', 'l', 'o', 't', 's', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'S', 'c', 'r', 'i', 'p', 't', 'a', 'b', 'l', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', ':', ':', 'B', 'u', 's', 'T', 'y', 'p', 'e', 0,
    'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'S', 'c', 'r', 'i', 'p', 't', 'a', 'b', 'l', 'e', 'S', 'i', 'g', 'n', 'a', 'l', 's', 0,
    'P', 'y', 'Q', 't', '6', '.', 's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 'D', 'B', 'u', 's', 'P', 'e', 'n', 'd', 'i', 'n', 'g', 'C', 'a', 'l', 'l', 'W', 'a', 't', 'c', 'h', 'e', 'r', 0,
    'Q', 'D', 'B', 'u', 's', 'R', 'e', 'p', 'l', 'y', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', 'L', 'i', 's', 't', '>', 0,
    'Q', 'D', 'B', 'u', 's', 'U', 'n', 'i', 'x', 'F', 'i', 'l', 'e', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'o', 'r', 0,
    'a', 'c', 't', 'i', 'v', 'a', 't', 'a', 'b', 'l', 'e', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'N', 'a', 'm', 'e', 's', 0,
    'Q', 'D', 'B', 'u', 's', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'R', 'e', 'p', 'l', 'a', 'c', 'e', 'E', 'x', 'i', 's', 't', 'i', 'n', 'g', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'W', 'a', 't', 'c', 'h', 'F', 'o', 'r', 'U', 'n', 'r', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'a', 'l', 'l', 'W', 'i', 't', 'h', 'C', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'F', 'a', 'i', 'l', 'e', 'd', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 0,
    'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'e', 'd', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'N', 'a', 'm', 'e', 's', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'S', 'c', 'r', 'i', 'p', 't', 'a', 'b', 'l', 'e', 'S', 'l', 'o', 't', 's', 0,
    'Q', 'D', 'B', 'u', 's', 'E', 'r', 'r', 'o', 'r', ':', ':', 'E', 'r', 'r', 'o', 'r', 'T', 'y', 'p', 'e', 0,
    'D', 'o', 'n', 't', 'A', 'l', 'l', 'o', 'w', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', 0,
    'Q', 'D', 'B', 'u', 's', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 'd', 'a', 'p', 't', 'o', 'r', 0,
    'S', 'e', 'r', 'v', 'i', 'c', 'e', 'N', 'o', 't', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'e', 'd', 0,
    'W', 'a', 't', 'c', 'h', 'F', 'o', 'r', 'R', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'a', 'l', 'l', 'W', 'i', 't', 'h', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 'L', 'i', 's', 't', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'T', 'a', 'r', 'g', 'e', 't', 'e', 'd', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'W', 'a', 't', 'c', 'h', 'e', 'd', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'A', 'l', 'l', 'I', 'n', 'v', 'o', 'k', 'a', 'b', 'l', 'e', 's', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'A', 'l', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 0,
    'Q', 'D', 'B', 'u', 's', 'R', 'e', 'p', 'l', 'y', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', '>', 0,
    'Q', 'D', 'B', 'u', 's', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'W', 'a', 't', 'c', 'h', 'e', 'r', 0,
    'Q', 'P', 'y', 'D', 'B', 'u', 's', 'P', 'e', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'p', 'l', 'y', 0,
    'W', 'a', 't', 'c', 'h', 'F', 'o', 'r', 'O', 'w', 'n', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'i', 's', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'e', 'd', 0,
    's', 'e', 'r', 'v', 'i', 'c', 'e', 'O', 'w', 'n', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'r', 'v', 'i', 'c', 'e', 'U', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'e', 'd', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'R', 'e', 'l', 'a', 'y', 'S', 'i', 'g', 'n', 'a', 'l', 's', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'S', 't', 'a', 'r', 't', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'C', 'h', 'i', 'l', 'd', 'O', 'b', 'j', 'e', 'c', 't', 's', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'F', 'r', 'o', 'm', 'P', 'e', 'e', 'r', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'e', 'd', 'A', 't', 0,
    's', 'e', 'r', 'v', 'i', 'c', 'e', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 0,
    's', 'e', 't', 'W', 'a', 't', 'c', 'h', 'e', 'd', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 's', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'A', 'l', 'l', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'O', 'b', 'j', 'e', 'c', 't', 'P', 'a', 't', 'h', 0,
    'M', 'e', 't', 'h', 'o', 'd', 'C', 'a', 'l', 'l', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    'Q', 'D', 'B', 'u', 's', 'P', 'e', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'p', 'l', 'y', 0,
    'a', 'd', 'd', 'W', 'a', 't', 'c', 'h', 'e', 'd', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'F', 'r', 'o', 'm', 'B', 'u', 's', 0,
    'f', 'r', 'o', 'm', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'd', 'C', 'a', 'l', 'l', 0,
    's', 'e', 'r', 'v', 'i', 'c', 'e', 'R', 'e', 'g', 'i', 's', 't', 'e', 'r', 'e', 'd', 0,
    's', 'e', 't', 'F', 'i', 'l', 'e', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'o', 'r', 0,
    'u', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'D', 'o', 'n', 't', 'Q', 'u', 'e', 'u', 'e', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'A', 'l', 'l', 'S', 'i', 'g', 'n', 'a', 'l', 's', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'S', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 0,
    'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    'Q', 'D', 'B', 'u', 's', 'P', 'e', 'n', 'd', 'i', 'n', 'g', 'C', 'a', 'l', 'l', 0,
    'Q', 'D', 'B', 'u', 's', 'R', 'e', 'p', 'l', 'y', '<', 'b', 'o', 'o', 'l', '>', 0,
    'Q', 'D', 'B', 'u', 's', 'R', 'e', 'p', 'l', 'y', '<', 'u', 'i', 'n', 't', '>', 0,
    'Q', 'D', 'B', 'u', 's', 'R', 'e', 'p', 'l', 'y', '<', 'v', 'o', 'i', 'd', '>', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'a', 'u', 't', 'o', 'R', 'e', 'l', 'a', 'y', 'S', 'i', 'g', 'n', 'a', 'l', 's', 0,
    'a', 'u', 't', 'o', 'S', 't', 'a', 'r', 't', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'c', 'a', 'l', 'l', 'W', 'i', 't', 'h', 'C', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'E', 'r', 'r', 'o', 'r', 'R', 'e', 'p', 'l', 'y', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'M', 'e', 't', 'h', 'o', 'd', 'C', 'a', 'l', 'l', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'u', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'A', 'l', 'l', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'Q', 'D', 'B', 'u', 's', ':', ':', 'C', 'a', 'l', 'l', 'M', 'o', 'd', 'e', 0,
    'Q', 'D', 'B', 'u', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'D', 'B', 'u', 's', 'O', 'b', 'j', 'e', 'c', 't', 'P', 'a', 't', 'h', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'i', 's', 'R', 'e', 'p', 'l', 'y', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd', 0,
    's', 'e', 't', 'D', 'e', 'l', 'a', 'y', 'e', 'd', 'R', 'e', 'p', 'l', 'y', 0,
    'w', 'a', 'i', 't', 'F', 'o', 'r', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'w', 'a', 't', 'c', 'h', 'e', 'd', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 's', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'A', 'd', 'a', 'p', 't', 'o', 'r', 's', 0,
    'E', 'x', 'p', 'o', 'r', 't', 'A', 'l', 'l', 'S', 'l', 'o', 't', 's', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'L', 'i', 'm', 'i', 't', 's', 'E', 'x', 'c', 'e', 'e', 'd', 'e', 'd', 0,
    'Q', 'D', 'B', 'u', 's', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'D', 'B', 'u', 's', 'S', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 0,
    'S', 'e', 'r', 'v', 'i', 'c', 'e', 'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    'U', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'N', 'o', 'd', 'e', 0,
    'U', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'T', 'r', 'e', 'e', 0,
    'b', 'e', 'g', 'i', 'n', 'S', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 0,
    'f', 'i', 'l', 'e', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'o', 'r', 0,
    'i', 's', 'D', 'e', 'l', 'a', 'y', 'e', 'd', 'R', 'e', 'p', 'l', 'y', 0,
    'l', 'o', 'c', 'a', 'l', 'M', 'a', 'c', 'h', 'i', 'n', 'e', 'I', 'd', 0,
    'A', 'c', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', 'B', 'u', 's', 0,
    'I', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'E', 'r', 'r', 'o', 'r', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'M', 'e', 'm', 'b', 'e', 'r', 0,
    'Q', 'D', 'B', 'u', 's', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 0,
    'S', 'e', 'r', 'v', 'i', 'c', 'e', 'Q', 'u', 'e', 'u', 'e', 'd', 0,
    'S', 'i', 'g', 'n', 'a', 'l', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'b', 'e', 'g', 'i', 'n', 'M', 'a', 'p', 'E', 'n', 't', 'r', 'y', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'T', 'o', 'P', 'e', 'e', 'r', 0,
    's', 'e', 't', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'A', 'c', 'c', 'e', 's', 's', 'D', 'e', 'n', 'i', 'e', 'd', 0,
    'A', 'd', 'd', 'r', 'e', 's', 's', 'I', 'n', 'U', 's', 'e', 0,
    'B', 'l', 'o', 'c', 'k', 'W', 'i', 't', 'h', 'G', 'u', 'i', 0,
    'D', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 0,
    'E', 'r', 'r', 'o', 'r', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    'N', 'o', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'P', 'y', 'Q', 't', '6', '.', 'Q', 't', 'D', 'B', 'u', 's', 0,
    'Q', 'D', 'B', 'u', 's', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    'Q', 'D', 'B', 'u', 's', 'V', 'a', 'r', 'i', 'a', 'n', 't', 0,
    'Q', 'P', 'y', 'D', 'B', 'u', 's', 'R', 'e', 'p', 'l', 'y', 0,
    'R', 'e', 'p', 'l', 'y', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'T', 'o', 'B', 'u', 's', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'e', 'n', 'd', 'S', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 0,
    'e', 'r', 'r', 'o', 'r', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    's', 'e', 'r', 'v', 'i', 'c', 'e', 'O', 'w', 'n', 'e', 'r', 0,
    's', 'e', 't', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', 0,
    's', 'e', 't', 'S', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'W', 'a', 't', 'c', 'h', 'M', 'o', 'd', 'e', 0,
    's', 't', 'a', 'r', 't', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'A', 'r', 'g', 's', 0,
    'b', 'a', 's', 'e', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'R', 'e', 'p', 'l', 'y', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'n', 'd', 'M', 'a', 'p', 'E', 'n', 't', 'r', 'y', 0,
    'e', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'i', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 0,
    'i', 's', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'A', 'u', 't', 'o', 'D', 'e', 't', 'e', 'c', 't', 0,
    'B', 'a', 'd', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'Q', 'D', 'B', 'u', 's', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'D', 'B', 'u', 's', 'R', 'e', 'p', 'l', 'y', 0,
    'S', 'e', 's', 's', 'i', 'o', 'n', 'B', 'u', 's', 0,
    '_', '_', 'l', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    'a', 'r', 'g', 'u', 'm', 'e', 'n', 't', 'A', 't', 0,
    'b', 'e', 'g', 'i', 'n', 'A', 'r', 'r', 'a', 'y', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 0,
    'i', 's', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    's', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'i', 'd', 0,
    's', 'e', 'r', 'v', 'i', 'c', 'e', 'U', 'i', 'd', 0,
    's', 'e', 's', 's', 'i', 'o', 'n', 'B', 'u', 's', 0,
    's', 'e', 't', 'T', 'i', 'm', 'e', 'o', 'u', 't', 0,
    's', 'e', 't', 'V', 'a', 'r', 'i', 'a', 'n', 't', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'N', 'o', 'N', 'e', 't', 'w', 'o', 'r', 'k', 0,
    'S', 'y', 's', 't', 'e', 'm', 'B', 'u', 's', 0,
    'a', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', 0,
    'a', 's', 'y', 'n', 'c', 'C', 'a', 'l', 'l', 0,
    'e', 'r', 'r', 'o', 'r', 'N', 'a', 'm', 'e', 0,
    'f', 'r', 'o', 'm', 'E', 'r', 'r', 'o', 'r', 0,
    'i', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'l', 'a', 's', 't', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 0,
    's', 'y', 's', 't', 'e', 'm', 'B', 'u', 's', 0,
    'w', 'a', 't', 'c', 'h', 'M', 'o', 'd', 'e', 0,
    'N', 'o', 'M', 'e', 'm', 'o', 'r', 'y', 0,
    'N', 'o', 'S', 'e', 'r', 'v', 'e', 'r', 0,
    'T', 'i', 'm', 'e', 'd', 'O', 'u', 't', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    'b', 'e', 'g', 'i', 'n', 'M', 'a', 'p', 0,
    'e', 'n', 'd', 'A', 'r', 'r', 'a', 'y', 0,
    'f', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'N', 'o', 'B', 'l', 'o', 'c', 'k', 0,
    'N', 'o', 'E', 'r', 'r', 'o', 'r', 0,
    'N', 'o', 'R', 'e', 'p', 'l', 'y', 0,
    'i', 's', 'E', 'r', 'r', 'o', 'r', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'm', 'e', 's', 's', 'a', 'g', 'e', 0,
    'o', 'p', 't', 'i', 'o', 'n', 's', 0,
    'q', 'o', 'p', 't', 'i', 'o', 'n', 0,
    'r', 'o', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    's', 'e', 't', 'P', 'a', 't', 'h', 0,
    't', 'i', 'm', 'e', 'o', 'u', 't', 0,
    'v', 'a', 'r', 'i', 'a', 'n', 't', 0,
    'w', 'a', 't', 'c', 'h', 'e', 'r', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'g', 'e', '_', '_', 0,
    '_', '_', 'l', 't', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    'e', 'n', 'd', 'M', 'a', 'p', 0,
    'm', 'e', 'm', 'b', 'e', 'r', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'O', 't', 'h', 'e', 'r', 0,
    'Q', 'D', 'B', 'u', 's', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'r', 'e', 'p', 'l', 'y', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'c', 'a', 'l', 'l', 0,
    'm', 'o', 'd', 'e', 0,
    'n', 'a', 'm', 'e', 0,
    'p', 'a', 't', 'h', 0,
    's', 'e', 'n', 'd', 0,
    's', 'w', 'a', 'p', 0,
    't', 'y', 'p', 'e', 0,
    'a', 'd', 'd', 0,
};
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusabstractinterface.sip"
// Imports from QtCore.
pyqt6_qtdbus_from_qvariant_by_type_t pyqt6_qtdbus_from_qvariant_by_type;
pyqt6_qtdbus_get_pyqtslot_parts_t pyqt6_qtdbus_get_pyqtslot_parts;
#line 318 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"

bool sipVH_QtDBus_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtDBus_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtDBus_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtDBus_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtDBus_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtDBus_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QDBusAbstractInterface(void **);}
static const sipTypeDef *sipSubClass_QDBusAbstractInterface(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 56 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusabstractinterface.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QDBusPendingCallWatcher, &sipType_QDBusPendingCallWatcher, -1, 1},
        {sipName_QDBusAbstractAdaptor, &sipType_QDBusAbstractAdaptor, -1, 2},
        {sipName_QDBusAbstractInterface, &sipType_QDBusAbstractInterface, 4, 3},
        {sipName_QDBusServiceWatcher, &sipType_QDBusServiceWatcher, -1, -1},
        {sipName_QDBusConnectionInterface, &sipType_QDBusConnectionInterface, -1, 5},
        {sipName_QDBusInterface, &sipType_QDBusInterface, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 399 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"

    return sipType;
}
static sipEnumTypeDef enumTypes[] = {
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDBus__CallMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_CallMode, 0, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDBusConnection__BusType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_BusType, 5, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDBusConnection__ConnectionCapability, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_ConnectionCapability, 5, 1, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDBusConnection__RegisterOption, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_RegisterOption, 5, 18, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDBusConnection__UnregisterMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_UnregisterMode, 5, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDBusConnectionInterface__RegisterServiceReply, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_RegisterServiceReply, 10, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDBusConnectionInterface__ServiceQueueOptions, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ServiceQueueOptions, 10, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDBusConnectionInterface__ServiceReplacementOptions, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ServiceReplacementOptions, 10, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDBusError__ErrorType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ErrorType, 14, 28, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDBusMessage__MessageType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_MessageType, 17, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDBusServiceWatcher__WatchModeFlag, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_WatchModeFlag, 29, 3, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtDBus[] = {
    &sipTypeDef_QtDBus_QDBus.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtDBus_QDBusAbstractAdaptor.ctd_base,
    &sipTypeDef_QtDBus_QDBusAbstractInterface.ctd_base,
    &sipTypeDef_QtDBus_QDBusArgument.ctd_base,
    &sipTypeDef_QtDBus_QDBusConnection.ctd_base,
    &enumTypes[1].etd_base,
    &enumTypes[2].etd_base,
    &enumTypes[3].etd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtDBus_QDBusConnectionInterface.ctd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &enumTypes[7].etd_base,
    &sipTypeDef_QtDBus_QDBusError.ctd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtDBus_QDBusInterface.ctd_base,
    &sipTypeDef_QtDBus_QDBusMessage.ctd_base,
    &enumTypes[9].etd_base,
    &sipTypeDef_QtDBus_QDBusObjectPath.ctd_base,
    &sipTypeDef_QtDBus_QDBusPendingCall.ctd_base,
    &sipTypeDef_QtDBus_QDBusPendingCallWatcher.ctd_base,
    &sipTypeDef_QtDBus_QDBusReply_0100QDBusConnectionInterface_RegisterServiceReply.mtd_base,
    &sipTypeDef_QtDBus_QDBusReply_0600QMap_0100QString_0100QVariant.mtd_base,
    &sipTypeDef_QtDBus_QDBusReply_0100QString.mtd_base,
    &sipTypeDef_QtDBus_QDBusReply_0100QStringList.mtd_base,
    &sipTypeDef_QtDBus_QDBusReply_2600.mtd_base,
    &sipTypeDef_QtDBus_QDBusReply_1900.mtd_base,
    &sipTypeDef_QtDBus_QDBusReply_0400.mtd_base,
    &sipTypeDef_QtDBus_QDBusServiceWatcher.ctd_base,
    &enumTypes[10].etd_base,
    &sipTypeDef_QtDBus_QDBusSignature.ctd_base,
    &sipTypeDef_QtDBus_QDBusUnixFileDescriptor.ctd_base,
    &sipTypeDef_QtDBus_QDBusVariant.ctd_base,
    &sipTypeDef_QtDBus_QFlags_0100QDBusConnection_ConnectionCapability.mtd_base,
    &sipTypeDef_QtDBus_QFlags_0100QDBusConnection_RegisterOption.mtd_base,
    &sipTypeDef_QtDBus_QFlags_0100QDBusServiceWatcher_WatchModeFlag.mtd_base,
    &sipTypeDef_QtDBus_QPyDBusPendingReply.ctd_base,
    &sipTypeDef_QtDBus_QPyDBusReply.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"QDBusConnection::ConnectionCapabilities", "QFlags<QDBusConnection::ConnectionCapability>"},
    {"QDBusConnection::RegisterOptions", "QFlags<QDBusConnection::RegisterOption>"},
    {"QDBusServiceWatcher::WatchMode", "QFlags<QDBusServiceWatcher::WatchModeFlag>"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtDBus_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QEvent"},
    {"QList<QVariant>"},
    {"QMetaMethod"},
    {"QMetaType"},
    {"QObject"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QVariant"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtDBus_QtCore[] = {
    {"PyQt6"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt6.QtCore", sipImportedTypes_QtDBus_QtCore, sipImportedVirtErrorHandlers_QtDBus_QtCore, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QDBusAbstractInterface, {6, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtDBus = {
    SIP_NULLPTR,
    8,
    sipNameNr_PyQt6_QtDBus,
    0,
    sipStrings_QtDBus,
    importsTable,
    39,
    sipExportedTypes_QtDBus,
    SIP_NULLPTR,
    3,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtDBus;

sip_qt_metaobject_func sip_QtDBus_qt_metaobject;
sip_qt_metacall_func sip_QtDBus_qt_metacall;
sip_qt_metacast_func sip_QtDBus_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtDBus()
#else
PyMODINIT_FUNC PyInit_QtDBus()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt6.QtDBus",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt6.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt6.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtDBus = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt6.sip._C_API"));

    if (sipAPI_QtDBus == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtDBus, 13, 8, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtDBus_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtDBus_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtDBus_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtDBus_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtDBus, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }
    qMetaTypeId<::QDBusServiceWatcher::WatchModeFlag>();
    qMetaTypeId<::QDBusMessage::MessageType>();
    qMetaTypeId<::QDBusError::ErrorType>();
    qMetaTypeId<::QDBusConnectionInterface::RegisterServiceReply>();
    qMetaTypeId<::QDBusConnectionInterface::ServiceReplacementOptions>();
    qMetaTypeId<::QDBusConnectionInterface::ServiceQueueOptions>();
    qMetaTypeId<::QDBusConnection::ConnectionCapability>();
    qMetaTypeId<::QDBusConnection::UnregisterMode>();
    qMetaTypeId<::QDBusConnection::RegisterOption>();
    qMetaTypeId<::QDBusConnection::BusType>();
    qMetaTypeId<::QDBus::CallMode>();
    qMetaTypeId<QFlags< ::QDBusServiceWatcher::WatchModeFlag>>();
    qMetaTypeId<QFlags< ::QDBusConnection::RegisterOption>>();
    qMetaTypeId<QFlags< ::QDBusConnection::ConnectionCapability>>();
#line 224 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusabstractinterface.sip"
qpydbus_post_init();

// Imports from QtCore.
pyqt6_qtdbus_from_qvariant_by_type = (pyqt6_qtdbus_from_qvariant_by_type_t)sipImportSymbol("pyqt6_from_qvariant_by_type");
Q_ASSERT(pyqt6_qtdbus_from_qvariant_by_type);

pyqt6_qtdbus_get_pyqtslot_parts = (pyqt6_qtdbus_get_pyqtslot_parts_t)sipImportSymbol("pyqt6_get_pyqtslot_parts");
Q_ASSERT(pyqt6_qtdbus_get_pyqtslot_parts);
#line 649 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipQtDBuscmodule.cpp"

    return sipModule;
}
