/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQEvent.cpp"



class sipQEvent : public ::QEvent
{
public:
    sipQEvent(::QEvent::Type);
    virtual ~sipQEvent();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QEvent* clone() const SIP_OVERRIDE;
    void setAccepted(bool) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQEvent(const sipQEvent &);
    sipQEvent &operator = (const sipQEvent &);

    char sipPyMethods[2];
};

sipQEvent::sipQEvent(::QEvent::Type a0): ::QEvent(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQEvent::~sipQEvent()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

::QEvent* sipQEvent::clone() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_clone);

    if (!sipMeth)
        return ::QEvent::clone();

    extern ::QEvent* sipVH_QtCore_52(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_52(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

void sipQEvent::setAccepted(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_setAccepted);

    if (!sipMeth)
    {
        ::QEvent::setAccepted(a0);
        return;
    }

    extern void sipVH_QtCore_51(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtCore_51(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QEvent_type, "type(self) -> QEvent.Type");

extern "C" {static PyObject *meth_QEvent_type(PyObject *, PyObject *);}
static PyObject *meth_QEvent_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            ::QEvent::Type sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QEvent_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_type, doc_QEvent_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_spontaneous, "spontaneous(self) -> bool");

extern "C" {static PyObject *meth_QEvent_spontaneous(PyObject *, PyObject *);}
static PyObject *meth_QEvent_spontaneous(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->spontaneous();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_spontaneous, doc_QEvent_spontaneous);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_setAccepted, "setAccepted(self, accepted: bool)");

extern "C" {static PyObject *meth_QEvent_setAccepted(PyObject *, PyObject *);}
static PyObject *meth_QEvent_setAccepted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
        ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QEvent, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QEvent::setAccepted(a0) : sipCpp->setAccepted(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_setAccepted, doc_QEvent_setAccepted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_isAccepted, "isAccepted(self) -> bool");

extern "C" {static PyObject *meth_QEvent_isAccepted(PyObject *, PyObject *);}
static PyObject *meth_QEvent_isAccepted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAccepted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_isAccepted, doc_QEvent_isAccepted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_accept, "accept(self)");

extern "C" {static PyObject *meth_QEvent_accept(PyObject *, PyObject *);}
static PyObject *meth_QEvent_accept(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            sipCpp->accept();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_accept, doc_QEvent_accept);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_ignore, "ignore(self)");

extern "C" {static PyObject *meth_QEvent_ignore(PyObject *, PyObject *);}
static PyObject *meth_QEvent_ignore(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            sipCpp->ignore();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_ignore, doc_QEvent_ignore);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_registerEventType, "registerEventType(hint: int = -1) -> int");

extern "C" {static PyObject *meth_QEvent_registerEventType(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QEvent_registerEventType(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = -1;

        static const char *sipKwdList[] = {
            sipName_hint,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "C|i", &sipSelf, &a0))
        {
            int sipRes;

            sipRes = ::QEvent::registerEventType(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_registerEventType, doc_QEvent_registerEventType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_isInputEvent, "isInputEvent(self) -> bool");

extern "C" {static PyObject *meth_QEvent_isInputEvent(PyObject *, PyObject *);}
static PyObject *meth_QEvent_isInputEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isInputEvent();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_isInputEvent, doc_QEvent_isInputEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_isPointerEvent, "isPointerEvent(self) -> bool");

extern "C" {static PyObject *meth_QEvent_isPointerEvent(PyObject *, PyObject *);}
static PyObject *meth_QEvent_isPointerEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isPointerEvent();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_isPointerEvent, doc_QEvent_isPointerEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_isSinglePointEvent, "isSinglePointEvent(self) -> bool");

extern "C" {static PyObject *meth_QEvent_isSinglePointEvent(PyObject *, PyObject *);}
static PyObject *meth_QEvent_isSinglePointEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSinglePointEvent();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_isSinglePointEvent, doc_QEvent_isSinglePointEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_clone, "clone(self) -> QEvent|None");

extern "C" {static PyObject *meth_QEvent_clone(PyObject *, PyObject *);}
static PyObject *meth_QEvent_clone(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            ::QEvent*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QEvent::clone() : sipCpp->clone());

            return sipConvertFromType(sipRes, sipType_QEvent, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_clone, doc_QEvent_clone);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QEvent(void *, int);}
static void release_QEvent(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQEvent *>(sipCppV);
    else
        delete reinterpret_cast< ::QEvent *>(sipCppV);
}


extern "C" {static void dealloc_QEvent(sipSimpleWrapper *);}
static void dealloc_QEvent(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQEvent *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QEvent(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QEvent(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QEvent(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQEvent *sipCpp = SIP_NULLPTR;

    {
        ::QEvent::Type a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "E", sipType_QEvent_Type, &a0))
        {
            sipCpp = new sipQEvent(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "i", &a0))
        {
            if (sipDeprecated(sipName_QEvent, SIP_NULLPTR) < 0)
                return SIP_NULLPTR;

#line 230 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
        // This overload allows an int to be passed as is rather than being wrapped in
        // a QEvent.Type. This was usefull before enums supported missing members and
        // is now deprecated.
        
        sipCpp = new sipQEvent(static_cast<QEvent::Type>(a0));
#line 447 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQEvent.cpp"

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QEvent[] = {
    {sipName_accept, meth_QEvent_accept, METH_VARARGS, doc_QEvent_accept},
    {sipName_clone, meth_QEvent_clone, METH_VARARGS, doc_QEvent_clone},
    {sipName_ignore, meth_QEvent_ignore, METH_VARARGS, doc_QEvent_ignore},
    {sipName_isAccepted, meth_QEvent_isAccepted, METH_VARARGS, doc_QEvent_isAccepted},
    {sipName_isInputEvent, meth_QEvent_isInputEvent, METH_VARARGS, doc_QEvent_isInputEvent},
    {sipName_isPointerEvent, meth_QEvent_isPointerEvent, METH_VARARGS, doc_QEvent_isPointerEvent},
    {sipName_isSinglePointEvent, meth_QEvent_isSinglePointEvent, METH_VARARGS, doc_QEvent_isSinglePointEvent},
    {sipName_registerEventType, SIP_MLMETH_CAST(meth_QEvent_registerEventType), METH_VARARGS|METH_KEYWORDS, doc_QEvent_registerEventType},
    {sipName_setAccepted, meth_QEvent_setAccepted, METH_VARARGS, doc_QEvent_setAccepted},
    {sipName_spontaneous, meth_QEvent_spontaneous, METH_VARARGS, doc_QEvent_spontaneous},
    {sipName_type, meth_QEvent_type, METH_VARARGS, doc_QEvent_type}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QEvent[] = {
    {sipName_None_, static_cast<int>(::QEvent::None)},
    {sipName_Timer, static_cast<int>(::QEvent::Timer)},
    {sipName_MouseButtonPress, static_cast<int>(::QEvent::MouseButtonPress)},
    {sipName_MouseButtonRelease, static_cast<int>(::QEvent::MouseButtonRelease)},
    {sipName_MouseButtonDblClick, static_cast<int>(::QEvent::MouseButtonDblClick)},
    {sipName_MouseMove, static_cast<int>(::QEvent::MouseMove)},
    {sipName_KeyPress, static_cast<int>(::QEvent::KeyPress)},
    {sipName_KeyRelease, static_cast<int>(::QEvent::KeyRelease)},
    {sipName_FocusIn, static_cast<int>(::QEvent::FocusIn)},
    {sipName_FocusOut, static_cast<int>(::QEvent::FocusOut)},
    {sipName_Enter, static_cast<int>(::QEvent::Enter)},
    {sipName_Leave, static_cast<int>(::QEvent::Leave)},
    {sipName_Paint, static_cast<int>(::QEvent::Paint)},
    {sipName_Move, static_cast<int>(::QEvent::Move)},
    {sipName_Resize, static_cast<int>(::QEvent::Resize)},
    {sipName_Show, static_cast<int>(::QEvent::Show)},
    {sipName_Hide, static_cast<int>(::QEvent::Hide)},
    {sipName_Close, static_cast<int>(::QEvent::Close)},
    {sipName_Quit, static_cast<int>(::QEvent::Quit)},
    {sipName_ParentChange, static_cast<int>(::QEvent::ParentChange)},
    {sipName_ParentAboutToChange, static_cast<int>(::QEvent::ParentAboutToChange)},
    {sipName_ThreadChange, static_cast<int>(::QEvent::ThreadChange)},
    {sipName_WindowActivate, static_cast<int>(::QEvent::WindowActivate)},
    {sipName_WindowDeactivate, static_cast<int>(::QEvent::WindowDeactivate)},
    {sipName_ShowToParent, static_cast<int>(::QEvent::ShowToParent)},
    {sipName_HideToParent, static_cast<int>(::QEvent::HideToParent)},
    {sipName_Wheel, static_cast<int>(::QEvent::Wheel)},
    {sipName_WindowTitleChange, static_cast<int>(::QEvent::WindowTitleChange)},
    {sipName_WindowIconChange, static_cast<int>(::QEvent::WindowIconChange)},
    {sipName_ApplicationWindowIconChange, static_cast<int>(::QEvent::ApplicationWindowIconChange)},
    {sipName_ApplicationFontChange, static_cast<int>(::QEvent::ApplicationFontChange)},
    {sipName_ApplicationLayoutDirectionChange, static_cast<int>(::QEvent::ApplicationLayoutDirectionChange)},
    {sipName_ApplicationPaletteChange, static_cast<int>(::QEvent::ApplicationPaletteChange)},
    {sipName_PaletteChange, static_cast<int>(::QEvent::PaletteChange)},
    {sipName_Clipboard, static_cast<int>(::QEvent::Clipboard)},
    {sipName_MetaCall, static_cast<int>(::QEvent::MetaCall)},
    {sipName_SockAct, static_cast<int>(::QEvent::SockAct)},
    {sipName_WinEventAct, static_cast<int>(::QEvent::WinEventAct)},
    {sipName_DeferredDelete, static_cast<int>(::QEvent::DeferredDelete)},
    {sipName_DragEnter, static_cast<int>(::QEvent::DragEnter)},
    {sipName_DragMove, static_cast<int>(::QEvent::DragMove)},
    {sipName_DragLeave, static_cast<int>(::QEvent::DragLeave)},
    {sipName_Drop, static_cast<int>(::QEvent::Drop)},
    {sipName_ChildAdded, static_cast<int>(::QEvent::ChildAdded)},
    {sipName_ChildPolished, static_cast<int>(::QEvent::ChildPolished)},
    {sipName_ChildRemoved, static_cast<int>(::QEvent::ChildRemoved)},
    {sipName_PolishRequest, static_cast<int>(::QEvent::PolishRequest)},
    {sipName_Polish, static_cast<int>(::QEvent::Polish)},
    {sipName_LayoutRequest, static_cast<int>(::QEvent::LayoutRequest)},
    {sipName_UpdateRequest, static_cast<int>(::QEvent::UpdateRequest)},
    {sipName_UpdateLater, static_cast<int>(::QEvent::UpdateLater)},
    {sipName_ContextMenu, static_cast<int>(::QEvent::ContextMenu)},
    {sipName_InputMethod, static_cast<int>(::QEvent::InputMethod)},
    {sipName_TabletMove, static_cast<int>(::QEvent::TabletMove)},
    {sipName_LocaleChange, static_cast<int>(::QEvent::LocaleChange)},
    {sipName_LanguageChange, static_cast<int>(::QEvent::LanguageChange)},
    {sipName_LayoutDirectionChange, static_cast<int>(::QEvent::LayoutDirectionChange)},
    {sipName_TabletPress, static_cast<int>(::QEvent::TabletPress)},
    {sipName_TabletRelease, static_cast<int>(::QEvent::TabletRelease)},
    {sipName_OkRequest, static_cast<int>(::QEvent::OkRequest)},
    {sipName_IconDrag, static_cast<int>(::QEvent::IconDrag)},
    {sipName_FontChange, static_cast<int>(::QEvent::FontChange)},
    {sipName_EnabledChange, static_cast<int>(::QEvent::EnabledChange)},
    {sipName_ActivationChange, static_cast<int>(::QEvent::ActivationChange)},
    {sipName_StyleChange, static_cast<int>(::QEvent::StyleChange)},
    {sipName_IconTextChange, static_cast<int>(::QEvent::IconTextChange)},
    {sipName_ModifiedChange, static_cast<int>(::QEvent::ModifiedChange)},
    {sipName_MouseTrackingChange, static_cast<int>(::QEvent::MouseTrackingChange)},
    {sipName_WindowBlocked, static_cast<int>(::QEvent::WindowBlocked)},
    {sipName_WindowUnblocked, static_cast<int>(::QEvent::WindowUnblocked)},
    {sipName_WindowStateChange, static_cast<int>(::QEvent::WindowStateChange)},
    {sipName_ToolTip, static_cast<int>(::QEvent::ToolTip)},
    {sipName_WhatsThis, static_cast<int>(::QEvent::WhatsThis)},
    {sipName_StatusTip, static_cast<int>(::QEvent::StatusTip)},
    {sipName_ActionChanged, static_cast<int>(::QEvent::ActionChanged)},
    {sipName_ActionAdded, static_cast<int>(::QEvent::ActionAdded)},
    {sipName_ActionRemoved, static_cast<int>(::QEvent::ActionRemoved)},
    {sipName_FileOpen, static_cast<int>(::QEvent::FileOpen)},
    {sipName_Shortcut, static_cast<int>(::QEvent::Shortcut)},
    {sipName_ShortcutOverride, static_cast<int>(::QEvent::ShortcutOverride)},
    {sipName_WhatsThisClicked, static_cast<int>(::QEvent::WhatsThisClicked)},
    {sipName_ToolBarChange, static_cast<int>(::QEvent::ToolBarChange)},
    {sipName_ApplicationActivate, static_cast<int>(::QEvent::ApplicationActivate)},
    {sipName_ApplicationActivated, static_cast<int>(::QEvent::ApplicationActivated)},
    {sipName_ApplicationDeactivate, static_cast<int>(::QEvent::ApplicationDeactivate)},
    {sipName_ApplicationDeactivated, static_cast<int>(::QEvent::ApplicationDeactivated)},
    {sipName_QueryWhatsThis, static_cast<int>(::QEvent::QueryWhatsThis)},
    {sipName_EnterWhatsThisMode, static_cast<int>(::QEvent::EnterWhatsThisMode)},
    {sipName_LeaveWhatsThisMode, static_cast<int>(::QEvent::LeaveWhatsThisMode)},
    {sipName_ZOrderChange, static_cast<int>(::QEvent::ZOrderChange)},
    {sipName_HoverEnter, static_cast<int>(::QEvent::HoverEnter)},
    {sipName_HoverLeave, static_cast<int>(::QEvent::HoverLeave)},
    {sipName_HoverMove, static_cast<int>(::QEvent::HoverMove)},
    {sipName_GraphicsSceneMouseMove, static_cast<int>(::QEvent::GraphicsSceneMouseMove)},
    {sipName_GraphicsSceneMousePress, static_cast<int>(::QEvent::GraphicsSceneMousePress)},
    {sipName_GraphicsSceneMouseRelease, static_cast<int>(::QEvent::GraphicsSceneMouseRelease)},
    {sipName_GraphicsSceneMouseDoubleClick, static_cast<int>(::QEvent::GraphicsSceneMouseDoubleClick)},
    {sipName_GraphicsSceneContextMenu, static_cast<int>(::QEvent::GraphicsSceneContextMenu)},
    {sipName_GraphicsSceneHoverEnter, static_cast<int>(::QEvent::GraphicsSceneHoverEnter)},
    {sipName_GraphicsSceneHoverMove, static_cast<int>(::QEvent::GraphicsSceneHoverMove)},
    {sipName_GraphicsSceneHoverLeave, static_cast<int>(::QEvent::GraphicsSceneHoverLeave)},
    {sipName_GraphicsSceneHelp, static_cast<int>(::QEvent::GraphicsSceneHelp)},
    {sipName_GraphicsSceneDragEnter, static_cast<int>(::QEvent::GraphicsSceneDragEnter)},
    {sipName_GraphicsSceneDragMove, static_cast<int>(::QEvent::GraphicsSceneDragMove)},
    {sipName_GraphicsSceneDragLeave, static_cast<int>(::QEvent::GraphicsSceneDragLeave)},
    {sipName_GraphicsSceneDrop, static_cast<int>(::QEvent::GraphicsSceneDrop)},
    {sipName_GraphicsSceneWheel, static_cast<int>(::QEvent::GraphicsSceneWheel)},
    {sipName_GraphicsSceneResize, static_cast<int>(::QEvent::GraphicsSceneResize)},
    {sipName_GraphicsSceneMove, static_cast<int>(::QEvent::GraphicsSceneMove)},
    {sipName_KeyboardLayoutChange, static_cast<int>(::QEvent::KeyboardLayoutChange)},
    {sipName_DynamicPropertyChange, static_cast<int>(::QEvent::DynamicPropertyChange)},
    {sipName_TabletEnterProximity, static_cast<int>(::QEvent::TabletEnterProximity)},
    {sipName_TabletLeaveProximity, static_cast<int>(::QEvent::TabletLeaveProximity)},
    {sipName_NonClientAreaMouseMove, static_cast<int>(::QEvent::NonClientAreaMouseMove)},
    {sipName_NonClientAreaMouseButtonPress, static_cast<int>(::QEvent::NonClientAreaMouseButtonPress)},
    {sipName_NonClientAreaMouseButtonRelease, static_cast<int>(::QEvent::NonClientAreaMouseButtonRelease)},
    {sipName_NonClientAreaMouseButtonDblClick, static_cast<int>(::QEvent::NonClientAreaMouseButtonDblClick)},
    {sipName_MacSizeChange, static_cast<int>(::QEvent::MacSizeChange)},
    {sipName_ContentsRectChange, static_cast<int>(::QEvent::ContentsRectChange)},
    {sipName_CursorChange, static_cast<int>(::QEvent::CursorChange)},
    {sipName_ToolTipChange, static_cast<int>(::QEvent::ToolTipChange)},
    {sipName_GrabMouse, static_cast<int>(::QEvent::GrabMouse)},
    {sipName_UngrabMouse, static_cast<int>(::QEvent::UngrabMouse)},
    {sipName_GrabKeyboard, static_cast<int>(::QEvent::GrabKeyboard)},
    {sipName_UngrabKeyboard, static_cast<int>(::QEvent::UngrabKeyboard)},
    {sipName_StateMachineSignal, static_cast<int>(::QEvent::StateMachineSignal)},
    {sipName_StateMachineWrapped, static_cast<int>(::QEvent::StateMachineWrapped)},
    {sipName_TouchBegin, static_cast<int>(::QEvent::TouchBegin)},
    {sipName_TouchUpdate, static_cast<int>(::QEvent::TouchUpdate)},
    {sipName_TouchEnd, static_cast<int>(::QEvent::TouchEnd)},
    {sipName_NativeGesture, static_cast<int>(::QEvent::NativeGesture)},
    {sipName_RequestSoftwareInputPanel, static_cast<int>(::QEvent::RequestSoftwareInputPanel)},
    {sipName_CloseSoftwareInputPanel, static_cast<int>(::QEvent::CloseSoftwareInputPanel)},
    {sipName_WinIdChange, static_cast<int>(::QEvent::WinIdChange)},
    {sipName_Gesture, static_cast<int>(::QEvent::Gesture)},
    {sipName_GestureOverride, static_cast<int>(::QEvent::GestureOverride)},
    {sipName_FocusAboutToChange, static_cast<int>(::QEvent::FocusAboutToChange)},
    {sipName_ScrollPrepare, static_cast<int>(::QEvent::ScrollPrepare)},
    {sipName_Scroll, static_cast<int>(::QEvent::Scroll)},
    {sipName_Expose, static_cast<int>(::QEvent::Expose)},
    {sipName_InputMethodQuery, static_cast<int>(::QEvent::InputMethodQuery)},
    {sipName_OrientationChange, static_cast<int>(::QEvent::OrientationChange)},
    {sipName_TouchCancel, static_cast<int>(::QEvent::TouchCancel)},
    {sipName_PlatformPanel, static_cast<int>(::QEvent::PlatformPanel)},
    {sipName_ApplicationStateChange, static_cast<int>(::QEvent::ApplicationStateChange)},
    {sipName_ReadOnlyChange, static_cast<int>(::QEvent::ReadOnlyChange)},
    {sipName_PlatformSurface, static_cast<int>(::QEvent::PlatformSurface)},
    {sipName_TabletTrackingChange, static_cast<int>(::QEvent::TabletTrackingChange)},
    {sipName_GraphicsSceneLeave, static_cast<int>(::QEvent::GraphicsSceneLeave)},
    {sipName_EnterEditFocus, static_cast<int>(::QEvent::EnterEditFocus)},
    {sipName_LeaveEditFocus, static_cast<int>(::QEvent::LeaveEditFocus)},
    {sipName_DevicePixelRatioChange, static_cast<int>(::QEvent::DevicePixelRatioChange)},
    {sipName_ChildWindowAdded, static_cast<int>(::QEvent::ChildWindowAdded)},
    {sipName_ChildWindowRemoved, static_cast<int>(::QEvent::ChildWindowRemoved)},
    {sipName_ParentWindowAboutToChange, static_cast<int>(::QEvent::ParentWindowAboutToChange)},
    {sipName_ParentWindowChange, static_cast<int>(::QEvent::ParentWindowChange)},
    {sipName_SafeAreaMarginsChange, static_cast<int>(::QEvent::SafeAreaMarginsChange)},
    {sipName_User, static_cast<int>(::QEvent::User)},
    {sipName_MaxUser, static_cast<int>(::QEvent::MaxUser)},
    {0, 0}
};

PyDoc_STRVAR(doc_QEvent, "\1QEvent(type: QEvent.Type)\n"
"QEvent(type: int)");


sipClassTypeDef sipTypeDef_QtCore_QEvent = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QEvent,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QEvent,
        {0, 0, 1},
        11, methods_QEvent,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QEvent, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QEvent,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QEvent),
};
