/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtTest.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtTest/qtestkeyboard.sip"
#include <qtestkeyboard.h>
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtTest/qtestmouse.sip"
#include <qtestmouse.h>
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtTest/qtestsystem.sip"
#include <qtestsystem.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtTest/sipQtTestQTest.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 37 "/build/pyqt6/src/pyqt6-6.11.0/build/QtTest/sipQtTestQTest.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtTest/sipQtTestQTest.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtTest/sipQtTestQTest.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtTest/sipQtTestQTest.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtTest/sipQtTestQTest.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtTest/sipQtTestQTest.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtTest/sipQtTestQTest.cpp"


PyDoc_STRVAR(doc_QTest_qWaitForWindowExposed, "qWaitForWindowExposed(window: QWindow|None, timeout: int = 5000) -> bool\n"
"qWaitForWindowExposed(widget: QWidget|None, timeout: int = 5000) -> bool");

extern "C" {static PyObject *meth_QTest_qWaitForWindowExposed(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_qWaitForWindowExposed(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWindow* a0;
        int a1 = 5000;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_timeout,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8|i", sipType_QWindow, &a0, &a1))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = ::QTest::qWaitForWindowExposed(a0, a1);
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QWidget* a0;
        int a1 = 5000;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_timeout,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8|i", sipType_QWidget, &a0, &a1))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = ::QTest::qWaitForWindowExposed(a0, a1);
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qWaitForWindowExposed, doc_QTest_qWaitForWindowExposed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_qWaitForWindowActive, "qWaitForWindowActive(window: QWindow|None, timeout: int = 5000) -> bool\n"
"qWaitForWindowActive(widget: QWidget|None, timeout: int = 5000) -> bool");

extern "C" {static PyObject *meth_QTest_qWaitForWindowActive(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_qWaitForWindowActive(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWindow* a0;
        int a1 = 5000;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_timeout,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8|i", sipType_QWindow, &a0, &a1))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = ::QTest::qWaitForWindowActive(a0, a1);
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QWidget* a0;
        int a1 = 5000;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_timeout,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8|i", sipType_QWidget, &a0, &a1))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = ::QTest::qWaitForWindowActive(a0, a1);
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qWaitForWindowActive, doc_QTest_qWaitForWindowActive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_qWait, "qWait(ms: int)");

extern "C" {static PyObject *meth_QTest_qWait(PyObject *, PyObject *);}
static PyObject *meth_QTest_qWait(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            ::QTest::qWait(a0);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qWait, doc_QTest_qWait);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_mouseRelease, "mouseRelease(widget: QWidget|None, button: Qt.MouseButton, modifier: Qt.KeyboardModifier = Qt.KeyboardModifiers(), pos: QPoint = QPoint(), delay: int = -1)\n"
"mouseRelease(window: QWindow|None, button: Qt.MouseButton, modifier: Qt.KeyboardModifier = Qt.KeyboardModifiers(), pos: QPoint = QPoint(), delay: int = -1)");

extern "C" {static PyObject *meth_QTest_mouseRelease(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_mouseRelease(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::Qt::MouseButton a1;
        ::Qt::KeyboardModifiers a2def = Qt::KeyboardModifiers();
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        ::QPoint a3def = QPoint();
        ::QPoint* a3 = &a3def;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_pos,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1J9i", sipType_QWidget, &a0, sipType_Qt_MouseButton, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, sipType_QPoint, &a3, &a4))
        {
            ::QTest::mouseRelease(a0, a1, *a2, *a3, a4);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        ::Qt::MouseButton a1;
        ::Qt::KeyboardModifiers a2def = Qt::KeyboardModifiers();
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        ::QPoint a3def = QPoint();
        ::QPoint* a3 = &a3def;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_pos,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1J9i", sipType_QWindow, &a0, sipType_Qt_MouseButton, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, sipType_QPoint, &a3, &a4))
        {
            ::QTest::mouseRelease(a0, a1, *a2, *a3, a4);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_mouseRelease, doc_QTest_mouseRelease);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_mousePress, "mousePress(widget: QWidget|None, button: Qt.MouseButton, modifier: Qt.KeyboardModifier = Qt.KeyboardModifiers(), pos: QPoint = QPoint(), delay: int = -1)\n"
"mousePress(window: QWindow|None, button: Qt.MouseButton, modifier: Qt.KeyboardModifier = Qt.KeyboardModifiers(), pos: QPoint = QPoint(), delay: int = -1)");

extern "C" {static PyObject *meth_QTest_mousePress(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_mousePress(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::Qt::MouseButton a1;
        ::Qt::KeyboardModifiers a2def = Qt::KeyboardModifiers();
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        ::QPoint a3def = QPoint();
        ::QPoint* a3 = &a3def;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_pos,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1J9i", sipType_QWidget, &a0, sipType_Qt_MouseButton, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, sipType_QPoint, &a3, &a4))
        {
            ::QTest::mousePress(a0, a1, *a2, *a3, a4);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        ::Qt::MouseButton a1;
        ::Qt::KeyboardModifiers a2def = Qt::KeyboardModifiers();
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        ::QPoint a3def = QPoint();
        ::QPoint* a3 = &a3def;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_pos,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1J9i", sipType_QWindow, &a0, sipType_Qt_MouseButton, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, sipType_QPoint, &a3, &a4))
        {
            ::QTest::mousePress(a0, a1, *a2, *a3, a4);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_mousePress, doc_QTest_mousePress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_mouseMove, "mouseMove(widget: QWidget|None, pos: QPoint = QPoint(), delay: int = -1)\n"
"mouseMove(window: QWindow|None, pos: QPoint = QPoint(), delay: int = -1)");

extern "C" {static PyObject *meth_QTest_mouseMove(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_mouseMove(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::QPoint a1def = QPoint();
        ::QPoint* a1 = &a1def;
        int a2 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_pos,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8|J9i", sipType_QWidget, &a0, sipType_QPoint, &a1, &a2))
        {
            ::QTest::mouseMove(a0, *a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        ::QPoint a1def = QPoint();
        ::QPoint* a1 = &a1def;
        int a2 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_pos,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8|J9i", sipType_QWindow, &a0, sipType_QPoint, &a1, &a2))
        {
            ::QTest::mouseMove(a0, *a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_mouseMove, doc_QTest_mouseMove);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_mouseDClick, "mouseDClick(widget: QWidget|None, button: Qt.MouseButton, modifier: Qt.KeyboardModifier = Qt.KeyboardModifiers(), pos: QPoint = QPoint(), delay: int = -1)\n"
"mouseDClick(window: QWindow|None, button: Qt.MouseButton, modifier: Qt.KeyboardModifier = Qt.KeyboardModifiers(), pos: QPoint = QPoint(), delay: int = -1)");

extern "C" {static PyObject *meth_QTest_mouseDClick(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_mouseDClick(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::Qt::MouseButton a1;
        ::Qt::KeyboardModifiers a2def = Qt::KeyboardModifiers();
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        ::QPoint a3def = QPoint();
        ::QPoint* a3 = &a3def;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_pos,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1J9i", sipType_QWidget, &a0, sipType_Qt_MouseButton, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, sipType_QPoint, &a3, &a4))
        {
            ::QTest::mouseDClick(a0, a1, *a2, *a3, a4);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        ::Qt::MouseButton a1;
        ::Qt::KeyboardModifiers a2def = Qt::KeyboardModifiers();
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        ::QPoint a3def = QPoint();
        ::QPoint* a3 = &a3def;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_pos,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1J9i", sipType_QWindow, &a0, sipType_Qt_MouseButton, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, sipType_QPoint, &a3, &a4))
        {
            ::QTest::mouseDClick(a0, a1, *a2, *a3, a4);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_mouseDClick, doc_QTest_mouseDClick);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_mouseClick, "mouseClick(widget: QWidget|None, button: Qt.MouseButton, modifier: Qt.KeyboardModifier = Qt.KeyboardModifiers(), pos: QPoint = QPoint(), delay: int = -1)\n"
"mouseClick(window: QWindow|None, button: Qt.MouseButton, modifier: Qt.KeyboardModifier = Qt.KeyboardModifiers(), pos: QPoint = QPoint(), delay: int = -1)");

extern "C" {static PyObject *meth_QTest_mouseClick(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_mouseClick(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::Qt::MouseButton a1;
        ::Qt::KeyboardModifiers a2def = Qt::KeyboardModifiers();
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        ::QPoint a3def = QPoint();
        ::QPoint* a3 = &a3def;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_pos,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1J9i", sipType_QWidget, &a0, sipType_Qt_MouseButton, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, sipType_QPoint, &a3, &a4))
        {
            ::QTest::mouseClick(a0, a1, *a2, *a3, a4);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        ::Qt::MouseButton a1;
        ::Qt::KeyboardModifiers a2def = Qt::KeyboardModifiers();
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        ::QPoint a3def = QPoint();
        ::QPoint* a3 = &a3def;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_pos,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1J9i", sipType_QWindow, &a0, sipType_Qt_MouseButton, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, sipType_QPoint, &a3, &a4))
        {
            ::QTest::mouseClick(a0, a1, *a2, *a3, a4);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_mouseClick, doc_QTest_mouseClick);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_sendKeyEvent, "sendKeyEvent(action: QTest.KeyAction, widget: QWidget|None, code: Qt.Key, ascii: str, modifier: Qt.KeyboardModifier, delay: int = -1)\n"
"sendKeyEvent(action: QTest.KeyAction, widget: QWidget|None, code: Qt.Key, text: str|None, modifier: Qt.KeyboardModifier, delay: int = -1)");

extern "C" {static PyObject *meth_QTest_sendKeyEvent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_sendKeyEvent(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTest::KeyAction a0;
        ::QWidget* a1;
        ::Qt::Key a2;
        char a3;
        ::Qt::KeyboardModifiers* a4;
        int a4State = 0;
        int a5 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "EJ8EaAJ1|i", sipType_QTest_KeyAction, &a0, sipType_QWidget, &a1, sipType_Qt_Key, &a2, &a3, sipType_QFlags_0100Qt_KeyboardModifier, &a4, &a4State, &a5))
        {
            ::QTest::sendKeyEvent(a0, a1, a2, a3, *a4, a5);
            sipReleaseType(a4, sipType_QFlags_0100Qt_KeyboardModifier, a4State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QTest::KeyAction a0;
        ::QWidget* a1;
        ::Qt::Key a2;
        ::QString* a3;
        int a3State = 0;
        ::Qt::KeyboardModifiers* a4;
        int a4State = 0;
        int a5 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "EJ8EJ1J1|i", sipType_QTest_KeyAction, &a0, sipType_QWidget, &a1, sipType_Qt_Key, &a2, sipType_QString, &a3, &a3State, sipType_QFlags_0100Qt_KeyboardModifier, &a4, &a4State, &a5))
        {
            ::QTest::sendKeyEvent(a0, a1, a2, *a3, *a4, a5);
            sipReleaseType(a3, sipType_QString, a3State);
            sipReleaseType(a4, sipType_QFlags_0100Qt_KeyboardModifier, a4State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_sendKeyEvent, doc_QTest_sendKeyEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_simulateEvent, "simulateEvent(widget: QWidget|None, press: bool, code: int, modifier: Qt.KeyboardModifier, text: str|None, repeat: bool, delay: int = -1)");

extern "C" {static PyObject *meth_QTest_simulateEvent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_simulateEvent(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        bool a1;
        int a2;
        ::Qt::KeyboardModifiers* a3;
        int a3State = 0;
        ::QString* a4;
        int a4State = 0;
        bool a5;
        int a6 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8biJ1J1b|i", sipType_QWidget, &a0, &a1, &a2, sipType_QFlags_0100Qt_KeyboardModifier, &a3, &a3State, sipType_QString, &a4, &a4State, &a5, &a6))
        {
            ::QTest::simulateEvent(a0, a1, a2, *a3, *a4, a5, a6);
            sipReleaseType(a3, sipType_QFlags_0100Qt_KeyboardModifier, a3State);
            sipReleaseType(a4, sipType_QString, a4State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_simulateEvent, doc_QTest_simulateEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_keySequence, "keySequence(widget: QWidget|None, keySequence: QKeySequence|QKeySequence.StandardKey|str|None|int)\n"
"keySequence(window: QWindow|None, keySequence: QKeySequence|QKeySequence.StandardKey|str|None|int)");

extern "C" {static PyObject *meth_QTest_keySequence(PyObject *, PyObject *);}
static PyObject *meth_QTest_keySequence(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        const ::QKeySequence* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8J1", sipType_QWidget, &a0, sipType_QKeySequence, &a1, &a1State))
        {
            ::QTest::keySequence(a0, *a1);
            sipReleaseType(const_cast< ::QKeySequence *>(a1), sipType_QKeySequence, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        const ::QKeySequence* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8J1", sipType_QWindow, &a0, sipType_QKeySequence, &a1, &a1State))
        {
            ::QTest::keySequence(a0, *a1);
            sipReleaseType(const_cast< ::QKeySequence *>(a1), sipType_QKeySequence, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_keySequence, doc_QTest_keySequence);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_keyRelease, "keyRelease(widget: QWidget|None, key: Qt.Key, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyRelease(widget: QWidget|None, key: str, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyRelease(window: QWindow|None, key: Qt.Key, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyRelease(window: QWindow|None, key: str, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)");

extern "C" {static PyObject *meth_QTest_keyRelease(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_keyRelease(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::Qt::Key a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1i", sipType_QWidget, &a0, sipType_Qt_Key, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyRelease(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWidget* a0;
        char a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8aA|J1i", sipType_QWidget, &a0, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyRelease(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        ::Qt::Key a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1i", sipType_QWindow, &a0, sipType_Qt_Key, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyRelease(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        char a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8aA|J1i", sipType_QWindow, &a0, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyRelease(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_keyRelease, doc_QTest_keyRelease);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_keyPress, "keyPress(widget: QWidget|None, key: Qt.Key, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyPress(widget: QWidget|None, key: str, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyPress(window: QWindow|None, key: Qt.Key, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyPress(window: QWindow|None, key: str, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)");

extern "C" {static PyObject *meth_QTest_keyPress(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_keyPress(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::Qt::Key a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1i", sipType_QWidget, &a0, sipType_Qt_Key, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyPress(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWidget* a0;
        char a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8aA|J1i", sipType_QWidget, &a0, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyPress(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        ::Qt::Key a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1i", sipType_QWindow, &a0, sipType_Qt_Key, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyPress(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        char a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8aA|J1i", sipType_QWindow, &a0, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyPress(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_keyPress, doc_QTest_keyPress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_keyEvent, "keyEvent(action: QTest.KeyAction, widget: QWidget|None, key: Qt.Key, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyEvent(action: QTest.KeyAction, widget: QWidget|None, ascii: str, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyEvent(action: QTest.KeyAction, window: QWindow|None, key: Qt.Key, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyEvent(action: QTest.KeyAction, window: QWindow|None, ascii: str, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)");

extern "C" {static PyObject *meth_QTest_keyEvent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_keyEvent(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTest::KeyAction a0;
        ::QWidget* a1;
        ::Qt::Key a2;
        ::Qt::KeyboardModifiers a3def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a3 = &a3def;
        int a3State = 0;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "EJ8E|J1i", sipType_QTest_KeyAction, &a0, sipType_QWidget, &a1, sipType_Qt_Key, &a2, sipType_QFlags_0100Qt_KeyboardModifier, &a3, &a3State, &a4))
        {
            ::QTest::keyEvent(a0, a1, a2, *a3, a4);
            sipReleaseType(a3, sipType_QFlags_0100Qt_KeyboardModifier, a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QTest::KeyAction a0;
        ::QWidget* a1;
        char a2;
        ::Qt::KeyboardModifiers a3def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a3 = &a3def;
        int a3State = 0;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "EJ8aA|J1i", sipType_QTest_KeyAction, &a0, sipType_QWidget, &a1, &a2, sipType_QFlags_0100Qt_KeyboardModifier, &a3, &a3State, &a4))
        {
            ::QTest::keyEvent(a0, a1, a2, *a3, a4);
            sipReleaseType(a3, sipType_QFlags_0100Qt_KeyboardModifier, a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QTest::KeyAction a0;
        ::QWindow* a1;
        ::Qt::Key a2;
        ::Qt::KeyboardModifiers a3def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a3 = &a3def;
        int a3State = 0;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "EJ8E|J1i", sipType_QTest_KeyAction, &a0, sipType_QWindow, &a1, sipType_Qt_Key, &a2, sipType_QFlags_0100Qt_KeyboardModifier, &a3, &a3State, &a4))
        {
            ::QTest::keyEvent(a0, a1, a2, *a3, a4);
            sipReleaseType(a3, sipType_QFlags_0100Qt_KeyboardModifier, a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QTest::KeyAction a0;
        ::QWindow* a1;
        char a2;
        ::Qt::KeyboardModifiers a3def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a3 = &a3def;
        int a3State = 0;
        int a4 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "EJ8aA|J1i", sipType_QTest_KeyAction, &a0, sipType_QWindow, &a1, &a2, sipType_QFlags_0100Qt_KeyboardModifier, &a3, &a3State, &a4))
        {
            ::QTest::keyEvent(a0, a1, a2, *a3, a4);
            sipReleaseType(a3, sipType_QFlags_0100Qt_KeyboardModifier, a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_keyEvent, doc_QTest_keyEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_keyClicks, "keyClicks(widget: QWidget|None, sequence: str|None, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)");

extern "C" {static PyObject *meth_QTest_keyClicks(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_keyClicks(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        const ::QString* a1;
        int a1State = 0;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8J1|J1i", sipType_QWidget, &a0, sipType_QString, &a1, &a1State, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyClicks(a0, *a1, *a2, a3);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_keyClicks, doc_QTest_keyClicks);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTest_keyClick, "keyClick(widget: QWidget|None, key: Qt.Key, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyClick(widget: QWidget|None, key: str, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyClick(window: QWindow|None, key: Qt.Key, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)\n"
"keyClick(window: QWindow|None, key: str, modifier: Qt.KeyboardModifier = Qt.NoModifier, delay: int = -1)");

extern "C" {static PyObject *meth_QTest_keyClick(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTest_keyClick(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::Qt::Key a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1i", sipType_QWidget, &a0, sipType_Qt_Key, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyClick(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWidget* a0;
        char a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8aA|J1i", sipType_QWidget, &a0, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyClick(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        ::Qt::Key a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8E|J1i", sipType_QWindow, &a0, sipType_Qt_Key, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyClick(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QWindow* a0;
        char a1;
        ::Qt::KeyboardModifiers a2def = Qt::NoModifier;
        ::Qt::KeyboardModifiers* a2 = &a2def;
        int a2State = 0;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_modifier,
            sipName_delay,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8aA|J1i", sipType_QWindow, &a0, &a1, sipType_QFlags_0100Qt_KeyboardModifier, &a2, &a2State, &a3))
        {
            ::QTest::keyClick(a0, a1, *a2, a3);
            sipReleaseType(a2, sipType_QFlags_0100Qt_KeyboardModifier, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_keyClick, doc_QTest_keyClick);

    return SIP_NULLPTR;
}


static PyMethodDef methods_QTest[] = {
    {sipName_keyClick, SIP_MLMETH_CAST(meth_QTest_keyClick), METH_VARARGS|METH_KEYWORDS, doc_QTest_keyClick},
    {sipName_keyClicks, SIP_MLMETH_CAST(meth_QTest_keyClicks), METH_VARARGS|METH_KEYWORDS, doc_QTest_keyClicks},
    {sipName_keyEvent, SIP_MLMETH_CAST(meth_QTest_keyEvent), METH_VARARGS|METH_KEYWORDS, doc_QTest_keyEvent},
    {sipName_keyPress, SIP_MLMETH_CAST(meth_QTest_keyPress), METH_VARARGS|METH_KEYWORDS, doc_QTest_keyPress},
    {sipName_keyRelease, SIP_MLMETH_CAST(meth_QTest_keyRelease), METH_VARARGS|METH_KEYWORDS, doc_QTest_keyRelease},
    {sipName_keySequence, meth_QTest_keySequence, METH_VARARGS, doc_QTest_keySequence},
    {sipName_mouseClick, SIP_MLMETH_CAST(meth_QTest_mouseClick), METH_VARARGS|METH_KEYWORDS, doc_QTest_mouseClick},
    {sipName_mouseDClick, SIP_MLMETH_CAST(meth_QTest_mouseDClick), METH_VARARGS|METH_KEYWORDS, doc_QTest_mouseDClick},
    {sipName_mouseMove, SIP_MLMETH_CAST(meth_QTest_mouseMove), METH_VARARGS|METH_KEYWORDS, doc_QTest_mouseMove},
    {sipName_mousePress, SIP_MLMETH_CAST(meth_QTest_mousePress), METH_VARARGS|METH_KEYWORDS, doc_QTest_mousePress},
    {sipName_mouseRelease, SIP_MLMETH_CAST(meth_QTest_mouseRelease), METH_VARARGS|METH_KEYWORDS, doc_QTest_mouseRelease},
    {sipName_qWait, meth_QTest_qWait, METH_VARARGS, doc_QTest_qWait},
    {sipName_qWaitForWindowActive, SIP_MLMETH_CAST(meth_QTest_qWaitForWindowActive), METH_VARARGS|METH_KEYWORDS, doc_QTest_qWaitForWindowActive},
    {sipName_qWaitForWindowExposed, SIP_MLMETH_CAST(meth_QTest_qWaitForWindowExposed), METH_VARARGS|METH_KEYWORDS, doc_QTest_qWaitForWindowExposed},
    {sipName_sendKeyEvent, SIP_MLMETH_CAST(meth_QTest_sendKeyEvent), METH_VARARGS|METH_KEYWORDS, doc_QTest_sendKeyEvent},
    {sipName_simulateEvent, SIP_MLMETH_CAST(meth_QTest_simulateEvent), METH_VARARGS|METH_KEYWORDS, doc_QTest_simulateEvent}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QTest[] = {
    {sipName_Press, static_cast<int>(::QTest::Press)},
    {sipName_Release, static_cast<int>(::QTest::Release)},
    {sipName_Click, static_cast<int>(::QTest::Click)},
    {sipName_Shortcut, static_cast<int>(::QTest::Shortcut)},
    {0, 0}
};


sipClassTypeDef sipTypeDef_QtTest_QTest = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_NAMESPACE,
        sipNameNr_QTest,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QTest,
        {0, 0, 1},
        16, methods_QTest,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QTest, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
