/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiodevice.sip"
#include <qaudiodevice.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDevice.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudioformat.sip"
#include <qaudioformat.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDevice.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qpymultimedia_qlist.sip"
#include <qaudioformat.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDevice.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDevice.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDevice.cpp"


PyDoc_STRVAR(doc_QAudioDevice_swap, "swap(self, other: QAudioDevice)");

extern "C" {static PyObject *meth_QAudioDevice_swap(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioDevice* a0;
        ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioDevice, &sipCpp, sipType_QAudioDevice, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_swap, doc_QAudioDevice_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QAudioDevice_isNull(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_isNull, doc_QAudioDevice_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_id, "id(self) -> QByteArray");

extern "C" {static PyObject *meth_QAudioDevice_id(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_id(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->id());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_id, doc_QAudioDevice_id);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_description, "description(self) -> str");

extern "C" {static PyObject *meth_QAudioDevice_description(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_description(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->description());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_description, doc_QAudioDevice_description);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_isDefault, "isDefault(self) -> bool");

extern "C" {static PyObject *meth_QAudioDevice_isDefault(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_isDefault(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDefault();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_isDefault, doc_QAudioDevice_isDefault);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_mode, "mode(self) -> QAudioDevice.Mode");

extern "C" {static PyObject *meth_QAudioDevice_mode(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_mode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            ::QAudioDevice::Mode sipRes;

            sipRes = sipCpp->mode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAudioDevice_Mode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_mode, doc_QAudioDevice_mode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_isFormatSupported, "isFormatSupported(self, format: QAudioFormat) -> bool");

extern "C" {static PyObject *meth_QAudioDevice_isFormatSupported(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_isFormatSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioFormat* a0;
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioDevice, &sipCpp, sipType_QAudioFormat, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isFormatSupported(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_isFormatSupported, doc_QAudioDevice_isFormatSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_preferredFormat, "preferredFormat(self) -> QAudioFormat");

extern "C" {static PyObject *meth_QAudioDevice_preferredFormat(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_preferredFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            ::QAudioFormat*sipRes;

            sipRes = new ::QAudioFormat(sipCpp->preferredFormat());

            return sipConvertFromNewType(sipRes, sipType_QAudioFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_preferredFormat, doc_QAudioDevice_preferredFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_minimumSampleRate, "minimumSampleRate(self) -> int");

extern "C" {static PyObject *meth_QAudioDevice_minimumSampleRate(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_minimumSampleRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->minimumSampleRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_minimumSampleRate, doc_QAudioDevice_minimumSampleRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_maximumSampleRate, "maximumSampleRate(self) -> int");

extern "C" {static PyObject *meth_QAudioDevice_maximumSampleRate(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_maximumSampleRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maximumSampleRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_maximumSampleRate, doc_QAudioDevice_maximumSampleRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_minimumChannelCount, "minimumChannelCount(self) -> int");

extern "C" {static PyObject *meth_QAudioDevice_minimumChannelCount(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_minimumChannelCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->minimumChannelCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_minimumChannelCount, doc_QAudioDevice_minimumChannelCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_maximumChannelCount, "maximumChannelCount(self) -> int");

extern "C" {static PyObject *meth_QAudioDevice_maximumChannelCount(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_maximumChannelCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maximumChannelCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_maximumChannelCount, doc_QAudioDevice_maximumChannelCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_supportedSampleFormats, "supportedSampleFormats(self) -> list[QAudioFormat.SampleFormat]");

extern "C" {static PyObject *meth_QAudioDevice_supportedSampleFormats(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_supportedSampleFormats(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            ::QList< ::QAudioFormat::SampleFormat>*sipRes;

            sipRes = new ::QList< ::QAudioFormat::SampleFormat>(sipCpp->supportedSampleFormats());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QAudioFormat_SampleFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_supportedSampleFormats, doc_QAudioDevice_supportedSampleFormats);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDevice_channelConfiguration, "channelConfiguration(self) -> QAudioFormat.ChannelConfig");

extern "C" {static PyObject *meth_QAudioDevice_channelConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QAudioDevice_channelConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDevice, &sipCpp))
        {
            ::QAudioFormat::ChannelConfig sipRes;

            sipRes = sipCpp->channelConfiguration();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAudioFormat_ChannelConfig);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDevice, sipName_channelConfiguration, doc_QAudioDevice_channelConfiguration);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QAudioDevice___ne__(PyObject *, PyObject *);}
static PyObject *slot_QAudioDevice___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QAudioDevice *sipCpp = reinterpret_cast< ::QAudioDevice *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QAudioDevice));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QAudioDevice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QAudioDevice::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, ne_slot, sipType_QAudioDevice, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QAudioDevice___eq__(PyObject *, PyObject *);}
static PyObject *slot_QAudioDevice___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QAudioDevice *sipCpp = reinterpret_cast< ::QAudioDevice *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QAudioDevice));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QAudioDevice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QAudioDevice::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, eq_slot, sipType_QAudioDevice, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QAudioDevice(void *, int);}
static void release_QAudioDevice(void *sipCppV, int)
{
    delete reinterpret_cast< ::QAudioDevice *>(sipCppV);
}


extern "C" {static void *array_QAudioDevice(Py_ssize_t);}
static void *array_QAudioDevice(Py_ssize_t sipNrElem)
{
    return new ::QAudioDevice[sipNrElem];
}


extern "C" {static void array_delete_QAudioDevice(void *);}
static void array_delete_QAudioDevice(void *sipCpp)
{
    delete[] reinterpret_cast< ::QAudioDevice *>(sipCpp);
}


extern "C" {static void assign_QAudioDevice(void *, Py_ssize_t, void *);}
static void assign_QAudioDevice(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QAudioDevice *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QAudioDevice *>(sipSrc);
}


extern "C" {static void *copy_QAudioDevice(const void *, Py_ssize_t);}
static void *copy_QAudioDevice(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QAudioDevice(reinterpret_cast<const ::QAudioDevice *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QAudioDevice(sipSimpleWrapper *);}
static void dealloc_QAudioDevice(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAudioDevice(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QAudioDevice(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAudioDevice(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QAudioDevice *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QAudioDevice();

            return sipCpp;
        }
    }

    {
        const ::QAudioDevice* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QAudioDevice, &a0))
        {
            sipCpp = new ::QAudioDevice(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QAudioDevice[] = {
    {(void *)slot_QAudioDevice___ne__, ne_slot},
    {(void *)slot_QAudioDevice___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QAudioDevice[] = {
    {sipName_channelConfiguration, meth_QAudioDevice_channelConfiguration, METH_VARARGS, doc_QAudioDevice_channelConfiguration},
    {sipName_description, meth_QAudioDevice_description, METH_VARARGS, doc_QAudioDevice_description},
    {sipName_id, meth_QAudioDevice_id, METH_VARARGS, doc_QAudioDevice_id},
    {sipName_isDefault, meth_QAudioDevice_isDefault, METH_VARARGS, doc_QAudioDevice_isDefault},
    {sipName_isFormatSupported, meth_QAudioDevice_isFormatSupported, METH_VARARGS, doc_QAudioDevice_isFormatSupported},
    {sipName_isNull, meth_QAudioDevice_isNull, METH_VARARGS, doc_QAudioDevice_isNull},
    {sipName_maximumChannelCount, meth_QAudioDevice_maximumChannelCount, METH_VARARGS, doc_QAudioDevice_maximumChannelCount},
    {sipName_maximumSampleRate, meth_QAudioDevice_maximumSampleRate, METH_VARARGS, doc_QAudioDevice_maximumSampleRate},
    {sipName_minimumChannelCount, meth_QAudioDevice_minimumChannelCount, METH_VARARGS, doc_QAudioDevice_minimumChannelCount},
    {sipName_minimumSampleRate, meth_QAudioDevice_minimumSampleRate, METH_VARARGS, doc_QAudioDevice_minimumSampleRate},
    {sipName_mode, meth_QAudioDevice_mode, METH_VARARGS, doc_QAudioDevice_mode},
    {sipName_preferredFormat, meth_QAudioDevice_preferredFormat, METH_VARARGS, doc_QAudioDevice_preferredFormat},
    {sipName_supportedSampleFormats, meth_QAudioDevice_supportedSampleFormats, METH_VARARGS, doc_QAudioDevice_supportedSampleFormats},
    {sipName_swap, meth_QAudioDevice_swap, METH_VARARGS, doc_QAudioDevice_swap}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QAudioDevice[] = {
    {sipName_Null, static_cast<int>(::QAudioDevice::Null)},
    {sipName_Input, static_cast<int>(::QAudioDevice::Input)},
    {sipName_Output, static_cast<int>(::QAudioDevice::Output)},
    {0, 0}
};

PyDoc_STRVAR(doc_QAudioDevice, "\1QAudioDevice()\n"
"QAudioDevice(other: QAudioDevice)");


sipClassTypeDef sipTypeDef_QtMultimedia_QAudioDevice = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAudioDevice,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QAudioDevice,
        {0, 0, 1},
        14, methods_QAudioDevice,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QAudioDevice, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAudioDevice,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QAudioDevice,
    init_type_QAudioDevice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAudioDevice,
    assign_QAudioDevice,
    array_QAudioDevice,
    copy_QAudioDevice,
    release_QAudioDevice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAudioDevice,
    sizeof (::QAudioDevice),
};
