/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeoareamonitorsource.sip"
#include <qgeoareamonitorsource.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeoareamonitorinfo.sip"
#include <qgeoareamonitorinfo.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeopositioninfo.sip"
#include <qgeopositioninfo.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeoshape.sip"
#include <qgeoshape.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeopositioninfosource.sip"
#include <qgeopositioninfosource.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorSource.cpp"


class sipQGeoAreaMonitorSource : public ::QGeoAreaMonitorSource
{
public:
    sipQGeoAreaMonitorSource(::QObject*);
    virtual ~sipQGeoAreaMonitorSource();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QVariant backendProperty(const ::QString&) const SIP_OVERRIDE;
    bool setBackendProperty(const ::QString&, const ::QVariant&) SIP_OVERRIDE;
    QList< ::QGeoAreaMonitorInfo> activeMonitors(const ::QGeoShape&) const SIP_OVERRIDE;
    QList< ::QGeoAreaMonitorInfo> activeMonitors() const SIP_OVERRIDE;
    bool requestUpdate(const ::QGeoAreaMonitorInfo&, const char*) SIP_OVERRIDE;
    bool stopMonitoring(const ::QGeoAreaMonitorInfo&) SIP_OVERRIDE;
    bool startMonitoring(const ::QGeoAreaMonitorInfo&) SIP_OVERRIDE;
    ::QGeoAreaMonitorSource::AreaMonitorFeatures supportedAreaMonitorFeatures() const SIP_OVERRIDE;
    ::QGeoAreaMonitorSource::Error error() const SIP_OVERRIDE;
    ::QGeoPositionInfoSource* positionInfoSource() const SIP_OVERRIDE;
    void setPositionInfoSource(::QGeoPositionInfoSource*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGeoAreaMonitorSource(const sipQGeoAreaMonitorSource &);
    sipQGeoAreaMonitorSource &operator = (const sipQGeoAreaMonitorSource &);

    char sipPyMethods[18];
};

sipQGeoAreaMonitorSource::sipQGeoAreaMonitorSource(::QObject*a0): ::QGeoAreaMonitorSource(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGeoAreaMonitorSource::~sipQGeoAreaMonitorSource()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGeoAreaMonitorSource::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtPositioning_qt_metaobject(sipPySelf, sipType_QGeoAreaMonitorSource);

    return ::QGeoAreaMonitorSource::metaObject();
}

int sipQGeoAreaMonitorSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGeoAreaMonitorSource::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtPositioning_qt_metacall(sipPySelf, sipType_QGeoAreaMonitorSource, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGeoAreaMonitorSource::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtPositioning_qt_metacast(sipPySelf, sipType_QGeoAreaMonitorSource, _clname, &sipCpp) ? sipCpp : ::QGeoAreaMonitorSource::qt_metacast(_clname));
}

::QVariant sipQGeoAreaMonitorSource::backendProperty(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_backendProperty);

    if (!sipMeth)
        return ::QGeoAreaMonitorSource::backendProperty(a0);

    extern ::QVariant sipVH_QtPositioning_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtPositioning_15(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoAreaMonitorSource::setBackendProperty(const ::QString& a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_setBackendProperty);

    if (!sipMeth)
        return ::QGeoAreaMonitorSource::setBackendProperty(a0, a1);

    extern bool sipVH_QtPositioning_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, const ::QVariant&);

    return sipVH_QtPositioning_14(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

QList< ::QGeoAreaMonitorInfo> sipQGeoAreaMonitorSource::activeMonitors(const ::QGeoShape& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QGeoAreaMonitorSource, sipName_activeMonitors);

    if (!sipMeth)
        return QList< ::QGeoAreaMonitorInfo>();

    extern QList< ::QGeoAreaMonitorInfo> sipVH_QtPositioning_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGeoShape&);

    return sipVH_QtPositioning_13(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

QList< ::QGeoAreaMonitorInfo> sipQGeoAreaMonitorSource::activeMonitors() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QGeoAreaMonitorSource, sipName_activeMonitors);

    if (!sipMeth)
        return QList< ::QGeoAreaMonitorInfo>();

    extern QList< ::QGeoAreaMonitorInfo> sipVH_QtPositioning_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPositioning_12(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQGeoAreaMonitorSource::requestUpdate(const ::QGeoAreaMonitorInfo& a0, const char*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, sipName_QGeoAreaMonitorSource, sipName_requestUpdate);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtPositioning_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGeoAreaMonitorInfo&, const char*);

    return sipVH_QtPositioning_11(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGeoAreaMonitorSource::stopMonitoring(const ::QGeoAreaMonitorInfo& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, sipName_QGeoAreaMonitorSource, sipName_stopMonitoring);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtPositioning_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGeoAreaMonitorInfo&);

    return sipVH_QtPositioning_10(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoAreaMonitorSource::startMonitoring(const ::QGeoAreaMonitorInfo& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, sipName_QGeoAreaMonitorSource, sipName_startMonitoring);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtPositioning_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGeoAreaMonitorInfo&);

    return sipVH_QtPositioning_10(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QGeoAreaMonitorSource::AreaMonitorFeatures sipQGeoAreaMonitorSource::supportedAreaMonitorFeatures() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QGeoAreaMonitorSource, sipName_supportedAreaMonitorFeatures);

    if (!sipMeth)
        return ::QGeoAreaMonitorSource::AreaMonitorFeatures();

    extern ::QGeoAreaMonitorSource::AreaMonitorFeatures sipVH_QtPositioning_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPositioning_9(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QGeoAreaMonitorSource::Error sipQGeoAreaMonitorSource::error() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QGeoAreaMonitorSource, sipName_error);

    if (!sipMeth)
        return ::QGeoAreaMonitorSource::AccessError;

    extern ::QGeoAreaMonitorSource::Error sipVH_QtPositioning_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPositioning_8(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QGeoPositionInfoSource* sipQGeoAreaMonitorSource::positionInfoSource() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_positionInfoSource);

    if (!sipMeth)
        return ::QGeoAreaMonitorSource::positionInfoSource();

    extern ::QGeoPositionInfoSource* sipVH_QtPositioning_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPositioning_7(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGeoAreaMonitorSource::setPositionInfoSource(::QGeoPositionInfoSource*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_setPositionInfoSource);

    if (!sipMeth)
    {
        ::QGeoAreaMonitorSource::setPositionInfoSource(a0);
        return;
    }

    extern void sipVH_QtPositioning_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGeoPositionInfoSource*);

    sipVH_QtPositioning_6(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoAreaMonitorSource::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGeoAreaMonitorSource::event(a0);

    extern bool sipVH_QtPositioning_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtPositioning_5(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoAreaMonitorSource::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGeoAreaMonitorSource::eventFilter(a0, a1);

    extern bool sipVH_QtPositioning_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtPositioning_4(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGeoAreaMonitorSource::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGeoAreaMonitorSource::timerEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtPositioning_3(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoAreaMonitorSource::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGeoAreaMonitorSource::childEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtPositioning_2(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoAreaMonitorSource::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGeoAreaMonitorSource::customEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPositioning_1(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoAreaMonitorSource::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGeoAreaMonitorSource::connectNotify(a0);
        return;
    }

    extern void sipVH_QtPositioning_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPositioning_0(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoAreaMonitorSource::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGeoAreaMonitorSource::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtPositioning_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPositioning_0(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_createDefaultSource, "createDefaultSource(parent: QObject|None) -> QGeoAreaMonitorSource|None");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_createDefaultSource(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_createDefaultSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        sipWrapper *sipOwner = SIP_NULLPTR;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJH", &sipSelf, sipType_QObject, &a0, &sipOwner))
        {
            ::QGeoAreaMonitorSource*sipRes;

            sipRes = ::QGeoAreaMonitorSource::createDefaultSource(a0);

            return sipConvertFromType(sipRes, sipType_QGeoAreaMonitorSource, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_createDefaultSource, doc_QGeoAreaMonitorSource_createDefaultSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_createSource, "createSource(sourceName: str|None, parent: QObject|None) -> QGeoAreaMonitorSource|None");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_createSource(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_createSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1;
        sipWrapper *sipOwner = SIP_NULLPTR;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1JH", &sipSelf, sipType_QString, &a0, &a0State, sipType_QObject, &a1, &sipOwner))
        {
            ::QGeoAreaMonitorSource*sipRes;

            sipRes = ::QGeoAreaMonitorSource::createSource(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(sipRes, sipType_QGeoAreaMonitorSource, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_createSource, doc_QGeoAreaMonitorSource_createSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_availableSources, "availableSources() -> list[str]");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_availableSources(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_availableSources(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QGeoAreaMonitorSource::availableSources());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_availableSources, doc_QGeoAreaMonitorSource_availableSources);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_setPositionInfoSource, "setPositionInfoSource(self, source: QGeoPositionInfoSource|None)");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_setPositionInfoSource(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_setPositionInfoSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGeoAreaMonitorSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGeoPositionInfoSource* a0;
        ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp, sipType_QGeoPositionInfoSource, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGeoAreaMonitorSource::setPositionInfoSource(a0) : sipCpp->setPositionInfoSource(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_setPositionInfoSource, doc_QGeoAreaMonitorSource_setPositionInfoSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_positionInfoSource, "positionInfoSource(self) -> QGeoPositionInfoSource|None");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_positionInfoSource(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_positionInfoSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGeoAreaMonitorSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp))
        {
            ::QGeoPositionInfoSource*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGeoAreaMonitorSource::positionInfoSource() : sipCpp->positionInfoSource());

            return sipConvertFromType(sipRes, sipType_QGeoPositionInfoSource, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_positionInfoSource, doc_QGeoAreaMonitorSource_positionInfoSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_sourceName, "sourceName(self) -> str");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_sourceName(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_sourceName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->sourceName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_sourceName, doc_QGeoAreaMonitorSource_sourceName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_error, "error(self) -> QGeoAreaMonitorSource.Error");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_error(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp))
        {
            ::QGeoAreaMonitorSource::Error sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoAreaMonitorSource, sipName_error);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoAreaMonitorSource_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_error, doc_QGeoAreaMonitorSource_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_supportedAreaMonitorFeatures, "supportedAreaMonitorFeatures(self) -> QGeoAreaMonitorSource.AreaMonitorFeature");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_supportedAreaMonitorFeatures(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_supportedAreaMonitorFeatures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp))
        {
            ::QGeoAreaMonitorSource::AreaMonitorFeatures*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoAreaMonitorSource, sipName_supportedAreaMonitorFeatures);
                return SIP_NULLPTR;
            }

            sipRes = new ::QGeoAreaMonitorSource::AreaMonitorFeatures(sipCpp->supportedAreaMonitorFeatures());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QGeoAreaMonitorSource_AreaMonitorFeature, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_supportedAreaMonitorFeatures, doc_QGeoAreaMonitorSource_supportedAreaMonitorFeatures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_startMonitoring, "startMonitoring(self, monitor: QGeoAreaMonitorInfo) -> bool");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_startMonitoring(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_startMonitoring(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QGeoAreaMonitorInfo* a0;
        ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp, sipType_QGeoAreaMonitorInfo, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoAreaMonitorSource, sipName_startMonitoring);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->startMonitoring(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_startMonitoring, doc_QGeoAreaMonitorSource_startMonitoring);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_stopMonitoring, "stopMonitoring(self, monitor: QGeoAreaMonitorInfo) -> bool");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_stopMonitoring(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_stopMonitoring(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QGeoAreaMonitorInfo* a0;
        ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp, sipType_QGeoAreaMonitorInfo, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoAreaMonitorSource, sipName_stopMonitoring);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->stopMonitoring(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_stopMonitoring, doc_QGeoAreaMonitorSource_stopMonitoring);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_requestUpdate, "requestUpdate(self, monitor: QGeoAreaMonitorInfo, signal: str) -> bool");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_requestUpdate(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_requestUpdate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QGeoAreaMonitorInfo* a0;
        const char* a1;
        PyObject *a1Keep;
        ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9AA", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp, sipType_QGeoAreaMonitorInfo, &a0, &a1Keep, &a1))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoAreaMonitorSource, sipName_requestUpdate);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->requestUpdate(*a0, a1);
            Py_DECREF(a1Keep);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_requestUpdate, doc_QGeoAreaMonitorSource_requestUpdate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_activeMonitors, "activeMonitors(self) -> list[QGeoAreaMonitorInfo]\n"
"activeMonitors(self, lookupArea: QGeoShape) -> list[QGeoAreaMonitorInfo]");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_activeMonitors(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_activeMonitors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp))
        {
            QList< ::QGeoAreaMonitorInfo>*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoAreaMonitorSource, sipName_activeMonitors);
                return SIP_NULLPTR;
            }

            sipRes = new QList< ::QGeoAreaMonitorInfo>(sipCpp->activeMonitors());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QGeoAreaMonitorInfo, SIP_NULLPTR);
        }
    }

    {
        const ::QGeoShape* a0;
        const ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp, sipType_QGeoShape, &a0))
        {
            QList< ::QGeoAreaMonitorInfo>*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoAreaMonitorSource, sipName_activeMonitors);
                return SIP_NULLPTR;
            }

            sipRes = new QList< ::QGeoAreaMonitorInfo>(sipCpp->activeMonitors(*a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QGeoAreaMonitorInfo, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_activeMonitors, doc_QGeoAreaMonitorSource_activeMonitors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_setBackendProperty, "setBackendProperty(self, name: str|None, value: Any) -> bool");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_setBackendProperty(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_setBackendProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGeoAreaMonitorSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGeoAreaMonitorSource::setBackendProperty(*a0, *a1) : sipCpp->setBackendProperty(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_setBackendProperty, doc_QGeoAreaMonitorSource_setBackendProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorSource_backendProperty, "backendProperty(self, name: str|None) -> Any");

extern "C" {static PyObject *meth_QGeoAreaMonitorSource_backendProperty(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorSource_backendProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGeoAreaMonitorSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QGeoAreaMonitorSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAreaMonitorSource, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QGeoAreaMonitorSource::backendProperty(*a0) : sipCpp->backendProperty(*a0)));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorSource, sipName_backendProperty, doc_QGeoAreaMonitorSource_backendProperty);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGeoAreaMonitorSource(void *, const sipTypeDef *);}
static void *cast_QGeoAreaMonitorSource(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGeoAreaMonitorSource *sipCpp = reinterpret_cast< ::QGeoAreaMonitorSource *>(sipCppV);

    if (targetType == sipType_QGeoAreaMonitorSource)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoAreaMonitorSource(void *, int);}
static void release_QGeoAreaMonitorSource(void *sipCppV, int)
{
    ::QGeoAreaMonitorSource *sipCpp = reinterpret_cast< ::QGeoAreaMonitorSource *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QGeoAreaMonitorSource(sipSimpleWrapper *);}
static void dealloc_QGeoAreaMonitorSource(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGeoAreaMonitorSource *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoAreaMonitorSource(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGeoAreaMonitorSource(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoAreaMonitorSource(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGeoAreaMonitorSource *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQGeoAreaMonitorSource(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGeoAreaMonitorSource[] = {{9, 0, 1}};


static PyMethodDef methods_QGeoAreaMonitorSource[] = {
    {sipName_activeMonitors, meth_QGeoAreaMonitorSource_activeMonitors, METH_VARARGS, doc_QGeoAreaMonitorSource_activeMonitors},
    {sipName_availableSources, meth_QGeoAreaMonitorSource_availableSources, METH_VARARGS, doc_QGeoAreaMonitorSource_availableSources},
    {sipName_backendProperty, meth_QGeoAreaMonitorSource_backendProperty, METH_VARARGS, doc_QGeoAreaMonitorSource_backendProperty},
    {sipName_createDefaultSource, meth_QGeoAreaMonitorSource_createDefaultSource, METH_VARARGS, doc_QGeoAreaMonitorSource_createDefaultSource},
    {sipName_createSource, meth_QGeoAreaMonitorSource_createSource, METH_VARARGS, doc_QGeoAreaMonitorSource_createSource},
    {sipName_error, meth_QGeoAreaMonitorSource_error, METH_VARARGS, doc_QGeoAreaMonitorSource_error},
    {sipName_positionInfoSource, meth_QGeoAreaMonitorSource_positionInfoSource, METH_VARARGS, doc_QGeoAreaMonitorSource_positionInfoSource},
    {sipName_requestUpdate, meth_QGeoAreaMonitorSource_requestUpdate, METH_VARARGS, doc_QGeoAreaMonitorSource_requestUpdate},
    {sipName_setBackendProperty, meth_QGeoAreaMonitorSource_setBackendProperty, METH_VARARGS, doc_QGeoAreaMonitorSource_setBackendProperty},
    {sipName_setPositionInfoSource, meth_QGeoAreaMonitorSource_setPositionInfoSource, METH_VARARGS, doc_QGeoAreaMonitorSource_setPositionInfoSource},
    {sipName_sourceName, meth_QGeoAreaMonitorSource_sourceName, METH_VARARGS, doc_QGeoAreaMonitorSource_sourceName},
    {sipName_startMonitoring, meth_QGeoAreaMonitorSource_startMonitoring, METH_VARARGS, doc_QGeoAreaMonitorSource_startMonitoring},
    {sipName_stopMonitoring, meth_QGeoAreaMonitorSource_stopMonitoring, METH_VARARGS, doc_QGeoAreaMonitorSource_stopMonitoring},
    {sipName_supportedAreaMonitorFeatures, meth_QGeoAreaMonitorSource_supportedAreaMonitorFeatures, METH_VARARGS, doc_QGeoAreaMonitorSource_supportedAreaMonitorFeatures}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QGeoAreaMonitorSource[] = {
    {sipName_PersistentAreaMonitorFeature, static_cast<int>(::QGeoAreaMonitorSource::PersistentAreaMonitorFeature)},
    {sipName_AnyAreaMonitorFeature, static_cast<int>(::QGeoAreaMonitorSource::AnyAreaMonitorFeature)},
    {sipName_AccessError, static_cast<int>(::QGeoAreaMonitorSource::AccessError)},
    {sipName_InsufficientPositionInfo, static_cast<int>(::QGeoAreaMonitorSource::InsufficientPositionInfo)},
    {sipName_UnknownSourceError, static_cast<int>(::QGeoAreaMonitorSource::UnknownSourceError)},
    {sipName_NoError, static_cast<int>(::QGeoAreaMonitorSource::NoError)},
    {0, 0}
};

PyDoc_STRVAR(doc_QGeoAreaMonitorSource, "\1QGeoAreaMonitorSource(parent: QObject|None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QGeoAreaMonitorSource[] = {
    {"errorOccurred(QGeoAreaMonitorSource::Error)", "\1errorOccurred(self, error: QGeoAreaMonitorSource.Error)", SIP_NULLPTR, SIP_NULLPTR},
    {"monitorExpired(QGeoAreaMonitorInfo)", "\1monitorExpired(self, monitor: QGeoAreaMonitorInfo)", SIP_NULLPTR, SIP_NULLPTR},
    {"areaExited(QGeoAreaMonitorInfo,QGeoPositionInfo)", "\1areaExited(self, monitor: QGeoAreaMonitorInfo, update: QGeoPositionInfo)", SIP_NULLPTR, SIP_NULLPTR},
    {"areaEntered(QGeoAreaMonitorInfo,QGeoPositionInfo)", "\1areaEntered(self, monitor: QGeoAreaMonitorInfo, update: QGeoPositionInfo)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QGeoAreaMonitorSource = {
    &::QGeoAreaMonitorSource::staticMetaObject,
    signals_QGeoAreaMonitorSource,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPositioning_QGeoAreaMonitorSource = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoAreaMonitorSource,
        SIP_NULLPTR,
        &plugin_QGeoAreaMonitorSource,
    },
    {
        sipNameNr_QGeoAreaMonitorSource,
        {0, 0, 1},
        14, methods_QGeoAreaMonitorSource,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QGeoAreaMonitorSource, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoAreaMonitorSource,
    -1,
    -1,
    supers_QGeoAreaMonitorSource,
    SIP_NULLPTR,
    init_type_QGeoAreaMonitorSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoAreaMonitorSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QGeoAreaMonitorSource,
    cast_QGeoAreaMonitorSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QGeoAreaMonitorSource),
};
