/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothlocaldevice.sip"
#include <qbluetoothlocaldevice.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothaddress.sip"
#include <qbluetoothaddress.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothhostinfo.sip"
#include <qbluetoothhostinfo.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothLocalDevice.cpp"


class sipQBluetoothLocalDevice : public ::QBluetoothLocalDevice
{
public:
    sipQBluetoothLocalDevice(::QObject*);
    sipQBluetoothLocalDevice(const ::QBluetoothAddress&, ::QObject*);
    virtual ~sipQBluetoothLocalDevice();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQBluetoothLocalDevice(const sipQBluetoothLocalDevice &);
    sipQBluetoothLocalDevice &operator = (const sipQBluetoothLocalDevice &);

    char sipPyMethods[7];
};

sipQBluetoothLocalDevice::sipQBluetoothLocalDevice(::QObject*a0): ::QBluetoothLocalDevice(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBluetoothLocalDevice::sipQBluetoothLocalDevice(const ::QBluetoothAddress& a0, ::QObject*a1): ::QBluetoothLocalDevice(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBluetoothLocalDevice::~sipQBluetoothLocalDevice()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQBluetoothLocalDevice::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtBluetooth_qt_metaobject(sipPySelf, sipType_QBluetoothLocalDevice);

    return ::QBluetoothLocalDevice::metaObject();
}

int sipQBluetoothLocalDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QBluetoothLocalDevice::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtBluetooth_qt_metacall(sipPySelf, sipType_QBluetoothLocalDevice, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQBluetoothLocalDevice::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtBluetooth_qt_metacast(sipPySelf, sipType_QBluetoothLocalDevice, _clname, &sipCpp) ? sipCpp : ::QBluetoothLocalDevice::qt_metacast(_clname));
}

bool sipQBluetoothLocalDevice::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QBluetoothLocalDevice::event(a0);

    extern bool sipVH_QtBluetooth_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtBluetooth_5(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQBluetoothLocalDevice::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QBluetoothLocalDevice::eventFilter(a0, a1);

    extern bool sipVH_QtBluetooth_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtBluetooth_4(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQBluetoothLocalDevice::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QBluetoothLocalDevice::timerEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtBluetooth_3(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothLocalDevice::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QBluetoothLocalDevice::childEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtBluetooth_2(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothLocalDevice::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QBluetoothLocalDevice::customEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtBluetooth_1(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothLocalDevice::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QBluetoothLocalDevice::connectNotify(a0);
        return;
    }

    extern void sipVH_QtBluetooth_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtBluetooth_0(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothLocalDevice::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QBluetoothLocalDevice::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtBluetooth_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtBluetooth_0(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QBluetoothLocalDevice_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QBluetoothLocalDevice_isValid(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothLocalDevice_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothLocalDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothLocalDevice, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothLocalDevice, sipName_isValid, doc_QBluetoothLocalDevice_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothLocalDevice_requestPairing, "requestPairing(self, address: QBluetoothAddress, pairing: QBluetoothLocalDevice.Pairing)");

extern "C" {static PyObject *meth_QBluetoothLocalDevice_requestPairing(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothLocalDevice_requestPairing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothAddress* a0;
        ::QBluetoothLocalDevice::Pairing a1;
        ::QBluetoothLocalDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9E", &sipSelf, sipType_QBluetoothLocalDevice, &sipCpp, sipType_QBluetoothAddress, &a0, sipType_QBluetoothLocalDevice_Pairing, &a1))
        {
            sipCpp->requestPairing(*a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothLocalDevice, sipName_requestPairing, doc_QBluetoothLocalDevice_requestPairing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothLocalDevice_pairingStatus, "pairingStatus(self, address: QBluetoothAddress) -> QBluetoothLocalDevice.Pairing");

extern "C" {static PyObject *meth_QBluetoothLocalDevice_pairingStatus(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothLocalDevice_pairingStatus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothAddress* a0;
        const ::QBluetoothLocalDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QBluetoothLocalDevice, &sipCpp, sipType_QBluetoothAddress, &a0))
        {
            ::QBluetoothLocalDevice::Pairing sipRes;

            sipRes = sipCpp->pairingStatus(*a0);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QBluetoothLocalDevice_Pairing);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothLocalDevice, sipName_pairingStatus, doc_QBluetoothLocalDevice_pairingStatus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothLocalDevice_setHostMode, "setHostMode(self, mode: QBluetoothLocalDevice.HostMode)");

extern "C" {static PyObject *meth_QBluetoothLocalDevice_setHostMode(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothLocalDevice_setHostMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothLocalDevice::HostMode a0;
        ::QBluetoothLocalDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QBluetoothLocalDevice, &sipCpp, sipType_QBluetoothLocalDevice_HostMode, &a0))
        {
            sipCpp->setHostMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothLocalDevice, sipName_setHostMode, doc_QBluetoothLocalDevice_setHostMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothLocalDevice_hostMode, "hostMode(self) -> QBluetoothLocalDevice.HostMode");

extern "C" {static PyObject *meth_QBluetoothLocalDevice_hostMode(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothLocalDevice_hostMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothLocalDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothLocalDevice, &sipCpp))
        {
            ::QBluetoothLocalDevice::HostMode sipRes;

            sipRes = sipCpp->hostMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QBluetoothLocalDevice_HostMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothLocalDevice, sipName_hostMode, doc_QBluetoothLocalDevice_hostMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothLocalDevice_powerOn, "powerOn(self)");

extern "C" {static PyObject *meth_QBluetoothLocalDevice_powerOn(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothLocalDevice_powerOn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothLocalDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothLocalDevice, &sipCpp))
        {
            sipCpp->powerOn();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothLocalDevice, sipName_powerOn, doc_QBluetoothLocalDevice_powerOn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothLocalDevice_name, "name(self) -> str");

extern "C" {static PyObject *meth_QBluetoothLocalDevice_name(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothLocalDevice_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothLocalDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothLocalDevice, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothLocalDevice, sipName_name, doc_QBluetoothLocalDevice_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothLocalDevice_address, "address(self) -> QBluetoothAddress");

extern "C" {static PyObject *meth_QBluetoothLocalDevice_address(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothLocalDevice_address(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothLocalDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothLocalDevice, &sipCpp))
        {
            ::QBluetoothAddress*sipRes;

            sipRes = new ::QBluetoothAddress(sipCpp->address());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothAddress, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothLocalDevice, sipName_address, doc_QBluetoothLocalDevice_address);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothLocalDevice_allDevices, "allDevices() -> list[QBluetoothHostInfo]");

extern "C" {static PyObject *meth_QBluetoothLocalDevice_allDevices(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothLocalDevice_allDevices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            QList< ::QBluetoothHostInfo>*sipRes;

            sipRes = new QList< ::QBluetoothHostInfo>(::QBluetoothLocalDevice::allDevices());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QBluetoothHostInfo, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothLocalDevice, sipName_allDevices, doc_QBluetoothLocalDevice_allDevices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothLocalDevice_connectedDevices, "connectedDevices(self) -> list[QBluetoothAddress]");

extern "C" {static PyObject *meth_QBluetoothLocalDevice_connectedDevices(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothLocalDevice_connectedDevices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothLocalDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothLocalDevice, &sipCpp))
        {
            QList< ::QBluetoothAddress>*sipRes;

            sipRes = new QList< ::QBluetoothAddress>(sipCpp->connectedDevices());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QBluetoothAddress, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothLocalDevice, sipName_connectedDevices, doc_QBluetoothLocalDevice_connectedDevices);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QBluetoothLocalDevice(void *, const sipTypeDef *);}
static void *cast_QBluetoothLocalDevice(void *sipCppV, const sipTypeDef *targetType)
{
    ::QBluetoothLocalDevice *sipCpp = reinterpret_cast< ::QBluetoothLocalDevice *>(sipCppV);

    if (targetType == sipType_QBluetoothLocalDevice)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QBluetoothLocalDevice(void *, int);}
static void release_QBluetoothLocalDevice(void *sipCppV, int)
{
    ::QBluetoothLocalDevice *sipCpp = reinterpret_cast< ::QBluetoothLocalDevice *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QBluetoothLocalDevice(Py_ssize_t);}
static void *array_QBluetoothLocalDevice(Py_ssize_t sipNrElem)
{
    return new ::QBluetoothLocalDevice[sipNrElem];
}


extern "C" {static void array_delete_QBluetoothLocalDevice(void *);}
static void array_delete_QBluetoothLocalDevice(void *sipCpp)
{
    delete[] reinterpret_cast< ::QBluetoothLocalDevice *>(sipCpp);
}


extern "C" {static void dealloc_QBluetoothLocalDevice(sipSimpleWrapper *);}
static void dealloc_QBluetoothLocalDevice(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQBluetoothLocalDevice *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QBluetoothLocalDevice(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QBluetoothLocalDevice(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QBluetoothLocalDevice(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQBluetoothLocalDevice *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQBluetoothLocalDevice(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QBluetoothAddress* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|JH", sipType_QBluetoothAddress, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQBluetoothLocalDevice(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QBluetoothLocalDevice[] = {{9, 0, 1}};


static PyMethodDef methods_QBluetoothLocalDevice[] = {
    {sipName_address, meth_QBluetoothLocalDevice_address, METH_VARARGS, doc_QBluetoothLocalDevice_address},
    {sipName_allDevices, meth_QBluetoothLocalDevice_allDevices, METH_VARARGS, doc_QBluetoothLocalDevice_allDevices},
    {sipName_connectedDevices, meth_QBluetoothLocalDevice_connectedDevices, METH_VARARGS, doc_QBluetoothLocalDevice_connectedDevices},
    {sipName_hostMode, meth_QBluetoothLocalDevice_hostMode, METH_VARARGS, doc_QBluetoothLocalDevice_hostMode},
    {sipName_isValid, meth_QBluetoothLocalDevice_isValid, METH_VARARGS, doc_QBluetoothLocalDevice_isValid},
    {sipName_name, meth_QBluetoothLocalDevice_name, METH_VARARGS, doc_QBluetoothLocalDevice_name},
    {sipName_pairingStatus, meth_QBluetoothLocalDevice_pairingStatus, METH_VARARGS, doc_QBluetoothLocalDevice_pairingStatus},
    {sipName_powerOn, meth_QBluetoothLocalDevice_powerOn, METH_VARARGS, doc_QBluetoothLocalDevice_powerOn},
    {sipName_requestPairing, meth_QBluetoothLocalDevice_requestPairing, METH_VARARGS, doc_QBluetoothLocalDevice_requestPairing},
    {sipName_setHostMode, meth_QBluetoothLocalDevice_setHostMode, METH_VARARGS, doc_QBluetoothLocalDevice_setHostMode}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QBluetoothLocalDevice[] = {
    {sipName_NoError, static_cast<int>(::QBluetoothLocalDevice::NoError)},
    {sipName_PairingError, static_cast<int>(::QBluetoothLocalDevice::PairingError)},
    {sipName_MissingPermissionsError, static_cast<int>(::QBluetoothLocalDevice::MissingPermissionsError)},
    {sipName_UnknownError, static_cast<int>(::QBluetoothLocalDevice::UnknownError)},
    {sipName_HostPoweredOff, static_cast<int>(::QBluetoothLocalDevice::HostPoweredOff)},
    {sipName_HostConnectable, static_cast<int>(::QBluetoothLocalDevice::HostConnectable)},
    {sipName_HostDiscoverable, static_cast<int>(::QBluetoothLocalDevice::HostDiscoverable)},
    {sipName_HostDiscoverableLimitedInquiry, static_cast<int>(::QBluetoothLocalDevice::HostDiscoverableLimitedInquiry)},
    {sipName_Unpaired, static_cast<int>(::QBluetoothLocalDevice::Unpaired)},
    {sipName_Paired, static_cast<int>(::QBluetoothLocalDevice::Paired)},
    {sipName_AuthorizedPaired, static_cast<int>(::QBluetoothLocalDevice::AuthorizedPaired)},
    {0, 0}
};

PyDoc_STRVAR(doc_QBluetoothLocalDevice, "\1QBluetoothLocalDevice(parent: QObject|None = None)\n"
"QBluetoothLocalDevice(address: QBluetoothAddress, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QBluetoothLocalDevice[] = {
    {"deviceDisconnected(QBluetoothAddress)", "\1deviceDisconnected(self, address: QBluetoothAddress)", SIP_NULLPTR, SIP_NULLPTR},
    {"deviceConnected(QBluetoothAddress)", "\1deviceConnected(self, address: QBluetoothAddress)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorOccurred(QBluetoothLocalDevice::Error)", "\1errorOccurred(self, error: QBluetoothLocalDevice.Error)", SIP_NULLPTR, SIP_NULLPTR},
    {"pairingFinished(QBluetoothAddress,QBluetoothLocalDevice::Pairing)", "\1pairingFinished(self, address: QBluetoothAddress, pairing: QBluetoothLocalDevice.Pairing)", SIP_NULLPTR, SIP_NULLPTR},
    {"hostModeStateChanged(QBluetoothLocalDevice::HostMode)", "\1hostModeStateChanged(self, state: QBluetoothLocalDevice.HostMode)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QBluetoothLocalDevice = {
    &::QBluetoothLocalDevice::staticMetaObject,
    signals_QBluetoothLocalDevice,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothLocalDevice = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QBluetoothLocalDevice,
        SIP_NULLPTR,
        &plugin_QBluetoothLocalDevice,
    },
    {
        sipNameNr_QBluetoothLocalDevice,
        {0, 0, 1},
        10, methods_QBluetoothLocalDevice,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QBluetoothLocalDevice, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QBluetoothLocalDevice,
    -1,
    -1,
    supers_QBluetoothLocalDevice,
    SIP_NULLPTR,
    init_type_QBluetoothLocalDevice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QBluetoothLocalDevice,
    SIP_NULLPTR,
    array_QBluetoothLocalDevice,
    SIP_NULLPTR,
    release_QBluetoothLocalDevice,
    cast_QBluetoothLocalDevice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QBluetoothLocalDevice,
    sizeof (::QBluetoothLocalDevice),
};
