/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 31 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQt.cpp"

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQt.cpp"


PyDoc_STRVAR(doc_Qt_ws, "ws(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_ws(PyObject *, PyObject *);}
static PyObject *meth_Qt_ws(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::ws(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_ws, doc_Qt_ws);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_bom, "bom(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_bom(PyObject *, PyObject *);}
static PyObject *meth_Qt_bom(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::bom(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_bom, doc_Qt_bom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_reset, "reset(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_reset(PyObject *, PyObject *);}
static PyObject *meth_Qt_reset(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::reset(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_reset, doc_Qt_reset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_flush, "flush(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_flush(PyObject *, PyObject *);}
static PyObject *meth_Qt_flush(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::flush(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_flush, doc_Qt_flush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_endl, "endl(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_endl(PyObject *, PyObject *);}
static PyObject *meth_Qt_endl(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::endl(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_endl, doc_Qt_endl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_center, "center(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_center(PyObject *, PyObject *);}
static PyObject *meth_Qt_center(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::center(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_center, doc_Qt_center);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_right, "right(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_right(PyObject *, PyObject *);}
static PyObject *meth_Qt_right(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::right(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_right, doc_Qt_right);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_left, "left(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_left(PyObject *, PyObject *);}
static PyObject *meth_Qt_left(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::left(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_left, doc_Qt_left);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_scientific, "scientific(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_scientific(PyObject *, PyObject *);}
static PyObject *meth_Qt_scientific(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::scientific(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_scientific, doc_Qt_scientific);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_fixed, "fixed(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_fixed(PyObject *, PyObject *);}
static PyObject *meth_Qt_fixed(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::fixed(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_fixed, doc_Qt_fixed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_lowercasedigits, "lowercasedigits(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_lowercasedigits(PyObject *, PyObject *);}
static PyObject *meth_Qt_lowercasedigits(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::lowercasedigits(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_lowercasedigits, doc_Qt_lowercasedigits);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_lowercasebase, "lowercasebase(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_lowercasebase(PyObject *, PyObject *);}
static PyObject *meth_Qt_lowercasebase(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::lowercasebase(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_lowercasebase, doc_Qt_lowercasebase);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_uppercasedigits, "uppercasedigits(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_uppercasedigits(PyObject *, PyObject *);}
static PyObject *meth_Qt_uppercasedigits(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::uppercasedigits(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_uppercasedigits, doc_Qt_uppercasedigits);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_uppercasebase, "uppercasebase(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_uppercasebase(PyObject *, PyObject *);}
static PyObject *meth_Qt_uppercasebase(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::uppercasebase(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_uppercasebase, doc_Qt_uppercasebase);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_noforcepoint, "noforcepoint(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_noforcepoint(PyObject *, PyObject *);}
static PyObject *meth_Qt_noforcepoint(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::noforcepoint(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_noforcepoint, doc_Qt_noforcepoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_noforcesign, "noforcesign(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_noforcesign(PyObject *, PyObject *);}
static PyObject *meth_Qt_noforcesign(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::noforcesign(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_noforcesign, doc_Qt_noforcesign);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_noshowbase, "noshowbase(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_noshowbase(PyObject *, PyObject *);}
static PyObject *meth_Qt_noshowbase(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::noshowbase(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_noshowbase, doc_Qt_noshowbase);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_forcepoint, "forcepoint(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_forcepoint(PyObject *, PyObject *);}
static PyObject *meth_Qt_forcepoint(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::forcepoint(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_forcepoint, doc_Qt_forcepoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_forcesign, "forcesign(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_forcesign(PyObject *, PyObject *);}
static PyObject *meth_Qt_forcesign(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::forcesign(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_forcesign, doc_Qt_forcesign);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_showbase, "showbase(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_showbase(PyObject *, PyObject *);}
static PyObject *meth_Qt_showbase(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::showbase(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_showbase, doc_Qt_showbase);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_hex, "hex(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_hex(PyObject *, PyObject *);}
static PyObject *meth_Qt_hex(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::hex(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_hex, doc_Qt_hex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_dec, "dec(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_dec(PyObject *, PyObject *);}
static PyObject *meth_Qt_dec(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::dec(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_dec, doc_Qt_dec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_oct, "oct(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_oct(PyObject *, PyObject *);}
static PyObject *meth_Qt_oct(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::oct(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_oct, doc_Qt_oct);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt_bin, "bin(s: QTextStream) -> QTextStream");

extern "C" {static PyObject *meth_Qt_bin(PyObject *, PyObject *);}
static PyObject *meth_Qt_bin(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextStream* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QTextStream, &a0))
        {
            ::QTextStream*sipRes;

            sipRes = &::Qt::bin(*a0);

            return sipConvertFromType(sipRes, sipType_QTextStream, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_bin, doc_Qt_bin);

    return SIP_NULLPTR;
}


static PyMethodDef methods_Qt[] = {
    {sipName_bin, meth_Qt_bin, METH_VARARGS, doc_Qt_bin},
    {sipName_bom, meth_Qt_bom, METH_VARARGS, doc_Qt_bom},
    {sipName_center, meth_Qt_center, METH_VARARGS, doc_Qt_center},
    {sipName_dec, meth_Qt_dec, METH_VARARGS, doc_Qt_dec},
    {sipName_endl, meth_Qt_endl, METH_VARARGS, doc_Qt_endl},
    {sipName_fixed, meth_Qt_fixed, METH_VARARGS, doc_Qt_fixed},
    {sipName_flush, meth_Qt_flush, METH_VARARGS, doc_Qt_flush},
    {sipName_forcepoint, meth_Qt_forcepoint, METH_VARARGS, doc_Qt_forcepoint},
    {sipName_forcesign, meth_Qt_forcesign, METH_VARARGS, doc_Qt_forcesign},
    {sipName_hex, meth_Qt_hex, METH_VARARGS, doc_Qt_hex},
    {sipName_left, meth_Qt_left, METH_VARARGS, doc_Qt_left},
    {sipName_lowercasebase, meth_Qt_lowercasebase, METH_VARARGS, doc_Qt_lowercasebase},
    {sipName_lowercasedigits, meth_Qt_lowercasedigits, METH_VARARGS, doc_Qt_lowercasedigits},
    {sipName_noforcepoint, meth_Qt_noforcepoint, METH_VARARGS, doc_Qt_noforcepoint},
    {sipName_noforcesign, meth_Qt_noforcesign, METH_VARARGS, doc_Qt_noforcesign},
    {sipName_noshowbase, meth_Qt_noshowbase, METH_VARARGS, doc_Qt_noshowbase},
    {sipName_oct, meth_Qt_oct, METH_VARARGS, doc_Qt_oct},
    {sipName_reset, meth_Qt_reset, METH_VARARGS, doc_Qt_reset},
    {sipName_right, meth_Qt_right, METH_VARARGS, doc_Qt_right},
    {sipName_scientific, meth_Qt_scientific, METH_VARARGS, doc_Qt_scientific},
    {sipName_showbase, meth_Qt_showbase, METH_VARARGS, doc_Qt_showbase},
    {sipName_uppercasebase, meth_Qt_uppercasebase, METH_VARARGS, doc_Qt_uppercasebase},
    {sipName_uppercasedigits, meth_Qt_uppercasedigits, METH_VARARGS, doc_Qt_uppercasedigits},
    {sipName_ws, meth_Qt_ws, METH_VARARGS, doc_Qt_ws}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_Qt[] = {
    {sipName_AlignLeft, static_cast<int>(::Qt::AlignLeft)},
    {sipName_AlignLeading, static_cast<int>(::Qt::AlignLeading)},
    {sipName_AlignRight, static_cast<int>(::Qt::AlignRight)},
    {sipName_AlignTrailing, static_cast<int>(::Qt::AlignTrailing)},
    {sipName_AlignHCenter, static_cast<int>(::Qt::AlignHCenter)},
    {sipName_AlignJustify, static_cast<int>(::Qt::AlignJustify)},
    {sipName_AlignAbsolute, static_cast<int>(::Qt::AlignAbsolute)},
    {sipName_AlignHorizontal_Mask, static_cast<int>(::Qt::AlignHorizontal_Mask)},
    {sipName_AlignTop, static_cast<int>(::Qt::AlignTop)},
    {sipName_AlignBottom, static_cast<int>(::Qt::AlignBottom)},
    {sipName_AlignVCenter, static_cast<int>(::Qt::AlignVCenter)},
    {sipName_AlignVertical_Mask, static_cast<int>(::Qt::AlignVertical_Mask)},
    {sipName_AlignCenter, static_cast<int>(::Qt::AlignCenter)},
    {sipName_AlignBaseline, static_cast<int>(::Qt::AlignBaseline)},
    {sipName_AnchorLeft, static_cast<int>(::Qt::AnchorLeft)},
    {sipName_AnchorHorizontalCenter, static_cast<int>(::Qt::AnchorHorizontalCenter)},
    {sipName_AnchorRight, static_cast<int>(::Qt::AnchorRight)},
    {sipName_AnchorTop, static_cast<int>(::Qt::AnchorTop)},
    {sipName_AnchorVerticalCenter, static_cast<int>(::Qt::AnchorVerticalCenter)},
    {sipName_AnchorBottom, static_cast<int>(::Qt::AnchorBottom)},
    {sipName_AA_DontShowIconsInMenus, static_cast<int>(::Qt::AA_DontShowIconsInMenus)},
    {sipName_AA_NativeWindows, static_cast<int>(::Qt::AA_NativeWindows)},
    {sipName_AA_DontCreateNativeWidgetSiblings, static_cast<int>(::Qt::AA_DontCreateNativeWidgetSiblings)},
    {sipName_AA_DontUseNativeMenuBar, static_cast<int>(::Qt::AA_DontUseNativeMenuBar)},
    {sipName_AA_MacDontSwapCtrlAndMeta, static_cast<int>(::Qt::AA_MacDontSwapCtrlAndMeta)},
    {sipName_AA_Use96Dpi, static_cast<int>(::Qt::AA_Use96Dpi)},
    {sipName_AA_SynthesizeTouchForUnhandledMouseEvents, static_cast<int>(::Qt::AA_SynthesizeTouchForUnhandledMouseEvents)},
    {sipName_AA_SynthesizeMouseForUnhandledTouchEvents, static_cast<int>(::Qt::AA_SynthesizeMouseForUnhandledTouchEvents)},
    {sipName_AA_ForceRasterWidgets, static_cast<int>(::Qt::AA_ForceRasterWidgets)},
    {sipName_AA_UseDesktopOpenGL, static_cast<int>(::Qt::AA_UseDesktopOpenGL)},
    {sipName_AA_UseOpenGLES, static_cast<int>(::Qt::AA_UseOpenGLES)},
    {sipName_AA_UseSoftwareOpenGL, static_cast<int>(::Qt::AA_UseSoftwareOpenGL)},
    {sipName_AA_ShareOpenGLContexts, static_cast<int>(::Qt::AA_ShareOpenGLContexts)},
    {sipName_AA_SetPalette, static_cast<int>(::Qt::AA_SetPalette)},
    {sipName_AA_PluginApplication, static_cast<int>(::Qt::AA_PluginApplication)},
    {sipName_AA_UseStyleSheetPropagationInWidgetStyles, static_cast<int>(::Qt::AA_UseStyleSheetPropagationInWidgetStyles)},
    {sipName_AA_DontUseNativeDialogs, static_cast<int>(::Qt::AA_DontUseNativeDialogs)},
    {sipName_AA_SynthesizeMouseForUnhandledTabletEvents, static_cast<int>(::Qt::AA_SynthesizeMouseForUnhandledTabletEvents)},
    {sipName_AA_CompressHighFrequencyEvents, static_cast<int>(::Qt::AA_CompressHighFrequencyEvents)},
    {sipName_AA_DontCheckOpenGLContextThreadAffinity, static_cast<int>(::Qt::AA_DontCheckOpenGLContextThreadAffinity)},
    {sipName_AA_DisableShaderDiskCache, static_cast<int>(::Qt::AA_DisableShaderDiskCache)},
    {sipName_AA_DontShowShortcutsInContextMenus, static_cast<int>(::Qt::AA_DontShowShortcutsInContextMenus)},
    {sipName_AA_CompressTabletEvents, static_cast<int>(::Qt::AA_CompressTabletEvents)},
    {sipName_AA_DisableSessionManager, static_cast<int>(::Qt::AA_DisableSessionManager)},
    {sipName_AA_DisableNativeVirtualKeyboard, static_cast<int>(::Qt::AA_DisableNativeVirtualKeyboard)},
    {sipName_AA_QtQuickUseDefaultSizePolicy, static_cast<int>(::Qt::AA_QtQuickUseDefaultSizePolicy)},
    {sipName_AA_DontUseNativeMenuWindows, static_cast<int>(::Qt::AA_DontUseNativeMenuWindows)},
    {sipName_ApplicationSuspended, static_cast<int>(::Qt::ApplicationSuspended)},
    {sipName_ApplicationHidden, static_cast<int>(::Qt::ApplicationHidden)},
    {sipName_ApplicationInactive, static_cast<int>(::Qt::ApplicationInactive)},
    {sipName_ApplicationActive, static_cast<int>(::Qt::ApplicationActive)},
    {sipName_NoArrow, static_cast<int>(::Qt::NoArrow)},
    {sipName_UpArrow, static_cast<int>(::Qt::UpArrow)},
    {sipName_DownArrow, static_cast<int>(::Qt::DownArrow)},
    {sipName_LeftArrow, static_cast<int>(::Qt::LeftArrow)},
    {sipName_RightArrow, static_cast<int>(::Qt::RightArrow)},
    {sipName_IgnoreAspectRatio, static_cast<int>(::Qt::IgnoreAspectRatio)},
    {sipName_KeepAspectRatio, static_cast<int>(::Qt::KeepAspectRatio)},
    {sipName_KeepAspectRatioByExpanding, static_cast<int>(::Qt::KeepAspectRatioByExpanding)},
    {sipName_XAxis, static_cast<int>(::Qt::XAxis)},
    {sipName_YAxis, static_cast<int>(::Qt::YAxis)},
    {sipName_ZAxis, static_cast<int>(::Qt::ZAxis)},
    {sipName_TransparentMode, static_cast<int>(::Qt::TransparentMode)},
    {sipName_OpaqueMode, static_cast<int>(::Qt::OpaqueMode)},
    {sipName_NoBrush, static_cast<int>(::Qt::NoBrush)},
    {sipName_SolidPattern, static_cast<int>(::Qt::SolidPattern)},
    {sipName_Dense1Pattern, static_cast<int>(::Qt::Dense1Pattern)},
    {sipName_Dense2Pattern, static_cast<int>(::Qt::Dense2Pattern)},
    {sipName_Dense3Pattern, static_cast<int>(::Qt::Dense3Pattern)},
    {sipName_Dense4Pattern, static_cast<int>(::Qt::Dense4Pattern)},
    {sipName_Dense5Pattern, static_cast<int>(::Qt::Dense5Pattern)},
    {sipName_Dense6Pattern, static_cast<int>(::Qt::Dense6Pattern)},
    {sipName_Dense7Pattern, static_cast<int>(::Qt::Dense7Pattern)},
    {sipName_HorPattern, static_cast<int>(::Qt::HorPattern)},
    {sipName_VerPattern, static_cast<int>(::Qt::VerPattern)},
    {sipName_CrossPattern, static_cast<int>(::Qt::CrossPattern)},
    {sipName_BDiagPattern, static_cast<int>(::Qt::BDiagPattern)},
    {sipName_FDiagPattern, static_cast<int>(::Qt::FDiagPattern)},
    {sipName_DiagCrossPattern, static_cast<int>(::Qt::DiagCrossPattern)},
    {sipName_LinearGradientPattern, static_cast<int>(::Qt::LinearGradientPattern)},
    {sipName_RadialGradientPattern, static_cast<int>(::Qt::RadialGradientPattern)},
    {sipName_ConicalGradientPattern, static_cast<int>(::Qt::ConicalGradientPattern)},
    {sipName_TexturePattern, static_cast<int>(::Qt::TexturePattern)},
    {sipName_CaseInsensitive, static_cast<int>(::Qt::CaseInsensitive)},
    {sipName_CaseSensitive, static_cast<int>(::Qt::CaseSensitive)},
    {sipName_Unchecked, static_cast<int>(::Qt::Unchecked)},
    {sipName_PartiallyChecked, static_cast<int>(::Qt::PartiallyChecked)},
    {sipName_Checked, static_cast<int>(::Qt::Checked)},
    {sipName_ChecksumIso3309, static_cast<int>(::Qt::ChecksumIso3309)},
    {sipName_ChecksumItuV41, static_cast<int>(::Qt::ChecksumItuV41)},
    {sipName_NoClip, static_cast<int>(::Qt::NoClip)},
    {sipName_ReplaceClip, static_cast<int>(::Qt::ReplaceClip)},
    {sipName_IntersectClip, static_cast<int>(::Qt::IntersectClip)},
    {sipName_Unknown, static_cast<int>(::Qt::ColorScheme::Unknown)},
    {sipName_Light, static_cast<int>(::Qt::ColorScheme::Light)},
    {sipName_Dark, static_cast<int>(::Qt::ColorScheme::Dark)},
    {sipName_AutoConnection, static_cast<int>(::Qt::AutoConnection)},
    {sipName_DirectConnection, static_cast<int>(::Qt::DirectConnection)},
    {sipName_QueuedConnection, static_cast<int>(::Qt::QueuedConnection)},
    {sipName_BlockingQueuedConnection, static_cast<int>(::Qt::BlockingQueuedConnection)},
    {sipName_UniqueConnection, static_cast<int>(::Qt::UniqueConnection)},
    {sipName_SingleShotConnection, static_cast<int>(::Qt::SingleShotConnection)},
    {sipName_NoContextMenu, static_cast<int>(::Qt::NoContextMenu)},
    {sipName_PreventContextMenu, static_cast<int>(::Qt::PreventContextMenu)},
    {sipName_DefaultContextMenu, static_cast<int>(::Qt::DefaultContextMenu)},
    {sipName_ActionsContextMenu, static_cast<int>(::Qt::ActionsContextMenu)},
    {sipName_CustomContextMenu, static_cast<int>(::Qt::CustomContextMenu)},
    {sipName_Press, static_cast<int>(::Qt::ContextMenuTrigger::Press)},
    {sipName_Release, static_cast<int>(::Qt::ContextMenuTrigger::Release)},
    {sipName_NoPreference, static_cast<int>(::Qt::ContrastPreference::NoPreference)},
    {sipName_HighContrast, static_cast<int>(::Qt::ContrastPreference::HighContrast)},
    {sipName_DeviceCoordinates, static_cast<int>(::Qt::DeviceCoordinates)},
    {sipName_LogicalCoordinates, static_cast<int>(::Qt::LogicalCoordinates)},
    {sipName_TopLeftCorner, static_cast<int>(::Qt::TopLeftCorner)},
    {sipName_TopRightCorner, static_cast<int>(::Qt::TopRightCorner)},
    {sipName_BottomLeftCorner, static_cast<int>(::Qt::BottomLeftCorner)},
    {sipName_BottomRightCorner, static_cast<int>(::Qt::BottomRightCorner)},
    {sipName_LogicalMoveStyle, static_cast<int>(::Qt::LogicalMoveStyle)},
    {sipName_VisualMoveStyle, static_cast<int>(::Qt::VisualMoveStyle)},
    {sipName_ArrowCursor, static_cast<int>(::Qt::ArrowCursor)},
    {sipName_UpArrowCursor, static_cast<int>(::Qt::UpArrowCursor)},
    {sipName_CrossCursor, static_cast<int>(::Qt::CrossCursor)},
    {sipName_WaitCursor, static_cast<int>(::Qt::WaitCursor)},
    {sipName_IBeamCursor, static_cast<int>(::Qt::IBeamCursor)},
    {sipName_SizeVerCursor, static_cast<int>(::Qt::SizeVerCursor)},
    {sipName_SizeHorCursor, static_cast<int>(::Qt::SizeHorCursor)},
    {sipName_SizeBDiagCursor, static_cast<int>(::Qt::SizeBDiagCursor)},
    {sipName_SizeFDiagCursor, static_cast<int>(::Qt::SizeFDiagCursor)},
    {sipName_SizeAllCursor, static_cast<int>(::Qt::SizeAllCursor)},
    {sipName_BlankCursor, static_cast<int>(::Qt::BlankCursor)},
    {sipName_SplitVCursor, static_cast<int>(::Qt::SplitVCursor)},
    {sipName_SplitHCursor, static_cast<int>(::Qt::SplitHCursor)},
    {sipName_PointingHandCursor, static_cast<int>(::Qt::PointingHandCursor)},
    {sipName_ForbiddenCursor, static_cast<int>(::Qt::ForbiddenCursor)},
    {sipName_OpenHandCursor, static_cast<int>(::Qt::OpenHandCursor)},
    {sipName_ClosedHandCursor, static_cast<int>(::Qt::ClosedHandCursor)},
    {sipName_WhatsThisCursor, static_cast<int>(::Qt::WhatsThisCursor)},
    {sipName_BusyCursor, static_cast<int>(::Qt::BusyCursor)},
    {sipName_LastCursor, static_cast<int>(::Qt::LastCursor)},
    {sipName_BitmapCursor, static_cast<int>(::Qt::BitmapCursor)},
    {sipName_CustomCursor, static_cast<int>(::Qt::CustomCursor)},
    {sipName_DragCopyCursor, static_cast<int>(::Qt::DragCopyCursor)},
    {sipName_DragMoveCursor, static_cast<int>(::Qt::DragMoveCursor)},
    {sipName_DragLinkCursor, static_cast<int>(::Qt::DragLinkCursor)},
    {sipName_TextDate, static_cast<int>(::Qt::TextDate)},
    {sipName_ISODate, static_cast<int>(::Qt::ISODate)},
    {sipName_ISODateWithMs, static_cast<int>(::Qt::ISODateWithMs)},
    {sipName_RFC2822Date, static_cast<int>(::Qt::RFC2822Date)},
    {sipName_Monday, static_cast<int>(::Qt::Monday)},
    {sipName_Tuesday, static_cast<int>(::Qt::Tuesday)},
    {sipName_Wednesday, static_cast<int>(::Qt::Wednesday)},
    {sipName_Thursday, static_cast<int>(::Qt::Thursday)},
    {sipName_Friday, static_cast<int>(::Qt::Friday)},
    {sipName_Saturday, static_cast<int>(::Qt::Saturday)},
    {sipName_Sunday, static_cast<int>(::Qt::Sunday)},
    {sipName_LeftDockWidgetArea, static_cast<int>(::Qt::LeftDockWidgetArea)},
    {sipName_RightDockWidgetArea, static_cast<int>(::Qt::RightDockWidgetArea)},
    {sipName_TopDockWidgetArea, static_cast<int>(::Qt::TopDockWidgetArea)},
    {sipName_BottomDockWidgetArea, static_cast<int>(::Qt::BottomDockWidgetArea)},
    {sipName_AllDockWidgetAreas, static_cast<int>(::Qt::AllDockWidgetAreas)},
    {sipName_NoDockWidgetArea, static_cast<int>(::Qt::NoDockWidgetArea)},
    {sipName_CopyAction, static_cast<int>(::Qt::CopyAction)},
    {sipName_MoveAction, static_cast<int>(::Qt::MoveAction)},
    {sipName_LinkAction, static_cast<int>(::Qt::LinkAction)},
    {sipName_ActionMask, static_cast<int>(::Qt::ActionMask)},
    {sipName_TargetMoveAction, static_cast<int>(::Qt::TargetMoveAction)},
    {sipName_IgnoreAction, static_cast<int>(::Qt::IgnoreAction)},
    {sipName_TopEdge, static_cast<int>(::Qt::TopEdge)},
    {sipName_LeftEdge, static_cast<int>(::Qt::LeftEdge)},
    {sipName_RightEdge, static_cast<int>(::Qt::RightEdge)},
    {sipName_BottomEdge, static_cast<int>(::Qt::BottomEdge)},
    {sipName_EnterKeyDefault, static_cast<int>(::Qt::EnterKeyDefault)},
    {sipName_EnterKeyReturn, static_cast<int>(::Qt::EnterKeyReturn)},
    {sipName_EnterKeyDone, static_cast<int>(::Qt::EnterKeyDone)},
    {sipName_EnterKeyGo, static_cast<int>(::Qt::EnterKeyGo)},
    {sipName_EnterKeySend, static_cast<int>(::Qt::EnterKeySend)},
    {sipName_EnterKeySearch, static_cast<int>(::Qt::EnterKeySearch)},
    {sipName_EnterKeyNext, static_cast<int>(::Qt::EnterKeyNext)},
    {sipName_EnterKeyPrevious, static_cast<int>(::Qt::EnterKeyPrevious)},
    {sipName_HighEventPriority, static_cast<int>(::Qt::HighEventPriority)},
    {sipName_NormalEventPriority, static_cast<int>(::Qt::NormalEventPriority)},
    {sipName_LowEventPriority, static_cast<int>(::Qt::LowEventPriority)},
    {sipName_OddEvenFill, static_cast<int>(::Qt::OddEvenFill)},
    {sipName_WindingFill, static_cast<int>(::Qt::WindingFill)},
    {sipName_FindDirectChildrenOnly, static_cast<int>(::Qt::FindDirectChildrenOnly)},
    {sipName_FindChildrenRecursively, static_cast<int>(::Qt::FindChildrenRecursively)},
    {sipName_NoFocus, static_cast<int>(::Qt::NoFocus)},
    {sipName_TabFocus, static_cast<int>(::Qt::TabFocus)},
    {sipName_ClickFocus, static_cast<int>(::Qt::ClickFocus)},
    {sipName_StrongFocus, static_cast<int>(::Qt::StrongFocus)},
    {sipName_WheelFocus, static_cast<int>(::Qt::WheelFocus)},
    {sipName_MouseFocusReason, static_cast<int>(::Qt::MouseFocusReason)},
    {sipName_TabFocusReason, static_cast<int>(::Qt::TabFocusReason)},
    {sipName_BacktabFocusReason, static_cast<int>(::Qt::BacktabFocusReason)},
    {sipName_ActiveWindowFocusReason, static_cast<int>(::Qt::ActiveWindowFocusReason)},
    {sipName_PopupFocusReason, static_cast<int>(::Qt::PopupFocusReason)},
    {sipName_ShortcutFocusReason, static_cast<int>(::Qt::ShortcutFocusReason)},
    {sipName_MenuBarFocusReason, static_cast<int>(::Qt::MenuBarFocusReason)},
    {sipName_OtherFocusReason, static_cast<int>(::Qt::OtherFocusReason)},
    {sipName_NoFocusReason, static_cast<int>(::Qt::NoFocusReason)},
    {sipName_DontStartGestureOnChildren, static_cast<int>(::Qt::DontStartGestureOnChildren)},
    {sipName_ReceivePartialGestures, static_cast<int>(::Qt::ReceivePartialGestures)},
    {sipName_IgnoredGesturesPropagateToParent, static_cast<int>(::Qt::IgnoredGesturesPropagateToParent)},
    {sipName_GestureStarted, static_cast<int>(::Qt::GestureStarted)},
    {sipName_GestureUpdated, static_cast<int>(::Qt::GestureUpdated)},
    {sipName_GestureFinished, static_cast<int>(::Qt::GestureFinished)},
    {sipName_GestureCanceled, static_cast<int>(::Qt::GestureCanceled)},
    {sipName_TapGesture, static_cast<int>(::Qt::TapGesture)},
    {sipName_TapAndHoldGesture, static_cast<int>(::Qt::TapAndHoldGesture)},
    {sipName_PanGesture, static_cast<int>(::Qt::PanGesture)},
    {sipName_PinchGesture, static_cast<int>(::Qt::PinchGesture)},
    {sipName_SwipeGesture, static_cast<int>(::Qt::SwipeGesture)},
    {sipName_CustomGesture, static_cast<int>(::Qt::CustomGesture)},
    {sipName_color0, static_cast<int>(::Qt::color0)},
    {sipName_color1, static_cast<int>(::Qt::color1)},
    {sipName_black, static_cast<int>(::Qt::black)},
    {sipName_white, static_cast<int>(::Qt::white)},
    {sipName_darkGray, static_cast<int>(::Qt::darkGray)},
    {sipName_gray, static_cast<int>(::Qt::gray)},
    {sipName_lightGray, static_cast<int>(::Qt::lightGray)},
    {sipName_red, static_cast<int>(::Qt::red)},
    {sipName_green, static_cast<int>(::Qt::green)},
    {sipName_blue, static_cast<int>(::Qt::blue)},
    {sipName_cyan, static_cast<int>(::Qt::cyan)},
    {sipName_magenta, static_cast<int>(::Qt::magenta)},
    {sipName_yellow, static_cast<int>(::Qt::yellow)},
    {sipName_darkRed, static_cast<int>(::Qt::darkRed)},
    {sipName_darkGreen, static_cast<int>(::Qt::darkGreen)},
    {sipName_darkBlue, static_cast<int>(::Qt::darkBlue)},
    {sipName_darkCyan, static_cast<int>(::Qt::darkCyan)},
    {sipName_darkMagenta, static_cast<int>(::Qt::darkMagenta)},
    {sipName_darkYellow, static_cast<int>(::Qt::darkYellow)},
    {sipName_transparent, static_cast<int>(::Qt::transparent)},
    {sipName_Round, static_cast<int>(::Qt::HighDpiScaleFactorRoundingPolicy::Round)},
    {sipName_Ceil, static_cast<int>(::Qt::HighDpiScaleFactorRoundingPolicy::Ceil)},
    {sipName_Floor, static_cast<int>(::Qt::HighDpiScaleFactorRoundingPolicy::Floor)},
    {sipName_RoundPreferFloor, static_cast<int>(::Qt::HighDpiScaleFactorRoundingPolicy::RoundPreferFloor)},
    {sipName_PassThrough, static_cast<int>(::Qt::HighDpiScaleFactorRoundingPolicy::PassThrough)},
    {sipName_ExactHit, static_cast<int>(::Qt::ExactHit)},
    {sipName_FuzzyHit, static_cast<int>(::Qt::FuzzyHit)},
    {sipName_AutoColor, static_cast<int>(::Qt::AutoColor)},
    {sipName_ColorOnly, static_cast<int>(::Qt::ColorOnly)},
    {sipName_MonoOnly, static_cast<int>(::Qt::MonoOnly)},
    {sipName_ThresholdAlphaDither, static_cast<int>(::Qt::ThresholdAlphaDither)},
    {sipName_OrderedAlphaDither, static_cast<int>(::Qt::OrderedAlphaDither)},
    {sipName_DiffuseAlphaDither, static_cast<int>(::Qt::DiffuseAlphaDither)},
    {sipName_DiffuseDither, static_cast<int>(::Qt::DiffuseDither)},
    {sipName_OrderedDither, static_cast<int>(::Qt::OrderedDither)},
    {sipName_ThresholdDither, static_cast<int>(::Qt::ThresholdDither)},
    {sipName_AutoDither, static_cast<int>(::Qt::AutoDither)},
    {sipName_PreferDither, static_cast<int>(::Qt::PreferDither)},
    {sipName_AvoidDither, static_cast<int>(::Qt::AvoidDither)},
    {sipName_NoOpaqueDetection, static_cast<int>(::Qt::NoOpaqueDetection)},
    {sipName_NoFormatConversion, static_cast<int>(::Qt::NoFormatConversion)},
    {sipName_ImhNone, static_cast<int>(::Qt::ImhNone)},
    {sipName_ImhHiddenText, static_cast<int>(::Qt::ImhHiddenText)},
    {sipName_ImhNoAutoUppercase, static_cast<int>(::Qt::ImhNoAutoUppercase)},
    {sipName_ImhPreferNumbers, static_cast<int>(::Qt::ImhPreferNumbers)},
    {sipName_ImhPreferUppercase, static_cast<int>(::Qt::ImhPreferUppercase)},
    {sipName_ImhPreferLowercase, static_cast<int>(::Qt::ImhPreferLowercase)},
    {sipName_ImhNoPredictiveText, static_cast<int>(::Qt::ImhNoPredictiveText)},
    {sipName_ImhDigitsOnly, static_cast<int>(::Qt::ImhDigitsOnly)},
    {sipName_ImhFormattedNumbersOnly, static_cast<int>(::Qt::ImhFormattedNumbersOnly)},
    {sipName_ImhUppercaseOnly, static_cast<int>(::Qt::ImhUppercaseOnly)},
    {sipName_ImhLowercaseOnly, static_cast<int>(::Qt::ImhLowercaseOnly)},
    {sipName_ImhDialableCharactersOnly, static_cast<int>(::Qt::ImhDialableCharactersOnly)},
    {sipName_ImhEmailCharactersOnly, static_cast<int>(::Qt::ImhEmailCharactersOnly)},
    {sipName_ImhUrlCharactersOnly, static_cast<int>(::Qt::ImhUrlCharactersOnly)},
    {sipName_ImhExclusiveInputMask, static_cast<int>(::Qt::ImhExclusiveInputMask)},
    {sipName_ImhSensitiveData, static_cast<int>(::Qt::ImhSensitiveData)},
    {sipName_ImhDate, static_cast<int>(::Qt::ImhDate)},
    {sipName_ImhTime, static_cast<int>(::Qt::ImhTime)},
    {sipName_ImhPreferLatin, static_cast<int>(::Qt::ImhPreferLatin)},
    {sipName_ImhLatinOnly, static_cast<int>(::Qt::ImhLatinOnly)},
    {sipName_ImhMultiLine, static_cast<int>(::Qt::ImhMultiLine)},
    {sipName_ImhNoEditMenu, static_cast<int>(::Qt::ImhNoEditMenu)},
    {sipName_ImhNoTextHandles, static_cast<int>(::Qt::ImhNoTextHandles)},
    {sipName_ImFont, static_cast<int>(::Qt::ImFont)},
    {sipName_ImCursorPosition, static_cast<int>(::Qt::ImCursorPosition)},
    {sipName_ImSurroundingText, static_cast<int>(::Qt::ImSurroundingText)},
    {sipName_ImCurrentSelection, static_cast<int>(::Qt::ImCurrentSelection)},
    {sipName_ImMaximumTextLength, static_cast<int>(::Qt::ImMaximumTextLength)},
    {sipName_ImAnchorPosition, static_cast<int>(::Qt::ImAnchorPosition)},
    {sipName_ImEnabled, static_cast<int>(::Qt::ImEnabled)},
    {sipName_ImCursorRectangle, static_cast<int>(::Qt::ImCursorRectangle)},
    {sipName_ImHints, static_cast<int>(::Qt::ImHints)},
    {sipName_ImPreferredLanguage, static_cast<int>(::Qt::ImPreferredLanguage)},
    {sipName_ImPlatformData, static_cast<int>(::Qt::ImPlatformData)},
    {sipName_ImQueryInput, static_cast<int>(::Qt::ImQueryInput)},
    {sipName_ImQueryAll, static_cast<int>(::Qt::ImQueryAll)},
    {sipName_ImAbsolutePosition, static_cast<int>(::Qt::ImAbsolutePosition)},
    {sipName_ImTextBeforeCursor, static_cast<int>(::Qt::ImTextBeforeCursor)},
    {sipName_ImTextAfterCursor, static_cast<int>(::Qt::ImTextAfterCursor)},
    {sipName_ImEnterKeyType, static_cast<int>(::Qt::ImEnterKeyType)},
    {sipName_ImAnchorRectangle, static_cast<int>(::Qt::ImAnchorRectangle)},
    {sipName_ImInputItemClipRectangle, static_cast<int>(::Qt::ImInputItemClipRectangle)},
    {sipName_ImReadOnly, static_cast<int>(::Qt::ImReadOnly)},
    {sipName_DisplayRole, static_cast<int>(::Qt::DisplayRole)},
    {sipName_DecorationRole, static_cast<int>(::Qt::DecorationRole)},
    {sipName_EditRole, static_cast<int>(::Qt::EditRole)},
    {sipName_ToolTipRole, static_cast<int>(::Qt::ToolTipRole)},
    {sipName_StatusTipRole, static_cast<int>(::Qt::StatusTipRole)},
    {sipName_WhatsThisRole, static_cast<int>(::Qt::WhatsThisRole)},
    {sipName_FontRole, static_cast<int>(::Qt::FontRole)},
    {sipName_TextAlignmentRole, static_cast<int>(::Qt::TextAlignmentRole)},
    {sipName_BackgroundRole, static_cast<int>(::Qt::BackgroundRole)},
    {sipName_ForegroundRole, static_cast<int>(::Qt::ForegroundRole)},
    {sipName_CheckStateRole, static_cast<int>(::Qt::CheckStateRole)},
    {sipName_AccessibleTextRole, static_cast<int>(::Qt::AccessibleTextRole)},
    {sipName_AccessibleDescriptionRole, static_cast<int>(::Qt::AccessibleDescriptionRole)},
    {sipName_SizeHintRole, static_cast<int>(::Qt::SizeHintRole)},
    {sipName_InitialSortOrderRole, static_cast<int>(::Qt::InitialSortOrderRole)},
    {sipName_RangeModelAdapterRole, static_cast<int>(::Qt::RangeModelAdapterRole)},
    {sipName_UserRole, static_cast<int>(::Qt::UserRole)},
    {sipName_NoItemFlags, static_cast<int>(::Qt::NoItemFlags)},
    {sipName_ItemIsSelectable, static_cast<int>(::Qt::ItemIsSelectable)},
    {sipName_ItemIsEditable, static_cast<int>(::Qt::ItemIsEditable)},
    {sipName_ItemIsDragEnabled, static_cast<int>(::Qt::ItemIsDragEnabled)},
    {sipName_ItemIsDropEnabled, static_cast<int>(::Qt::ItemIsDropEnabled)},
    {sipName_ItemIsUserCheckable, static_cast<int>(::Qt::ItemIsUserCheckable)},
    {sipName_ItemIsEnabled, static_cast<int>(::Qt::ItemIsEnabled)},
    {sipName_ItemNeverHasChildren, static_cast<int>(::Qt::ItemNeverHasChildren)},
    {sipName_ItemIsUserTristate, static_cast<int>(::Qt::ItemIsUserTristate)},
    {sipName_ItemIsAutoTristate, static_cast<int>(::Qt::ItemIsAutoTristate)},
    {sipName_ContainsItemShape, static_cast<int>(::Qt::ContainsItemShape)},
    {sipName_IntersectsItemShape, static_cast<int>(::Qt::IntersectsItemShape)},
    {sipName_ContainsItemBoundingRect, static_cast<int>(::Qt::ContainsItemBoundingRect)},
    {sipName_IntersectsItemBoundingRect, static_cast<int>(::Qt::IntersectsItemBoundingRect)},
    {sipName_ReplaceSelection, static_cast<int>(::Qt::ReplaceSelection)},
    {sipName_AddToSelection, static_cast<int>(::Qt::AddToSelection)},
    {sipName_Key_Escape, static_cast<int>(::Qt::Key_Escape)},
    {sipName_Key_Tab, static_cast<int>(::Qt::Key_Tab)},
    {sipName_Key_Backtab, static_cast<int>(::Qt::Key_Backtab)},
    {sipName_Key_Backspace, static_cast<int>(::Qt::Key_Backspace)},
    {sipName_Key_Return, static_cast<int>(::Qt::Key_Return)},
    {sipName_Key_Enter, static_cast<int>(::Qt::Key_Enter)},
    {sipName_Key_Insert, static_cast<int>(::Qt::Key_Insert)},
    {sipName_Key_Delete, static_cast<int>(::Qt::Key_Delete)},
    {sipName_Key_Pause, static_cast<int>(::Qt::Key_Pause)},
    {sipName_Key_Print, static_cast<int>(::Qt::Key_Print)},
    {sipName_Key_SysReq, static_cast<int>(::Qt::Key_SysReq)},
    {sipName_Key_Clear, static_cast<int>(::Qt::Key_Clear)},
    {sipName_Key_Home, static_cast<int>(::Qt::Key_Home)},
    {sipName_Key_End, static_cast<int>(::Qt::Key_End)},
    {sipName_Key_Left, static_cast<int>(::Qt::Key_Left)},
    {sipName_Key_Up, static_cast<int>(::Qt::Key_Up)},
    {sipName_Key_Right, static_cast<int>(::Qt::Key_Right)},
    {sipName_Key_Down, static_cast<int>(::Qt::Key_Down)},
    {sipName_Key_PageUp, static_cast<int>(::Qt::Key_PageUp)},
    {sipName_Key_PageDown, static_cast<int>(::Qt::Key_PageDown)},
    {sipName_Key_Shift, static_cast<int>(::Qt::Key_Shift)},
    {sipName_Key_Control, static_cast<int>(::Qt::Key_Control)},
    {sipName_Key_Meta, static_cast<int>(::Qt::Key_Meta)},
    {sipName_Key_Alt, static_cast<int>(::Qt::Key_Alt)},
    {sipName_Key_CapsLock, static_cast<int>(::Qt::Key_CapsLock)},
    {sipName_Key_NumLock, static_cast<int>(::Qt::Key_NumLock)},
    {sipName_Key_ScrollLock, static_cast<int>(::Qt::Key_ScrollLock)},
    {sipName_Key_F1, static_cast<int>(::Qt::Key_F1)},
    {sipName_Key_F2, static_cast<int>(::Qt::Key_F2)},
    {sipName_Key_F3, static_cast<int>(::Qt::Key_F3)},
    {sipName_Key_F4, static_cast<int>(::Qt::Key_F4)},
    {sipName_Key_F5, static_cast<int>(::Qt::Key_F5)},
    {sipName_Key_F6, static_cast<int>(::Qt::Key_F6)},
    {sipName_Key_F7, static_cast<int>(::Qt::Key_F7)},
    {sipName_Key_F8, static_cast<int>(::Qt::Key_F8)},
    {sipName_Key_F9, static_cast<int>(::Qt::Key_F9)},
    {sipName_Key_F10, static_cast<int>(::Qt::Key_F10)},
    {sipName_Key_F11, static_cast<int>(::Qt::Key_F11)},
    {sipName_Key_F12, static_cast<int>(::Qt::Key_F12)},
    {sipName_Key_F13, static_cast<int>(::Qt::Key_F13)},
    {sipName_Key_F14, static_cast<int>(::Qt::Key_F14)},
    {sipName_Key_F15, static_cast<int>(::Qt::Key_F15)},
    {sipName_Key_F16, static_cast<int>(::Qt::Key_F16)},
    {sipName_Key_F17, static_cast<int>(::Qt::Key_F17)},
    {sipName_Key_F18, static_cast<int>(::Qt::Key_F18)},
    {sipName_Key_F19, static_cast<int>(::Qt::Key_F19)},
    {sipName_Key_F20, static_cast<int>(::Qt::Key_F20)},
    {sipName_Key_F21, static_cast<int>(::Qt::Key_F21)},
    {sipName_Key_F22, static_cast<int>(::Qt::Key_F22)},
    {sipName_Key_F23, static_cast<int>(::Qt::Key_F23)},
    {sipName_Key_F24, static_cast<int>(::Qt::Key_F24)},
    {sipName_Key_F25, static_cast<int>(::Qt::Key_F25)},
    {sipName_Key_F26, static_cast<int>(::Qt::Key_F26)},
    {sipName_Key_F27, static_cast<int>(::Qt::Key_F27)},
    {sipName_Key_F28, static_cast<int>(::Qt::Key_F28)},
    {sipName_Key_F29, static_cast<int>(::Qt::Key_F29)},
    {sipName_Key_F30, static_cast<int>(::Qt::Key_F30)},
    {sipName_Key_F31, static_cast<int>(::Qt::Key_F31)},
    {sipName_Key_F32, static_cast<int>(::Qt::Key_F32)},
    {sipName_Key_F33, static_cast<int>(::Qt::Key_F33)},
    {sipName_Key_F34, static_cast<int>(::Qt::Key_F34)},
    {sipName_Key_F35, static_cast<int>(::Qt::Key_F35)},
    {sipName_Key_Super_L, static_cast<int>(::Qt::Key_Super_L)},
    {sipName_Key_Super_R, static_cast<int>(::Qt::Key_Super_R)},
    {sipName_Key_Menu, static_cast<int>(::Qt::Key_Menu)},
    {sipName_Key_Hyper_L, static_cast<int>(::Qt::Key_Hyper_L)},
    {sipName_Key_Hyper_R, static_cast<int>(::Qt::Key_Hyper_R)},
    {sipName_Key_Help, static_cast<int>(::Qt::Key_Help)},
    {sipName_Key_Direction_L, static_cast<int>(::Qt::Key_Direction_L)},
    {sipName_Key_Direction_R, static_cast<int>(::Qt::Key_Direction_R)},
    {sipName_Key_Space, static_cast<int>(::Qt::Key_Space)},
    {sipName_Key_Any, static_cast<int>(::Qt::Key_Any)},
    {sipName_Key_Exclam, static_cast<int>(::Qt::Key_Exclam)},
    {sipName_Key_QuoteDbl, static_cast<int>(::Qt::Key_QuoteDbl)},
    {sipName_Key_NumberSign, static_cast<int>(::Qt::Key_NumberSign)},
    {sipName_Key_Dollar, static_cast<int>(::Qt::Key_Dollar)},
    {sipName_Key_Percent, static_cast<int>(::Qt::Key_Percent)},
    {sipName_Key_Ampersand, static_cast<int>(::Qt::Key_Ampersand)},
    {sipName_Key_Apostrophe, static_cast<int>(::Qt::Key_Apostrophe)},
    {sipName_Key_ParenLeft, static_cast<int>(::Qt::Key_ParenLeft)},
    {sipName_Key_ParenRight, static_cast<int>(::Qt::Key_ParenRight)},
    {sipName_Key_Asterisk, static_cast<int>(::Qt::Key_Asterisk)},
    {sipName_Key_Plus, static_cast<int>(::Qt::Key_Plus)},
    {sipName_Key_Comma, static_cast<int>(::Qt::Key_Comma)},
    {sipName_Key_Minus, static_cast<int>(::Qt::Key_Minus)},
    {sipName_Key_Period, static_cast<int>(::Qt::Key_Period)},
    {sipName_Key_Slash, static_cast<int>(::Qt::Key_Slash)},
    {sipName_Key_0, static_cast<int>(::Qt::Key_0)},
    {sipName_Key_1, static_cast<int>(::Qt::Key_1)},
    {sipName_Key_2, static_cast<int>(::Qt::Key_2)},
    {sipName_Key_3, static_cast<int>(::Qt::Key_3)},
    {sipName_Key_4, static_cast<int>(::Qt::Key_4)},
    {sipName_Key_5, static_cast<int>(::Qt::Key_5)},
    {sipName_Key_6, static_cast<int>(::Qt::Key_6)},
    {sipName_Key_7, static_cast<int>(::Qt::Key_7)},
    {sipName_Key_8, static_cast<int>(::Qt::Key_8)},
    {sipName_Key_9, static_cast<int>(::Qt::Key_9)},
    {sipName_Key_Colon, static_cast<int>(::Qt::Key_Colon)},
    {sipName_Key_Semicolon, static_cast<int>(::Qt::Key_Semicolon)},
    {sipName_Key_Less, static_cast<int>(::Qt::Key_Less)},
    {sipName_Key_Equal, static_cast<int>(::Qt::Key_Equal)},
    {sipName_Key_Greater, static_cast<int>(::Qt::Key_Greater)},
    {sipName_Key_Question, static_cast<int>(::Qt::Key_Question)},
    {sipName_Key_At, static_cast<int>(::Qt::Key_At)},
    {sipName_Key_A, static_cast<int>(::Qt::Key_A)},
    {sipName_Key_B, static_cast<int>(::Qt::Key_B)},
    {sipName_Key_C, static_cast<int>(::Qt::Key_C)},
    {sipName_Key_D, static_cast<int>(::Qt::Key_D)},
    {sipName_Key_E, static_cast<int>(::Qt::Key_E)},
    {sipName_Key_F, static_cast<int>(::Qt::Key_F)},
    {sipName_Key_G, static_cast<int>(::Qt::Key_G)},
    {sipName_Key_H, static_cast<int>(::Qt::Key_H)},
    {sipName_Key_I, static_cast<int>(::Qt::Key_I)},
    {sipName_Key_J, static_cast<int>(::Qt::Key_J)},
    {sipName_Key_K, static_cast<int>(::Qt::Key_K)},
    {sipName_Key_L, static_cast<int>(::Qt::Key_L)},
    {sipName_Key_M, static_cast<int>(::Qt::Key_M)},
    {sipName_Key_N, static_cast<int>(::Qt::Key_N)},
    {sipName_Key_O, static_cast<int>(::Qt::Key_O)},
    {sipName_Key_P, static_cast<int>(::Qt::Key_P)},
    {sipName_Key_Q, static_cast<int>(::Qt::Key_Q)},
    {sipName_Key_R, static_cast<int>(::Qt::Key_R)},
    {sipName_Key_S, static_cast<int>(::Qt::Key_S)},
    {sipName_Key_T, static_cast<int>(::Qt::Key_T)},
    {sipName_Key_U, static_cast<int>(::Qt::Key_U)},
    {sipName_Key_V, static_cast<int>(::Qt::Key_V)},
    {sipName_Key_W, static_cast<int>(::Qt::Key_W)},
    {sipName_Key_X, static_cast<int>(::Qt::Key_X)},
    {sipName_Key_Y, static_cast<int>(::Qt::Key_Y)},
    {sipName_Key_Z, static_cast<int>(::Qt::Key_Z)},
    {sipName_Key_BracketLeft, static_cast<int>(::Qt::Key_BracketLeft)},
    {sipName_Key_Backslash, static_cast<int>(::Qt::Key_Backslash)},
    {sipName_Key_BracketRight, static_cast<int>(::Qt::Key_BracketRight)},
    {sipName_Key_AsciiCircum, static_cast<int>(::Qt::Key_AsciiCircum)},
    {sipName_Key_Underscore, static_cast<int>(::Qt::Key_Underscore)},
    {sipName_Key_QuoteLeft, static_cast<int>(::Qt::Key_QuoteLeft)},
    {sipName_Key_BraceLeft, static_cast<int>(::Qt::Key_BraceLeft)},
    {sipName_Key_Bar, static_cast<int>(::Qt::Key_Bar)},
    {sipName_Key_BraceRight, static_cast<int>(::Qt::Key_BraceRight)},
    {sipName_Key_AsciiTilde, static_cast<int>(::Qt::Key_AsciiTilde)},
    {sipName_Key_nobreakspace, static_cast<int>(::Qt::Key_nobreakspace)},
    {sipName_Key_exclamdown, static_cast<int>(::Qt::Key_exclamdown)},
    {sipName_Key_cent, static_cast<int>(::Qt::Key_cent)},
    {sipName_Key_sterling, static_cast<int>(::Qt::Key_sterling)},
    {sipName_Key_currency, static_cast<int>(::Qt::Key_currency)},
    {sipName_Key_yen, static_cast<int>(::Qt::Key_yen)},
    {sipName_Key_brokenbar, static_cast<int>(::Qt::Key_brokenbar)},
    {sipName_Key_section, static_cast<int>(::Qt::Key_section)},
    {sipName_Key_diaeresis, static_cast<int>(::Qt::Key_diaeresis)},
    {sipName_Key_copyright, static_cast<int>(::Qt::Key_copyright)},
    {sipName_Key_ordfeminine, static_cast<int>(::Qt::Key_ordfeminine)},
    {sipName_Key_guillemotleft, static_cast<int>(::Qt::Key_guillemotleft)},
    {sipName_Key_notsign, static_cast<int>(::Qt::Key_notsign)},
    {sipName_Key_hyphen, static_cast<int>(::Qt::Key_hyphen)},
    {sipName_Key_registered, static_cast<int>(::Qt::Key_registered)},
    {sipName_Key_macron, static_cast<int>(::Qt::Key_macron)},
    {sipName_Key_degree, static_cast<int>(::Qt::Key_degree)},
    {sipName_Key_plusminus, static_cast<int>(::Qt::Key_plusminus)},
    {sipName_Key_twosuperior, static_cast<int>(::Qt::Key_twosuperior)},
    {sipName_Key_threesuperior, static_cast<int>(::Qt::Key_threesuperior)},
    {sipName_Key_acute, static_cast<int>(::Qt::Key_acute)},
    {sipName_Key_mu, static_cast<int>(::Qt::Key_mu)},
    {sipName_Key_paragraph, static_cast<int>(::Qt::Key_paragraph)},
    {sipName_Key_periodcentered, static_cast<int>(::Qt::Key_periodcentered)},
    {sipName_Key_cedilla, static_cast<int>(::Qt::Key_cedilla)},
    {sipName_Key_onesuperior, static_cast<int>(::Qt::Key_onesuperior)},
    {sipName_Key_masculine, static_cast<int>(::Qt::Key_masculine)},
    {sipName_Key_guillemotright, static_cast<int>(::Qt::Key_guillemotright)},
    {sipName_Key_onequarter, static_cast<int>(::Qt::Key_onequarter)},
    {sipName_Key_onehalf, static_cast<int>(::Qt::Key_onehalf)},
    {sipName_Key_threequarters, static_cast<int>(::Qt::Key_threequarters)},
    {sipName_Key_questiondown, static_cast<int>(::Qt::Key_questiondown)},
    {sipName_Key_Agrave, static_cast<int>(::Qt::Key_Agrave)},
    {sipName_Key_Aacute, static_cast<int>(::Qt::Key_Aacute)},
    {sipName_Key_Acircumflex, static_cast<int>(::Qt::Key_Acircumflex)},
    {sipName_Key_Atilde, static_cast<int>(::Qt::Key_Atilde)},
    {sipName_Key_Adiaeresis, static_cast<int>(::Qt::Key_Adiaeresis)},
    {sipName_Key_Aring, static_cast<int>(::Qt::Key_Aring)},
    {sipName_Key_AE, static_cast<int>(::Qt::Key_AE)},
    {sipName_Key_Ccedilla, static_cast<int>(::Qt::Key_Ccedilla)},
    {sipName_Key_Egrave, static_cast<int>(::Qt::Key_Egrave)},
    {sipName_Key_Eacute, static_cast<int>(::Qt::Key_Eacute)},
    {sipName_Key_Ecircumflex, static_cast<int>(::Qt::Key_Ecircumflex)},
    {sipName_Key_Ediaeresis, static_cast<int>(::Qt::Key_Ediaeresis)},
    {sipName_Key_Igrave, static_cast<int>(::Qt::Key_Igrave)},
    {sipName_Key_Iacute, static_cast<int>(::Qt::Key_Iacute)},
    {sipName_Key_Icircumflex, static_cast<int>(::Qt::Key_Icircumflex)},
    {sipName_Key_Idiaeresis, static_cast<int>(::Qt::Key_Idiaeresis)},
    {sipName_Key_ETH, static_cast<int>(::Qt::Key_ETH)},
    {sipName_Key_Ntilde, static_cast<int>(::Qt::Key_Ntilde)},
    {sipName_Key_Ograve, static_cast<int>(::Qt::Key_Ograve)},
    {sipName_Key_Oacute, static_cast<int>(::Qt::Key_Oacute)},
    {sipName_Key_Ocircumflex, static_cast<int>(::Qt::Key_Ocircumflex)},
    {sipName_Key_Otilde, static_cast<int>(::Qt::Key_Otilde)},
    {sipName_Key_Odiaeresis, static_cast<int>(::Qt::Key_Odiaeresis)},
    {sipName_Key_multiply, static_cast<int>(::Qt::Key_multiply)},
    {sipName_Key_Ooblique, static_cast<int>(::Qt::Key_Ooblique)},
    {sipName_Key_Ugrave, static_cast<int>(::Qt::Key_Ugrave)},
    {sipName_Key_Uacute, static_cast<int>(::Qt::Key_Uacute)},
    {sipName_Key_Ucircumflex, static_cast<int>(::Qt::Key_Ucircumflex)},
    {sipName_Key_Udiaeresis, static_cast<int>(::Qt::Key_Udiaeresis)},
    {sipName_Key_Yacute, static_cast<int>(::Qt::Key_Yacute)},
    {sipName_Key_THORN, static_cast<int>(::Qt::Key_THORN)},
    {sipName_Key_ssharp, static_cast<int>(::Qt::Key_ssharp)},
    {sipName_Key_division, static_cast<int>(::Qt::Key_division)},
    {sipName_Key_ydiaeresis, static_cast<int>(::Qt::Key_ydiaeresis)},
    {sipName_Key_AltGr, static_cast<int>(::Qt::Key_AltGr)},
    {sipName_Key_Multi_key, static_cast<int>(::Qt::Key_Multi_key)},
    {sipName_Key_Codeinput, static_cast<int>(::Qt::Key_Codeinput)},
    {sipName_Key_SingleCandidate, static_cast<int>(::Qt::Key_SingleCandidate)},
    {sipName_Key_MultipleCandidate, static_cast<int>(::Qt::Key_MultipleCandidate)},
    {sipName_Key_PreviousCandidate, static_cast<int>(::Qt::Key_PreviousCandidate)},
    {sipName_Key_Mode_switch, static_cast<int>(::Qt::Key_Mode_switch)},
    {sipName_Key_Kanji, static_cast<int>(::Qt::Key_Kanji)},
    {sipName_Key_Muhenkan, static_cast<int>(::Qt::Key_Muhenkan)},
    {sipName_Key_Henkan, static_cast<int>(::Qt::Key_Henkan)},
    {sipName_Key_Romaji, static_cast<int>(::Qt::Key_Romaji)},
    {sipName_Key_Hiragana, static_cast<int>(::Qt::Key_Hiragana)},
    {sipName_Key_Katakana, static_cast<int>(::Qt::Key_Katakana)},
    {sipName_Key_Hiragana_Katakana, static_cast<int>(::Qt::Key_Hiragana_Katakana)},
    {sipName_Key_Zenkaku, static_cast<int>(::Qt::Key_Zenkaku)},
    {sipName_Key_Hankaku, static_cast<int>(::Qt::Key_Hankaku)},
    {sipName_Key_Zenkaku_Hankaku, static_cast<int>(::Qt::Key_Zenkaku_Hankaku)},
    {sipName_Key_Touroku, static_cast<int>(::Qt::Key_Touroku)},
    {sipName_Key_Massyo, static_cast<int>(::Qt::Key_Massyo)},
    {sipName_Key_Kana_Lock, static_cast<int>(::Qt::Key_Kana_Lock)},
    {sipName_Key_Kana_Shift, static_cast<int>(::Qt::Key_Kana_Shift)},
    {sipName_Key_Eisu_Shift, static_cast<int>(::Qt::Key_Eisu_Shift)},
    {sipName_Key_Eisu_toggle, static_cast<int>(::Qt::Key_Eisu_toggle)},
    {sipName_Key_Hangul, static_cast<int>(::Qt::Key_Hangul)},
    {sipName_Key_Hangul_Start, static_cast<int>(::Qt::Key_Hangul_Start)},
    {sipName_Key_Hangul_End, static_cast<int>(::Qt::Key_Hangul_End)},
    {sipName_Key_Hangul_Hanja, static_cast<int>(::Qt::Key_Hangul_Hanja)},
    {sipName_Key_Hangul_Jamo, static_cast<int>(::Qt::Key_Hangul_Jamo)},
    {sipName_Key_Hangul_Romaja, static_cast<int>(::Qt::Key_Hangul_Romaja)},
    {sipName_Key_Hangul_Jeonja, static_cast<int>(::Qt::Key_Hangul_Jeonja)},
    {sipName_Key_Hangul_Banja, static_cast<int>(::Qt::Key_Hangul_Banja)},
    {sipName_Key_Hangul_PreHanja, static_cast<int>(::Qt::Key_Hangul_PreHanja)},
    {sipName_Key_Hangul_PostHanja, static_cast<int>(::Qt::Key_Hangul_PostHanja)},
    {sipName_Key_Hangul_Special, static_cast<int>(::Qt::Key_Hangul_Special)},
    {sipName_Key_Dead_Grave, static_cast<int>(::Qt::Key_Dead_Grave)},
    {sipName_Key_Dead_Acute, static_cast<int>(::Qt::Key_Dead_Acute)},
    {sipName_Key_Dead_Circumflex, static_cast<int>(::Qt::Key_Dead_Circumflex)},
    {sipName_Key_Dead_Tilde, static_cast<int>(::Qt::Key_Dead_Tilde)},
    {sipName_Key_Dead_Macron, static_cast<int>(::Qt::Key_Dead_Macron)},
    {sipName_Key_Dead_Breve, static_cast<int>(::Qt::Key_Dead_Breve)},
    {sipName_Key_Dead_Abovedot, static_cast<int>(::Qt::Key_Dead_Abovedot)},
    {sipName_Key_Dead_Diaeresis, static_cast<int>(::Qt::Key_Dead_Diaeresis)},
    {sipName_Key_Dead_Abovering, static_cast<int>(::Qt::Key_Dead_Abovering)},
    {sipName_Key_Dead_Doubleacute, static_cast<int>(::Qt::Key_Dead_Doubleacute)},
    {sipName_Key_Dead_Caron, static_cast<int>(::Qt::Key_Dead_Caron)},
    {sipName_Key_Dead_Cedilla, static_cast<int>(::Qt::Key_Dead_Cedilla)},
    {sipName_Key_Dead_Ogonek, static_cast<int>(::Qt::Key_Dead_Ogonek)},
    {sipName_Key_Dead_Iota, static_cast<int>(::Qt::Key_Dead_Iota)},
    {sipName_Key_Dead_Voiced_Sound, static_cast<int>(::Qt::Key_Dead_Voiced_Sound)},
    {sipName_Key_Dead_Semivoiced_Sound, static_cast<int>(::Qt::Key_Dead_Semivoiced_Sound)},
    {sipName_Key_Dead_Belowdot, static_cast<int>(::Qt::Key_Dead_Belowdot)},
    {sipName_Key_Dead_Hook, static_cast<int>(::Qt::Key_Dead_Hook)},
    {sipName_Key_Dead_Horn, static_cast<int>(::Qt::Key_Dead_Horn)},
    {sipName_Key_Back, static_cast<int>(::Qt::Key_Back)},
    {sipName_Key_Forward, static_cast<int>(::Qt::Key_Forward)},
    {sipName_Key_Stop, static_cast<int>(::Qt::Key_Stop)},
    {sipName_Key_Refresh, static_cast<int>(::Qt::Key_Refresh)},
    {sipName_Key_VolumeDown, static_cast<int>(::Qt::Key_VolumeDown)},
    {sipName_Key_VolumeMute, static_cast<int>(::Qt::Key_VolumeMute)},
    {sipName_Key_VolumeUp, static_cast<int>(::Qt::Key_VolumeUp)},
    {sipName_Key_BassBoost, static_cast<int>(::Qt::Key_BassBoost)},
    {sipName_Key_BassUp, static_cast<int>(::Qt::Key_BassUp)},
    {sipName_Key_BassDown, static_cast<int>(::Qt::Key_BassDown)},
    {sipName_Key_TrebleUp, static_cast<int>(::Qt::Key_TrebleUp)},
    {sipName_Key_TrebleDown, static_cast<int>(::Qt::Key_TrebleDown)},
    {sipName_Key_MediaPlay, static_cast<int>(::Qt::Key_MediaPlay)},
    {sipName_Key_MediaStop, static_cast<int>(::Qt::Key_MediaStop)},
    {sipName_Key_MediaPrevious, static_cast<int>(::Qt::Key_MediaPrevious)},
    {sipName_Key_MediaNext, static_cast<int>(::Qt::Key_MediaNext)},
    {sipName_Key_MediaRecord, static_cast<int>(::Qt::Key_MediaRecord)},
    {sipName_Key_HomePage, static_cast<int>(::Qt::Key_HomePage)},
    {sipName_Key_Favorites, static_cast<int>(::Qt::Key_Favorites)},
    {sipName_Key_Search, static_cast<int>(::Qt::Key_Search)},
    {sipName_Key_Standby, static_cast<int>(::Qt::Key_Standby)},
    {sipName_Key_OpenUrl, static_cast<int>(::Qt::Key_OpenUrl)},
    {sipName_Key_LaunchMail, static_cast<int>(::Qt::Key_LaunchMail)},
    {sipName_Key_LaunchMedia, static_cast<int>(::Qt::Key_LaunchMedia)},
    {sipName_Key_Launch0, static_cast<int>(::Qt::Key_Launch0)},
    {sipName_Key_Launch1, static_cast<int>(::Qt::Key_Launch1)},
    {sipName_Key_Launch2, static_cast<int>(::Qt::Key_Launch2)},
    {sipName_Key_Launch3, static_cast<int>(::Qt::Key_Launch3)},
    {sipName_Key_Launch4, static_cast<int>(::Qt::Key_Launch4)},
    {sipName_Key_Launch5, static_cast<int>(::Qt::Key_Launch5)},
    {sipName_Key_Launch6, static_cast<int>(::Qt::Key_Launch6)},
    {sipName_Key_Launch7, static_cast<int>(::Qt::Key_Launch7)},
    {sipName_Key_Launch8, static_cast<int>(::Qt::Key_Launch8)},
    {sipName_Key_Launch9, static_cast<int>(::Qt::Key_Launch9)},
    {sipName_Key_LaunchA, static_cast<int>(::Qt::Key_LaunchA)},
    {sipName_Key_LaunchB, static_cast<int>(::Qt::Key_LaunchB)},
    {sipName_Key_LaunchC, static_cast<int>(::Qt::Key_LaunchC)},
    {sipName_Key_LaunchD, static_cast<int>(::Qt::Key_LaunchD)},
    {sipName_Key_LaunchE, static_cast<int>(::Qt::Key_LaunchE)},
    {sipName_Key_LaunchF, static_cast<int>(::Qt::Key_LaunchF)},
    {sipName_Key_MediaLast, static_cast<int>(::Qt::Key_MediaLast)},
    {sipName_Key_Select, static_cast<int>(::Qt::Key_Select)},
    {sipName_Key_Yes, static_cast<int>(::Qt::Key_Yes)},
    {sipName_Key_No, static_cast<int>(::Qt::Key_No)},
    {sipName_Key_Context1, static_cast<int>(::Qt::Key_Context1)},
    {sipName_Key_Context2, static_cast<int>(::Qt::Key_Context2)},
    {sipName_Key_Context3, static_cast<int>(::Qt::Key_Context3)},
    {sipName_Key_Context4, static_cast<int>(::Qt::Key_Context4)},
    {sipName_Key_Call, static_cast<int>(::Qt::Key_Call)},
    {sipName_Key_Hangup, static_cast<int>(::Qt::Key_Hangup)},
    {sipName_Key_Flip, static_cast<int>(::Qt::Key_Flip)},
    {sipName_Key_unknown, static_cast<int>(::Qt::Key_unknown)},
    {sipName_Key_Execute, static_cast<int>(::Qt::Key_Execute)},
    {sipName_Key_Printer, static_cast<int>(::Qt::Key_Printer)},
    {sipName_Key_Play, static_cast<int>(::Qt::Key_Play)},
    {sipName_Key_Sleep, static_cast<int>(::Qt::Key_Sleep)},
    {sipName_Key_Zoom, static_cast<int>(::Qt::Key_Zoom)},
    {sipName_Key_Cancel, static_cast<int>(::Qt::Key_Cancel)},
    {sipName_Key_MonBrightnessUp, static_cast<int>(::Qt::Key_MonBrightnessUp)},
    {sipName_Key_MonBrightnessDown, static_cast<int>(::Qt::Key_MonBrightnessDown)},
    {sipName_Key_KeyboardLightOnOff, static_cast<int>(::Qt::Key_KeyboardLightOnOff)},
    {sipName_Key_KeyboardBrightnessUp, static_cast<int>(::Qt::Key_KeyboardBrightnessUp)},
    {sipName_Key_KeyboardBrightnessDown, static_cast<int>(::Qt::Key_KeyboardBrightnessDown)},
    {sipName_Key_PowerOff, static_cast<int>(::Qt::Key_PowerOff)},
    {sipName_Key_WakeUp, static_cast<int>(::Qt::Key_WakeUp)},
    {sipName_Key_Eject, static_cast<int>(::Qt::Key_Eject)},
    {sipName_Key_ScreenSaver, static_cast<int>(::Qt::Key_ScreenSaver)},
    {sipName_Key_WWW, static_cast<int>(::Qt::Key_WWW)},
    {sipName_Key_Memo, static_cast<int>(::Qt::Key_Memo)},
    {sipName_Key_LightBulb, static_cast<int>(::Qt::Key_LightBulb)},
    {sipName_Key_Shop, static_cast<int>(::Qt::Key_Shop)},
    {sipName_Key_History, static_cast<int>(::Qt::Key_History)},
    {sipName_Key_AddFavorite, static_cast<int>(::Qt::Key_AddFavorite)},
    {sipName_Key_HotLinks, static_cast<int>(::Qt::Key_HotLinks)},
    {sipName_Key_BrightnessAdjust, static_cast<int>(::Qt::Key_BrightnessAdjust)},
    {sipName_Key_Finance, static_cast<int>(::Qt::Key_Finance)},
    {sipName_Key_Community, static_cast<int>(::Qt::Key_Community)},
    {sipName_Key_AudioRewind, static_cast<int>(::Qt::Key_AudioRewind)},
    {sipName_Key_BackForward, static_cast<int>(::Qt::Key_BackForward)},
    {sipName_Key_ApplicationLeft, static_cast<int>(::Qt::Key_ApplicationLeft)},
    {sipName_Key_ApplicationRight, static_cast<int>(::Qt::Key_ApplicationRight)},
    {sipName_Key_Book, static_cast<int>(::Qt::Key_Book)},
    {sipName_Key_CD, static_cast<int>(::Qt::Key_CD)},
    {sipName_Key_Calculator, static_cast<int>(::Qt::Key_Calculator)},
    {sipName_Key_ToDoList, static_cast<int>(::Qt::Key_ToDoList)},
    {sipName_Key_ClearGrab, static_cast<int>(::Qt::Key_ClearGrab)},
    {sipName_Key_Close, static_cast<int>(::Qt::Key_Close)},
    {sipName_Key_Copy, static_cast<int>(::Qt::Key_Copy)},
    {sipName_Key_Cut, static_cast<int>(::Qt::Key_Cut)},
    {sipName_Key_Display, static_cast<int>(::Qt::Key_Display)},
    {sipName_Key_DOS, static_cast<int>(::Qt::Key_DOS)},
    {sipName_Key_Documents, static_cast<int>(::Qt::Key_Documents)},
    {sipName_Key_Excel, static_cast<int>(::Qt::Key_Excel)},
    {sipName_Key_Explorer, static_cast<int>(::Qt::Key_Explorer)},
    {sipName_Key_Game, static_cast<int>(::Qt::Key_Game)},
    {sipName_Key_Go, static_cast<int>(::Qt::Key_Go)},
    {sipName_Key_iTouch, static_cast<int>(::Qt::Key_iTouch)},
    {sipName_Key_LogOff, static_cast<int>(::Qt::Key_LogOff)},
    {sipName_Key_Market, static_cast<int>(::Qt::Key_Market)},
    {sipName_Key_Meeting, static_cast<int>(::Qt::Key_Meeting)},
    {sipName_Key_MenuKB, static_cast<int>(::Qt::Key_MenuKB)},
    {sipName_Key_MenuPB, static_cast<int>(::Qt::Key_MenuPB)},
    {sipName_Key_MySites, static_cast<int>(::Qt::Key_MySites)},
    {sipName_Key_News, static_cast<int>(::Qt::Key_News)},
    {sipName_Key_OfficeHome, static_cast<int>(::Qt::Key_OfficeHome)},
    {sipName_Key_Option, static_cast<int>(::Qt::Key_Option)},
    {sipName_Key_Paste, static_cast<int>(::Qt::Key_Paste)},
    {sipName_Key_Phone, static_cast<int>(::Qt::Key_Phone)},
    {sipName_Key_Calendar, static_cast<int>(::Qt::Key_Calendar)},
    {sipName_Key_Reply, static_cast<int>(::Qt::Key_Reply)},
    {sipName_Key_Reload, static_cast<int>(::Qt::Key_Reload)},
    {sipName_Key_RotateWindows, static_cast<int>(::Qt::Key_RotateWindows)},
    {sipName_Key_RotationPB, static_cast<int>(::Qt::Key_RotationPB)},
    {sipName_Key_RotationKB, static_cast<int>(::Qt::Key_RotationKB)},
    {sipName_Key_Save, static_cast<int>(::Qt::Key_Save)},
    {sipName_Key_Send, static_cast<int>(::Qt::Key_Send)},
    {sipName_Key_Spell, static_cast<int>(::Qt::Key_Spell)},
    {sipName_Key_SplitScreen, static_cast<int>(::Qt::Key_SplitScreen)},
    {sipName_Key_Support, static_cast<int>(::Qt::Key_Support)},
    {sipName_Key_TaskPane, static_cast<int>(::Qt::Key_TaskPane)},
    {sipName_Key_Terminal, static_cast<int>(::Qt::Key_Terminal)},
    {sipName_Key_Tools, static_cast<int>(::Qt::Key_Tools)},
    {sipName_Key_Travel, static_cast<int>(::Qt::Key_Travel)},
    {sipName_Key_Video, static_cast<int>(::Qt::Key_Video)},
    {sipName_Key_Word, static_cast<int>(::Qt::Key_Word)},
    {sipName_Key_Xfer, static_cast<int>(::Qt::Key_Xfer)},
    {sipName_Key_ZoomIn, static_cast<int>(::Qt::Key_ZoomIn)},
    {sipName_Key_ZoomOut, static_cast<int>(::Qt::Key_ZoomOut)},
    {sipName_Key_Away, static_cast<int>(::Qt::Key_Away)},
    {sipName_Key_Messenger, static_cast<int>(::Qt::Key_Messenger)},
    {sipName_Key_WebCam, static_cast<int>(::Qt::Key_WebCam)},
    {sipName_Key_MailForward, static_cast<int>(::Qt::Key_MailForward)},
    {sipName_Key_Pictures, static_cast<int>(::Qt::Key_Pictures)},
    {sipName_Key_Music, static_cast<int>(::Qt::Key_Music)},
    {sipName_Key_Battery, static_cast<int>(::Qt::Key_Battery)},
    {sipName_Key_Bluetooth, static_cast<int>(::Qt::Key_Bluetooth)},
    {sipName_Key_WLAN, static_cast<int>(::Qt::Key_WLAN)},
    {sipName_Key_UWB, static_cast<int>(::Qt::Key_UWB)},
    {sipName_Key_AudioForward, static_cast<int>(::Qt::Key_AudioForward)},
    {sipName_Key_AudioRepeat, static_cast<int>(::Qt::Key_AudioRepeat)},
    {sipName_Key_AudioRandomPlay, static_cast<int>(::Qt::Key_AudioRandomPlay)},
    {sipName_Key_Subtitle, static_cast<int>(::Qt::Key_Subtitle)},
    {sipName_Key_AudioCycleTrack, static_cast<int>(::Qt::Key_AudioCycleTrack)},
    {sipName_Key_Time, static_cast<int>(::Qt::Key_Time)},
    {sipName_Key_Hibernate, static_cast<int>(::Qt::Key_Hibernate)},
    {sipName_Key_View, static_cast<int>(::Qt::Key_View)},
    {sipName_Key_TopMenu, static_cast<int>(::Qt::Key_TopMenu)},
    {sipName_Key_PowerDown, static_cast<int>(::Qt::Key_PowerDown)},
    {sipName_Key_Suspend, static_cast<int>(::Qt::Key_Suspend)},
    {sipName_Key_ContrastAdjust, static_cast<int>(::Qt::Key_ContrastAdjust)},
    {sipName_Key_MediaPause, static_cast<int>(::Qt::Key_MediaPause)},
    {sipName_Key_MediaTogglePlayPause, static_cast<int>(::Qt::Key_MediaTogglePlayPause)},
    {sipName_Key_LaunchG, static_cast<int>(::Qt::Key_LaunchG)},
    {sipName_Key_LaunchH, static_cast<int>(::Qt::Key_LaunchH)},
    {sipName_Key_ToggleCallHangup, static_cast<int>(::Qt::Key_ToggleCallHangup)},
    {sipName_Key_VoiceDial, static_cast<int>(::Qt::Key_VoiceDial)},
    {sipName_Key_LastNumberRedial, static_cast<int>(::Qt::Key_LastNumberRedial)},
    {sipName_Key_Camera, static_cast<int>(::Qt::Key_Camera)},
    {sipName_Key_CameraFocus, static_cast<int>(::Qt::Key_CameraFocus)},
    {sipName_Key_TouchpadToggle, static_cast<int>(::Qt::Key_TouchpadToggle)},
    {sipName_Key_TouchpadOn, static_cast<int>(::Qt::Key_TouchpadOn)},
    {sipName_Key_TouchpadOff, static_cast<int>(::Qt::Key_TouchpadOff)},
    {sipName_Key_MicMute, static_cast<int>(::Qt::Key_MicMute)},
    {sipName_Key_Red, static_cast<int>(::Qt::Key_Red)},
    {sipName_Key_Green, static_cast<int>(::Qt::Key_Green)},
    {sipName_Key_Yellow, static_cast<int>(::Qt::Key_Yellow)},
    {sipName_Key_Blue, static_cast<int>(::Qt::Key_Blue)},
    {sipName_Key_ChannelUp, static_cast<int>(::Qt::Key_ChannelUp)},
    {sipName_Key_ChannelDown, static_cast<int>(::Qt::Key_ChannelDown)},
    {sipName_Key_Guide, static_cast<int>(::Qt::Key_Guide)},
    {sipName_Key_Info, static_cast<int>(::Qt::Key_Info)},
    {sipName_Key_Settings, static_cast<int>(::Qt::Key_Settings)},
    {sipName_Key_Exit, static_cast<int>(::Qt::Key_Exit)},
    {sipName_Key_MicVolumeUp, static_cast<int>(::Qt::Key_MicVolumeUp)},
    {sipName_Key_MicVolumeDown, static_cast<int>(::Qt::Key_MicVolumeDown)},
    {sipName_Key_New, static_cast<int>(::Qt::Key_New)},
    {sipName_Key_Open, static_cast<int>(::Qt::Key_Open)},
    {sipName_Key_Find, static_cast<int>(::Qt::Key_Find)},
    {sipName_Key_Undo, static_cast<int>(::Qt::Key_Undo)},
    {sipName_Key_Redo, static_cast<int>(::Qt::Key_Redo)},
    {sipName_Key_Dead_Stroke, static_cast<int>(::Qt::Key_Dead_Stroke)},
    {sipName_Key_Dead_Abovecomma, static_cast<int>(::Qt::Key_Dead_Abovecomma)},
    {sipName_Key_Dead_Abovereversedcomma, static_cast<int>(::Qt::Key_Dead_Abovereversedcomma)},
    {sipName_Key_Dead_Doublegrave, static_cast<int>(::Qt::Key_Dead_Doublegrave)},
    {sipName_Key_Dead_Belowring, static_cast<int>(::Qt::Key_Dead_Belowring)},
    {sipName_Key_Dead_Belowmacron, static_cast<int>(::Qt::Key_Dead_Belowmacron)},
    {sipName_Key_Dead_Belowcircumflex, static_cast<int>(::Qt::Key_Dead_Belowcircumflex)},
    {sipName_Key_Dead_Belowtilde, static_cast<int>(::Qt::Key_Dead_Belowtilde)},
    {sipName_Key_Dead_Belowbreve, static_cast<int>(::Qt::Key_Dead_Belowbreve)},
    {sipName_Key_Dead_Belowdiaeresis, static_cast<int>(::Qt::Key_Dead_Belowdiaeresis)},
    {sipName_Key_Dead_Invertedbreve, static_cast<int>(::Qt::Key_Dead_Invertedbreve)},
    {sipName_Key_Dead_Belowcomma, static_cast<int>(::Qt::Key_Dead_Belowcomma)},
    {sipName_Key_Dead_Currency, static_cast<int>(::Qt::Key_Dead_Currency)},
    {sipName_Key_Dead_a, static_cast<int>(::Qt::Key_Dead_a)},
    {sipName_Key_Dead_A, static_cast<int>(::Qt::Key_Dead_A)},
    {sipName_Key_Dead_e, static_cast<int>(::Qt::Key_Dead_e)},
    {sipName_Key_Dead_E, static_cast<int>(::Qt::Key_Dead_E)},
    {sipName_Key_Dead_i, static_cast<int>(::Qt::Key_Dead_i)},
    {sipName_Key_Dead_I, static_cast<int>(::Qt::Key_Dead_I)},
    {sipName_Key_Dead_o, static_cast<int>(::Qt::Key_Dead_o)},
    {sipName_Key_Dead_O, static_cast<int>(::Qt::Key_Dead_O)},
    {sipName_Key_Dead_u, static_cast<int>(::Qt::Key_Dead_u)},
    {sipName_Key_Dead_U, static_cast<int>(::Qt::Key_Dead_U)},
    {sipName_Key_Dead_Small_Schwa, static_cast<int>(::Qt::Key_Dead_Small_Schwa)},
    {sipName_Key_Dead_Capital_Schwa, static_cast<int>(::Qt::Key_Dead_Capital_Schwa)},
    {sipName_Key_Dead_Greek, static_cast<int>(::Qt::Key_Dead_Greek)},
    {sipName_Key_Dead_Lowline, static_cast<int>(::Qt::Key_Dead_Lowline)},
    {sipName_Key_Dead_Aboveverticalline, static_cast<int>(::Qt::Key_Dead_Aboveverticalline)},
    {sipName_Key_Dead_Belowverticalline, static_cast<int>(::Qt::Key_Dead_Belowverticalline)},
    {sipName_Key_Dead_Longsolidusoverlay, static_cast<int>(::Qt::Key_Dead_Longsolidusoverlay)},
    {sipName_Key_micro, static_cast<int>(::Qt::Key_micro)},
    {sipName_Key_Keyboard, static_cast<int>(::Qt::Key_Keyboard)},
    {sipName_NoModifier, static_cast<int>(::Qt::NoModifier)},
    {sipName_ShiftModifier, static_cast<int>(::Qt::ShiftModifier)},
    {sipName_ControlModifier, static_cast<int>(::Qt::ControlModifier)},
    {sipName_AltModifier, static_cast<int>(::Qt::AltModifier)},
    {sipName_MetaModifier, static_cast<int>(::Qt::MetaModifier)},
    {sipName_KeypadModifier, static_cast<int>(::Qt::KeypadModifier)},
    {sipName_GroupSwitchModifier, static_cast<int>(::Qt::GroupSwitchModifier)},
    {sipName_KeyboardModifierMask, static_cast<int>(::Qt::KeyboardModifierMask)},
    {sipName_LeftToRight, static_cast<int>(::Qt::LeftToRight)},
    {sipName_RightToLeft, static_cast<int>(::Qt::RightToLeft)},
    {sipName_LayoutDirectionAuto, static_cast<int>(::Qt::LayoutDirectionAuto)},
    {sipName_MaskInColor, static_cast<int>(::Qt::MaskInColor)},
    {sipName_MaskOutColor, static_cast<int>(::Qt::MaskOutColor)},
    {sipName_MatchExactly, static_cast<int>(::Qt::MatchExactly)},
    {sipName_MatchFixedString, static_cast<int>(::Qt::MatchFixedString)},
    {sipName_MatchContains, static_cast<int>(::Qt::MatchContains)},
    {sipName_MatchStartsWith, static_cast<int>(::Qt::MatchStartsWith)},
    {sipName_MatchEndsWith, static_cast<int>(::Qt::MatchEndsWith)},
    {sipName_MatchWildcard, static_cast<int>(::Qt::MatchWildcard)},
    {sipName_MatchCaseSensitive, static_cast<int>(::Qt::MatchCaseSensitive)},
    {sipName_MatchWrap, static_cast<int>(::Qt::MatchWrap)},
    {sipName_MatchRecursive, static_cast<int>(::Qt::MatchRecursive)},
    {sipName_MatchRegularExpression, static_cast<int>(::Qt::MatchRegularExpression)},
    {sipName_META, static_cast<int>(::Qt::META)},
    {sipName_SHIFT, static_cast<int>(::Qt::SHIFT)},
    {sipName_CTRL, static_cast<int>(::Qt::CTRL)},
    {sipName_ALT, static_cast<int>(::Qt::ALT)},
    {sipName_MODIFIER_MASK, static_cast<int>(::Qt::MODIFIER_MASK)},
    {sipName_NoButton, static_cast<int>(::Qt::NoButton)},
    {sipName_AllButtons, static_cast<int>(::Qt::AllButtons)},
    {sipName_LeftButton, static_cast<int>(::Qt::LeftButton)},
    {sipName_RightButton, static_cast<int>(::Qt::RightButton)},
    {sipName_MiddleButton, static_cast<int>(::Qt::MiddleButton)},
    {sipName_XButton1, static_cast<int>(::Qt::XButton1)},
    {sipName_XButton2, static_cast<int>(::Qt::XButton2)},
    {sipName_BackButton, static_cast<int>(::Qt::BackButton)},
    {sipName_ExtraButton1, static_cast<int>(::Qt::ExtraButton1)},
    {sipName_ForwardButton, static_cast<int>(::Qt::ForwardButton)},
    {sipName_ExtraButton2, static_cast<int>(::Qt::ExtraButton2)},
    {sipName_TaskButton, static_cast<int>(::Qt::TaskButton)},
    {sipName_ExtraButton3, static_cast<int>(::Qt::ExtraButton3)},
    {sipName_ExtraButton4, static_cast<int>(::Qt::ExtraButton4)},
    {sipName_ExtraButton5, static_cast<int>(::Qt::ExtraButton5)},
    {sipName_ExtraButton6, static_cast<int>(::Qt::ExtraButton6)},
    {sipName_ExtraButton7, static_cast<int>(::Qt::ExtraButton7)},
    {sipName_ExtraButton8, static_cast<int>(::Qt::ExtraButton8)},
    {sipName_ExtraButton9, static_cast<int>(::Qt::ExtraButton9)},
    {sipName_ExtraButton10, static_cast<int>(::Qt::ExtraButton10)},
    {sipName_ExtraButton11, static_cast<int>(::Qt::ExtraButton11)},
    {sipName_ExtraButton12, static_cast<int>(::Qt::ExtraButton12)},
    {sipName_ExtraButton13, static_cast<int>(::Qt::ExtraButton13)},
    {sipName_ExtraButton14, static_cast<int>(::Qt::ExtraButton14)},
    {sipName_ExtraButton15, static_cast<int>(::Qt::ExtraButton15)},
    {sipName_ExtraButton16, static_cast<int>(::Qt::ExtraButton16)},
    {sipName_ExtraButton17, static_cast<int>(::Qt::ExtraButton17)},
    {sipName_ExtraButton18, static_cast<int>(::Qt::ExtraButton18)},
    {sipName_ExtraButton19, static_cast<int>(::Qt::ExtraButton19)},
    {sipName_ExtraButton20, static_cast<int>(::Qt::ExtraButton20)},
    {sipName_ExtraButton21, static_cast<int>(::Qt::ExtraButton21)},
    {sipName_ExtraButton22, static_cast<int>(::Qt::ExtraButton22)},
    {sipName_ExtraButton23, static_cast<int>(::Qt::ExtraButton23)},
    {sipName_ExtraButton24, static_cast<int>(::Qt::ExtraButton24)},
    {sipName_MouseEventCreatedDoubleClick, static_cast<int>(::Qt::MouseEventCreatedDoubleClick)},
    {sipName_MouseEventNotSynthesized, static_cast<int>(::Qt::MouseEventNotSynthesized)},
    {sipName_MouseEventSynthesizedBySystem, static_cast<int>(::Qt::MouseEventSynthesizedBySystem)},
    {sipName_MouseEventSynthesizedByQt, static_cast<int>(::Qt::MouseEventSynthesizedByQt)},
    {sipName_MouseEventSynthesizedByApplication, static_cast<int>(::Qt::MouseEventSynthesizedByApplication)},
    {sipName_BeginNativeGesture, static_cast<int>(::Qt::BeginNativeGesture)},
    {sipName_EndNativeGesture, static_cast<int>(::Qt::EndNativeGesture)},
    {sipName_PanNativeGesture, static_cast<int>(::Qt::PanNativeGesture)},
    {sipName_ZoomNativeGesture, static_cast<int>(::Qt::ZoomNativeGesture)},
    {sipName_SmartZoomNativeGesture, static_cast<int>(::Qt::SmartZoomNativeGesture)},
    {sipName_RotateNativeGesture, static_cast<int>(::Qt::RotateNativeGesture)},
    {sipName_SwipeNativeGesture, static_cast<int>(::Qt::SwipeNativeGesture)},
    {sipName_NavigationModeNone, static_cast<int>(::Qt::NavigationModeNone)},
    {sipName_NavigationModeKeypadTabOrder, static_cast<int>(::Qt::NavigationModeKeypadTabOrder)},
    {sipName_NavigationModeKeypadDirectional, static_cast<int>(::Qt::NavigationModeKeypadDirectional)},
    {sipName_NavigationModeCursorAuto, static_cast<int>(::Qt::NavigationModeCursorAuto)},
    {sipName_NavigationModeCursorForceVisible, static_cast<int>(::Qt::NavigationModeCursorForceVisible)},
    {sipName_Horizontal, static_cast<int>(::Qt::Horizontal)},
    {sipName_Vertical, static_cast<int>(::Qt::Vertical)},
    {sipName_FlatCap, static_cast<int>(::Qt::FlatCap)},
    {sipName_SquareCap, static_cast<int>(::Qt::SquareCap)},
    {sipName_RoundCap, static_cast<int>(::Qt::RoundCap)},
    {sipName_MiterJoin, static_cast<int>(::Qt::MiterJoin)},
    {sipName_BevelJoin, static_cast<int>(::Qt::BevelJoin)},
    {sipName_RoundJoin, static_cast<int>(::Qt::RoundJoin)},
    {sipName_MPenJoinStyle, static_cast<int>(::Qt::MPenJoinStyle)},
    {sipName_SvgMiterJoin, static_cast<int>(::Qt::SvgMiterJoin)},
    {sipName_NoPen, static_cast<int>(::Qt::NoPen)},
    {sipName_SolidLine, static_cast<int>(::Qt::SolidLine)},
    {sipName_DashLine, static_cast<int>(::Qt::DashLine)},
    {sipName_DotLine, static_cast<int>(::Qt::DotLine)},
    {sipName_DashDotLine, static_cast<int>(::Qt::DashDotLine)},
    {sipName_DashDotDotLine, static_cast<int>(::Qt::DashDotDotLine)},
    {sipName_CustomDashLine, static_cast<int>(::Qt::CustomDashLine)},
    {sipName_Undetermined, static_cast<int>(::Qt::PermissionStatus::Undetermined)},
    {sipName_Granted, static_cast<int>(::Qt::PermissionStatus::Granted)},
    {sipName_Denied, static_cast<int>(::Qt::PermissionStatus::Denied)},
    {sipName_PrimaryOrientation, static_cast<int>(::Qt::PrimaryOrientation)},
    {sipName_PortraitOrientation, static_cast<int>(::Qt::PortraitOrientation)},
    {sipName_LandscapeOrientation, static_cast<int>(::Qt::LandscapeOrientation)},
    {sipName_InvertedPortraitOrientation, static_cast<int>(::Qt::InvertedPortraitOrientation)},
    {sipName_InvertedLandscapeOrientation, static_cast<int>(::Qt::InvertedLandscapeOrientation)},
    {sipName_ScrollBarAsNeeded, static_cast<int>(::Qt::ScrollBarAsNeeded)},
    {sipName_ScrollBarAlwaysOff, static_cast<int>(::Qt::ScrollBarAlwaysOff)},
    {sipName_ScrollBarAlwaysOn, static_cast<int>(::Qt::ScrollBarAlwaysOn)},
    {sipName_ScrollBegin, static_cast<int>(::Qt::ScrollBegin)},
    {sipName_ScrollUpdate, static_cast<int>(::Qt::ScrollUpdate)},
    {sipName_ScrollEnd, static_cast<int>(::Qt::ScrollEnd)},
    {sipName_NoScrollPhase, static_cast<int>(::Qt::NoScrollPhase)},
    {sipName_ScrollMomentum, static_cast<int>(::Qt::ScrollMomentum)},
    {sipName_WidgetShortcut, static_cast<int>(::Qt::WidgetShortcut)},
    {sipName_WindowShortcut, static_cast<int>(::Qt::WindowShortcut)},
    {sipName_ApplicationShortcut, static_cast<int>(::Qt::ApplicationShortcut)},
    {sipName_WidgetWithChildrenShortcut, static_cast<int>(::Qt::WidgetWithChildrenShortcut)},
    {sipName_MinimumSize, static_cast<int>(::Qt::MinimumSize)},
    {sipName_PreferredSize, static_cast<int>(::Qt::PreferredSize)},
    {sipName_MaximumSize, static_cast<int>(::Qt::MaximumSize)},
    {sipName_MinimumDescent, static_cast<int>(::Qt::MinimumDescent)},
    {sipName_AbsoluteSize, static_cast<int>(::Qt::AbsoluteSize)},
    {sipName_RelativeSize, static_cast<int>(::Qt::RelativeSize)},
    {sipName_AscendingOrder, static_cast<int>(::Qt::AscendingOrder)},
    {sipName_DescendingOrder, static_cast<int>(::Qt::DescendingOrder)},
    {sipName_NoTabFocus, static_cast<int>(::Qt::NoTabFocus)},
    {sipName_TabFocusTextControls, static_cast<int>(::Qt::TabFocusTextControls)},
    {sipName_TabFocusListControls, static_cast<int>(::Qt::TabFocusListControls)},
    {sipName_TabFocusAllControls, static_cast<int>(::Qt::TabFocusAllControls)},
    {sipName_ElideLeft, static_cast<int>(::Qt::ElideLeft)},
    {sipName_ElideRight, static_cast<int>(::Qt::ElideRight)},
    {sipName_ElideMiddle, static_cast<int>(::Qt::ElideMiddle)},
    {sipName_ElideNone, static_cast<int>(::Qt::ElideNone)},
    {sipName_TextSingleLine, static_cast<int>(::Qt::TextSingleLine)},
    {sipName_TextDontClip, static_cast<int>(::Qt::TextDontClip)},
    {sipName_TextExpandTabs, static_cast<int>(::Qt::TextExpandTabs)},
    {sipName_TextShowMnemonic, static_cast<int>(::Qt::TextShowMnemonic)},
    {sipName_TextWordWrap, static_cast<int>(::Qt::TextWordWrap)},
    {sipName_TextWrapAnywhere, static_cast<int>(::Qt::TextWrapAnywhere)},
    {sipName_TextDontPrint, static_cast<int>(::Qt::TextDontPrint)},
    {sipName_TextIncludeTrailingSpaces, static_cast<int>(::Qt::TextIncludeTrailingSpaces)},
    {sipName_TextHideMnemonic, static_cast<int>(::Qt::TextHideMnemonic)},
    {sipName_TextJustificationForced, static_cast<int>(::Qt::TextJustificationForced)},
    {sipName_PlainText, static_cast<int>(::Qt::PlainText)},
    {sipName_RichText, static_cast<int>(::Qt::RichText)},
    {sipName_AutoText, static_cast<int>(::Qt::AutoText)},
    {sipName_MarkdownText, static_cast<int>(::Qt::MarkdownText)},
    {sipName_NoTextInteraction, static_cast<int>(::Qt::NoTextInteraction)},
    {sipName_TextSelectableByMouse, static_cast<int>(::Qt::TextSelectableByMouse)},
    {sipName_TextSelectableByKeyboard, static_cast<int>(::Qt::TextSelectableByKeyboard)},
    {sipName_LinksAccessibleByMouse, static_cast<int>(::Qt::LinksAccessibleByMouse)},
    {sipName_LinksAccessibleByKeyboard, static_cast<int>(::Qt::LinksAccessibleByKeyboard)},
    {sipName_TextEditable, static_cast<int>(::Qt::TextEditable)},
    {sipName_TextEditorInteraction, static_cast<int>(::Qt::TextEditorInteraction)},
    {sipName_TextBrowserInteraction, static_cast<int>(::Qt::TextBrowserInteraction)},
    {sipName_StretchTile, static_cast<int>(::Qt::StretchTile)},
    {sipName_RepeatTile, static_cast<int>(::Qt::RepeatTile)},
    {sipName_RoundTile, static_cast<int>(::Qt::RoundTile)},
    {sipName_LocalTime, static_cast<int>(::Qt::LocalTime)},
    {sipName_UTC, static_cast<int>(::Qt::UTC)},
    {sipName_OffsetFromUTC, static_cast<int>(::Qt::OffsetFromUTC)},
    {sipName_TimeZone, static_cast<int>(::Qt::TimeZone)},
    {sipName_PreciseTimer, static_cast<int>(::Qt::PreciseTimer)},
    {sipName_CoarseTimer, static_cast<int>(::Qt::CoarseTimer)},
    {sipName_VeryCoarseTimer, static_cast<int>(::Qt::VeryCoarseTimer)},
    {sipName_LeftToolBarArea, static_cast<int>(::Qt::LeftToolBarArea)},
    {sipName_RightToolBarArea, static_cast<int>(::Qt::RightToolBarArea)},
    {sipName_TopToolBarArea, static_cast<int>(::Qt::TopToolBarArea)},
    {sipName_BottomToolBarArea, static_cast<int>(::Qt::BottomToolBarArea)},
    {sipName_AllToolBarAreas, static_cast<int>(::Qt::AllToolBarAreas)},
    {sipName_NoToolBarArea, static_cast<int>(::Qt::NoToolBarArea)},
    {sipName_ToolButtonIconOnly, static_cast<int>(::Qt::ToolButtonIconOnly)},
    {sipName_ToolButtonTextOnly, static_cast<int>(::Qt::ToolButtonTextOnly)},
    {sipName_ToolButtonTextBesideIcon, static_cast<int>(::Qt::ToolButtonTextBesideIcon)},
    {sipName_ToolButtonTextUnderIcon, static_cast<int>(::Qt::ToolButtonTextUnderIcon)},
    {sipName_ToolButtonFollowStyle, static_cast<int>(::Qt::ToolButtonFollowStyle)},
    {sipName_TouchPointUnknownState, static_cast<int>(::Qt::TouchPointUnknownState)},
    {sipName_TouchPointPressed, static_cast<int>(::Qt::TouchPointPressed)},
    {sipName_TouchPointMoved, static_cast<int>(::Qt::TouchPointMoved)},
    {sipName_TouchPointStationary, static_cast<int>(::Qt::TouchPointStationary)},
    {sipName_TouchPointReleased, static_cast<int>(::Qt::TouchPointReleased)},
    {sipName_FastTransformation, static_cast<int>(::Qt::FastTransformation)},
    {sipName_SmoothTransformation, static_cast<int>(::Qt::SmoothTransformation)},
    {sipName_UI_General, static_cast<int>(::Qt::UI_General)},
    {sipName_UI_AnimateMenu, static_cast<int>(::Qt::UI_AnimateMenu)},
    {sipName_UI_FadeMenu, static_cast<int>(::Qt::UI_FadeMenu)},
    {sipName_UI_AnimateCombo, static_cast<int>(::Qt::UI_AnimateCombo)},
    {sipName_UI_AnimateTooltip, static_cast<int>(::Qt::UI_AnimateTooltip)},
    {sipName_UI_FadeTooltip, static_cast<int>(::Qt::UI_FadeTooltip)},
    {sipName_UI_AnimateToolBox, static_cast<int>(::Qt::UI_AnimateToolBox)},
    {sipName_WhiteSpaceNormal, static_cast<int>(::Qt::WhiteSpaceNormal)},
    {sipName_WhiteSpacePre, static_cast<int>(::Qt::WhiteSpacePre)},
    {sipName_WhiteSpaceNoWrap, static_cast<int>(::Qt::WhiteSpaceNoWrap)},
    {sipName_WhiteSpaceModeUndefined, static_cast<int>(::Qt::WhiteSpaceModeUndefined)},
    {sipName_WA_Disabled, static_cast<int>(::Qt::WA_Disabled)},
    {sipName_WA_UnderMouse, static_cast<int>(::Qt::WA_UnderMouse)},
    {sipName_WA_MouseTracking, static_cast<int>(::Qt::WA_MouseTracking)},
    {sipName_WA_OpaquePaintEvent, static_cast<int>(::Qt::WA_OpaquePaintEvent)},
    {sipName_WA_StaticContents, static_cast<int>(::Qt::WA_StaticContents)},
    {sipName_WA_LaidOut, static_cast<int>(::Qt::WA_LaidOut)},
    {sipName_WA_PaintOnScreen, static_cast<int>(::Qt::WA_PaintOnScreen)},
    {sipName_WA_NoSystemBackground, static_cast<int>(::Qt::WA_NoSystemBackground)},
    {sipName_WA_UpdatesDisabled, static_cast<int>(::Qt::WA_UpdatesDisabled)},
    {sipName_WA_Mapped, static_cast<int>(::Qt::WA_Mapped)},
    {sipName_WA_InputMethodEnabled, static_cast<int>(::Qt::WA_InputMethodEnabled)},
    {sipName_WA_WState_Visible, static_cast<int>(::Qt::WA_WState_Visible)},
    {sipName_WA_WState_Hidden, static_cast<int>(::Qt::WA_WState_Hidden)},
    {sipName_WA_ForceDisabled, static_cast<int>(::Qt::WA_ForceDisabled)},
    {sipName_WA_KeyCompression, static_cast<int>(::Qt::WA_KeyCompression)},
    {sipName_WA_PendingMoveEvent, static_cast<int>(::Qt::WA_PendingMoveEvent)},
    {sipName_WA_PendingResizeEvent, static_cast<int>(::Qt::WA_PendingResizeEvent)},
    {sipName_WA_SetPalette, static_cast<int>(::Qt::WA_SetPalette)},
    {sipName_WA_SetFont, static_cast<int>(::Qt::WA_SetFont)},
    {sipName_WA_SetCursor, static_cast<int>(::Qt::WA_SetCursor)},
    {sipName_WA_NoChildEventsFromChildren, static_cast<int>(::Qt::WA_NoChildEventsFromChildren)},
    {sipName_WA_WindowModified, static_cast<int>(::Qt::WA_WindowModified)},
    {sipName_WA_Resized, static_cast<int>(::Qt::WA_Resized)},
    {sipName_WA_Moved, static_cast<int>(::Qt::WA_Moved)},
    {sipName_WA_PendingUpdate, static_cast<int>(::Qt::WA_PendingUpdate)},
    {sipName_WA_InvalidSize, static_cast<int>(::Qt::WA_InvalidSize)},
    {sipName_WA_CustomWhatsThis, static_cast<int>(::Qt::WA_CustomWhatsThis)},
    {sipName_WA_LayoutOnEntireRect, static_cast<int>(::Qt::WA_LayoutOnEntireRect)},
    {sipName_WA_OutsideWSRange, static_cast<int>(::Qt::WA_OutsideWSRange)},
    {sipName_WA_GrabbedShortcut, static_cast<int>(::Qt::WA_GrabbedShortcut)},
    {sipName_WA_TransparentForMouseEvents, static_cast<int>(::Qt::WA_TransparentForMouseEvents)},
    {sipName_WA_PaintUnclipped, static_cast<int>(::Qt::WA_PaintUnclipped)},
    {sipName_WA_SetWindowIcon, static_cast<int>(::Qt::WA_SetWindowIcon)},
    {sipName_WA_NoMouseReplay, static_cast<int>(::Qt::WA_NoMouseReplay)},
    {sipName_WA_DeleteOnClose, static_cast<int>(::Qt::WA_DeleteOnClose)},
    {sipName_WA_RightToLeft, static_cast<int>(::Qt::WA_RightToLeft)},
    {sipName_WA_SetLayoutDirection, static_cast<int>(::Qt::WA_SetLayoutDirection)},
    {sipName_WA_NoChildEventsForParent, static_cast<int>(::Qt::WA_NoChildEventsForParent)},
    {sipName_WA_ForceUpdatesDisabled, static_cast<int>(::Qt::WA_ForceUpdatesDisabled)},
    {sipName_WA_WState_Created, static_cast<int>(::Qt::WA_WState_Created)},
    {sipName_WA_WState_CompressKeys, static_cast<int>(::Qt::WA_WState_CompressKeys)},
    {sipName_WA_WState_InPaintEvent, static_cast<int>(::Qt::WA_WState_InPaintEvent)},
    {sipName_WA_WState_Reparented, static_cast<int>(::Qt::WA_WState_Reparented)},
    {sipName_WA_WState_ConfigPending, static_cast<int>(::Qt::WA_WState_ConfigPending)},
    {sipName_WA_WState_Polished, static_cast<int>(::Qt::WA_WState_Polished)},
    {sipName_WA_WState_OwnSizePolicy, static_cast<int>(::Qt::WA_WState_OwnSizePolicy)},
    {sipName_WA_WState_ExplicitShowHide, static_cast<int>(::Qt::WA_WState_ExplicitShowHide)},
    {sipName_WA_MouseNoMask, static_cast<int>(::Qt::WA_MouseNoMask)},
    {sipName_WA_NoMousePropagation, static_cast<int>(::Qt::WA_NoMousePropagation)},
    {sipName_WA_Hover, static_cast<int>(::Qt::WA_Hover)},
    {sipName_WA_InputMethodTransparent, static_cast<int>(::Qt::WA_InputMethodTransparent)},
    {sipName_WA_QuitOnClose, static_cast<int>(::Qt::WA_QuitOnClose)},
    {sipName_WA_KeyboardFocusChange, static_cast<int>(::Qt::WA_KeyboardFocusChange)},
    {sipName_WA_AcceptDrops, static_cast<int>(::Qt::WA_AcceptDrops)},
    {sipName_WA_WindowPropagation, static_cast<int>(::Qt::WA_WindowPropagation)},
    {sipName_WA_NoX11EventCompression, static_cast<int>(::Qt::WA_NoX11EventCompression)},
    {sipName_WA_TintedBackground, static_cast<int>(::Qt::WA_TintedBackground)},
    {sipName_WA_X11OpenGLOverlay, static_cast<int>(::Qt::WA_X11OpenGLOverlay)},
    {sipName_WA_AttributeCount, static_cast<int>(::Qt::WA_AttributeCount)},
    {sipName_WA_AlwaysShowToolTips, static_cast<int>(::Qt::WA_AlwaysShowToolTips)},
    {sipName_WA_MacOpaqueSizeGrip, static_cast<int>(::Qt::WA_MacOpaqueSizeGrip)},
    {sipName_WA_SetStyle, static_cast<int>(::Qt::WA_SetStyle)},
    {sipName_WA_SetLocale, static_cast<int>(::Qt::WA_SetLocale)},
    {sipName_WA_MacShowFocusRect, static_cast<int>(::Qt::WA_MacShowFocusRect)},
    {sipName_WA_MacNormalSize, static_cast<int>(::Qt::WA_MacNormalSize)},
    {sipName_WA_MacSmallSize, static_cast<int>(::Qt::WA_MacSmallSize)},
    {sipName_WA_MacMiniSize, static_cast<int>(::Qt::WA_MacMiniSize)},
    {sipName_WA_LayoutUsesWidgetRect, static_cast<int>(::Qt::WA_LayoutUsesWidgetRect)},
    {sipName_WA_StyledBackground, static_cast<int>(::Qt::WA_StyledBackground)},
    {sipName_WA_MacAlwaysShowToolWindow, static_cast<int>(::Qt::WA_MacAlwaysShowToolWindow)},
    {sipName_WA_StyleSheet, static_cast<int>(::Qt::WA_StyleSheet)},
    {sipName_WA_ShowWithoutActivating, static_cast<int>(::Qt::WA_ShowWithoutActivating)},
    {sipName_WA_NativeWindow, static_cast<int>(::Qt::WA_NativeWindow)},
    {sipName_WA_DontCreateNativeAncestors, static_cast<int>(::Qt::WA_DontCreateNativeAncestors)},
    {sipName_WA_DontShowOnScreen, static_cast<int>(::Qt::WA_DontShowOnScreen)},
    {sipName_WA_X11NetWmWindowTypeDesktop, static_cast<int>(::Qt::WA_X11NetWmWindowTypeDesktop)},
    {sipName_WA_X11NetWmWindowTypeDock, static_cast<int>(::Qt::WA_X11NetWmWindowTypeDock)},
    {sipName_WA_X11NetWmWindowTypeToolBar, static_cast<int>(::Qt::WA_X11NetWmWindowTypeToolBar)},
    {sipName_WA_X11NetWmWindowTypeMenu, static_cast<int>(::Qt::WA_X11NetWmWindowTypeMenu)},
    {sipName_WA_X11NetWmWindowTypeUtility, static_cast<int>(::Qt::WA_X11NetWmWindowTypeUtility)},
    {sipName_WA_X11NetWmWindowTypeSplash, static_cast<int>(::Qt::WA_X11NetWmWindowTypeSplash)},
    {sipName_WA_X11NetWmWindowTypeDialog, static_cast<int>(::Qt::WA_X11NetWmWindowTypeDialog)},
    {sipName_WA_X11NetWmWindowTypeDropDownMenu, static_cast<int>(::Qt::WA_X11NetWmWindowTypeDropDownMenu)},
    {sipName_WA_X11NetWmWindowTypePopupMenu, static_cast<int>(::Qt::WA_X11NetWmWindowTypePopupMenu)},
    {sipName_WA_X11NetWmWindowTypeToolTip, static_cast<int>(::Qt::WA_X11NetWmWindowTypeToolTip)},
    {sipName_WA_X11NetWmWindowTypeNotification, static_cast<int>(::Qt::WA_X11NetWmWindowTypeNotification)},
    {sipName_WA_X11NetWmWindowTypeCombo, static_cast<int>(::Qt::WA_X11NetWmWindowTypeCombo)},
    {sipName_WA_X11NetWmWindowTypeDND, static_cast<int>(::Qt::WA_X11NetWmWindowTypeDND)},
    {sipName_WA_TranslucentBackground, static_cast<int>(::Qt::WA_TranslucentBackground)},
    {sipName_WA_AcceptTouchEvents, static_cast<int>(::Qt::WA_AcceptTouchEvents)},
    {sipName_WA_TouchPadAcceptSingleTouchEvents, static_cast<int>(::Qt::WA_TouchPadAcceptSingleTouchEvents)},
    {sipName_WA_X11DoNotAcceptFocus, static_cast<int>(::Qt::WA_X11DoNotAcceptFocus)},
    {sipName_WA_AlwaysStackOnTop, static_cast<int>(::Qt::WA_AlwaysStackOnTop)},
    {sipName_WA_TabletTracking, static_cast<int>(::Qt::WA_TabletTracking)},
    {sipName_WA_ContentsMarginsRespectsSafeArea, static_cast<int>(::Qt::WA_ContentsMarginsRespectsSafeArea)},
    {sipName_WA_StyleSheetTarget, static_cast<int>(::Qt::WA_StyleSheetTarget)},
    {sipName_NoSection, static_cast<int>(::Qt::NoSection)},
    {sipName_LeftSection, static_cast<int>(::Qt::LeftSection)},
    {sipName_TopLeftSection, static_cast<int>(::Qt::TopLeftSection)},
    {sipName_TopSection, static_cast<int>(::Qt::TopSection)},
    {sipName_TopRightSection, static_cast<int>(::Qt::TopRightSection)},
    {sipName_RightSection, static_cast<int>(::Qt::RightSection)},
    {sipName_BottomRightSection, static_cast<int>(::Qt::BottomRightSection)},
    {sipName_BottomSection, static_cast<int>(::Qt::BottomSection)},
    {sipName_BottomLeftSection, static_cast<int>(::Qt::BottomLeftSection)},
    {sipName_TitleBarArea, static_cast<int>(::Qt::TitleBarArea)},
    {sipName_NonModal, static_cast<int>(::Qt::NonModal)},
    {sipName_WindowModal, static_cast<int>(::Qt::WindowModal)},
    {sipName_ApplicationModal, static_cast<int>(::Qt::ApplicationModal)},
    {sipName_WindowNoState, static_cast<int>(::Qt::WindowNoState)},
    {sipName_WindowMinimized, static_cast<int>(::Qt::WindowMinimized)},
    {sipName_WindowMaximized, static_cast<int>(::Qt::WindowMaximized)},
    {sipName_WindowFullScreen, static_cast<int>(::Qt::WindowFullScreen)},
    {sipName_WindowActive, static_cast<int>(::Qt::WindowActive)},
    {sipName_Widget, static_cast<int>(::Qt::Widget)},
    {sipName_Window, static_cast<int>(::Qt::Window)},
    {sipName_Dialog, static_cast<int>(::Qt::Dialog)},
    {sipName_Sheet, static_cast<int>(::Qt::Sheet)},
    {sipName_Drawer, static_cast<int>(::Qt::Drawer)},
    {sipName_Popup, static_cast<int>(::Qt::Popup)},
    {sipName_Tool, static_cast<int>(::Qt::Tool)},
    {sipName_ToolTip, static_cast<int>(::Qt::ToolTip)},
    {sipName_SplashScreen, static_cast<int>(::Qt::SplashScreen)},
    {sipName_Desktop, static_cast<int>(::Qt::Desktop)},
    {sipName_SubWindow, static_cast<int>(::Qt::SubWindow)},
    {sipName_WindowType_Mask, static_cast<int>(::Qt::WindowType_Mask)},
    {sipName_MSWindowsFixedSizeDialogHint, static_cast<int>(::Qt::MSWindowsFixedSizeDialogHint)},
    {sipName_MSWindowsOwnDC, static_cast<int>(::Qt::MSWindowsOwnDC)},
    {sipName_X11BypassWindowManagerHint, static_cast<int>(::Qt::X11BypassWindowManagerHint)},
    {sipName_FramelessWindowHint, static_cast<int>(::Qt::FramelessWindowHint)},
    {sipName_CustomizeWindowHint, static_cast<int>(::Qt::CustomizeWindowHint)},
    {sipName_WindowTitleHint, static_cast<int>(::Qt::WindowTitleHint)},
    {sipName_WindowSystemMenuHint, static_cast<int>(::Qt::WindowSystemMenuHint)},
    {sipName_WindowMinimizeButtonHint, static_cast<int>(::Qt::WindowMinimizeButtonHint)},
    {sipName_WindowMaximizeButtonHint, static_cast<int>(::Qt::WindowMaximizeButtonHint)},
    {sipName_WindowMinMaxButtonsHint, static_cast<int>(::Qt::WindowMinMaxButtonsHint)},
    {sipName_WindowContextHelpButtonHint, static_cast<int>(::Qt::WindowContextHelpButtonHint)},
    {sipName_WindowShadeButtonHint, static_cast<int>(::Qt::WindowShadeButtonHint)},
    {sipName_WindowStaysOnTopHint, static_cast<int>(::Qt::WindowStaysOnTopHint)},
    {sipName_WindowStaysOnBottomHint, static_cast<int>(::Qt::WindowStaysOnBottomHint)},
    {sipName_WindowCloseButtonHint, static_cast<int>(::Qt::WindowCloseButtonHint)},
    {sipName_MacWindowToolBarButtonHint, static_cast<int>(::Qt::MacWindowToolBarButtonHint)},
    {sipName_BypassGraphicsProxyWidget, static_cast<int>(::Qt::BypassGraphicsProxyWidget)},
    {sipName_WindowTransparentForInput, static_cast<int>(::Qt::WindowTransparentForInput)},
    {sipName_WindowOverridesSystemGestures, static_cast<int>(::Qt::WindowOverridesSystemGestures)},
    {sipName_WindowDoesNotAcceptFocus, static_cast<int>(::Qt::WindowDoesNotAcceptFocus)},
    {sipName_NoDropShadowWindowHint, static_cast<int>(::Qt::NoDropShadowWindowHint)},
    {sipName_WindowFullscreenButtonHint, static_cast<int>(::Qt::WindowFullscreenButtonHint)},
    {sipName_ForeignWindow, static_cast<int>(::Qt::ForeignWindow)},
    {sipName_BypassWindowManagerHint, static_cast<int>(::Qt::BypassWindowManagerHint)},
    {sipName_CoverWindow, static_cast<int>(::Qt::CoverWindow)},
    {sipName_MaximizeUsingFullscreenGeometryHint, static_cast<int>(::Qt::MaximizeUsingFullscreenGeometryHint)},
    {sipName_ExpandedClientAreaHint, static_cast<int>(::Qt::ExpandedClientAreaHint)},
    {sipName_NoTitleBarBackgroundHint, static_cast<int>(::Qt::NoTitleBarBackgroundHint)},
    {0, 0}
};


sipClassTypeDef sipTypeDef_QtCore_Qt = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_NAMESPACE,
        sipNameNr_Qt,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_Qt,
        {0, 0, 1},
        24, methods_Qt,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_Qt, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
