/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qsgmaterialtype.sip"
#include <qsgmaterialtype.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGMaterialType.cpp"



/* Call the instance's destructor. */
extern "C" {static void release_QSGMaterialType(void *, int);}
static void release_QSGMaterialType(void *sipCppV, int)
{
    delete reinterpret_cast< ::QSGMaterialType *>(sipCppV);
}


extern "C" {static void *array_QSGMaterialType(Py_ssize_t);}
static void *array_QSGMaterialType(Py_ssize_t sipNrElem)
{
    return new ::QSGMaterialType[sipNrElem];
}


extern "C" {static void array_delete_QSGMaterialType(void *);}
static void array_delete_QSGMaterialType(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSGMaterialType *>(sipCpp);
}


extern "C" {static void assign_QSGMaterialType(void *, Py_ssize_t, void *);}
static void assign_QSGMaterialType(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QSGMaterialType *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QSGMaterialType *>(sipSrc);
}


extern "C" {static void *copy_QSGMaterialType(const void *, Py_ssize_t);}
static void *copy_QSGMaterialType(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QSGMaterialType(reinterpret_cast<const ::QSGMaterialType *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QSGMaterialType(sipSimpleWrapper *);}
static void dealloc_QSGMaterialType(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGMaterialType(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QSGMaterialType(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSGMaterialType(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QSGMaterialType *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QSGMaterialType();

            return sipCpp;
        }
    }

    {
        const ::QSGMaterialType* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QSGMaterialType, &a0))
        {
            sipCpp = new ::QSGMaterialType(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}

PyDoc_STRVAR(doc_QSGMaterialType, "\1QSGMaterialType()\n"
"QSGMaterialType(a0: QSGMaterialType)");


sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialType = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGMaterialType,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QSGMaterialType,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSGMaterialType,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QSGMaterialType,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSGMaterialType,
    assign_QSGMaterialType,
    array_QSGMaterialType,
    copy_QSGMaterialType,
    release_QSGMaterialType,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSGMaterialType,
    sizeof (::QSGMaterialType),
};
