/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrangemodel.sip"
#include <qrangemodel.h>
#include "qpycore_qrangemodel.h"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qrangemodel.sip"
#include "qpycore_qrangemodel.h"
#line 34 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 37 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 40 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 43 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
// The capsule destructor for a QModelRoleData array.
static void qpycore_gc_modelroledata(PyObject *mrd_obj);
#line 58 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 61 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 64 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 67 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 271 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 789 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 108 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 111 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 114 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 117 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 120 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 123 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 126 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 129 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 132 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 138 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 141 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"

sipQRangeModel::~sipQRangeModel()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQRangeModel::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtCore_qt_metaobject(sipPySelf, sipType_QRangeModel);

    return ::QRangeModel::metaObject();
}

int sipQRangeModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QRangeModel::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtCore_qt_metacall(sipPySelf, sipType_QRangeModel, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQRangeModel::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtCore_qt_metacast(sipPySelf, sipType_QRangeModel, _clname, &sipCpp) ? sipCpp : ::QRangeModel::qt_metacast(_clname));
}

void sipQRangeModel::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QRangeModel::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQRangeModel::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QRangeModel::connectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQRangeModel::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QRangeModel::customEvent(a0);
        return;
    }

    extern void sipVH_QtCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtCore_4(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQRangeModel::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QRangeModel::childEvent(a0);
        return;
    }

    extern void sipVH_QtCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtCore_3(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQRangeModel::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QRangeModel::timerEvent(a0);
        return;
    }

    extern void sipVH_QtCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtCore_2(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

bool sipQRangeModel::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QRangeModel::eventFilter(a0, a1);

    extern bool sipVH_QtCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtCore_1(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1);
}

bool sipQRangeModel::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QRangeModel::event(a0);

    extern bool sipVH_QtCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtCore_0(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

::QVariant sipQRangeModel::data(const ::QModelIndex& a0, int a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_data);

    if (!sipMeth)
        return ::QRangeModel::data(a0, a1);

    extern ::QVariant sipVH_QtCore_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int);

    return sipVH_QtCore_21(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1);
}

bool sipQRangeModel::setData(const ::QModelIndex& a0, const ::QVariant& a1, int a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_setData);

    if (!sipMeth)
        return ::QRangeModel::setData(a0, a1, a2);

    extern bool sipVH_QtCore_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QVariant&, int);

    return sipVH_QtCore_22(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1, a2);
}

::QVariant sipQRangeModel::headerData(int a0, ::Qt::Orientation a1, int a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_headerData);

    if (!sipMeth)
        return ::QRangeModel::headerData(a0, a1, a2);

    extern ::QVariant sipVH_QtCore_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::Orientation, int);

    return sipVH_QtCore_23(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQRangeModel::setHeaderData(int a0, ::Qt::Orientation a1, const ::QVariant& a2, int a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_setHeaderData);

    if (!sipMeth)
        return ::QRangeModel::setHeaderData(a0, a1, a2, a3);

    extern bool sipVH_QtCore_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::Orientation, const ::QVariant&, int);

    return sipVH_QtCore_24(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1, a2, a3);
}

QMap<int, ::QVariant> sipQRangeModel::itemData(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_itemData);

    if (!sipMeth)
        return ::QRangeModel::itemData(a0);

    extern QMap<int, ::QVariant> sipVH_QtCore_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_25(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

bool sipQRangeModel::setItemData(const ::QModelIndex& a0, const QMap<int, ::QVariant>& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_setItemData);

    if (!sipMeth)
        return ::QRangeModel::setItemData(a0, a1);

    extern bool sipVH_QtCore_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const QMap<int, ::QVariant>&);

    return sipVH_QtCore_26(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1);
}

::QStringList sipQRangeModel::mimeTypes() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mimeTypes);

    if (!sipMeth)
        return ::QRangeModel::mimeTypes();

    extern ::QStringList sipVH_QtCore_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_27(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

::QMimeData* sipQRangeModel::mimeData(const ::QModelIndexList& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mimeData);

    if (!sipMeth)
        return ::QRangeModel::mimeData(a0);

    extern ::QMimeData* sipVH_QtCore_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndexList&);

    return sipVH_QtCore_28(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

bool sipQRangeModel::dropMimeData(const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_dropMimeData);

    if (!sipMeth)
        return ::QRangeModel::dropMimeData(a0, a1, a2, a3, a4);

    extern bool sipVH_QtCore_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&);

    return sipVH_QtCore_29(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

::Qt::DropActions sipQRangeModel::supportedDropActions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[16]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportedDropActions);

    if (!sipMeth)
        return ::QRangeModel::supportedDropActions();

    extern ::Qt::DropActions sipVH_QtCore_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_30(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

void sipQRangeModel::fetchMore(const ::QModelIndex& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_fetchMore);

    if (!sipMeth)
    {
        ::QRangeModel::fetchMore(a0);
        return;
    }

    extern void sipVH_QtCore_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    sipVH_QtCore_32(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

bool sipQRangeModel::canFetchMore(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[18]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_canFetchMore);

    if (!sipMeth)
        return ::QRangeModel::canFetchMore(a0);

    extern bool sipVH_QtCore_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_20(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

::Qt::ItemFlags sipQRangeModel::flags(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[19]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_flags);

    if (!sipMeth)
        return ::QRangeModel::flags(a0);

    extern ::Qt::ItemFlags sipVH_QtCore_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_33(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQRangeModel::sort(int a0, ::Qt::SortOrder a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_sort);

    if (!sipMeth)
    {
        ::QRangeModel::sort(a0, a1);
        return;
    }

    extern void sipVH_QtCore_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::SortOrder);

    sipVH_QtCore_34(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1);
}

::QModelIndex sipQRangeModel::buddy(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_buddy);

    if (!sipMeth)
        return ::QRangeModel::buddy(a0);

    extern ::QModelIndex sipVH_QtCore_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_18(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

::QModelIndexList sipQRangeModel::match(const ::QModelIndex& a0, int a1, const ::QVariant& a2, int a3, ::Qt::MatchFlags a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[22]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_match);

    if (!sipMeth)
        return ::QRangeModel::match(a0, a1, a2, a3, a4);

    extern ::QModelIndexList sipVH_QtCore_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, const ::QVariant&, int, ::Qt::MatchFlags);

    return sipVH_QtCore_35(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

::QSize sipQRangeModel::span(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[23]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_span);

    if (!sipMeth)
        return ::QRangeModel::span(a0);

    extern ::QSize sipVH_QtCore_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_36(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

bool sipQRangeModel::submit()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_submit);

    if (!sipMeth)
        return ::QRangeModel::submit();

    extern bool sipVH_QtCore_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_37(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

void sipQRangeModel::revert()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_revert);

    if (!sipMeth)
    {
        ::QRangeModel::revert();
        return;
    }

    extern void sipVH_QtCore_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtCore_15(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

::Qt::DropActions sipQRangeModel::supportedDragActions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[26]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportedDragActions);

    if (!sipMeth)
        return ::QRangeModel::supportedDragActions();

    extern ::Qt::DropActions sipVH_QtCore_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_30(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

QHash<int, ::QByteArray> sipQRangeModel::roleNames() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[27]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_roleNames);

    if (!sipMeth)
        return ::QRangeModel::roleNames();

    extern QHash<int, ::QByteArray> sipVH_QtCore_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_38(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

void sipQRangeModel::resetInternalData()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_resetInternalData);

    if (!sipMeth)
    {
        ::QRangeModel::resetInternalData();
        return;
    }

    extern void sipVH_QtCore_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtCore_15(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

bool sipQRangeModel::canDropMimeData(const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[29]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_canDropMimeData);

    if (!sipMeth)
        return ::QRangeModel::canDropMimeData(a0, a1, a2, a3, a4);

    extern bool sipVH_QtCore_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&);

    return sipVH_QtCore_29(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

bool sipQRangeModel::clearItemData(const ::QModelIndex& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_clearItemData);

    if (!sipMeth)
        return ::QRangeModel::clearItemData(a0);

    extern bool sipVH_QtCore_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_20(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQRangeModel::multiData(const ::QModelIndex& a0, ::QModelRoleDataSpan a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[31]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_multiData);

    if (!sipMeth)
    {
        ::QRangeModel::multiData(a0, a1);
        return;
    }

    extern void sipVH_QtCore_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, ::QModelRoleDataSpan);

    sipVH_QtCore_40(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1);
}


PyDoc_STRVAR(doc_QRangeModel_index, "index(self, row: int, column: int, parent: QModelIndex = {}) -> QModelIndex");

extern "C" {static PyObject *meth_QRangeModel_index(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_index(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = {};
        const ::QModelIndex* a2 = &a2def;
        const ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QRangeModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex(sipCpp->index(a0, a1, *a2));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_index, doc_QRangeModel_index);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_parent, "parent(self, child: QModelIndex) -> QModelIndex");

extern "C" {static PyObject *meth_QRangeModel_parent(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_parent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex* a0;
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex(sipCpp->parent(*a0));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_parent, doc_QRangeModel_parent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_sibling, "sibling(self, row: int, column: int, index: QModelIndex) -> QModelIndex");

extern "C" {static PyObject *meth_QRangeModel_sibling(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_sibling(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QModelIndex* a2;
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiJ9", &sipSelf, sipType_QRangeModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex(sipCpp->sibling(a0, a1, *a2));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_sibling, doc_QRangeModel_sibling);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_rowCount, "rowCount(self, parent: QModelIndex = {}) -> int");

extern "C" {static PyObject *meth_QRangeModel_rowCount(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_rowCount(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex& a0def = {};
        const ::QModelIndex* a0 = &a0def;
        const ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            int sipRes;

            sipRes = sipCpp->rowCount(*a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_rowCount, doc_QRangeModel_rowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_columnCount, "columnCount(self, parent: QModelIndex = {}) -> int");

extern "C" {static PyObject *meth_QRangeModel_columnCount(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_columnCount(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex& a0def = {};
        const ::QModelIndex* a0 = &a0def;
        const ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            int sipRes;

            sipRes = sipCpp->columnCount(*a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_columnCount, doc_QRangeModel_columnCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_flags, "flags(self, index: QModelIndex) -> Qt.ItemFlag");

extern "C" {static PyObject *meth_QRangeModel_flags(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::Qt::ItemFlags*sipRes;

            sipRes = new ::Qt::ItemFlags((sipSelfWasArg ? sipCpp->::QRangeModel::flags(*a0) : sipCpp->flags(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_ItemFlag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_flags, doc_QRangeModel_flags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_headerData, "headerData(self, section: int, orientation: Qt.Orientation, role: int = Qt.DisplayRole) -> Any");

extern "C" {static PyObject *meth_QRangeModel_headerData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_headerData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::Qt::Orientation a1;
        int a2 = Qt::DisplayRole;
        const ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiE|i", &sipSelf, sipType_QRangeModel, &sipCpp, &a0, sipType_Qt_Orientation, &a1, &a2))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QRangeModel::headerData(a0, a1, a2) : sipCpp->headerData(a0, a1, a2)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_headerData, doc_QRangeModel_headerData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_setHeaderData, "setHeaderData(self, section: int, orientation: Qt.Orientation, data: Any, role: int = Qt.EditRole) -> bool");

extern "C" {static PyObject *meth_QRangeModel_setHeaderData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_setHeaderData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::Qt::Orientation a1;
        const ::QVariant* a2;
        int a2State = 0;
        int a3 = Qt::EditRole;
        ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiEJ1|i", &sipSelf, sipType_QRangeModel, &sipCpp, &a0, sipType_Qt_Orientation, &a1, sipType_QVariant, &a2, &a2State, &a3))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRangeModel::setHeaderData(a0, a1, *a2, a3) : sipCpp->setHeaderData(a0, a1, *a2, a3));
            sipReleaseType(const_cast< ::QVariant *>(a2), sipType_QVariant, a2State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_setHeaderData, doc_QRangeModel_setHeaderData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_data, "data(self, index: QModelIndex, role: int = Qt.DisplayRole) -> Any");

extern "C" {static PyObject *meth_QRangeModel_data(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_data(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        int a1 = Qt::DisplayRole;
        const ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|i", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0, &a1))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QRangeModel::data(*a0, a1) : sipCpp->data(*a0, a1)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_data, doc_QRangeModel_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_setData, "setData(self, index: QModelIndex, data: Any, role: int = Qt.EditRole) -> bool");

extern "C" {static PyObject *meth_QRangeModel_setData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_setData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QVariant* a1;
        int a1State = 0;
        int a2 = Qt::EditRole;
        ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9J1|i", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0, sipType_QVariant, &a1, &a1State, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRangeModel::setData(*a0, *a1, a2) : sipCpp->setData(*a0, *a1, a2));
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_setData, doc_QRangeModel_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_itemData, "itemData(self, index: QModelIndex) -> dict[int, Any]");

extern "C" {static PyObject *meth_QRangeModel_itemData(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_itemData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            QMap<int, ::QVariant>*sipRes;

            sipRes = new QMap<int, ::QVariant>((sipSelfWasArg ? sipCpp->::QRangeModel::itemData(*a0) : sipCpp->itemData(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QMap_1800_0100QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_itemData, doc_QRangeModel_itemData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_setItemData, "setItemData(self, index: QModelIndex, data: dict[int, Any]) -> bool");

extern "C" {static PyObject *meth_QRangeModel_setItemData(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_setItemData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const QMap<int, ::QVariant>* a1;
        int a1State = 0;
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0, sipType_QMap_1800_0100QVariant, &a1, &a1State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRangeModel::setItemData(*a0, *a1) : sipCpp->setItemData(*a0, *a1));
            sipReleaseType(const_cast<QMap<int, ::QVariant> *>(a1), sipType_QMap_1800_0100QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_setItemData, doc_QRangeModel_setItemData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_clearItemData, "clearItemData(self, index: QModelIndex) -> bool");

extern "C" {static PyObject *meth_QRangeModel_clearItemData(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_clearItemData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRangeModel::clearItemData(*a0) : sipCpp->clearItemData(*a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_clearItemData, doc_QRangeModel_clearItemData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_insertColumns, "insertColumns(self, column: int, count: int, parent: QModelIndex = {}) -> bool");

extern "C" {static PyObject *meth_QRangeModel_insertColumns(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_insertColumns(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = {};
        const ::QModelIndex* a2 = &a2def;
        ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QRangeModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = sipCpp->insertColumns(a0, a1, *a2);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_insertColumns, doc_QRangeModel_insertColumns);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_removeColumns, "removeColumns(self, column: int, count: int, parent: QModelIndex = {}) -> bool");

extern "C" {static PyObject *meth_QRangeModel_removeColumns(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_removeColumns(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = {};
        const ::QModelIndex* a2 = &a2def;
        ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QRangeModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = sipCpp->removeColumns(a0, a1, *a2);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_removeColumns, doc_QRangeModel_removeColumns);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_moveColumns, "moveColumns(self, sourceParent: QModelIndex, sourceColumn: int, count: int, destParent: QModelIndex, destColumn: int) -> bool");

extern "C" {static PyObject *meth_QRangeModel_moveColumns(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_moveColumns(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex* a0;
        int a1;
        int a2;
        const ::QModelIndex* a3;
        int a4;
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9iiJ9i", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0, &a1, &a2, sipType_QModelIndex, &a3, &a4))
        {
            bool sipRes;

            sipRes = sipCpp->moveColumns(*a0, a1, a2, *a3, a4);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_moveColumns, doc_QRangeModel_moveColumns);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_insertRows, "insertRows(self, row: int, count: int, parent: QModelIndex = {}) -> bool");

extern "C" {static PyObject *meth_QRangeModel_insertRows(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_insertRows(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = {};
        const ::QModelIndex* a2 = &a2def;
        ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QRangeModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = sipCpp->insertRows(a0, a1, *a2);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_insertRows, doc_QRangeModel_insertRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_removeRows, "removeRows(self, row: int, count: int, parent: QModelIndex = {}) -> bool");

extern "C" {static PyObject *meth_QRangeModel_removeRows(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_removeRows(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = {};
        const ::QModelIndex* a2 = &a2def;
        ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QRangeModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = sipCpp->removeRows(a0, a1, *a2);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_removeRows, doc_QRangeModel_removeRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_moveRows, "moveRows(self, sourceParent: QModelIndex, sourceRow: int, count: int, destParent: QModelIndex, destRow: int) -> bool");

extern "C" {static PyObject *meth_QRangeModel_moveRows(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_moveRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex* a0;
        int a1;
        int a2;
        const ::QModelIndex* a3;
        int a4;
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9iiJ9i", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0, &a1, &a2, sipType_QModelIndex, &a3, &a4))
        {
            bool sipRes;

            sipRes = sipCpp->moveRows(*a0, a1, a2, *a3, a4);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_moveRows, doc_QRangeModel_moveRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_roleNames, "roleNames(self) -> dict[int, QByteArray]");

extern "C" {static PyObject *meth_QRangeModel_roleNames(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_roleNames(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRangeModel, &sipCpp))
        {
            QHash<int, ::QByteArray>*sipRes;

            sipRes = new QHash<int, ::QByteArray>((sipSelfWasArg ? sipCpp->::QRangeModel::roleNames() : sipCpp->roleNames()));

            return sipConvertFromNewType(sipRes, sipType_QHash_1800_0100QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_roleNames, doc_QRangeModel_roleNames);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_setRoleNames, "setRoleNames(self, names: dict[int, QByteArray|bytes|bytearray|memoryview])");

extern "C" {static PyObject *meth_QRangeModel_setRoleNames(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_setRoleNames(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QHash<int, ::QByteArray>* a0;
        int a0State = 0;
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QHash_1800_0100QByteArray, &a0, &a0State))
        {
            sipCpp->setRoleNames(*a0);
            sipReleaseType(const_cast<QHash<int, ::QByteArray> *>(a0), sipType_QHash_1800_0100QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_setRoleNames, doc_QRangeModel_setRoleNames);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_resetRoleNames, "resetRoleNames(self)");

extern "C" {static PyObject *meth_QRangeModel_resetRoleNames(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_resetRoleNames(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRangeModel, &sipCpp))
        {
            sipCpp->resetRoleNames();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_resetRoleNames, doc_QRangeModel_resetRoleNames);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_canFetchMore, "canFetchMore(self, parent: QModelIndex) -> bool");

extern "C" {static PyObject *meth_QRangeModel_canFetchMore(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_canFetchMore(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRangeModel::canFetchMore(*a0) : sipCpp->canFetchMore(*a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_canFetchMore, doc_QRangeModel_canFetchMore);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_fetchMore, "fetchMore(self, parent: QModelIndex)");

extern "C" {static PyObject *meth_QRangeModel_fetchMore(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_fetchMore(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QRangeModel::fetchMore(*a0) : sipCpp->fetchMore(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_fetchMore, doc_QRangeModel_fetchMore);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_hasChildren, "hasChildren(self, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QRangeModel_hasChildren(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_hasChildren(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex& a0def = QModelIndex();
        const ::QModelIndex* a0 = &a0def;
        const ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->hasChildren(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_hasChildren, doc_QRangeModel_hasChildren);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_buddy, "buddy(self, index: QModelIndex) -> QModelIndex");

extern "C" {static PyObject *meth_QRangeModel_buddy(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_buddy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex((sipSelfWasArg ? sipCpp->::QRangeModel::buddy(*a0) : sipCpp->buddy(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_buddy, doc_QRangeModel_buddy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_canDropMimeData, "canDropMimeData(self, data: QMimeData|None, action: Qt.DropAction, row: int, column: int, parent: QModelIndex) -> bool");

extern "C" {static PyObject *meth_QRangeModel_canDropMimeData(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_canDropMimeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QMimeData* a0;
        ::Qt::DropAction a1;
        int a2;
        int a3;
        const ::QModelIndex* a4;
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8EiiJ9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QMimeData, &a0, sipType_Qt_DropAction, &a1, &a2, &a3, sipType_QModelIndex, &a4))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRangeModel::canDropMimeData(a0, a1, a2, a3, *a4) : sipCpp->canDropMimeData(a0, a1, a2, a3, *a4));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_canDropMimeData, doc_QRangeModel_canDropMimeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_dropMimeData, "dropMimeData(self, data: QMimeData|None, action: Qt.DropAction, row: int, column: int, parent: QModelIndex) -> bool");

extern "C" {static PyObject *meth_QRangeModel_dropMimeData(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_dropMimeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QMimeData* a0;
        ::Qt::DropAction a1;
        int a2;
        int a3;
        const ::QModelIndex* a4;
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8EiiJ9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QMimeData, &a0, sipType_Qt_DropAction, &a1, &a2, &a3, sipType_QModelIndex, &a4))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRangeModel::dropMimeData(a0, a1, a2, a3, *a4) : sipCpp->dropMimeData(a0, a1, a2, a3, *a4));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_dropMimeData, doc_QRangeModel_dropMimeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_mimeData, "mimeData(self, indexes: Iterable[QModelIndex]) -> QMimeData|None");

extern "C" {static PyObject *meth_QRangeModel_mimeData(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_mimeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndexList* a0;
        int a0State = 0;
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QList_0100QModelIndex, &a0, &a0State))
        {
            ::QMimeData*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRangeModel::mimeData(*a0) : sipCpp->mimeData(*a0));
            sipReleaseType(const_cast< ::QModelIndexList *>(a0), sipType_QList_0100QModelIndex, a0State);

            return sipConvertFromType(sipRes, sipType_QMimeData, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_mimeData, doc_QRangeModel_mimeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_mimeTypes, "mimeTypes(self) -> list[str]");

extern "C" {static PyObject *meth_QRangeModel_mimeTypes(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_mimeTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRangeModel, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList((sipSelfWasArg ? sipCpp->::QRangeModel::mimeTypes() : sipCpp->mimeTypes()));

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_mimeTypes, doc_QRangeModel_mimeTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_match, "match(self, start: QModelIndex, role: int, value: Any, hits: int, flags: Qt.MatchFlag) -> list[QModelIndex]");

extern "C" {static PyObject *meth_QRangeModel_match(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_match(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        int a1;
        const ::QVariant* a2;
        int a2State = 0;
        int a3;
        ::Qt::MatchFlags* a4;
        int a4State = 0;
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9iJ1iJ1", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0, &a1, sipType_QVariant, &a2, &a2State, &a3, sipType_QFlags_0100Qt_MatchFlag, &a4, &a4State))
        {
            ::QModelIndexList*sipRes;

            sipRes = new ::QModelIndexList((sipSelfWasArg ? sipCpp->::QRangeModel::match(*a0, a1, *a2, a3, *a4) : sipCpp->match(*a0, a1, *a2, a3, *a4)));
            sipReleaseType(const_cast< ::QVariant *>(a2), sipType_QVariant, a2State);
            sipReleaseType(a4, sipType_QFlags_0100Qt_MatchFlag, a4State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_match, doc_QRangeModel_match);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_multiData, "multiData(self, index: QModelIndex, roleDataSpan: QModelRoleDataSpan)");

extern "C" {static PyObject *meth_QRangeModel_multiData(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_multiData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        ::QModelRoleDataSpan* a1;
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0, sipType_QModelRoleDataSpan, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QRangeModel::multiData(*a0, *a1) : sipCpp->multiData(*a0, *a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_multiData, doc_QRangeModel_multiData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_sort, "sort(self, column: int, order: Qt.SortOrder = Qt.AscendingOrder)");

extern "C" {static PyObject *meth_QRangeModel_sort(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_sort(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::Qt::SortOrder a1 = Qt::AscendingOrder;
        ::QRangeModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_order,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QRangeModel, &sipCpp, &a0, sipType_Qt_SortOrder, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QRangeModel::sort(a0, a1) : sipCpp->sort(a0, a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_sort, doc_QRangeModel_sort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_span, "span(self, index: QModelIndex) -> QSize");

extern "C" {static PyObject *meth_QRangeModel_span(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_span(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QRangeModel::span(*a0) : sipCpp->span(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_span, doc_QRangeModel_span);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_supportedDragActions, "supportedDragActions(self) -> Qt.DropAction");

extern "C" {static PyObject *meth_QRangeModel_supportedDragActions(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_supportedDragActions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRangeModel, &sipCpp))
        {
            ::Qt::DropActions*sipRes;

            sipRes = new ::Qt::DropActions((sipSelfWasArg ? sipCpp->::QRangeModel::supportedDragActions() : sipCpp->supportedDragActions()));

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_DropAction, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_supportedDragActions, doc_QRangeModel_supportedDragActions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_supportedDropActions, "supportedDropActions(self) -> Qt.DropAction");

extern "C" {static PyObject *meth_QRangeModel_supportedDropActions(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_supportedDropActions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRangeModel, &sipCpp))
        {
            ::Qt::DropActions*sipRes;

            sipRes = new ::Qt::DropActions((sipSelfWasArg ? sipCpp->::QRangeModel::supportedDropActions() : sipCpp->supportedDropActions()));

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_DropAction, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_supportedDropActions, doc_QRangeModel_supportedDropActions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_resetInternalData, "resetInternalData(self)");

extern "C" {static PyObject *meth_QRangeModel_resetInternalData(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_resetInternalData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QRangeModel, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QRangeModel::resetInternalData() : sipCpp->resetInternalData());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_resetInternalData, doc_QRangeModel_resetInternalData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_event, "event(self, a0: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QRangeModel_event(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRangeModel::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_event, doc_QRangeModel_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_eventFilter, "eventFilter(self, a0: QObject|None, a1: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QRangeModel_eventFilter(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_eventFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRangeModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QObject* a0;
        ::QEvent* a1;
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J8", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QObject, &a0, sipType_QEvent, &a1))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRangeModel::eventFilter(a0, a1) : sipCpp->eventFilter(a0, a1));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_eventFilter, doc_QRangeModel_eventFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_autoConnectPolicy, "autoConnectPolicy(self) -> QRangeModel.AutoConnectPolicy");

extern "C" {static PyObject *meth_QRangeModel_autoConnectPolicy(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_autoConnectPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRangeModel, &sipCpp))
        {
            ::QRangeModel::AutoConnectPolicy sipRes;

            sipRes = sipCpp->autoConnectPolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRangeModel_AutoConnectPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_autoConnectPolicy, doc_QRangeModel_autoConnectPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRangeModel_setAutoConnectPolicy, "setAutoConnectPolicy(self, policy: QRangeModel.AutoConnectPolicy)");

extern "C" {static PyObject *meth_QRangeModel_setAutoConnectPolicy(PyObject *, PyObject *);}
static PyObject *meth_QRangeModel_setAutoConnectPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRangeModel::AutoConnectPolicy a0;
        ::QRangeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QRangeModel, &sipCpp, sipType_QRangeModel_AutoConnectPolicy, &a0))
        {
            sipCpp->setAutoConnectPolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRangeModel, sipName_setAutoConnectPolicy, doc_QRangeModel_setAutoConnectPolicy);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRangeModel(void *, const sipTypeDef *);}
static void *cast_QRangeModel(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRangeModel *sipCpp = reinterpret_cast< ::QRangeModel *>(sipCppV);

    if (targetType == sipType_QRangeModel)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstractItemModel)->ctd_cast(static_cast< ::QAbstractItemModel *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRangeModel(void *, int);}
static void release_QRangeModel(void *sipCppV, int)
{
    ::QRangeModel *sipCpp = reinterpret_cast< ::QRangeModel *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QRangeModel(sipSimpleWrapper *);}
static void dealloc_QRangeModel(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQRangeModel *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRangeModel(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QRangeModel(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QRangeModel(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQRangeModel *sipCpp = SIP_NULLPTR;

    {
        ::QPyAbstractRange* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "#J:|JH", sipSelf, sipType_QPyAbstractRange, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipErrorState sipError = sipErrorNone;

#line 42 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrangemodel.sip"
        sipCpp = a0->create(a1);
        
        if (!sipCpp)
            sipError = sipErrorFail;
#line 2009 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQRangeModel.cpp"

            if (sipError == sipErrorNone)
            {
                sipCpp->sipPySelf = sipSelf;

                return sipCpp;
            }

            if (sipUnused)
            {
                Py_XDECREF(*sipUnused);
            }

            sipAddException(sipError, sipParseErr);

            if (sipError == sipErrorFail)
                return SIP_NULLPTR;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRangeModel[] = {{7, 255, 1}};


static PyMethodDef methods_QRangeModel[] = {
    {sipName_autoConnectPolicy, meth_QRangeModel_autoConnectPolicy, METH_VARARGS, doc_QRangeModel_autoConnectPolicy},
    {sipName_buddy, meth_QRangeModel_buddy, METH_VARARGS, doc_QRangeModel_buddy},
    {sipName_canDropMimeData, meth_QRangeModel_canDropMimeData, METH_VARARGS, doc_QRangeModel_canDropMimeData},
    {sipName_canFetchMore, meth_QRangeModel_canFetchMore, METH_VARARGS, doc_QRangeModel_canFetchMore},
    {sipName_clearItemData, meth_QRangeModel_clearItemData, METH_VARARGS, doc_QRangeModel_clearItemData},
    {sipName_columnCount, SIP_MLMETH_CAST(meth_QRangeModel_columnCount), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_columnCount},
    {sipName_data, SIP_MLMETH_CAST(meth_QRangeModel_data), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_data},
    {sipName_dropMimeData, meth_QRangeModel_dropMimeData, METH_VARARGS, doc_QRangeModel_dropMimeData},
    {sipName_event, meth_QRangeModel_event, METH_VARARGS, doc_QRangeModel_event},
    {sipName_eventFilter, meth_QRangeModel_eventFilter, METH_VARARGS, doc_QRangeModel_eventFilter},
    {sipName_fetchMore, meth_QRangeModel_fetchMore, METH_VARARGS, doc_QRangeModel_fetchMore},
    {sipName_flags, meth_QRangeModel_flags, METH_VARARGS, doc_QRangeModel_flags},
    {sipName_hasChildren, SIP_MLMETH_CAST(meth_QRangeModel_hasChildren), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_hasChildren},
    {sipName_headerData, SIP_MLMETH_CAST(meth_QRangeModel_headerData), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_headerData},
    {sipName_index, SIP_MLMETH_CAST(meth_QRangeModel_index), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_index},
    {sipName_insertColumns, SIP_MLMETH_CAST(meth_QRangeModel_insertColumns), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_insertColumns},
    {sipName_insertRows, SIP_MLMETH_CAST(meth_QRangeModel_insertRows), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_insertRows},
    {sipName_itemData, meth_QRangeModel_itemData, METH_VARARGS, doc_QRangeModel_itemData},
    {sipName_match, meth_QRangeModel_match, METH_VARARGS, doc_QRangeModel_match},
    {sipName_mimeData, meth_QRangeModel_mimeData, METH_VARARGS, doc_QRangeModel_mimeData},
    {sipName_mimeTypes, meth_QRangeModel_mimeTypes, METH_VARARGS, doc_QRangeModel_mimeTypes},
    {sipName_moveColumns, meth_QRangeModel_moveColumns, METH_VARARGS, doc_QRangeModel_moveColumns},
    {sipName_moveRows, meth_QRangeModel_moveRows, METH_VARARGS, doc_QRangeModel_moveRows},
    {sipName_multiData, meth_QRangeModel_multiData, METH_VARARGS, doc_QRangeModel_multiData},
    {sipName_parent, meth_QRangeModel_parent, METH_VARARGS, doc_QRangeModel_parent},
    {sipName_removeColumns, SIP_MLMETH_CAST(meth_QRangeModel_removeColumns), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_removeColumns},
    {sipName_removeRows, SIP_MLMETH_CAST(meth_QRangeModel_removeRows), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_removeRows},
    {sipName_resetInternalData, meth_QRangeModel_resetInternalData, METH_VARARGS, doc_QRangeModel_resetInternalData},
    {sipName_resetRoleNames, meth_QRangeModel_resetRoleNames, METH_VARARGS, doc_QRangeModel_resetRoleNames},
    {sipName_roleNames, meth_QRangeModel_roleNames, METH_VARARGS, doc_QRangeModel_roleNames},
    {sipName_rowCount, SIP_MLMETH_CAST(meth_QRangeModel_rowCount), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_rowCount},
    {sipName_setAutoConnectPolicy, meth_QRangeModel_setAutoConnectPolicy, METH_VARARGS, doc_QRangeModel_setAutoConnectPolicy},
    {sipName_setData, SIP_MLMETH_CAST(meth_QRangeModel_setData), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_setData},
    {sipName_setHeaderData, SIP_MLMETH_CAST(meth_QRangeModel_setHeaderData), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_setHeaderData},
    {sipName_setItemData, meth_QRangeModel_setItemData, METH_VARARGS, doc_QRangeModel_setItemData},
    {sipName_setRoleNames, meth_QRangeModel_setRoleNames, METH_VARARGS, doc_QRangeModel_setRoleNames},
    {sipName_sibling, meth_QRangeModel_sibling, METH_VARARGS, doc_QRangeModel_sibling},
    {sipName_sort, SIP_MLMETH_CAST(meth_QRangeModel_sort), METH_VARARGS|METH_KEYWORDS, doc_QRangeModel_sort},
    {sipName_span, meth_QRangeModel_span, METH_VARARGS, doc_QRangeModel_span},
    {sipName_supportedDragActions, meth_QRangeModel_supportedDragActions, METH_VARARGS, doc_QRangeModel_supportedDragActions},
    {sipName_supportedDropActions, meth_QRangeModel_supportedDropActions, METH_VARARGS, doc_QRangeModel_supportedDropActions}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QRangeModel[] = {
    {sipName_None_, static_cast<int>(::QRangeModel::AutoConnectPolicy::None)},
    {sipName_Full, static_cast<int>(::QRangeModel::AutoConnectPolicy::Full)},
    {sipName_OnRead, static_cast<int>(::QRangeModel::AutoConnectPolicy::OnRead)},
    {0, 0}
};

PyDoc_STRVAR(doc_QRangeModel, "\1QRangeModel(range: QPyAbstractRange|None, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QRangeModel[] = {
    {"autoConnectPolicyChanged(QRangeModel::AutoConnectPolicy)", "\1autoConnectPolicyChanged(self, policy: QRangeModel.AutoConnectPolicy)", SIP_NULLPTR, SIP_NULLPTR},
    {"roleNamesChanged()", "\1roleNamesChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QRangeModel = {
    &::QRangeModel::staticMetaObject,
    signals_QRangeModel,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QRangeModel = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRangeModel,
        SIP_NULLPTR,
        &plugin_QRangeModel,
    },
    {
        sipNameNr_QRangeModel,
        {0, 0, 1},
        41, methods_QRangeModel,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QRangeModel, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QRangeModel,
    -1,
    -1,
    supers_QRangeModel,
    SIP_NULLPTR,
    init_type_QRangeModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRangeModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QRangeModel,
    cast_QRangeModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QRangeModel),
};
