/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qlowenergyconnectionparameters.sip"
#include <qlowenergyconnectionparameters.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyConnectionParameters.cpp"



PyDoc_STRVAR(doc_QLowEnergyConnectionParameters_setIntervalRange, "setIntervalRange(self, minimum: float, maximum: float)");

extern "C" {static PyObject *meth_QLowEnergyConnectionParameters_setIntervalRange(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyConnectionParameters_setIntervalRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        double a1;
        ::QLowEnergyConnectionParameters *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QLowEnergyConnectionParameters, &sipCpp, &a0, &a1))
        {
            sipCpp->setIntervalRange(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyConnectionParameters, sipName_setIntervalRange, doc_QLowEnergyConnectionParameters_setIntervalRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyConnectionParameters_minimumInterval, "minimumInterval(self) -> float");

extern "C" {static PyObject *meth_QLowEnergyConnectionParameters_minimumInterval(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyConnectionParameters_minimumInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyConnectionParameters *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyConnectionParameters, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->minimumInterval();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyConnectionParameters, sipName_minimumInterval, doc_QLowEnergyConnectionParameters_minimumInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyConnectionParameters_maximumInterval, "maximumInterval(self) -> float");

extern "C" {static PyObject *meth_QLowEnergyConnectionParameters_maximumInterval(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyConnectionParameters_maximumInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyConnectionParameters *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyConnectionParameters, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->maximumInterval();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyConnectionParameters, sipName_maximumInterval, doc_QLowEnergyConnectionParameters_maximumInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyConnectionParameters_setLatency, "setLatency(self, latency: int)");

extern "C" {static PyObject *meth_QLowEnergyConnectionParameters_setLatency(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyConnectionParameters_setLatency(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLowEnergyConnectionParameters *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QLowEnergyConnectionParameters, &sipCpp, &a0))
        {
            sipCpp->setLatency(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyConnectionParameters, sipName_setLatency, doc_QLowEnergyConnectionParameters_setLatency);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyConnectionParameters_latency, "latency(self) -> int");

extern "C" {static PyObject *meth_QLowEnergyConnectionParameters_latency(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyConnectionParameters_latency(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyConnectionParameters *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyConnectionParameters, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->latency();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyConnectionParameters, sipName_latency, doc_QLowEnergyConnectionParameters_latency);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyConnectionParameters_setSupervisionTimeout, "setSupervisionTimeout(self, timeout: int)");

extern "C" {static PyObject *meth_QLowEnergyConnectionParameters_setSupervisionTimeout(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyConnectionParameters_setSupervisionTimeout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLowEnergyConnectionParameters *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QLowEnergyConnectionParameters, &sipCpp, &a0))
        {
            sipCpp->setSupervisionTimeout(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyConnectionParameters, sipName_setSupervisionTimeout, doc_QLowEnergyConnectionParameters_setSupervisionTimeout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyConnectionParameters_supervisionTimeout, "supervisionTimeout(self) -> int");

extern "C" {static PyObject *meth_QLowEnergyConnectionParameters_supervisionTimeout(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyConnectionParameters_supervisionTimeout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyConnectionParameters *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyConnectionParameters, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->supervisionTimeout();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyConnectionParameters, sipName_supervisionTimeout, doc_QLowEnergyConnectionParameters_supervisionTimeout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyConnectionParameters_swap, "swap(self, other: QLowEnergyConnectionParameters)");

extern "C" {static PyObject *meth_QLowEnergyConnectionParameters_swap(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyConnectionParameters_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLowEnergyConnectionParameters* a0;
        ::QLowEnergyConnectionParameters *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLowEnergyConnectionParameters, &sipCpp, sipType_QLowEnergyConnectionParameters, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyConnectionParameters, sipName_swap, doc_QLowEnergyConnectionParameters_swap);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QLowEnergyConnectionParameters___eq__(PyObject *, PyObject *);}
static PyObject *slot_QLowEnergyConnectionParameters___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLowEnergyConnectionParameters *sipCpp = reinterpret_cast< ::QLowEnergyConnectionParameters *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLowEnergyConnectionParameters));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyConnectionParameters* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLowEnergyConnectionParameters, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, eq_slot, sipType_QLowEnergyConnectionParameters, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QLowEnergyConnectionParameters___ne__(PyObject *, PyObject *);}
static PyObject *slot_QLowEnergyConnectionParameters___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLowEnergyConnectionParameters *sipCpp = reinterpret_cast< ::QLowEnergyConnectionParameters *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLowEnergyConnectionParameters));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyConnectionParameters* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLowEnergyConnectionParameters, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, ne_slot, sipType_QLowEnergyConnectionParameters, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QLowEnergyConnectionParameters(void *, int);}
static void release_QLowEnergyConnectionParameters(void *sipCppV, int)
{
    delete reinterpret_cast< ::QLowEnergyConnectionParameters *>(sipCppV);
}


extern "C" {static void *array_QLowEnergyConnectionParameters(Py_ssize_t);}
static void *array_QLowEnergyConnectionParameters(Py_ssize_t sipNrElem)
{
    return new ::QLowEnergyConnectionParameters[sipNrElem];
}


extern "C" {static void array_delete_QLowEnergyConnectionParameters(void *);}
static void array_delete_QLowEnergyConnectionParameters(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLowEnergyConnectionParameters *>(sipCpp);
}


extern "C" {static void assign_QLowEnergyConnectionParameters(void *, Py_ssize_t, void *);}
static void assign_QLowEnergyConnectionParameters(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QLowEnergyConnectionParameters *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QLowEnergyConnectionParameters *>(sipSrc);
}


extern "C" {static void *copy_QLowEnergyConnectionParameters(const void *, Py_ssize_t);}
static void *copy_QLowEnergyConnectionParameters(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QLowEnergyConnectionParameters(reinterpret_cast<const ::QLowEnergyConnectionParameters *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QLowEnergyConnectionParameters(sipSimpleWrapper *);}
static void dealloc_QLowEnergyConnectionParameters(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLowEnergyConnectionParameters(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QLowEnergyConnectionParameters(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLowEnergyConnectionParameters(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QLowEnergyConnectionParameters *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QLowEnergyConnectionParameters();

            return sipCpp;
        }
    }

    {
        const ::QLowEnergyConnectionParameters* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QLowEnergyConnectionParameters, &a0))
        {
            sipCpp = new ::QLowEnergyConnectionParameters(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QLowEnergyConnectionParameters[] = {
    {(void *)slot_QLowEnergyConnectionParameters___eq__, eq_slot},
    {(void *)slot_QLowEnergyConnectionParameters___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QLowEnergyConnectionParameters[] = {
    {sipName_latency, meth_QLowEnergyConnectionParameters_latency, METH_VARARGS, doc_QLowEnergyConnectionParameters_latency},
    {sipName_maximumInterval, meth_QLowEnergyConnectionParameters_maximumInterval, METH_VARARGS, doc_QLowEnergyConnectionParameters_maximumInterval},
    {sipName_minimumInterval, meth_QLowEnergyConnectionParameters_minimumInterval, METH_VARARGS, doc_QLowEnergyConnectionParameters_minimumInterval},
    {sipName_setIntervalRange, meth_QLowEnergyConnectionParameters_setIntervalRange, METH_VARARGS, doc_QLowEnergyConnectionParameters_setIntervalRange},
    {sipName_setLatency, meth_QLowEnergyConnectionParameters_setLatency, METH_VARARGS, doc_QLowEnergyConnectionParameters_setLatency},
    {sipName_setSupervisionTimeout, meth_QLowEnergyConnectionParameters_setSupervisionTimeout, METH_VARARGS, doc_QLowEnergyConnectionParameters_setSupervisionTimeout},
    {sipName_supervisionTimeout, meth_QLowEnergyConnectionParameters_supervisionTimeout, METH_VARARGS, doc_QLowEnergyConnectionParameters_supervisionTimeout},
    {sipName_swap, meth_QLowEnergyConnectionParameters_swap, METH_VARARGS, doc_QLowEnergyConnectionParameters_swap}
};

PyDoc_STRVAR(doc_QLowEnergyConnectionParameters, "\1QLowEnergyConnectionParameters()\n"
"QLowEnergyConnectionParameters(other: QLowEnergyConnectionParameters)");


sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyConnectionParameters = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLowEnergyConnectionParameters,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QLowEnergyConnectionParameters,
        {0, 0, 1},
        8, methods_QLowEnergyConnectionParameters,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLowEnergyConnectionParameters,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QLowEnergyConnectionParameters,
    init_type_QLowEnergyConnectionParameters,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLowEnergyConnectionParameters,
    assign_QLowEnergyConnectionParameters,
    array_QLowEnergyConnectionParameters,
    copy_QLowEnergyConnectionParameters,
    release_QLowEnergyConnectionParameters,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLowEnergyConnectionParameters,
    sizeof (::QLowEnergyConnectionParameters),
};
