/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediatimerange.sip"
#include <qmediatimerange.h>
#line 58 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediatimerange.sip"
#include <qmediatimerange.h>
#line 31 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaTimeRangeInterval.cpp"



PyDoc_STRVAR(doc_QMediaTimeRange_Interval_start, "start(self) -> int");

extern "C" {static PyObject *meth_QMediaTimeRange_Interval_start(PyObject *, PyObject *);}
static PyObject *meth_QMediaTimeRange_Interval_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaTimeRange::Interval *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaTimeRange_Interval, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->start();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Interval, sipName_start, doc_QMediaTimeRange_Interval_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaTimeRange_Interval_end, "end(self) -> int");

extern "C" {static PyObject *meth_QMediaTimeRange_Interval_end(PyObject *, PyObject *);}
static PyObject *meth_QMediaTimeRange_Interval_end(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaTimeRange::Interval *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaTimeRange_Interval, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->end();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Interval, sipName_end, doc_QMediaTimeRange_Interval_end);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaTimeRange_Interval_contains, "contains(self, time: int) -> bool");

extern "C" {static PyObject *meth_QMediaTimeRange_Interval_contains(PyObject *, PyObject *);}
static PyObject *meth_QMediaTimeRange_Interval_contains(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;
        const ::QMediaTimeRange::Interval *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QMediaTimeRange_Interval, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->contains(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Interval, sipName_contains, doc_QMediaTimeRange_Interval_contains);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaTimeRange_Interval_isNormal, "isNormal(self) -> bool");

extern "C" {static PyObject *meth_QMediaTimeRange_Interval_isNormal(PyObject *, PyObject *);}
static PyObject *meth_QMediaTimeRange_Interval_isNormal(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaTimeRange::Interval *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaTimeRange_Interval, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNormal();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Interval, sipName_isNormal, doc_QMediaTimeRange_Interval_isNormal);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaTimeRange_Interval_normalized, "normalized(self) -> QMediaTimeRange.Interval");

extern "C" {static PyObject *meth_QMediaTimeRange_Interval_normalized(PyObject *, PyObject *);}
static PyObject *meth_QMediaTimeRange_Interval_normalized(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaTimeRange::Interval *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaTimeRange_Interval, &sipCpp))
        {
            ::QMediaTimeRange::Interval*sipRes;

            sipRes = new ::QMediaTimeRange::Interval(sipCpp->normalized());

            return sipConvertFromNewType(sipRes, sipType_QMediaTimeRange_Interval, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Interval, sipName_normalized, doc_QMediaTimeRange_Interval_normalized);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaTimeRange_Interval_translated, "translated(self, offset: int) -> QMediaTimeRange.Interval");

extern "C" {static PyObject *meth_QMediaTimeRange_Interval_translated(PyObject *, PyObject *);}
static PyObject *meth_QMediaTimeRange_Interval_translated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;
        const ::QMediaTimeRange::Interval *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QMediaTimeRange_Interval, &sipCpp, &a0))
        {
            ::QMediaTimeRange::Interval*sipRes;

            sipRes = new ::QMediaTimeRange::Interval(sipCpp->translated(a0));

            return sipConvertFromNewType(sipRes, sipType_QMediaTimeRange_Interval, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Interval, sipName_translated, doc_QMediaTimeRange_Interval_translated);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QMediaTimeRange_Interval___eq__(PyObject *, PyObject *);}
static PyObject *slot_QMediaTimeRange_Interval___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QMediaTimeRange::Interval *sipCpp = reinterpret_cast< ::QMediaTimeRange::Interval *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QMediaTimeRange_Interval));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaTimeRange::Interval* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QMediaTimeRange_Interval, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, eq_slot, sipType_QMediaTimeRange_Interval, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QMediaTimeRange_Interval___ne__(PyObject *, PyObject *);}
static PyObject *slot_QMediaTimeRange_Interval___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QMediaTimeRange::Interval *sipCpp = reinterpret_cast< ::QMediaTimeRange::Interval *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QMediaTimeRange_Interval));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaTimeRange::Interval* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QMediaTimeRange_Interval, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, ne_slot, sipType_QMediaTimeRange_Interval, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QMediaTimeRange_Interval(void *, int);}
static void release_QMediaTimeRange_Interval(void *sipCppV, int)
{
    delete reinterpret_cast< ::QMediaTimeRange::Interval *>(sipCppV);
}


extern "C" {static void assign_QMediaTimeRange_Interval(void *, Py_ssize_t, void *);}
static void assign_QMediaTimeRange_Interval(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QMediaTimeRange::Interval *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QMediaTimeRange::Interval *>(sipSrc);
}


extern "C" {static void *copy_QMediaTimeRange_Interval(const void *, Py_ssize_t);}
static void *copy_QMediaTimeRange_Interval(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QMediaTimeRange::Interval(reinterpret_cast<const ::QMediaTimeRange::Interval *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QMediaTimeRange_Interval(sipSimpleWrapper *);}
static void dealloc_QMediaTimeRange_Interval(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMediaTimeRange_Interval(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QMediaTimeRange_Interval(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMediaTimeRange_Interval(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QMediaTimeRange::Interval *sipCpp = SIP_NULLPTR;

    {
        ::qint64 a0;
        ::qint64 a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "nn", &a0, &a1))
        {
            sipCpp = new ::QMediaTimeRange::Interval(a0, a1);

            return sipCpp;
        }
    }

    {
        const ::QMediaTimeRange::Interval* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QMediaTimeRange_Interval, &a0))
        {
            sipCpp = new ::QMediaTimeRange::Interval(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QMediaTimeRange_Interval[] = {
    {(void *)slot_QMediaTimeRange_Interval___eq__, eq_slot},
    {(void *)slot_QMediaTimeRange_Interval___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QMediaTimeRange_Interval[] = {
    {sipName_contains, meth_QMediaTimeRange_Interval_contains, METH_VARARGS, doc_QMediaTimeRange_Interval_contains},
    {sipName_end, meth_QMediaTimeRange_Interval_end, METH_VARARGS, doc_QMediaTimeRange_Interval_end},
    {sipName_isNormal, meth_QMediaTimeRange_Interval_isNormal, METH_VARARGS, doc_QMediaTimeRange_Interval_isNormal},
    {sipName_normalized, meth_QMediaTimeRange_Interval_normalized, METH_VARARGS, doc_QMediaTimeRange_Interval_normalized},
    {sipName_start, meth_QMediaTimeRange_Interval_start, METH_VARARGS, doc_QMediaTimeRange_Interval_start},
    {sipName_translated, meth_QMediaTimeRange_Interval_translated, METH_VARARGS, doc_QMediaTimeRange_Interval_translated}
};

PyDoc_STRVAR(doc_QMediaTimeRange_Interval, "\1QMediaTimeRange.Interval(start: int, end: int)\n"
"QMediaTimeRange.Interval(a0: QMediaTimeRange.Interval)");


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaTimeRange_Interval = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMediaTimeRange__Interval,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_Interval,
        {70, 255, 0},
        6, methods_QMediaTimeRange_Interval,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMediaTimeRange_Interval,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QMediaTimeRange_Interval,
    init_type_QMediaTimeRange_Interval,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMediaTimeRange_Interval,
    assign_QMediaTimeRange_Interval,
    SIP_NULLPTR,
    copy_QMediaTimeRange_Interval,
    release_QMediaTimeRange_Interval,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QMediaTimeRange::Interval),
};
