/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdir.sip"
#include <qdir.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qchar.sip"
#include <qchar.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qfileinfo.sip"
#include <qfileinfo.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qfiledevice.sip"
#include <qfiledevice.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"


PyDoc_STRVAR(doc_QDir_setPath, "setPath(self, path: str|None)");

extern "C" {static PyObject *meth_QDir_setPath(PyObject *, PyObject *);}
static PyObject *meth_QDir_setPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setPath(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_setPath, doc_QDir_setPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_path, "path(self) -> str");

extern "C" {static PyObject *meth_QDir_path(PyObject *, PyObject *);}
static PyObject *meth_QDir_path(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->path());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_path, doc_QDir_path);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_absolutePath, "absolutePath(self) -> str");

extern "C" {static PyObject *meth_QDir_absolutePath(PyObject *, PyObject *);}
static PyObject *meth_QDir_absolutePath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->absolutePath());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_absolutePath, doc_QDir_absolutePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_canonicalPath, "canonicalPath(self) -> str");

extern "C" {static PyObject *meth_QDir_canonicalPath(PyObject *, PyObject *);}
static PyObject *meth_QDir_canonicalPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->canonicalPath());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_canonicalPath, doc_QDir_canonicalPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_dirName, "dirName(self) -> str");

extern "C" {static PyObject *meth_QDir_dirName(PyObject *, PyObject *);}
static PyObject *meth_QDir_dirName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->dirName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_dirName, doc_QDir_dirName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_filePath, "filePath(self, fileName: str|None) -> str");

extern "C" {static PyObject *meth_QDir_filePath(PyObject *, PyObject *);}
static PyObject *meth_QDir_filePath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->filePath(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_filePath, doc_QDir_filePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_absoluteFilePath, "absoluteFilePath(self, fileName: str|None) -> str");

extern "C" {static PyObject *meth_QDir_absoluteFilePath(PyObject *, PyObject *);}
static PyObject *meth_QDir_absoluteFilePath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->absoluteFilePath(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_absoluteFilePath, doc_QDir_absoluteFilePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_relativeFilePath, "relativeFilePath(self, fileName: str|None) -> str");

extern "C" {static PyObject *meth_QDir_relativeFilePath(PyObject *, PyObject *);}
static PyObject *meth_QDir_relativeFilePath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->relativeFilePath(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_relativeFilePath, doc_QDir_relativeFilePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_cd, "cd(self, dirName: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_cd(PyObject *, PyObject *);}
static PyObject *meth_QDir_cd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->cd(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_cd, doc_QDir_cd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_cdUp, "cdUp(self) -> bool");

extern "C" {static PyObject *meth_QDir_cdUp(PyObject *, PyObject *);}
static PyObject *meth_QDir_cdUp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->cdUp();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_cdUp, doc_QDir_cdUp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_nameFilters, "nameFilters(self) -> list[str]");

extern "C" {static PyObject *meth_QDir_nameFilters(PyObject *, PyObject *);}
static PyObject *meth_QDir_nameFilters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->nameFilters());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_nameFilters, doc_QDir_nameFilters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_setNameFilters, "setNameFilters(self, nameFilters: Iterable[str|None])");

extern "C" {static PyObject *meth_QDir_setNameFilters(PyObject *, PyObject *);}
static PyObject *meth_QDir_setNameFilters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setNameFilters(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_setNameFilters, doc_QDir_setNameFilters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_filter, "filter(self) -> QDir.Filter");

extern "C" {static PyObject *meth_QDir_filter(PyObject *, PyObject *);}
static PyObject *meth_QDir_filter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            ::QDir::Filters*sipRes;

            sipRes = new ::QDir::Filters(sipCpp->filter());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QDir_Filter, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_filter, doc_QDir_filter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_setFilter, "setFilter(self, filter: QDir.Filter)");

extern "C" {static PyObject *meth_QDir_setFilter(PyObject *, PyObject *);}
static PyObject *meth_QDir_setFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDir::Filters* a0;
        int a0State = 0;
        ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QFlags_0100QDir_Filter, &a0, &a0State))
        {
            sipCpp->setFilter(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QDir_Filter, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_setFilter, doc_QDir_setFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_sorting, "sorting(self) -> QDir.SortFlag");

extern "C" {static PyObject *meth_QDir_sorting(PyObject *, PyObject *);}
static PyObject *meth_QDir_sorting(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            ::QDir::SortFlags*sipRes;

            sipRes = new ::QDir::SortFlags(sipCpp->sorting());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QDir_SortFlag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_sorting, doc_QDir_sorting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_setSorting, "setSorting(self, sort: QDir.SortFlag)");

extern "C" {static PyObject *meth_QDir_setSorting(PyObject *, PyObject *);}
static PyObject *meth_QDir_setSorting(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDir::SortFlags* a0;
        int a0State = 0;
        ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QFlags_0100QDir_SortFlag, &a0, &a0State))
        {
            sipCpp->setSorting(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QDir_SortFlag, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_setSorting, doc_QDir_setSorting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_count, "count(self) -> int");

extern "C" {static PyObject *meth_QDir_count(PyObject *, PyObject *);}
static PyObject *meth_QDir_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            ::qsizetype sipRes = 0;

#line 96 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdir.sip"
        sipRes = sipCpp->count(Qt::Disambiguated);
#line 512 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_count, doc_QDir_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_nameFiltersFromString, "nameFiltersFromString(nameFilter: str|None) -> list[str]");

extern "C" {static PyObject *meth_QDir_nameFiltersFromString(PyObject *, PyObject *);}
static PyObject *meth_QDir_nameFiltersFromString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QDir::nameFiltersFromString(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_nameFiltersFromString, doc_QDir_nameFiltersFromString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_entryList, "entryList(self, filters: QDir.Filter = QDir.NoFilter, sort: QDir.SortFlag = QDir.NoSort) -> list[str]\n"
"entryList(self, nameFilters: Iterable[str|None], filters: QDir.Filter = QDir.NoFilter, sort: QDir.SortFlag = QDir.NoSort) -> list[str]");

extern "C" {static PyObject *meth_QDir_entryList(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDir_entryList(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDir::Filters a0def = QDir::NoFilter;
        ::QDir::Filters* a0 = &a0def;
        int a0State = 0;
        ::QDir::SortFlags a1def = QDir::NoSort;
        ::QDir::SortFlags* a1 = &a1def;
        int a1State = 0;
        const ::QDir *sipCpp;

        static const char *sipKwdList[] = {
            sipName_filters,
            sipName_sort,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1J1", &sipSelf, sipType_QDir, &sipCpp, sipType_QFlags_0100QDir_Filter, &a0, &a0State, sipType_QFlags_0100QDir_SortFlag, &a1, &a1State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->entryList(*a0, *a1));
            sipReleaseType(a0, sipType_QFlags_0100QDir_Filter, a0State);
            sipReleaseType(a1, sipType_QFlags_0100QDir_SortFlag, a1State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QDir::Filters a1def = QDir::NoFilter;
        ::QDir::Filters* a1 = &a1def;
        int a1State = 0;
        ::QDir::SortFlags a2def = QDir::NoSort;
        ::QDir::SortFlags* a2 = &a2def;
        int a2State = 0;
        const ::QDir *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_filters,
            sipName_sort,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1J1", &sipSelf, sipType_QDir, &sipCpp, sipType_QStringList, &a0, &a0State, sipType_QFlags_0100QDir_Filter, &a1, &a1State, sipType_QFlags_0100QDir_SortFlag, &a2, &a2State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->entryList(*a0, *a1, *a2));
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);
            sipReleaseType(a1, sipType_QFlags_0100QDir_Filter, a1State);
            sipReleaseType(a2, sipType_QFlags_0100QDir_SortFlag, a2State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_entryList, doc_QDir_entryList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_entryInfoList, "entryInfoList(self, filters: QDir.Filter = QDir.NoFilter, sort: QDir.SortFlag = QDir.NoSort) -> list[QFileInfo]\n"
"entryInfoList(self, nameFilters: Iterable[str|None], filters: QDir.Filter = QDir.NoFilter, sort: QDir.SortFlag = QDir.NoSort) -> list[QFileInfo]");

extern "C" {static PyObject *meth_QDir_entryInfoList(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDir_entryInfoList(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDir::Filters a0def = QDir::NoFilter;
        ::QDir::Filters* a0 = &a0def;
        int a0State = 0;
        ::QDir::SortFlags a1def = QDir::NoSort;
        ::QDir::SortFlags* a1 = &a1def;
        int a1State = 0;
        const ::QDir *sipCpp;

        static const char *sipKwdList[] = {
            sipName_filters,
            sipName_sort,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1J1", &sipSelf, sipType_QDir, &sipCpp, sipType_QFlags_0100QDir_Filter, &a0, &a0State, sipType_QFlags_0100QDir_SortFlag, &a1, &a1State))
        {
            ::QFileInfoList*sipRes;

            sipRes = new ::QFileInfoList(sipCpp->entryInfoList(*a0, *a1));
            sipReleaseType(a0, sipType_QFlags_0100QDir_Filter, a0State);
            sipReleaseType(a1, sipType_QFlags_0100QDir_SortFlag, a1State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QFileInfo, SIP_NULLPTR);
        }
    }

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QDir::Filters a1def = QDir::NoFilter;
        ::QDir::Filters* a1 = &a1def;
        int a1State = 0;
        ::QDir::SortFlags a2def = QDir::NoSort;
        ::QDir::SortFlags* a2 = &a2def;
        int a2State = 0;
        const ::QDir *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_filters,
            sipName_sort,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1J1", &sipSelf, sipType_QDir, &sipCpp, sipType_QStringList, &a0, &a0State, sipType_QFlags_0100QDir_Filter, &a1, &a1State, sipType_QFlags_0100QDir_SortFlag, &a2, &a2State))
        {
            ::QFileInfoList*sipRes;

            sipRes = new ::QFileInfoList(sipCpp->entryInfoList(*a0, *a1, *a2));
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);
            sipReleaseType(a1, sipType_QFlags_0100QDir_Filter, a1State);
            sipReleaseType(a2, sipType_QFlags_0100QDir_SortFlag, a2State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QFileInfo, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_entryInfoList, doc_QDir_entryInfoList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_mkdir, "mkdir(self, dirName: str|None, permissions: QFileDevice.Permission) -> bool\n"
"mkdir(self, dirName: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_mkdir(PyObject *, PyObject *);}
static PyObject *meth_QDir_mkdir(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QFileDevice::Permissions* a1;
        int a1State = 0;
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State, sipType_QFlags_0100QFileDevice_Permission, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->mkdir(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(a1, sipType_QFlags_0100QFileDevice_Permission, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->mkdir(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_mkdir, doc_QDir_mkdir);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_rmdir, "rmdir(self, dirName: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_rmdir(PyObject *, PyObject *);}
static PyObject *meth_QDir_rmdir(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->rmdir(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_rmdir, doc_QDir_rmdir);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_mkpath, "mkpath(self, dirPath: str|None, permissions: QFileDevice.Permission) -> bool\n"
"mkpath(self, dirPath: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_mkpath(PyObject *, PyObject *);}
static PyObject *meth_QDir_mkpath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QFileDevice::Permissions* a1;
        int a1State = 0;
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State, sipType_QFlags_0100QFileDevice_Permission, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->mkpath(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(a1, sipType_QFlags_0100QFileDevice_Permission, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->mkpath(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_mkpath, doc_QDir_mkpath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_rmpath, "rmpath(self, dirPath: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_rmpath(PyObject *, PyObject *);}
static PyObject *meth_QDir_rmpath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->rmpath(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_rmpath, doc_QDir_rmpath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_isReadable, "isReadable(self) -> bool");

extern "C" {static PyObject *meth_QDir_isReadable(PyObject *, PyObject *);}
static PyObject *meth_QDir_isReadable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isReadable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_isReadable, doc_QDir_isReadable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_exists, "exists(self) -> bool\n"
"exists(self, name: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_exists(PyObject *, PyObject *);}
static PyObject *meth_QDir_exists(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->exists();

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->exists(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_exists, doc_QDir_exists);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_isRoot, "isRoot(self) -> bool");

extern "C" {static PyObject *meth_QDir_isRoot(PyObject *, PyObject *);}
static PyObject *meth_QDir_isRoot(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isRoot();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_isRoot, doc_QDir_isRoot);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_isRelativePath, "isRelativePath(path: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_isRelativePath(PyObject *, PyObject *);}
static PyObject *meth_QDir_isRelativePath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = ::QDir::isRelativePath(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_isRelativePath, doc_QDir_isRelativePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_isAbsolutePath, "isAbsolutePath(path: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_isAbsolutePath(PyObject *, PyObject *);}
static PyObject *meth_QDir_isAbsolutePath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = ::QDir::isAbsolutePath(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_isAbsolutePath, doc_QDir_isAbsolutePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_isRelative, "isRelative(self) -> bool");

extern "C" {static PyObject *meth_QDir_isRelative(PyObject *, PyObject *);}
static PyObject *meth_QDir_isRelative(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isRelative();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_isRelative, doc_QDir_isRelative);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_isAbsolute, "isAbsolute(self) -> bool");

extern "C" {static PyObject *meth_QDir_isAbsolute(PyObject *, PyObject *);}
static PyObject *meth_QDir_isAbsolute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAbsolute();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_isAbsolute, doc_QDir_isAbsolute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_makeAbsolute, "makeAbsolute(self) -> bool");

extern "C" {static PyObject *meth_QDir_makeAbsolute(PyObject *, PyObject *);}
static PyObject *meth_QDir_makeAbsolute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->makeAbsolute();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_makeAbsolute, doc_QDir_makeAbsolute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_remove, "remove(self, fileName: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_remove(PyObject *, PyObject *);}
static PyObject *meth_QDir_remove(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->remove(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_remove, doc_QDir_remove);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_rename, "rename(self, oldName: str|None, newName: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_rename(PyObject *, PyObject *);}
static PyObject *meth_QDir_rename(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QDir, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->rename(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_rename, doc_QDir_rename);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_refresh, "refresh(self)");

extern "C" {static PyObject *meth_QDir_refresh(PyObject *, PyObject *);}
static PyObject *meth_QDir_refresh(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            sipCpp->refresh();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_refresh, doc_QDir_refresh);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_drives, "drives() -> list[QFileInfo]");

extern "C" {static PyObject *meth_QDir_drives(PyObject *, PyObject *);}
static PyObject *meth_QDir_drives(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QFileInfoList*sipRes;

            sipRes = new ::QFileInfoList(::QDir::drives());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QFileInfo, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_drives, doc_QDir_drives);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_separator, "separator() -> str");

extern "C" {static PyObject *meth_QDir_separator(PyObject *, PyObject *);}
static PyObject *meth_QDir_separator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QChar*sipRes;

            sipRes = new ::QChar(::QDir::separator());

            return sipConvertFromNewType(sipRes, sipType_QChar, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_separator, doc_QDir_separator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_setCurrent, "setCurrent(path: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_setCurrent(PyObject *, PyObject *);}
static PyObject *meth_QDir_setCurrent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = ::QDir::setCurrent(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_setCurrent, doc_QDir_setCurrent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_current, "current() -> QDir");

extern "C" {static PyObject *meth_QDir_current(PyObject *, PyObject *);}
static PyObject *meth_QDir_current(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QDir*sipRes;

            sipRes = new ::QDir(::QDir::current());

            return sipConvertFromNewType(sipRes, sipType_QDir, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_current, doc_QDir_current);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_currentPath, "currentPath() -> str");

extern "C" {static PyObject *meth_QDir_currentPath(PyObject *, PyObject *);}
static PyObject *meth_QDir_currentPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QDir::currentPath());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_currentPath, doc_QDir_currentPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_home, "home() -> QDir");

extern "C" {static PyObject *meth_QDir_home(PyObject *, PyObject *);}
static PyObject *meth_QDir_home(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QDir*sipRes;

            sipRes = new ::QDir(::QDir::home());

            return sipConvertFromNewType(sipRes, sipType_QDir, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_home, doc_QDir_home);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_homePath, "homePath() -> str");

extern "C" {static PyObject *meth_QDir_homePath(PyObject *, PyObject *);}
static PyObject *meth_QDir_homePath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QDir::homePath());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_homePath, doc_QDir_homePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_root, "root() -> QDir");

extern "C" {static PyObject *meth_QDir_root(PyObject *, PyObject *);}
static PyObject *meth_QDir_root(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QDir*sipRes;

            sipRes = new ::QDir(::QDir::root());

            return sipConvertFromNewType(sipRes, sipType_QDir, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_root, doc_QDir_root);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_rootPath, "rootPath() -> str");

extern "C" {static PyObject *meth_QDir_rootPath(PyObject *, PyObject *);}
static PyObject *meth_QDir_rootPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QDir::rootPath());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_rootPath, doc_QDir_rootPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_temp, "temp() -> QDir");

extern "C" {static PyObject *meth_QDir_temp(PyObject *, PyObject *);}
static PyObject *meth_QDir_temp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QDir*sipRes;

            sipRes = new ::QDir(::QDir::temp());

            return sipConvertFromNewType(sipRes, sipType_QDir, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_temp, doc_QDir_temp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_tempPath, "tempPath() -> str");

extern "C" {static PyObject *meth_QDir_tempPath(PyObject *, PyObject *);}
static PyObject *meth_QDir_tempPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QDir::tempPath());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_tempPath, doc_QDir_tempPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_match, "match(filters: Iterable[str|None], fileName: str|None) -> bool\n"
"match(filter: str|None, fileName: str|None) -> bool");

extern "C" {static PyObject *meth_QDir_match(PyObject *, PyObject *);}
static PyObject *meth_QDir_match(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1J1", &sipSelf, sipType_QStringList, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            sipRes = ::QDir::match(*a0, *a1);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1J1", &sipSelf, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            sipRes = ::QDir::match(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_match, doc_QDir_match);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_cleanPath, "cleanPath(path: str|None) -> str");

extern "C" {static PyObject *meth_QDir_cleanPath(PyObject *, PyObject *);}
static PyObject *meth_QDir_cleanPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QDir::cleanPath(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_cleanPath, doc_QDir_cleanPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_toNativeSeparators, "toNativeSeparators(pathName: str|None) -> str");

extern "C" {static PyObject *meth_QDir_toNativeSeparators(PyObject *, PyObject *);}
static PyObject *meth_QDir_toNativeSeparators(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QDir::toNativeSeparators(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_toNativeSeparators, doc_QDir_toNativeSeparators);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_fromNativeSeparators, "fromNativeSeparators(pathName: str|None) -> str");

extern "C" {static PyObject *meth_QDir_fromNativeSeparators(PyObject *, PyObject *);}
static PyObject *meth_QDir_fromNativeSeparators(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QDir::fromNativeSeparators(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_fromNativeSeparators, doc_QDir_fromNativeSeparators);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_setSearchPaths, "setSearchPaths(prefix: str|None, searchPaths: Iterable[str|None])");

extern "C" {static PyObject *meth_QDir_setSearchPaths(PyObject *, PyObject *);}
static PyObject *meth_QDir_setSearchPaths(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QStringList* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1J1", &sipSelf, sipType_QString, &a0, &a0State, sipType_QStringList, &a1, &a1State))
        {
            ::QDir::setSearchPaths(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QStringList *>(a1), sipType_QStringList, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_setSearchPaths, doc_QDir_setSearchPaths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_addSearchPath, "addSearchPath(prefix: str|None, path: str|None)");

extern "C" {static PyObject *meth_QDir_addSearchPath(PyObject *, PyObject *);}
static PyObject *meth_QDir_addSearchPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1J1", &sipSelf, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QDir::addSearchPath(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_addSearchPath, doc_QDir_addSearchPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_searchPaths, "searchPaths(prefix: str|None) -> list[str]");

extern "C" {static PyObject *meth_QDir_searchPaths(PyObject *, PyObject *);}
static PyObject *meth_QDir_searchPaths(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QDir::searchPaths(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_searchPaths, doc_QDir_searchPaths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_removeRecursively, "removeRecursively(self) -> bool");

extern "C" {static PyObject *meth_QDir_removeRecursively(PyObject *, PyObject *);}
static PyObject *meth_QDir_removeRecursively(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDir, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->removeRecursively();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_removeRecursively, doc_QDir_removeRecursively);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_swap, "swap(self, other: QDir)");

extern "C" {static PyObject *meth_QDir_swap(PyObject *, PyObject *);}
static PyObject *meth_QDir_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDir* a0;
        ::QDir *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QDir, &sipCpp, sipType_QDir, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_swap, doc_QDir_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_listSeparator, "listSeparator() -> str");

extern "C" {static PyObject *meth_QDir_listSeparator(PyObject *, PyObject *);}
static PyObject *meth_QDir_listSeparator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QChar*sipRes;

            sipRes = new ::QChar(::QDir::listSeparator());

            return sipConvertFromNewType(sipRes, sipType_QChar, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_listSeparator, doc_QDir_listSeparator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDir_isEmpty, "isEmpty(self, filters: QDir.Filter = QDir.Filters(QDir.AllEntries|QDir.NoDotAndDotDot)) -> bool");

extern "C" {static PyObject *meth_QDir_isEmpty(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDir_isEmpty(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDir::Filters a0def = QDir::Filters(QDir::AllEntries|QDir::NoDotAndDotDot);
        ::QDir::Filters* a0 = &a0def;
        int a0State = 0;
        const ::QDir *sipCpp;

        static const char *sipKwdList[] = {
            sipName_filters,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QDir, &sipCpp, sipType_QFlags_0100QDir_Filter, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QDir_Filter, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName_isEmpty, doc_QDir_isEmpty);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QDir___eq__(PyObject *, PyObject *);}
static PyObject *slot_QDir___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QDir *sipCpp = reinterpret_cast< ::QDir *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QDir));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QDir, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QDir, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QDir___ne__(PyObject *, PyObject *);}
static PyObject *slot_QDir___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QDir *sipCpp = reinterpret_cast< ::QDir *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QDir));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDir* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QDir, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QDir, sipSelf, sipArg);
}


extern "C" {static int slot_QDir___contains__(PyObject *, PyObject *);}
static int slot_QDir___contains__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QDir *sipCpp = reinterpret_cast< ::QDir *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QDir));

    if (!sipCpp)
        return -1;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QString, &a0, &a0State))
        {
            int sipRes = 0;

#line 149 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdir.sip"
        sipRes = bool(sipCpp->entryList().contains(*a0));
#line 1841 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName___contains__, SIP_NULLPTR);

    return -1;
}


extern "C" {static PyObject *slot_QDir___getitem__(PyObject *, PyObject *);}
static PyObject *slot_QDir___getitem__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QDir *sipCpp = reinterpret_cast< ::QDir *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QDir));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1n", &a0))
        {
            ::QString*sipRes = 0;
            int sipIsErr = 0;

#line 106 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdir.sip"
        Py_ssize_t idx = sipConvertFromSequenceIndex(a0, sipCpp->count());
        
        if (idx < 0)
            sipIsErr = 1;
        else
            sipRes = new QString(sipCpp->operator[]((qsizetype)idx));
#line 1879 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"

            if (sipIsErr)
                return 0;

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        PyObject * a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1T", &PySlice_Type, &a0))
        {
            ::QStringList*sipRes = 0;
            int sipIsErr = 0;

#line 129 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdir.sip"
        Py_ssize_t start, stop, step, slicelength;
        
        if (sipConvertFromSliceObject(a0, sipCpp->count(), &start, &stop, &step, &slicelength) < 0)
        {
            sipIsErr = 1;
        }
        else
        {
            sipRes = new QStringList();
        
            for (Py_ssize_t i = 0; i < slicelength; ++i)
            {
                (*sipRes) += (*sipCpp)[start];
                start += step;
            }
        }
#line 1913 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"

            if (sipIsErr)
                return 0;

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDir, sipName___getitem__, SIP_NULLPTR);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QDir___len__(PyObject *);}
static Py_ssize_t slot_QDir___len__(PyObject *sipSelf)
{
    ::QDir *sipCpp = reinterpret_cast< ::QDir *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QDir));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 96 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdir.sip"
        sipRes = sipCpp->count(Qt::Disambiguated);
#line 1943 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQDir.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDir(void *, int);}
static void release_QDir(void *sipCppV, int)
{
    delete reinterpret_cast< ::QDir *>(sipCppV);
}


extern "C" {static void *array_QDir(Py_ssize_t);}
static void *array_QDir(Py_ssize_t sipNrElem)
{
    return new ::QDir[sipNrElem];
}


extern "C" {static void array_delete_QDir(void *);}
static void array_delete_QDir(void *sipCpp)
{
    delete[] reinterpret_cast< ::QDir *>(sipCpp);
}


extern "C" {static void assign_QDir(void *, Py_ssize_t, void *);}
static void assign_QDir(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QDir *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QDir *>(sipSrc);
}


extern "C" {static void *copy_QDir(const void *, Py_ssize_t);}
static void *copy_QDir(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QDir(reinterpret_cast<const ::QDir *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QDir(sipSimpleWrapper *);}
static void dealloc_QDir(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDir(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QDir(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDir(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QDir *sipCpp = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QDir::SortFlags a2def = QDir::SortFlags(QDir::Name|QDir::IgnoreCase);
        ::QDir::SortFlags* a2 = &a2def;
        int a2State = 0;
        ::QDir::Filters a3def = QDir::AllEntries;
        ::QDir::Filters* a3 = &a3def;
        int a3State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_sort,
            sipName_filters,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1J1|J1J1", sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QFlags_0100QDir_SortFlag, &a2, &a2State, sipType_QFlags_0100QDir_Filter, &a3, &a3State))
        {
            sipCpp = new ::QDir(*a0, *a1, *a2, *a3);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(a2, sipType_QFlags_0100QDir_SortFlag, a2State);
            sipReleaseType(a3, sipType_QFlags_0100QDir_Filter, a3State);

            return sipCpp;
        }
    }

    {
        const ::QDir* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDir, &a0))
        {
            sipCpp = new ::QDir(*a0);

            return sipCpp;
        }
    }

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;

        static const char *sipKwdList[] = {
            sipName_path,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|J1", sipType_QString, &a0, &a0State))
        {
            sipCpp = new ::QDir(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QDir[] = {
    {(void *)slot_QDir___eq__, eq_slot},
    {(void *)slot_QDir___ne__, ne_slot},
    {(void *)slot_QDir___contains__, contains_slot},
    {(void *)slot_QDir___getitem__, getitem_slot},
    {(void *)slot_QDir___len__, len_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QDir[] = {
    {sipName_absoluteFilePath, meth_QDir_absoluteFilePath, METH_VARARGS, doc_QDir_absoluteFilePath},
    {sipName_absolutePath, meth_QDir_absolutePath, METH_VARARGS, doc_QDir_absolutePath},
    {sipName_addSearchPath, meth_QDir_addSearchPath, METH_VARARGS, doc_QDir_addSearchPath},
    {sipName_canonicalPath, meth_QDir_canonicalPath, METH_VARARGS, doc_QDir_canonicalPath},
    {sipName_cd, meth_QDir_cd, METH_VARARGS, doc_QDir_cd},
    {sipName_cdUp, meth_QDir_cdUp, METH_VARARGS, doc_QDir_cdUp},
    {sipName_cleanPath, meth_QDir_cleanPath, METH_VARARGS, doc_QDir_cleanPath},
    {sipName_count, meth_QDir_count, METH_VARARGS, doc_QDir_count},
    {sipName_current, meth_QDir_current, METH_VARARGS, doc_QDir_current},
    {sipName_currentPath, meth_QDir_currentPath, METH_VARARGS, doc_QDir_currentPath},
    {sipName_dirName, meth_QDir_dirName, METH_VARARGS, doc_QDir_dirName},
    {sipName_drives, meth_QDir_drives, METH_VARARGS, doc_QDir_drives},
    {sipName_entryInfoList, SIP_MLMETH_CAST(meth_QDir_entryInfoList), METH_VARARGS|METH_KEYWORDS, doc_QDir_entryInfoList},
    {sipName_entryList, SIP_MLMETH_CAST(meth_QDir_entryList), METH_VARARGS|METH_KEYWORDS, doc_QDir_entryList},
    {sipName_exists, meth_QDir_exists, METH_VARARGS, doc_QDir_exists},
    {sipName_filePath, meth_QDir_filePath, METH_VARARGS, doc_QDir_filePath},
    {sipName_filter, meth_QDir_filter, METH_VARARGS, doc_QDir_filter},
    {sipName_fromNativeSeparators, meth_QDir_fromNativeSeparators, METH_VARARGS, doc_QDir_fromNativeSeparators},
    {sipName_home, meth_QDir_home, METH_VARARGS, doc_QDir_home},
    {sipName_homePath, meth_QDir_homePath, METH_VARARGS, doc_QDir_homePath},
    {sipName_isAbsolute, meth_QDir_isAbsolute, METH_VARARGS, doc_QDir_isAbsolute},
    {sipName_isAbsolutePath, meth_QDir_isAbsolutePath, METH_VARARGS, doc_QDir_isAbsolutePath},
    {sipName_isEmpty, SIP_MLMETH_CAST(meth_QDir_isEmpty), METH_VARARGS|METH_KEYWORDS, doc_QDir_isEmpty},
    {sipName_isReadable, meth_QDir_isReadable, METH_VARARGS, doc_QDir_isReadable},
    {sipName_isRelative, meth_QDir_isRelative, METH_VARARGS, doc_QDir_isRelative},
    {sipName_isRelativePath, meth_QDir_isRelativePath, METH_VARARGS, doc_QDir_isRelativePath},
    {sipName_isRoot, meth_QDir_isRoot, METH_VARARGS, doc_QDir_isRoot},
    {sipName_listSeparator, meth_QDir_listSeparator, METH_VARARGS, doc_QDir_listSeparator},
    {sipName_makeAbsolute, meth_QDir_makeAbsolute, METH_VARARGS, doc_QDir_makeAbsolute},
    {sipName_match, meth_QDir_match, METH_VARARGS, doc_QDir_match},
    {sipName_mkdir, meth_QDir_mkdir, METH_VARARGS, doc_QDir_mkdir},
    {sipName_mkpath, meth_QDir_mkpath, METH_VARARGS, doc_QDir_mkpath},
    {sipName_nameFilters, meth_QDir_nameFilters, METH_VARARGS, doc_QDir_nameFilters},
    {sipName_nameFiltersFromString, meth_QDir_nameFiltersFromString, METH_VARARGS, doc_QDir_nameFiltersFromString},
    {sipName_path, meth_QDir_path, METH_VARARGS, doc_QDir_path},
    {sipName_refresh, meth_QDir_refresh, METH_VARARGS, doc_QDir_refresh},
    {sipName_relativeFilePath, meth_QDir_relativeFilePath, METH_VARARGS, doc_QDir_relativeFilePath},
    {sipName_remove, meth_QDir_remove, METH_VARARGS, doc_QDir_remove},
    {sipName_removeRecursively, meth_QDir_removeRecursively, METH_VARARGS, doc_QDir_removeRecursively},
    {sipName_rename, meth_QDir_rename, METH_VARARGS, doc_QDir_rename},
    {sipName_rmdir, meth_QDir_rmdir, METH_VARARGS, doc_QDir_rmdir},
    {sipName_rmpath, meth_QDir_rmpath, METH_VARARGS, doc_QDir_rmpath},
    {sipName_root, meth_QDir_root, METH_VARARGS, doc_QDir_root},
    {sipName_rootPath, meth_QDir_rootPath, METH_VARARGS, doc_QDir_rootPath},
    {sipName_searchPaths, meth_QDir_searchPaths, METH_VARARGS, doc_QDir_searchPaths},
    {sipName_separator, meth_QDir_separator, METH_VARARGS, doc_QDir_separator},
    {sipName_setCurrent, meth_QDir_setCurrent, METH_VARARGS, doc_QDir_setCurrent},
    {sipName_setFilter, meth_QDir_setFilter, METH_VARARGS, doc_QDir_setFilter},
    {sipName_setNameFilters, meth_QDir_setNameFilters, METH_VARARGS, doc_QDir_setNameFilters},
    {sipName_setPath, meth_QDir_setPath, METH_VARARGS, doc_QDir_setPath},
    {sipName_setSearchPaths, meth_QDir_setSearchPaths, METH_VARARGS, doc_QDir_setSearchPaths},
    {sipName_setSorting, meth_QDir_setSorting, METH_VARARGS, doc_QDir_setSorting},
    {sipName_sorting, meth_QDir_sorting, METH_VARARGS, doc_QDir_sorting},
    {sipName_swap, meth_QDir_swap, METH_VARARGS, doc_QDir_swap},
    {sipName_temp, meth_QDir_temp, METH_VARARGS, doc_QDir_temp},
    {sipName_tempPath, meth_QDir_tempPath, METH_VARARGS, doc_QDir_tempPath},
    {sipName_toNativeSeparators, meth_QDir_toNativeSeparators, METH_VARARGS, doc_QDir_toNativeSeparators}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QDir[] = {
    {sipName_Dirs, static_cast<int>(::QDir::Dirs)},
    {sipName_Files, static_cast<int>(::QDir::Files)},
    {sipName_Drives, static_cast<int>(::QDir::Drives)},
    {sipName_NoSymLinks, static_cast<int>(::QDir::NoSymLinks)},
    {sipName_AllEntries, static_cast<int>(::QDir::AllEntries)},
    {sipName_TypeMask, static_cast<int>(::QDir::TypeMask)},
    {sipName_Readable, static_cast<int>(::QDir::Readable)},
    {sipName_Writable, static_cast<int>(::QDir::Writable)},
    {sipName_Executable, static_cast<int>(::QDir::Executable)},
    {sipName_PermissionMask, static_cast<int>(::QDir::PermissionMask)},
    {sipName_Modified, static_cast<int>(::QDir::Modified)},
    {sipName_Hidden, static_cast<int>(::QDir::Hidden)},
    {sipName_System, static_cast<int>(::QDir::System)},
    {sipName_AccessMask, static_cast<int>(::QDir::AccessMask)},
    {sipName_AllDirs, static_cast<int>(::QDir::AllDirs)},
    {sipName_CaseSensitive, static_cast<int>(::QDir::CaseSensitive)},
    {sipName_NoDotAndDotDot, static_cast<int>(::QDir::NoDotAndDotDot)},
    {sipName_NoFilter, static_cast<int>(::QDir::NoFilter)},
    {sipName_NoDot, static_cast<int>(::QDir::NoDot)},
    {sipName_NoDotDot, static_cast<int>(::QDir::NoDotDot)},
    {sipName_Name, static_cast<int>(::QDir::Name)},
    {sipName_Time, static_cast<int>(::QDir::Time)},
    {sipName_Size, static_cast<int>(::QDir::Size)},
    {sipName_Unsorted, static_cast<int>(::QDir::Unsorted)},
    {sipName_SortByMask, static_cast<int>(::QDir::SortByMask)},
    {sipName_DirsFirst, static_cast<int>(::QDir::DirsFirst)},
    {sipName_Reversed, static_cast<int>(::QDir::Reversed)},
    {sipName_IgnoreCase, static_cast<int>(::QDir::IgnoreCase)},
    {sipName_DirsLast, static_cast<int>(::QDir::DirsLast)},
    {sipName_LocaleAware, static_cast<int>(::QDir::LocaleAware)},
    {sipName_Type, static_cast<int>(::QDir::Type)},
    {sipName_NoSort, static_cast<int>(::QDir::NoSort)},
    {0, 0}
};

PyDoc_STRVAR(doc_QDir, "\1QDir(path: str|None, nameFilter: str|None, sort: QDir.SortFlag = QDir.SortFlags(QDir.Name|QDir.IgnoreCase), filters: QDir.Filter = QDir.AllEntries)\n"
"QDir(a0: QDir)\n"
"QDir(path: str|None = '')");


sipClassTypeDef sipTypeDef_QtCore_QDir = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDir,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QDir,
        {0, 0, 1},
        57, methods_QDir,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QDir, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDir,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QDir,
    init_type_QDir,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDir,
    assign_QDir,
    array_QDir,
    copy_QDir,
    release_QDir,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QDir,
    sizeof (::QDir),
};
