/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothserviceinfo.sip"
#include <qbluetoothserviceinfo.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceInfo.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceInfo.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothuuid.sip"
#include <qbluetoothuuid.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceInfo.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceInfo.cpp"
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qpybluetooth_qlist.sip"
#include <qbluetoothserviceinfo.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceInfo.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceInfo.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothaddress.sip"
#include <qbluetoothaddress.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceInfo.cpp"
#line 991 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceInfo.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothdeviceinfo.sip"
#include <qbluetoothdeviceinfo.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceInfo.cpp"


PyDoc_STRVAR(doc_QBluetoothServiceInfo_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_isValid(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_isValid, doc_QBluetoothServiceInfo_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_isComplete, "isComplete(self) -> bool");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_isComplete(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_isComplete(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isComplete();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_isComplete, doc_QBluetoothServiceInfo_isComplete);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_setDevice, "setDevice(self, info: QBluetoothDeviceInfo)");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_setDevice(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_setDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothDeviceInfo* a0;
        ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, sipType_QBluetoothDeviceInfo, &a0))
        {
            sipCpp->setDevice(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_setDevice, doc_QBluetoothServiceInfo_setDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_device, "device(self) -> QBluetoothDeviceInfo");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_device(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_device(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            ::QBluetoothDeviceInfo*sipRes;

            sipRes = new ::QBluetoothDeviceInfo(sipCpp->device());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothDeviceInfo, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_device, doc_QBluetoothServiceInfo_device);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_attribute, "attribute(self, attributeId: int) -> Any");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_attribute(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_attribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint16 a0;
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bt", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, &a0))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->attribute(a0));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_attribute, doc_QBluetoothServiceInfo_attribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_attributes, "attributes(self) -> list[int]");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_attributes(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_attributes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            ::QList<unsigned short>*sipRes;

            sipRes = new ::QList<unsigned short>(sipCpp->attributes());

            return sipConvertFromNewType(sipRes, sipType_QList_1600, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_attributes, doc_QBluetoothServiceInfo_attributes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_contains, "contains(self, attributeId: int) -> bool");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_contains(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_contains(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint16 a0;
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bt", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->contains(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_contains, doc_QBluetoothServiceInfo_contains);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_removeAttribute, "removeAttribute(self, attributeId: int)");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_removeAttribute(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_removeAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint16 a0;
        ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bt", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, &a0))
        {
            sipCpp->removeAttribute(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_removeAttribute, doc_QBluetoothServiceInfo_removeAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_socketProtocol, "socketProtocol(self) -> QBluetoothServiceInfo.Protocol");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_socketProtocol(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_socketProtocol(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            ::QBluetoothServiceInfo::Protocol sipRes;

            sipRes = sipCpp->socketProtocol();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QBluetoothServiceInfo_Protocol);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_socketProtocol, doc_QBluetoothServiceInfo_socketProtocol);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_protocolServiceMultiplexer, "protocolServiceMultiplexer(self) -> int");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_protocolServiceMultiplexer(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_protocolServiceMultiplexer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->protocolServiceMultiplexer();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_protocolServiceMultiplexer, doc_QBluetoothServiceInfo_protocolServiceMultiplexer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_serverChannel, "serverChannel(self) -> int");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_serverChannel(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_serverChannel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->serverChannel();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_serverChannel, doc_QBluetoothServiceInfo_serverChannel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_protocolDescriptor, "protocolDescriptor(self, protocol: QBluetoothUuid.ProtocolUuid) -> list[Any]");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_protocolDescriptor(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_protocolDescriptor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothUuid::ProtocolUuid a0;
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, sipType_QBluetoothUuid_ProtocolUuid, &a0))
        {
            ::QBluetoothServiceInfo::Sequence*sipRes;

            sipRes = new ::QBluetoothServiceInfo::Sequence(sipCpp->protocolDescriptor(a0));

            return sipConvertFromNewType(sipRes, sipType_QBluetoothServiceInfo_Sequence, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_protocolDescriptor, doc_QBluetoothServiceInfo_protocolDescriptor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_isRegistered, "isRegistered(self) -> bool");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_isRegistered(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_isRegistered(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isRegistered();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_isRegistered, doc_QBluetoothServiceInfo_isRegistered);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_registerService, "registerService(self, localAdapter: QBluetoothAddress = QBluetoothAddress()) -> bool");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_registerService(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_registerService(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothAddress& a0def = QBluetoothAddress();
        const ::QBluetoothAddress* a0 = &a0def;
        ::QBluetoothServiceInfo *sipCpp;

        static const char *sipKwdList[] = {
            sipName_localAdapter,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, sipType_QBluetoothAddress, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->registerService(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_registerService, doc_QBluetoothServiceInfo_registerService);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_unregisterService, "unregisterService(self) -> bool");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_unregisterService(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_unregisterService(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->unregisterService();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_unregisterService, doc_QBluetoothServiceInfo_unregisterService);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_setAttribute, "setAttribute(self, attributeId: int, value: QBluetoothUuid)\n"
"setAttribute(self, attributeId: int, value: Iterable[Any])\n"
"setAttribute(self, attributeId: int, value: Any)");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_setAttribute(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_setAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint16 a0;
        const ::QBluetoothUuid* a1;
        ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BtJ9", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, &a0, sipType_QBluetoothUuid, &a1))
        {
            sipCpp->setAttribute(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::quint16 a0;
        const ::QBluetoothServiceInfo::Sequence* a1;
        int a1State = 0;
        ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BtJ1", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, &a0, sipType_QBluetoothServiceInfo_Sequence, &a1, &a1State))
        {
            sipCpp->setAttribute(a0, *a1);
            sipReleaseType(const_cast< ::QBluetoothServiceInfo::Sequence *>(a1), sipType_QBluetoothServiceInfo_Sequence, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::quint16 a0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BtJ1", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, &a0, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->setAttribute(a0, *a1);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_setAttribute, doc_QBluetoothServiceInfo_setAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_setServiceName, "setServiceName(self, name: str|None)");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_setServiceName(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_setServiceName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setServiceName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_setServiceName, doc_QBluetoothServiceInfo_setServiceName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_serviceName, "serviceName(self) -> str");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_serviceName(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_serviceName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->serviceName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_serviceName, doc_QBluetoothServiceInfo_serviceName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_setServiceDescription, "setServiceDescription(self, description: str|None)");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_setServiceDescription(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_setServiceDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setServiceDescription(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_setServiceDescription, doc_QBluetoothServiceInfo_setServiceDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_serviceDescription, "serviceDescription(self) -> str");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_serviceDescription(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_serviceDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->serviceDescription());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_serviceDescription, doc_QBluetoothServiceInfo_serviceDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_setServiceProvider, "setServiceProvider(self, provider: str|None)");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_setServiceProvider(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_setServiceProvider(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setServiceProvider(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_setServiceProvider, doc_QBluetoothServiceInfo_setServiceProvider);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_serviceProvider, "serviceProvider(self) -> str");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_serviceProvider(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_serviceProvider(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->serviceProvider());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_serviceProvider, doc_QBluetoothServiceInfo_serviceProvider);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_setServiceAvailability, "setServiceAvailability(self, availability: int)");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_setServiceAvailability(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_setServiceAvailability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint8 a0;
        ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BM", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, &a0))
        {
            sipCpp->setServiceAvailability(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_setServiceAvailability, doc_QBluetoothServiceInfo_setServiceAvailability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_serviceAvailability, "serviceAvailability(self) -> int");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_serviceAvailability(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_serviceAvailability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            ::quint8 sipRes;

            sipRes = sipCpp->serviceAvailability();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_serviceAvailability, doc_QBluetoothServiceInfo_serviceAvailability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_setServiceUuid, "setServiceUuid(self, uuid: QBluetoothUuid)");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_setServiceUuid(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_setServiceUuid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothUuid* a0;
        ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp, sipType_QBluetoothUuid, &a0))
        {
            sipCpp->setServiceUuid(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_setServiceUuid, doc_QBluetoothServiceInfo_setServiceUuid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_serviceUuid, "serviceUuid(self) -> QBluetoothUuid");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_serviceUuid(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_serviceUuid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            ::QBluetoothUuid*sipRes;

            sipRes = new ::QBluetoothUuid(sipCpp->serviceUuid());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothUuid, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_serviceUuid, doc_QBluetoothServiceInfo_serviceUuid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceInfo_serviceClassUuids, "serviceClassUuids(self) -> list[QBluetoothUuid]");

extern "C" {static PyObject *meth_QBluetoothServiceInfo_serviceClassUuids(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceInfo_serviceClassUuids(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceInfo, &sipCpp))
        {
            QList< ::QBluetoothUuid>*sipRes;

            sipRes = new QList< ::QBluetoothUuid>(sipCpp->serviceClassUuids());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QBluetoothUuid, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceInfo, sipName_serviceClassUuids, doc_QBluetoothServiceInfo_serviceClassUuids);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QBluetoothServiceInfo(void *, int);}
static void release_QBluetoothServiceInfo(void *sipCppV, int)
{
    delete reinterpret_cast< ::QBluetoothServiceInfo *>(sipCppV);
}


extern "C" {static void *array_QBluetoothServiceInfo(Py_ssize_t);}
static void *array_QBluetoothServiceInfo(Py_ssize_t sipNrElem)
{
    return new ::QBluetoothServiceInfo[sipNrElem];
}


extern "C" {static void array_delete_QBluetoothServiceInfo(void *);}
static void array_delete_QBluetoothServiceInfo(void *sipCpp)
{
    delete[] reinterpret_cast< ::QBluetoothServiceInfo *>(sipCpp);
}


extern "C" {static void assign_QBluetoothServiceInfo(void *, Py_ssize_t, void *);}
static void assign_QBluetoothServiceInfo(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QBluetoothServiceInfo *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QBluetoothServiceInfo *>(sipSrc);
}


extern "C" {static void *copy_QBluetoothServiceInfo(const void *, Py_ssize_t);}
static void *copy_QBluetoothServiceInfo(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QBluetoothServiceInfo(reinterpret_cast<const ::QBluetoothServiceInfo *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QBluetoothServiceInfo(sipSimpleWrapper *);}
static void dealloc_QBluetoothServiceInfo(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QBluetoothServiceInfo(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QBluetoothServiceInfo(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QBluetoothServiceInfo(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QBluetoothServiceInfo *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QBluetoothServiceInfo();

            return sipCpp;
        }
    }

    {
        const ::QBluetoothServiceInfo* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QBluetoothServiceInfo, &a0))
        {
            sipCpp = new ::QBluetoothServiceInfo(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QBluetoothServiceInfo[] = {
    {sipName_attribute, meth_QBluetoothServiceInfo_attribute, METH_VARARGS, doc_QBluetoothServiceInfo_attribute},
    {sipName_attributes, meth_QBluetoothServiceInfo_attributes, METH_VARARGS, doc_QBluetoothServiceInfo_attributes},
    {sipName_contains, meth_QBluetoothServiceInfo_contains, METH_VARARGS, doc_QBluetoothServiceInfo_contains},
    {sipName_device, meth_QBluetoothServiceInfo_device, METH_VARARGS, doc_QBluetoothServiceInfo_device},
    {sipName_isComplete, meth_QBluetoothServiceInfo_isComplete, METH_VARARGS, doc_QBluetoothServiceInfo_isComplete},
    {sipName_isRegistered, meth_QBluetoothServiceInfo_isRegistered, METH_VARARGS, doc_QBluetoothServiceInfo_isRegistered},
    {sipName_isValid, meth_QBluetoothServiceInfo_isValid, METH_VARARGS, doc_QBluetoothServiceInfo_isValid},
    {sipName_protocolDescriptor, meth_QBluetoothServiceInfo_protocolDescriptor, METH_VARARGS, doc_QBluetoothServiceInfo_protocolDescriptor},
    {sipName_protocolServiceMultiplexer, meth_QBluetoothServiceInfo_protocolServiceMultiplexer, METH_VARARGS, doc_QBluetoothServiceInfo_protocolServiceMultiplexer},
    {sipName_registerService, SIP_MLMETH_CAST(meth_QBluetoothServiceInfo_registerService), METH_VARARGS|METH_KEYWORDS, doc_QBluetoothServiceInfo_registerService},
    {sipName_removeAttribute, meth_QBluetoothServiceInfo_removeAttribute, METH_VARARGS, doc_QBluetoothServiceInfo_removeAttribute},
    {sipName_serverChannel, meth_QBluetoothServiceInfo_serverChannel, METH_VARARGS, doc_QBluetoothServiceInfo_serverChannel},
    {sipName_serviceAvailability, meth_QBluetoothServiceInfo_serviceAvailability, METH_VARARGS, doc_QBluetoothServiceInfo_serviceAvailability},
    {sipName_serviceClassUuids, meth_QBluetoothServiceInfo_serviceClassUuids, METH_VARARGS, doc_QBluetoothServiceInfo_serviceClassUuids},
    {sipName_serviceDescription, meth_QBluetoothServiceInfo_serviceDescription, METH_VARARGS, doc_QBluetoothServiceInfo_serviceDescription},
    {sipName_serviceName, meth_QBluetoothServiceInfo_serviceName, METH_VARARGS, doc_QBluetoothServiceInfo_serviceName},
    {sipName_serviceProvider, meth_QBluetoothServiceInfo_serviceProvider, METH_VARARGS, doc_QBluetoothServiceInfo_serviceProvider},
    {sipName_serviceUuid, meth_QBluetoothServiceInfo_serviceUuid, METH_VARARGS, doc_QBluetoothServiceInfo_serviceUuid},
    {sipName_setAttribute, meth_QBluetoothServiceInfo_setAttribute, METH_VARARGS, doc_QBluetoothServiceInfo_setAttribute},
    {sipName_setDevice, meth_QBluetoothServiceInfo_setDevice, METH_VARARGS, doc_QBluetoothServiceInfo_setDevice},
    {sipName_setServiceAvailability, meth_QBluetoothServiceInfo_setServiceAvailability, METH_VARARGS, doc_QBluetoothServiceInfo_setServiceAvailability},
    {sipName_setServiceDescription, meth_QBluetoothServiceInfo_setServiceDescription, METH_VARARGS, doc_QBluetoothServiceInfo_setServiceDescription},
    {sipName_setServiceName, meth_QBluetoothServiceInfo_setServiceName, METH_VARARGS, doc_QBluetoothServiceInfo_setServiceName},
    {sipName_setServiceProvider, meth_QBluetoothServiceInfo_setServiceProvider, METH_VARARGS, doc_QBluetoothServiceInfo_setServiceProvider},
    {sipName_setServiceUuid, meth_QBluetoothServiceInfo_setServiceUuid, METH_VARARGS, doc_QBluetoothServiceInfo_setServiceUuid},
    {sipName_socketProtocol, meth_QBluetoothServiceInfo_socketProtocol, METH_VARARGS, doc_QBluetoothServiceInfo_socketProtocol},
    {sipName_unregisterService, meth_QBluetoothServiceInfo_unregisterService, METH_VARARGS, doc_QBluetoothServiceInfo_unregisterService}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QBluetoothServiceInfo[] = {
    {sipName_ServiceRecordHandle, static_cast<int>(::QBluetoothServiceInfo::ServiceRecordHandle)},
    {sipName_ServiceClassIds, static_cast<int>(::QBluetoothServiceInfo::ServiceClassIds)},
    {sipName_ServiceRecordState, static_cast<int>(::QBluetoothServiceInfo::ServiceRecordState)},
    {sipName_ServiceId, static_cast<int>(::QBluetoothServiceInfo::ServiceId)},
    {sipName_ProtocolDescriptorList, static_cast<int>(::QBluetoothServiceInfo::ProtocolDescriptorList)},
    {sipName_BrowseGroupList, static_cast<int>(::QBluetoothServiceInfo::BrowseGroupList)},
    {sipName_LanguageBaseAttributeIdList, static_cast<int>(::QBluetoothServiceInfo::LanguageBaseAttributeIdList)},
    {sipName_ServiceInfoTimeToLive, static_cast<int>(::QBluetoothServiceInfo::ServiceInfoTimeToLive)},
    {sipName_ServiceAvailability, static_cast<int>(::QBluetoothServiceInfo::ServiceAvailability)},
    {sipName_BluetoothProfileDescriptorList, static_cast<int>(::QBluetoothServiceInfo::BluetoothProfileDescriptorList)},
    {sipName_DocumentationUrl, static_cast<int>(::QBluetoothServiceInfo::DocumentationUrl)},
    {sipName_ClientExecutableUrl, static_cast<int>(::QBluetoothServiceInfo::ClientExecutableUrl)},
    {sipName_IconUrl, static_cast<int>(::QBluetoothServiceInfo::IconUrl)},
    {sipName_AdditionalProtocolDescriptorList, static_cast<int>(::QBluetoothServiceInfo::AdditionalProtocolDescriptorList)},
    {sipName_PrimaryLanguageBase, static_cast<int>(::QBluetoothServiceInfo::PrimaryLanguageBase)},
    {sipName_ServiceName, static_cast<int>(::QBluetoothServiceInfo::ServiceName)},
    {sipName_ServiceDescription, static_cast<int>(::QBluetoothServiceInfo::ServiceDescription)},
    {sipName_ServiceProvider, static_cast<int>(::QBluetoothServiceInfo::ServiceProvider)},
    {sipName_UnknownProtocol, static_cast<int>(::QBluetoothServiceInfo::UnknownProtocol)},
    {sipName_L2capProtocol, static_cast<int>(::QBluetoothServiceInfo::L2capProtocol)},
    {sipName_RfcommProtocol, static_cast<int>(::QBluetoothServiceInfo::RfcommProtocol)},
    {0, 0}
};

PyDoc_STRVAR(doc_QBluetoothServiceInfo, "\1QBluetoothServiceInfo()\n"
"QBluetoothServiceInfo(other: QBluetoothServiceInfo)");


sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothServiceInfo = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QBluetoothServiceInfo,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QBluetoothServiceInfo,
        {0, 0, 1},
        27, methods_QBluetoothServiceInfo,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QBluetoothServiceInfo, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QBluetoothServiceInfo,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QBluetoothServiceInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QBluetoothServiceInfo,
    assign_QBluetoothServiceInfo,
    array_QBluetoothServiceInfo,
    copy_QBluetoothServiceInfo,
    release_QBluetoothServiceInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QBluetoothServiceInfo,
    sizeof (::QBluetoothServiceInfo),
};
