/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qsgtextnode.sip"
#include <qsgtextnode.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGTextNode.cpp"

#line 170 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGTextNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qsgtexture.sip"
#include <qsgtexture.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGTextNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGTextNode.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGTextNode.cpp"
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextlayout.sip"
#include <qtextlayout.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGTextNode.cpp"
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextdocument.sip"
#include <qtextdocument.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGTextNode.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qmatrix4x4.sip"
#include <qmatrix4x4.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGTextNode.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGTextNode.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGTextNode.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGTextNode.cpp"


PyDoc_STRVAR(doc_QSGTextNode_addTextDocument, "addTextDocument(self, position: QPointF, document: QTextDocument|None, selectionStart: int = -1, selectionCount: int = -1)");

extern "C" {static PyObject *meth_QSGTextNode_addTextDocument(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_addTextDocument(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPointF* a0;
        ::QTextDocument* a1;
        int a2 = -1;
        int a3 = -1;
        ::QSGTextNode *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_selectionStart,
            sipName_selectionCount,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9J8|ii", &sipSelf, sipType_QSGTextNode, &sipCpp, sipType_QPointF, &a0, sipType_QTextDocument, &a1, &a2, &a3))
        {
            sipCpp->addTextDocument(*a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_addTextDocument, doc_QSGTextNode_addTextDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_addTextLayout, "addTextLayout(self, position: QPointF, layout: QTextLayout|None, selectionStart: int = -1, selectionCount: int = -1, lineStart: int = 0, lineCount: int = -1)");

extern "C" {static PyObject *meth_QSGTextNode_addTextLayout(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_addTextLayout(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPointF* a0;
        ::QTextLayout* a1;
        int a2 = -1;
        int a3 = -1;
        int a4 = 0;
        int a5 = -1;
        ::QSGTextNode *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_selectionStart,
            sipName_selectionCount,
            sipName_lineStart,
            sipName_lineCount,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9J8|iiii", &sipSelf, sipType_QSGTextNode, &sipCpp, sipType_QPointF, &a0, sipType_QTextLayout, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->addTextLayout(*a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_addTextLayout, doc_QSGTextNode_addTextLayout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_setColor, "setColor(self, color: QColor|Qt.GlobalColor|int)");

extern "C" {static PyObject *meth_QSGTextNode_setColor(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_setColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSGTextNode, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_setColor);
                return SIP_NULLPTR;
            }

            sipCpp->setColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_setColor, doc_QSGTextNode_setColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_color, "color(self) -> QColor");

extern "C" {static PyObject *meth_QSGTextNode_color(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_color(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTextNode, &sipCpp))
        {
            ::QColor*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_color);
                return SIP_NULLPTR;
            }

            sipRes = new ::QColor(sipCpp->color());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_color, doc_QSGTextNode_color);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_setTextStyle, "setTextStyle(self, textStyle: QSGTextNode.TextStyle)");

extern "C" {static PyObject *meth_QSGTextNode_setTextStyle(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_setTextStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QSGTextNode::TextStyle a0;
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGTextNode, &sipCpp, sipType_QSGTextNode_TextStyle, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_setTextStyle);
                return SIP_NULLPTR;
            }

            sipCpp->setTextStyle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_setTextStyle, doc_QSGTextNode_setTextStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_textStyle, "textStyle(self) -> QSGTextNode.TextStyle");

extern "C" {static PyObject *meth_QSGTextNode_textStyle(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_textStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTextNode, &sipCpp))
        {
            ::QSGTextNode::TextStyle sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_textStyle);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->textStyle();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTextNode_TextStyle);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_textStyle, doc_QSGTextNode_textStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_setStyleColor, "setStyleColor(self, styleColor: QColor|Qt.GlobalColor|int)");

extern "C" {static PyObject *meth_QSGTextNode_setStyleColor(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_setStyleColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSGTextNode, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_setStyleColor);
                return SIP_NULLPTR;
            }

            sipCpp->setStyleColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_setStyleColor, doc_QSGTextNode_setStyleColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_styleColor, "styleColor(self) -> QColor");

extern "C" {static PyObject *meth_QSGTextNode_styleColor(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_styleColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTextNode, &sipCpp))
        {
            ::QColor*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_styleColor);
                return SIP_NULLPTR;
            }

            sipRes = new ::QColor(sipCpp->styleColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_styleColor, doc_QSGTextNode_styleColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_setLinkColor, "setLinkColor(self, linkColor: QColor|Qt.GlobalColor|int)");

extern "C" {static PyObject *meth_QSGTextNode_setLinkColor(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_setLinkColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSGTextNode, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_setLinkColor);
                return SIP_NULLPTR;
            }

            sipCpp->setLinkColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_setLinkColor, doc_QSGTextNode_setLinkColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_linkColor, "linkColor(self) -> QColor");

extern "C" {static PyObject *meth_QSGTextNode_linkColor(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_linkColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTextNode, &sipCpp))
        {
            ::QColor*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_linkColor);
                return SIP_NULLPTR;
            }

            sipRes = new ::QColor(sipCpp->linkColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_linkColor, doc_QSGTextNode_linkColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_setSelectionColor, "setSelectionColor(self, selectionColor: QColor|Qt.GlobalColor|int)");

extern "C" {static PyObject *meth_QSGTextNode_setSelectionColor(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_setSelectionColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSGTextNode, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_setSelectionColor);
                return SIP_NULLPTR;
            }

            sipCpp->setSelectionColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_setSelectionColor, doc_QSGTextNode_setSelectionColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_selectionColor, "selectionColor(self) -> QColor");

extern "C" {static PyObject *meth_QSGTextNode_selectionColor(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_selectionColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTextNode, &sipCpp))
        {
            ::QColor*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_selectionColor);
                return SIP_NULLPTR;
            }

            sipRes = new ::QColor(sipCpp->selectionColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_selectionColor, doc_QSGTextNode_selectionColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_setSelectionTextColor, "setSelectionTextColor(self, selectionTextColor: QColor|Qt.GlobalColor|int)");

extern "C" {static PyObject *meth_QSGTextNode_setSelectionTextColor(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_setSelectionTextColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSGTextNode, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_setSelectionTextColor);
                return SIP_NULLPTR;
            }

            sipCpp->setSelectionTextColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_setSelectionTextColor, doc_QSGTextNode_setSelectionTextColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_selectionTextColor, "selectionTextColor(self) -> QColor");

extern "C" {static PyObject *meth_QSGTextNode_selectionTextColor(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_selectionTextColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTextNode, &sipCpp))
        {
            ::QColor*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_selectionTextColor);
                return SIP_NULLPTR;
            }

            sipRes = new ::QColor(sipCpp->selectionTextColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_selectionTextColor, doc_QSGTextNode_selectionTextColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_setRenderType, "setRenderType(self, renderType: QSGTextNode.RenderType)");

extern "C" {static PyObject *meth_QSGTextNode_setRenderType(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_setRenderType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QSGTextNode::RenderType a0;
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGTextNode, &sipCpp, sipType_QSGTextNode_RenderType, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_setRenderType);
                return SIP_NULLPTR;
            }

            sipCpp->setRenderType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_setRenderType, doc_QSGTextNode_setRenderType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_renderType, "renderType(self) -> QSGTextNode.RenderType");

extern "C" {static PyObject *meth_QSGTextNode_renderType(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_renderType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTextNode, &sipCpp))
        {
            ::QSGTextNode::RenderType sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_renderType);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->renderType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTextNode_RenderType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_renderType, doc_QSGTextNode_renderType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_setRenderTypeQuality, "setRenderTypeQuality(self, renderTypeQuality: int)");

extern "C" {static PyObject *meth_QSGTextNode_setRenderTypeQuality(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_setRenderTypeQuality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSGTextNode, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_setRenderTypeQuality);
                return SIP_NULLPTR;
            }

            sipCpp->setRenderTypeQuality(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_setRenderTypeQuality, doc_QSGTextNode_setRenderTypeQuality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_renderTypeQuality, "renderTypeQuality(self) -> int");

extern "C" {static PyObject *meth_QSGTextNode_renderTypeQuality(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_renderTypeQuality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTextNode, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_renderTypeQuality);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->renderTypeQuality();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_renderTypeQuality, doc_QSGTextNode_renderTypeQuality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_setFiltering, "setFiltering(self, a0: QSGTexture.Filtering)");

extern "C" {static PyObject *meth_QSGTextNode_setFiltering(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_setFiltering(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QSGTexture::Filtering a0;
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGTextNode, &sipCpp, sipType_QSGTexture_Filtering, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_setFiltering);
                return SIP_NULLPTR;
            }

            sipCpp->setFiltering(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_setFiltering, doc_QSGTextNode_setFiltering);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_filtering, "filtering(self) -> QSGTexture.Filtering");

extern "C" {static PyObject *meth_QSGTextNode_filtering(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_filtering(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTextNode, &sipCpp))
        {
            ::QSGTexture::Filtering sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_filtering);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->filtering();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTexture_Filtering);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_filtering, doc_QSGTextNode_filtering);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_clear, "clear(self)");

extern "C" {static PyObject *meth_QSGTextNode_clear(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTextNode, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_clear);
                return SIP_NULLPTR;
            }

            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_clear, doc_QSGTextNode_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_setViewport, "setViewport(self, viewport: QRectF)");

extern "C" {static PyObject *meth_QSGTextNode_setViewport(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_setViewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRectF* a0;
        ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSGTextNode, &sipCpp, sipType_QRectF, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_setViewport);
                return SIP_NULLPTR;
            }

            sipCpp->setViewport(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_setViewport, doc_QSGTextNode_setViewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTextNode_viewport, "viewport(self) -> QRectF");

extern "C" {static PyObject *meth_QSGTextNode_viewport(PyObject *, PyObject *);}
static PyObject *meth_QSGTextNode_viewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QSGTextNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTextNode, &sipCpp))
        {
            ::QRectF*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTextNode, sipName_viewport);
                return SIP_NULLPTR;
            }

            sipRes = new ::QRectF(sipCpp->viewport());

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTextNode, sipName_viewport, doc_QSGTextNode_viewport);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSGTextNode(void *, const sipTypeDef *);}
static void *cast_QSGTextNode(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSGTextNode *sipCpp = reinterpret_cast< ::QSGTextNode *>(sipCppV);

    if (targetType == sipType_QSGTextNode)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QSGTransformNode)->ctd_cast(static_cast< ::QSGTransformNode *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSGTextNode(void *, int);}
static void release_QSGTextNode(void *sipCppV, int)
{
    delete reinterpret_cast< ::QSGTextNode *>(sipCppV);
}


extern "C" {static void dealloc_QSGTextNode(sipSimpleWrapper *);}
static void dealloc_QSGTextNode(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGTextNode(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSGTextNode[] = {{113, 255, 1}};


static PyMethodDef methods_QSGTextNode[] = {
    {sipName_addTextDocument, SIP_MLMETH_CAST(meth_QSGTextNode_addTextDocument), METH_VARARGS|METH_KEYWORDS, doc_QSGTextNode_addTextDocument},
    {sipName_addTextLayout, SIP_MLMETH_CAST(meth_QSGTextNode_addTextLayout), METH_VARARGS|METH_KEYWORDS, doc_QSGTextNode_addTextLayout},
    {sipName_clear, meth_QSGTextNode_clear, METH_VARARGS, doc_QSGTextNode_clear},
    {sipName_color, meth_QSGTextNode_color, METH_VARARGS, doc_QSGTextNode_color},
    {sipName_filtering, meth_QSGTextNode_filtering, METH_VARARGS, doc_QSGTextNode_filtering},
    {sipName_linkColor, meth_QSGTextNode_linkColor, METH_VARARGS, doc_QSGTextNode_linkColor},
    {sipName_renderType, meth_QSGTextNode_renderType, METH_VARARGS, doc_QSGTextNode_renderType},
    {sipName_renderTypeQuality, meth_QSGTextNode_renderTypeQuality, METH_VARARGS, doc_QSGTextNode_renderTypeQuality},
    {sipName_selectionColor, meth_QSGTextNode_selectionColor, METH_VARARGS, doc_QSGTextNode_selectionColor},
    {sipName_selectionTextColor, meth_QSGTextNode_selectionTextColor, METH_VARARGS, doc_QSGTextNode_selectionTextColor},
    {sipName_setColor, meth_QSGTextNode_setColor, METH_VARARGS, doc_QSGTextNode_setColor},
    {sipName_setFiltering, meth_QSGTextNode_setFiltering, METH_VARARGS, doc_QSGTextNode_setFiltering},
    {sipName_setLinkColor, meth_QSGTextNode_setLinkColor, METH_VARARGS, doc_QSGTextNode_setLinkColor},
    {sipName_setRenderType, meth_QSGTextNode_setRenderType, METH_VARARGS, doc_QSGTextNode_setRenderType},
    {sipName_setRenderTypeQuality, meth_QSGTextNode_setRenderTypeQuality, METH_VARARGS, doc_QSGTextNode_setRenderTypeQuality},
    {sipName_setSelectionColor, meth_QSGTextNode_setSelectionColor, METH_VARARGS, doc_QSGTextNode_setSelectionColor},
    {sipName_setSelectionTextColor, meth_QSGTextNode_setSelectionTextColor, METH_VARARGS, doc_QSGTextNode_setSelectionTextColor},
    {sipName_setStyleColor, meth_QSGTextNode_setStyleColor, METH_VARARGS, doc_QSGTextNode_setStyleColor},
    {sipName_setTextStyle, meth_QSGTextNode_setTextStyle, METH_VARARGS, doc_QSGTextNode_setTextStyle},
    {sipName_setViewport, meth_QSGTextNode_setViewport, METH_VARARGS, doc_QSGTextNode_setViewport},
    {sipName_styleColor, meth_QSGTextNode_styleColor, METH_VARARGS, doc_QSGTextNode_styleColor},
    {sipName_textStyle, meth_QSGTextNode_textStyle, METH_VARARGS, doc_QSGTextNode_textStyle},
    {sipName_viewport, meth_QSGTextNode_viewport, METH_VARARGS, doc_QSGTextNode_viewport}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QSGTextNode[] = {
    {sipName_QtRendering, static_cast<int>(::QSGTextNode::QtRendering)},
    {sipName_NativeRendering, static_cast<int>(::QSGTextNode::NativeRendering)},
    {sipName_CurveRendering, static_cast<int>(::QSGTextNode::CurveRendering)},
    {sipName_Normal, static_cast<int>(::QSGTextNode::Normal)},
    {sipName_Outline, static_cast<int>(::QSGTextNode::Outline)},
    {sipName_Raised, static_cast<int>(::QSGTextNode::Raised)},
    {sipName_Sunken, static_cast<int>(::QSGTextNode::Sunken)},
    {0, 0}
};


sipClassTypeDef sipTypeDef_QtQuick_QSGTextNode = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGTextNode,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QSGTextNode,
        {0, 0, 1},
        23, methods_QSGTextNode,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QSGTextNode, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QSGTextNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSGTextNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QSGTextNode,
    cast_QSGTextNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
