/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtHelp.h"

#line 49 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpindexwidget.sip"
#include <qhelpindexwidget.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelplink.sip"
#include <qhelplink.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 612 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 126 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractitemview.sip"
#include <qabstractitemview.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 789 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlistview.sip"
#include <qlistview.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractitemdelegate.sip"
#include <qabstractitemdelegate.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractscrollarea.sip"
#include <qabstractscrollarea.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qscrollbar.sip"
#include <qscrollbar.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qframe.sip"
#include <qframe.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 215 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 221 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 224 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 227 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 230 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 233 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 236 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 242 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 245 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 248 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 251 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 257 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 260 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 263 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 266 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 272 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 275 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 278 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 281 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 284 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 287 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 292 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 295 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 298 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 301 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 304 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 307 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 310 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 313 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 316 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 319 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpIndexWidget.cpp"


PyDoc_STRVAR(doc_QHelpIndexWidget_filterIndices, "filterIndices(self, filter: str|None, wildcard: str|None = '')");

extern "C" {static PyObject *meth_QHelpIndexWidget_filterIndices(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QHelpIndexWidget_filterIndices(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        ::QHelpIndexWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_wildcard,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QHelpIndexWidget, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            sipCpp->filterIndices(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpIndexWidget, sipName_filterIndices, doc_QHelpIndexWidget_filterIndices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpIndexWidget_activateCurrentItem, "activateCurrentItem(self)");

extern "C" {static PyObject *meth_QHelpIndexWidget_activateCurrentItem(PyObject *, PyObject *);}
static PyObject *meth_QHelpIndexWidget_activateCurrentItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpIndexWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpIndexWidget, &sipCpp))
        {
            sipCpp->activateCurrentItem();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpIndexWidget, sipName_activateCurrentItem, doc_QHelpIndexWidget_activateCurrentItem);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QHelpIndexWidget(void *, const sipTypeDef *);}
static void *cast_QHelpIndexWidget(void *sipCppV, const sipTypeDef *targetType)
{
    ::QHelpIndexWidget *sipCpp = reinterpret_cast< ::QHelpIndexWidget *>(sipCppV);

    if (targetType == sipType_QHelpIndexWidget)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QListView)->ctd_cast(static_cast< ::QListView *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHelpIndexWidget(void *, int);}
static void release_QHelpIndexWidget(void *sipCppV, int)
{
    ::QHelpIndexWidget *sipCpp = reinterpret_cast< ::QHelpIndexWidget *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QHelpIndexWidget(sipSimpleWrapper *);}
static void dealloc_QHelpIndexWidget(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHelpIndexWidget(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QHelpIndexWidget[] = {{8, 2, 1}};


static PyMethodDef methods_QHelpIndexWidget[] = {
    {sipName_activateCurrentItem, meth_QHelpIndexWidget_activateCurrentItem, METH_VARARGS, doc_QHelpIndexWidget_activateCurrentItem},
    {sipName_filterIndices, SIP_MLMETH_CAST(meth_QHelpIndexWidget_filterIndices), METH_VARARGS|METH_KEYWORDS, doc_QHelpIndexWidget_filterIndices}
};


/* Define this type's signals. */
static const pyqt6QtSignal signals_QHelpIndexWidget[] = {
    {"documentsActivated(QList<QHelpLink>,QString)", "\1documentsActivated(self, documents: Iterable[QHelpLink], keyword: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"documentActivated(QHelpLink,QString)", "\1documentActivated(self, document: QHelpLink, keyword: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QHelpIndexWidget = {
    &::QHelpIndexWidget::staticMetaObject,
    signals_QHelpIndexWidget,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtHelp_QHelpIndexWidget = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHelpIndexWidget,
        SIP_NULLPTR,
        &plugin_QHelpIndexWidget,
    },
    {
        sipNameNr_QHelpIndexWidget,
        {0, 0, 1},
        2, methods_QHelpIndexWidget,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QHelpIndexWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHelpIndexWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QHelpIndexWidget,
    cast_QHelpIndexWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
