/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNfc.h"

#line 44 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefnfcsmartposterrecord.sip"
#include <qndefnfcsmartposterrecord.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcSmartPosterRecord.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefrecord.sip"
#include <qndefrecord.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcSmartPosterRecord.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcSmartPosterRecord.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcSmartPosterRecord.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefnfcsmartposterrecord.sip"
#include <qndefnfcsmartposterrecord.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcSmartPosterRecord.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcSmartPosterRecord.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefnfcurirecord.sip"
#include <qndefnfcurirecord.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcSmartPosterRecord.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcSmartPosterRecord.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcSmartPosterRecord.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefnfctextrecord.sip"
#include <qndefnfctextrecord.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcSmartPosterRecord.cpp"


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_setPayload, "setPayload(self, payload: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_setPayload(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_setPayload(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setPayload(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_setPayload, doc_QNdefNfcSmartPosterRecord_setPayload);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_hasTitle, "hasTitle(self, locale: str|None = '') -> bool");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_hasTitle(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_hasTitle(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        static const char *sipKwdList[] = {
            sipName_locale,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->hasTitle(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_hasTitle, doc_QNdefNfcSmartPosterRecord_hasTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_hasAction, "hasAction(self) -> bool");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_hasAction(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_hasAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasAction();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_hasAction, doc_QNdefNfcSmartPosterRecord_hasAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_hasIcon, "hasIcon(self, mimetype: QByteArray|bytes|bytearray|memoryview = QByteArray()) -> bool");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_hasIcon(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_hasIcon(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray& a0def = QByteArray();
        const ::QByteArray* a0 = &a0def;
        int a0State = 0;
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        static const char *sipKwdList[] = {
            sipName_mimetype,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->hasIcon(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_hasIcon, doc_QNdefNfcSmartPosterRecord_hasIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_hasSize, "hasSize(self) -> bool");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_hasSize(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_hasSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasSize();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_hasSize, doc_QNdefNfcSmartPosterRecord_hasSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_hasTypeInfo, "hasTypeInfo(self) -> bool");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_hasTypeInfo(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_hasTypeInfo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasTypeInfo();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_hasTypeInfo, doc_QNdefNfcSmartPosterRecord_hasTypeInfo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_titleCount, "titleCount(self) -> int");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_titleCount(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_titleCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            ::qsizetype sipRes;

            sipRes = sipCpp->titleCount();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_titleCount, doc_QNdefNfcSmartPosterRecord_titleCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_title, "title(self, locale: str|None = '') -> str");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_title(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_title(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        static const char *sipKwdList[] = {
            sipName_locale,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_title, doc_QNdefNfcSmartPosterRecord_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_titleRecord, "titleRecord(self, index: int) -> QNdefNfcTextRecord");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_titleRecord(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_titleRecord(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, &a0))
        {
            ::QNdefNfcTextRecord*sipRes;

            sipRes = new ::QNdefNfcTextRecord(sipCpp->titleRecord(a0));

            return sipConvertFromNewType(sipRes, sipType_QNdefNfcTextRecord, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_titleRecord, doc_QNdefNfcSmartPosterRecord_titleRecord);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_titleRecords, "titleRecords(self) -> list[QNdefNfcTextRecord]");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_titleRecords(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_titleRecords(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            QList< ::QNdefNfcTextRecord>*sipRes;

            sipRes = new QList< ::QNdefNfcTextRecord>(sipCpp->titleRecords());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QNdefNfcTextRecord, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_titleRecords, doc_QNdefNfcSmartPosterRecord_titleRecords);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_addTitle, "addTitle(self, text: QNdefNfcTextRecord) -> bool\n"
"addTitle(self, text: str|None, locale: str|None, encoding: QNdefNfcTextRecord.Encoding) -> bool");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_addTitle(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_addTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcTextRecord* a0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QNdefNfcTextRecord, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->addTitle(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QNdefNfcTextRecord::Encoding a2;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1E", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QNdefNfcTextRecord_Encoding, &a2))
        {
            bool sipRes;

            sipRes = sipCpp->addTitle(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_addTitle, doc_QNdefNfcSmartPosterRecord_addTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_removeTitle, "removeTitle(self, text: QNdefNfcTextRecord) -> bool\n"
"removeTitle(self, locale: str|None) -> bool");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_removeTitle(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_removeTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcTextRecord* a0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QNdefNfcTextRecord, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->removeTitle(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->removeTitle(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_removeTitle, doc_QNdefNfcSmartPosterRecord_removeTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_setTitles, "setTitles(self, titles: Iterable[QNdefNfcTextRecord])");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_setTitles(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_setTitles(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QNdefNfcTextRecord>* a0;
        int a0State = 0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QList_0100QNdefNfcTextRecord, &a0, &a0State))
        {
            sipCpp->setTitles(*a0);
            sipReleaseType(const_cast<QList< ::QNdefNfcTextRecord> *>(a0), sipType_QList_0100QNdefNfcTextRecord, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_setTitles, doc_QNdefNfcSmartPosterRecord_setTitles);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_uri, "uri(self) -> QUrl");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_uri(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_uri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->uri());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_uri, doc_QNdefNfcSmartPosterRecord_uri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_uriRecord, "uriRecord(self) -> QNdefNfcUriRecord");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_uriRecord(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_uriRecord(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            ::QNdefNfcUriRecord*sipRes;

            sipRes = new ::QNdefNfcUriRecord(sipCpp->uriRecord());

            return sipConvertFromNewType(sipRes, sipType_QNdefNfcUriRecord, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_uriRecord, doc_QNdefNfcSmartPosterRecord_uriRecord);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_setUri, "setUri(self, url: QNdefNfcUriRecord)\n"
"setUri(self, url: QUrl)");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_setUri(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_setUri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcUriRecord* a0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QNdefNfcUriRecord, &a0))
        {
            sipCpp->setUri(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QUrl* a0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setUri(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_setUri, doc_QNdefNfcSmartPosterRecord_setUri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_action, "action(self) -> QNdefNfcSmartPosterRecord.Action");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_action(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_action(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            ::QNdefNfcSmartPosterRecord::Action sipRes;

            sipRes = sipCpp->action();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QNdefNfcSmartPosterRecord_Action);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_action, doc_QNdefNfcSmartPosterRecord_action);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_setAction, "setAction(self, act: QNdefNfcSmartPosterRecord.Action)");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_setAction(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_setAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNdefNfcSmartPosterRecord::Action a0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QNdefNfcSmartPosterRecord_Action, &a0))
        {
            sipCpp->setAction(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_setAction, doc_QNdefNfcSmartPosterRecord_setAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_iconCount, "iconCount(self) -> int");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_iconCount(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_iconCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            ::qsizetype sipRes;

            sipRes = sipCpp->iconCount();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_iconCount, doc_QNdefNfcSmartPosterRecord_iconCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_icon, "icon(self, mimetype: QByteArray|bytes|bytearray|memoryview = QByteArray()) -> QByteArray");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_icon(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_icon(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray& a0def = QByteArray();
        const ::QByteArray* a0 = &a0def;
        int a0State = 0;
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        static const char *sipKwdList[] = {
            sipName_mimetype,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->icon(*a0));
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_icon, doc_QNdefNfcSmartPosterRecord_icon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_iconRecord, "iconRecord(self, index: int) -> QNdefNfcIconRecord");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_iconRecord(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_iconRecord(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, &a0))
        {
            ::QNdefNfcIconRecord*sipRes;

            sipRes = new ::QNdefNfcIconRecord(sipCpp->iconRecord(a0));

            return sipConvertFromNewType(sipRes, sipType_QNdefNfcIconRecord, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_iconRecord, doc_QNdefNfcSmartPosterRecord_iconRecord);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_iconRecords, "iconRecords(self) -> list[QNdefNfcIconRecord]");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_iconRecords(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_iconRecords(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            QList< ::QNdefNfcIconRecord>*sipRes;

            sipRes = new QList< ::QNdefNfcIconRecord>(sipCpp->iconRecords());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QNdefNfcIconRecord, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_iconRecords, doc_QNdefNfcSmartPosterRecord_iconRecords);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_addIcon, "addIcon(self, icon: QNdefNfcIconRecord)\n"
"addIcon(self, type: QByteArray|bytes|bytearray|memoryview, data: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_addIcon(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_addIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcIconRecord* a0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QNdefNfcIconRecord, &a0))
        {
            sipCpp->addIcon(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QByteArray* a0;
        int a0State = 0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QByteArray, &a0, &a0State, sipType_QByteArray, &a1, &a1State))
        {
            sipCpp->addIcon(*a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_addIcon, doc_QNdefNfcSmartPosterRecord_addIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_removeIcon, "removeIcon(self, icon: QNdefNfcIconRecord) -> bool\n"
"removeIcon(self, type: QByteArray|bytes|bytearray|memoryview) -> bool");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_removeIcon(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_removeIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcIconRecord* a0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QNdefNfcIconRecord, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->removeIcon(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->removeIcon(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_removeIcon, doc_QNdefNfcSmartPosterRecord_removeIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_setIcons, "setIcons(self, icons: Iterable[QNdefNfcIconRecord])");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_setIcons(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_setIcons(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QNdefNfcIconRecord>* a0;
        int a0State = 0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QList_0100QNdefNfcIconRecord, &a0, &a0State))
        {
            sipCpp->setIcons(*a0);
            sipReleaseType(const_cast<QList< ::QNdefNfcIconRecord> *>(a0), sipType_QList_0100QNdefNfcIconRecord, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_setIcons, doc_QNdefNfcSmartPosterRecord_setIcons);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_size, "size(self) -> int");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_size(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            ::quint32 sipRes;

            sipRes = sipCpp->size();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_size, doc_QNdefNfcSmartPosterRecord_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_setSize, "setSize(self, size: int)");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_setSize(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_setSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint32 a0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, &a0))
        {
            sipCpp->setSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_setSize, doc_QNdefNfcSmartPosterRecord_setSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_typeInfo, "typeInfo(self) -> str");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_typeInfo(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_typeInfo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->typeInfo());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_typeInfo, doc_QNdefNfcSmartPosterRecord_typeInfo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord_setTypeInfo, "setTypeInfo(self, type: str|None)");

extern "C" {static PyObject *meth_QNdefNfcSmartPosterRecord_setTypeInfo(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcSmartPosterRecord_setTypeInfo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QNdefNfcSmartPosterRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNdefNfcSmartPosterRecord, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTypeInfo(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcSmartPosterRecord, sipName_setTypeInfo, doc_QNdefNfcSmartPosterRecord_setTypeInfo);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QNdefNfcSmartPosterRecord(void *, const sipTypeDef *);}
static void *cast_QNdefNfcSmartPosterRecord(void *sipCppV, const sipTypeDef *targetType)
{
    ::QNdefNfcSmartPosterRecord *sipCpp = reinterpret_cast< ::QNdefNfcSmartPosterRecord *>(sipCppV);

    if (targetType == sipType_QNdefNfcSmartPosterRecord)
        return sipCppV;

    if (targetType == sipType_QNdefRecord)
        return static_cast< ::QNdefRecord *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNdefNfcSmartPosterRecord(void *, int);}
static void release_QNdefNfcSmartPosterRecord(void *sipCppV, int)
{
    delete reinterpret_cast< ::QNdefNfcSmartPosterRecord *>(sipCppV);
}


extern "C" {static void *array_QNdefNfcSmartPosterRecord(Py_ssize_t);}
static void *array_QNdefNfcSmartPosterRecord(Py_ssize_t sipNrElem)
{
    return new ::QNdefNfcSmartPosterRecord[sipNrElem];
}


extern "C" {static void array_delete_QNdefNfcSmartPosterRecord(void *);}
static void array_delete_QNdefNfcSmartPosterRecord(void *sipCpp)
{
    delete[] reinterpret_cast< ::QNdefNfcSmartPosterRecord *>(sipCpp);
}


extern "C" {static void assign_QNdefNfcSmartPosterRecord(void *, Py_ssize_t, void *);}
static void assign_QNdefNfcSmartPosterRecord(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QNdefNfcSmartPosterRecord *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QNdefNfcSmartPosterRecord *>(sipSrc);
}


extern "C" {static void *copy_QNdefNfcSmartPosterRecord(const void *, Py_ssize_t);}
static void *copy_QNdefNfcSmartPosterRecord(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QNdefNfcSmartPosterRecord(reinterpret_cast<const ::QNdefNfcSmartPosterRecord *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QNdefNfcSmartPosterRecord(sipSimpleWrapper *);}
static void dealloc_QNdefNfcSmartPosterRecord(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNdefNfcSmartPosterRecord(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QNdefNfcSmartPosterRecord(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QNdefNfcSmartPosterRecord(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QNdefNfcSmartPosterRecord *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QNdefNfcSmartPosterRecord();

            return sipCpp;
        }
    }

    {
        const ::QNdefNfcSmartPosterRecord* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QNdefNfcSmartPosterRecord, &a0))
        {
            sipCpp = new ::QNdefNfcSmartPosterRecord(*a0);

            return sipCpp;
        }
    }

    {
        const ::QNdefRecord* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QNdefRecord, &a0))
        {
            sipCpp = new ::QNdefNfcSmartPosterRecord(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QNdefNfcSmartPosterRecord[] = {{14, 255, 1}};


static PyMethodDef methods_QNdefNfcSmartPosterRecord[] = {
    {sipName_action, meth_QNdefNfcSmartPosterRecord_action, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_action},
    {sipName_addIcon, meth_QNdefNfcSmartPosterRecord_addIcon, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_addIcon},
    {sipName_addTitle, meth_QNdefNfcSmartPosterRecord_addTitle, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_addTitle},
    {sipName_hasAction, meth_QNdefNfcSmartPosterRecord_hasAction, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_hasAction},
    {sipName_hasIcon, SIP_MLMETH_CAST(meth_QNdefNfcSmartPosterRecord_hasIcon), METH_VARARGS|METH_KEYWORDS, doc_QNdefNfcSmartPosterRecord_hasIcon},
    {sipName_hasSize, meth_QNdefNfcSmartPosterRecord_hasSize, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_hasSize},
    {sipName_hasTitle, SIP_MLMETH_CAST(meth_QNdefNfcSmartPosterRecord_hasTitle), METH_VARARGS|METH_KEYWORDS, doc_QNdefNfcSmartPosterRecord_hasTitle},
    {sipName_hasTypeInfo, meth_QNdefNfcSmartPosterRecord_hasTypeInfo, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_hasTypeInfo},
    {sipName_icon, SIP_MLMETH_CAST(meth_QNdefNfcSmartPosterRecord_icon), METH_VARARGS|METH_KEYWORDS, doc_QNdefNfcSmartPosterRecord_icon},
    {sipName_iconCount, meth_QNdefNfcSmartPosterRecord_iconCount, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_iconCount},
    {sipName_iconRecord, meth_QNdefNfcSmartPosterRecord_iconRecord, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_iconRecord},
    {sipName_iconRecords, meth_QNdefNfcSmartPosterRecord_iconRecords, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_iconRecords},
    {sipName_removeIcon, meth_QNdefNfcSmartPosterRecord_removeIcon, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_removeIcon},
    {sipName_removeTitle, meth_QNdefNfcSmartPosterRecord_removeTitle, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_removeTitle},
    {sipName_setAction, meth_QNdefNfcSmartPosterRecord_setAction, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_setAction},
    {sipName_setIcons, meth_QNdefNfcSmartPosterRecord_setIcons, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_setIcons},
    {sipName_setPayload, meth_QNdefNfcSmartPosterRecord_setPayload, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_setPayload},
    {sipName_setSize, meth_QNdefNfcSmartPosterRecord_setSize, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_setSize},
    {sipName_setTitles, meth_QNdefNfcSmartPosterRecord_setTitles, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_setTitles},
    {sipName_setTypeInfo, meth_QNdefNfcSmartPosterRecord_setTypeInfo, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_setTypeInfo},
    {sipName_setUri, meth_QNdefNfcSmartPosterRecord_setUri, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_setUri},
    {sipName_size, meth_QNdefNfcSmartPosterRecord_size, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_size},
    {sipName_title, SIP_MLMETH_CAST(meth_QNdefNfcSmartPosterRecord_title), METH_VARARGS|METH_KEYWORDS, doc_QNdefNfcSmartPosterRecord_title},
    {sipName_titleCount, meth_QNdefNfcSmartPosterRecord_titleCount, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_titleCount},
    {sipName_titleRecord, meth_QNdefNfcSmartPosterRecord_titleRecord, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_titleRecord},
    {sipName_titleRecords, meth_QNdefNfcSmartPosterRecord_titleRecords, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_titleRecords},
    {sipName_typeInfo, meth_QNdefNfcSmartPosterRecord_typeInfo, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_typeInfo},
    {sipName_uri, meth_QNdefNfcSmartPosterRecord_uri, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_uri},
    {sipName_uriRecord, meth_QNdefNfcSmartPosterRecord_uriRecord, METH_VARARGS, doc_QNdefNfcSmartPosterRecord_uriRecord}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QNdefNfcSmartPosterRecord[] = {
    {sipName_UnspecifiedAction, static_cast<int>(::QNdefNfcSmartPosterRecord::UnspecifiedAction)},
    {sipName_DoAction, static_cast<int>(::QNdefNfcSmartPosterRecord::DoAction)},
    {sipName_SaveAction, static_cast<int>(::QNdefNfcSmartPosterRecord::SaveAction)},
    {sipName_EditAction, static_cast<int>(::QNdefNfcSmartPosterRecord::EditAction)},
    {0, 0}
};

PyDoc_STRVAR(doc_QNdefNfcSmartPosterRecord, "\1QNdefNfcSmartPosterRecord()\n"
"QNdefNfcSmartPosterRecord(other: QNdefNfcSmartPosterRecord)\n"
"QNdefNfcSmartPosterRecord(other: QNdefRecord)");


sipClassTypeDef sipTypeDef_QtNfc_QNdefNfcSmartPosterRecord = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNdefNfcSmartPosterRecord,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QNdefNfcSmartPosterRecord,
        {0, 0, 1},
        29, methods_QNdefNfcSmartPosterRecord,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QNdefNfcSmartPosterRecord, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QNdefNfcSmartPosterRecord,
    -1,
    -1,
    supers_QNdefNfcSmartPosterRecord,
    SIP_NULLPTR,
    init_type_QNdefNfcSmartPosterRecord,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QNdefNfcSmartPosterRecord,
    assign_QNdefNfcSmartPosterRecord,
    array_QNdefNfcSmartPosterRecord,
    copy_QNdefNfcSmartPosterRecord,
    release_QNdefNfcSmartPosterRecord,
    cast_QNdefNfcSmartPosterRecord,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QNdefNfcSmartPosterRecord,
    sizeof (::QNdefNfcSmartPosterRecord),
};
