/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevicebase.sip"
#include <qiodevicebase.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQIODeviceBase.cpp"



/* Call the instance's destructor. */
extern "C" {static void release_QIODeviceBase(void *, int);}
static void release_QIODeviceBase(void *, int)
{
}


extern "C" {static void *init_type_QIODeviceBase(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QIODeviceBase(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QIODeviceBase *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QIODeviceBase();

            return sipCpp;
        }
    }

    {
        const ::QIODeviceBase* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QIODeviceBase, &a0))
        {
            sipCpp = new ::QIODeviceBase(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QIODeviceBase[] = {
    {sipName_NotOpen, static_cast<int>(::QIODeviceBase::NotOpen)},
    {sipName_ReadOnly, static_cast<int>(::QIODeviceBase::ReadOnly)},
    {sipName_WriteOnly, static_cast<int>(::QIODeviceBase::WriteOnly)},
    {sipName_ReadWrite, static_cast<int>(::QIODeviceBase::ReadWrite)},
    {sipName_Append, static_cast<int>(::QIODeviceBase::Append)},
    {sipName_Truncate, static_cast<int>(::QIODeviceBase::Truncate)},
    {sipName_Text, static_cast<int>(::QIODeviceBase::Text)},
    {sipName_Unbuffered, static_cast<int>(::QIODeviceBase::Unbuffered)},
    {sipName_NewOnly, static_cast<int>(::QIODeviceBase::NewOnly)},
    {sipName_ExistingOnly, static_cast<int>(::QIODeviceBase::ExistingOnly)},
    {0, 0}
};

PyDoc_STRVAR(doc_QIODeviceBase, "\1QIODeviceBase()\n"
"QIODeviceBase(a0: QIODeviceBase)");


sipClassTypeDef sipTypeDef_QtCore_QIODeviceBase = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QIODeviceBase,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QIODeviceBase,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QIODeviceBase, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QIODeviceBase,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QIODeviceBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QIODeviceBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QIODeviceBase),
};
