/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothservicediscoveryagent.sip"
#include <qbluetoothservicediscoveryagent.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothaddress.sip"
#include <qbluetoothaddress.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothserviceinfo.sip"
#include <qbluetoothserviceinfo.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothuuid.sip"
#include <qbluetoothuuid.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServiceDiscoveryAgent.cpp"


class sipQBluetoothServiceDiscoveryAgent : public ::QBluetoothServiceDiscoveryAgent
{
public:
    sipQBluetoothServiceDiscoveryAgent(::QObject*);
    sipQBluetoothServiceDiscoveryAgent(const ::QBluetoothAddress&, ::QObject*);
    virtual ~sipQBluetoothServiceDiscoveryAgent();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQBluetoothServiceDiscoveryAgent(const sipQBluetoothServiceDiscoveryAgent &);
    sipQBluetoothServiceDiscoveryAgent &operator = (const sipQBluetoothServiceDiscoveryAgent &);

    char sipPyMethods[7];
};

sipQBluetoothServiceDiscoveryAgent::sipQBluetoothServiceDiscoveryAgent(::QObject*a0): ::QBluetoothServiceDiscoveryAgent(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBluetoothServiceDiscoveryAgent::sipQBluetoothServiceDiscoveryAgent(const ::QBluetoothAddress& a0, ::QObject*a1): ::QBluetoothServiceDiscoveryAgent(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBluetoothServiceDiscoveryAgent::~sipQBluetoothServiceDiscoveryAgent()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQBluetoothServiceDiscoveryAgent::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtBluetooth_qt_metaobject(sipPySelf, sipType_QBluetoothServiceDiscoveryAgent);

    return ::QBluetoothServiceDiscoveryAgent::metaObject();
}

int sipQBluetoothServiceDiscoveryAgent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QBluetoothServiceDiscoveryAgent::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtBluetooth_qt_metacall(sipPySelf, sipType_QBluetoothServiceDiscoveryAgent, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQBluetoothServiceDiscoveryAgent::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtBluetooth_qt_metacast(sipPySelf, sipType_QBluetoothServiceDiscoveryAgent, _clname, &sipCpp) ? sipCpp : ::QBluetoothServiceDiscoveryAgent::qt_metacast(_clname));
}

bool sipQBluetoothServiceDiscoveryAgent::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QBluetoothServiceDiscoveryAgent::event(a0);

    extern bool sipVH_QtBluetooth_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtBluetooth_5(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQBluetoothServiceDiscoveryAgent::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QBluetoothServiceDiscoveryAgent::eventFilter(a0, a1);

    extern bool sipVH_QtBluetooth_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtBluetooth_4(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQBluetoothServiceDiscoveryAgent::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QBluetoothServiceDiscoveryAgent::timerEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtBluetooth_3(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothServiceDiscoveryAgent::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QBluetoothServiceDiscoveryAgent::childEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtBluetooth_2(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothServiceDiscoveryAgent::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QBluetoothServiceDiscoveryAgent::customEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtBluetooth_1(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothServiceDiscoveryAgent::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QBluetoothServiceDiscoveryAgent::connectNotify(a0);
        return;
    }

    extern void sipVH_QtBluetooth_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtBluetooth_0(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothServiceDiscoveryAgent::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QBluetoothServiceDiscoveryAgent::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtBluetooth_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtBluetooth_0(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent_isActive, "isActive(self) -> bool");

extern "C" {static PyObject *meth_QBluetoothServiceDiscoveryAgent_isActive(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceDiscoveryAgent_isActive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceDiscoveryAgent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isActive();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceDiscoveryAgent, sipName_isActive, doc_QBluetoothServiceDiscoveryAgent_isActive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent_error, "error(self) -> QBluetoothServiceDiscoveryAgent.Error");

extern "C" {static PyObject *meth_QBluetoothServiceDiscoveryAgent_error(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceDiscoveryAgent_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceDiscoveryAgent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp))
        {
            ::QBluetoothServiceDiscoveryAgent::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QBluetoothServiceDiscoveryAgent_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceDiscoveryAgent, sipName_error, doc_QBluetoothServiceDiscoveryAgent_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QBluetoothServiceDiscoveryAgent_errorString(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceDiscoveryAgent_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceDiscoveryAgent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceDiscoveryAgent, sipName_errorString, doc_QBluetoothServiceDiscoveryAgent_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent_discoveredServices, "discoveredServices(self) -> list[QBluetoothServiceInfo]");

extern "C" {static PyObject *meth_QBluetoothServiceDiscoveryAgent_discoveredServices(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceDiscoveryAgent_discoveredServices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceDiscoveryAgent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp))
        {
            QList< ::QBluetoothServiceInfo>*sipRes;

            sipRes = new QList< ::QBluetoothServiceInfo>(sipCpp->discoveredServices());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QBluetoothServiceInfo, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceDiscoveryAgent, sipName_discoveredServices, doc_QBluetoothServiceDiscoveryAgent_discoveredServices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent_setUuidFilter, "setUuidFilter(self, uuids: Iterable[QBluetoothUuid])\n"
"setUuidFilter(self, uuid: QBluetoothUuid)");

extern "C" {static PyObject *meth_QBluetoothServiceDiscoveryAgent_setUuidFilter(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceDiscoveryAgent_setUuidFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QBluetoothUuid>* a0;
        int a0State = 0;
        ::QBluetoothServiceDiscoveryAgent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp, sipType_QList_0100QBluetoothUuid, &a0, &a0State))
        {
            sipCpp->setUuidFilter(*a0);
            sipReleaseType(const_cast<QList< ::QBluetoothUuid> *>(a0), sipType_QList_0100QBluetoothUuid, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QBluetoothUuid* a0;
        ::QBluetoothServiceDiscoveryAgent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp, sipType_QBluetoothUuid, &a0))
        {
            sipCpp->setUuidFilter(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceDiscoveryAgent, sipName_setUuidFilter, doc_QBluetoothServiceDiscoveryAgent_setUuidFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent_uuidFilter, "uuidFilter(self) -> list[QBluetoothUuid]");

extern "C" {static PyObject *meth_QBluetoothServiceDiscoveryAgent_uuidFilter(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceDiscoveryAgent_uuidFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceDiscoveryAgent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp))
        {
            QList< ::QBluetoothUuid>*sipRes;

            sipRes = new QList< ::QBluetoothUuid>(sipCpp->uuidFilter());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QBluetoothUuid, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceDiscoveryAgent, sipName_uuidFilter, doc_QBluetoothServiceDiscoveryAgent_uuidFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent_setRemoteAddress, "setRemoteAddress(self, address: QBluetoothAddress) -> bool");

extern "C" {static PyObject *meth_QBluetoothServiceDiscoveryAgent_setRemoteAddress(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceDiscoveryAgent_setRemoteAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothAddress* a0;
        ::QBluetoothServiceDiscoveryAgent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp, sipType_QBluetoothAddress, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->setRemoteAddress(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceDiscoveryAgent, sipName_setRemoteAddress, doc_QBluetoothServiceDiscoveryAgent_setRemoteAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent_remoteAddress, "remoteAddress(self) -> QBluetoothAddress");

extern "C" {static PyObject *meth_QBluetoothServiceDiscoveryAgent_remoteAddress(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceDiscoveryAgent_remoteAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceDiscoveryAgent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp))
        {
            ::QBluetoothAddress*sipRes;

            sipRes = new ::QBluetoothAddress(sipCpp->remoteAddress());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothAddress, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceDiscoveryAgent, sipName_remoteAddress, doc_QBluetoothServiceDiscoveryAgent_remoteAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent_start, "start(self, mode: QBluetoothServiceDiscoveryAgent.DiscoveryMode = QBluetoothServiceDiscoveryAgent.MinimalDiscovery)");

extern "C" {static PyObject *meth_QBluetoothServiceDiscoveryAgent_start(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceDiscoveryAgent_start(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothServiceDiscoveryAgent::DiscoveryMode a0 = QBluetoothServiceDiscoveryAgent::MinimalDiscovery;
        ::QBluetoothServiceDiscoveryAgent *sipCpp;

        static const char *sipKwdList[] = {
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp, sipType_QBluetoothServiceDiscoveryAgent_DiscoveryMode, &a0))
        {
            sipCpp->start(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceDiscoveryAgent, sipName_start, doc_QBluetoothServiceDiscoveryAgent_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent_stop, "stop(self)");

extern "C" {static PyObject *meth_QBluetoothServiceDiscoveryAgent_stop(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceDiscoveryAgent_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothServiceDiscoveryAgent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceDiscoveryAgent, sipName_stop, doc_QBluetoothServiceDiscoveryAgent_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent_clear, "clear(self)");

extern "C" {static PyObject *meth_QBluetoothServiceDiscoveryAgent_clear(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServiceDiscoveryAgent_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothServiceDiscoveryAgent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServiceDiscoveryAgent, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServiceDiscoveryAgent, sipName_clear, doc_QBluetoothServiceDiscoveryAgent_clear);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QBluetoothServiceDiscoveryAgent(void *, const sipTypeDef *);}
static void *cast_QBluetoothServiceDiscoveryAgent(void *sipCppV, const sipTypeDef *targetType)
{
    ::QBluetoothServiceDiscoveryAgent *sipCpp = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(sipCppV);

    if (targetType == sipType_QBluetoothServiceDiscoveryAgent)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QBluetoothServiceDiscoveryAgent(void *, int);}
static void release_QBluetoothServiceDiscoveryAgent(void *sipCppV, int)
{
    ::QBluetoothServiceDiscoveryAgent *sipCpp = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QBluetoothServiceDiscoveryAgent(Py_ssize_t);}
static void *array_QBluetoothServiceDiscoveryAgent(Py_ssize_t sipNrElem)
{
    return new ::QBluetoothServiceDiscoveryAgent[sipNrElem];
}


extern "C" {static void array_delete_QBluetoothServiceDiscoveryAgent(void *);}
static void array_delete_QBluetoothServiceDiscoveryAgent(void *sipCpp)
{
    delete[] reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(sipCpp);
}


extern "C" {static void dealloc_QBluetoothServiceDiscoveryAgent(sipSimpleWrapper *);}
static void dealloc_QBluetoothServiceDiscoveryAgent(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQBluetoothServiceDiscoveryAgent *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QBluetoothServiceDiscoveryAgent(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QBluetoothServiceDiscoveryAgent(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QBluetoothServiceDiscoveryAgent(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQBluetoothServiceDiscoveryAgent *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQBluetoothServiceDiscoveryAgent(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QBluetoothAddress* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|JH", sipType_QBluetoothAddress, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQBluetoothServiceDiscoveryAgent(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QBluetoothServiceDiscoveryAgent[] = {{9, 0, 1}};


static PyMethodDef methods_QBluetoothServiceDiscoveryAgent[] = {
    {sipName_clear, meth_QBluetoothServiceDiscoveryAgent_clear, METH_VARARGS, doc_QBluetoothServiceDiscoveryAgent_clear},
    {sipName_discoveredServices, meth_QBluetoothServiceDiscoveryAgent_discoveredServices, METH_VARARGS, doc_QBluetoothServiceDiscoveryAgent_discoveredServices},
    {sipName_error, meth_QBluetoothServiceDiscoveryAgent_error, METH_VARARGS, doc_QBluetoothServiceDiscoveryAgent_error},
    {sipName_errorString, meth_QBluetoothServiceDiscoveryAgent_errorString, METH_VARARGS, doc_QBluetoothServiceDiscoveryAgent_errorString},
    {sipName_isActive, meth_QBluetoothServiceDiscoveryAgent_isActive, METH_VARARGS, doc_QBluetoothServiceDiscoveryAgent_isActive},
    {sipName_remoteAddress, meth_QBluetoothServiceDiscoveryAgent_remoteAddress, METH_VARARGS, doc_QBluetoothServiceDiscoveryAgent_remoteAddress},
    {sipName_setRemoteAddress, meth_QBluetoothServiceDiscoveryAgent_setRemoteAddress, METH_VARARGS, doc_QBluetoothServiceDiscoveryAgent_setRemoteAddress},
    {sipName_setUuidFilter, meth_QBluetoothServiceDiscoveryAgent_setUuidFilter, METH_VARARGS, doc_QBluetoothServiceDiscoveryAgent_setUuidFilter},
    {sipName_start, SIP_MLMETH_CAST(meth_QBluetoothServiceDiscoveryAgent_start), METH_VARARGS|METH_KEYWORDS, doc_QBluetoothServiceDiscoveryAgent_start},
    {sipName_stop, meth_QBluetoothServiceDiscoveryAgent_stop, METH_VARARGS, doc_QBluetoothServiceDiscoveryAgent_stop},
    {sipName_uuidFilter, meth_QBluetoothServiceDiscoveryAgent_uuidFilter, METH_VARARGS, doc_QBluetoothServiceDiscoveryAgent_uuidFilter}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QBluetoothServiceDiscoveryAgent[] = {
    {sipName_MinimalDiscovery, static_cast<int>(::QBluetoothServiceDiscoveryAgent::MinimalDiscovery)},
    {sipName_FullDiscovery, static_cast<int>(::QBluetoothServiceDiscoveryAgent::FullDiscovery)},
    {sipName_NoError, static_cast<int>(::QBluetoothServiceDiscoveryAgent::NoError)},
    {sipName_InputOutputError, static_cast<int>(::QBluetoothServiceDiscoveryAgent::InputOutputError)},
    {sipName_PoweredOffError, static_cast<int>(::QBluetoothServiceDiscoveryAgent::PoweredOffError)},
    {sipName_InvalidBluetoothAdapterError, static_cast<int>(::QBluetoothServiceDiscoveryAgent::InvalidBluetoothAdapterError)},
    {sipName_MissingPermissionsError, static_cast<int>(::QBluetoothServiceDiscoveryAgent::MissingPermissionsError)},
    {sipName_UnknownError, static_cast<int>(::QBluetoothServiceDiscoveryAgent::UnknownError)},
    {0, 0}
};

PyDoc_STRVAR(doc_QBluetoothServiceDiscoveryAgent, "\1QBluetoothServiceDiscoveryAgent(parent: QObject|None = None)\n"
"QBluetoothServiceDiscoveryAgent(deviceAdapter: QBluetoothAddress, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QBluetoothServiceDiscoveryAgent[] = {
    {"errorOccurred(QBluetoothServiceDiscoveryAgent::Error)", "\1errorOccurred(self, error: QBluetoothServiceDiscoveryAgent.Error)", SIP_NULLPTR, SIP_NULLPTR},
    {"canceled()", "\1canceled(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"finished()", "\1finished(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"serviceDiscovered(QBluetoothServiceInfo)", "\1serviceDiscovered(self, info: QBluetoothServiceInfo)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QBluetoothServiceDiscoveryAgent = {
    &::QBluetoothServiceDiscoveryAgent::staticMetaObject,
    signals_QBluetoothServiceDiscoveryAgent,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothServiceDiscoveryAgent = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QBluetoothServiceDiscoveryAgent,
        SIP_NULLPTR,
        &plugin_QBluetoothServiceDiscoveryAgent,
    },
    {
        sipNameNr_QBluetoothServiceDiscoveryAgent,
        {0, 0, 1},
        11, methods_QBluetoothServiceDiscoveryAgent,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QBluetoothServiceDiscoveryAgent, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QBluetoothServiceDiscoveryAgent,
    -1,
    -1,
    supers_QBluetoothServiceDiscoveryAgent,
    SIP_NULLPTR,
    init_type_QBluetoothServiceDiscoveryAgent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QBluetoothServiceDiscoveryAgent,
    SIP_NULLPTR,
    array_QBluetoothServiceDiscoveryAgent,
    SIP_NULLPTR,
    release_QBluetoothServiceDiscoveryAgent,
    cast_QBluetoothServiceDiscoveryAgent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QBluetoothServiceDiscoveryAgent,
    sizeof (::QBluetoothServiceDiscoveryAgent),
};
