/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtRemoteObjects.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qtremoteobjectglobal.sip"
#include <qtremoteobjectglobal.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectSourceLocationInfo.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectSourceLocationInfo.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectSourceLocationInfo.cpp"


extern "C" {static PyObject *slot_QRemoteObjectSourceLocationInfo___ne__(PyObject *, PyObject *);}
static PyObject *slot_QRemoteObjectSourceLocationInfo___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QRemoteObjectSourceLocationInfo *sipCpp = reinterpret_cast< ::QRemoteObjectSourceLocationInfo *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QRemoteObjectSourceLocationInfo));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectSourceLocationInfo* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QRemoteObjectSourceLocationInfo, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QRemoteObjectSourceLocationInfo::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtRemoteObjects, ne_slot, sipType_QRemoteObjectSourceLocationInfo, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QRemoteObjectSourceLocationInfo___eq__(PyObject *, PyObject *);}
static PyObject *slot_QRemoteObjectSourceLocationInfo___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QRemoteObjectSourceLocationInfo *sipCpp = reinterpret_cast< ::QRemoteObjectSourceLocationInfo *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QRemoteObjectSourceLocationInfo));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectSourceLocationInfo* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QRemoteObjectSourceLocationInfo, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QRemoteObjectSourceLocationInfo::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtRemoteObjects, eq_slot, sipType_QRemoteObjectSourceLocationInfo, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QRemoteObjectSourceLocationInfo(void *, int);}
static void release_QRemoteObjectSourceLocationInfo(void *sipCppV, int)
{
    delete reinterpret_cast< ::QRemoteObjectSourceLocationInfo *>(sipCppV);
}


extern "C" {static void *array_QRemoteObjectSourceLocationInfo(Py_ssize_t);}
static void *array_QRemoteObjectSourceLocationInfo(Py_ssize_t sipNrElem)
{
    return new ::QRemoteObjectSourceLocationInfo[sipNrElem];
}


extern "C" {static void array_delete_QRemoteObjectSourceLocationInfo(void *);}
static void array_delete_QRemoteObjectSourceLocationInfo(void *sipCpp)
{
    delete[] reinterpret_cast< ::QRemoteObjectSourceLocationInfo *>(sipCpp);
}


extern "C" {static void assign_QRemoteObjectSourceLocationInfo(void *, Py_ssize_t, void *);}
static void assign_QRemoteObjectSourceLocationInfo(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QRemoteObjectSourceLocationInfo *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QRemoteObjectSourceLocationInfo *>(sipSrc);
}


extern "C" {static void *copy_QRemoteObjectSourceLocationInfo(const void *, Py_ssize_t);}
static void *copy_QRemoteObjectSourceLocationInfo(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QRemoteObjectSourceLocationInfo(reinterpret_cast<const ::QRemoteObjectSourceLocationInfo *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QRemoteObjectSourceLocationInfo(sipSimpleWrapper *);}
static void dealloc_QRemoteObjectSourceLocationInfo(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRemoteObjectSourceLocationInfo(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QRemoteObjectSourceLocationInfo(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QRemoteObjectSourceLocationInfo(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QRemoteObjectSourceLocationInfo *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QRemoteObjectSourceLocationInfo();

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QUrl* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1J9", sipType_QString, &a0, &a0State, sipType_QUrl, &a1))
        {
            sipCpp = new ::QRemoteObjectSourceLocationInfo(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipCpp;
        }
    }

    {
        const ::QRemoteObjectSourceLocationInfo* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QRemoteObjectSourceLocationInfo, &a0))
        {
            sipCpp = new ::QRemoteObjectSourceLocationInfo(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QRemoteObjectSourceLocationInfo[] = {
    {(void *)slot_QRemoteObjectSourceLocationInfo___ne__, ne_slot},
    {(void *)slot_QRemoteObjectSourceLocationInfo___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


extern "C" {static PyObject *varget_QRemoteObjectSourceLocationInfo_hostUrl(void *, PyObject *, PyObject *);}
static PyObject *varget_QRemoteObjectSourceLocationInfo_hostUrl(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
    ::QUrl*sipVal;
    ::QRemoteObjectSourceLocationInfo *sipCpp = reinterpret_cast< ::QRemoteObjectSourceLocationInfo *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -1);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->hostUrl;

    sipPy = sipConvertFromType(sipVal, sipType_QUrl, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -8, sipPySelf);
        sipKeepReference(sipPySelf, -1, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QRemoteObjectSourceLocationInfo_hostUrl(void *, PyObject *, PyObject *);}
static int varset_QRemoteObjectSourceLocationInfo_hostUrl(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QUrl*sipVal;
    ::QRemoteObjectSourceLocationInfo *sipCpp = reinterpret_cast< ::QRemoteObjectSourceLocationInfo *>(sipSelf);

    int sipIsErr = 0;
    sipVal = reinterpret_cast< ::QUrl *>(sipForceConvertToType(sipPy, sipType_QUrl, SIP_NULLPTR, SIP_NOT_NONE, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->hostUrl = *sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QRemoteObjectSourceLocationInfo_typeName(void *, PyObject *, PyObject *);}
static PyObject *varget_QRemoteObjectSourceLocationInfo_typeName(void *sipSelf, PyObject *, PyObject *)
{
    ::QString*sipVal;
    ::QRemoteObjectSourceLocationInfo *sipCpp = reinterpret_cast< ::QRemoteObjectSourceLocationInfo *>(sipSelf);

    sipVal = &sipCpp->typeName;

    return sipConvertFromType(sipVal, sipType_QString, SIP_NULLPTR);
}


extern "C" {static int varset_QRemoteObjectSourceLocationInfo_typeName(void *, PyObject *, PyObject *);}
static int varset_QRemoteObjectSourceLocationInfo_typeName(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QString*sipVal;
    ::QRemoteObjectSourceLocationInfo *sipCpp = reinterpret_cast< ::QRemoteObjectSourceLocationInfo *>(sipSelf);

    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast< ::QString *>(sipForceConvertToType(sipPy, sipType_QString, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->typeName = *sipVal;

    sipReleaseType(sipVal, sipType_QString, sipValState);

    return 0;
}

sipVariableDef variables_QRemoteObjectSourceLocationInfo[] = {
    {InstanceVariable, sipName_hostUrl, (PyMethodDef *)varget_QRemoteObjectSourceLocationInfo_hostUrl, (PyMethodDef *)varset_QRemoteObjectSourceLocationInfo_hostUrl, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_typeName, (PyMethodDef *)varget_QRemoteObjectSourceLocationInfo_typeName, (PyMethodDef *)varset_QRemoteObjectSourceLocationInfo_typeName, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QRemoteObjectSourceLocationInfo, "\1QRemoteObjectSourceLocationInfo()\n"
"QRemoteObjectSourceLocationInfo(typeName_: str|None, hostUrl_: QUrl)\n"
"QRemoteObjectSourceLocationInfo(a0: QRemoteObjectSourceLocationInfo)");


sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectSourceLocationInfo = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRemoteObjectSourceLocationInfo,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QRemoteObjectSourceLocationInfo,
        {0, 0, 1},
        0, SIP_NULLPTR,
        2, variables_QRemoteObjectSourceLocationInfo,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QRemoteObjectSourceLocationInfo,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QRemoteObjectSourceLocationInfo,
    init_type_QRemoteObjectSourceLocationInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRemoteObjectSourceLocationInfo,
    assign_QRemoteObjectSourceLocationInfo,
    array_QRemoteObjectSourceLocationInfo,
    copy_QRemoteObjectSourceLocationInfo,
    release_QRemoteObjectSourceLocationInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QRemoteObjectSourceLocationInfo,
    sizeof (::QRemoteObjectSourceLocationInfo),
};
