/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiosource.sip"
#include <qaudiosource.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiodevice.sip"
#include <qaudiodevice.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudioformat.sip"
#include <qaudioformat.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudio.sip"
#include <qaudio.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioSource.cpp"


class sipQAudioSource : public ::QAudioSource
{
public:
    sipQAudioSource(const ::QAudioDevice&, const ::QAudioFormat&, ::QObject*);
    sipQAudioSource(const ::QAudioFormat&, ::QObject*);
    virtual ~sipQAudioSource();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAudioSource(const sipQAudioSource &);
    sipQAudioSource &operator = (const sipQAudioSource &);

    char sipPyMethods[7];
};

sipQAudioSource::sipQAudioSource(const ::QAudioDevice& a0, const ::QAudioFormat& a1, ::QObject*a2): ::QAudioSource(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioSource::sipQAudioSource(const ::QAudioFormat& a0, ::QObject*a1): ::QAudioSource(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioSource::~sipQAudioSource()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAudioSource::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QAudioSource);

    return ::QAudioSource::metaObject();
}

int sipQAudioSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAudioSource::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QAudioSource, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAudioSource::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QAudioSource, _clname, &sipCpp) ? sipCpp : ::QAudioSource::qt_metacast(_clname));
}

bool sipQAudioSource::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAudioSource::event(a0);

    extern bool sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAudioSource::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAudioSource::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_4(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAudioSource::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAudioSource::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_3(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioSource::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAudioSource::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioSource::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAudioSource::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_1(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioSource::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAudioSource::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioSource::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAudioSource::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAudioSource_format, "format(self) -> QAudioFormat");

extern "C" {static PyObject *meth_QAudioSource_format(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_format(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            ::QAudioFormat*sipRes;

            sipRes = new ::QAudioFormat(sipCpp->format());

            return sipConvertFromNewType(sipRes, sipType_QAudioFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_format, doc_QAudioSource_format);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_start, "start(self, device: QIODevice|None)\n"
"start(self) -> QIODevice|None");

extern "C" {static PyObject *meth_QAudioSource_start(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QAudioSource, &sipCpp, sipType_QIODevice, &a0))
        {
            sipCpp->start(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            ::QIODevice*sipRes;

            sipRes = sipCpp->start();

            return sipConvertFromType(sipRes, sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_start, doc_QAudioSource_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_stop, "stop(self)");

extern "C" {static PyObject *meth_QAudioSource_stop(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_stop, doc_QAudioSource_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_reset, "reset(self)");

extern "C" {static PyObject *meth_QAudioSource_reset(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_reset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            sipCpp->reset();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_reset, doc_QAudioSource_reset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_suspend, "suspend(self)");

extern "C" {static PyObject *meth_QAudioSource_suspend(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_suspend(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            sipCpp->suspend();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_suspend, doc_QAudioSource_suspend);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_resume, "resume(self)");

extern "C" {static PyObject *meth_QAudioSource_resume(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_resume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            sipCpp->resume();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_resume, doc_QAudioSource_resume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_setBufferSize, "setBufferSize(self, bytes: int)");

extern "C" {static PyObject *meth_QAudioSource_setBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_setBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QAudioSource, &sipCpp, &a0))
        {
            sipCpp->setBufferSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_setBufferSize, doc_QAudioSource_setBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_bufferSize, "bufferSize(self) -> int");

extern "C" {static PyObject *meth_QAudioSource_bufferSize(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_bufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            ::qsizetype sipRes;

            sipRes = sipCpp->bufferSize();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_bufferSize, doc_QAudioSource_bufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_bytesAvailable, "bytesAvailable(self) -> int");

extern "C" {static PyObject *meth_QAudioSource_bytesAvailable(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_bytesAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            ::qsizetype sipRes;

            sipRes = sipCpp->bytesAvailable();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_bytesAvailable, doc_QAudioSource_bytesAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_setVolume, "setVolume(self, volume: float)");

extern "C" {static PyObject *meth_QAudioSource_setVolume(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_setVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QAudioSource, &sipCpp, &a0))
        {
            sipCpp->setVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_setVolume, doc_QAudioSource_setVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_volume, "volume(self) -> float");

extern "C" {static PyObject *meth_QAudioSource_volume(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_volume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->volume();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_volume, doc_QAudioSource_volume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_processedUSecs, "processedUSecs(self) -> int");

extern "C" {static PyObject *meth_QAudioSource_processedUSecs(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_processedUSecs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->processedUSecs();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_processedUSecs, doc_QAudioSource_processedUSecs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_elapsedUSecs, "elapsedUSecs(self) -> int");

extern "C" {static PyObject *meth_QAudioSource_elapsedUSecs(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_elapsedUSecs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->elapsedUSecs();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_elapsedUSecs, doc_QAudioSource_elapsedUSecs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_error, "error(self) -> QAudio.Error");

extern "C" {static PyObject *meth_QAudioSource_error(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            ::QAudio::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAudio_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_error, doc_QAudioSource_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_state, "state(self) -> QAudio.State");

extern "C" {static PyObject *meth_QAudioSource_state(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            ::QAudio::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAudio_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_state, doc_QAudioSource_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_setBufferFrameCount, "setBufferFrameCount(self, frames: int)");

extern "C" {static PyObject *meth_QAudioSource_setBufferFrameCount(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_setBufferFrameCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QAudioSource, &sipCpp, &a0))
        {
            sipCpp->setBufferFrameCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_setBufferFrameCount, doc_QAudioSource_setBufferFrameCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_bufferFrameCount, "bufferFrameCount(self) -> int");

extern "C" {static PyObject *meth_QAudioSource_bufferFrameCount(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_bufferFrameCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            ::qsizetype sipRes;

            sipRes = sipCpp->bufferFrameCount();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_bufferFrameCount, doc_QAudioSource_bufferFrameCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioSource_framesAvailable, "framesAvailable(self) -> int");

extern "C" {static PyObject *meth_QAudioSource_framesAvailable(PyObject *, PyObject *);}
static PyObject *meth_QAudioSource_framesAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioSource, &sipCpp))
        {
            ::qsizetype sipRes;

            sipRes = sipCpp->framesAvailable();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioSource, sipName_framesAvailable, doc_QAudioSource_framesAvailable);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAudioSource(void *, const sipTypeDef *);}
static void *cast_QAudioSource(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAudioSource *sipCpp = reinterpret_cast< ::QAudioSource *>(sipCppV);

    if (targetType == sipType_QAudioSource)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAudioSource(void *, int);}
static void release_QAudioSource(void *sipCppV, int)
{
    ::QAudioSource *sipCpp = reinterpret_cast< ::QAudioSource *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QAudioSource(Py_ssize_t);}
static void *array_QAudioSource(Py_ssize_t sipNrElem)
{
    return new ::QAudioSource[sipNrElem];
}


extern "C" {static void array_delete_QAudioSource(void *);}
static void array_delete_QAudioSource(void *sipCpp)
{
    delete[] reinterpret_cast< ::QAudioSource *>(sipCpp);
}


extern "C" {static void dealloc_QAudioSource(sipSimpleWrapper *);}
static void dealloc_QAudioSource(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAudioSource *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAudioSource(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAudioSource(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAudioSource(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAudioSource *sipCpp = SIP_NULLPTR;

    {
        const ::QAudioDevice* a0;
        const ::QAudioFormat& a1def = QAudioFormat();
        const ::QAudioFormat* a1 = &a1def;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|J9JH", sipType_QAudioDevice, &a0, sipType_QAudioFormat, &a1, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQAudioSource(*a0, *a1, a2);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QAudioFormat& a0def = QAudioFormat();
        const ::QAudioFormat* a0 = &a0def;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            sipName_format,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|J9JH", sipType_QAudioFormat, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQAudioSource(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAudioSource[] = {{7, 0, 1}};


static PyMethodDef methods_QAudioSource[] = {
    {sipName_bufferFrameCount, meth_QAudioSource_bufferFrameCount, METH_VARARGS, doc_QAudioSource_bufferFrameCount},
    {sipName_bufferSize, meth_QAudioSource_bufferSize, METH_VARARGS, doc_QAudioSource_bufferSize},
    {sipName_bytesAvailable, meth_QAudioSource_bytesAvailable, METH_VARARGS, doc_QAudioSource_bytesAvailable},
    {sipName_elapsedUSecs, meth_QAudioSource_elapsedUSecs, METH_VARARGS, doc_QAudioSource_elapsedUSecs},
    {sipName_error, meth_QAudioSource_error, METH_VARARGS, doc_QAudioSource_error},
    {sipName_format, meth_QAudioSource_format, METH_VARARGS, doc_QAudioSource_format},
    {sipName_framesAvailable, meth_QAudioSource_framesAvailable, METH_VARARGS, doc_QAudioSource_framesAvailable},
    {sipName_processedUSecs, meth_QAudioSource_processedUSecs, METH_VARARGS, doc_QAudioSource_processedUSecs},
    {sipName_reset, meth_QAudioSource_reset, METH_VARARGS, doc_QAudioSource_reset},
    {sipName_resume, meth_QAudioSource_resume, METH_VARARGS, doc_QAudioSource_resume},
    {sipName_setBufferFrameCount, meth_QAudioSource_setBufferFrameCount, METH_VARARGS, doc_QAudioSource_setBufferFrameCount},
    {sipName_setBufferSize, meth_QAudioSource_setBufferSize, METH_VARARGS, doc_QAudioSource_setBufferSize},
    {sipName_setVolume, meth_QAudioSource_setVolume, METH_VARARGS, doc_QAudioSource_setVolume},
    {sipName_start, meth_QAudioSource_start, METH_VARARGS, doc_QAudioSource_start},
    {sipName_state, meth_QAudioSource_state, METH_VARARGS, doc_QAudioSource_state},
    {sipName_stop, meth_QAudioSource_stop, METH_VARARGS, doc_QAudioSource_stop},
    {sipName_suspend, meth_QAudioSource_suspend, METH_VARARGS, doc_QAudioSource_suspend},
    {sipName_volume, meth_QAudioSource_volume, METH_VARARGS, doc_QAudioSource_volume}
};

PyDoc_STRVAR(doc_QAudioSource, "\1QAudioSource(audioDeviceInfo: QAudioDevice, format: QAudioFormat = QAudioFormat(), parent: QObject|None = None)\n"
"QAudioSource(format: QAudioFormat = QAudioFormat(), parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QAudioSource[] = {
    {"stateChanged(QAudio::State)", "\1stateChanged(self, state: QAudio.State)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QAudioSource = {
    &::QAudioSource::staticMetaObject,
    signals_QAudioSource,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QAudioSource = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAudioSource,
        SIP_NULLPTR,
        &plugin_QAudioSource,
    },
    {
        sipNameNr_QAudioSource,
        {0, 0, 1},
        18, methods_QAudioSource,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAudioSource,
    -1,
    -1,
    supers_QAudioSource,
    SIP_NULLPTR,
    init_type_QAudioSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAudioSource,
    SIP_NULLPTR,
    array_QAudioSource,
    SIP_NULLPTR,
    release_QAudioSource,
    cast_QAudioSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAudioSource,
    sizeof (::QAudioSource),
};
