/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothserver.sip"
#include <qbluetoothserver.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothserviceinfo.sip"
#include <qbluetoothserviceinfo.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetooth.sip"
#include <qbluetooth.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothaddress.sip"
#include <qbluetoothaddress.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothsocket.sip"
#include <qbluetoothsocket.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothuuid.sip"
#include <qbluetoothuuid.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothServer.cpp"


class sipQBluetoothServer : public ::QBluetoothServer
{
public:
    sipQBluetoothServer(::QBluetoothServiceInfo::Protocol, ::QObject*);
    virtual ~sipQBluetoothServer();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQBluetoothServer(const sipQBluetoothServer &);
    sipQBluetoothServer &operator = (const sipQBluetoothServer &);

    char sipPyMethods[7];
};

sipQBluetoothServer::sipQBluetoothServer(::QBluetoothServiceInfo::Protocol a0, ::QObject*a1): ::QBluetoothServer(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBluetoothServer::~sipQBluetoothServer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQBluetoothServer::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtBluetooth_qt_metaobject(sipPySelf, sipType_QBluetoothServer);

    return ::QBluetoothServer::metaObject();
}

int sipQBluetoothServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QBluetoothServer::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtBluetooth_qt_metacall(sipPySelf, sipType_QBluetoothServer, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQBluetoothServer::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtBluetooth_qt_metacast(sipPySelf, sipType_QBluetoothServer, _clname, &sipCpp) ? sipCpp : ::QBluetoothServer::qt_metacast(_clname));
}

bool sipQBluetoothServer::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QBluetoothServer::event(a0);

    extern bool sipVH_QtBluetooth_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtBluetooth_5(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQBluetoothServer::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QBluetoothServer::eventFilter(a0, a1);

    extern bool sipVH_QtBluetooth_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtBluetooth_4(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQBluetoothServer::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QBluetoothServer::timerEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtBluetooth_3(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothServer::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QBluetoothServer::childEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtBluetooth_2(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothServer::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QBluetoothServer::customEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtBluetooth_1(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothServer::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QBluetoothServer::connectNotify(a0);
        return;
    }

    extern void sipVH_QtBluetooth_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtBluetooth_0(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothServer::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QBluetoothServer::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtBluetooth_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtBluetooth_0(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QBluetoothServer_close, "close(self)");

extern "C" {static PyObject *meth_QBluetoothServer_close(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_close(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServer, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->close();
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_close, doc_QBluetoothServer_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_listen, "listen(self, address: QBluetoothAddress = QBluetoothAddress(), port: int = 0) -> bool\n"
"listen(self, uuid: QBluetoothUuid, serviceName: str|None = '') -> QBluetoothServiceInfo");

extern "C" {static PyObject *meth_QBluetoothServer_listen(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_listen(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothAddress& a0def = QBluetoothAddress();
        const ::QBluetoothAddress* a0 = &a0def;
        ::quint16 a1 = 0;
        ::QBluetoothServer *sipCpp;

        static const char *sipKwdList[] = {
            sipName_address,
            sipName_port,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9t", &sipSelf, sipType_QBluetoothServer, &sipCpp, sipType_QBluetoothAddress, &a0, &a1))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->listen(*a0, a1);
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QBluetoothUuid* a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        ::QBluetoothServer *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_serviceName,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J1", &sipSelf, sipType_QBluetoothServer, &sipCpp, sipType_QBluetoothUuid, &a0, sipType_QString, &a1, &a1State))
        {
            ::QBluetoothServiceInfo*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = new ::QBluetoothServiceInfo(sipCpp->listen(*a0, *a1));
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QBluetoothServiceInfo, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_listen, doc_QBluetoothServer_listen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_isListening, "isListening(self) -> bool");

extern "C" {static PyObject *meth_QBluetoothServer_isListening(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_isListening(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isListening();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_isListening, doc_QBluetoothServer_isListening);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_setMaxPendingConnections, "setMaxPendingConnections(self, numConnections: int)");

extern "C" {static PyObject *meth_QBluetoothServer_setMaxPendingConnections(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_setMaxPendingConnections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QBluetoothServer, &sipCpp, &a0))
        {
            sipCpp->setMaxPendingConnections(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_setMaxPendingConnections, doc_QBluetoothServer_setMaxPendingConnections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_maxPendingConnections, "maxPendingConnections(self) -> int");

extern "C" {static PyObject *meth_QBluetoothServer_maxPendingConnections(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_maxPendingConnections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxPendingConnections();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_maxPendingConnections, doc_QBluetoothServer_maxPendingConnections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_hasPendingConnections, "hasPendingConnections(self) -> bool");

extern "C" {static PyObject *meth_QBluetoothServer_hasPendingConnections(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_hasPendingConnections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasPendingConnections();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_hasPendingConnections, doc_QBluetoothServer_hasPendingConnections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_nextPendingConnection, "nextPendingConnection(self) -> QBluetoothSocket|None");

extern "C" {static PyObject *meth_QBluetoothServer_nextPendingConnection(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_nextPendingConnection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServer, &sipCpp))
        {
            ::QBluetoothSocket*sipRes;

            sipRes = sipCpp->nextPendingConnection();

            return sipConvertFromType(sipRes, sipType_QBluetoothSocket, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_nextPendingConnection, doc_QBluetoothServer_nextPendingConnection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_serverAddress, "serverAddress(self) -> QBluetoothAddress");

extern "C" {static PyObject *meth_QBluetoothServer_serverAddress(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_serverAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServer, &sipCpp))
        {
            ::QBluetoothAddress*sipRes;

            sipRes = new ::QBluetoothAddress(sipCpp->serverAddress());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothAddress, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_serverAddress, doc_QBluetoothServer_serverAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_serverPort, "serverPort(self) -> int");

extern "C" {static PyObject *meth_QBluetoothServer_serverPort(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_serverPort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServer, &sipCpp))
        {
            ::quint16 sipRes;

            sipRes = sipCpp->serverPort();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_serverPort, doc_QBluetoothServer_serverPort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_setSecurityFlags, "setSecurityFlags(self, security: QBluetooth.Security)");

extern "C" {static PyObject *meth_QBluetoothServer_setSecurityFlags(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_setSecurityFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetooth::SecurityFlags* a0;
        int a0State = 0;
        ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QBluetoothServer, &sipCpp, sipType_QFlags_0100QBluetooth_Security, &a0, &a0State))
        {
            sipCpp->setSecurityFlags(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QBluetooth_Security, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_setSecurityFlags, doc_QBluetoothServer_setSecurityFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_securityFlags, "securityFlags(self) -> QBluetooth.Security");

extern "C" {static PyObject *meth_QBluetoothServer_securityFlags(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_securityFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServer, &sipCpp))
        {
            ::QBluetooth::SecurityFlags*sipRes;

            sipRes = new ::QBluetooth::SecurityFlags(sipCpp->securityFlags());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QBluetooth_Security, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_securityFlags, doc_QBluetoothServer_securityFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_serverType, "serverType(self) -> QBluetoothServiceInfo.Protocol");

extern "C" {static PyObject *meth_QBluetoothServer_serverType(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_serverType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServer, &sipCpp))
        {
            ::QBluetoothServiceInfo::Protocol sipRes;

            sipRes = sipCpp->serverType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QBluetoothServiceInfo_Protocol);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_serverType, doc_QBluetoothServer_serverType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothServer_error, "error(self) -> QBluetoothServer.Error");

extern "C" {static PyObject *meth_QBluetoothServer_error(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothServer_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothServer, &sipCpp))
        {
            ::QBluetoothServer::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QBluetoothServer_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothServer, sipName_error, doc_QBluetoothServer_error);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QBluetoothServer(void *, const sipTypeDef *);}
static void *cast_QBluetoothServer(void *sipCppV, const sipTypeDef *targetType)
{
    ::QBluetoothServer *sipCpp = reinterpret_cast< ::QBluetoothServer *>(sipCppV);

    if (targetType == sipType_QBluetoothServer)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QBluetoothServer(void *, int);}
static void release_QBluetoothServer(void *sipCppV, int)
{
    ::QBluetoothServer *sipCpp = reinterpret_cast< ::QBluetoothServer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QBluetoothServer(sipSimpleWrapper *);}
static void dealloc_QBluetoothServer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQBluetoothServer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QBluetoothServer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QBluetoothServer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QBluetoothServer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQBluetoothServer *sipCpp = SIP_NULLPTR;

    {
        ::QBluetoothServiceInfo::Protocol a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|JH", sipType_QBluetoothServiceInfo_Protocol, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQBluetoothServer(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QBluetoothServer[] = {{9, 0, 1}};


static PyMethodDef methods_QBluetoothServer[] = {
    {sipName_close, meth_QBluetoothServer_close, METH_VARARGS, doc_QBluetoothServer_close},
    {sipName_error, meth_QBluetoothServer_error, METH_VARARGS, doc_QBluetoothServer_error},
    {sipName_hasPendingConnections, meth_QBluetoothServer_hasPendingConnections, METH_VARARGS, doc_QBluetoothServer_hasPendingConnections},
    {sipName_isListening, meth_QBluetoothServer_isListening, METH_VARARGS, doc_QBluetoothServer_isListening},
    {sipName_listen, SIP_MLMETH_CAST(meth_QBluetoothServer_listen), METH_VARARGS|METH_KEYWORDS, doc_QBluetoothServer_listen},
    {sipName_maxPendingConnections, meth_QBluetoothServer_maxPendingConnections, METH_VARARGS, doc_QBluetoothServer_maxPendingConnections},
    {sipName_nextPendingConnection, meth_QBluetoothServer_nextPendingConnection, METH_VARARGS, doc_QBluetoothServer_nextPendingConnection},
    {sipName_securityFlags, meth_QBluetoothServer_securityFlags, METH_VARARGS, doc_QBluetoothServer_securityFlags},
    {sipName_serverAddress, meth_QBluetoothServer_serverAddress, METH_VARARGS, doc_QBluetoothServer_serverAddress},
    {sipName_serverPort, meth_QBluetoothServer_serverPort, METH_VARARGS, doc_QBluetoothServer_serverPort},
    {sipName_serverType, meth_QBluetoothServer_serverType, METH_VARARGS, doc_QBluetoothServer_serverType},
    {sipName_setMaxPendingConnections, meth_QBluetoothServer_setMaxPendingConnections, METH_VARARGS, doc_QBluetoothServer_setMaxPendingConnections},
    {sipName_setSecurityFlags, meth_QBluetoothServer_setSecurityFlags, METH_VARARGS, doc_QBluetoothServer_setSecurityFlags}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QBluetoothServer[] = {
    {sipName_NoError, static_cast<int>(::QBluetoothServer::NoError)},
    {sipName_UnknownError, static_cast<int>(::QBluetoothServer::UnknownError)},
    {sipName_PoweredOffError, static_cast<int>(::QBluetoothServer::PoweredOffError)},
    {sipName_InputOutputError, static_cast<int>(::QBluetoothServer::InputOutputError)},
    {sipName_ServiceAlreadyRegisteredError, static_cast<int>(::QBluetoothServer::ServiceAlreadyRegisteredError)},
    {sipName_UnsupportedProtocolError, static_cast<int>(::QBluetoothServer::UnsupportedProtocolError)},
    {sipName_MissingPermissionsError, static_cast<int>(::QBluetoothServer::MissingPermissionsError)},
    {0, 0}
};

PyDoc_STRVAR(doc_QBluetoothServer, "\1QBluetoothServer(serverType: QBluetoothServiceInfo.Protocol, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QBluetoothServer[] = {
    {"errorOccurred(QBluetoothServer::Error)", "\1errorOccurred(self, error: QBluetoothServer.Error)", SIP_NULLPTR, SIP_NULLPTR},
    {"newConnection()", "\1newConnection(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QBluetoothServer = {
    &::QBluetoothServer::staticMetaObject,
    signals_QBluetoothServer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothServer = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QBluetoothServer,
        SIP_NULLPTR,
        &plugin_QBluetoothServer,
    },
    {
        sipNameNr_QBluetoothServer,
        {0, 0, 1},
        13, methods_QBluetoothServer,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QBluetoothServer, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QBluetoothServer,
    -1,
    -1,
    supers_QBluetoothServer,
    SIP_NULLPTR,
    init_type_QBluetoothServer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QBluetoothServer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QBluetoothServer,
    cast_QBluetoothServer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QBluetoothServer),
};
