/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qfileselector.sip"
#include <qfileselector.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFileSelector.cpp"


class sipQFileSelector : public ::QFileSelector
{
public:
    sipQFileSelector(::QObject*);
    virtual ~sipQFileSelector();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQFileSelector(const sipQFileSelector &);
    sipQFileSelector &operator = (const sipQFileSelector &);

    char sipPyMethods[7];
};

sipQFileSelector::sipQFileSelector(::QObject*a0): ::QFileSelector(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQFileSelector::~sipQFileSelector()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQFileSelector::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtCore_qt_metaobject(sipPySelf, sipType_QFileSelector);

    return ::QFileSelector::metaObject();
}

int sipQFileSelector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QFileSelector::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtCore_qt_metacall(sipPySelf, sipType_QFileSelector, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQFileSelector::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtCore_qt_metacast(sipPySelf, sipType_QFileSelector, _clname, &sipCpp) ? sipCpp : ::QFileSelector::qt_metacast(_clname));
}

bool sipQFileSelector::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QFileSelector::event(a0);

    extern bool sipVH_QtCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtCore_0(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

bool sipQFileSelector::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QFileSelector::eventFilter(a0, a1);

    extern bool sipVH_QtCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtCore_1(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1);
}

void sipQFileSelector::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QFileSelector::timerEvent(a0);
        return;
    }

    extern void sipVH_QtCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtCore_2(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQFileSelector::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QFileSelector::childEvent(a0);
        return;
    }

    extern void sipVH_QtCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtCore_3(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQFileSelector::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QFileSelector::customEvent(a0);
        return;
    }

    extern void sipVH_QtCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtCore_4(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQFileSelector::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QFileSelector::connectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQFileSelector::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QFileSelector::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QFileSelector_select, "select(self, filePath: str|None) -> str\n"
"select(self, filePath: QUrl) -> QUrl");

extern "C" {static PyObject *meth_QFileSelector_select(PyObject *, PyObject *);}
static PyObject *meth_QFileSelector_select(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QFileSelector *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFileSelector, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->select(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QUrl* a0;
        const ::QFileSelector *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QFileSelector, &sipCpp, sipType_QUrl, &a0))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->select(*a0));

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFileSelector, sipName_select, doc_QFileSelector_select);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFileSelector_extraSelectors, "extraSelectors(self) -> list[str]");

extern "C" {static PyObject *meth_QFileSelector_extraSelectors(PyObject *, PyObject *);}
static PyObject *meth_QFileSelector_extraSelectors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFileSelector *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFileSelector, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->extraSelectors());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFileSelector, sipName_extraSelectors, doc_QFileSelector_extraSelectors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFileSelector_setExtraSelectors, "setExtraSelectors(self, list: Iterable[str|None])");

extern "C" {static PyObject *meth_QFileSelector_setExtraSelectors(PyObject *, PyObject *);}
static PyObject *meth_QFileSelector_setExtraSelectors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QFileSelector *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFileSelector, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setExtraSelectors(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QFileSelector, sipName_setExtraSelectors, doc_QFileSelector_setExtraSelectors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFileSelector_allSelectors, "allSelectors(self) -> list[str]");

extern "C" {static PyObject *meth_QFileSelector_allSelectors(PyObject *, PyObject *);}
static PyObject *meth_QFileSelector_allSelectors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFileSelector *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFileSelector, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->allSelectors());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFileSelector, sipName_allSelectors, doc_QFileSelector_allSelectors);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QFileSelector(void *, const sipTypeDef *);}
static void *cast_QFileSelector(void *sipCppV, const sipTypeDef *targetType)
{
    ::QFileSelector *sipCpp = reinterpret_cast< ::QFileSelector *>(sipCppV);

    if (targetType == sipType_QFileSelector)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QFileSelector(void *, int);}
static void release_QFileSelector(void *sipCppV, int)
{
    ::QFileSelector *sipCpp = reinterpret_cast< ::QFileSelector *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QFileSelector(Py_ssize_t);}
static void *array_QFileSelector(Py_ssize_t sipNrElem)
{
    return new ::QFileSelector[sipNrElem];
}


extern "C" {static void array_delete_QFileSelector(void *);}
static void array_delete_QFileSelector(void *sipCpp)
{
    delete[] reinterpret_cast< ::QFileSelector *>(sipCpp);
}


extern "C" {static void dealloc_QFileSelector(sipSimpleWrapper *);}
static void dealloc_QFileSelector(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQFileSelector *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QFileSelector(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QFileSelector(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QFileSelector(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQFileSelector *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQFileSelector(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QFileSelector[] = {{255, 255, 1}};


static PyMethodDef methods_QFileSelector[] = {
    {sipName_allSelectors, meth_QFileSelector_allSelectors, METH_VARARGS, doc_QFileSelector_allSelectors},
    {sipName_extraSelectors, meth_QFileSelector_extraSelectors, METH_VARARGS, doc_QFileSelector_extraSelectors},
    {sipName_select, meth_QFileSelector_select, METH_VARARGS, doc_QFileSelector_select},
    {sipName_setExtraSelectors, meth_QFileSelector_setExtraSelectors, METH_VARARGS, doc_QFileSelector_setExtraSelectors}
};

PyDoc_STRVAR(doc_QFileSelector, "\1QFileSelector(parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QFileSelector = {
    &::QFileSelector::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QFileSelector = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QFileSelector,
        SIP_NULLPTR,
        &plugin_QFileSelector,
    },
    {
        sipNameNr_QFileSelector,
        {0, 0, 1},
        4, methods_QFileSelector,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QFileSelector,
    -1,
    -1,
    supers_QFileSelector,
    SIP_NULLPTR,
    init_type_QFileSelector,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QFileSelector,
    SIP_NULLPTR,
    array_QFileSelector,
    SIP_NULLPTR,
    release_QFileSelector,
    cast_QFileSelector,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QFileSelector,
    sizeof (::QFileSelector),
};
