/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickitemgrabresult.sip"
#include <qquickitemgrabresult.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qimage.sip"
#include <qimage.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickItemGrabResult.cpp"


PyDoc_STRVAR(doc_QQuickItemGrabResult_image, "image(self) -> QImage");

extern "C" {static PyObject *meth_QQuickItemGrabResult_image(PyObject *, PyObject *);}
static PyObject *meth_QQuickItemGrabResult_image(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickItemGrabResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickItemGrabResult, &sipCpp))
        {
            ::QImage*sipRes;

            sipRes = new ::QImage(sipCpp->image());

            return sipConvertFromNewType(sipRes, sipType_QImage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickItemGrabResult, sipName_image, doc_QQuickItemGrabResult_image);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickItemGrabResult_url, "url(self) -> QUrl");

extern "C" {static PyObject *meth_QQuickItemGrabResult_url(PyObject *, PyObject *);}
static PyObject *meth_QQuickItemGrabResult_url(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickItemGrabResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickItemGrabResult, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->url());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickItemGrabResult, sipName_url, doc_QQuickItemGrabResult_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickItemGrabResult_saveToFile, "saveToFile(self, fileName: str|None) -> bool\n"
"saveToFile(self, fileName: QUrl) -> bool");

extern "C" {static PyObject *meth_QQuickItemGrabResult_saveToFile(PyObject *, PyObject *);}
static PyObject *meth_QQuickItemGrabResult_saveToFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QQuickItemGrabResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQuickItemGrabResult, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->saveToFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QUrl* a0;
        const ::QQuickItemGrabResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QQuickItemGrabResult, &sipCpp, sipType_QUrl, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->saveToFile(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickItemGrabResult, sipName_saveToFile, doc_QQuickItemGrabResult_saveToFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickItemGrabResult_event, "event(self, a0: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QQuickItemGrabResult_event(PyObject *, PyObject *);}
static PyObject *meth_QQuickItemGrabResult_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QQuickItemGrabResult)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QQuickItemGrabResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QQuickItemGrabResult, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QQuickItemGrabResult::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickItemGrabResult, sipName_event, doc_QQuickItemGrabResult_event);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQuickItemGrabResult(void *, const sipTypeDef *);}
static void *cast_QQuickItemGrabResult(void *sipCppV, const sipTypeDef *targetType)
{
    ::QQuickItemGrabResult *sipCpp = reinterpret_cast< ::QQuickItemGrabResult *>(sipCppV);

    if (targetType == sipType_QQuickItemGrabResult)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQuickItemGrabResult(void *, int);}
static void release_QQuickItemGrabResult(void *sipCppV, int)
{
    ::QQuickItemGrabResult *sipCpp = reinterpret_cast< ::QQuickItemGrabResult *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QQuickItemGrabResult(sipSimpleWrapper *);}
static void dealloc_QQuickItemGrabResult(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuickItemGrabResult(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQuickItemGrabResult[] = {{11, 0, 1}};


static PyMethodDef methods_QQuickItemGrabResult[] = {
    {sipName_event, meth_QQuickItemGrabResult_event, METH_VARARGS, doc_QQuickItemGrabResult_event},
    {sipName_image, meth_QQuickItemGrabResult_image, METH_VARARGS, doc_QQuickItemGrabResult_image},
    {sipName_saveToFile, meth_QQuickItemGrabResult_saveToFile, METH_VARARGS, doc_QQuickItemGrabResult_saveToFile},
    {sipName_url, meth_QQuickItemGrabResult_url, METH_VARARGS, doc_QQuickItemGrabResult_url}
};


/* Define this type's signals. */
static const pyqt6QtSignal signals_QQuickItemGrabResult[] = {
    {"ready()", "\1ready(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QQuickItemGrabResult = {
    &::QQuickItemGrabResult::staticMetaObject,
    signals_QQuickItemGrabResult,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QQuickItemGrabResult = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuickItemGrabResult,
        SIP_NULLPTR,
        &plugin_QQuickItemGrabResult,
    },
    {
        sipNameNr_QQuickItemGrabResult,
        {0, 0, 1},
        4, methods_QQuickItemGrabResult,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QQuickItemGrabResult,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuickItemGrabResult,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQuickItemGrabResult,
    cast_QQuickItemGrabResult,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
