/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/membersheet.sip"
#include <membersheet.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerMemberSheetExtension.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerMemberSheetExtension.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerMemberSheetExtension.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerMemberSheetExtension.cpp"


class sipQDesignerMemberSheetExtension : public ::QDesignerMemberSheetExtension
{
public:
    sipQDesignerMemberSheetExtension();
    virtual ~sipQDesignerMemberSheetExtension();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    QList< ::QByteArray> parameterNames(int) const SIP_OVERRIDE;
    QList< ::QByteArray> parameterTypes(int) const SIP_OVERRIDE;
    ::QString signature(int) const SIP_OVERRIDE;
    ::QString declaredInClass(int) const SIP_OVERRIDE;
    bool inheritedFromWidget(int) const SIP_OVERRIDE;
    bool isSlot(int) const SIP_OVERRIDE;
    bool isSignal(int) const SIP_OVERRIDE;
    void setVisible(int, bool) SIP_OVERRIDE;
    bool isVisible(int) const SIP_OVERRIDE;
    void setMemberGroup(int, const ::QString&) SIP_OVERRIDE;
    ::QString memberGroup(int) const SIP_OVERRIDE;
    ::QString memberName(int) const SIP_OVERRIDE;
    int indexOf(const ::QString&) const SIP_OVERRIDE;
    int count() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQDesignerMemberSheetExtension(const sipQDesignerMemberSheetExtension &);
    sipQDesignerMemberSheetExtension &operator = (const sipQDesignerMemberSheetExtension &);

    char sipPyMethods[14];
};

sipQDesignerMemberSheetExtension::sipQDesignerMemberSheetExtension(): ::QDesignerMemberSheetExtension(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQDesignerMemberSheetExtension::~sipQDesignerMemberSheetExtension()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

QList< ::QByteArray> sipQDesignerMemberSheetExtension::parameterNames(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_parameterNames);

    if (!sipMeth)
        return QList< ::QByteArray>();

    extern QList< ::QByteArray> sipVH_QtDesigner_92(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_92(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

QList< ::QByteArray> sipQDesignerMemberSheetExtension::parameterTypes(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_parameterTypes);

    if (!sipMeth)
        return QList< ::QByteArray>();

    extern QList< ::QByteArray> sipVH_QtDesigner_92(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_92(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQDesignerMemberSheetExtension::signature(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_signature);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_89(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_89(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQDesignerMemberSheetExtension::declaredInClass(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_declaredInClass);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_89(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_89(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQDesignerMemberSheetExtension::inheritedFromWidget(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_inheritedFromWidget);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQDesignerMemberSheetExtension::isSlot(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_isSlot);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQDesignerMemberSheetExtension::isSignal(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_isSignal);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerMemberSheetExtension::setVisible(int a0, bool a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, sipName_QDesignerMemberSheetExtension, sipName_setVisible);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, bool);

    sipVH_QtDesigner_91(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQDesignerMemberSheetExtension::isVisible(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_isVisible);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerMemberSheetExtension::setMemberGroup(int a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, sipName_QDesignerMemberSheetExtension, sipName_setMemberGroup);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_90(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, const ::QString&);

    sipVH_QtDesigner_90(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QString sipQDesignerMemberSheetExtension::memberGroup(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_memberGroup);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_89(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_89(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQDesignerMemberSheetExtension::memberName(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_memberName);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_89(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_89(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQDesignerMemberSheetExtension::indexOf(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_indexOf);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtDesigner_88(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtDesigner_88(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQDesignerMemberSheetExtension::count() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerMemberSheetExtension, sipName_count);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtDesigner_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_29(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_count, "count(self) -> int");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_count(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_count);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_count, doc_QDesignerMemberSheetExtension_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_indexOf, "indexOf(self, name: str|None) -> int");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_indexOf(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_indexOf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_indexOf);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->indexOf(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_indexOf, doc_QDesignerMemberSheetExtension_indexOf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_memberName, "memberName(self, index: int) -> str");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_memberName(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_memberName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_memberName);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->memberName(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_memberName, doc_QDesignerMemberSheetExtension_memberName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_memberGroup, "memberGroup(self, index: int) -> str");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_memberGroup(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_memberGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_memberGroup);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->memberGroup(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_memberGroup, doc_QDesignerMemberSheetExtension_memberGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_setMemberGroup, "setMemberGroup(self, index: int, group: str|None)");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_setMemberGroup(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_setMemberGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QString* a1;
        int a1State = 0;
        ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0, sipType_QString, &a1, &a1State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_setMemberGroup);
                return SIP_NULLPTR;
            }

            sipCpp->setMemberGroup(a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_setMemberGroup, doc_QDesignerMemberSheetExtension_setMemberGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_isVisible, "isVisible(self, index: int) -> bool");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_isVisible(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_isVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_isVisible);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isVisible(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_isVisible, doc_QDesignerMemberSheetExtension_isVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_setVisible, "setVisible(self, index: int, b: bool)");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_setVisible(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_setVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        bool a1;
        ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bib", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0, &a1))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_setVisible);
                return SIP_NULLPTR;
            }

            sipCpp->setVisible(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_setVisible, doc_QDesignerMemberSheetExtension_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_isSignal, "isSignal(self, index: int) -> bool");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_isSignal(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_isSignal(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_isSignal);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isSignal(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_isSignal, doc_QDesignerMemberSheetExtension_isSignal);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_isSlot, "isSlot(self, index: int) -> bool");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_isSlot(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_isSlot(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_isSlot);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isSlot(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_isSlot, doc_QDesignerMemberSheetExtension_isSlot);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_inheritedFromWidget, "inheritedFromWidget(self, index: int) -> bool");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_inheritedFromWidget(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_inheritedFromWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_inheritedFromWidget);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->inheritedFromWidget(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_inheritedFromWidget, doc_QDesignerMemberSheetExtension_inheritedFromWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_declaredInClass, "declaredInClass(self, index: int) -> str");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_declaredInClass(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_declaredInClass(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_declaredInClass);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->declaredInClass(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_declaredInClass, doc_QDesignerMemberSheetExtension_declaredInClass);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_signature, "signature(self, index: int) -> str");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_signature(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_signature(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_signature);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->signature(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_signature, doc_QDesignerMemberSheetExtension_signature);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_parameterTypes, "parameterTypes(self, index: int) -> list[QByteArray]");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_parameterTypes(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_parameterTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0))
        {
            QList< ::QByteArray>*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_parameterTypes);
                return SIP_NULLPTR;
            }

            sipRes = new QList< ::QByteArray>(sipCpp->parameterTypes(a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_parameterTypes, doc_QDesignerMemberSheetExtension_parameterTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerMemberSheetExtension_parameterNames, "parameterNames(self, index: int) -> list[QByteArray]");

extern "C" {static PyObject *meth_QDesignerMemberSheetExtension_parameterNames(PyObject *, PyObject *);}
static PyObject *meth_QDesignerMemberSheetExtension_parameterNames(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerMemberSheetExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerMemberSheetExtension, &sipCpp, &a0))
        {
            QList< ::QByteArray>*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerMemberSheetExtension, sipName_parameterNames);
                return SIP_NULLPTR;
            }

            sipRes = new QList< ::QByteArray>(sipCpp->parameterNames(a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerMemberSheetExtension, sipName_parameterNames, doc_QDesignerMemberSheetExtension_parameterNames);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QDesignerMemberSheetExtension___len__(PyObject *);}
static Py_ssize_t slot_QDesignerMemberSheetExtension___len__(PyObject *sipSelf)
{
    ::QDesignerMemberSheetExtension *sipCpp = reinterpret_cast< ::QDesignerMemberSheetExtension *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QDesignerMemberSheetExtension));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 793 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerMemberSheetExtension.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDesignerMemberSheetExtension(void *, int);}
static void release_QDesignerMemberSheetExtension(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQDesignerMemberSheetExtension *>(sipCppV);
    else
        delete reinterpret_cast< ::QDesignerMemberSheetExtension *>(sipCppV);
}


extern "C" {static void dealloc_QDesignerMemberSheetExtension(sipSimpleWrapper *);}
static void dealloc_QDesignerMemberSheetExtension(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQDesignerMemberSheetExtension *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDesignerMemberSheetExtension(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QDesignerMemberSheetExtension(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDesignerMemberSheetExtension(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQDesignerMemberSheetExtension *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQDesignerMemberSheetExtension();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QDesignerMemberSheetExtension[] = {
    {(void *)slot_QDesignerMemberSheetExtension___len__, len_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QDesignerMemberSheetExtension[] = {
    {sipName_count, meth_QDesignerMemberSheetExtension_count, METH_VARARGS, doc_QDesignerMemberSheetExtension_count},
    {sipName_declaredInClass, meth_QDesignerMemberSheetExtension_declaredInClass, METH_VARARGS, doc_QDesignerMemberSheetExtension_declaredInClass},
    {sipName_indexOf, meth_QDesignerMemberSheetExtension_indexOf, METH_VARARGS, doc_QDesignerMemberSheetExtension_indexOf},
    {sipName_inheritedFromWidget, meth_QDesignerMemberSheetExtension_inheritedFromWidget, METH_VARARGS, doc_QDesignerMemberSheetExtension_inheritedFromWidget},
    {sipName_isSignal, meth_QDesignerMemberSheetExtension_isSignal, METH_VARARGS, doc_QDesignerMemberSheetExtension_isSignal},
    {sipName_isSlot, meth_QDesignerMemberSheetExtension_isSlot, METH_VARARGS, doc_QDesignerMemberSheetExtension_isSlot},
    {sipName_isVisible, meth_QDesignerMemberSheetExtension_isVisible, METH_VARARGS, doc_QDesignerMemberSheetExtension_isVisible},
    {sipName_memberGroup, meth_QDesignerMemberSheetExtension_memberGroup, METH_VARARGS, doc_QDesignerMemberSheetExtension_memberGroup},
    {sipName_memberName, meth_QDesignerMemberSheetExtension_memberName, METH_VARARGS, doc_QDesignerMemberSheetExtension_memberName},
    {sipName_parameterNames, meth_QDesignerMemberSheetExtension_parameterNames, METH_VARARGS, doc_QDesignerMemberSheetExtension_parameterNames},
    {sipName_parameterTypes, meth_QDesignerMemberSheetExtension_parameterTypes, METH_VARARGS, doc_QDesignerMemberSheetExtension_parameterTypes},
    {sipName_setMemberGroup, meth_QDesignerMemberSheetExtension_setMemberGroup, METH_VARARGS, doc_QDesignerMemberSheetExtension_setMemberGroup},
    {sipName_setVisible, meth_QDesignerMemberSheetExtension_setVisible, METH_VARARGS, doc_QDesignerMemberSheetExtension_setVisible},
    {sipName_signature, meth_QDesignerMemberSheetExtension_signature, METH_VARARGS, doc_QDesignerMemberSheetExtension_signature}
};

PyDoc_STRVAR(doc_QDesignerMemberSheetExtension, "\1QDesignerMemberSheetExtension()");


sipClassTypeDef sipTypeDef_QtDesigner_QDesignerMemberSheetExtension = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDesignerMemberSheetExtension,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QDesignerMemberSheetExtension,
        {0, 0, 1},
        14, methods_QDesignerMemberSheetExtension,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDesignerMemberSheetExtension,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QDesignerMemberSheetExtension,
    init_type_QDesignerMemberSheetExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDesignerMemberSheetExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QDesignerMemberSheetExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QDesignerMemberSheetExtension),
};
