/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtRemoteObjects.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectnode.sip"
#include <qremoteobjectnode.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectAbstractPersistedStore.cpp"


class sipQRemoteObjectAbstractPersistedStore : public ::QRemoteObjectAbstractPersistedStore
{
public:
    sipQRemoteObjectAbstractPersistedStore(::QObject*);
    virtual ~sipQRemoteObjectAbstractPersistedStore();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QVariantList restoreProperties(const ::QString&, const ::QByteArray&) SIP_OVERRIDE;
    void saveProperties(const ::QString&, const ::QByteArray&, const ::QVariantList&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQRemoteObjectAbstractPersistedStore(const sipQRemoteObjectAbstractPersistedStore &);
    sipQRemoteObjectAbstractPersistedStore &operator = (const sipQRemoteObjectAbstractPersistedStore &);

    char sipPyMethods[9];
};

sipQRemoteObjectAbstractPersistedStore::sipQRemoteObjectAbstractPersistedStore(::QObject*a0): ::QRemoteObjectAbstractPersistedStore(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQRemoteObjectAbstractPersistedStore::~sipQRemoteObjectAbstractPersistedStore()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQRemoteObjectAbstractPersistedStore::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtRemoteObjects_qt_metaobject(sipPySelf, sipType_QRemoteObjectAbstractPersistedStore);

    return ::QRemoteObjectAbstractPersistedStore::metaObject();
}

int sipQRemoteObjectAbstractPersistedStore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QRemoteObjectAbstractPersistedStore::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtRemoteObjects_qt_metacall(sipPySelf, sipType_QRemoteObjectAbstractPersistedStore, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQRemoteObjectAbstractPersistedStore::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtRemoteObjects_qt_metacast(sipPySelf, sipType_QRemoteObjectAbstractPersistedStore, _clname, &sipCpp) ? sipCpp : ::QRemoteObjectAbstractPersistedStore::qt_metacast(_clname));
}

::QVariantList sipQRemoteObjectAbstractPersistedStore::restoreProperties(const ::QString& a0, const ::QByteArray& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QRemoteObjectAbstractPersistedStore, sipName_restoreProperties);

    if (!sipMeth)
        return ::QVariantList();

    extern ::QVariantList sipVH_QtRemoteObjects_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, const ::QByteArray&);

    return sipVH_QtRemoteObjects_33(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQRemoteObjectAbstractPersistedStore::saveProperties(const ::QString& a0, const ::QByteArray& a1, const ::QVariantList& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, sipName_QRemoteObjectAbstractPersistedStore, sipName_saveProperties);

    if (!sipMeth)
        return;

    extern void sipVH_QtRemoteObjects_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, const ::QByteArray&, const ::QVariantList&);

    sipVH_QtRemoteObjects_32(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQRemoteObjectAbstractPersistedStore::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QRemoteObjectAbstractPersistedStore::event(a0);

    extern bool sipVH_QtRemoteObjects_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtRemoteObjects_25(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRemoteObjectAbstractPersistedStore::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QRemoteObjectAbstractPersistedStore::eventFilter(a0, a1);

    extern bool sipVH_QtRemoteObjects_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtRemoteObjects_26(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQRemoteObjectAbstractPersistedStore::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QRemoteObjectAbstractPersistedStore::timerEvent(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtRemoteObjects_27(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectAbstractPersistedStore::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QRemoteObjectAbstractPersistedStore::childEvent(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtRemoteObjects_28(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectAbstractPersistedStore::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QRemoteObjectAbstractPersistedStore::customEvent(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtRemoteObjects_29(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectAbstractPersistedStore::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QRemoteObjectAbstractPersistedStore::connectNotify(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtRemoteObjects_30(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectAbstractPersistedStore::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QRemoteObjectAbstractPersistedStore::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtRemoteObjects_30(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QRemoteObjectAbstractPersistedStore_saveProperties, "saveProperties(self, repName: str|None, repSig: QByteArray|bytes|bytearray|memoryview, values: Iterable[Any])");

extern "C" {static PyObject *meth_QRemoteObjectAbstractPersistedStore_saveProperties(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectAbstractPersistedStore_saveProperties(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QByteArray* a1;
        int a1State = 0;
        const ::QVariantList* a2;
        int a2State = 0;
        ::QRemoteObjectAbstractPersistedStore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1J1", &sipSelf, sipType_QRemoteObjectAbstractPersistedStore, &sipCpp, sipType_QString, &a0, &a0State, sipType_QByteArray, &a1, &a1State, sipType_QList_0100QVariant, &a2, &a2State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRemoteObjectAbstractPersistedStore, sipName_saveProperties);
                return SIP_NULLPTR;
            }

            sipCpp->saveProperties(*a0, *a1, *a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);
            sipReleaseType(const_cast< ::QVariantList *>(a2), sipType_QList_0100QVariant, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectAbstractPersistedStore, sipName_saveProperties, doc_QRemoteObjectAbstractPersistedStore_saveProperties);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectAbstractPersistedStore_restoreProperties, "restoreProperties(self, repName: str|None, repSig: QByteArray|bytes|bytearray|memoryview) -> list[Any]");

extern "C" {static PyObject *meth_QRemoteObjectAbstractPersistedStore_restoreProperties(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectAbstractPersistedStore_restoreProperties(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QRemoteObjectAbstractPersistedStore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QRemoteObjectAbstractPersistedStore, &sipCpp, sipType_QString, &a0, &a0State, sipType_QByteArray, &a1, &a1State))
        {
            ::QVariantList*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRemoteObjectAbstractPersistedStore, sipName_restoreProperties);
                return SIP_NULLPTR;
            }

            sipRes = new ::QVariantList(sipCpp->restoreProperties(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectAbstractPersistedStore, sipName_restoreProperties, doc_QRemoteObjectAbstractPersistedStore_restoreProperties);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRemoteObjectAbstractPersistedStore(void *, const sipTypeDef *);}
static void *cast_QRemoteObjectAbstractPersistedStore(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRemoteObjectAbstractPersistedStore *sipCpp = reinterpret_cast< ::QRemoteObjectAbstractPersistedStore *>(sipCppV);

    if (targetType == sipType_QRemoteObjectAbstractPersistedStore)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRemoteObjectAbstractPersistedStore(void *, int);}
static void release_QRemoteObjectAbstractPersistedStore(void *sipCppV, int)
{
    ::QRemoteObjectAbstractPersistedStore *sipCpp = reinterpret_cast< ::QRemoteObjectAbstractPersistedStore *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QRemoteObjectAbstractPersistedStore(sipSimpleWrapper *);}
static void dealloc_QRemoteObjectAbstractPersistedStore(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQRemoteObjectAbstractPersistedStore *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRemoteObjectAbstractPersistedStore(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QRemoteObjectAbstractPersistedStore(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QRemoteObjectAbstractPersistedStore(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQRemoteObjectAbstractPersistedStore *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQRemoteObjectAbstractPersistedStore(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRemoteObjectAbstractPersistedStore[] = {{19, 0, 1}};


static PyMethodDef methods_QRemoteObjectAbstractPersistedStore[] = {
    {sipName_restoreProperties, meth_QRemoteObjectAbstractPersistedStore_restoreProperties, METH_VARARGS, doc_QRemoteObjectAbstractPersistedStore_restoreProperties},
    {sipName_saveProperties, meth_QRemoteObjectAbstractPersistedStore_saveProperties, METH_VARARGS, doc_QRemoteObjectAbstractPersistedStore_saveProperties}
};

PyDoc_STRVAR(doc_QRemoteObjectAbstractPersistedStore, "\1QRemoteObjectAbstractPersistedStore(parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QRemoteObjectAbstractPersistedStore = {
    &::QRemoteObjectAbstractPersistedStore::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectAbstractPersistedStore = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRemoteObjectAbstractPersistedStore,
        SIP_NULLPTR,
        &plugin_QRemoteObjectAbstractPersistedStore,
    },
    {
        sipNameNr_QRemoteObjectAbstractPersistedStore,
        {0, 0, 1},
        2, methods_QRemoteObjectAbstractPersistedStore,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QRemoteObjectAbstractPersistedStore,
    -1,
    -1,
    supers_QRemoteObjectAbstractPersistedStore,
    SIP_NULLPTR,
    init_type_QRemoteObjectAbstractPersistedStore,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRemoteObjectAbstractPersistedStore,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QRemoteObjectAbstractPersistedStore,
    cast_QRemoteObjectAbstractPersistedStore,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QRemoteObjectAbstractPersistedStore),
};
