/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtRemoteObjects.h"

#line 190 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectnode.sip"
#include <qremoteobjectnode.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 789 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectnode.sip"
#include <qremoteobjectnode.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_std_pair.sip"
#include <utility>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qtremoteobjectglobal.sip"
#include <qtremoteobjectglobal.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectnode.sip"
#include <qremoteobjectnode.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectregistry.sip"
#include <qremoteobjectregistry.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectabstractitemmodelreplica.sip"
#include <qremoteobjectabstractitemmodelreplica.h>
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qtremoteobjectglobal.sip"
#include <qtremoteobjectglobal.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectdynamicreplica.sip"
#include <qremoteobjectdynamicreplica.h>
#line 78 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringview.sip"
#include <qstringview.h>
#line 84 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 118 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 124 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 127 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 130 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistryHost.cpp"


class sipQRemoteObjectRegistryHost : public ::QRemoteObjectRegistryHost
{
public:
    sipQRemoteObjectRegistryHost(const ::QUrl&, ::QObject*);
    virtual ~sipQRemoteObjectRegistryHost();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool setRegistryUrl(const ::QUrl&) SIP_OVERRIDE;
    void setName(const ::QString&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQRemoteObjectRegistryHost(const sipQRemoteObjectRegistryHost &);
    sipQRemoteObjectRegistryHost &operator = (const sipQRemoteObjectRegistryHost &);

    char sipPyMethods[9];
};

sipQRemoteObjectRegistryHost::sipQRemoteObjectRegistryHost(const ::QUrl& a0, ::QObject*a1): ::QRemoteObjectRegistryHost(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQRemoteObjectRegistryHost::~sipQRemoteObjectRegistryHost()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQRemoteObjectRegistryHost::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtRemoteObjects_qt_metaobject(sipPySelf, sipType_QRemoteObjectRegistryHost);

    return ::QRemoteObjectRegistryHost::metaObject();
}

int sipQRemoteObjectRegistryHost::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QRemoteObjectRegistryHost::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtRemoteObjects_qt_metacall(sipPySelf, sipType_QRemoteObjectRegistryHost, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQRemoteObjectRegistryHost::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtRemoteObjects_qt_metacast(sipPySelf, sipType_QRemoteObjectRegistryHost, _clname, &sipCpp) ? sipCpp : ::QRemoteObjectRegistryHost::qt_metacast(_clname));
}

bool sipQRemoteObjectRegistryHost::setRegistryUrl(const ::QUrl& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_setRegistryUrl);

    if (!sipMeth)
        return ::QRemoteObjectRegistryHost::setRegistryUrl(a0);

    extern bool sipVH_QtRemoteObjects_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QUrl&);

    return sipVH_QtRemoteObjects_35(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectRegistryHost::setName(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_setName);

    if (!sipMeth)
    {
        ::QRemoteObjectRegistryHost::setName(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    sipVH_QtRemoteObjects_34(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRemoteObjectRegistryHost::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QRemoteObjectRegistryHost::event(a0);

    extern bool sipVH_QtRemoteObjects_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtRemoteObjects_25(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRemoteObjectRegistryHost::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QRemoteObjectRegistryHost::eventFilter(a0, a1);

    extern bool sipVH_QtRemoteObjects_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtRemoteObjects_26(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQRemoteObjectRegistryHost::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QRemoteObjectRegistryHost::timerEvent(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtRemoteObjects_27(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectRegistryHost::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QRemoteObjectRegistryHost::childEvent(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtRemoteObjects_28(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectRegistryHost::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QRemoteObjectRegistryHost::customEvent(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtRemoteObjects_29(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectRegistryHost::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QRemoteObjectRegistryHost::connectNotify(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtRemoteObjects_30(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRemoteObjectRegistryHost::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QRemoteObjectRegistryHost::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtRemoteObjects_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtRemoteObjects_30(sipGILState, sipImportedVirtErrorHandlers_QtRemoteObjects_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QRemoteObjectRegistryHost_setRegistryUrl, "setRegistryUrl(self, registryUrl: QUrl) -> bool");

extern "C" {static PyObject *meth_QRemoteObjectRegistryHost_setRegistryUrl(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectRegistryHost_setRegistryUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRemoteObjectRegistryHost)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QUrl* a0;
        ::QRemoteObjectRegistryHost *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QRemoteObjectRegistryHost, &sipCpp, sipType_QUrl, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRemoteObjectRegistryHost::setRegistryUrl(*a0) : sipCpp->setRegistryUrl(*a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectRegistryHost, sipName_setRegistryUrl, doc_QRemoteObjectRegistryHost_setRegistryUrl);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRemoteObjectRegistryHost(void *, const sipTypeDef *);}
static void *cast_QRemoteObjectRegistryHost(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRemoteObjectRegistryHost *sipCpp = reinterpret_cast< ::QRemoteObjectRegistryHost *>(sipCppV);

    if (targetType == sipType_QRemoteObjectRegistryHost)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QRemoteObjectHostBase)->ctd_cast(static_cast< ::QRemoteObjectHostBase *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRemoteObjectRegistryHost(void *, int);}
static void release_QRemoteObjectRegistryHost(void *sipCppV, int)
{
    ::QRemoteObjectRegistryHost *sipCpp = reinterpret_cast< ::QRemoteObjectRegistryHost *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QRemoteObjectRegistryHost(Py_ssize_t);}
static void *array_QRemoteObjectRegistryHost(Py_ssize_t sipNrElem)
{
    return new ::QRemoteObjectRegistryHost[sipNrElem];
}


extern "C" {static void array_delete_QRemoteObjectRegistryHost(void *);}
static void array_delete_QRemoteObjectRegistryHost(void *sipCpp)
{
    delete[] reinterpret_cast< ::QRemoteObjectRegistryHost *>(sipCpp);
}


extern "C" {static void dealloc_QRemoteObjectRegistryHost(sipSimpleWrapper *);}
static void dealloc_QRemoteObjectRegistryHost(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQRemoteObjectRegistryHost *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRemoteObjectRegistryHost(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QRemoteObjectRegistryHost(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QRemoteObjectRegistryHost(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQRemoteObjectRegistryHost *sipCpp = SIP_NULLPTR;

    {
        const ::QUrl& a0def = QUrl();
        const ::QUrl* a0 = &a0def;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            sipName_registryAddress,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|J9JH", sipType_QUrl, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQRemoteObjectRegistryHost(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRemoteObjectRegistryHost[] = {{5, 255, 1}};


static PyMethodDef methods_QRemoteObjectRegistryHost[] = {
    {sipName_setRegistryUrl, meth_QRemoteObjectRegistryHost_setRegistryUrl, METH_VARARGS, doc_QRemoteObjectRegistryHost_setRegistryUrl}
};

PyDoc_STRVAR(doc_QRemoteObjectRegistryHost, "\1QRemoteObjectRegistryHost(registryAddress: QUrl = QUrl(), parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QRemoteObjectRegistryHost = {
    &::QRemoteObjectRegistryHost::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectRegistryHost = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRemoteObjectRegistryHost,
        SIP_NULLPTR,
        &plugin_QRemoteObjectRegistryHost,
    },
    {
        sipNameNr_QRemoteObjectRegistryHost,
        {0, 0, 1},
        1, methods_QRemoteObjectRegistryHost,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QRemoteObjectRegistryHost,
    -1,
    -1,
    supers_QRemoteObjectRegistryHost,
    SIP_NULLPTR,
    init_type_QRemoteObjectRegistryHost,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRemoteObjectRegistryHost,
    SIP_NULLPTR,
    array_QRemoteObjectRegistryHost,
    SIP_NULLPTR,
    release_QRemoteObjectRegistryHost,
    cast_QRemoteObjectRegistryHost,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QRemoteObjectRegistryHost,
    sizeof (::QRemoteObjectRegistryHost),
};
