/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlcdnumber.sip"
#include <qlcdnumber.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qframe.sip"
#include <qframe.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 215 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 223 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 226 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 229 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 232 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 235 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 238 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 241 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 244 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 247 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 250 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 253 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 256 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"


class sipQLCDNumber : public ::QLCDNumber
{
public:
    sipQLCDNumber(::QWidget*);
    sipQLCDNumber(::uint, ::QWidget*);
    virtual ~sipQLCDNumber();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void initPainter(::QPainter*) const SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void enterEvent(::QEnterEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void initStyleOption(::QStyleOptionFrame*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQLCDNumber(const sipQLCDNumber &);
    sipQLCDNumber &operator = (const sipQLCDNumber &);

    char sipPyMethods[47];
};

sipQLCDNumber::sipQLCDNumber(::QWidget*a0): ::QLCDNumber(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQLCDNumber::sipQLCDNumber(::uint a0, ::QWidget*a1): ::QLCDNumber(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQLCDNumber::~sipQLCDNumber()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQLCDNumber::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QLCDNumber);

    return ::QLCDNumber::metaObject();
}

int sipQLCDNumber::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QLCDNumber::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QLCDNumber, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQLCDNumber::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QLCDNumber, _clname, &sipCpp) ? sipCpp : ::QLCDNumber::qt_metacast(_clname));
}

void sipQLCDNumber::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QLCDNumber::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPainter* sipQLCDNumber::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QLCDNumber::sharedPainter();

    extern ::QPainter* sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQLCDNumber::nativeEvent(const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QLCDNumber::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, ::qintptr*);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQLCDNumber::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QLCDNumber::hasHeightForWidth();

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQLCDNumber::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QLCDNumber::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQLCDNumber::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QLCDNumber::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::enterEvent(::QEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEnterEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQLCDNumber::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[32]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QLCDNumber::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQLCDNumber::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[33]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QLCDNumber::minimumSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQLCDNumber::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[34]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QLCDNumber::sizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQLCDNumber::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QLCDNumber::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQLCDNumber::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[36]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QLCDNumber::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QPaintEngine* sipQLCDNumber::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[37]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QLCDNumber::paintEngine();

    extern ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQLCDNumber::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[38]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QLCDNumber::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQLCDNumber::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QLCDNumber::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQLCDNumber::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QLCDNumber::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQLCDNumber::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[41], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QLCDNumber::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QLCDNumber::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QLCDNumber::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLCDNumber::initStyleOption(::QStyleOptionFrame*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initStyleOption);

    if (!sipMeth)
    {
        ::QLCDNumber::initStyleOption(a0);
        return;
    }

    extern void sipVH_QtWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyleOptionFrame*);

    sipVH_QtWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QLCDNumber_smallDecimalPoint, "smallDecimalPoint(self) -> bool");

extern "C" {static PyObject *meth_QLCDNumber_smallDecimalPoint(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_smallDecimalPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLCDNumber, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->smallDecimalPoint();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_smallDecimalPoint, doc_QLCDNumber_smallDecimalPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_digitCount, "digitCount(self) -> int");

extern "C" {static PyObject *meth_QLCDNumber_digitCount(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_digitCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLCDNumber, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->digitCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_digitCount, doc_QLCDNumber_digitCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_setDigitCount, "setDigitCount(self, nDigits: int)");

extern "C" {static PyObject *meth_QLCDNumber_setDigitCount(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_setDigitCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QLCDNumber, &sipCpp, &a0))
        {
            sipCpp->setDigitCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_setDigitCount, doc_QLCDNumber_setDigitCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_setNumDigits, "setNumDigits(self, nDigits: int)");

extern "C" {static PyObject *meth_QLCDNumber_setNumDigits(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_setNumDigits(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QLCDNumber, &sipCpp, &a0))
        {
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlcdnumber.sip"
        // This is implemented for Qt v5 so that .ui files created with Designer for Qt v4 will continue to work.
        sipCpp->setDigitCount(a0);
#line 1279 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQLCDNumber.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_setNumDigits, doc_QLCDNumber_setNumDigits);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_checkOverflow, "checkOverflow(self, num: float) -> bool\n"
"checkOverflow(self, num: int) -> bool");

extern "C" {static PyObject *meth_QLCDNumber_checkOverflow(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_checkOverflow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        const ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BXd", &sipSelf, sipType_QLCDNumber, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->checkOverflow(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        int a0;
        const ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QLCDNumber, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->checkOverflow(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_checkOverflow, doc_QLCDNumber_checkOverflow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_mode, "mode(self) -> QLCDNumber.Mode");

extern "C" {static PyObject *meth_QLCDNumber_mode(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_mode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLCDNumber, &sipCpp))
        {
            ::QLCDNumber::Mode sipRes;

            sipRes = sipCpp->mode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLCDNumber_Mode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_mode, doc_QLCDNumber_mode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_setMode, "setMode(self, a0: QLCDNumber.Mode)");

extern "C" {static PyObject *meth_QLCDNumber_setMode(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_setMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLCDNumber::Mode a0;
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QLCDNumber, &sipCpp, sipType_QLCDNumber_Mode, &a0))
        {
            sipCpp->setMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_setMode, doc_QLCDNumber_setMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_segmentStyle, "segmentStyle(self) -> QLCDNumber.SegmentStyle");

extern "C" {static PyObject *meth_QLCDNumber_segmentStyle(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_segmentStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLCDNumber, &sipCpp))
        {
            ::QLCDNumber::SegmentStyle sipRes;

            sipRes = sipCpp->segmentStyle();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLCDNumber_SegmentStyle);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_segmentStyle, doc_QLCDNumber_segmentStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_setSegmentStyle, "setSegmentStyle(self, a0: QLCDNumber.SegmentStyle)");

extern "C" {static PyObject *meth_QLCDNumber_setSegmentStyle(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_setSegmentStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLCDNumber::SegmentStyle a0;
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QLCDNumber, &sipCpp, sipType_QLCDNumber_SegmentStyle, &a0))
        {
            sipCpp->setSegmentStyle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_setSegmentStyle, doc_QLCDNumber_setSegmentStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_value, "value(self) -> float");

extern "C" {static PyObject *meth_QLCDNumber_value(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLCDNumber, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->value();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_value, doc_QLCDNumber_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_intValue, "intValue(self) -> int");

extern "C" {static PyObject *meth_QLCDNumber_intValue(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_intValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLCDNumber, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->intValue();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_intValue, doc_QLCDNumber_intValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QLCDNumber_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QLCDNumber)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLCDNumber, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QLCDNumber::sizeHint() : sipCpp->sizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_sizeHint, doc_QLCDNumber_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_display, "display(self, str: str|None)\n"
"display(self, num: float)\n"
"display(self, num: int)");

extern "C" {static PyObject *meth_QLCDNumber_display(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_display(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLCDNumber, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->display(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        double a0;
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BXd", &sipSelf, sipType_QLCDNumber, &sipCpp, &a0))
        {
            sipCpp->display(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QLCDNumber, &sipCpp, &a0))
        {
            sipCpp->display(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_display, doc_QLCDNumber_display);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_setHexMode, "setHexMode(self)");

extern "C" {static PyObject *meth_QLCDNumber_setHexMode(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_setHexMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLCDNumber, &sipCpp))
        {
            sipCpp->setHexMode();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_setHexMode, doc_QLCDNumber_setHexMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_setDecMode, "setDecMode(self)");

extern "C" {static PyObject *meth_QLCDNumber_setDecMode(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_setDecMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLCDNumber, &sipCpp))
        {
            sipCpp->setDecMode();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_setDecMode, doc_QLCDNumber_setDecMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_setOctMode, "setOctMode(self)");

extern "C" {static PyObject *meth_QLCDNumber_setOctMode(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_setOctMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLCDNumber, &sipCpp))
        {
            sipCpp->setOctMode();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_setOctMode, doc_QLCDNumber_setOctMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_setBinMode, "setBinMode(self)");

extern "C" {static PyObject *meth_QLCDNumber_setBinMode(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_setBinMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLCDNumber, &sipCpp))
        {
            sipCpp->setBinMode();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_setBinMode, doc_QLCDNumber_setBinMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_setSmallDecimalPoint, "setSmallDecimalPoint(self, a0: bool)");

extern "C" {static PyObject *meth_QLCDNumber_setSmallDecimalPoint(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_setSmallDecimalPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QLCDNumber, &sipCpp, &a0))
        {
            sipCpp->setSmallDecimalPoint(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_setSmallDecimalPoint, doc_QLCDNumber_setSmallDecimalPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_event, "event(self, e: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QLCDNumber_event(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QLCDNumber)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QLCDNumber, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QLCDNumber::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_event, doc_QLCDNumber_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLCDNumber_paintEvent, "paintEvent(self, a0: QPaintEvent|None)");

extern "C" {static PyObject *meth_QLCDNumber_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QLCDNumber_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QLCDNumber)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::QLCDNumber *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QLCDNumber, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QLCDNumber::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLCDNumber, sipName_paintEvent, doc_QLCDNumber_paintEvent);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QLCDNumber(void *, const sipTypeDef *);}
static void *cast_QLCDNumber(void *sipCppV, const sipTypeDef *targetType)
{
    ::QLCDNumber *sipCpp = reinterpret_cast< ::QLCDNumber *>(sipCppV);

    if (targetType == sipType_QLCDNumber)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QFrame)->ctd_cast(static_cast< ::QFrame *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QLCDNumber(void *, int);}
static void release_QLCDNumber(void *sipCppV, int)
{
    ::QLCDNumber *sipCpp = reinterpret_cast< ::QLCDNumber *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QLCDNumber(Py_ssize_t);}
static void *array_QLCDNumber(Py_ssize_t sipNrElem)
{
    return new ::QLCDNumber[sipNrElem];
}


extern "C" {static void array_delete_QLCDNumber(void *);}
static void array_delete_QLCDNumber(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLCDNumber *>(sipCpp);
}


extern "C" {static void dealloc_QLCDNumber(sipSimpleWrapper *);}
static void dealloc_QLCDNumber(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQLCDNumber *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLCDNumber(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QLCDNumber(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLCDNumber(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQLCDNumber *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQLCDNumber(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::uint a0;
        ::QWidget* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "u|JH", &a0, sipType_QWidget, &a1, sipOwner))
        {
            sipCpp = new sipQLCDNumber(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QLCDNumber[] = {{115, 255, 1}};


static PyMethodDef methods_QLCDNumber[] = {
    {sipName_checkOverflow, meth_QLCDNumber_checkOverflow, METH_VARARGS, doc_QLCDNumber_checkOverflow},
    {sipName_digitCount, meth_QLCDNumber_digitCount, METH_VARARGS, doc_QLCDNumber_digitCount},
    {sipName_display, meth_QLCDNumber_display, METH_VARARGS, doc_QLCDNumber_display},
    {sipName_event, meth_QLCDNumber_event, METH_VARARGS, doc_QLCDNumber_event},
    {sipName_intValue, meth_QLCDNumber_intValue, METH_VARARGS, doc_QLCDNumber_intValue},
    {sipName_mode, meth_QLCDNumber_mode, METH_VARARGS, doc_QLCDNumber_mode},
    {sipName_paintEvent, meth_QLCDNumber_paintEvent, METH_VARARGS, doc_QLCDNumber_paintEvent},
    {sipName_segmentStyle, meth_QLCDNumber_segmentStyle, METH_VARARGS, doc_QLCDNumber_segmentStyle},
    {sipName_setBinMode, meth_QLCDNumber_setBinMode, METH_VARARGS, doc_QLCDNumber_setBinMode},
    {sipName_setDecMode, meth_QLCDNumber_setDecMode, METH_VARARGS, doc_QLCDNumber_setDecMode},
    {sipName_setDigitCount, meth_QLCDNumber_setDigitCount, METH_VARARGS, doc_QLCDNumber_setDigitCount},
    {sipName_setHexMode, meth_QLCDNumber_setHexMode, METH_VARARGS, doc_QLCDNumber_setHexMode},
    {sipName_setMode, meth_QLCDNumber_setMode, METH_VARARGS, doc_QLCDNumber_setMode},
    {sipName_setNumDigits, meth_QLCDNumber_setNumDigits, METH_VARARGS, doc_QLCDNumber_setNumDigits},
    {sipName_setOctMode, meth_QLCDNumber_setOctMode, METH_VARARGS, doc_QLCDNumber_setOctMode},
    {sipName_setSegmentStyle, meth_QLCDNumber_setSegmentStyle, METH_VARARGS, doc_QLCDNumber_setSegmentStyle},
    {sipName_setSmallDecimalPoint, meth_QLCDNumber_setSmallDecimalPoint, METH_VARARGS, doc_QLCDNumber_setSmallDecimalPoint},
    {sipName_sizeHint, meth_QLCDNumber_sizeHint, METH_VARARGS, doc_QLCDNumber_sizeHint},
    {sipName_smallDecimalPoint, meth_QLCDNumber_smallDecimalPoint, METH_VARARGS, doc_QLCDNumber_smallDecimalPoint},
    {sipName_value, meth_QLCDNumber_value, METH_VARARGS, doc_QLCDNumber_value}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QLCDNumber[] = {
    {sipName_Hex, static_cast<int>(::QLCDNumber::Hex)},
    {sipName_Dec, static_cast<int>(::QLCDNumber::Dec)},
    {sipName_Oct, static_cast<int>(::QLCDNumber::Oct)},
    {sipName_Bin, static_cast<int>(::QLCDNumber::Bin)},
    {sipName_Outline, static_cast<int>(::QLCDNumber::Outline)},
    {sipName_Filled, static_cast<int>(::QLCDNumber::Filled)},
    {sipName_Flat, static_cast<int>(::QLCDNumber::Flat)},
    {0, 0}
};

PyDoc_STRVAR(doc_QLCDNumber, "\1QLCDNumber(parent: QWidget|None = None)\n"
"QLCDNumber(numDigits: int, parent: QWidget|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QLCDNumber[] = {
    {"overflow()", "\1overflow(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QLCDNumber = {
    &::QLCDNumber::staticMetaObject,
    signals_QLCDNumber,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QLCDNumber = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLCDNumber,
        SIP_NULLPTR,
        &plugin_QLCDNumber,
    },
    {
        sipNameNr_QLCDNumber,
        {0, 0, 1},
        20, methods_QLCDNumber,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QLCDNumber, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLCDNumber,
    -1,
    -1,
    supers_QLCDNumber,
    SIP_NULLPTR,
    init_type_QLCDNumber,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLCDNumber,
    SIP_NULLPTR,
    array_QLCDNumber,
    SIP_NULLPTR,
    release_QLCDNumber,
    cast_QLCDNumber,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLCDNumber,
    sizeof (::QLCDNumber),
};
