/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 244 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTextBlockUserData.cpp"



class sipQTextBlockUserData : public ::QTextBlockUserData
{
public:
    sipQTextBlockUserData();
    sipQTextBlockUserData(const ::QTextBlockUserData&);
    ~sipQTextBlockUserData();

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQTextBlockUserData(const sipQTextBlockUserData &);
    sipQTextBlockUserData &operator = (const sipQTextBlockUserData &);
};

sipQTextBlockUserData::sipQTextBlockUserData(): ::QTextBlockUserData(), sipPySelf(SIP_NULLPTR)
{
}

sipQTextBlockUserData::sipQTextBlockUserData(const ::QTextBlockUserData& a0): ::QTextBlockUserData(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQTextBlockUserData::~sipQTextBlockUserData()
{
    sipInstanceDestroyedEx(&sipPySelf);
}


/* Call the instance's destructor. */
extern "C" {static void release_QTextBlockUserData(void *, int);}
static void release_QTextBlockUserData(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQTextBlockUserData *>(sipCppV);
    else
        delete reinterpret_cast< ::QTextBlockUserData *>(sipCppV);
}


extern "C" {static void *array_QTextBlockUserData(Py_ssize_t);}
static void *array_QTextBlockUserData(Py_ssize_t sipNrElem)
{
    return new ::QTextBlockUserData[sipNrElem];
}


extern "C" {static void array_delete_QTextBlockUserData(void *);}
static void array_delete_QTextBlockUserData(void *sipCpp)
{
    delete[] reinterpret_cast< ::QTextBlockUserData *>(sipCpp);
}


extern "C" {static void assign_QTextBlockUserData(void *, Py_ssize_t, void *);}
static void assign_QTextBlockUserData(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QTextBlockUserData *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QTextBlockUserData *>(sipSrc);
}


extern "C" {static void *copy_QTextBlockUserData(const void *, Py_ssize_t);}
static void *copy_QTextBlockUserData(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QTextBlockUserData(reinterpret_cast<const ::QTextBlockUserData *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QTextBlockUserData(sipSimpleWrapper *);}
static void dealloc_QTextBlockUserData(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQTextBlockUserData *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QTextBlockUserData(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QTextBlockUserData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QTextBlockUserData(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQTextBlockUserData *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQTextBlockUserData();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QTextBlockUserData* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QTextBlockUserData, &a0))
        {
            sipCpp = new sipQTextBlockUserData(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}

PyDoc_STRVAR(doc_QTextBlockUserData, "\1QTextBlockUserData()\n"
"QTextBlockUserData(a0: QTextBlockUserData)");


sipClassTypeDef sipTypeDef_QtGui_QTextBlockUserData = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QTextBlockUserData,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QTextBlockUserData,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QTextBlockUserData,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QTextBlockUserData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QTextBlockUserData,
    assign_QTextBlockUserData,
    array_QTextBlockUserData,
    copy_QTextBlockUserData,
    release_QTextBlockUserData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QTextBlockUserData,
    sizeof (::QTextBlockUserData),
};
