/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtipccommon.sip"
#include <qtipccommon.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQNativeIpcKey.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQNativeIpcKey.cpp"


PyDoc_STRVAR(doc_QNativeIpcKey_legacyDefaultTypeForOs, "legacyDefaultTypeForOs() -> QNativeIpcKey.Type");

extern "C" {static PyObject *meth_QNativeIpcKey_legacyDefaultTypeForOs(PyObject *, PyObject *);}
static PyObject *meth_QNativeIpcKey_legacyDefaultTypeForOs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QNativeIpcKey::Type sipRes;

            sipRes = ::QNativeIpcKey::legacyDefaultTypeForOs();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QNativeIpcKey_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeIpcKey, sipName_legacyDefaultTypeForOs, doc_QNativeIpcKey_legacyDefaultTypeForOs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeIpcKey_swap, "swap(self, other: QNativeIpcKey)");

extern "C" {static PyObject *meth_QNativeIpcKey_swap(PyObject *, PyObject *);}
static PyObject *meth_QNativeIpcKey_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNativeIpcKey* a0;
        ::QNativeIpcKey *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QNativeIpcKey, &sipCpp, sipType_QNativeIpcKey, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeIpcKey, sipName_swap, doc_QNativeIpcKey_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeIpcKey_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QNativeIpcKey_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QNativeIpcKey_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNativeIpcKey *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNativeIpcKey, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeIpcKey, sipName_isEmpty, doc_QNativeIpcKey_isEmpty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeIpcKey_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QNativeIpcKey_isValid(PyObject *, PyObject *);}
static PyObject *meth_QNativeIpcKey_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNativeIpcKey *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNativeIpcKey, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeIpcKey, sipName_isValid, doc_QNativeIpcKey_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeIpcKey_type, "type(self) -> QNativeIpcKey.Type");

extern "C" {static PyObject *meth_QNativeIpcKey_type(PyObject *, PyObject *);}
static PyObject *meth_QNativeIpcKey_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNativeIpcKey *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNativeIpcKey, &sipCpp))
        {
            ::QNativeIpcKey::Type sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QNativeIpcKey_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeIpcKey, sipName_type, doc_QNativeIpcKey_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeIpcKey_setType, "setType(self, type: QNativeIpcKey.Type)");

extern "C" {static PyObject *meth_QNativeIpcKey_setType(PyObject *, PyObject *);}
static PyObject *meth_QNativeIpcKey_setType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QNativeIpcKey *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QNativeIpcKey, &sipCpp, sipType_QNativeIpcKey_Type, &a0))
        {
            sipCpp->setType(static_cast< ::QNativeIpcKey::Type>(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeIpcKey, sipName_setType, doc_QNativeIpcKey_setType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeIpcKey_nativeKey, "nativeKey(self) -> str");

extern "C" {static PyObject *meth_QNativeIpcKey_nativeKey(PyObject *, PyObject *);}
static PyObject *meth_QNativeIpcKey_nativeKey(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNativeIpcKey *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNativeIpcKey, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->nativeKey());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeIpcKey, sipName_nativeKey, doc_QNativeIpcKey_nativeKey);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeIpcKey_setNativeKey, "setNativeKey(self, newKey: str|None)");

extern "C" {static PyObject *meth_QNativeIpcKey_setNativeKey(PyObject *, PyObject *);}
static PyObject *meth_QNativeIpcKey_setNativeKey(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QNativeIpcKey *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNativeIpcKey, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setNativeKey(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeIpcKey, sipName_setNativeKey, doc_QNativeIpcKey_setNativeKey);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeIpcKey_toString, "toString(self) -> str");

extern "C" {static PyObject *meth_QNativeIpcKey_toString(PyObject *, PyObject *);}
static PyObject *meth_QNativeIpcKey_toString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNativeIpcKey *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNativeIpcKey, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeIpcKey, sipName_toString, doc_QNativeIpcKey_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeIpcKey_fromString, "fromString(string: str|None) -> QNativeIpcKey");

extern "C" {static PyObject *meth_QNativeIpcKey_fromString(PyObject *, PyObject *);}
static PyObject *meth_QNativeIpcKey_fromString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QNativeIpcKey*sipRes;

            sipRes = new ::QNativeIpcKey(::QNativeIpcKey::fromString(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QNativeIpcKey, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeIpcKey, sipName_fromString, doc_QNativeIpcKey_fromString);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QNativeIpcKey___eq__(PyObject *, PyObject *);}
static PyObject *slot_QNativeIpcKey___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QNativeIpcKey *sipCpp = reinterpret_cast< ::QNativeIpcKey *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QNativeIpcKey));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNativeIpcKey* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QNativeIpcKey, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QNativeIpcKey, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QNativeIpcKey___ne__(PyObject *, PyObject *);}
static PyObject *slot_QNativeIpcKey___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QNativeIpcKey *sipCpp = reinterpret_cast< ::QNativeIpcKey *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QNativeIpcKey));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNativeIpcKey* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QNativeIpcKey, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QNativeIpcKey, sipSelf, sipArg);
}


extern "C" {static Py_hash_t slot_QNativeIpcKey___hash__(PyObject *);}
static Py_hash_t slot_QNativeIpcKey___hash__(PyObject *sipSelf)
{
    ::QNativeIpcKey *sipCpp = reinterpret_cast< ::QNativeIpcKey *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QNativeIpcKey));

    if (!sipCpp)
        return 0;


    {
        {
            Py_hash_t sipRes = 0;

#line 57 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtipccommon.sip"
        sipRes = qHash(*sipCpp);
#line 371 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQNativeIpcKey.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNativeIpcKey(void *, int);}
static void release_QNativeIpcKey(void *sipCppV, int)
{
    delete reinterpret_cast< ::QNativeIpcKey *>(sipCppV);
}


extern "C" {static void *array_QNativeIpcKey(Py_ssize_t);}
static void *array_QNativeIpcKey(Py_ssize_t sipNrElem)
{
    return new ::QNativeIpcKey[sipNrElem];
}


extern "C" {static void array_delete_QNativeIpcKey(void *);}
static void array_delete_QNativeIpcKey(void *sipCpp)
{
    delete[] reinterpret_cast< ::QNativeIpcKey *>(sipCpp);
}


extern "C" {static void assign_QNativeIpcKey(void *, Py_ssize_t, void *);}
static void assign_QNativeIpcKey(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QNativeIpcKey *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QNativeIpcKey *>(sipSrc);
}


extern "C" {static void *copy_QNativeIpcKey(const void *, Py_ssize_t);}
static void *copy_QNativeIpcKey(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QNativeIpcKey(reinterpret_cast<const ::QNativeIpcKey *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QNativeIpcKey(sipSimpleWrapper *);}
static void dealloc_QNativeIpcKey(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNativeIpcKey(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QNativeIpcKey(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QNativeIpcKey(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QNativeIpcKey *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QNativeIpcKey();

            return sipCpp;
        }
    }

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "E", sipType_QNativeIpcKey_Type, &a0))
        {
            sipCpp = new ::QNativeIpcKey(static_cast< ::QNativeIpcKey::Type>(a0));

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        int a1 = static_cast<int>(QNativeIpcKey::DefaultTypeForOs);

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_type,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|E", sipType_QString, &a0, &a0State, sipType_QNativeIpcKey_Type, &a1))
        {
            sipCpp = new ::QNativeIpcKey(*a0, static_cast< ::QNativeIpcKey::Type>(a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipCpp;
        }
    }

    {
        const ::QNativeIpcKey* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QNativeIpcKey, &a0))
        {
            sipCpp = new ::QNativeIpcKey(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QNativeIpcKey[] = {
    {(void *)slot_QNativeIpcKey___eq__, eq_slot},
    {(void *)slot_QNativeIpcKey___ne__, ne_slot},
    {(void *)slot_QNativeIpcKey___hash__, hash_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QNativeIpcKey[] = {
    {sipName_fromString, meth_QNativeIpcKey_fromString, METH_VARARGS, doc_QNativeIpcKey_fromString},
    {sipName_isEmpty, meth_QNativeIpcKey_isEmpty, METH_VARARGS, doc_QNativeIpcKey_isEmpty},
    {sipName_isValid, meth_QNativeIpcKey_isValid, METH_VARARGS, doc_QNativeIpcKey_isValid},
    {sipName_legacyDefaultTypeForOs, meth_QNativeIpcKey_legacyDefaultTypeForOs, METH_VARARGS, doc_QNativeIpcKey_legacyDefaultTypeForOs},
    {sipName_nativeKey, meth_QNativeIpcKey_nativeKey, METH_VARARGS, doc_QNativeIpcKey_nativeKey},
    {sipName_setNativeKey, meth_QNativeIpcKey_setNativeKey, METH_VARARGS, doc_QNativeIpcKey_setNativeKey},
    {sipName_setType, meth_QNativeIpcKey_setType, METH_VARARGS, doc_QNativeIpcKey_setType},
    {sipName_swap, meth_QNativeIpcKey_swap, METH_VARARGS, doc_QNativeIpcKey_swap},
    {sipName_toString, meth_QNativeIpcKey_toString, METH_VARARGS, doc_QNativeIpcKey_toString},
    {sipName_type, meth_QNativeIpcKey_type, METH_VARARGS, doc_QNativeIpcKey_type}
};


extern "C" {static PyObject *varget_QNativeIpcKey_DefaultTypeForOs(void *, PyObject *, PyObject *);}
static PyObject *varget_QNativeIpcKey_DefaultTypeForOs(void *, PyObject *, PyObject *)
{
    ::QNativeIpcKey::Type sipVal;

    sipVal = ::QNativeIpcKey::DefaultTypeForOs;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QNativeIpcKey_Type);
}

sipVariableDef variables_QNativeIpcKey[] = {
    {ClassVariable, sipName_DefaultTypeForOs, (PyMethodDef *)varget_QNativeIpcKey_DefaultTypeForOs, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QNativeIpcKey[] = {
    {sipName_SystemV, static_cast<int>(::QNativeIpcKey::Type::SystemV)},
    {sipName_PosixRealtime, static_cast<int>(::QNativeIpcKey::Type::PosixRealtime)},
    {sipName_Windows, static_cast<int>(::QNativeIpcKey::Type::Windows)},
    {0, 0}
};

PyDoc_STRVAR(doc_QNativeIpcKey, "\1QNativeIpcKey()\n"
"QNativeIpcKey(type: QNativeIpcKey.Type)\n"
"QNativeIpcKey(k: str|None, type: QNativeIpcKey.Type = QNativeIpcKey.DefaultTypeForOs)\n"
"QNativeIpcKey(other: QNativeIpcKey)");


sipClassTypeDef sipTypeDef_QtCore_QNativeIpcKey = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNativeIpcKey,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QNativeIpcKey,
        {0, 0, 1},
        10, methods_QNativeIpcKey,
        1, variables_QNativeIpcKey,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QNativeIpcKey, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QNativeIpcKey,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QNativeIpcKey,
    init_type_QNativeIpcKey,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QNativeIpcKey,
    assign_QNativeIpcKey,
    array_QNativeIpcKey,
    copy_QNativeIpcKey,
    release_QNativeIpcKey,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QNativeIpcKey,
    sizeof (::QNativeIpcKey),
};
