/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 282 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpermissions.sip"
#include <qpermissions.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQBluetoothPermission.cpp"

#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQBluetoothPermission.cpp"


PyDoc_STRVAR(doc_QBluetoothPermission_setCommunicationModes, "setCommunicationModes(self, modes: QBluetoothPermission.CommunicationMode)");

extern "C" {static PyObject *meth_QBluetoothPermission_setCommunicationModes(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothPermission_setCommunicationModes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothPermission::CommunicationModes* a0;
        int a0State = 0;
        ::QBluetoothPermission *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QBluetoothPermission, &sipCpp, sipType_QFlags_0100QBluetoothPermission_CommunicationMode, &a0, &a0State))
        {
            sipCpp->setCommunicationModes(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QBluetoothPermission_CommunicationMode, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothPermission, sipName_setCommunicationModes, doc_QBluetoothPermission_setCommunicationModes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothPermission_communicationModes, "communicationModes(self) -> QBluetoothPermission.CommunicationMode");

extern "C" {static PyObject *meth_QBluetoothPermission_communicationModes(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothPermission_communicationModes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothPermission *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothPermission, &sipCpp))
        {
            ::QBluetoothPermission::CommunicationModes*sipRes;

            sipRes = new ::QBluetoothPermission::CommunicationModes(sipCpp->communicationModes());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QBluetoothPermission_CommunicationMode, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothPermission, sipName_communicationModes, doc_QBluetoothPermission_communicationModes);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QBluetoothPermission(void *, int);}
static void release_QBluetoothPermission(void *sipCppV, int)
{
    delete reinterpret_cast< ::QBluetoothPermission *>(sipCppV);
}


extern "C" {static void *array_QBluetoothPermission(Py_ssize_t);}
static void *array_QBluetoothPermission(Py_ssize_t sipNrElem)
{
    return new ::QBluetoothPermission[sipNrElem];
}


extern "C" {static void array_delete_QBluetoothPermission(void *);}
static void array_delete_QBluetoothPermission(void *sipCpp)
{
    delete[] reinterpret_cast< ::QBluetoothPermission *>(sipCpp);
}


extern "C" {static void assign_QBluetoothPermission(void *, Py_ssize_t, void *);}
static void assign_QBluetoothPermission(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QBluetoothPermission *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QBluetoothPermission *>(sipSrc);
}


extern "C" {static void *copy_QBluetoothPermission(const void *, Py_ssize_t);}
static void *copy_QBluetoothPermission(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QBluetoothPermission(reinterpret_cast<const ::QBluetoothPermission *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QBluetoothPermission(sipSimpleWrapper *);}
static void dealloc_QBluetoothPermission(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QBluetoothPermission(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QBluetoothPermission(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QBluetoothPermission(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QBluetoothPermission *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QBluetoothPermission();

            return sipCpp;
        }
    }

    {
        const ::QBluetoothPermission* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QBluetoothPermission, &a0))
        {
            sipCpp = new ::QBluetoothPermission(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QBluetoothPermission[] = {
    {sipName_communicationModes, meth_QBluetoothPermission_communicationModes, METH_VARARGS, doc_QBluetoothPermission_communicationModes},
    {sipName_setCommunicationModes, meth_QBluetoothPermission_setCommunicationModes, METH_VARARGS, doc_QBluetoothPermission_setCommunicationModes}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QBluetoothPermission[] = {
    {sipName_Access, static_cast<int>(::QBluetoothPermission::Access)},
    {sipName_Advertise, static_cast<int>(::QBluetoothPermission::Advertise)},
    {sipName_Default, static_cast<int>(::QBluetoothPermission::Default)},
    {0, 0}
};

PyDoc_STRVAR(doc_QBluetoothPermission, "\1QBluetoothPermission()\n"
"QBluetoothPermission(other: QBluetoothPermission)");


sipClassTypeDef sipTypeDef_QtCore_QBluetoothPermission = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QBluetoothPermission,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QBluetoothPermission,
        {0, 0, 1},
        2, methods_QBluetoothPermission,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QBluetoothPermission, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QBluetoothPermission,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QBluetoothPermission,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QBluetoothPermission,
    assign_QBluetoothPermission,
    array_QBluetoothPermission,
    copy_QBluetoothPermission,
    release_QBluetoothPermission,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QBluetoothPermission,
    sizeof (::QBluetoothPermission),
};
