/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qhttpheaders.sip"
#include <qhttpheaders.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"

#line 262 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"
#line 27 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_std_optional.sip"
#include <optional>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"
#line 61 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_std_optional.sip"
#include <optional>
#include <qlist.h>
#line 43 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_std_optional.sip"
#include <optional>
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_std_optional.sip"
#include <optional>
#include <qlist.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"
#line 245 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <utility>
#include <qlist.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearrayview.sip"
#include <qbytearrayview.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttpHeaders.cpp"


PyDoc_STRVAR(doc_QHttpHeaders_swap, "swap(self, other: QHttpHeaders)");

extern "C" {static PyObject *meth_QHttpHeaders_swap(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHttpHeaders* a0;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_swap, doc_QHttpHeaders_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_append, "append(self, name: QByteArray|bytes|bytearray|memoryview|str|None, value: QByteArray|bytes|bytearray|memoryview|str|None) -> bool\n"
"append(self, name: QHttpHeaders.WellKnownHeader, value: QByteArray|bytes|bytearray|memoryview|str|None) -> bool");

extern "C" {static PyObject *meth_QHttpHeaders_append(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_append(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QAnyStringView, &a1, &a1State, &a1UserState))
        {
            bool sipRes;

            sipRes = sipCpp->append(*a0, *a1);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QHttpHeaders::WellKnownHeader a0;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0, sipType_QAnyStringView, &a1, &a1State, &a1UserState))
        {
            bool sipRes;

            sipRes = sipCpp->append(a0, *a1);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_append, doc_QHttpHeaders_append);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_insert, "insert(self, i: int, name: QByteArray|bytes|bytearray|memoryview|str|None, value: QByteArray|bytes|bytearray|memoryview|str|None) -> bool\n"
"insert(self, i: int, name: QHttpHeaders.WellKnownHeader, value: QByteArray|bytes|bytearray|memoryview|str|None) -> bool");

extern "C" {static PyObject *meth_QHttpHeaders_insert(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_insert(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QAnyStringView* a2;
        int a2State = 0;
        void *a2UserState = SIP_NULLPTR;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BnJ1J1", &sipSelf, sipType_QHttpHeaders, &sipCpp, &a0, sipType_QAnyStringView, &a1, &a1State, &a1UserState, sipType_QAnyStringView, &a2, &a2State, &a2UserState))
        {
            bool sipRes;

            sipRes = sipCpp->insert(a0, *a1, *a2);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);
            sipReleaseTypeUS(a2, sipType_QAnyStringView, a2State, a2UserState);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::qsizetype a0;
        ::QHttpHeaders::WellKnownHeader a1;
        ::QAnyStringView* a2;
        int a2State = 0;
        void *a2UserState = SIP_NULLPTR;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BnEJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, &a0, sipType_QHttpHeaders_WellKnownHeader, &a1, sipType_QAnyStringView, &a2, &a2State, &a2UserState))
        {
            bool sipRes;

            sipRes = sipCpp->insert(a0, a1, *a2);
            sipReleaseTypeUS(a2, sipType_QAnyStringView, a2State, a2UserState);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_insert, doc_QHttpHeaders_insert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_replace, "replace(self, i: int, name: QByteArray|bytes|bytearray|memoryview|str|None, newValue: QByteArray|bytes|bytearray|memoryview|str|None) -> bool\n"
"replace(self, i: int, name: QHttpHeaders.WellKnownHeader, newValue: QByteArray|bytes|bytearray|memoryview|str|None) -> bool");

extern "C" {static PyObject *meth_QHttpHeaders_replace(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_replace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QAnyStringView* a2;
        int a2State = 0;
        void *a2UserState = SIP_NULLPTR;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BnJ1J1", &sipSelf, sipType_QHttpHeaders, &sipCpp, &a0, sipType_QAnyStringView, &a1, &a1State, &a1UserState, sipType_QAnyStringView, &a2, &a2State, &a2UserState))
        {
            bool sipRes;

            sipRes = sipCpp->replace(a0, *a1, *a2);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);
            sipReleaseTypeUS(a2, sipType_QAnyStringView, a2State, a2UserState);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::qsizetype a0;
        ::QHttpHeaders::WellKnownHeader a1;
        ::QAnyStringView* a2;
        int a2State = 0;
        void *a2UserState = SIP_NULLPTR;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BnEJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, &a0, sipType_QHttpHeaders_WellKnownHeader, &a1, sipType_QAnyStringView, &a2, &a2State, &a2UserState))
        {
            bool sipRes;

            sipRes = sipCpp->replace(a0, a1, *a2);
            sipReleaseTypeUS(a2, sipType_QAnyStringView, a2State, a2UserState);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_replace, doc_QHttpHeaders_replace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_contains, "contains(self, name: QByteArray|bytes|bytearray|memoryview|str|None) -> bool\n"
"contains(self, name: QHttpHeaders.WellKnownHeader) -> bool");

extern "C" {static PyObject *meth_QHttpHeaders_contains(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_contains(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            bool sipRes;

            sipRes = sipCpp->contains(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QHttpHeaders::WellKnownHeader a0;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->contains(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_contains, doc_QHttpHeaders_contains);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_clear, "clear(self)");

extern "C" {static PyObject *meth_QHttpHeaders_clear(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHttpHeaders, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_clear, doc_QHttpHeaders_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_removeAll, "removeAll(self, name: QByteArray|bytes|bytearray|memoryview|str|None)\n"
"removeAll(self, name: QHttpHeaders.WellKnownHeader)");

extern "C" {static PyObject *meth_QHttpHeaders_removeAll(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_removeAll(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            sipCpp->removeAll(*a0);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QHttpHeaders::WellKnownHeader a0;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0))
        {
            sipCpp->removeAll(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_removeAll, doc_QHttpHeaders_removeAll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_removeAt, "removeAt(self, i: int)");

extern "C" {static PyObject *meth_QHttpHeaders_removeAt(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_removeAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QHttpHeaders, &sipCpp, &a0))
        {
            sipCpp->removeAt(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_removeAt, doc_QHttpHeaders_removeAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_value, "value(self, name: QByteArray|bytes|bytearray|memoryview|str|None, defaultValue: QByteArray|bytes|bytearray|memoryview = {}) -> QByteArray\n"
"value(self, name: QHttpHeaders.WellKnownHeader, defaultValue: QByteArray|bytes|bytearray|memoryview = {}) -> QByteArray");

extern "C" {static PyObject *meth_QHttpHeaders_value(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_value(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QByteArrayView a1def = {};
        ::QByteArrayView* a1 = &a1def;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        const ::QHttpHeaders *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_defaultValue,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QByteArrayView, &a1, &a1State, &a1UserState))
        {
            ::QByteArrayView*sipRes;

            sipRes = new ::QByteArrayView(sipCpp->value(*a0, *a1));
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QByteArrayView, a1State, a1UserState);

            return sipConvertFromNewType(sipRes, sipType_QByteArrayView, SIP_NULLPTR);
        }
    }

    {
        ::QHttpHeaders::WellKnownHeader a0;
        ::QByteArrayView a1def = {};
        ::QByteArrayView* a1 = &a1def;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        const ::QHttpHeaders *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_defaultValue,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0, sipType_QByteArrayView, &a1, &a1State, &a1UserState))
        {
            ::QByteArrayView*sipRes;

            sipRes = new ::QByteArrayView(sipCpp->value(a0, *a1));
            sipReleaseTypeUS(a1, sipType_QByteArrayView, a1State, a1UserState);

            return sipConvertFromNewType(sipRes, sipType_QByteArrayView, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_value, doc_QHttpHeaders_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_values, "values(self, name: QByteArray|bytes|bytearray|memoryview|str|None) -> list[QByteArray]\n"
"values(self, name: QHttpHeaders.WellKnownHeader) -> list[QByteArray]");

extern "C" {static PyObject *meth_QHttpHeaders_values(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_values(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            QList< ::QByteArray>*sipRes;

            sipRes = new QList< ::QByteArray>(sipCpp->values(*a0));
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QByteArray, SIP_NULLPTR);
        }
    }

    {
        ::QHttpHeaders::WellKnownHeader a0;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0))
        {
            QList< ::QByteArray>*sipRes;

            sipRes = new QList< ::QByteArray>(sipCpp->values(a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_values, doc_QHttpHeaders_values);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_valueAt, "valueAt(self, i: int) -> QByteArray");

extern "C" {static PyObject *meth_QHttpHeaders_valueAt(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_valueAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QHttpHeaders, &sipCpp, &a0))
        {
            ::QByteArrayView*sipRes;

            sipRes = new ::QByteArrayView(sipCpp->valueAt(a0));

            return sipConvertFromNewType(sipRes, sipType_QByteArrayView, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_valueAt, doc_QHttpHeaders_valueAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_nameAt, "nameAt(self, i: int) -> str");

extern "C" {static PyObject *meth_QHttpHeaders_nameAt(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_nameAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QHttpHeaders, &sipCpp, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->nameAt(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_nameAt, doc_QHttpHeaders_nameAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_combinedValue, "combinedValue(self, name: QByteArray|bytes|bytearray|memoryview|str|None) -> QByteArray\n"
"combinedValue(self, name: QHttpHeaders.WellKnownHeader) -> QByteArray");

extern "C" {static PyObject *meth_QHttpHeaders_combinedValue(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_combinedValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->combinedValue(*a0));
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    {
        ::QHttpHeaders::WellKnownHeader a0;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->combinedValue(a0));

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_combinedValue, doc_QHttpHeaders_combinedValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_size, "size(self) -> int");

extern "C" {static PyObject *meth_QHttpHeaders_size(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHttpHeaders, &sipCpp))
        {
            ::qsizetype sipRes;

            sipRes = sipCpp->size();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_size, doc_QHttpHeaders_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_reserve, "reserve(self, size: int)");

extern "C" {static PyObject *meth_QHttpHeaders_reserve(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_reserve(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QHttpHeaders, &sipCpp, &a0))
        {
            sipCpp->reserve(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_reserve, doc_QHttpHeaders_reserve);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QHttpHeaders_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHttpHeaders, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_isEmpty, doc_QHttpHeaders_isEmpty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_wellKnownHeaderName, "wellKnownHeaderName(name: QHttpHeaders.WellKnownHeader) -> QByteArray");

extern "C" {static PyObject *meth_QHttpHeaders_wellKnownHeaderName(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_wellKnownHeaderName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHttpHeaders::WellKnownHeader a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QHttpHeaders_WellKnownHeader, &a0))
        {
            ::QByteArrayView*sipRes;

            sipRes = new ::QByteArrayView(::QHttpHeaders::wellKnownHeaderName(a0));

            return sipConvertFromNewType(sipRes, sipType_QByteArrayView, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_wellKnownHeaderName, doc_QHttpHeaders_wellKnownHeaderName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_fromListOfPairs, "fromListOfPairs(headers: Iterable[tuple[QByteArray|bytes|bytearray|memoryview, QByteArray|bytes|bytearray|memoryview]]) -> QHttpHeaders");

extern "C" {static PyObject *meth_QHttpHeaders_fromListOfPairs(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_fromListOfPairs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList<std::pair<QByteArray, QByteArray>>* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QList_0600std_pair_0100QByteArray_0100QByteArray, &a0, &a0State))
        {
            ::QHttpHeaders*sipRes;

            sipRes = new ::QHttpHeaders(::QHttpHeaders::fromListOfPairs(*a0));
            sipReleaseType(const_cast<QList<std::pair<QByteArray, QByteArray>> *>(a0), sipType_QList_0600std_pair_0100QByteArray_0100QByteArray, a0State);

            return sipConvertFromNewType(sipRes, sipType_QHttpHeaders, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_fromListOfPairs, doc_QHttpHeaders_fromListOfPairs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_toListOfPairs, "toListOfPairs(self) -> list[tuple[QByteArray, QByteArray]]");

extern "C" {static PyObject *meth_QHttpHeaders_toListOfPairs(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_toListOfPairs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHttpHeaders, &sipCpp))
        {
            QList<std::pair<QByteArray, QByteArray>>*sipRes;

            sipRes = new QList<std::pair<QByteArray, QByteArray>>(sipCpp->toListOfPairs());

            return sipConvertFromNewType(sipRes, sipType_QList_0600std_pair_0100QByteArray_0100QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_toListOfPairs, doc_QHttpHeaders_toListOfPairs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_replaceOrAppend, "replaceOrAppend(self, name: QHttpHeaders.WellKnownHeader, newValue: QByteArray|bytes|bytearray|memoryview|str|None) -> bool\n"
"replaceOrAppend(self, name: QByteArray|bytes|bytearray|memoryview|str|None, newValue: QByteArray|bytes|bytearray|memoryview|str|None) -> bool");

extern "C" {static PyObject *meth_QHttpHeaders_replaceOrAppend(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_replaceOrAppend(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHttpHeaders::WellKnownHeader a0;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0, sipType_QAnyStringView, &a1, &a1State, &a1UserState))
        {
            bool sipRes;

            sipRes = sipCpp->replaceOrAppend(a0, *a1);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QAnyStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QAnyStringView, &a1, &a1State, &a1UserState))
        {
            bool sipRes;

            sipRes = sipCpp->replaceOrAppend(*a0, *a1);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseTypeUS(a1, sipType_QAnyStringView, a1State, a1UserState);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_replaceOrAppend, doc_QHttpHeaders_replaceOrAppend);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_intValue, "intValue(self, name: QHttpHeaders.WellKnownHeader) -> int|None\n"
"intValue(self, name: QByteArray|bytes|bytearray|memoryview|str|None) -> int|None");

extern "C" {static PyObject *meth_QHttpHeaders_intValue(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_intValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHttpHeaders::WellKnownHeader a0;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0))
        {
            ::std::optional< ::qint64>*sipRes;

            sipRes = new ::std::optional< ::qint64>(sipCpp->intValue(a0));

            return sipConvertFromNewType(sipRes, sipType_std_optional_3800, SIP_NULLPTR);
        }
    }

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            ::std::optional< ::qint64>*sipRes;

            sipRes = new ::std::optional< ::qint64>(sipCpp->intValue(*a0));
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            return sipConvertFromNewType(sipRes, sipType_std_optional_3800, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_intValue, doc_QHttpHeaders_intValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_intValues, "intValues(self, name: QHttpHeaders.WellKnownHeader) -> list[int]|None\n"
"intValues(self, name: QByteArray|bytes|bytearray|memoryview|str|None) -> list[int]|None");

extern "C" {static PyObject *meth_QHttpHeaders_intValues(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_intValues(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHttpHeaders::WellKnownHeader a0;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0))
        {
            ::std::optional<QList< ::qint64>>*sipRes;

            sipRes = new ::std::optional<QList< ::qint64>>(sipCpp->intValues(a0));

            return sipConvertFromNewType(sipRes, sipType_std_optional_0600QList_3800, SIP_NULLPTR);
        }
    }

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            ::std::optional<QList< ::qint64>>*sipRes;

            sipRes = new ::std::optional<QList< ::qint64>>(sipCpp->intValues(*a0));
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            return sipConvertFromNewType(sipRes, sipType_std_optional_0600QList_3800, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_intValues, doc_QHttpHeaders_intValues);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_intValueAt, "intValueAt(self, i: int) -> int|None");

extern "C" {static PyObject *meth_QHttpHeaders_intValueAt(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_intValueAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QHttpHeaders, &sipCpp, &a0))
        {
            ::std::optional< ::qint64>*sipRes;

            sipRes = new ::std::optional< ::qint64>(sipCpp->intValueAt(a0));

            return sipConvertFromNewType(sipRes, sipType_std_optional_3800, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_intValueAt, doc_QHttpHeaders_intValueAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_dateTimeValue, "dateTimeValue(self, name: QHttpHeaders.WellKnownHeader) -> QDateTime|None\n"
"dateTimeValue(self, name: QByteArray|bytes|bytearray|memoryview|str|None) -> QDateTime|None");

extern "C" {static PyObject *meth_QHttpHeaders_dateTimeValue(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_dateTimeValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHttpHeaders::WellKnownHeader a0;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0))
        {
            std::optional< ::QDateTime>*sipRes;

            sipRes = new std::optional< ::QDateTime>(sipCpp->dateTimeValue(a0));

            return sipConvertFromNewType(sipRes, sipType_std_optional_0100QDateTime, SIP_NULLPTR);
        }
    }

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            std::optional< ::QDateTime>*sipRes;

            sipRes = new std::optional< ::QDateTime>(sipCpp->dateTimeValue(*a0));
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            return sipConvertFromNewType(sipRes, sipType_std_optional_0100QDateTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_dateTimeValue, doc_QHttpHeaders_dateTimeValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_dateTimeValues, "dateTimeValues(self, name: QHttpHeaders.WellKnownHeader) -> list[QDateTime]|None\n"
"dateTimeValues(self, name: QByteArray|bytes|bytearray|memoryview|str|None) -> list[QDateTime]|None");

extern "C" {static PyObject *meth_QHttpHeaders_dateTimeValues(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_dateTimeValues(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHttpHeaders::WellKnownHeader a0;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0))
        {
            std::optional<QList<QDateTime>>*sipRes;

            sipRes = new std::optional<QList<QDateTime>>(sipCpp->dateTimeValues(a0));

            return sipConvertFromNewType(sipRes, sipType_std_optional_0600QList_0100QDateTime, SIP_NULLPTR);
        }
    }

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState))
        {
            std::optional<QList<QDateTime>>*sipRes;

            sipRes = new std::optional<QList<QDateTime>>(sipCpp->dateTimeValues(*a0));
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);

            return sipConvertFromNewType(sipRes, sipType_std_optional_0600QList_0100QDateTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_dateTimeValues, doc_QHttpHeaders_dateTimeValues);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_dateTimeValueAt, "dateTimeValueAt(self, i: int) -> QDateTime|None");

extern "C" {static PyObject *meth_QHttpHeaders_dateTimeValueAt(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_dateTimeValueAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        const ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QHttpHeaders, &sipCpp, &a0))
        {
            std::optional< ::QDateTime>*sipRes;

            sipRes = new std::optional< ::QDateTime>(sipCpp->dateTimeValueAt(a0));

            return sipConvertFromNewType(sipRes, sipType_std_optional_0100QDateTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_dateTimeValueAt, doc_QHttpHeaders_dateTimeValueAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttpHeaders_setDateTimeValue, "setDateTimeValue(self, name: QHttpHeaders.WellKnownHeader, dateTime: QDateTime|datetime.datetime)\n"
"setDateTimeValue(self, name: QByteArray|bytes|bytearray|memoryview|str|None, dateTime: QDateTime|datetime.datetime)");

extern "C" {static PyObject *meth_QHttpHeaders_setDateTimeValue(PyObject *, PyObject *);}
static PyObject *meth_QHttpHeaders_setDateTimeValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHttpHeaders::WellKnownHeader a0;
        const ::QDateTime* a1;
        int a1State = 0;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QHttpHeaders_WellKnownHeader, &a0, sipType_QDateTime, &a1, &a1State))
        {
            sipCpp->setDateTimeValue(a0, *a1);
            sipReleaseType(const_cast< ::QDateTime *>(a1), sipType_QDateTime, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QAnyStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        const ::QDateTime* a1;
        int a1State = 0;
        ::QHttpHeaders *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QHttpHeaders, &sipCpp, sipType_QAnyStringView, &a0, &a0State, &a0UserState, sipType_QDateTime, &a1, &a1State))
        {
            sipCpp->setDateTimeValue(*a0, *a1);
            sipReleaseTypeUS(a0, sipType_QAnyStringView, a0State, a0UserState);
            sipReleaseType(const_cast< ::QDateTime *>(a1), sipType_QDateTime, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttpHeaders, sipName_setDateTimeValue, doc_QHttpHeaders_setDateTimeValue);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHttpHeaders(void *, int);}
static void release_QHttpHeaders(void *sipCppV, int)
{
    delete reinterpret_cast< ::QHttpHeaders *>(sipCppV);
}


extern "C" {static void *array_QHttpHeaders(Py_ssize_t);}
static void *array_QHttpHeaders(Py_ssize_t sipNrElem)
{
    return new ::QHttpHeaders[sipNrElem];
}


extern "C" {static void array_delete_QHttpHeaders(void *);}
static void array_delete_QHttpHeaders(void *sipCpp)
{
    delete[] reinterpret_cast< ::QHttpHeaders *>(sipCpp);
}


extern "C" {static void assign_QHttpHeaders(void *, Py_ssize_t, void *);}
static void assign_QHttpHeaders(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QHttpHeaders *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QHttpHeaders *>(sipSrc);
}


extern "C" {static void *copy_QHttpHeaders(const void *, Py_ssize_t);}
static void *copy_QHttpHeaders(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QHttpHeaders(reinterpret_cast<const ::QHttpHeaders *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QHttpHeaders(sipSimpleWrapper *);}
static void dealloc_QHttpHeaders(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHttpHeaders(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QHttpHeaders(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QHttpHeaders(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QHttpHeaders *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QHttpHeaders();

            return sipCpp;
        }
    }

    {
        const ::QHttpHeaders* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QHttpHeaders, &a0))
        {
            sipCpp = new ::QHttpHeaders(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QHttpHeaders[] = {
    {sipName_append, meth_QHttpHeaders_append, METH_VARARGS, doc_QHttpHeaders_append},
    {sipName_clear, meth_QHttpHeaders_clear, METH_VARARGS, doc_QHttpHeaders_clear},
    {sipName_combinedValue, meth_QHttpHeaders_combinedValue, METH_VARARGS, doc_QHttpHeaders_combinedValue},
    {sipName_contains, meth_QHttpHeaders_contains, METH_VARARGS, doc_QHttpHeaders_contains},
    {sipName_dateTimeValue, meth_QHttpHeaders_dateTimeValue, METH_VARARGS, doc_QHttpHeaders_dateTimeValue},
    {sipName_dateTimeValueAt, meth_QHttpHeaders_dateTimeValueAt, METH_VARARGS, doc_QHttpHeaders_dateTimeValueAt},
    {sipName_dateTimeValues, meth_QHttpHeaders_dateTimeValues, METH_VARARGS, doc_QHttpHeaders_dateTimeValues},
    {sipName_fromListOfPairs, meth_QHttpHeaders_fromListOfPairs, METH_VARARGS, doc_QHttpHeaders_fromListOfPairs},
    {sipName_insert, meth_QHttpHeaders_insert, METH_VARARGS, doc_QHttpHeaders_insert},
    {sipName_intValue, meth_QHttpHeaders_intValue, METH_VARARGS, doc_QHttpHeaders_intValue},
    {sipName_intValueAt, meth_QHttpHeaders_intValueAt, METH_VARARGS, doc_QHttpHeaders_intValueAt},
    {sipName_intValues, meth_QHttpHeaders_intValues, METH_VARARGS, doc_QHttpHeaders_intValues},
    {sipName_isEmpty, meth_QHttpHeaders_isEmpty, METH_VARARGS, doc_QHttpHeaders_isEmpty},
    {sipName_nameAt, meth_QHttpHeaders_nameAt, METH_VARARGS, doc_QHttpHeaders_nameAt},
    {sipName_removeAll, meth_QHttpHeaders_removeAll, METH_VARARGS, doc_QHttpHeaders_removeAll},
    {sipName_removeAt, meth_QHttpHeaders_removeAt, METH_VARARGS, doc_QHttpHeaders_removeAt},
    {sipName_replace, meth_QHttpHeaders_replace, METH_VARARGS, doc_QHttpHeaders_replace},
    {sipName_replaceOrAppend, meth_QHttpHeaders_replaceOrAppend, METH_VARARGS, doc_QHttpHeaders_replaceOrAppend},
    {sipName_reserve, meth_QHttpHeaders_reserve, METH_VARARGS, doc_QHttpHeaders_reserve},
    {sipName_setDateTimeValue, meth_QHttpHeaders_setDateTimeValue, METH_VARARGS, doc_QHttpHeaders_setDateTimeValue},
    {sipName_size, meth_QHttpHeaders_size, METH_VARARGS, doc_QHttpHeaders_size},
    {sipName_swap, meth_QHttpHeaders_swap, METH_VARARGS, doc_QHttpHeaders_swap},
    {sipName_toListOfPairs, meth_QHttpHeaders_toListOfPairs, METH_VARARGS, doc_QHttpHeaders_toListOfPairs},
    {sipName_value, SIP_MLMETH_CAST(meth_QHttpHeaders_value), METH_VARARGS|METH_KEYWORDS, doc_QHttpHeaders_value},
    {sipName_valueAt, meth_QHttpHeaders_valueAt, METH_VARARGS, doc_QHttpHeaders_valueAt},
    {sipName_values, meth_QHttpHeaders_values, METH_VARARGS, doc_QHttpHeaders_values},
    {sipName_wellKnownHeaderName, meth_QHttpHeaders_wellKnownHeaderName, METH_VARARGS, doc_QHttpHeaders_wellKnownHeaderName}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QHttpHeaders[] = {
    {sipName_AIM, static_cast<int>(::QHttpHeaders::WellKnownHeader::AIM)},
    {sipName_Accept, static_cast<int>(::QHttpHeaders::WellKnownHeader::Accept)},
    {sipName_AcceptAdditions, static_cast<int>(::QHttpHeaders::WellKnownHeader::AcceptAdditions)},
    {sipName_AcceptCH, static_cast<int>(::QHttpHeaders::WellKnownHeader::AcceptCH)},
    {sipName_AcceptDatetime, static_cast<int>(::QHttpHeaders::WellKnownHeader::AcceptDatetime)},
    {sipName_AcceptEncoding, static_cast<int>(::QHttpHeaders::WellKnownHeader::AcceptEncoding)},
    {sipName_AcceptFeatures, static_cast<int>(::QHttpHeaders::WellKnownHeader::AcceptFeatures)},
    {sipName_AcceptLanguage, static_cast<int>(::QHttpHeaders::WellKnownHeader::AcceptLanguage)},
    {sipName_AcceptPatch, static_cast<int>(::QHttpHeaders::WellKnownHeader::AcceptPatch)},
    {sipName_AcceptPost, static_cast<int>(::QHttpHeaders::WellKnownHeader::AcceptPost)},
    {sipName_AcceptRanges, static_cast<int>(::QHttpHeaders::WellKnownHeader::AcceptRanges)},
    {sipName_AcceptSignature, static_cast<int>(::QHttpHeaders::WellKnownHeader::AcceptSignature)},
    {sipName_AccessControlAllowCredentials, static_cast<int>(::QHttpHeaders::WellKnownHeader::AccessControlAllowCredentials)},
    {sipName_AccessControlAllowHeaders, static_cast<int>(::QHttpHeaders::WellKnownHeader::AccessControlAllowHeaders)},
    {sipName_AccessControlAllowMethods, static_cast<int>(::QHttpHeaders::WellKnownHeader::AccessControlAllowMethods)},
    {sipName_AccessControlAllowOrigin, static_cast<int>(::QHttpHeaders::WellKnownHeader::AccessControlAllowOrigin)},
    {sipName_AccessControlExposeHeaders, static_cast<int>(::QHttpHeaders::WellKnownHeader::AccessControlExposeHeaders)},
    {sipName_AccessControlMaxAge, static_cast<int>(::QHttpHeaders::WellKnownHeader::AccessControlMaxAge)},
    {sipName_AccessControlRequestHeaders, static_cast<int>(::QHttpHeaders::WellKnownHeader::AccessControlRequestHeaders)},
    {sipName_AccessControlRequestMethod, static_cast<int>(::QHttpHeaders::WellKnownHeader::AccessControlRequestMethod)},
    {sipName_Age, static_cast<int>(::QHttpHeaders::WellKnownHeader::Age)},
    {sipName_Allow, static_cast<int>(::QHttpHeaders::WellKnownHeader::Allow)},
    {sipName_ALPN, static_cast<int>(::QHttpHeaders::WellKnownHeader::ALPN)},
    {sipName_AltSvc, static_cast<int>(::QHttpHeaders::WellKnownHeader::AltSvc)},
    {sipName_AltUsed, static_cast<int>(::QHttpHeaders::WellKnownHeader::AltUsed)},
    {sipName_Alternates, static_cast<int>(::QHttpHeaders::WellKnownHeader::Alternates)},
    {sipName_ApplyToRedirectRef, static_cast<int>(::QHttpHeaders::WellKnownHeader::ApplyToRedirectRef)},
    {sipName_AuthenticationControl, static_cast<int>(::QHttpHeaders::WellKnownHeader::AuthenticationControl)},
    {sipName_AuthenticationInfo, static_cast<int>(::QHttpHeaders::WellKnownHeader::AuthenticationInfo)},
    {sipName_Authorization, static_cast<int>(::QHttpHeaders::WellKnownHeader::Authorization)},
    {sipName_CacheControl, static_cast<int>(::QHttpHeaders::WellKnownHeader::CacheControl)},
    {sipName_CacheStatus, static_cast<int>(::QHttpHeaders::WellKnownHeader::CacheStatus)},
    {sipName_CalManagedID, static_cast<int>(::QHttpHeaders::WellKnownHeader::CalManagedID)},
    {sipName_CalDAVTimezones, static_cast<int>(::QHttpHeaders::WellKnownHeader::CalDAVTimezones)},
    {sipName_CapsuleProtocol, static_cast<int>(::QHttpHeaders::WellKnownHeader::CapsuleProtocol)},
    {sipName_CDNCacheControl, static_cast<int>(::QHttpHeaders::WellKnownHeader::CDNCacheControl)},
    {sipName_CDNLoop, static_cast<int>(::QHttpHeaders::WellKnownHeader::CDNLoop)},
    {sipName_CertNotAfter, static_cast<int>(::QHttpHeaders::WellKnownHeader::CertNotAfter)},
    {sipName_CertNotBefore, static_cast<int>(::QHttpHeaders::WellKnownHeader::CertNotBefore)},
    {sipName_ClearSiteData, static_cast<int>(::QHttpHeaders::WellKnownHeader::ClearSiteData)},
    {sipName_ClientCert, static_cast<int>(::QHttpHeaders::WellKnownHeader::ClientCert)},
    {sipName_ClientCertChain, static_cast<int>(::QHttpHeaders::WellKnownHeader::ClientCertChain)},
    {sipName_Close, static_cast<int>(::QHttpHeaders::WellKnownHeader::Close)},
    {sipName_Connection, static_cast<int>(::QHttpHeaders::WellKnownHeader::Connection)},
    {sipName_ContentDigest, static_cast<int>(::QHttpHeaders::WellKnownHeader::ContentDigest)},
    {sipName_ContentDisposition, static_cast<int>(::QHttpHeaders::WellKnownHeader::ContentDisposition)},
    {sipName_ContentEncoding, static_cast<int>(::QHttpHeaders::WellKnownHeader::ContentEncoding)},
    {sipName_ContentID, static_cast<int>(::QHttpHeaders::WellKnownHeader::ContentID)},
    {sipName_ContentLanguage, static_cast<int>(::QHttpHeaders::WellKnownHeader::ContentLanguage)},
    {sipName_ContentLength, static_cast<int>(::QHttpHeaders::WellKnownHeader::ContentLength)},
    {sipName_ContentLocation, static_cast<int>(::QHttpHeaders::WellKnownHeader::ContentLocation)},
    {sipName_ContentRange, static_cast<int>(::QHttpHeaders::WellKnownHeader::ContentRange)},
    {sipName_ContentSecurityPolicy, static_cast<int>(::QHttpHeaders::WellKnownHeader::ContentSecurityPolicy)},
    {sipName_ContentSecurityPolicyReportOnly, static_cast<int>(::QHttpHeaders::WellKnownHeader::ContentSecurityPolicyReportOnly)},
    {sipName_ContentType, static_cast<int>(::QHttpHeaders::WellKnownHeader::ContentType)},
    {sipName_Cookie, static_cast<int>(::QHttpHeaders::WellKnownHeader::Cookie)},
    {sipName_CrossOriginEmbedderPolicy, static_cast<int>(::QHttpHeaders::WellKnownHeader::CrossOriginEmbedderPolicy)},
    {sipName_CrossOriginEmbedderPolicyReportOnly, static_cast<int>(::QHttpHeaders::WellKnownHeader::CrossOriginEmbedderPolicyReportOnly)},
    {sipName_CrossOriginOpenerPolicy, static_cast<int>(::QHttpHeaders::WellKnownHeader::CrossOriginOpenerPolicy)},
    {sipName_CrossOriginOpenerPolicyReportOnly, static_cast<int>(::QHttpHeaders::WellKnownHeader::CrossOriginOpenerPolicyReportOnly)},
    {sipName_CrossOriginResourcePolicy, static_cast<int>(::QHttpHeaders::WellKnownHeader::CrossOriginResourcePolicy)},
    {sipName_DASL, static_cast<int>(::QHttpHeaders::WellKnownHeader::DASL)},
    {sipName_Date, static_cast<int>(::QHttpHeaders::WellKnownHeader::Date)},
    {sipName_DAV, static_cast<int>(::QHttpHeaders::WellKnownHeader::DAV)},
    {sipName_DeltaBase, static_cast<int>(::QHttpHeaders::WellKnownHeader::DeltaBase)},
    {sipName_Depth, static_cast<int>(::QHttpHeaders::WellKnownHeader::Depth)},
    {sipName_Destination, static_cast<int>(::QHttpHeaders::WellKnownHeader::Destination)},
    {sipName_DifferentialID, static_cast<int>(::QHttpHeaders::WellKnownHeader::DifferentialID)},
    {sipName_DPoP, static_cast<int>(::QHttpHeaders::WellKnownHeader::DPoP)},
    {sipName_DPoPNonce, static_cast<int>(::QHttpHeaders::WellKnownHeader::DPoPNonce)},
    {sipName_EarlyData, static_cast<int>(::QHttpHeaders::WellKnownHeader::EarlyData)},
    {sipName_ETag, static_cast<int>(::QHttpHeaders::WellKnownHeader::ETag)},
    {sipName_Expect, static_cast<int>(::QHttpHeaders::WellKnownHeader::Expect)},
    {sipName_ExpectCT, static_cast<int>(::QHttpHeaders::WellKnownHeader::ExpectCT)},
    {sipName_Expires, static_cast<int>(::QHttpHeaders::WellKnownHeader::Expires)},
    {sipName_Forwarded, static_cast<int>(::QHttpHeaders::WellKnownHeader::Forwarded)},
    {sipName_From, static_cast<int>(::QHttpHeaders::WellKnownHeader::From)},
    {sipName_Hobareg, static_cast<int>(::QHttpHeaders::WellKnownHeader::Hobareg)},
    {sipName_Host, static_cast<int>(::QHttpHeaders::WellKnownHeader::Host)},
    {sipName_If, static_cast<int>(::QHttpHeaders::WellKnownHeader::If)},
    {sipName_IfMatch, static_cast<int>(::QHttpHeaders::WellKnownHeader::IfMatch)},
    {sipName_IfModifiedSince, static_cast<int>(::QHttpHeaders::WellKnownHeader::IfModifiedSince)},
    {sipName_IfNoneMatch, static_cast<int>(::QHttpHeaders::WellKnownHeader::IfNoneMatch)},
    {sipName_IfRange, static_cast<int>(::QHttpHeaders::WellKnownHeader::IfRange)},
    {sipName_IfScheduleTagMatch, static_cast<int>(::QHttpHeaders::WellKnownHeader::IfScheduleTagMatch)},
    {sipName_IfUnmodifiedSince, static_cast<int>(::QHttpHeaders::WellKnownHeader::IfUnmodifiedSince)},
    {sipName_IM, static_cast<int>(::QHttpHeaders::WellKnownHeader::IM)},
    {sipName_IncludeReferredTokenBindingID, static_cast<int>(::QHttpHeaders::WellKnownHeader::IncludeReferredTokenBindingID)},
    {sipName_KeepAlive, static_cast<int>(::QHttpHeaders::WellKnownHeader::KeepAlive)},
    {sipName_Label, static_cast<int>(::QHttpHeaders::WellKnownHeader::Label)},
    {sipName_LastEventID, static_cast<int>(::QHttpHeaders::WellKnownHeader::LastEventID)},
    {sipName_LastModified, static_cast<int>(::QHttpHeaders::WellKnownHeader::LastModified)},
    {sipName_Link, static_cast<int>(::QHttpHeaders::WellKnownHeader::Link)},
    {sipName_Location, static_cast<int>(::QHttpHeaders::WellKnownHeader::Location)},
    {sipName_LockToken, static_cast<int>(::QHttpHeaders::WellKnownHeader::LockToken)},
    {sipName_MaxForwards, static_cast<int>(::QHttpHeaders::WellKnownHeader::MaxForwards)},
    {sipName_MementoDatetime, static_cast<int>(::QHttpHeaders::WellKnownHeader::MementoDatetime)},
    {sipName_Meter, static_cast<int>(::QHttpHeaders::WellKnownHeader::Meter)},
    {sipName_MIMEVersion, static_cast<int>(::QHttpHeaders::WellKnownHeader::MIMEVersion)},
    {sipName_Negotiate, static_cast<int>(::QHttpHeaders::WellKnownHeader::Negotiate)},
    {sipName_NEL, static_cast<int>(::QHttpHeaders::WellKnownHeader::NEL)},
    {sipName_ODataEntityId, static_cast<int>(::QHttpHeaders::WellKnownHeader::ODataEntityId)},
    {sipName_ODataIsolation, static_cast<int>(::QHttpHeaders::WellKnownHeader::ODataIsolation)},
    {sipName_ODataMaxVersion, static_cast<int>(::QHttpHeaders::WellKnownHeader::ODataMaxVersion)},
    {sipName_ODataVersion, static_cast<int>(::QHttpHeaders::WellKnownHeader::ODataVersion)},
    {sipName_OptionalWWWAuthenticate, static_cast<int>(::QHttpHeaders::WellKnownHeader::OptionalWWWAuthenticate)},
    {sipName_OrderingType, static_cast<int>(::QHttpHeaders::WellKnownHeader::OrderingType)},
    {sipName_Origin, static_cast<int>(::QHttpHeaders::WellKnownHeader::Origin)},
    {sipName_OriginAgentCluster, static_cast<int>(::QHttpHeaders::WellKnownHeader::OriginAgentCluster)},
    {sipName_OSCORE, static_cast<int>(::QHttpHeaders::WellKnownHeader::OSCORE)},
    {sipName_OSLCCoreVersion, static_cast<int>(::QHttpHeaders::WellKnownHeader::OSLCCoreVersion)},
    {sipName_Overwrite, static_cast<int>(::QHttpHeaders::WellKnownHeader::Overwrite)},
    {sipName_PingFrom, static_cast<int>(::QHttpHeaders::WellKnownHeader::PingFrom)},
    {sipName_PingTo, static_cast<int>(::QHttpHeaders::WellKnownHeader::PingTo)},
    {sipName_Position, static_cast<int>(::QHttpHeaders::WellKnownHeader::Position)},
    {sipName_Prefer, static_cast<int>(::QHttpHeaders::WellKnownHeader::Prefer)},
    {sipName_PreferenceApplied, static_cast<int>(::QHttpHeaders::WellKnownHeader::PreferenceApplied)},
    {sipName_Priority, static_cast<int>(::QHttpHeaders::WellKnownHeader::Priority)},
    {sipName_ProxyAuthenticate, static_cast<int>(::QHttpHeaders::WellKnownHeader::ProxyAuthenticate)},
    {sipName_ProxyAuthenticationInfo, static_cast<int>(::QHttpHeaders::WellKnownHeader::ProxyAuthenticationInfo)},
    {sipName_ProxyAuthorization, static_cast<int>(::QHttpHeaders::WellKnownHeader::ProxyAuthorization)},
    {sipName_ProxyStatus, static_cast<int>(::QHttpHeaders::WellKnownHeader::ProxyStatus)},
    {sipName_PublicKeyPins, static_cast<int>(::QHttpHeaders::WellKnownHeader::PublicKeyPins)},
    {sipName_PublicKeyPinsReportOnly, static_cast<int>(::QHttpHeaders::WellKnownHeader::PublicKeyPinsReportOnly)},
    {sipName_Range, static_cast<int>(::QHttpHeaders::WellKnownHeader::Range)},
    {sipName_RedirectRef, static_cast<int>(::QHttpHeaders::WellKnownHeader::RedirectRef)},
    {sipName_Referer, static_cast<int>(::QHttpHeaders::WellKnownHeader::Referer)},
    {sipName_Refresh, static_cast<int>(::QHttpHeaders::WellKnownHeader::Refresh)},
    {sipName_ReplayNonce, static_cast<int>(::QHttpHeaders::WellKnownHeader::ReplayNonce)},
    {sipName_ReprDigest, static_cast<int>(::QHttpHeaders::WellKnownHeader::ReprDigest)},
    {sipName_RetryAfter, static_cast<int>(::QHttpHeaders::WellKnownHeader::RetryAfter)},
    {sipName_ScheduleReply, static_cast<int>(::QHttpHeaders::WellKnownHeader::ScheduleReply)},
    {sipName_ScheduleTag, static_cast<int>(::QHttpHeaders::WellKnownHeader::ScheduleTag)},
    {sipName_SecPurpose, static_cast<int>(::QHttpHeaders::WellKnownHeader::SecPurpose)},
    {sipName_SecTokenBinding, static_cast<int>(::QHttpHeaders::WellKnownHeader::SecTokenBinding)},
    {sipName_SecWebSocketAccept, static_cast<int>(::QHttpHeaders::WellKnownHeader::SecWebSocketAccept)},
    {sipName_SecWebSocketExtensions, static_cast<int>(::QHttpHeaders::WellKnownHeader::SecWebSocketExtensions)},
    {sipName_SecWebSocketKey, static_cast<int>(::QHttpHeaders::WellKnownHeader::SecWebSocketKey)},
    {sipName_SecWebSocketProtocol, static_cast<int>(::QHttpHeaders::WellKnownHeader::SecWebSocketProtocol)},
    {sipName_SecWebSocketVersion, static_cast<int>(::QHttpHeaders::WellKnownHeader::SecWebSocketVersion)},
    {sipName_Server, static_cast<int>(::QHttpHeaders::WellKnownHeader::Server)},
    {sipName_ServerTiming, static_cast<int>(::QHttpHeaders::WellKnownHeader::ServerTiming)},
    {sipName_SetCookie, static_cast<int>(::QHttpHeaders::WellKnownHeader::SetCookie)},
    {sipName_Signature, static_cast<int>(::QHttpHeaders::WellKnownHeader::Signature)},
    {sipName_SignatureInput, static_cast<int>(::QHttpHeaders::WellKnownHeader::SignatureInput)},
    {sipName_SLUG, static_cast<int>(::QHttpHeaders::WellKnownHeader::SLUG)},
    {sipName_SoapAction, static_cast<int>(::QHttpHeaders::WellKnownHeader::SoapAction)},
    {sipName_StatusURI, static_cast<int>(::QHttpHeaders::WellKnownHeader::StatusURI)},
    {sipName_StrictTransportSecurity, static_cast<int>(::QHttpHeaders::WellKnownHeader::StrictTransportSecurity)},
    {sipName_Sunset, static_cast<int>(::QHttpHeaders::WellKnownHeader::Sunset)},
    {sipName_SurrogateCapability, static_cast<int>(::QHttpHeaders::WellKnownHeader::SurrogateCapability)},
    {sipName_SurrogateControl, static_cast<int>(::QHttpHeaders::WellKnownHeader::SurrogateControl)},
    {sipName_TCN, static_cast<int>(::QHttpHeaders::WellKnownHeader::TCN)},
    {sipName_TE, static_cast<int>(::QHttpHeaders::WellKnownHeader::TE)},
    {sipName_Timeout, static_cast<int>(::QHttpHeaders::WellKnownHeader::Timeout)},
    {sipName_Topic, static_cast<int>(::QHttpHeaders::WellKnownHeader::Topic)},
    {sipName_Traceparent, static_cast<int>(::QHttpHeaders::WellKnownHeader::Traceparent)},
    {sipName_Tracestate, static_cast<int>(::QHttpHeaders::WellKnownHeader::Tracestate)},
    {sipName_Trailer, static_cast<int>(::QHttpHeaders::WellKnownHeader::Trailer)},
    {sipName_TransferEncoding, static_cast<int>(::QHttpHeaders::WellKnownHeader::TransferEncoding)},
    {sipName_TTL, static_cast<int>(::QHttpHeaders::WellKnownHeader::TTL)},
    {sipName_Upgrade, static_cast<int>(::QHttpHeaders::WellKnownHeader::Upgrade)},
    {sipName_Urgency, static_cast<int>(::QHttpHeaders::WellKnownHeader::Urgency)},
    {sipName_UserAgent, static_cast<int>(::QHttpHeaders::WellKnownHeader::UserAgent)},
    {sipName_VariantVary, static_cast<int>(::QHttpHeaders::WellKnownHeader::VariantVary)},
    {sipName_Vary, static_cast<int>(::QHttpHeaders::WellKnownHeader::Vary)},
    {sipName_Via, static_cast<int>(::QHttpHeaders::WellKnownHeader::Via)},
    {sipName_WantContentDigest, static_cast<int>(::QHttpHeaders::WellKnownHeader::WantContentDigest)},
    {sipName_WantReprDigest, static_cast<int>(::QHttpHeaders::WellKnownHeader::WantReprDigest)},
    {sipName_WWWAuthenticate, static_cast<int>(::QHttpHeaders::WellKnownHeader::WWWAuthenticate)},
    {sipName_XContentTypeOptions, static_cast<int>(::QHttpHeaders::WellKnownHeader::XContentTypeOptions)},
    {sipName_XFrameOptions, static_cast<int>(::QHttpHeaders::WellKnownHeader::XFrameOptions)},
    {sipName_AcceptCharset, static_cast<int>(::QHttpHeaders::WellKnownHeader::AcceptCharset)},
    {sipName_CPEPInfo, static_cast<int>(::QHttpHeaders::WellKnownHeader::CPEPInfo)},
    {sipName_Pragma, static_cast<int>(::QHttpHeaders::WellKnownHeader::Pragma)},
    {sipName_ProtocolInfo, static_cast<int>(::QHttpHeaders::WellKnownHeader::ProtocolInfo)},
    {sipName_ProtocolQuery, static_cast<int>(::QHttpHeaders::WellKnownHeader::ProtocolQuery)},
    {0, 0}
};

PyDoc_STRVAR(doc_QHttpHeaders, "\1QHttpHeaders()\n"
"QHttpHeaders(other: QHttpHeaders)");


sipClassTypeDef sipTypeDef_QtNetwork_QHttpHeaders = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHttpHeaders,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QHttpHeaders,
        {0, 0, 1},
        27, methods_QHttpHeaders,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QHttpHeaders, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QHttpHeaders,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QHttpHeaders,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHttpHeaders,
    assign_QHttpHeaders,
    array_QHttpHeaders,
    copy_QHttpHeaders,
    release_QHttpHeaders,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QHttpHeaders,
    sizeof (::QHttpHeaders),
};
