/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtRemoteObjects.h"

#line 138 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectnode.sip"
#include <qremoteobjectnode.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 789 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectnode.sip"
#include <qremoteobjectnode.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_std_pair.sip"
#include <utility>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qtremoteobjectglobal.sip"
#include <qtremoteobjectglobal.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectnode.sip"
#include <qremoteobjectnode.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectregistry.sip"
#include <qremoteobjectregistry.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectabstractitemmodelreplica.sip"
#include <qremoteobjectabstractitemmodelreplica.h>
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qtremoteobjectglobal.sip"
#include <qtremoteobjectglobal.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectdynamicreplica.sip"
#include <qremoteobjectdynamicreplica.h>
#line 78 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringview.sip"
#include <qstringview.h>
#line 84 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 118 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 124 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 127 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 130 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectHostBase.cpp"


PyDoc_STRVAR(doc_QRemoteObjectHostBase_setName, "setName(self, name: str|None)");

extern "C" {static PyObject *meth_QRemoteObjectHostBase_setName(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectHostBase_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRemoteObjectHostBase)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        ::QRemoteObjectHostBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QRemoteObjectHostBase, &sipCpp, sipType_QString, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QRemoteObjectHostBase::setName(*a0) : sipCpp->setName(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectHostBase, sipName_setName, doc_QRemoteObjectHostBase_setName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectHostBase_enableRemoting, "enableRemoting(self, object: QObject|None, name: str|None = '') -> bool\n"
"enableRemoting(self, model: QAbstractItemModel|None, name: str|None, roles: Iterable[int], selectionModel: QItemSelectionModel|None = None) -> bool");

extern "C" {static PyObject *meth_QRemoteObjectHostBase_enableRemoting(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectHostBase_enableRemoting(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        ::QRemoteObjectHostBase *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_name,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|J1", &sipSelf, sipType_QRemoteObjectHostBase, &sipCpp, sipType_QObject, &a0, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->enableRemoting(a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QAbstractItemModel* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QList<int>* a2;
        int a2State = 0;
        ::QItemSelectionModel* a3 = 0;
        ::QRemoteObjectHostBase *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_selectionModel,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J1J1|J8", &sipSelf, sipType_QRemoteObjectHostBase, &sipCpp, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QList_1800, &a2, &a2State, sipType_QItemSelectionModel, &a3))
        {
            bool sipRes;

            sipRes = sipCpp->enableRemoting(a0, *a1, *a2, a3);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QList<int> *>(a2), sipType_QList_1800, a2State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectHostBase, sipName_enableRemoting, doc_QRemoteObjectHostBase_enableRemoting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectHostBase_disableRemoting, "disableRemoting(self, remoteObject: QObject|None) -> bool");

extern "C" {static PyObject *meth_QRemoteObjectHostBase_disableRemoting(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectHostBase_disableRemoting(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        ::QRemoteObjectHostBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QRemoteObjectHostBase, &sipCpp, sipType_QObject, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->disableRemoting(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectHostBase, sipName_disableRemoting, doc_QRemoteObjectHostBase_disableRemoting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectHostBase_addHostSideConnection, "addHostSideConnection(self, ioDevice: QIODevice|None)");

extern "C" {static PyObject *meth_QRemoteObjectHostBase_addHostSideConnection(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectHostBase_addHostSideConnection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QRemoteObjectHostBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QRemoteObjectHostBase, &sipCpp, sipType_QIODevice, &a0))
        {
            sipCpp->addHostSideConnection(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectHostBase, sipName_addHostSideConnection, doc_QRemoteObjectHostBase_addHostSideConnection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectHostBase_proxy, "proxy(self, registryUrl: QUrl, hostUrl: QUrl = QUrl()) -> bool");

extern "C" {static PyObject *meth_QRemoteObjectHostBase_proxy(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectHostBase_proxy(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        const ::QUrl& a1def = {};
        const ::QUrl* a1 = &a1def;
        ::QRemoteObjectHostBase *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_hostUrl,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J9", &sipSelf, sipType_QRemoteObjectHostBase, &sipCpp, sipType_QUrl, &a0, sipType_QUrl, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->proxy(*a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectHostBase, sipName_proxy, doc_QRemoteObjectHostBase_proxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectHostBase_reverseProxy, "reverseProxy(self) -> bool");

extern "C" {static PyObject *meth_QRemoteObjectHostBase_reverseProxy(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectHostBase_reverseProxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRemoteObjectHostBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRemoteObjectHostBase, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->reverseProxy();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectHostBase, sipName_reverseProxy, doc_QRemoteObjectHostBase_reverseProxy);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRemoteObjectHostBase(void *, const sipTypeDef *);}
static void *cast_QRemoteObjectHostBase(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRemoteObjectHostBase *sipCpp = reinterpret_cast< ::QRemoteObjectHostBase *>(sipCppV);

    if (targetType == sipType_QRemoteObjectHostBase)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QRemoteObjectNode)->ctd_cast(static_cast< ::QRemoteObjectNode *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRemoteObjectHostBase(void *, int);}
static void release_QRemoteObjectHostBase(void *sipCppV, int)
{
    ::QRemoteObjectHostBase *sipCpp = reinterpret_cast< ::QRemoteObjectHostBase *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QRemoteObjectHostBase(sipSimpleWrapper *);}
static void dealloc_QRemoteObjectHostBase(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRemoteObjectHostBase(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRemoteObjectHostBase[] = {{7, 255, 1}};


static PyMethodDef methods_QRemoteObjectHostBase[] = {
    {sipName_addHostSideConnection, meth_QRemoteObjectHostBase_addHostSideConnection, METH_VARARGS, doc_QRemoteObjectHostBase_addHostSideConnection},
    {sipName_disableRemoting, meth_QRemoteObjectHostBase_disableRemoting, METH_VARARGS, doc_QRemoteObjectHostBase_disableRemoting},
    {sipName_enableRemoting, SIP_MLMETH_CAST(meth_QRemoteObjectHostBase_enableRemoting), METH_VARARGS|METH_KEYWORDS, doc_QRemoteObjectHostBase_enableRemoting},
    {sipName_proxy, SIP_MLMETH_CAST(meth_QRemoteObjectHostBase_proxy), METH_VARARGS|METH_KEYWORDS, doc_QRemoteObjectHostBase_proxy},
    {sipName_reverseProxy, meth_QRemoteObjectHostBase_reverseProxy, METH_VARARGS, doc_QRemoteObjectHostBase_reverseProxy},
    {sipName_setName, meth_QRemoteObjectHostBase_setName, METH_VARARGS, doc_QRemoteObjectHostBase_setName}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QRemoteObjectHostBase[] = {
    {sipName_BuiltInSchemasOnly, static_cast<int>(::QRemoteObjectHostBase::BuiltInSchemasOnly)},
    {sipName_AllowExternalRegistration, static_cast<int>(::QRemoteObjectHostBase::AllowExternalRegistration)},
    {0, 0}
};


static pyqt6ClassPluginDef plugin_QRemoteObjectHostBase = {
    &::QRemoteObjectHostBase::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectHostBase = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRemoteObjectHostBase,
        SIP_NULLPTR,
        &plugin_QRemoteObjectHostBase,
    },
    {
        sipNameNr_QRemoteObjectHostBase,
        {0, 0, 1},
        6, methods_QRemoteObjectHostBase,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QRemoteObjectHostBase, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QRemoteObjectHostBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRemoteObjectHostBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QRemoteObjectHostBase,
    cast_QRemoteObjectHostBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
