/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtWebSocketsAPI_H
#define _QtWebSocketsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtWebSockets[0]
#define sipNameNr_preSharedKeyAuthenticationRequired 35
#define sipName_preSharedKeyAuthenticationRequired &sipStrings_QtWebSockets[35]
#define sipNameNr_setMaxAllowedIncomingMessageSize 70
#define sipName_setMaxAllowedIncomingMessageSize &sipStrings_QtWebSockets[70]
#define sipNameNr_CloseCodeAbnormalDisconnection 103
#define sipName_CloseCodeAbnormalDisconnection &sipStrings_QtWebSockets[103]
#define sipNameNr_setMaxAllowedIncomingFrameSize 134
#define sipName_setMaxAllowedIncomingFrameSize &sipStrings_QtWebSockets[134]
#define sipNameNr_CloseCodeDatatypeNotSupported 165
#define sipName_CloseCodeDatatypeNotSupported &sipStrings_QtWebSockets[165]
#define sipNameNr_QWebSocketProtocol__CloseCode 195
#define sipName_QWebSocketProtocol__CloseCode &sipStrings_QtWebSockets[195]
#define sipNameNr_maxAllowedIncomingMessageSize 225
#define sipName_maxAllowedIncomingMessageSize &sipStrings_QtWebSockets[225]
#define sipNameNr_continueInterruptedHandshake 255
#define sipName_continueInterruptedHandshake &sipStrings_QtWebSockets[255]
#define sipNameNr_originAuthenticationRequired 284
#define sipName_originAuthenticationRequired &sipStrings_QtWebSockets[284]
#define sipNameNr_CloseCodeTlsHandshakeFailed 313
#define sipName_CloseCodeTlsHandshakeFailed &sipStrings_QtWebSockets[313]
#define sipNameNr_QWebSocketCorsAuthenticator 341
#define sipName_QWebSocketCorsAuthenticator &sipStrings_QtWebSockets[341]
#define sipNameNr_QWebSocketProtocol__Version 369
#define sipName_QWebSocketProtocol__Version &sipStrings_QtWebSockets[369]
#define sipNameNr_handshakeInterruptedOnError 397
#define sipName_handshakeInterruptedOnError &sipStrings_QtWebSockets[397]
#define sipNameNr_maxAllowedIncomingFrameSize 425
#define sipName_maxAllowedIncomingFrameSize &sipStrings_QtWebSockets[425]
#define sipNameNr_proxyAuthenticationRequired 453
#define sipName_proxyAuthenticationRequired &sipStrings_QtWebSockets[453]
#define sipNameNr_CloseCodeMissingStatusCode 481
#define sipName_CloseCodeMissingStatusCode &sipStrings_QtWebSockets[481]
#define sipNameNr_QWebSocketHandshakeOptions 508
#define sipName_QWebSocketHandshakeOptions &sipStrings_QtWebSockets[508]
#define sipNameNr_CloseCodeMissingExtension 535
#define sipName_CloseCodeMissingExtension &sipStrings_QtWebSockets[535]
#define sipNameNr_QWebSocketServer__SslMode 561
#define sipName_QWebSocketServer__SslMode &sipStrings_QtWebSockets[561]
#define sipNameNr_setMaxPendingConnections 587
#define sipName_setMaxPendingConnections &sipStrings_QtWebSockets[587]
#define sipNameNr_setSupportedSubprotocols 612
#define sipName_setSupportedSubprotocols &sipStrings_QtWebSockets[612]
#define sipNameNr_CloseCodePolicyViolated 637
#define sipName_CloseCodePolicyViolated &sipStrings_QtWebSockets[637]
#define sipNameNr_PyQt6_sip_simplewrapper 661
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtWebSockets[661]
#define sipNameNr_CloseCodeProtocolError 685
#define sipName_CloseCodeProtocolError &sipStrings_QtWebSockets[685]
#define sipNameNr_CloseCodeWrongDatatype 708
#define sipName_CloseCodeWrongDatatype &sipStrings_QtWebSockets[708]
#define sipNameNr_authenticationRequired 731
#define sipName_authenticationRequired &sipStrings_QtWebSockets[731]
#define sipNameNr_maxIncomingMessageSize 754
#define sipName_maxIncomingMessageSize &sipStrings_QtWebSockets[754]
#define sipNameNr_CloseCodeBadOperation 777
#define sipName_CloseCodeBadOperation &sipStrings_QtWebSockets[777]
#define sipNameNr_CloseCodeReserved1004 799
#define sipName_CloseCodeReserved1004 &sipStrings_QtWebSockets[799]
#define sipNameNr_binaryMessageReceived 821
#define sipName_binaryMessageReceived &sipStrings_QtWebSockets[821]
#define sipNameNr_hasPendingConnections 843
#define sipName_hasPendingConnections &sipStrings_QtWebSockets[843]
#define sipNameNr_maxPendingConnections 865
#define sipName_maxPendingConnections &sipStrings_QtWebSockets[865]
#define sipNameNr_nextPendingConnection 887
#define sipName_nextPendingConnection &sipStrings_QtWebSockets[887]
#define sipNameNr_supportedSubprotocols 909
#define sipName_supportedSubprotocols &sipStrings_QtWebSockets[909]
#define sipNameNr_CloseCodeTooMuchData 931
#define sipName_CloseCodeTooMuchData &sipStrings_QtWebSockets[931]
#define sipNameNr_maxIncomingFrameSize 952
#define sipName_maxIncomingFrameSize &sipStrings_QtWebSockets[952]
#define sipNameNr_maxOutgoingFrameSize 973
#define sipName_maxOutgoingFrameSize &sipStrings_QtWebSockets[973]
#define sipNameNr_setOutgoingFrameSize 994
#define sipName_setOutgoingFrameSize &sipStrings_QtWebSockets[994]
#define sipNameNr_binaryFrameReceived 1015
#define sipName_binaryFrameReceived &sipStrings_QtWebSockets[1015]
#define sipNameNr_readChannelFinished 1035
#define sipName_readChannelFinished &sipStrings_QtWebSockets[1035]
#define sipNameNr_setHandshakeTimeout 1055
#define sipName_setHandshakeTimeout &sipStrings_QtWebSockets[1055]
#define sipNameNr_setSocketDescriptor 1075
#define sipName_setSocketDescriptor &sipStrings_QtWebSockets[1075]
#define sipNameNr_setSslConfiguration 1095
#define sipName_setSslConfiguration &sipStrings_QtWebSockets[1095]
#define sipNameNr_textMessageReceived 1115
#define sipName_textMessageReceived &sipStrings_QtWebSockets[1115]
#define sipNameNr_CloseCodeGoingAway 1135
#define sipName_CloseCodeGoingAway &sipStrings_QtWebSockets[1135]
#define sipNameNr_PyQt6_QtWebSockets 1154
#define sipName_PyQt6_QtWebSockets &sipStrings_QtWebSockets[1154]
#define sipNameNr_QWebSocketProtocol 1173
#define sipName_QWebSocketProtocol &sipStrings_QtWebSockets[1173]
#define sipNameNr_handshakeTimeoutMS 1192
#define sipName_handshakeTimeoutMS &sipStrings_QtWebSockets[1192]
#define sipNameNr_outgoingFrameSize 1211
#define sipName_outgoingFrameSize &sipStrings_QtWebSockets[1211]
#define sipNameNr_sendBinaryMessage 1229
#define sipName_sendBinaryMessage &sipStrings_QtWebSockets[1229]
#define sipNameNr_setReadBufferSize 1247
#define sipName_setReadBufferSize &sipStrings_QtWebSockets[1247]
#define sipNameNr_sslErrorsOccurred 1265
#define sipName_sslErrorsOccurred &sipStrings_QtWebSockets[1265]
#define sipNameNr_supportedVersions 1283
#define sipName_supportedVersions &sipStrings_QtWebSockets[1283]
#define sipNameNr_textFrameReceived 1301
#define sipName_textFrameReceived &sipStrings_QtWebSockets[1301]
#define sipNameNr_QWebSocketServer 1319
#define sipName_QWebSocketServer &sipStrings_QtWebSockets[1319]
#define sipNameNr_disconnectNotify 1336
#define sipName_disconnectNotify &sipStrings_QtWebSockets[1336]
#define sipNameNr_handleConnection 1353
#define sipName_handleConnection &sipStrings_QtWebSockets[1353]
#define sipNameNr_handshakeOptions 1370
#define sipName_handshakeOptions &sipStrings_QtWebSockets[1370]
#define sipNameNr_setMaskGenerator 1387
#define sipName_setMaskGenerator &sipStrings_QtWebSockets[1387]
#define sipNameNr_socketDescriptor 1404
#define sipName_socketDescriptor &sipStrings_QtWebSockets[1404]
#define sipNameNr_sslConfiguration 1421
#define sipName_sslConfiguration &sipStrings_QtWebSockets[1421]
#define sipNameNr_CloseCodeNormal 1438
#define sipName_CloseCodeNormal &sipStrings_QtWebSockets[1438]
#define sipNameNr_ignoreSslErrors 1454
#define sipName_ignoreSslErrors &sipStrings_QtWebSockets[1454]
#define sipNameNr_peerVerifyError 1470
#define sipName_peerVerifyError &sipStrings_QtWebSockets[1470]
#define sipNameNr_resumeAccepting 1486
#define sipName_resumeAccepting &sipStrings_QtWebSockets[1486]
#define sipNameNr_sendTextMessage 1502
#define sipName_sendTextMessage &sipStrings_QtWebSockets[1502]
#define sipNameNr_setSubprotocols 1518
#define sipName_setSubprotocols &sipStrings_QtWebSockets[1518]
#define sipNameNr_QMaskGenerator 1534
#define sipName_QMaskGenerator &sipStrings_QtWebSockets[1534]
#define sipNameNr_VersionUnknown 1549
#define sipName_VersionUnknown &sipStrings_QtWebSockets[1549]
#define sipNameNr_pauseAccepting 1564
#define sipName_pauseAccepting &sipStrings_QtWebSockets[1564]
#define sipNameNr_readBufferSize 1579
#define sipName_readBufferSize &sipStrings_QtWebSockets[1579]
#define sipNameNr_NonSecureMode 1594
#define sipName_NonSecureMode &sipStrings_QtWebSockets[1594]
#define sipNameNr_VersionLatest 1608
#define sipName_VersionLatest &sipStrings_QtWebSockets[1608]
#define sipNameNr_alertReceived 1622
#define sipName_alertReceived &sipStrings_QtWebSockets[1622]
#define sipNameNr_connectNotify 1339
#define sipName_connectNotify &sipStrings_QtWebSockets[1339]
#define sipNameNr_errorOccurred 1636
#define sipName_errorOccurred &sipStrings_QtWebSockets[1636]
#define sipNameNr_maskGenerator 1650
#define sipName_maskGenerator &sipStrings_QtWebSockets[1650]
#define sipNameNr_newConnection 1664
#define sipName_newConnection &sipStrings_QtWebSockets[1664]
#define sipNameNr_serverAddress 1678
#define sipName_serverAddress &sipStrings_QtWebSockets[1678]
#define sipNameNr_setServerName 1692
#define sipName_setServerName &sipStrings_QtWebSockets[1692]
#define sipNameNr_aboutToClose 1706
#define sipName_aboutToClose &sipStrings_QtWebSockets[1706]
#define sipNameNr_bytesToWrite 1719
#define sipName_bytesToWrite &sipStrings_QtWebSockets[1719]
#define sipNameNr_bytesWritten 1732
#define sipName_bytesWritten &sipStrings_QtWebSockets[1732]
#define sipNameNr_disconnected 1745
#define sipName_disconnected &sipStrings_QtWebSockets[1745]
#define sipNameNr_localAddress 1758
#define sipName_localAddress &sipStrings_QtWebSockets[1758]
#define sipNameNr_resourceName 1771
#define sipName_resourceName &sipStrings_QtWebSockets[1771]
#define sipNameNr_setPauseMode 1784
#define sipName_setPauseMode &sipStrings_QtWebSockets[1784]
#define sipNameNr_stateChanged 1797
#define sipName_stateChanged &sipStrings_QtWebSockets[1797]
#define sipNameNr_subprotocols 1810
#define sipName_subprotocols &sipStrings_QtWebSockets[1810]
#define sipNameNr_acceptError 1823
#define sipName_acceptError &sipStrings_QtWebSockets[1823]
#define sipNameNr_closeReason 1835
#define sipName_closeReason &sipStrings_QtWebSockets[1835]
#define sipNameNr_customEvent 1847
#define sipName_customEvent &sipStrings_QtWebSockets[1847]
#define sipNameNr_errorString 1859
#define sipName_errorString &sipStrings_QtWebSockets[1859]
#define sipNameNr_eventFilter 1871
#define sipName_eventFilter &sipStrings_QtWebSockets[1871]
#define sipNameNr_isListening 1883
#define sipName_isListening &sipStrings_QtWebSockets[1883]
#define sipNameNr_peerAddress 1895
#define sipName_peerAddress &sipStrings_QtWebSockets[1895]
#define sipNameNr_serverError 1907
#define sipName_serverError &sipStrings_QtWebSockets[1907]
#define sipNameNr_subprotocol 1919
#define sipName_subprotocol &sipStrings_QtWebSockets[1919]
#define sipNameNr_QWebSocket 1931
#define sipName_QWebSocket &sipStrings_QtWebSockets[1931]
#define sipNameNr_SecureMode 1597
#define sipName_SecureMode &sipStrings_QtWebSockets[1597]
#define sipNameNr_childEvent 1942
#define sipName_childEvent &sipStrings_QtWebSockets[1942]
#define sipNameNr_requestUrl 1953
#define sipName_requestUrl &sipStrings_QtWebSockets[1953]
#define sipNameNr_secureMode 1964
#define sipName_secureMode &sipStrings_QtWebSockets[1964]
#define sipNameNr_serverName 1975
#define sipName_serverName &sipStrings_QtWebSockets[1975]
#define sipNameNr_serverPort 1986
#define sipName_serverPort &sipStrings_QtWebSockets[1986]
#define sipNameNr_setAllowed 1997
#define sipName_setAllowed &sipStrings_QtWebSockets[1997]
#define sipNameNr_timerEvent 2008
#define sipName_timerEvent &sipStrings_QtWebSockets[2008]
#define sipNameNr_CloseCode 215
#define sipName_CloseCode &sipStrings_QtWebSockets[215]
#define sipNameNr_Version13 2019
#define sipName_Version13 &sipStrings_QtWebSockets[2019]
#define sipNameNr_alertSent 2029
#define sipName_alertSent &sipStrings_QtWebSockets[2029]
#define sipNameNr_closeCode 2039
#define sipName_closeCode &sipStrings_QtWebSockets[2039]
#define sipNameNr_connected 1748
#define sipName_connected &sipStrings_QtWebSockets[1748]
#define sipNameNr_localPort 2049
#define sipName_localPort &sipStrings_QtWebSockets[2049]
#define sipNameNr_pauseMode 2059
#define sipName_pauseMode &sipStrings_QtWebSockets[2059]
#define sipNameNr_serverUrl 2069
#define sipName_serverUrl &sipStrings_QtWebSockets[2069]
#define sipNameNr_sslErrors 2079
#define sipName_sslErrors &sipStrings_QtWebSockets[2079]
#define sipNameNr_Version0 2089
#define sipName_Version0 &sipStrings_QtWebSockets[2089]
#define sipNameNr_Version4 2098
#define sipName_Version4 &sipStrings_QtWebSockets[2098]
#define sipNameNr_Version5 2107
#define sipName_Version5 &sipStrings_QtWebSockets[2107]
#define sipNameNr_Version6 2116
#define sipName_Version6 &sipStrings_QtWebSockets[2116]
#define sipNameNr_Version7 2125
#define sipName_Version7 &sipStrings_QtWebSockets[2125]
#define sipNameNr_Version8 2134
#define sipName_Version8 &sipStrings_QtWebSockets[2134]
#define sipNameNr_nextMask 2143
#define sipName_nextMask &sipStrings_QtWebSockets[2143]
#define sipNameNr_peerName 2152
#define sipName_peerName &sipStrings_QtWebSockets[2152]
#define sipNameNr_peerPort 2161
#define sipName_peerPort &sipStrings_QtWebSockets[2161]
#define sipNameNr_setProxy 2170
#define sipName_setProxy &sipStrings_QtWebSockets[2170]
#define sipNameNr_SslMode 579
#define sipName_SslMode &sipStrings_QtWebSockets[579]
#define sipNameNr_Version 389
#define sipName_Version &sipStrings_QtWebSockets[389]
#define sipNameNr_address 2179
#define sipName_address &sipStrings_QtWebSockets[2179]
#define sipNameNr_allowed 2187
#define sipName_allowed &sipStrings_QtWebSockets[2187]
#define sipNameNr_isValid 2195
#define sipName_isValid &sipStrings_QtWebSockets[2195]
#define sipNameNr_payload 2203
#define sipName_payload &sipStrings_QtWebSockets[2203]
#define sipNameNr_request 2211
#define sipName_request &sipStrings_QtWebSockets[2211]
#define sipNameNr_version 2219
#define sipName_version &sipStrings_QtWebSockets[2219]
#define sipNameNr___eq__ 2227
#define sipName___eq__ &sipStrings_QtWebSockets[2227]
#define sipNameNr___ne__ 2234
#define sipName___ne__ &sipStrings_QtWebSockets[2234]
#define sipNameNr_closed 2241
#define sipName_closed &sipStrings_QtWebSockets[2241]
#define sipNameNr_listen 2248
#define sipName_listen &sipStrings_QtWebSockets[2248]
#define sipNameNr_origin 2255
#define sipName_origin &sipStrings_QtWebSockets[2255]
#define sipNameNr_parent 2262
#define sipName_parent &sipStrings_QtWebSockets[2262]
#define sipNameNr_reason 2269
#define sipName_reason &sipStrings_QtWebSockets[2269]
#define sipNameNr_resume 2276
#define sipName_resume &sipStrings_QtWebSockets[2276]
#define sipNameNr_abort 2283
#define sipName_abort &sipStrings_QtWebSockets[2283]
#define sipNameNr_close 2289
#define sipName_close &sipStrings_QtWebSockets[2289]
#define sipNameNr_error 2295
#define sipName_error &sipStrings_QtWebSockets[2295]
#define sipNameNr_event 2301
#define sipName_event &sipStrings_QtWebSockets[2301]
#define sipNameNr_flush 2307
#define sipName_flush &sipStrings_QtWebSockets[2307]
#define sipNameNr_proxy 2313
#define sipName_proxy &sipStrings_QtWebSockets[2313]
#define sipNameNr_state 2319
#define sipName_state &sipStrings_QtWebSockets[2319]
#define sipNameNr_open 2325
#define sipName_open &sipStrings_QtWebSockets[2325]
#define sipNameNr_ping 2330
#define sipName_ping &sipStrings_QtWebSockets[2330]
#define sipNameNr_pong 2335
#define sipName_pong &sipStrings_QtWebSockets[2335]
#define sipNameNr_port 2340
#define sipName_port &sipStrings_QtWebSockets[2340]
#define sipNameNr_seed 2345
#define sipName_seed &sipStrings_QtWebSockets[2345]
#define sipNameNr_swap 2350
#define sipName_swap &sipStrings_QtWebSockets[2350]

#define sipMalloc                   sipAPI_QtWebSockets->api_malloc
#define sipFree                     sipAPI_QtWebSockets->api_free
#define sipBuildResult              sipAPI_QtWebSockets->api_build_result
#define sipCallMethod               sipAPI_QtWebSockets->api_call_method
#define sipCallProcedureMethod      sipAPI_QtWebSockets->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtWebSockets->api_call_error_handler
#define sipParseResultEx            sipAPI_QtWebSockets->api_parse_result_ex
#define sipParseResult              sipAPI_QtWebSockets->api_parse_result
#define sipParseArgs                sipAPI_QtWebSockets->api_parse_args
#define sipParseKwdArgs             sipAPI_QtWebSockets->api_parse_kwd_args
#define sipParsePair                sipAPI_QtWebSockets->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtWebSockets->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtWebSockets->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtWebSockets->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtWebSockets->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtWebSockets->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtWebSockets->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtWebSockets->api_add_exception
#define sipNoFunction               sipAPI_QtWebSockets->api_no_function
#define sipNoMethod                 sipAPI_QtWebSockets->api_no_method
#define sipAbstractMethod           sipAPI_QtWebSockets->api_abstract_method
#define sipBadClass                 sipAPI_QtWebSockets->api_bad_class
#define sipBadCatcherResult         sipAPI_QtWebSockets->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtWebSockets->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtWebSockets->api_bad_operator_arg
#define sipTrace                    sipAPI_QtWebSockets->api_trace
#define sipTransferBack             sipAPI_QtWebSockets->api_transfer_back
#define sipTransferTo               sipAPI_QtWebSockets->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtWebSockets->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtWebSockets->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtWebSockets->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtWebSockets->api_voidptr_type
#define sipGetPyObject              sipAPI_QtWebSockets->api_get_pyobject
#define sipGetAddress               sipAPI_QtWebSockets->api_get_address
#define sipGetMixinAddress          sipAPI_QtWebSockets->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtWebSockets->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtWebSockets->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtWebSockets->api_call_hook
#define sipEndThread                sipAPI_QtWebSockets->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtWebSockets->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtWebSockets->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtWebSockets->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtWebSockets->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtWebSockets->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtWebSockets->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtWebSockets->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtWebSockets->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtWebSockets->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtWebSockets->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtWebSockets->api_convert_to_bool
#define sipReleaseType              sipAPI_QtWebSockets->api_release_type
#define sipConvertFromType          sipAPI_QtWebSockets->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtWebSockets->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtWebSockets->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtWebSockets->api_convert_from_enum
#define sipGetState                 sipAPI_QtWebSockets->api_get_state
#define sipExportSymbol             sipAPI_QtWebSockets->api_export_symbol
#define sipImportSymbol             sipAPI_QtWebSockets->api_import_symbol
#define sipFindType                 sipAPI_QtWebSockets->api_find_type
#define sipBytes_AsChar             sipAPI_QtWebSockets->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtWebSockets->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtWebSockets->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtWebSockets->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtWebSockets->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtWebSockets->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtWebSockets->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtWebSockets->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtWebSockets->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtWebSockets->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtWebSockets->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtWebSockets->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtWebSockets->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtWebSockets->api_get_reference
#define sipKeepReference            sipAPI_QtWebSockets->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtWebSockets->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtWebSockets->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtWebSockets->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtWebSockets->api_type_scope
#define sipResolveTypedef           sipAPI_QtWebSockets->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtWebSockets->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtWebSockets->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtWebSockets->api_init_mixin
#define sipExportModule             sipAPI_QtWebSockets->api_export_module
#define sipInitModule               sipAPI_QtWebSockets->api_init_module
#define sipGetInterpreter           sipAPI_QtWebSockets->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtWebSockets->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtWebSockets->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtWebSockets->api_py_type_dict
#define sipPyTypeName               sipAPI_QtWebSockets->api_py_type_name
#define sipGetCFunction             sipAPI_QtWebSockets->api_get_c_function
#define sipGetMethod                sipAPI_QtWebSockets->api_get_method
#define sipFromMethod               sipAPI_QtWebSockets->api_from_method
#define sipGetDate                  sipAPI_QtWebSockets->api_get_date
#define sipFromDate                 sipAPI_QtWebSockets->api_from_date
#define sipGetDateTime              sipAPI_QtWebSockets->api_get_datetime
#define sipFromDateTime             sipAPI_QtWebSockets->api_from_datetime
#define sipGetTime                  sipAPI_QtWebSockets->api_get_time
#define sipFromTime                 sipAPI_QtWebSockets->api_from_time
#define sipIsUserType               sipAPI_QtWebSockets->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtWebSockets->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtWebSockets->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtWebSockets->api_unicode_write
#define sipUnicodeData              sipAPI_QtWebSockets->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtWebSockets->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtWebSockets->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtWebSockets->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtWebSockets->api_is_derived_class
#define sipGetUserObject            sipAPI_QtWebSockets->api_get_user_object
#define sipSetUserObject            sipAPI_QtWebSockets->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtWebSockets->api_register_event_handler
#define sipConvertToArray           sipAPI_QtWebSockets->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtWebSockets->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtWebSockets->api_enable_gc
#define sipPrintObject              sipAPI_QtWebSockets->api_print_object
#define sipLong_AsChar              sipAPI_QtWebSockets->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtWebSockets->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtWebSockets->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtWebSockets->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtWebSockets->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtWebSockets->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtWebSockets->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtWebSockets->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtWebSockets->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtWebSockets->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtWebSockets->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtWebSockets->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtWebSockets->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtWebSockets->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtWebSockets->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtWebSockets->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtWebSockets->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtWebSockets->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtWebSockets->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtWebSockets->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtWebSockets->api_release_type_us
#define sipIsPyMethod               sipAPI_QtWebSockets->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtWebSockets[];

#define sipType_QMaskGenerator sipExportedTypes_QtWebSockets[1]

extern sipClassTypeDef sipTypeDef_QtWebSockets_QMaskGenerator;

#define sipType_QWebSocket sipExportedTypes_QtWebSockets[2]

extern sipClassTypeDef sipTypeDef_QtWebSockets_QWebSocket;

#define sipType_QWebSocketCorsAuthenticator sipExportedTypes_QtWebSockets[3]

extern sipClassTypeDef sipTypeDef_QtWebSockets_QWebSocketCorsAuthenticator;

#define sipType_QWebSocketHandshakeOptions sipExportedTypes_QtWebSockets[4]

extern sipClassTypeDef sipTypeDef_QtWebSockets_QWebSocketHandshakeOptions;

#define sipType_QWebSocketProtocol sipExportedTypes_QtWebSockets[5]

#define sipType_QWebSocketProtocol_CloseCode sipExportedTypes_QtWebSockets[6]

#define sipType_QWebSocketProtocol_Version sipExportedTypes_QtWebSockets[7]

extern sipClassTypeDef sipTypeDef_QtWebSockets_QWebSocketProtocol;

#define sipType_QWebSocketServer sipExportedTypes_QtWebSockets[8]

#define sipType_QWebSocketServer_SslMode sipExportedTypes_QtWebSockets[9]

extern sipClassTypeDef sipTypeDef_QtWebSockets_QWebSocketServer;

#define sipType_QList_0100QWebSocketProtocol_Version sipExportedTypes_QtWebSockets[0]

extern sipMappedTypeDef sipTypeDef_QtWebSockets_QList_0100QWebSocketProtocol_Version;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtWebSockets;
extern sipExportedModuleDef sipModuleAPI_QtWebSockets;
extern sipTypeDef *sipExportedTypes_QtWebSockets[];

#define sipType_QObject sipImportedTypes_QtWebSockets_QtCore[4].it_td

#define sipType_QByteArray sipImportedTypes_QtWebSockets_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtWebSockets_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtWebSockets_QtCore[7].it_td

#define sipType_QChildEvent sipImportedTypes_QtWebSockets_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtWebSockets_QtCore[3].it_td

#define sipType_QUrl sipImportedTypes_QtWebSockets_QtCore[8].it_td

#define sipType_QStringList sipImportedTypes_QtWebSockets_QtCore[6].it_td

#define sipType_QString sipImportedTypes_QtWebSockets_QtCore[5].it_td

#define sipType_qintptr sipImportedTypes_QtWebSockets_QtCore[9].it_td
extern sipImportedTypeDef sipImportedTypes_QtWebSockets_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtWebSockets_QtCore[];

#define sipType_QAbstractSocket_SocketState sipImportedTypes_QtWebSockets_QtNetwork[1].it_td

#define sipType_QAbstractSocket_SocketError sipImportedTypes_QtWebSockets_QtNetwork[0].it_td

#define sipType_QAuthenticator sipImportedTypes_QtWebSockets_QtNetwork[2].it_td

#define sipType_QHostAddress sipImportedTypes_QtWebSockets_QtNetwork[4].it_td

#define sipType_QNetworkProxy sipImportedTypes_QtWebSockets_QtNetwork[6].it_td

#define sipType_QNetworkRequest sipImportedTypes_QtWebSockets_QtNetwork[7].it_td

#define sipType_QSsl_AlertType sipImportedTypes_QtWebSockets_QtNetwork[9].it_td

#define sipType_QSsl_AlertLevel sipImportedTypes_QtWebSockets_QtNetwork[8].it_td

#define sipType_QSslConfiguration sipImportedTypes_QtWebSockets_QtNetwork[10].it_td

#define sipType_QSslError sipImportedTypes_QtWebSockets_QtNetwork[11].it_td

#define sipType_QSslPreSharedKeyAuthenticator sipImportedTypes_QtWebSockets_QtNetwork[12].it_td

#define sipType_QTcpSocket sipImportedTypes_QtWebSockets_QtNetwork[14].it_td

#define sipType_QSslSocket sipImportedTypes_QtWebSockets_QtNetwork[13].it_td

#define sipType_QList_0100QSslError sipImportedTypes_QtWebSockets_QtNetwork[5].it_td

#define sipType_QFlags_0100QAbstractSocket_PauseMode sipImportedTypes_QtWebSockets_QtNetwork[3].it_td
extern sipImportedTypeDef sipImportedTypes_QtWebSockets_QtNetwork[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtWebSockets_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtWebSockets_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtWebSockets_qt_metacast;

#endif
