/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtHelp.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qcompressedhelpinfo.sip"
#include <qcompressedhelpinfo.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQCompressedHelpInfo.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQCompressedHelpInfo.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qversionnumber.sip"
#include <qversionnumber.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQCompressedHelpInfo.cpp"


PyDoc_STRVAR(doc_QCompressedHelpInfo_swap, "swap(self, other: QCompressedHelpInfo)");

extern "C" {static PyObject *meth_QCompressedHelpInfo_swap(PyObject *, PyObject *);}
static PyObject *meth_QCompressedHelpInfo_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCompressedHelpInfo* a0;
        ::QCompressedHelpInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QCompressedHelpInfo, &sipCpp, sipType_QCompressedHelpInfo, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCompressedHelpInfo, sipName_swap, doc_QCompressedHelpInfo_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCompressedHelpInfo_namespaceName, "namespaceName(self) -> str");

extern "C" {static PyObject *meth_QCompressedHelpInfo_namespaceName(PyObject *, PyObject *);}
static PyObject *meth_QCompressedHelpInfo_namespaceName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCompressedHelpInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCompressedHelpInfo, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->namespaceName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCompressedHelpInfo, sipName_namespaceName, doc_QCompressedHelpInfo_namespaceName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCompressedHelpInfo_component, "component(self) -> str");

extern "C" {static PyObject *meth_QCompressedHelpInfo_component(PyObject *, PyObject *);}
static PyObject *meth_QCompressedHelpInfo_component(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCompressedHelpInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCompressedHelpInfo, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->component());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCompressedHelpInfo, sipName_component, doc_QCompressedHelpInfo_component);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCompressedHelpInfo_version, "version(self) -> QVersionNumber");

extern "C" {static PyObject *meth_QCompressedHelpInfo_version(PyObject *, PyObject *);}
static PyObject *meth_QCompressedHelpInfo_version(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCompressedHelpInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCompressedHelpInfo, &sipCpp))
        {
            ::QVersionNumber*sipRes;

            sipRes = new ::QVersionNumber(sipCpp->version());

            return sipConvertFromNewType(sipRes, sipType_QVersionNumber, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCompressedHelpInfo, sipName_version, doc_QCompressedHelpInfo_version);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCompressedHelpInfo_fromCompressedHelpFile, "fromCompressedHelpFile(documentationFileName: str|None) -> QCompressedHelpInfo");

extern "C" {static PyObject *meth_QCompressedHelpInfo_fromCompressedHelpFile(PyObject *, PyObject *);}
static PyObject *meth_QCompressedHelpInfo_fromCompressedHelpFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QCompressedHelpInfo*sipRes;

            sipRes = new ::QCompressedHelpInfo(::QCompressedHelpInfo::fromCompressedHelpFile(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QCompressedHelpInfo, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCompressedHelpInfo, sipName_fromCompressedHelpFile, doc_QCompressedHelpInfo_fromCompressedHelpFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCompressedHelpInfo_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QCompressedHelpInfo_isNull(PyObject *, PyObject *);}
static PyObject *meth_QCompressedHelpInfo_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCompressedHelpInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCompressedHelpInfo, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCompressedHelpInfo, sipName_isNull, doc_QCompressedHelpInfo_isNull);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCompressedHelpInfo(void *, int);}
static void release_QCompressedHelpInfo(void *sipCppV, int)
{
    delete reinterpret_cast< ::QCompressedHelpInfo *>(sipCppV);
}


extern "C" {static void *array_QCompressedHelpInfo(Py_ssize_t);}
static void *array_QCompressedHelpInfo(Py_ssize_t sipNrElem)
{
    return new ::QCompressedHelpInfo[sipNrElem];
}


extern "C" {static void array_delete_QCompressedHelpInfo(void *);}
static void array_delete_QCompressedHelpInfo(void *sipCpp)
{
    delete[] reinterpret_cast< ::QCompressedHelpInfo *>(sipCpp);
}


extern "C" {static void assign_QCompressedHelpInfo(void *, Py_ssize_t, void *);}
static void assign_QCompressedHelpInfo(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QCompressedHelpInfo *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QCompressedHelpInfo *>(sipSrc);
}


extern "C" {static void *copy_QCompressedHelpInfo(const void *, Py_ssize_t);}
static void *copy_QCompressedHelpInfo(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QCompressedHelpInfo(reinterpret_cast<const ::QCompressedHelpInfo *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QCompressedHelpInfo(sipSimpleWrapper *);}
static void dealloc_QCompressedHelpInfo(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCompressedHelpInfo(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QCompressedHelpInfo(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCompressedHelpInfo(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QCompressedHelpInfo *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QCompressedHelpInfo();

            return sipCpp;
        }
    }

    {
        const ::QCompressedHelpInfo* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QCompressedHelpInfo, &a0))
        {
            sipCpp = new ::QCompressedHelpInfo(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QCompressedHelpInfo[] = {
    {sipName_component, meth_QCompressedHelpInfo_component, METH_VARARGS, doc_QCompressedHelpInfo_component},
    {sipName_fromCompressedHelpFile, meth_QCompressedHelpInfo_fromCompressedHelpFile, METH_VARARGS, doc_QCompressedHelpInfo_fromCompressedHelpFile},
    {sipName_isNull, meth_QCompressedHelpInfo_isNull, METH_VARARGS, doc_QCompressedHelpInfo_isNull},
    {sipName_namespaceName, meth_QCompressedHelpInfo_namespaceName, METH_VARARGS, doc_QCompressedHelpInfo_namespaceName},
    {sipName_swap, meth_QCompressedHelpInfo_swap, METH_VARARGS, doc_QCompressedHelpInfo_swap},
    {sipName_version, meth_QCompressedHelpInfo_version, METH_VARARGS, doc_QCompressedHelpInfo_version}
};

PyDoc_STRVAR(doc_QCompressedHelpInfo, "\1QCompressedHelpInfo()\n"
"QCompressedHelpInfo(other: QCompressedHelpInfo)");


sipClassTypeDef sipTypeDef_QtHelp_QCompressedHelpInfo = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCompressedHelpInfo,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QCompressedHelpInfo,
        {0, 0, 1},
        6, methods_QCompressedHelpInfo,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCompressedHelpInfo,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QCompressedHelpInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCompressedHelpInfo,
    assign_QCompressedHelpInfo,
    array_QCompressedHelpInfo,
    copy_QCompressedHelpInfo,
    release_QCompressedHelpInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QCompressedHelpInfo,
    sizeof (::QCompressedHelpInfo),
};
