/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtDesignerAPI_H
#define _QtDesignerAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QDesignerFormWindowCursorInterface__MoveOperation 0
#define sipName_QDesignerFormWindowCursorInterface__MoveOperation &sipStrings_QtDesigner[0]
#define sipNameNr_50 50
#define sipName_50 &sipStrings_QtDesigner[50]
#define sipNameNr_QDesignerFormWindowManagerInterface__ActionGroup 100
#define sipName_QDesignerFormWindowManagerInterface__ActionGroup &sipStrings_QtDesigner[100]
#define sipNameNr_QDesignerFormWindowCursorInterface__MoveMode 149
#define sipName_QDesignerFormWindowCursorInterface__MoveMode &sipStrings_QtDesigner[149]
#define sipNameNr_QDesignerFormWindowManagerInterface__Action 194
#define sipName_QDesignerFormWindowManagerInterface__Action &sipStrings_QtDesigner[194]
#define sipNameNr_QDesignerFormWindowInterface__FeatureFlag 238
#define sipName_QDesignerFormWindowInterface__FeatureFlag &sipStrings_QtDesigner[238]
#define sipNameNr_QDesignerCustomWidgetCollectionInterface 280
#define sipName_QDesignerCustomWidgetCollectionInterface &sipStrings_QtDesigner[280]
#define sipNameNr_QPyDesignerCustomWidgetCollectionPlugin 321
#define sipName_QPyDesignerCustomWidgetCollectionPlugin &sipStrings_QtDesigner[321]
#define sipNameNr_361 361
#define sipName_361 &sipStrings_QtDesigner[361]
#define sipNameNr_QDesignerFormWindowManagerInterface 400
#define sipName_QDesignerFormWindowManagerInterface &sipStrings_QtDesigner[400]
#define sipNameNr_QDesignerFormWindowCursorInterface 436
#define sipName_QDesignerFormWindowCursorInterface &sipStrings_QtDesigner[436]
#define sipNameNr_QDesignerObjectInspectorInterface 471
#define sipName_QDesignerObjectInspectorInterface &sipStrings_QtDesigner[471]
#define sipNameNr_QPyDesignerPropertySheetExtension 505
#define sipName_QPyDesignerPropertySheetExtension &sipStrings_QtDesigner[505]
#define sipNameNr_QDesignerPropertyEditorInterface 539
#define sipName_QDesignerPropertyEditorInterface &sipStrings_QtDesigner[539]
#define sipNameNr_QDesignerPropertySheetExtension 572
#define sipName_QDesignerPropertySheetExtension &sipStrings_QtDesigner[572]
#define sipNameNr_QPyDesignerMemberSheetExtension 604
#define sipName_QPyDesignerMemberSheetExtension &sipStrings_QtDesigner[604]
#define sipNameNr_FormWindowSettingsDialogAction 636
#define sipName_FormWindowSettingsDialogAction &sipStrings_QtDesigner[636]
#define sipNameNr_QDesignerActionEditorInterface 667
#define sipName_QDesignerActionEditorInterface &sipStrings_QtDesigner[667]
#define sipNameNr_QDesignerCustomWidgetInterface 698
#define sipName_QDesignerCustomWidgetInterface &sipStrings_QtDesigner[698]
#define sipNameNr_QDesignerMemberSheetExtension 729
#define sipName_QDesignerMemberSheetExtension &sipStrings_QtDesigner[729]
#define sipNameNr_QPyDesignerContainerExtension 759
#define sipName_QPyDesignerContainerExtension &sipStrings_QtDesigner[759]
#define sipNameNr_QPyDesignerCustomWidgetPlugin 789
#define sipName_QPyDesignerCustomWidgetPlugin &sipStrings_QtDesigner[789]
#define sipNameNr_QDesignerFormEditorInterface 819
#define sipName_QDesignerFormEditorInterface &sipStrings_QtDesigner[819]
#define sipNameNr_QDesignerFormWindowInterface 848
#define sipName_QDesignerFormWindowInterface &sipStrings_QtDesigner[848]
#define sipNameNr_QPyDesignerTaskMenuExtension 877
#define sipName_QPyDesignerTaskMenuExtension &sipStrings_QtDesigner[877]
#define sipNameNr_QDesignerContainerExtension 906
#define sipName_QDesignerContainerExtension &sipStrings_QtDesigner[906]
#define sipNameNr_QDesignerWidgetBoxInterface 934
#define sipName_QDesignerWidgetBoxInterface &sipStrings_QtDesigner[934]
#define sipNameNr_QDesignerTaskMenuExtension 962
#define sipName_QDesignerTaskMenuExtension &sipStrings_QtDesigner[962]
#define sipNameNr_QAbstractExtensionFactory 989
#define sipName_QAbstractExtensionFactory &sipStrings_QtDesigner[989]
#define sipNameNr_QAbstractExtensionManager 1015
#define sipName_QAbstractExtensionManager &sipStrings_QtDesigner[1015]
#define sipNameNr_activateResourceFilePaths 1041
#define sipName_activateResourceFilePaths &sipStrings_QtDesigner[1041]
#define sipNameNr_formWindowSettingsChanged 1067
#define sipName_formWindowSettingsChanged &sipStrings_QtDesigner[1067]
#define sipNameNr_StyledPreviewActionGroup 1093
#define sipName_StyledPreviewActionGroup &sipStrings_QtDesigner[1093]
#define sipNameNr_PyQt6_sip_simplewrapper 1118
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtDesigner[1118]
#define sipNameNr_activeFormWindowChanged 1142
#define sipName_activeFormWindowChanged &sipStrings_QtDesigner[1142]
#define sipNameNr_activeResourceFilePaths 1166
#define sipName_activeResourceFilePaths &sipStrings_QtDesigner[1166]
#define sipNameNr_HorizontalLayoutAction 1190
#define sipName_HorizontalLayoutAction &sipStrings_QtDesigner[1190]
#define sipNameNr_SplitHorizontalAction 1213
#define sipName_SplitHorizontalAction &sipStrings_QtDesigner[1213]
#define sipNameNr_aboutToUnmanageWidget 1235
#define sipName_aboutToUnmanageWidget &sipStrings_QtDesigner[1235]
#define sipNameNr_mouseDoubleClickEvent 1257
#define sipName_mouseDoubleClickEvent &sipStrings_QtDesigner[1257]
#define sipNameNr_DefaultPreviewAction 1279
#define sipName_DefaultPreviewAction &sipStrings_QtDesigner[1279]
#define sipNameNr_QAbstractFormBuilder 1300
#define sipName_QAbstractFormBuilder &sipStrings_QtDesigner[1300]
#define sipNameNr_SimplifyLayoutAction 1321
#define sipName_SimplifyLayoutAction &sipStrings_QtDesigner[1321]
#define sipNameNr_VerticalLayoutAction 1342
#define sipName_VerticalLayoutAction &sipStrings_QtDesigner[1342]
#define sipNameNr_actionSimplifyLayout 1363
#define sipName_actionSimplifyLayout &sipStrings_QtDesigner[1363]
#define sipNameNr_emitSelectionChanged 1384
#define sipName_emitSelectionChanged &sipStrings_QtDesigner[1384]
#define sipNameNr_mainContainerChanged 1405
#define sipName_mainContainerChanged &sipStrings_QtDesigner[1405]
#define sipNameNr_resourceFilesChanged 1426
#define sipName_resourceFilesChanged &sipStrings_QtDesigner[1426]
#define sipNameNr_unregisterExtensions 1447
#define sipName_unregisterExtensions &sipStrings_QtDesigner[1447]
#define sipNameNr_SplitVerticalAction 1468
#define sipName_SplitVerticalAction &sipStrings_QtDesigner[1468]
#define sipNameNr_currentPropertyName 1488
#define sipName_currentPropertyName &sipStrings_QtDesigner[1488]
#define sipNameNr_inheritedFromWidget 1508
#define sipName_inheritedFromWidget &sipStrings_QtDesigner[1508]
#define sipNameNr_preferredEditAction 1528
#define sipName_preferredEditAction &sipStrings_QtDesigner[1528]
#define sipNameNr_resetWidgetProperty 1548
#define sipName_resetWidgetProperty &sipStrings_QtDesigner[1548]
#define sipNameNr_selectedWidgetCount 1568
#define sipName_selectedWidgetCount &sipStrings_QtDesigner[1568]
#define sipNameNr_setActiveFormWindow 1588
#define sipName_setActiveFormWindow &sipStrings_QtDesigner[1588]
#define sipNameNr_setWorkingDirectory 1608
#define sipName_setWorkingDirectory &sipStrings_QtDesigner[1608]
#define sipNameNr_focusNextPrevChild 1628
#define sipName_focusNextPrevChild &sipStrings_QtDesigner[1628]
#define sipNameNr_registerExtensions 1449
#define sipName_registerExtensions &sipStrings_QtDesigner[1449]
#define sipNameNr_removeResourceFile 1647
#define sipName_removeResourceFile &sipStrings_QtDesigner[1647]
#define sipNameNr_setObjectInspector 1666
#define sipName_setObjectInspector &sipStrings_QtDesigner[1666]
#define sipNameNr_BreakLayoutAction 1685
#define sipName_BreakLayoutAction &sipStrings_QtDesigner[1685]
#define sipNameNr_QExtensionFactory 1703
#define sipName_QExtensionFactory &sipStrings_QtDesigner[1703]
#define sipNameNr_QExtensionManager 1721
#define sipName_QExtensionManager &sipStrings_QtDesigner[1721]
#define sipNameNr_formWindowManager 1739
#define sipName_formWindowManager &sipStrings_QtDesigner[1739]
#define sipNameNr_formWindowRemoved 1757
#define sipName_formWindowRemoved &sipStrings_QtDesigner[1757]
#define sipNameNr_hasHeightForWidth 1775
#define sipName_hasHeightForWidth &sipStrings_QtDesigner[1775]
#define sipNameNr_mouseReleaseEvent 1793
#define sipName_mouseReleaseEvent &sipStrings_QtDesigner[1793]
#define sipNameNr_setLayoutFunction 1811
#define sipName_setLayoutFunction &sipStrings_QtDesigner[1811]
#define sipNameNr_setPixmapFunction 1829
#define sipName_setPixmapFunction &sipStrings_QtDesigner[1829]
#define sipNameNr_setPropertyEditor 1847
#define sipName_setPropertyEditor &sipStrings_QtDesigner[1847]
#define sipNameNr_setWidgetProperty 1550
#define sipName_setWidgetProperty &sipStrings_QtDesigner[1550]
#define sipNameNr_AdjustSizeAction 1865
#define sipName_AdjustSizeAction &sipStrings_QtDesigner[1865]
#define sipNameNr_FormLayoutAction 1882
#define sipName_FormLayoutAction &sipStrings_QtDesigner[1882]
#define sipNameNr_GridLayoutAction 1899
#define sipName_GridLayoutAction &sipStrings_QtDesigner[1899]
#define sipNameNr_PyQt6_QtDesigner 1916
#define sipName_PyQt6_QtDesigner &sipStrings_QtDesigner[1916]
#define sipNameNr_actionFormLayout 1933
#define sipName_actionFormLayout &sipStrings_QtDesigner[1933]
#define sipNameNr_activeFormWindow 1950
#define sipName_activeFormWindow &sipStrings_QtDesigner[1950]
#define sipNameNr_clearPluginPaths 1967
#define sipName_clearPluginPaths &sipStrings_QtDesigner[1967]
#define sipNameNr_closeAllPreviews 1984
#define sipName_closeAllPreviews &sipStrings_QtDesigner[1984]
#define sipNameNr_contextMenuEvent 2001
#define sipName_contextMenuEvent &sipStrings_QtDesigner[2001]
#define sipNameNr_createFormWindow 2018
#define sipName_createFormWindow &sipStrings_QtDesigner[2018]
#define sipNameNr_disconnectNotify 2035
#define sipName_disconnectNotify &sipStrings_QtDesigner[2035]
#define sipNameNr_extensionManager 2052
#define sipName_extensionManager &sipStrings_QtDesigner[2052]
#define sipNameNr_inputMethodEvent 2069
#define sipName_inputMethodEvent &sipStrings_QtDesigner[2069]
#define sipNameNr_inputMethodQuery 2086
#define sipName_inputMethodQuery &sipStrings_QtDesigner[2086]
#define sipNameNr_isWidgetSelected 2103
#define sipName_isWidgetSelected &sipStrings_QtDesigner[2103]
#define sipNameNr_removeFormWindow 2120
#define sipName_removeFormWindow &sipStrings_QtDesigner[2120]
#define sipNameNr_selectionChanged 2137
#define sipName_selectionChanged &sipStrings_QtDesigner[2137]
#define sipNameNr_setLayoutDefault 2154
#define sipName_setLayoutDefault &sipStrings_QtDesigner[2154]
#define sipNameNr_setMainContainer 2171
#define sipName_setMainContainer &sipStrings_QtDesigner[2171]
#define sipNameNr_setPropertyGroup 2188
#define sipName_setPropertyGroup &sipStrings_QtDesigner[2188]
#define sipNameNr_setPropertyValue 2205
#define sipName_setPropertyValue &sipStrings_QtDesigner[2205]
#define sipNameNr_showPluginDialog 2222
#define sipName_showPluginDialog &sipStrings_QtDesigner[2222]
#define sipNameNr_workingDirectory 2239
#define sipName_workingDirectory &sipStrings_QtDesigner[2239]
#define sipNameNr_SelectAllAction 2256
#define sipName_SelectAllAction &sipStrings_QtDesigner[2256]
#define sipNameNr_TabOrderFeature 2272
#define sipName_TabOrderFeature &sipStrings_QtDesigner[2272]
#define sipNameNr_addResourceFile 2288
#define sipName_addResourceFile &sipStrings_QtDesigner[2288]
#define sipNameNr_createExtension 2304
#define sipName_createExtension &sipStrings_QtDesigner[2304]
#define sipNameNr_declaredInClass 2320
#define sipName_declaredInClass &sipStrings_QtDesigner[2320]
#define sipNameNr_fileNameChanged 2336
#define sipName_fileNameChanged &sipStrings_QtDesigner[2336]
#define sipNameNr_formWindowAdded 2352
#define sipName_formWindowAdded &sipStrings_QtDesigner[2352]
#define sipNameNr_formWindowCount 2368
#define sipName_formWindowCount &sipStrings_QtDesigner[2368]
#define sipNameNr_geometryChanged 2384
#define sipName_geometryChanged &sipStrings_QtDesigner[2384]
#define sipNameNr_keyReleaseEvent 2400
#define sipName_keyReleaseEvent &sipStrings_QtDesigner[2400]
#define sipNameNr_minimumSizeHint 2416
#define sipName_minimumSizeHint &sipStrings_QtDesigner[2416]
#define sipNameNr_mousePressEvent 2432
#define sipName_mousePressEvent &sipStrings_QtDesigner[2432]
#define sipNameNr_objectInspector 2448
#define sipName_objectInspector &sipStrings_QtDesigner[2448]
#define sipNameNr_propertyChanged 2464
#define sipName_propertyChanged &sipStrings_QtDesigner[2464]
#define sipNameNr_setActionEditor 2480
#define sipName_setActionEditor &sipStrings_QtDesigner[2480]
#define sipNameNr_setCurrentIndex 2496
#define sipName_setCurrentIndex &sipStrings_QtDesigner[2496]
#define sipNameNr_setIncludeHints 2512
#define sipName_setIncludeHints &sipStrings_QtDesigner[2512]
#define sipNameNr_widgetUnmanaged 2528
#define sipName_widgetUnmanaged &sipStrings_QtDesigner[2528]
#define sipNameNr_DefaultFeature 2544
#define sipName_DefaultFeature &sipStrings_QtDesigner[2544]
#define sipNameNr_clearSelection 2559
#define sipName_clearSelection &sipStrings_QtDesigner[2559]
#define sipNameNr_dragEnterEvent 2574
#define sipName_dragEnterEvent &sipStrings_QtDesigner[2574]
#define sipNameNr_dragLeaveEvent 2589
#define sipName_dragLeaveEvent &sipStrings_QtDesigner[2589]
#define sipNameNr_featureChanged 2604
#define sipName_featureChanged &sipStrings_QtDesigner[2604]
#define sipNameNr_findFormWindow 2619
#define sipName_findFormWindow &sipStrings_QtDesigner[2619]
#define sipNameNr_heightForWidth 2634
#define sipName_heightForWidth &sipStrings_QtDesigner[2634]
#define sipNameNr_layoutFunction 2649
#define sipName_layoutFunction &sipStrings_QtDesigner[2649]
#define sipNameNr_mouseMoveEvent 2664
#define sipName_mouseMoveEvent &sipStrings_QtDesigner[2664]
#define sipNameNr_parameterNames 2679
#define sipName_parameterNames &sipStrings_QtDesigner[2679]
#define sipNameNr_parameterTypes 2694
#define sipName_parameterTypes &sipStrings_QtDesigner[2694]
#define sipNameNr_pixmapFunction 2709
#define sipName_pixmapFunction &sipStrings_QtDesigner[2709]
#define sipNameNr_propertyEditor 2724
#define sipName_propertyEditor &sipStrings_QtDesigner[2724]
#define sipNameNr_selectedWidget 2739
#define sipName_selectedWidget &sipStrings_QtDesigner[2739]
#define sipNameNr_setExportMacro 2754
#define sipName_setExportMacro &sipStrings_QtDesigner[2754]
#define sipNameNr_setMemberGroup 2769
#define sipName_setMemberGroup &sipStrings_QtDesigner[2769]
#define sipNameNr_unmanageAction 2784
#define sipName_unmanageAction &sipStrings_QtDesigner[2784]
#define sipNameNr_unmanageWidget 2799
#define sipName_unmanageWidget &sipStrings_QtDesigner[2799]
#define sipNameNr_MoveOperation 36
#define sipName_MoveOperation &sipStrings_QtDesigner[36]
#define sipNameNr_addFormWindow 2814
#define sipName_addFormWindow &sipStrings_QtDesigner[2814]
#define sipNameNr_addPluginPath 2828
#define sipName_addPluginPath &sipStrings_QtDesigner[2828]
#define sipNameNr_checkContents 2842
#define sipName_checkContents &sipStrings_QtDesigner[2842]
#define sipNameNr_connectNotify 2038
#define sipName_connectNotify &sipStrings_QtDesigner[2038]
#define sipNameNr_customWidgets 2856
#define sipName_customWidgets &sipStrings_QtDesigner[2856]
#define sipNameNr_dragMoveEvent 2870
#define sipName_dragMoveEvent &sipStrings_QtDesigner[2870]
#define sipNameNr_errorMessages 2884
#define sipName_errorMessages &sipStrings_QtDesigner[2884]
#define sipNameNr_focusOutEvent 2898
#define sipName_focusOutEvent &sipStrings_QtDesigner[2898]
#define sipNameNr_formContainer 2912
#define sipName_formContainer &sipStrings_QtDesigner[2912]
#define sipNameNr_isInitialized 2926
#define sipName_isInitialized &sipStrings_QtDesigner[2926]
#define sipNameNr_keyPressEvent 2940
#define sipName_keyPressEvent &sipStrings_QtDesigner[2940]
#define sipNameNr_layoutDefault 2954
#define sipName_layoutDefault &sipStrings_QtDesigner[2954]
#define sipNameNr_mainContainer 2968
#define sipName_mainContainer &sipStrings_QtDesigner[2968]
#define sipNameNr_objectRemoved 2982
#define sipName_objectRemoved &sipStrings_QtDesigner[2982]
#define sipNameNr_propertyGroup 2996
#define sipName_propertyGroup &sipStrings_QtDesigner[2996]
#define sipNameNr_resourceFiles 3010
#define sipName_resourceFiles &sipStrings_QtDesigner[3010]
#define sipNameNr_setFormWindow 3024
#define sipName_setFormWindow &sipStrings_QtDesigner[3024]
#define sipNameNr_setPluginPath 3038
#define sipName_setPluginPath &sipStrings_QtDesigner[3038]
#define sipNameNr_sharedPainter 3052
#define sipName_sharedPainter &sipStrings_QtDesigner[3052]
#define sipNameNr_widgetManaged 3066
#define sipName_widgetManaged &sipStrings_QtDesigner[3066]
#define sipNameNr_widgetRemoved 3080
#define sipName_widgetRemoved &sipStrings_QtDesigner[3080]
#define sipNameNr_DeleteAction 3094
#define sipName_DeleteAction &sipStrings_QtDesigner[3094]
#define sipNameNr_QFormBuilder 3107
#define sipName_QFormBuilder &sipStrings_QtDesigner[3107]
#define sipNameNr_actionEditor 3120
#define sipName_actionEditor &sipStrings_QtDesigner[3120]
#define sipNameNr_canAddWidget 3133
#define sipName_canAddWidget &sipStrings_QtDesigner[3133]
#define sipNameNr_codeTemplate 3146
#define sipName_codeTemplate &sipStrings_QtDesigner[3146]
#define sipNameNr_createWidget 3159
#define sipName_createWidget &sipStrings_QtDesigner[3159]
#define sipNameNr_currentIndex 3172
#define sipName_currentIndex &sipStrings_QtDesigner[3172]
#define sipNameNr_errorMessage 3185
#define sipName_errorMessage &sipStrings_QtDesigner[3185]
#define sipNameNr_focusInEvent 3198
#define sipName_focusInEvent &sipStrings_QtDesigner[3198]
#define sipNameNr_hasSelection 3211
#define sipName_hasSelection &sipStrings_QtDesigner[3211]
#define sipNameNr_includeHints 3224
#define sipName_includeHints &sipStrings_QtDesigner[3224]
#define sipNameNr_insertWidget 3237
#define sipName_insertWidget &sipStrings_QtDesigner[3237]
#define sipNameNr_manageAction 2786
#define sipName_manageAction &sipStrings_QtDesigner[2786]
#define sipNameNr_manageWidget 1244
#define sipName_manageWidget &sipStrings_QtDesigner[1244]
#define sipNameNr_movePosition 3250
#define sipName_movePosition &sipStrings_QtDesigner[3250]
#define sipNameNr_propertyName 3263
#define sipName_propertyName &sipStrings_QtDesigner[3263]
#define sipNameNr_selectWidget 3276
#define sipName_selectWidget &sipStrings_QtDesigner[3276]
#define sipNameNr_setAttribute 3289
#define sipName_setAttribute &sipStrings_QtDesigner[3289]
#define sipNameNr_setWidgetBox 3302
#define sipName_setWidgetBox &sipStrings_QtDesigner[3302]
#define sipNameNr_ActionGroup 137
#define sipName_ActionGroup &sipStrings_QtDesigner[137]
#define sipNameNr_EditFeature 3315
#define sipName_EditFeature &sipStrings_QtDesigner[3315]
#define sipNameNr_FeatureFlag 268
#define sipName_FeatureFlag &sipStrings_QtDesigner[268]
#define sipNameNr_GridFeature 3327
#define sipName_GridFeature &sipStrings_QtDesigner[3327]
#define sipNameNr_LowerAction 3339
#define sipName_LowerAction &sipStrings_QtDesigner[3339]
#define sipNameNr_PasteAction 3351
#define sipName_PasteAction &sipStrings_QtDesigner[3351]
#define sipNameNr_RaiseAction 3363
#define sipName_RaiseAction &sipStrings_QtDesigner[3363]
#define sipNameNr_absoluteDir 3375
#define sipName_absoluteDir &sipStrings_QtDesigner[3375]
#define sipNameNr_actionEvent 3387
#define sipName_actionEvent &sipStrings_QtDesigner[3387]
#define sipNameNr_actionGroup 3399
#define sipName_actionGroup &sipStrings_QtDesigner[3399]
#define sipNameNr_changeEvent 3411
#define sipName_changeEvent &sipStrings_QtDesigner[3411]
#define sipNameNr_customEvent 3423
#define sipName_customEvent &sipStrings_QtDesigner[3423]
#define sipNameNr_errorString 3435
#define sipName_errorString &sipStrings_QtDesigner[3435]
#define sipNameNr_eventFilter 3447
#define sipName_eventFilter &sipStrings_QtDesigner[3447]
#define sipNameNr_exportMacro 3459
#define sipName_exportMacro &sipStrings_QtDesigner[3459]
#define sipNameNr_includeFile 3471
#define sipName_includeFile &sipStrings_QtDesigner[3471]
#define sipNameNr_initPainter 3483
#define sipName_initPainter &sipStrings_QtDesigner[3483]
#define sipNameNr_isAttribute 3495
#define sipName_isAttribute &sipStrings_QtDesigner[3495]
#define sipNameNr_isContainer 3507
#define sipName_isContainer &sipStrings_QtDesigner[3507]
#define sipNameNr_memberGroup 3519
#define sipName_memberGroup &sipStrings_QtDesigner[3519]
#define sipNameNr_nativeEvent 3531
#define sipName_nativeEvent &sipStrings_QtDesigner[3531]
#define sipNameNr_paintEngine 3543
#define sipName_paintEngine &sipStrings_QtDesigner[3543]
#define sipNameNr_pluginPaths 3555
#define sipName_pluginPaths &sipStrings_QtDesigner[3555]
#define sipNameNr_resizeEvent 3567
#define sipName_resizeEvent &sipStrings_QtDesigner[3567]
#define sipNameNr_setContents 3579
#define sipName_setContents &sipStrings_QtDesigner[3579]
#define sipNameNr_setFeatures 3591
#define sipName_setFeatures &sipStrings_QtDesigner[3591]
#define sipNameNr_setFileName 3603
#define sipName_setFileName &sipStrings_QtDesigner[3603]
#define sipNameNr_setPosition 3615
#define sipName_setPosition &sipStrings_QtDesigner[3615]
#define sipNameNr_setProperty 3627
#define sipName_setProperty &sipStrings_QtDesigner[3627]
#define sipNameNr_setReadOnly 3639
#define sipName_setReadOnly &sipStrings_QtDesigner[3639]
#define sipNameNr_showPreview 3651
#define sipName_showPreview &sipStrings_QtDesigner[3651]
#define sipNameNr_tabletEvent 3663
#define sipName_tabletEvent &sipStrings_QtDesigner[3663]
#define sipNameNr_taskActions 3675
#define sipName_taskActions &sipStrings_QtDesigner[3675]
#define sipNameNr_widgetCount 3687
#define sipName_widgetCount &sipStrings_QtDesigner[3687]
#define sipNameNr_CopyAction 3699
#define sipName_CopyAction &sipStrings_QtDesigner[3699]
#define sipNameNr_KeepAnchor 3710
#define sipName_KeepAnchor &sipStrings_QtDesigner[3710]
#define sipNameNr_MoveAnchor 3721
#define sipName_MoveAnchor &sipStrings_QtDesigner[3721]
#define sipNameNr_RedoAction 3732
#define sipName_RedoAction &sipStrings_QtDesigner[3732]
#define sipNameNr_UndoAction 3743
#define sipName_UndoAction &sipStrings_QtDesigner[3743]
#define sipNameNr_childEvent 3754
#define sipName_childEvent &sipStrings_QtDesigner[3754]
#define sipNameNr_closeEvent 3765
#define sipName_closeEvent &sipStrings_QtDesigner[3765]
#define sipNameNr_enterEvent 3776
#define sipName_enterEvent &sipStrings_QtDesigner[3776]
#define sipNameNr_errorCount 3787
#define sipName_errorCount &sipStrings_QtDesigner[3787]
#define sipNameNr_formWindow 3798
#define sipName_formWindow &sipStrings_QtDesigner[3798]
#define sipNameNr_hasFeature 3809
#define sipName_hasFeature &sipStrings_QtDesigner[3809]
#define sipNameNr_initialize 3820
#define sipName_initialize &sipStrings_QtDesigner[3820]
#define sipNameNr_isReadOnly 3831
#define sipName_isReadOnly &sipStrings_QtDesigner[3831]
#define sipNameNr_leaveEvent 3842
#define sipName_leaveEvent &sipStrings_QtDesigner[3842]
#define sipNameNr_memberName 3853
#define sipName_memberName &sipStrings_QtDesigner[3853]
#define sipNameNr_paintEvent 3864
#define sipName_paintEvent &sipStrings_QtDesigner[3864]
#define sipNameNr_setChanged 3875
#define sipName_setChanged &sipStrings_QtDesigner[3875]
#define sipNameNr_setComment 3886
#define sipName_setComment &sipStrings_QtDesigner[3886]
#define sipNameNr_setVisible 3897
#define sipName_setVisible &sipStrings_QtDesigner[3897]
#define sipNameNr_timerEvent 3908
#define sipName_timerEvent &sipStrings_QtDesigner[3908]
#define sipNameNr_wheelEvent 3919
#define sipName_wheelEvent &sipStrings_QtDesigner[3919]
#define sipNameNr_CutAction 3930
#define sipName_CutAction &sipStrings_QtDesigner[3930]
#define sipNameNr_activated 3940
#define sipName_activated &sipStrings_QtDesigner[3940]
#define sipNameNr_addWidget 3950
#define sipName_addWidget &sipStrings_QtDesigner[3950]
#define sipNameNr_canRemove 3960
#define sipName_canRemove &sipStrings_QtDesigner[3960]
#define sipNameNr_dropEvent 3970
#define sipName_dropEvent &sipStrings_QtDesigner[3970]
#define sipNameNr_extension 3980
#define sipName_extension &sipStrings_QtDesigner[3980]
#define sipNameNr_hideEvent 3990
#define sipName_hideEvent &sipStrings_QtDesigner[3990]
#define sipNameNr_isChanged 4000
#define sipName_isChanged &sipStrings_QtDesigner[4000]
#define sipNameNr_isEnabled 4010
#define sipName_isEnabled &sipStrings_QtDesigner[4010]
#define sipNameNr_isManaged 4020
#define sipName_isManaged &sipStrings_QtDesigner[4020]
#define sipNameNr_isVisible 4030
#define sipName_isVisible &sipStrings_QtDesigner[4030]
#define sipNameNr_moveEvent 4040
#define sipName_moveEvent &sipStrings_QtDesigner[4040]
#define sipNameNr_setAuthor 4050
#define sipName_setAuthor &sipStrings_QtDesigner[4050]
#define sipNameNr_setObject 4060
#define sipName_setObject &sipStrings_QtDesigner[4060]
#define sipNameNr_showEvent 4070
#define sipName_showEvent &sipStrings_QtDesigner[4070]
#define sipNameNr_signature 4080
#define sipName_signature &sipStrings_QtDesigner[4080]
#define sipNameNr_whatsThis 4090
#define sipName_whatsThis &sipStrings_QtDesigner[4090]
#define sipNameNr_widgetBox 4100
#define sipName_widgetBox &sipStrings_QtDesigner[4100]
#define sipNameNr_MoveMode 185
#define sipName_MoveMode &sipStrings_QtDesigner[185]
#define sipNameNr_contents 4110
#define sipName_contents &sipStrings_QtDesigner[4110]
#define sipNameNr_features 4119
#define sipName_features &sipStrings_QtDesigner[4119]
#define sipNameNr_fileName 4128
#define sipName_fileName &sipStrings_QtDesigner[4128]
#define sipNameNr_hasReset 4137
#define sipName_hasReset &sipStrings_QtDesigner[4137]
#define sipNameNr_isSignal 4146
#define sipName_isSignal &sipStrings_QtDesigner[4146]
#define sipNameNr_position 4155
#define sipName_position &sipStrings_QtDesigner[4155]
#define sipNameNr_property 4164
#define sipName_property &sipStrings_QtDesigner[4164]
#define sipNameNr_setDirty 4173
#define sipName_setDirty &sipStrings_QtDesigner[4173]
#define sipNameNr_sizeHint 4182
#define sipName_sizeHint &sipStrings_QtDesigner[4182]
#define sipNameNr_topLevel 4191
#define sipName_topLevel &sipStrings_QtDesigner[4191]
#define sipNameNr___len__ 4200
#define sipName___len__ &sipStrings_QtDesigner[4200]
#define sipNameNr_changed 4208
#define sipName_changed &sipStrings_QtDesigner[4208]
#define sipNameNr_comment 4216
#define sipName_comment &sipStrings_QtDesigner[4216]
#define sipNameNr_current 4224
#define sipName_current &sipStrings_QtDesigner[4224]
#define sipNameNr_devType 4232
#define sipName_devType &sipStrings_QtDesigner[4232]
#define sipNameNr_indexOf 4240
#define sipName_indexOf &sipStrings_QtDesigner[4240]
#define sipNameNr_isDirty 4248
#define sipName_isDirty &sipStrings_QtDesigner[4248]
#define sipNameNr_setGrid 4256
#define sipName_setGrid &sipStrings_QtDesigner[4256]
#define sipNameNr_toolTip 4264
#define sipName_toolTip &sipStrings_QtDesigner[4264]
#define sipNameNr_Action 231
#define sipName_Action &sipStrings_QtDesigner[231]
#define sipNameNr_NoMove 4272
#define sipName_NoMove &sipStrings_QtDesigner[4272]
#define sipNameNr_action 4279
#define sipName_action &sipStrings_QtDesigner[4279]
#define sipNameNr_author 4286
#define sipName_author &sipStrings_QtDesigner[4286]
#define sipNameNr_cursor 4293
#define sipName_cursor &sipStrings_QtDesigner[4293]
#define sipNameNr_domXml 4300
#define sipName_domXml &sipStrings_QtDesigner[4300]
#define sipNameNr_isSlot 4307
#define sipName_isSlot &sipStrings_QtDesigner[4307]
#define sipNameNr_metric 4314
#define sipName_metric &sipStrings_QtDesigner[4314]
#define sipNameNr_object 4321
#define sipName_object &sipStrings_QtDesigner[4321]
#define sipNameNr_parent 4328
#define sipName_parent &sipStrings_QtDesigner[4328]
#define sipNameNr_remove 4335
#define sipName_remove &sipStrings_QtDesigner[4335]
#define sipNameNr_select 4342
#define sipName_select &sipStrings_QtDesigner[4342]
#define sipNameNr_update 4349
#define sipName_update &sipStrings_QtDesigner[4349]
#define sipNameNr_widget 4356
#define sipName_widget &sipStrings_QtDesigner[4356]
#define sipNameNr_Right 4363
#define sipName_Right &sipStrings_QtDesigner[4363]
#define sipNameNr_Start 4369
#define sipName_Start &sipStrings_QtDesigner[4369]
#define sipNameNr_count 4375
#define sipName_count &sipStrings_QtDesigner[4375]
#define sipNameNr_event 4381
#define sipName_event &sipStrings_QtDesigner[4381]
#define sipNameNr_flags 4387
#define sipName_flags &sipStrings_QtDesigner[4387]
#define sipNameNr_group 4393
#define sipName_group &sipStrings_QtDesigner[4393]
#define sipNameNr_reset 4399
#define sipName_reset &sipStrings_QtDesigner[4399]
#define sipNameNr_Down 4405
#define sipName_Down &sipStrings_QtDesigner[4405]
#define sipNameNr_Left 4410
#define sipName_Left &sipStrings_QtDesigner[4410]
#define sipNameNr_Next 4415
#define sipName_Next &sipStrings_QtDesigner[4415]
#define sipNameNr_Prev 4420
#define sipName_Prev &sipStrings_QtDesigner[4420]
#define sipNameNr_core 4425
#define sipName_core &sipStrings_QtDesigner[4425]
#define sipNameNr_grid 4430
#define sipName_grid &sipStrings_QtDesigner[4430]
#define sipNameNr_icon 4435
#define sipName_icon &sipStrings_QtDesigner[4435]
#define sipNameNr_load 4440
#define sipName_load &sipStrings_QtDesigner[4440]
#define sipNameNr_mode 4445
#define sipName_mode &sipStrings_QtDesigner[4445]
#define sipNameNr_name 4450
#define sipName_name &sipStrings_QtDesigner[4450]
#define sipNameNr_save 4455
#define sipName_save &sipStrings_QtDesigner[4455]
#define sipNameNr_End 4460
#define sipName_End &sipStrings_QtDesigner[4460]
#define sipNameNr_iid 4464
#define sipName_iid &sipStrings_QtDesigner[4464]
#define sipNameNr_Up 4468
#define sipName_Up &sipStrings_QtDesigner[4468]

#define sipMalloc                   sipAPI_QtDesigner->api_malloc
#define sipFree                     sipAPI_QtDesigner->api_free
#define sipBuildResult              sipAPI_QtDesigner->api_build_result
#define sipCallMethod               sipAPI_QtDesigner->api_call_method
#define sipCallProcedureMethod      sipAPI_QtDesigner->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtDesigner->api_call_error_handler
#define sipParseResultEx            sipAPI_QtDesigner->api_parse_result_ex
#define sipParseResult              sipAPI_QtDesigner->api_parse_result
#define sipParseArgs                sipAPI_QtDesigner->api_parse_args
#define sipParseKwdArgs             sipAPI_QtDesigner->api_parse_kwd_args
#define sipParsePair                sipAPI_QtDesigner->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtDesigner->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtDesigner->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtDesigner->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtDesigner->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtDesigner->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtDesigner->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtDesigner->api_add_exception
#define sipNoFunction               sipAPI_QtDesigner->api_no_function
#define sipNoMethod                 sipAPI_QtDesigner->api_no_method
#define sipAbstractMethod           sipAPI_QtDesigner->api_abstract_method
#define sipBadClass                 sipAPI_QtDesigner->api_bad_class
#define sipBadCatcherResult         sipAPI_QtDesigner->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtDesigner->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtDesigner->api_bad_operator_arg
#define sipTrace                    sipAPI_QtDesigner->api_trace
#define sipTransferBack             sipAPI_QtDesigner->api_transfer_back
#define sipTransferTo               sipAPI_QtDesigner->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtDesigner->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtDesigner->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtDesigner->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtDesigner->api_voidptr_type
#define sipGetPyObject              sipAPI_QtDesigner->api_get_pyobject
#define sipGetAddress               sipAPI_QtDesigner->api_get_address
#define sipGetMixinAddress          sipAPI_QtDesigner->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtDesigner->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtDesigner->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtDesigner->api_call_hook
#define sipEndThread                sipAPI_QtDesigner->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtDesigner->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtDesigner->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtDesigner->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtDesigner->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtDesigner->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtDesigner->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtDesigner->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtDesigner->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtDesigner->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtDesigner->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtDesigner->api_convert_to_bool
#define sipReleaseType              sipAPI_QtDesigner->api_release_type
#define sipConvertFromType          sipAPI_QtDesigner->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtDesigner->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtDesigner->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtDesigner->api_convert_from_enum
#define sipGetState                 sipAPI_QtDesigner->api_get_state
#define sipExportSymbol             sipAPI_QtDesigner->api_export_symbol
#define sipImportSymbol             sipAPI_QtDesigner->api_import_symbol
#define sipFindType                 sipAPI_QtDesigner->api_find_type
#define sipBytes_AsChar             sipAPI_QtDesigner->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtDesigner->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtDesigner->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtDesigner->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtDesigner->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtDesigner->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtDesigner->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtDesigner->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtDesigner->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtDesigner->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtDesigner->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtDesigner->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtDesigner->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtDesigner->api_get_reference
#define sipKeepReference            sipAPI_QtDesigner->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtDesigner->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtDesigner->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtDesigner->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtDesigner->api_type_scope
#define sipResolveTypedef           sipAPI_QtDesigner->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtDesigner->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtDesigner->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtDesigner->api_init_mixin
#define sipExportModule             sipAPI_QtDesigner->api_export_module
#define sipInitModule               sipAPI_QtDesigner->api_init_module
#define sipGetInterpreter           sipAPI_QtDesigner->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtDesigner->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtDesigner->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtDesigner->api_py_type_dict
#define sipPyTypeName               sipAPI_QtDesigner->api_py_type_name
#define sipGetCFunction             sipAPI_QtDesigner->api_get_c_function
#define sipGetMethod                sipAPI_QtDesigner->api_get_method
#define sipFromMethod               sipAPI_QtDesigner->api_from_method
#define sipGetDate                  sipAPI_QtDesigner->api_get_date
#define sipFromDate                 sipAPI_QtDesigner->api_from_date
#define sipGetDateTime              sipAPI_QtDesigner->api_get_datetime
#define sipFromDateTime             sipAPI_QtDesigner->api_from_datetime
#define sipGetTime                  sipAPI_QtDesigner->api_get_time
#define sipFromTime                 sipAPI_QtDesigner->api_from_time
#define sipIsUserType               sipAPI_QtDesigner->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtDesigner->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtDesigner->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtDesigner->api_unicode_write
#define sipUnicodeData              sipAPI_QtDesigner->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtDesigner->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtDesigner->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtDesigner->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtDesigner->api_is_derived_class
#define sipGetUserObject            sipAPI_QtDesigner->api_get_user_object
#define sipSetUserObject            sipAPI_QtDesigner->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtDesigner->api_register_event_handler
#define sipConvertToArray           sipAPI_QtDesigner->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtDesigner->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtDesigner->api_enable_gc
#define sipPrintObject              sipAPI_QtDesigner->api_print_object
#define sipLong_AsChar              sipAPI_QtDesigner->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtDesigner->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtDesigner->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtDesigner->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtDesigner->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtDesigner->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtDesigner->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtDesigner->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtDesigner->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtDesigner->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtDesigner->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtDesigner->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtDesigner->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtDesigner->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtDesigner->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtDesigner->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtDesigner->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtDesigner->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtDesigner->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtDesigner->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtDesigner->api_release_type_us
#define sipIsPyMethod               sipAPI_QtDesigner->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtDesigner[];

#define sipType_QDesignerActionEditorInterface sipExportedTypes_QtDesigner[3]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerActionEditorInterface;

#define sipType_QAbstractFormBuilder sipExportedTypes_QtDesigner[2]

extern sipClassTypeDef sipTypeDef_QtDesigner_QAbstractFormBuilder;

#define sipType_QDesignerFormEditorInterface sipExportedTypes_QtDesigner[7]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormEditorInterface;

#define sipType_QDesignerFormWindowInterface sipExportedTypes_QtDesigner[11]

#define sipType_QDesignerFormWindowInterface_FeatureFlag sipExportedTypes_QtDesigner[12]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormWindowInterface;

#define sipType_QDesignerFormWindowCursorInterface sipExportedTypes_QtDesigner[8]

#define sipType_QDesignerFormWindowCursorInterface_MoveMode sipExportedTypes_QtDesigner[9]

#define sipType_QDesignerFormWindowCursorInterface_MoveOperation sipExportedTypes_QtDesigner[10]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormWindowCursorInterface;

#define sipType_QDesignerFormWindowManagerInterface sipExportedTypes_QtDesigner[13]

#define sipType_QDesignerFormWindowManagerInterface_ActionGroup sipExportedTypes_QtDesigner[15]

#define sipType_QDesignerFormWindowManagerInterface_Action sipExportedTypes_QtDesigner[14]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormWindowManagerInterface;

#define sipType_QDesignerObjectInspectorInterface sipExportedTypes_QtDesigner[17]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerObjectInspectorInterface;

#define sipType_QDesignerPropertyEditorInterface sipExportedTypes_QtDesigner[18]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerPropertyEditorInterface;

#define sipType_QDesignerWidgetBoxInterface sipExportedTypes_QtDesigner[21]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerWidgetBoxInterface;

#define sipType_QDesignerContainerExtension sipExportedTypes_QtDesigner[4]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerContainerExtension;

#define sipType_QDesignerCustomWidgetInterface sipExportedTypes_QtDesigner[6]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerCustomWidgetInterface;

#define sipType_QDesignerCustomWidgetCollectionInterface sipExportedTypes_QtDesigner[5]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerCustomWidgetCollectionInterface;

#define sipType_QAbstractExtensionFactory sipExportedTypes_QtDesigner[0]

extern sipClassTypeDef sipTypeDef_QtDesigner_QAbstractExtensionFactory;

#define sipType_QExtensionFactory sipExportedTypes_QtDesigner[22]

extern sipClassTypeDef sipTypeDef_QtDesigner_QExtensionFactory;

#define sipType_QAbstractExtensionManager sipExportedTypes_QtDesigner[1]

extern sipClassTypeDef sipTypeDef_QtDesigner_QAbstractExtensionManager;

#define sipType_QFormBuilder sipExportedTypes_QtDesigner[25]

extern sipClassTypeDef sipTypeDef_QtDesigner_QFormBuilder;

#define sipType_QDesignerMemberSheetExtension sipExportedTypes_QtDesigner[16]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerMemberSheetExtension;

#define sipType_QDesignerPropertySheetExtension sipExportedTypes_QtDesigner[19]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerPropertySheetExtension;

#define sipType_QExtensionManager sipExportedTypes_QtDesigner[23]

extern sipClassTypeDef sipTypeDef_QtDesigner_QExtensionManager;

#define sipType_QDesignerTaskMenuExtension sipExportedTypes_QtDesigner[20]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerTaskMenuExtension;

#define sipType_QPyDesignerContainerExtension sipExportedTypes_QtDesigner[27]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerContainerExtension;

#define sipType_QPyDesignerCustomWidgetCollectionPlugin sipExportedTypes_QtDesigner[28]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerCustomWidgetCollectionPlugin;

#define sipType_QPyDesignerCustomWidgetPlugin sipExportedTypes_QtDesigner[29]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerCustomWidgetPlugin;

#define sipType_QPyDesignerTaskMenuExtension sipExportedTypes_QtDesigner[32]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerTaskMenuExtension;

#define sipType_QPyDesignerPropertySheetExtension sipExportedTypes_QtDesigner[31]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerPropertySheetExtension;

#define sipType_QPyDesignerMemberSheetExtension sipExportedTypes_QtDesigner[30]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerMemberSheetExtension;

#define sipType_QList_0101QDesignerCustomWidgetInterface sipExportedTypes_QtDesigner[26]

extern sipMappedTypeDef sipTypeDef_QtDesigner_QList_0101QDesignerCustomWidgetInterface;

#define sipType_QFlags_0100QDesignerFormWindowInterface_FeatureFlag sipExportedTypes_QtDesigner[24]

extern sipMappedTypeDef sipTypeDef_QtDesigner_QFlags_0100QDesignerFormWindowInterface_FeatureFlag;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtDesigner;
extern sipExportedModuleDef sipModuleAPI_QtDesigner;
extern sipTypeDef *sipExportedTypes_QtDesigner[];

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtDesigner_QtCore[15].it_td

#define sipType_QObject sipImportedTypes_QtDesigner_QtCore[8].it_td

#define sipType_QIODevice sipImportedTypes_QtDesigner_QtCore[5].it_td

#define sipType_QByteArray sipImportedTypes_QtDesigner_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtDesigner_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtDesigner_QtCore[13].it_td

#define sipType_QChildEvent sipImportedTypes_QtDesigner_QtCore[1].it_td

#define sipType_QDir sipImportedTypes_QtDesigner_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtDesigner_QtCore[7].it_td

#define sipType_QPoint sipImportedTypes_QtDesigner_QtCore[9].it_td

#define sipType_QSize sipImportedTypes_QtDesigner_QtCore[10].it_td

#define sipType_QVariant sipImportedTypes_QtDesigner_QtCore[14].it_td

#define sipType_QList_0100QByteArray sipImportedTypes_QtDesigner_QtCore[6].it_td

#define sipType_QFlags_0100Qt_WindowType sipImportedTypes_QtDesigner_QtCore[4].it_td

#define sipType_QStringList sipImportedTypes_QtDesigner_QtCore[12].it_td

#define sipType_QString sipImportedTypes_QtDesigner_QtCore[11].it_td

#define sipType_qintptr sipImportedTypes_QtDesigner_QtCore[16].it_td
extern sipImportedTypeDef sipImportedTypes_QtDesigner_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtDesigner_QtCore[];

#define sipType_QAction sipImportedTypes_QtDesigner_QtGui[0].it_td

#define sipType_QActionGroup sipImportedTypes_QtDesigner_QtGui[2].it_td

#define sipType_QPaintDevice sipImportedTypes_QtDesigner_QtGui[18].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtDesigner_QtGui[19].it_td

#define sipType_QKeyEvent sipImportedTypes_QtDesigner_QtGui[14].it_td

#define sipType_QFocusEvent sipImportedTypes_QtDesigner_QtGui[10].it_td

#define sipType_QPaintEvent sipImportedTypes_QtDesigner_QtGui[21].it_td

#define sipType_QMoveEvent sipImportedTypes_QtDesigner_QtGui[17].it_td

#define sipType_QResizeEvent sipImportedTypes_QtDesigner_QtGui[23].it_td

#define sipType_QCloseEvent sipImportedTypes_QtDesigner_QtGui[3].it_td

#define sipType_QShowEvent sipImportedTypes_QtDesigner_QtGui[24].it_td

#define sipType_QHideEvent sipImportedTypes_QtDesigner_QtGui[11].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtDesigner_QtGui[4].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtDesigner_QtGui[13].it_td

#define sipType_QDropEvent sipImportedTypes_QtDesigner_QtGui[8].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtDesigner_QtGui[7].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtDesigner_QtGui[5].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtDesigner_QtGui[6].it_td

#define sipType_QActionEvent sipImportedTypes_QtDesigner_QtGui[1].it_td

#define sipType_QEnterEvent sipImportedTypes_QtDesigner_QtGui[9].it_td

#define sipType_QMouseEvent sipImportedTypes_QtDesigner_QtGui[16].it_td

#define sipType_QWheelEvent sipImportedTypes_QtDesigner_QtGui[26].it_td

#define sipType_QTabletEvent sipImportedTypes_QtDesigner_QtGui[25].it_td

#define sipType_QIcon sipImportedTypes_QtDesigner_QtGui[12].it_td

#define sipType_QPaintEngine sipImportedTypes_QtDesigner_QtGui[20].it_td

#define sipType_QPainter sipImportedTypes_QtDesigner_QtGui[22].it_td

#define sipType_QList_0101QAction sipImportedTypes_QtDesigner_QtGui[15].it_td
extern sipImportedTypeDef sipImportedTypes_QtDesigner_QtGui[];

#define sipType_QWidget sipImportedTypes_QtDesigner_QtWidgets[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtDesigner_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtDesigner_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtDesigner_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtDesigner_qt_metacast;

#endif
