/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 130 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 67 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQGraphicsDropShadowEffect.cpp"


class sipQGraphicsDropShadowEffect : public ::QGraphicsDropShadowEffect
{
public:
    sipQGraphicsDropShadowEffect(::QObject*);
    virtual ~sipQGraphicsDropShadowEffect();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QRectF boundingRectFor(const ::QRectF&) const SIP_OVERRIDE;
    void draw(::QPainter*) SIP_OVERRIDE;
    void sourceChanged(::QGraphicsEffect::ChangeFlags) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGraphicsDropShadowEffect(const sipQGraphicsDropShadowEffect &);
    sipQGraphicsDropShadowEffect &operator = (const sipQGraphicsDropShadowEffect &);

    char sipPyMethods[10];
};

sipQGraphicsDropShadowEffect::sipQGraphicsDropShadowEffect(::QObject*a0): ::QGraphicsDropShadowEffect(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGraphicsDropShadowEffect::~sipQGraphicsDropShadowEffect()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGraphicsDropShadowEffect::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QGraphicsDropShadowEffect);

    return ::QGraphicsDropShadowEffect::metaObject();
}

int sipQGraphicsDropShadowEffect::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGraphicsDropShadowEffect::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QGraphicsDropShadowEffect, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGraphicsDropShadowEffect::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QGraphicsDropShadowEffect, _clname, &sipCpp) ? sipCpp : ::QGraphicsDropShadowEffect::qt_metacast(_clname));
}

void sipQGraphicsDropShadowEffect::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGraphicsDropShadowEffect::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsDropShadowEffect::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGraphicsDropShadowEffect::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsDropShadowEffect::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGraphicsDropShadowEffect::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsDropShadowEffect::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGraphicsDropShadowEffect::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsDropShadowEffect::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGraphicsDropShadowEffect::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsDropShadowEffect::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGraphicsDropShadowEffect::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsDropShadowEffect::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGraphicsDropShadowEffect::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRectF sipQGraphicsDropShadowEffect::boundingRectFor(const ::QRectF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_boundingRectFor);

    if (!sipMeth)
        return ::QGraphicsDropShadowEffect::boundingRectFor(a0);

    extern ::QRectF sipVH_QtWidgets_136(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRectF&);

    return sipVH_QtWidgets_136(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsDropShadowEffect::draw(::QPainter*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_draw);

    if (!sipMeth)
    {
        ::QGraphicsDropShadowEffect::draw(a0);
        return;
    }

    extern void sipVH_QtWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsDropShadowEffect::sourceChanged(::QGraphicsEffect::ChangeFlags a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_sourceChanged);

    if (!sipMeth)
    {
        ::QGraphicsDropShadowEffect::sourceChanged(a0);
        return;
    }

    extern void sipVH_QtWidgets_137(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsEffect::ChangeFlags);

    sipVH_QtWidgets_137(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_boundingRectFor, "boundingRectFor(self, rect: QRectF) -> QRectF");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_boundingRectFor(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_boundingRectFor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsDropShadowEffect)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QRectF* a0;
        const ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp, sipType_QRectF, &a0))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF((sipSelfWasArg ? sipCpp->::QGraphicsDropShadowEffect::boundingRectFor(*a0) : sipCpp->boundingRectFor(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_boundingRectFor, doc_QGraphicsDropShadowEffect_boundingRectFor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_offset, "offset(self) -> QPointF");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_offset(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_offset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->offset());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_offset, doc_QGraphicsDropShadowEffect_offset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_xOffset, "xOffset(self) -> float");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_xOffset(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_xOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->xOffset();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_xOffset, doc_QGraphicsDropShadowEffect_xOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_yOffset, "yOffset(self) -> float");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_yOffset(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_yOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->yOffset();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_yOffset, doc_QGraphicsDropShadowEffect_yOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_blurRadius, "blurRadius(self) -> float");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_blurRadius(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_blurRadius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->blurRadius();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_blurRadius, doc_QGraphicsDropShadowEffect_blurRadius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_color, "color(self) -> QColor");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_color(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_color(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->color());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_color, doc_QGraphicsDropShadowEffect_color);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_setOffset, "setOffset(self, ofs: QPointF)\n"
"setOffset(self, dx: float, dy: float)\n"
"setOffset(self, d: float)");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_setOffset(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_setOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp, sipType_QPointF, &a0))
        {
            sipCpp->setOffset(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp, &a0, &a1))
        {
            sipCpp->setOffset(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::qreal a0;
        ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp, &a0))
        {
            sipCpp->setOffset(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_setOffset, doc_QGraphicsDropShadowEffect_setOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_setXOffset, "setXOffset(self, dx: float)");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_setXOffset(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_setXOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp, &a0))
        {
            sipCpp->setXOffset(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_setXOffset, doc_QGraphicsDropShadowEffect_setXOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_setYOffset, "setYOffset(self, dy: float)");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_setYOffset(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_setYOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp, &a0))
        {
            sipCpp->setYOffset(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_setYOffset, doc_QGraphicsDropShadowEffect_setYOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_setBlurRadius, "setBlurRadius(self, blurRadius: float)");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_setBlurRadius(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_setBlurRadius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp, &a0))
        {
            sipCpp->setBlurRadius(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_setBlurRadius, doc_QGraphicsDropShadowEffect_setBlurRadius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_setColor, "setColor(self, color: QColor|Qt.GlobalColor|int)");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_setColor(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_setColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_setColor, doc_QGraphicsDropShadowEffect_setColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsDropShadowEffect_draw, "draw(self, painter: QPainter|None)");

extern "C" {static PyObject *meth_QGraphicsDropShadowEffect_draw(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsDropShadowEffect_draw(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsDropShadowEffect)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPainter* a0;
        ::QGraphicsDropShadowEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsDropShadowEffect, &sipCpp, sipType_QPainter, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsDropShadowEffect::draw(a0) : sipCpp->draw(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsDropShadowEffect, sipName_draw, doc_QGraphicsDropShadowEffect_draw);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGraphicsDropShadowEffect(void *, const sipTypeDef *);}
static void *cast_QGraphicsDropShadowEffect(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGraphicsDropShadowEffect *sipCpp = reinterpret_cast< ::QGraphicsDropShadowEffect *>(sipCppV);

    if (targetType == sipType_QGraphicsDropShadowEffect)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGraphicsEffect)->ctd_cast(static_cast< ::QGraphicsEffect *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGraphicsDropShadowEffect(void *, int);}
static void release_QGraphicsDropShadowEffect(void *sipCppV, int)
{
    ::QGraphicsDropShadowEffect *sipCpp = reinterpret_cast< ::QGraphicsDropShadowEffect *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QGraphicsDropShadowEffect(Py_ssize_t);}
static void *array_QGraphicsDropShadowEffect(Py_ssize_t sipNrElem)
{
    return new ::QGraphicsDropShadowEffect[sipNrElem];
}


extern "C" {static void array_delete_QGraphicsDropShadowEffect(void *);}
static void array_delete_QGraphicsDropShadowEffect(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGraphicsDropShadowEffect *>(sipCpp);
}


extern "C" {static void dealloc_QGraphicsDropShadowEffect(sipSimpleWrapper *);}
static void dealloc_QGraphicsDropShadowEffect(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGraphicsDropShadowEffect *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGraphicsDropShadowEffect(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGraphicsDropShadowEffect(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGraphicsDropShadowEffect(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGraphicsDropShadowEffect *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQGraphicsDropShadowEffect(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGraphicsDropShadowEffect[] = {{130, 255, 1}};


static PyMethodDef methods_QGraphicsDropShadowEffect[] = {
    {sipName_blurRadius, meth_QGraphicsDropShadowEffect_blurRadius, METH_VARARGS, doc_QGraphicsDropShadowEffect_blurRadius},
    {sipName_boundingRectFor, meth_QGraphicsDropShadowEffect_boundingRectFor, METH_VARARGS, doc_QGraphicsDropShadowEffect_boundingRectFor},
    {sipName_color, meth_QGraphicsDropShadowEffect_color, METH_VARARGS, doc_QGraphicsDropShadowEffect_color},
    {sipName_draw, meth_QGraphicsDropShadowEffect_draw, METH_VARARGS, doc_QGraphicsDropShadowEffect_draw},
    {sipName_offset, meth_QGraphicsDropShadowEffect_offset, METH_VARARGS, doc_QGraphicsDropShadowEffect_offset},
    {sipName_setBlurRadius, meth_QGraphicsDropShadowEffect_setBlurRadius, METH_VARARGS, doc_QGraphicsDropShadowEffect_setBlurRadius},
    {sipName_setColor, meth_QGraphicsDropShadowEffect_setColor, METH_VARARGS, doc_QGraphicsDropShadowEffect_setColor},
    {sipName_setOffset, meth_QGraphicsDropShadowEffect_setOffset, METH_VARARGS, doc_QGraphicsDropShadowEffect_setOffset},
    {sipName_setXOffset, meth_QGraphicsDropShadowEffect_setXOffset, METH_VARARGS, doc_QGraphicsDropShadowEffect_setXOffset},
    {sipName_setYOffset, meth_QGraphicsDropShadowEffect_setYOffset, METH_VARARGS, doc_QGraphicsDropShadowEffect_setYOffset},
    {sipName_xOffset, meth_QGraphicsDropShadowEffect_xOffset, METH_VARARGS, doc_QGraphicsDropShadowEffect_xOffset},
    {sipName_yOffset, meth_QGraphicsDropShadowEffect_yOffset, METH_VARARGS, doc_QGraphicsDropShadowEffect_yOffset}
};

PyDoc_STRVAR(doc_QGraphicsDropShadowEffect, "\1QGraphicsDropShadowEffect(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QGraphicsDropShadowEffect[] = {
    {"colorChanged(QColor)", "\1colorChanged(self, color: QColor|Qt.GlobalColor|int)", SIP_NULLPTR, SIP_NULLPTR},
    {"blurRadiusChanged(qreal)", "\1blurRadiusChanged(self, blurRadius: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"offsetChanged(QPointF)", "\1offsetChanged(self, offset: QPointF)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QGraphicsDropShadowEffect = {
    &::QGraphicsDropShadowEffect::staticMetaObject,
    signals_QGraphicsDropShadowEffect,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsDropShadowEffect = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGraphicsDropShadowEffect,
        SIP_NULLPTR,
        &plugin_QGraphicsDropShadowEffect,
    },
    {
        sipNameNr_QGraphicsDropShadowEffect,
        {0, 0, 1},
        12, methods_QGraphicsDropShadowEffect,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGraphicsDropShadowEffect,
    -1,
    -1,
    supers_QGraphicsDropShadowEffect,
    SIP_NULLPTR,
    init_type_QGraphicsDropShadowEffect,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGraphicsDropShadowEffect,
    SIP_NULLPTR,
    array_QGraphicsDropShadowEffect,
    SIP_NULLPTR,
    release_QGraphicsDropShadowEffect,
    cast_QGraphicsDropShadowEffect,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGraphicsDropShadowEffect,
    sizeof (::QGraphicsDropShadowEffect),
};
