/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtStateMachineAPI_H
#define _QtStateMachineAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_StateMachineChildModeSetToParallelError 0
#define sipName_StateMachineChildModeSetToParallelError &sipStrings_QtStateMachine[0]
#define sipNameNr_QAbstractTransition__TransitionType 40
#define sipName_QAbstractTransition__TransitionType &sipStrings_QtStateMachine[40]
#define sipNameNr_NoCommonAncestorForTransitionError 76
#define sipName_NoCommonAncestorForTransitionError &sipStrings_QtStateMachine[76]
#define sipNameNr_NoDefaultStateInHistoryStateError 111
#define sipName_NoDefaultStateInHistoryStateError &sipStrings_QtStateMachine[111]
#define sipNameNr_QStateMachine__EventPriority 145
#define sipName_QStateMachine__EventPriority &sipStrings_QtStateMachine[145]
#define sipNameNr_174 174
#define sipName_174 &sipStrings_QtStateMachine[174]
#define sipNameNr_QStateMachine__WrappedEvent 202
#define sipName_QStateMachine__WrappedEvent &sipStrings_QtStateMachine[202]
#define sipNameNr_QHistoryState__HistoryType 230
#define sipName_QHistoryState__HistoryType &sipStrings_QtStateMachine[230]
#define sipNameNr_257 257
#define sipName_257 &sipStrings_QtStateMachine[257]
#define sipNameNr_QStateMachine__SignalEvent 284
#define sipName_QStateMachine__SignalEvent &sipStrings_QtStateMachine[284]
#define sipNameNr_defaultTransitionChanged 311
#define sipName_defaultTransitionChanged &sipStrings_QtStateMachine[311]
#define sipNameNr_336 336
#define sipName_336 &sipStrings_QtStateMachine[336]
#define sipNameNr_removeDefaultAnimation 359
#define sipName_removeDefaultAnimation &sipStrings_QtStateMachine[359]
#define sipNameNr_setGlobalRestorePolicy 382
#define sipName_setGlobalRestorePolicy &sipStrings_QtStateMachine[382]
#define sipNameNr_DontRestoreProperties 405
#define sipName_DontRestoreProperties &sipStrings_QtStateMachine[405]
#define sipNameNr_QMouseEventTransition 427
#define sipName_QMouseEventTransition &sipStrings_QtStateMachine[427]
#define sipNameNr_449 449
#define sipName_449 &sipStrings_QtStateMachine[449]
#define sipNameNr_QState__RestorePolicy 471
#define sipName_QState__RestorePolicy &sipStrings_QtStateMachine[471]
#define sipNameNr_PyQt6_QtStateMachine 493
#define sipName_PyQt6_QtStateMachine &sipStrings_QtStateMachine[493]
#define sipNameNr_QStateMachine__Error 514
#define sipName_QStateMachine__Error &sipStrings_QtStateMachine[514]
#define sipNameNr_setDefaultTransition 535
#define sipName_setDefaultTransition &sipStrings_QtStateMachine[535]
#define sipNameNr_NoInitialStateError 556
#define sipName_NoInitialStateError &sipStrings_QtStateMachine[556]
#define sipNameNr_QAbstractTransition 576
#define sipName_QAbstractTransition &sipStrings_QtStateMachine[576]
#define sipNameNr_QKeyEventTransition 596
#define sipName_QKeyEventTransition &sipStrings_QtStateMachine[596]
#define sipNameNr_addDefaultAnimation 616
#define sipName_addDefaultAnimation &sipStrings_QtStateMachine[616]
#define sipNameNr_defaultStateChanged 636
#define sipName_defaultStateChanged &sipStrings_QtStateMachine[636]
#define sipNameNr_globalRestorePolicy 656
#define sipName_globalRestorePolicy &sipStrings_QtStateMachine[656]
#define sipNameNr_initialStateChanged 676
#define sipName_initialStateChanged &sipStrings_QtStateMachine[676]
#define sipNameNr_senderObjectChanged 696
#define sipName_senderObjectChanged &sipStrings_QtStateMachine[696]
#define sipNameNr_targetStatesChanged 716
#define sipName_targetStatesChanged &sipStrings_QtStateMachine[716]
#define sipNameNr_ExternalTransition 736
#define sipName_ExternalTransition &sipStrings_QtStateMachine[736]
#define sipNameNr_InternalTransition 755
#define sipName_InternalTransition &sipStrings_QtStateMachine[755]
#define sipNameNr_cancelDelayedEvent 774
#define sipName_cancelDelayedEvent &sipStrings_QtStateMachine[774]
#define sipNameNr_historyTypeChanged 793
#define sipName_historyTypeChanged &sipStrings_QtStateMachine[793]
#define sipNameNr_propertiesAssigned 812
#define sipName_propertiesAssigned &sipStrings_QtStateMachine[812]
#define sipNameNr_targetStateChanged 831
#define sipName_targetStateChanged &sipStrings_QtStateMachine[831]
#define sipNameNr_QSignalTransition 850
#define sipName_QSignalTransition &sipStrings_QtStateMachine[850]
#define sipNameNr_QState__ChildMode 868
#define sipName_QState__ChildMode &sipStrings_QtStateMachine[868]
#define sipNameNr_RestoreProperties 409
#define sipName_RestoreProperties &sipStrings_QtStateMachine[409]
#define sipNameNr_defaultAnimations 886
#define sipName_defaultAnimations &sipStrings_QtStateMachine[886]
#define sipNameNr_defaultTransition 904
#define sipName_defaultTransition &sipStrings_QtStateMachine[904]
#define sipNameNr_errorStateChanged 922
#define sipName_errorStateChanged &sipStrings_QtStateMachine[922]
#define sipNameNr_setTransitionType 940
#define sipName_setTransitionType &sipStrings_QtStateMachine[940]
#define sipNameNr_QEventTransition 958
#define sipName_QEventTransition &sipStrings_QtStateMachine[958]
#define sipNameNr_childModeChanged 975
#define sipName_childModeChanged &sipStrings_QtStateMachine[975]
#define sipNameNr_disconnectNotify 992
#define sipName_disconnectNotify &sipStrings_QtStateMachine[992]
#define sipNameNr_postDelayedEvent 1009
#define sipName_postDelayedEvent &sipStrings_QtStateMachine[1009]
#define sipNameNr_removeTransition 1026
#define sipName_removeTransition &sipStrings_QtStateMachine[1026]
#define sipNameNr_ExclusiveStates 1043
#define sipName_ExclusiveStates &sipStrings_QtStateMachine[1043]
#define sipNameNr_removeAnimation 1059
#define sipName_removeAnimation &sipStrings_QtStateMachine[1059]
#define sipNameNr_setDefaultState 1075
#define sipName_setDefaultState &sipStrings_QtStateMachine[1075]
#define sipNameNr_setInitialState 1091
#define sipName_setInitialState &sipStrings_QtStateMachine[1091]
#define sipNameNr_setModifierMask 1107
#define sipName_setModifierMask &sipStrings_QtStateMachine[1107]
#define sipNameNr_setSenderObject 1123
#define sipName_setSenderObject &sipStrings_QtStateMachine[1123]
#define sipNameNr_setTargetStates 1139
#define sipName_setTargetStates &sipStrings_QtStateMachine[1139]
#define sipNameNr_NormalPriority 1155
#define sipName_NormalPriority &sipStrings_QtStateMachine[1155]
#define sipNameNr_ParallelStates 1170
#define sipName_ParallelStates &sipStrings_QtStateMachine[1170]
#define sipNameNr_QAbstractState 1185
#define sipName_QAbstractState &sipStrings_QtStateMachine[1185]
#define sipNameNr_ShallowHistory 1200
#define sipName_ShallowHistory &sipStrings_QtStateMachine[1200]
#define sipNameNr_TransitionType 61
#define sipName_TransitionType &sipStrings_QtStateMachine[61]
#define sipNameNr_assignProperty 1215
#define sipName_assignProperty &sipStrings_QtStateMachine[1215]
#define sipNameNr_runningChanged 1230
#define sipName_runningChanged &sipStrings_QtStateMachine[1230]
#define sipNameNr_setEventSource 1245
#define sipName_setEventSource &sipStrings_QtStateMachine[1245]
#define sipNameNr_setHistoryType 1260
#define sipName_setHistoryType &sipStrings_QtStateMachine[1260]
#define sipNameNr_setHitTestPath 1275
#define sipName_setHitTestPath &sipStrings_QtStateMachine[1275]
#define sipNameNr_setTargetState 1290
#define sipName_setTargetState &sipStrings_QtStateMachine[1290]
#define sipNameNr_transitionType 1305
#define sipName_transitionType &sipStrings_QtStateMachine[1305]
#define sipNameNr_EventPriority 160
#define sipName_EventPriority &sipStrings_QtStateMachine[160]
#define sipNameNr_QHistoryState 1320
#define sipName_QHistoryState &sipStrings_QtStateMachine[1320]
#define sipNameNr_QStateMachine 1334
#define sipName_QStateMachine &sipStrings_QtStateMachine[1334]
#define sipNameNr_RestorePolicy 391
#define sipName_RestorePolicy &sipStrings_QtStateMachine[391]
#define sipNameNr_activeChanged 1348
#define sipName_activeChanged &sipStrings_QtStateMachine[1348]
#define sipNameNr_addTransition 1362
#define sipName_addTransition &sipStrings_QtStateMachine[1362]
#define sipNameNr_configuration 1376
#define sipName_configuration &sipStrings_QtStateMachine[1376]
#define sipNameNr_connectNotify 995
#define sipName_connectNotify &sipStrings_QtStateMachine[995]
#define sipNameNr_setErrorState 1390
#define sipName_setErrorState &sipStrings_QtStateMachine[1390]
#define sipNameNr_signalChanged 1404
#define sipName_signalChanged &sipStrings_QtStateMachine[1404]
#define sipNameNr_HighPriority 1418
#define sipName_HighPriority &sipStrings_QtStateMachine[1418]
#define sipNameNr_WrappedEvent 217
#define sipName_WrappedEvent &sipStrings_QtStateMachine[217]
#define sipNameNr_addAnimation 1431
#define sipName_addAnimation &sipStrings_QtStateMachine[1431]
#define sipNameNr_defaultState 1444
#define sipName_defaultState &sipStrings_QtStateMachine[1444]
#define sipNameNr_initialState 1457
#define sipName_initialState &sipStrings_QtStateMachine[1457]
#define sipNameNr_modifierMask 1470
#define sipName_modifierMask &sipStrings_QtStateMachine[1470]
#define sipNameNr_onTransition 1483
#define sipName_onTransition &sipStrings_QtStateMachine[1483]
#define sipNameNr_senderObject 1496
#define sipName_senderObject &sipStrings_QtStateMachine[1496]
#define sipNameNr_setChildMode 1509
#define sipName_setChildMode &sipStrings_QtStateMachine[1509]
#define sipNameNr_setEventType 1522
#define sipName_setEventType &sipStrings_QtStateMachine[1522]
#define sipNameNr_targetStates 1535
#define sipName_targetStates &sipStrings_QtStateMachine[1535]
#define sipNameNr_DeepHistory 1548
#define sipName_DeepHistory &sipStrings_QtStateMachine[1548]
#define sipNameNr_HistoryType 245
#define sipName_HistoryType &sipStrings_QtStateMachine[245]
#define sipNameNr_QFinalState 1560
#define sipName_QFinalState &sipStrings_QtStateMachine[1560]
#define sipNameNr_SignalEvent 299
#define sipName_SignalEvent &sipStrings_QtStateMachine[299]
#define sipNameNr_customEvent 1572
#define sipName_customEvent &sipStrings_QtStateMachine[1572]
#define sipNameNr_errorString 1584
#define sipName_errorString &sipStrings_QtStateMachine[1584]
#define sipNameNr_eventFilter 1596
#define sipName_eventFilter &sipStrings_QtStateMachine[1596]
#define sipNameNr_eventSource 1608
#define sipName_eventSource &sipStrings_QtStateMachine[1608]
#define sipNameNr_historyType 1620
#define sipName_historyType &sipStrings_QtStateMachine[1620]
#define sipNameNr_hitTestPath 1632
#define sipName_hitTestPath &sipStrings_QtStateMachine[1632]
#define sipNameNr_parentState 1644
#define sipName_parentState &sipStrings_QtStateMachine[1644]
#define sipNameNr_removeState 1656
#define sipName_removeState &sipStrings_QtStateMachine[1656]
#define sipNameNr_setAccepted 1668
#define sipName_setAccepted &sipStrings_QtStateMachine[1668]
#define sipNameNr_setAnimated 1680
#define sipName_setAnimated &sipStrings_QtStateMachine[1680]
#define sipNameNr_signalIndex 1692
#define sipName_signalIndex &sipStrings_QtStateMachine[1692]
#define sipNameNr_sourceState 1704
#define sipName_sourceState &sipStrings_QtStateMachine[1704]
#define sipNameNr_targetState 1716
#define sipName_targetState &sipStrings_QtStateMachine[1716]
#define sipNameNr_transitions 1728
#define sipName_transitions &sipStrings_QtStateMachine[1728]
#define sipNameNr_animations 1740
#define sipName_animations &sipStrings_QtStateMachine[1740]
#define sipNameNr_childEvent 1751
#define sipName_childEvent &sipStrings_QtStateMachine[1751]
#define sipNameNr_clearError 1762
#define sipName_clearError &sipStrings_QtStateMachine[1762]
#define sipNameNr_errorState 1773
#define sipName_errorState &sipStrings_QtStateMachine[1773]
#define sipNameNr_isAnimated 1784
#define sipName_isAnimated &sipStrings_QtStateMachine[1784]
#define sipNameNr_setRunning 1795
#define sipName_setRunning &sipStrings_QtStateMachine[1795]
#define sipNameNr_timerEvent 1806
#define sipName_timerEvent &sipStrings_QtStateMachine[1806]
#define sipNameNr_ChildMode 876
#define sipName_ChildMode &sipStrings_QtStateMachine[876]
#define sipNameNr_arguments 1817
#define sipName_arguments &sipStrings_QtStateMachine[1817]
#define sipNameNr_childMode 1827
#define sipName_childMode &sipStrings_QtStateMachine[1827]
#define sipNameNr_eventTest 1837
#define sipName_eventTest &sipStrings_QtStateMachine[1837]
#define sipNameNr_eventType 1847
#define sipName_eventType &sipStrings_QtStateMachine[1847]
#define sipNameNr_isRunning 1857
#define sipName_isRunning &sipStrings_QtStateMachine[1857]
#define sipNameNr_postEvent 1867
#define sipName_postEvent &sipStrings_QtStateMachine[1867]
#define sipNameNr_setButton 1877
#define sipName_setButton &sipStrings_QtStateMachine[1877]
#define sipNameNr_setSignal 1887
#define sipName_setSignal &sipStrings_QtStateMachine[1887]
#define sipNameNr_triggered 1897
#define sipName_triggered &sipStrings_QtStateMachine[1897]
#define sipNameNr_addState 1907
#define sipName_addState &sipStrings_QtStateMachine[1907]
#define sipNameNr_finished 1916
#define sipName_finished &sipStrings_QtStateMachine[1916]
#define sipNameNr_priority 1925
#define sipName_priority &sipStrings_QtStateMachine[1925]
#define sipNameNr_NoError 1934
#define sipName_NoError &sipStrings_QtStateMachine[1934]
#define sipNameNr_entered 1942
#define sipName_entered &sipStrings_QtStateMachine[1942]
#define sipNameNr_machine 1950
#define sipName_machine &sipStrings_QtStateMachine[1950]
#define sipNameNr_onEntry 1958
#define sipName_onEntry &sipStrings_QtStateMachine[1958]
#define sipNameNr_started 1966
#define sipName_started &sipStrings_QtStateMachine[1966]
#define sipNameNr_stopped 1974
#define sipName_stopped &sipStrings_QtStateMachine[1974]
#define sipNameNr_QState 1982
#define sipName_QState &sipStrings_QtStateMachine[1982]
#define sipNameNr_active 1989
#define sipName_active &sipStrings_QtStateMachine[1989]
#define sipNameNr_button 1996
#define sipName_button &sipStrings_QtStateMachine[1996]
#define sipNameNr_exited 2003
#define sipName_exited &sipStrings_QtStateMachine[2003]
#define sipNameNr_object 2010
#define sipName_object &sipStrings_QtStateMachine[2010]
#define sipNameNr_onExit 2017
#define sipName_onExit &sipStrings_QtStateMachine[2017]
#define sipNameNr_parent 2024
#define sipName_parent &sipStrings_QtStateMachine[2024]
#define sipNameNr_sender 2031
#define sipName_sender &sipStrings_QtStateMachine[2031]
#define sipNameNr_setKey 2038
#define sipName_setKey &sipStrings_QtStateMachine[2038]
#define sipNameNr_signal 2045
#define sipName_signal &sipStrings_QtStateMachine[2045]
#define sipNameNr_Error 34
#define sipName_Error &sipStrings_QtStateMachine[34]
#define sipNameNr_clone 2052
#define sipName_clone &sipStrings_QtStateMachine[2052]
#define sipNameNr_error 2058
#define sipName_error &sipStrings_QtStateMachine[2058]
#define sipNameNr_event 2064
#define sipName_event &sipStrings_QtStateMachine[2064]
#define sipNameNr_start 2070
#define sipName_start &sipStrings_QtStateMachine[2070]
#define sipNameNr_stop 2076
#define sipName_stop &sipStrings_QtStateMachine[2076]
#define sipNameNr_key 2081
#define sipName_key &sipStrings_QtStateMachine[2081]

#define sipMalloc                   sipAPI_QtStateMachine->api_malloc
#define sipFree                     sipAPI_QtStateMachine->api_free
#define sipBuildResult              sipAPI_QtStateMachine->api_build_result
#define sipCallMethod               sipAPI_QtStateMachine->api_call_method
#define sipCallProcedureMethod      sipAPI_QtStateMachine->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtStateMachine->api_call_error_handler
#define sipParseResultEx            sipAPI_QtStateMachine->api_parse_result_ex
#define sipParseResult              sipAPI_QtStateMachine->api_parse_result
#define sipParseArgs                sipAPI_QtStateMachine->api_parse_args
#define sipParseKwdArgs             sipAPI_QtStateMachine->api_parse_kwd_args
#define sipParsePair                sipAPI_QtStateMachine->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtStateMachine->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtStateMachine->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtStateMachine->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtStateMachine->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtStateMachine->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtStateMachine->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtStateMachine->api_add_exception
#define sipNoFunction               sipAPI_QtStateMachine->api_no_function
#define sipNoMethod                 sipAPI_QtStateMachine->api_no_method
#define sipAbstractMethod           sipAPI_QtStateMachine->api_abstract_method
#define sipBadClass                 sipAPI_QtStateMachine->api_bad_class
#define sipBadCatcherResult         sipAPI_QtStateMachine->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtStateMachine->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtStateMachine->api_bad_operator_arg
#define sipTrace                    sipAPI_QtStateMachine->api_trace
#define sipTransferBack             sipAPI_QtStateMachine->api_transfer_back
#define sipTransferTo               sipAPI_QtStateMachine->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtStateMachine->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtStateMachine->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtStateMachine->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtStateMachine->api_voidptr_type
#define sipGetPyObject              sipAPI_QtStateMachine->api_get_pyobject
#define sipGetAddress               sipAPI_QtStateMachine->api_get_address
#define sipGetMixinAddress          sipAPI_QtStateMachine->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtStateMachine->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtStateMachine->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtStateMachine->api_call_hook
#define sipEndThread                sipAPI_QtStateMachine->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtStateMachine->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtStateMachine->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtStateMachine->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtStateMachine->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtStateMachine->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtStateMachine->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtStateMachine->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtStateMachine->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtStateMachine->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtStateMachine->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtStateMachine->api_convert_to_bool
#define sipReleaseType              sipAPI_QtStateMachine->api_release_type
#define sipConvertFromType          sipAPI_QtStateMachine->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtStateMachine->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtStateMachine->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtStateMachine->api_convert_from_enum
#define sipGetState                 sipAPI_QtStateMachine->api_get_state
#define sipExportSymbol             sipAPI_QtStateMachine->api_export_symbol
#define sipImportSymbol             sipAPI_QtStateMachine->api_import_symbol
#define sipFindType                 sipAPI_QtStateMachine->api_find_type
#define sipBytes_AsChar             sipAPI_QtStateMachine->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtStateMachine->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtStateMachine->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtStateMachine->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtStateMachine->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtStateMachine->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtStateMachine->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtStateMachine->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtStateMachine->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtStateMachine->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtStateMachine->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtStateMachine->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtStateMachine->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtStateMachine->api_get_reference
#define sipKeepReference            sipAPI_QtStateMachine->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtStateMachine->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtStateMachine->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtStateMachine->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtStateMachine->api_type_scope
#define sipResolveTypedef           sipAPI_QtStateMachine->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtStateMachine->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtStateMachine->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtStateMachine->api_init_mixin
#define sipExportModule             sipAPI_QtStateMachine->api_export_module
#define sipInitModule               sipAPI_QtStateMachine->api_init_module
#define sipGetInterpreter           sipAPI_QtStateMachine->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtStateMachine->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtStateMachine->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtStateMachine->api_py_type_dict
#define sipPyTypeName               sipAPI_QtStateMachine->api_py_type_name
#define sipGetCFunction             sipAPI_QtStateMachine->api_get_c_function
#define sipGetMethod                sipAPI_QtStateMachine->api_get_method
#define sipFromMethod               sipAPI_QtStateMachine->api_from_method
#define sipGetDate                  sipAPI_QtStateMachine->api_get_date
#define sipFromDate                 sipAPI_QtStateMachine->api_from_date
#define sipGetDateTime              sipAPI_QtStateMachine->api_get_datetime
#define sipFromDateTime             sipAPI_QtStateMachine->api_from_datetime
#define sipGetTime                  sipAPI_QtStateMachine->api_get_time
#define sipFromTime                 sipAPI_QtStateMachine->api_from_time
#define sipIsUserType               sipAPI_QtStateMachine->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtStateMachine->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtStateMachine->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtStateMachine->api_unicode_write
#define sipUnicodeData              sipAPI_QtStateMachine->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtStateMachine->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtStateMachine->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtStateMachine->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtStateMachine->api_is_derived_class
#define sipGetUserObject            sipAPI_QtStateMachine->api_get_user_object
#define sipSetUserObject            sipAPI_QtStateMachine->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtStateMachine->api_register_event_handler
#define sipConvertToArray           sipAPI_QtStateMachine->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtStateMachine->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtStateMachine->api_enable_gc
#define sipPrintObject              sipAPI_QtStateMachine->api_print_object
#define sipLong_AsChar              sipAPI_QtStateMachine->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtStateMachine->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtStateMachine->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtStateMachine->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtStateMachine->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtStateMachine->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtStateMachine->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtStateMachine->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtStateMachine->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtStateMachine->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtStateMachine->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtStateMachine->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtStateMachine->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtStateMachine->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtStateMachine->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtStateMachine->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtStateMachine->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtStateMachine->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtStateMachine->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtStateMachine->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtStateMachine->api_release_type_us
#define sipIsPyMethod               sipAPI_QtStateMachine->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtStateMachine[];

#define sipType_QAbstractState sipExportedTypes_QtStateMachine[0]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QAbstractState;

#define sipType_QAbstractTransition sipExportedTypes_QtStateMachine[1]

#define sipType_QAbstractTransition_TransitionType sipExportedTypes_QtStateMachine[2]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QAbstractTransition;

#define sipType_QEventTransition sipExportedTypes_QtStateMachine[3]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QEventTransition;

#define sipType_QFinalState sipExportedTypes_QtStateMachine[4]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QFinalState;

#define sipType_QHistoryState sipExportedTypes_QtStateMachine[5]

#define sipType_QHistoryState_HistoryType sipExportedTypes_QtStateMachine[6]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QHistoryState;

#define sipType_QKeyEventTransition sipExportedTypes_QtStateMachine[7]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QKeyEventTransition;

#define sipType_QMouseEventTransition sipExportedTypes_QtStateMachine[11]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QMouseEventTransition;

#define sipType_QSignalTransition sipExportedTypes_QtStateMachine[13]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QSignalTransition;

#define sipType_QState sipExportedTypes_QtStateMachine[14]

#define sipType_QState_RestorePolicy sipExportedTypes_QtStateMachine[16]

#define sipType_QState_ChildMode sipExportedTypes_QtStateMachine[15]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QState;

#define sipType_QStateMachine sipExportedTypes_QtStateMachine[17]

#define sipType_QStateMachine_Error sipExportedTypes_QtStateMachine[18]

#define sipType_QStateMachine_EventPriority sipExportedTypes_QtStateMachine[19]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QStateMachine;

#define sipType_QStateMachine_SignalEvent sipExportedTypes_QtStateMachine[20]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QStateMachine_SignalEvent;

#define sipType_QStateMachine_WrappedEvent sipExportedTypes_QtStateMachine[21]

extern sipClassTypeDef sipTypeDef_QtStateMachine_QStateMachine_WrappedEvent;

#define sipType_QSet_0101QAbstractState sipExportedTypes_QtStateMachine[12]

extern sipMappedTypeDef sipTypeDef_QtStateMachine_QSet_0101QAbstractState;

#define sipType_QList_0101QAbstractTransition sipExportedTypes_QtStateMachine[10]

extern sipMappedTypeDef sipTypeDef_QtStateMachine_QList_0101QAbstractTransition;

#define sipType_QList_0101QAbstractAnimation sipExportedTypes_QtStateMachine[8]

extern sipMappedTypeDef sipTypeDef_QtStateMachine_QList_0101QAbstractAnimation;

#define sipType_QList_0101QAbstractState sipExportedTypes_QtStateMachine[9]

extern sipMappedTypeDef sipTypeDef_QtStateMachine_QList_0101QAbstractState;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtStateMachine;
extern sipExportedModuleDef sipModuleAPI_QtStateMachine;
extern sipTypeDef *sipExportedTypes_QtStateMachine[];

#define sipType_Qt_MouseButton sipImportedTypes_QtStateMachine_QtCore[12].it_td

#define sipType_QObject sipImportedTypes_QtStateMachine_QtCore[8].it_td

#define sipType_QAbstractAnimation sipImportedTypes_QtStateMachine_QtCore[0].it_td

#define sipType_QByteArray sipImportedTypes_QtStateMachine_QtCore[1].it_td

#define sipType_QEvent sipImportedTypes_QtStateMachine_QtCore[3].it_td

#define sipType_QEvent_Type sipImportedTypes_QtStateMachine_QtCore[4].it_td

#define sipType_QTimerEvent sipImportedTypes_QtStateMachine_QtCore[10].it_td

#define sipType_QChildEvent sipImportedTypes_QtStateMachine_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtStateMachine_QtCore[7].it_td

#define sipType_QVariant sipImportedTypes_QtStateMachine_QtCore[11].it_td

#define sipType_QFlags_0100Qt_KeyboardModifier sipImportedTypes_QtStateMachine_QtCore[5].it_td

#define sipType_QList_0100QVariant sipImportedTypes_QtStateMachine_QtCore[6].it_td

#define sipType_QString sipImportedTypes_QtStateMachine_QtCore[9].it_td
extern sipImportedTypeDef sipImportedTypes_QtStateMachine_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtStateMachine_QtCore[];

#define sipType_QPainterPath sipImportedTypes_QtStateMachine_QtGui[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtStateMachine_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtStateMachine_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtStateMachine_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtStateMachine_qt_metacast;
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtStateMachine/qstate.sip"
// Imports from QtCore.
typedef sipErrorState (*pyqt6_qtstatemachine_get_pyqtsignal_parts_t)(PyObject *, QObject **, QByteArray &);
extern pyqt6_qtstatemachine_get_pyqtsignal_parts_t pyqt6_qtstatemachine_get_pyqtsignal_parts;
#line 626 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipAPIQtStateMachine.h"

#endif
