/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtHelp.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpengine.sip"
#include <qhelpengine.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpsearchengine.sip"
#include <qhelpsearchengine.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 49 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpindexwidget.sip"
#include <qhelpindexwidget.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpcontentwidget.sip"
#include <qhelpcontentwidget.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpindexwidget.sip"
#include <qhelpindexwidget.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpcontentwidget.sip"
#include <qhelpcontentwidget.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelplink.sip"
#include <qhelplink.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpfilterengine.sip"
#include <qhelpfilterengine.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 112 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 118 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpEngine.cpp"


class sipQHelpEngine : public ::QHelpEngine
{
public:
    sipQHelpEngine(const ::QString&, ::QObject*);
    virtual ~sipQHelpEngine();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQHelpEngine(const sipQHelpEngine &);
    sipQHelpEngine &operator = (const sipQHelpEngine &);

    char sipPyMethods[7];
};

sipQHelpEngine::sipQHelpEngine(const ::QString& a0, ::QObject*a1): ::QHelpEngine(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQHelpEngine::~sipQHelpEngine()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQHelpEngine::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtHelp_qt_metaobject(sipPySelf, sipType_QHelpEngine);

    return ::QHelpEngine::metaObject();
}

int sipQHelpEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QHelpEngine::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtHelp_qt_metacall(sipPySelf, sipType_QHelpEngine, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQHelpEngine::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtHelp_qt_metacast(sipPySelf, sipType_QHelpEngine, _clname, &sipCpp) ? sipCpp : ::QHelpEngine::qt_metacast(_clname));
}

void sipQHelpEngine::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QHelpEngine::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtHelp_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtHelp_30(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpEngine::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QHelpEngine::connectNotify(a0);
        return;
    }

    extern void sipVH_QtHelp_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtHelp_30(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpEngine::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QHelpEngine::customEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtHelp_29(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpEngine::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QHelpEngine::childEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtHelp_28(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpEngine::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QHelpEngine::timerEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtHelp_27(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQHelpEngine::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QHelpEngine::eventFilter(a0, a1);

    extern bool sipVH_QtHelp_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtHelp_26(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQHelpEngine::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QHelpEngine::event(a0);

    extern bool sipVH_QtHelp_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtHelp_25(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QHelpEngine_contentModel, "contentModel(self) -> QHelpContentModel|None");

extern "C" {static PyObject *meth_QHelpEngine_contentModel(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngine_contentModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngine, &sipCpp))
        {
            ::QHelpContentModel*sipRes;

            sipRes = sipCpp->contentModel();

            return sipConvertFromType(sipRes, sipType_QHelpContentModel, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngine, sipName_contentModel, doc_QHelpEngine_contentModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngine_indexModel, "indexModel(self) -> QHelpIndexModel|None");

extern "C" {static PyObject *meth_QHelpEngine_indexModel(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngine_indexModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngine, &sipCpp))
        {
            ::QHelpIndexModel*sipRes;

            sipRes = sipCpp->indexModel();

            return sipConvertFromType(sipRes, sipType_QHelpIndexModel, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngine, sipName_indexModel, doc_QHelpEngine_indexModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngine_contentWidget, "contentWidget(self) -> QHelpContentWidget|None");

extern "C" {static PyObject *meth_QHelpEngine_contentWidget(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngine_contentWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngine, &sipCpp))
        {
            ::QHelpContentWidget*sipRes;

            sipRes = sipCpp->contentWidget();

            return sipConvertFromType(sipRes, sipType_QHelpContentWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngine, sipName_contentWidget, doc_QHelpEngine_contentWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngine_indexWidget, "indexWidget(self) -> QHelpIndexWidget|None");

extern "C" {static PyObject *meth_QHelpEngine_indexWidget(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngine_indexWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngine, &sipCpp))
        {
            ::QHelpIndexWidget*sipRes;

            sipRes = sipCpp->indexWidget();

            return sipConvertFromType(sipRes, sipType_QHelpIndexWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngine, sipName_indexWidget, doc_QHelpEngine_indexWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngine_searchEngine, "searchEngine(self) -> QHelpSearchEngine|None");

extern "C" {static PyObject *meth_QHelpEngine_searchEngine(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngine_searchEngine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngine, &sipCpp))
        {
            ::QHelpSearchEngine*sipRes;

            sipRes = sipCpp->searchEngine();

            return sipConvertFromType(sipRes, sipType_QHelpSearchEngine, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngine, sipName_searchEngine, doc_QHelpEngine_searchEngine);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QHelpEngine(void *, const sipTypeDef *);}
static void *cast_QHelpEngine(void *sipCppV, const sipTypeDef *targetType)
{
    ::QHelpEngine *sipCpp = reinterpret_cast< ::QHelpEngine *>(sipCppV);

    if (targetType == sipType_QHelpEngine)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QHelpEngineCore)->ctd_cast(static_cast< ::QHelpEngineCore *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHelpEngine(void *, int);}
static void release_QHelpEngine(void *sipCppV, int)
{
    ::QHelpEngine *sipCpp = reinterpret_cast< ::QHelpEngine *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QHelpEngine(sipSimpleWrapper *);}
static void dealloc_QHelpEngine(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQHelpEngine *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHelpEngine(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QHelpEngine(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QHelpEngine(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQHelpEngine *sipCpp = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QString, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQHelpEngine(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QHelpEngine[] = {{5, 255, 1}};


static PyMethodDef methods_QHelpEngine[] = {
    {sipName_contentModel, meth_QHelpEngine_contentModel, METH_VARARGS, doc_QHelpEngine_contentModel},
    {sipName_contentWidget, meth_QHelpEngine_contentWidget, METH_VARARGS, doc_QHelpEngine_contentWidget},
    {sipName_indexModel, meth_QHelpEngine_indexModel, METH_VARARGS, doc_QHelpEngine_indexModel},
    {sipName_indexWidget, meth_QHelpEngine_indexWidget, METH_VARARGS, doc_QHelpEngine_indexWidget},
    {sipName_searchEngine, meth_QHelpEngine_searchEngine, METH_VARARGS, doc_QHelpEngine_searchEngine}
};

PyDoc_STRVAR(doc_QHelpEngine, "\1QHelpEngine(collectionFile: str|None, parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QHelpEngine = {
    &::QHelpEngine::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtHelp_QHelpEngine = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHelpEngine,
        SIP_NULLPTR,
        &plugin_QHelpEngine,
    },
    {
        sipNameNr_QHelpEngine,
        {0, 0, 1},
        5, methods_QHelpEngine,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QHelpEngine,
    -1,
    -1,
    supers_QHelpEngine,
    SIP_NULLPTR,
    init_type_QHelpEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHelpEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QHelpEngine,
    cast_QHelpEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QHelpEngine),
};
