/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qeventpoint.sip"
#include <qeventpoint.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQEventPoint.cpp"

#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQEventPoint.cpp"
#line 114 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQEventPoint.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpointingdevice.sip"
#include <qpointingdevice.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQEventPoint.cpp"
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpointingdevice.sip"
#include <qpointingdevice.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQEventPoint.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQEventPoint.cpp"


PyDoc_STRVAR(doc_QEventPoint_swap, "swap(self, other: QEventPoint)");

extern "C" {static PyObject *meth_QEventPoint_swap(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QEventPoint* a0;
        ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QEventPoint, &sipCpp, sipType_QEventPoint, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_swap, doc_QEventPoint_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_position, "position(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_position(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->position());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_position, doc_QEventPoint_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_pressPosition, "pressPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_pressPosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_pressPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->pressPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_pressPosition, doc_QEventPoint_pressPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_grabPosition, "grabPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_grabPosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_grabPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->grabPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_grabPosition, doc_QEventPoint_grabPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_lastPosition, "lastPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_lastPosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_lastPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->lastPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_lastPosition, doc_QEventPoint_lastPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_scenePosition, "scenePosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_scenePosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_scenePosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->scenePosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_scenePosition, doc_QEventPoint_scenePosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_scenePressPosition, "scenePressPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_scenePressPosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_scenePressPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->scenePressPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_scenePressPosition, doc_QEventPoint_scenePressPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_sceneGrabPosition, "sceneGrabPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_sceneGrabPosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_sceneGrabPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->sceneGrabPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_sceneGrabPosition, doc_QEventPoint_sceneGrabPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_sceneLastPosition, "sceneLastPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_sceneLastPosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_sceneLastPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->sceneLastPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_sceneLastPosition, doc_QEventPoint_sceneLastPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_globalPosition, "globalPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_globalPosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_globalPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->globalPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_globalPosition, doc_QEventPoint_globalPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_globalPressPosition, "globalPressPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_globalPressPosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_globalPressPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->globalPressPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_globalPressPosition, doc_QEventPoint_globalPressPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_globalGrabPosition, "globalGrabPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_globalGrabPosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_globalGrabPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->globalGrabPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_globalGrabPosition, doc_QEventPoint_globalGrabPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_globalLastPosition, "globalLastPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_globalLastPosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_globalLastPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->globalLastPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_globalLastPosition, doc_QEventPoint_globalLastPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_normalizedPosition, "normalizedPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QEventPoint_normalizedPosition(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_normalizedPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->normalizedPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_normalizedPosition, doc_QEventPoint_normalizedPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_velocity, "velocity(self) -> QVector2D");

extern "C" {static PyObject *meth_QEventPoint_velocity(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_velocity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QVector2D*sipRes;

            sipRes = new ::QVector2D(sipCpp->velocity());

            return sipConvertFromNewType(sipRes, sipType_QVector2D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_velocity, doc_QEventPoint_velocity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_state, "state(self) -> QEventPoint.State");

extern "C" {static PyObject *meth_QEventPoint_state(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QEventPoint::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QEventPoint_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_state, doc_QEventPoint_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_device, "device(self) -> QPointingDevice|None");

extern "C" {static PyObject *meth_QEventPoint_device(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_device(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            const ::QPointingDevice*sipRes;

            sipRes = sipCpp->device();

            return sipConvertFromType(const_cast< ::QPointingDevice *>(sipRes), sipType_QPointingDevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_device, doc_QEventPoint_device);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_id, "id(self) -> int");

extern "C" {static PyObject *meth_QEventPoint_id(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_id(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->id();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_id, doc_QEventPoint_id);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_uniqueId, "uniqueId(self) -> QPointingDeviceUniqueId");

extern "C" {static PyObject *meth_QEventPoint_uniqueId(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_uniqueId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QPointingDeviceUniqueId*sipRes;

            sipRes = new ::QPointingDeviceUniqueId(sipCpp->uniqueId());

            return sipConvertFromNewType(sipRes, sipType_QPointingDeviceUniqueId, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_uniqueId, doc_QEventPoint_uniqueId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_timestamp, "timestamp(self) -> int");

extern "C" {static PyObject *meth_QEventPoint_timestamp(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_timestamp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::ulong sipRes;

            sipRes = sipCpp->timestamp();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_timestamp, doc_QEventPoint_timestamp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_lastTimestamp, "lastTimestamp(self) -> int");

extern "C" {static PyObject *meth_QEventPoint_lastTimestamp(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_lastTimestamp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::ulong sipRes;

            sipRes = sipCpp->lastTimestamp();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_lastTimestamp, doc_QEventPoint_lastTimestamp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_pressTimestamp, "pressTimestamp(self) -> int");

extern "C" {static PyObject *meth_QEventPoint_pressTimestamp(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_pressTimestamp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::ulong sipRes;

            sipRes = sipCpp->pressTimestamp();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_pressTimestamp, doc_QEventPoint_pressTimestamp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_timeHeld, "timeHeld(self) -> float");

extern "C" {static PyObject *meth_QEventPoint_timeHeld(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_timeHeld(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->timeHeld();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_timeHeld, doc_QEventPoint_timeHeld);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_pressure, "pressure(self) -> float");

extern "C" {static PyObject *meth_QEventPoint_pressure(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_pressure(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->pressure();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_pressure, doc_QEventPoint_pressure);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_rotation, "rotation(self) -> float");

extern "C" {static PyObject *meth_QEventPoint_rotation(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->rotation();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_rotation, doc_QEventPoint_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_ellipseDiameters, "ellipseDiameters(self) -> QSizeF");

extern "C" {static PyObject *meth_QEventPoint_ellipseDiameters(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_ellipseDiameters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            ::QSizeF*sipRes;

            sipRes = new ::QSizeF(sipCpp->ellipseDiameters());

            return sipConvertFromNewType(sipRes, sipType_QSizeF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_ellipseDiameters, doc_QEventPoint_ellipseDiameters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_isAccepted, "isAccepted(self) -> bool");

extern "C" {static PyObject *meth_QEventPoint_isAccepted(PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_isAccepted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEventPoint, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAccepted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_isAccepted, doc_QEventPoint_isAccepted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEventPoint_setAccepted, "setAccepted(self, accepted: bool = True)");

extern "C" {static PyObject *meth_QEventPoint_setAccepted(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QEventPoint_setAccepted(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QEventPoint *sipCpp;

        static const char *sipKwdList[] = {
            sipName_accepted,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QEventPoint, &sipCpp, &a0))
        {
            sipCpp->setAccepted(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QEventPoint, sipName_setAccepted, doc_QEventPoint_setAccepted);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QEventPoint___ne__(PyObject *, PyObject *);}
static PyObject *slot_QEventPoint___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QEventPoint *sipCpp = reinterpret_cast< ::QEventPoint *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QEventPoint));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QEventPoint, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QEventPoint::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, ne_slot, sipType_QEventPoint, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QEventPoint___eq__(PyObject *, PyObject *);}
static PyObject *slot_QEventPoint___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QEventPoint *sipCpp = reinterpret_cast< ::QEventPoint *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QEventPoint));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QEventPoint* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QEventPoint, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QEventPoint::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, eq_slot, sipType_QEventPoint, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QEventPoint(void *, int);}
static void release_QEventPoint(void *sipCppV, int)
{
    delete reinterpret_cast< ::QEventPoint *>(sipCppV);
}


extern "C" {static void assign_QEventPoint(void *, Py_ssize_t, void *);}
static void assign_QEventPoint(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QEventPoint *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QEventPoint *>(sipSrc);
}


extern "C" {static void *copy_QEventPoint(const void *, Py_ssize_t);}
static void *copy_QEventPoint(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QEventPoint(reinterpret_cast<const ::QEventPoint *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QEventPoint(sipSimpleWrapper *);}
static void dealloc_QEventPoint(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QEventPoint(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QEventPoint(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QEventPoint(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QEventPoint *sipCpp = SIP_NULLPTR;

    {
        int a0;
        ::QEventPoint::State a1;
        const ::QPointF* a2;
        const ::QPointF* a3;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "iEJ9J9", &a0, sipType_QEventPoint_State, &a1, sipType_QPointF, &a2, sipType_QPointF, &a3))
        {
            sipCpp = new ::QEventPoint(a0, a1, *a2, *a3);

            return sipCpp;
        }
    }

    {
        const ::QEventPoint* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QEventPoint, &a0))
        {
            sipCpp = new ::QEventPoint(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QEventPoint[] = {
    {(void *)slot_QEventPoint___ne__, ne_slot},
    {(void *)slot_QEventPoint___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QEventPoint[] = {
    {sipName_device, meth_QEventPoint_device, METH_VARARGS, doc_QEventPoint_device},
    {sipName_ellipseDiameters, meth_QEventPoint_ellipseDiameters, METH_VARARGS, doc_QEventPoint_ellipseDiameters},
    {sipName_globalGrabPosition, meth_QEventPoint_globalGrabPosition, METH_VARARGS, doc_QEventPoint_globalGrabPosition},
    {sipName_globalLastPosition, meth_QEventPoint_globalLastPosition, METH_VARARGS, doc_QEventPoint_globalLastPosition},
    {sipName_globalPosition, meth_QEventPoint_globalPosition, METH_VARARGS, doc_QEventPoint_globalPosition},
    {sipName_globalPressPosition, meth_QEventPoint_globalPressPosition, METH_VARARGS, doc_QEventPoint_globalPressPosition},
    {sipName_grabPosition, meth_QEventPoint_grabPosition, METH_VARARGS, doc_QEventPoint_grabPosition},
    {sipName_id, meth_QEventPoint_id, METH_VARARGS, doc_QEventPoint_id},
    {sipName_isAccepted, meth_QEventPoint_isAccepted, METH_VARARGS, doc_QEventPoint_isAccepted},
    {sipName_lastPosition, meth_QEventPoint_lastPosition, METH_VARARGS, doc_QEventPoint_lastPosition},
    {sipName_lastTimestamp, meth_QEventPoint_lastTimestamp, METH_VARARGS, doc_QEventPoint_lastTimestamp},
    {sipName_normalizedPosition, meth_QEventPoint_normalizedPosition, METH_VARARGS, doc_QEventPoint_normalizedPosition},
    {sipName_position, meth_QEventPoint_position, METH_VARARGS, doc_QEventPoint_position},
    {sipName_pressPosition, meth_QEventPoint_pressPosition, METH_VARARGS, doc_QEventPoint_pressPosition},
    {sipName_pressTimestamp, meth_QEventPoint_pressTimestamp, METH_VARARGS, doc_QEventPoint_pressTimestamp},
    {sipName_pressure, meth_QEventPoint_pressure, METH_VARARGS, doc_QEventPoint_pressure},
    {sipName_rotation, meth_QEventPoint_rotation, METH_VARARGS, doc_QEventPoint_rotation},
    {sipName_sceneGrabPosition, meth_QEventPoint_sceneGrabPosition, METH_VARARGS, doc_QEventPoint_sceneGrabPosition},
    {sipName_sceneLastPosition, meth_QEventPoint_sceneLastPosition, METH_VARARGS, doc_QEventPoint_sceneLastPosition},
    {sipName_scenePosition, meth_QEventPoint_scenePosition, METH_VARARGS, doc_QEventPoint_scenePosition},
    {sipName_scenePressPosition, meth_QEventPoint_scenePressPosition, METH_VARARGS, doc_QEventPoint_scenePressPosition},
    {sipName_setAccepted, SIP_MLMETH_CAST(meth_QEventPoint_setAccepted), METH_VARARGS|METH_KEYWORDS, doc_QEventPoint_setAccepted},
    {sipName_state, meth_QEventPoint_state, METH_VARARGS, doc_QEventPoint_state},
    {sipName_swap, meth_QEventPoint_swap, METH_VARARGS, doc_QEventPoint_swap},
    {sipName_timeHeld, meth_QEventPoint_timeHeld, METH_VARARGS, doc_QEventPoint_timeHeld},
    {sipName_timestamp, meth_QEventPoint_timestamp, METH_VARARGS, doc_QEventPoint_timestamp},
    {sipName_uniqueId, meth_QEventPoint_uniqueId, METH_VARARGS, doc_QEventPoint_uniqueId},
    {sipName_velocity, meth_QEventPoint_velocity, METH_VARARGS, doc_QEventPoint_velocity}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QEventPoint[] = {
    {sipName_Unknown, static_cast<int>(::QEventPoint::Unknown)},
    {sipName_Stationary, static_cast<int>(::QEventPoint::Stationary)},
    {sipName_Pressed, static_cast<int>(::QEventPoint::Pressed)},
    {sipName_Updated, static_cast<int>(::QEventPoint::Updated)},
    {sipName_Released, static_cast<int>(::QEventPoint::Released)},
    {0, 0}
};

PyDoc_STRVAR(doc_QEventPoint, "\1QEventPoint(pointId: int, state: QEventPoint.State, scenePosition: QPointF, globalPosition: QPointF)\n"
"QEventPoint(other: QEventPoint)");


sipClassTypeDef sipTypeDef_QtGui_QEventPoint = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QEventPoint,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QEventPoint,
        {0, 0, 1},
        28, methods_QEventPoint,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QEventPoint, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QEventPoint,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QEventPoint,
    init_type_QEventPoint,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QEventPoint,
    assign_QEventPoint,
    SIP_NULLPTR,
    copy_QEventPoint,
    release_QEventPoint,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QEventPoint),
};
