/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtOpenGL.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglvertexarrayobject.sip"
#include <qopenglvertexarrayobject.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglvertexarrayobject.sip"
#include <qopenglvertexarrayobject.h>
#line 31 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLVertexArrayObjectBinder.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglvertexarrayobject.sip"
#include <qopenglvertexarrayobject.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLVertexArrayObjectBinder.cpp"


PyDoc_STRVAR(doc_QOpenGLVertexArrayObject_Binder_release, "release(self)");

extern "C" {static PyObject *meth_QOpenGLVertexArrayObject_Binder_release(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLVertexArrayObject_Binder_release(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLVertexArrayObject::Binder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLVertexArrayObject_Binder, &sipCpp))
        {
            sipCpp->release();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Binder, sipName_release, doc_QOpenGLVertexArrayObject_Binder_release);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLVertexArrayObject_Binder_rebind, "rebind(self)");

extern "C" {static PyObject *meth_QOpenGLVertexArrayObject_Binder_rebind(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLVertexArrayObject_Binder_rebind(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLVertexArrayObject::Binder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLVertexArrayObject_Binder, &sipCpp))
        {
            sipCpp->rebind();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Binder, sipName_rebind, doc_QOpenGLVertexArrayObject_Binder_rebind);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLVertexArrayObject_Binder___enter__, "__enter__(self) -> Any");

extern "C" {static PyObject *meth_QOpenGLVertexArrayObject_Binder___enter__(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLVertexArrayObject_Binder___enter__(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLVertexArrayObject::Binder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLVertexArrayObject_Binder, &sipCpp))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 52 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglvertexarrayobject.sip"
            // Just return a reference to self.
            sipRes = sipSelf;
            Py_INCREF(sipRes);
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLVertexArrayObjectBinder.cpp"

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_Binder, sipName___enter__, doc_QOpenGLVertexArrayObject_Binder___enter__);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLVertexArrayObject_Binder___exit__, "__exit__(self, type: Any, value: Any, traceback: Any)");

extern "C" {static PyObject *meth_QOpenGLVertexArrayObject_Binder___exit__(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLVertexArrayObject_Binder___exit__(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        PyObject * a1;
        PyObject * a2;
        ::QOpenGLVertexArrayObject::Binder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0P0P0", &sipSelf, sipType_QOpenGLVertexArrayObject_Binder, &sipCpp, &a0, &a1, &a2))
        {
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglvertexarrayobject.sip"
            sipCpp->release();
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLVertexArrayObjectBinder.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Binder, sipName___exit__, doc_QOpenGLVertexArrayObject_Binder___exit__);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QOpenGLVertexArrayObject_Binder(void *, int);}
static void release_QOpenGLVertexArrayObject_Binder(void *sipCppV, int)
{
    delete reinterpret_cast< ::QOpenGLVertexArrayObject::Binder *>(sipCppV);
}


extern "C" {static void dealloc_QOpenGLVertexArrayObject_Binder(sipSimpleWrapper *);}
static void dealloc_QOpenGLVertexArrayObject_Binder(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QOpenGLVertexArrayObject_Binder(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QOpenGLVertexArrayObject_Binder(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QOpenGLVertexArrayObject_Binder(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QOpenGLVertexArrayObject::Binder *sipCpp = SIP_NULLPTR;

    {
        ::QOpenGLVertexArrayObject* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8", sipType_QOpenGLVertexArrayObject, &a0))
        {
            sipCpp = new ::QOpenGLVertexArrayObject::Binder(a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QOpenGLVertexArrayObject_Binder[] = {
    {sipName___enter__, meth_QOpenGLVertexArrayObject_Binder___enter__, METH_VARARGS, doc_QOpenGLVertexArrayObject_Binder___enter__},
    {sipName___exit__, meth_QOpenGLVertexArrayObject_Binder___exit__, METH_VARARGS, doc_QOpenGLVertexArrayObject_Binder___exit__},
    {sipName_rebind, meth_QOpenGLVertexArrayObject_Binder_rebind, METH_VARARGS, doc_QOpenGLVertexArrayObject_Binder_rebind},
    {sipName_release, meth_QOpenGLVertexArrayObject_Binder_release, METH_VARARGS, doc_QOpenGLVertexArrayObject_Binder_release}
};

PyDoc_STRVAR(doc_QOpenGLVertexArrayObject_Binder, "\1QOpenGLVertexArrayObject.Binder(v: QOpenGLVertexArrayObject|None)");


sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLVertexArrayObject_Binder = {
    {
        SIP_NULLPTR,
        SIP_TYPE_NONLAZY|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QOpenGLVertexArrayObject__Binder,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_Binder,
        {57, 255, 0},
        4, methods_QOpenGLVertexArrayObject_Binder,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QOpenGLVertexArrayObject_Binder,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QOpenGLVertexArrayObject_Binder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QOpenGLVertexArrayObject_Binder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QOpenGLVertexArrayObject_Binder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QOpenGLVertexArrayObject::Binder),
};
