/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtTextToSpeechAPI_H
#define _QtTextToSpeechAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtTextToSpeech[0]
#define sipNameNr_QTextToSpeech__BoundaryHint 34
#define sipName_QTextToSpeech__BoundaryHint &sipStrings_QtTextToSpeech[34]
#define sipNameNr_QTextToSpeech__ErrorReason 62
#define sipName_QTextToSpeech__ErrorReason &sipStrings_QtTextToSpeech[62]
#define sipNameNr_QTextToSpeech__Capability 89
#define sipName_QTextToSpeech__Capability &sipStrings_QtTextToSpeech[89]
#define sipNameNr_PyQt6_sip_simplewrapper 115
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtTextToSpeech[115]
#define sipNameNr_PyQt6_QtTextToSpeech 139
#define sipName_PyQt6_QtTextToSpeech &sipStrings_QtTextToSpeech[139]
#define sipNameNr_QTextToSpeech__State 160
#define sipName_QTextToSpeech__State &sipStrings_QtTextToSpeech[160]
#define sipNameNr_WordByWordProgress 181
#define sipName_WordByWordProgress &sipStrings_QtTextToSpeech[181]
#define sipNameNr_engineCapabilities 200
#define sipName_engineCapabilities &sipStrings_QtTextToSpeech[200]
#define sipNameNr_aboutToSynthesize 219
#define sipName_aboutToSynthesize &sipStrings_QtTextToSpeech[219]
#define sipNameNr_availableEngines 237
#define sipName_availableEngines &sipStrings_QtTextToSpeech[237]
#define sipNameNr_availableLocales 254
#define sipName_availableLocales &sipStrings_QtTextToSpeech[254]
#define sipNameNr_disconnectNotify 271
#define sipName_disconnectNotify &sipStrings_QtTextToSpeech[271]
#define sipNameNr_availableVoices 288
#define sipName_availableVoices &sipStrings_QtTextToSpeech[288]
#define sipNameNr_Initialization 304
#define sipName_Initialization &sipStrings_QtTextToSpeech[304]
#define sipNameNr_QVoice__Gender 319
#define sipName_QVoice__Gender &sipStrings_QtTextToSpeech[319]
#define sipNameNr_Configuration 334
#define sipName_Configuration &sipStrings_QtTextToSpeech[334]
#define sipNameNr_348 348
#define sipName_348 &sipStrings_QtTextToSpeech[348]
#define sipNameNr_QTextToSpeech 362
#define sipName_QTextToSpeech &sipStrings_QtTextToSpeech[362]
#define sipNameNr_connectNotify 274
#define sipName_connectNotify &sipStrings_QtTextToSpeech[274]
#define sipNameNr_engineChanged 376
#define sipName_engineChanged &sipStrings_QtTextToSpeech[376]
#define sipNameNr_errorOccurred 390
#define sipName_errorOccurred &sipStrings_QtTextToSpeech[390]
#define sipNameNr_localeChanged 404
#define sipName_localeChanged &sipStrings_QtTextToSpeech[404]
#define sipNameNr_volumeChanged 418
#define sipName_volumeChanged &sipStrings_QtTextToSpeech[418]
#define sipNameNr_BoundaryHint 49
#define sipName_BoundaryHint &sipStrings_QtTextToSpeech[49]
#define sipNameNr_Synthesizing 432
#define sipName_Synthesizing &sipStrings_QtTextToSpeech[432]
#define sipNameNr_boundaryHint 445
#define sipName_boundaryHint &sipStrings_QtTextToSpeech[445]
#define sipNameNr_pitchChanged 458
#define sipName_pitchChanged &sipStrings_QtTextToSpeech[458]
#define sipNameNr_stateChanged 471
#define sipName_stateChanged &sipStrings_QtTextToSpeech[471]
#define sipNameNr_voiceChanged 484
#define sipName_voiceChanged &sipStrings_QtTextToSpeech[484]
#define sipNameNr_ErrorReason 77
#define sipName_ErrorReason &sipStrings_QtTextToSpeech[77]
#define sipNameNr_PauseResume 497
#define sipName_PauseResume &sipStrings_QtTextToSpeech[497]
#define sipNameNr_QVoice__Age 509
#define sipName_QVoice__Age &sipStrings_QtTextToSpeech[509]
#define sipNameNr_customEvent 521
#define sipName_customEvent &sipStrings_QtTextToSpeech[521]
#define sipNameNr_errorReason 533
#define sipName_errorReason &sipStrings_QtTextToSpeech[533]
#define sipNameNr_errorString 545
#define sipName_errorString &sipStrings_QtTextToSpeech[545]
#define sipNameNr_eventFilter 557
#define sipName_eventFilter &sipStrings_QtTextToSpeech[557]
#define sipNameNr_rateChanged 569
#define sipName_rateChanged &sipStrings_QtTextToSpeech[569]
#define sipNameNr_Capability 104
#define sipName_Capability &sipStrings_QtTextToSpeech[104]
#define sipNameNr_Synthesize 226
#define sipName_Synthesize &sipStrings_QtTextToSpeech[226]
#define sipNameNr___lshift__ 581
#define sipName___lshift__ &sipStrings_QtTextToSpeech[581]
#define sipNameNr___rshift__ 592
#define sipName___rshift__ &sipStrings_QtTextToSpeech[592]
#define sipNameNr_childEvent 603
#define sipName_childEvent &sipStrings_QtTextToSpeech[603]
#define sipNameNr_genderName 614
#define sipName_genderName &sipStrings_QtTextToSpeech[614]
#define sipNameNr_sayingWord 625
#define sipName_sayingWord &sipStrings_QtTextToSpeech[625]
#define sipNameNr_timerEvent 636
#define sipName_timerEvent &sipStrings_QtTextToSpeech[636]
#define sipNameNr_Immediate 647
#define sipName_Immediate &sipStrings_QtTextToSpeech[647]
#define sipNameNr_Utterance 657
#define sipName_Utterance &sipStrings_QtTextToSpeech[657]
#define sipNameNr_setEngine 667
#define sipName_setEngine &sipStrings_QtTextToSpeech[667]
#define sipNameNr_setLocale 677
#define sipName_setLocale &sipStrings_QtTextToSpeech[677]
#define sipNameNr_setVolume 687
#define sipName_setVolume &sipStrings_QtTextToSpeech[687]
#define sipNameNr_Playback 697
#define sipName_Playback &sipStrings_QtTextToSpeech[697]
#define sipNameNr_Sentence 706
#define sipName_Sentence &sipStrings_QtTextToSpeech[706]
#define sipNameNr_Speaking 715
#define sipName_Speaking &sipStrings_QtTextToSpeech[715]
#define sipNameNr_Teenager 724
#define sipName_Teenager &sipStrings_QtTextToSpeech[724]
#define sipNameNr_language 733
#define sipName_language &sipStrings_QtTextToSpeech[733]
#define sipNameNr_setPitch 742
#define sipName_setPitch &sipStrings_QtTextToSpeech[742]
#define sipNameNr_setVoice 751
#define sipName_setVoice &sipStrings_QtTextToSpeech[751]
#define sipNameNr_Default 760
#define sipName_Default &sipStrings_QtTextToSpeech[760]
#define sipNameNr_NoError 768
#define sipName_NoError &sipStrings_QtTextToSpeech[768]
#define sipNameNr_Unknown 776
#define sipName_Unknown &sipStrings_QtTextToSpeech[776]
#define sipNameNr_ageName 784
#define sipName_ageName &sipStrings_QtTextToSpeech[784]
#define sipNameNr_enqueue 792
#define sipName_enqueue &sipStrings_QtTextToSpeech[792]
#define sipNameNr_setRate 800
#define sipName_setRate &sipStrings_QtTextToSpeech[800]
#define sipNameNr_Female 808
#define sipName_Female &sipStrings_QtTextToSpeech[808]
#define sipNameNr_Gender 327
#define sipName_Gender &sipStrings_QtTextToSpeech[327]
#define sipNameNr_Paused 815
#define sipName_Paused &sipStrings_QtTextToSpeech[815]
#define sipNameNr_QVoice 822
#define sipName_QVoice &sipStrings_QtTextToSpeech[822]
#define sipNameNr_Senior 829
#define sipName_Senior &sipStrings_QtTextToSpeech[829]
#define sipNameNr___eq__ 836
#define sipName___eq__ &sipStrings_QtTextToSpeech[836]
#define sipNameNr___ne__ 843
#define sipName___ne__ &sipStrings_QtTextToSpeech[843]
#define sipNameNr_engine 850
#define sipName_engine &sipStrings_QtTextToSpeech[850]
#define sipNameNr_gender 857
#define sipName_gender &sipStrings_QtTextToSpeech[857]
#define sipNameNr_locale 864
#define sipName_locale &sipStrings_QtTextToSpeech[864]
#define sipNameNr_params 871
#define sipName_params &sipStrings_QtTextToSpeech[871]
#define sipNameNr_parent 878
#define sipName_parent &sipStrings_QtTextToSpeech[878]
#define sipNameNr_resume 885
#define sipName_resume &sipStrings_QtTextToSpeech[885]
#define sipNameNr_volume 892
#define sipName_volume &sipStrings_QtTextToSpeech[892]
#define sipNameNr_Adult 899
#define sipName_Adult &sipStrings_QtTextToSpeech[899]
#define sipNameNr_Child 905
#define sipName_Child &sipStrings_QtTextToSpeech[905]
#define sipNameNr_Error 770
#define sipName_Error &sipStrings_QtTextToSpeech[770]
#define sipNameNr_Input 911
#define sipName_Input &sipStrings_QtTextToSpeech[911]
#define sipNameNr_None_ 917
#define sipName_None_ &sipStrings_QtTextToSpeech[917]
#define sipNameNr_Other 923
#define sipName_Other &sipStrings_QtTextToSpeech[923]
#define sipNameNr_Ready 929
#define sipName_Ready &sipStrings_QtTextToSpeech[929]
#define sipNameNr_Speak 935
#define sipName_Speak &sipStrings_QtTextToSpeech[935]
#define sipNameNr_State 175
#define sipName_State &sipStrings_QtTextToSpeech[175]
#define sipNameNr_event 941
#define sipName_event &sipStrings_QtTextToSpeech[941]
#define sipNameNr_pause 947
#define sipName_pause &sipStrings_QtTextToSpeech[947]
#define sipNameNr_pitch 953
#define sipName_pitch &sipStrings_QtTextToSpeech[953]
#define sipNameNr_state 959
#define sipName_state &sipStrings_QtTextToSpeech[959]
#define sipNameNr_voice 965
#define sipName_voice &sipStrings_QtTextToSpeech[965]
#define sipNameNr_Male 971
#define sipName_Male &sipStrings_QtTextToSpeech[971]
#define sipNameNr_Word 631
#define sipName_Word &sipStrings_QtTextToSpeech[631]
#define sipNameNr_name 976
#define sipName_name &sipStrings_QtTextToSpeech[976]
#define sipNameNr_rate 981
#define sipName_rate &sipStrings_QtTextToSpeech[981]
#define sipNameNr_stop 986
#define sipName_stop &sipStrings_QtTextToSpeech[986]
#define sipNameNr_swap 991
#define sipName_swap &sipStrings_QtTextToSpeech[991]
#define sipNameNr_Age 517
#define sipName_Age &sipStrings_QtTextToSpeech[517]
#define sipNameNr_age 738
#define sipName_age &sipStrings_QtTextToSpeech[738]
#define sipNameNr_say 996
#define sipName_say &sipStrings_QtTextToSpeech[996]

#define sipMalloc                   sipAPI_QtTextToSpeech->api_malloc
#define sipFree                     sipAPI_QtTextToSpeech->api_free
#define sipBuildResult              sipAPI_QtTextToSpeech->api_build_result
#define sipCallMethod               sipAPI_QtTextToSpeech->api_call_method
#define sipCallProcedureMethod      sipAPI_QtTextToSpeech->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtTextToSpeech->api_call_error_handler
#define sipParseResultEx            sipAPI_QtTextToSpeech->api_parse_result_ex
#define sipParseResult              sipAPI_QtTextToSpeech->api_parse_result
#define sipParseArgs                sipAPI_QtTextToSpeech->api_parse_args
#define sipParseKwdArgs             sipAPI_QtTextToSpeech->api_parse_kwd_args
#define sipParsePair                sipAPI_QtTextToSpeech->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtTextToSpeech->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtTextToSpeech->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtTextToSpeech->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtTextToSpeech->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtTextToSpeech->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtTextToSpeech->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtTextToSpeech->api_add_exception
#define sipNoFunction               sipAPI_QtTextToSpeech->api_no_function
#define sipNoMethod                 sipAPI_QtTextToSpeech->api_no_method
#define sipAbstractMethod           sipAPI_QtTextToSpeech->api_abstract_method
#define sipBadClass                 sipAPI_QtTextToSpeech->api_bad_class
#define sipBadCatcherResult         sipAPI_QtTextToSpeech->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtTextToSpeech->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtTextToSpeech->api_bad_operator_arg
#define sipTrace                    sipAPI_QtTextToSpeech->api_trace
#define sipTransferBack             sipAPI_QtTextToSpeech->api_transfer_back
#define sipTransferTo               sipAPI_QtTextToSpeech->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtTextToSpeech->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtTextToSpeech->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtTextToSpeech->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtTextToSpeech->api_voidptr_type
#define sipGetPyObject              sipAPI_QtTextToSpeech->api_get_pyobject
#define sipGetAddress               sipAPI_QtTextToSpeech->api_get_address
#define sipGetMixinAddress          sipAPI_QtTextToSpeech->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtTextToSpeech->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtTextToSpeech->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtTextToSpeech->api_call_hook
#define sipEndThread                sipAPI_QtTextToSpeech->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtTextToSpeech->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtTextToSpeech->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtTextToSpeech->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtTextToSpeech->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtTextToSpeech->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtTextToSpeech->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtTextToSpeech->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtTextToSpeech->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtTextToSpeech->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtTextToSpeech->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtTextToSpeech->api_convert_to_bool
#define sipReleaseType              sipAPI_QtTextToSpeech->api_release_type
#define sipConvertFromType          sipAPI_QtTextToSpeech->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtTextToSpeech->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtTextToSpeech->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtTextToSpeech->api_convert_from_enum
#define sipGetState                 sipAPI_QtTextToSpeech->api_get_state
#define sipExportSymbol             sipAPI_QtTextToSpeech->api_export_symbol
#define sipImportSymbol             sipAPI_QtTextToSpeech->api_import_symbol
#define sipFindType                 sipAPI_QtTextToSpeech->api_find_type
#define sipBytes_AsChar             sipAPI_QtTextToSpeech->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtTextToSpeech->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtTextToSpeech->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtTextToSpeech->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtTextToSpeech->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtTextToSpeech->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtTextToSpeech->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtTextToSpeech->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtTextToSpeech->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtTextToSpeech->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtTextToSpeech->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtTextToSpeech->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtTextToSpeech->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtTextToSpeech->api_get_reference
#define sipKeepReference            sipAPI_QtTextToSpeech->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtTextToSpeech->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtTextToSpeech->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtTextToSpeech->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtTextToSpeech->api_type_scope
#define sipResolveTypedef           sipAPI_QtTextToSpeech->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtTextToSpeech->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtTextToSpeech->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtTextToSpeech->api_init_mixin
#define sipExportModule             sipAPI_QtTextToSpeech->api_export_module
#define sipInitModule               sipAPI_QtTextToSpeech->api_init_module
#define sipGetInterpreter           sipAPI_QtTextToSpeech->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtTextToSpeech->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtTextToSpeech->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtTextToSpeech->api_py_type_dict
#define sipPyTypeName               sipAPI_QtTextToSpeech->api_py_type_name
#define sipGetCFunction             sipAPI_QtTextToSpeech->api_get_c_function
#define sipGetMethod                sipAPI_QtTextToSpeech->api_get_method
#define sipFromMethod               sipAPI_QtTextToSpeech->api_from_method
#define sipGetDate                  sipAPI_QtTextToSpeech->api_get_date
#define sipFromDate                 sipAPI_QtTextToSpeech->api_from_date
#define sipGetDateTime              sipAPI_QtTextToSpeech->api_get_datetime
#define sipFromDateTime             sipAPI_QtTextToSpeech->api_from_datetime
#define sipGetTime                  sipAPI_QtTextToSpeech->api_get_time
#define sipFromTime                 sipAPI_QtTextToSpeech->api_from_time
#define sipIsUserType               sipAPI_QtTextToSpeech->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtTextToSpeech->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtTextToSpeech->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtTextToSpeech->api_unicode_write
#define sipUnicodeData              sipAPI_QtTextToSpeech->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtTextToSpeech->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtTextToSpeech->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtTextToSpeech->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtTextToSpeech->api_is_derived_class
#define sipGetUserObject            sipAPI_QtTextToSpeech->api_get_user_object
#define sipSetUserObject            sipAPI_QtTextToSpeech->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtTextToSpeech->api_register_event_handler
#define sipConvertToArray           sipAPI_QtTextToSpeech->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtTextToSpeech->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtTextToSpeech->api_enable_gc
#define sipPrintObject              sipAPI_QtTextToSpeech->api_print_object
#define sipLong_AsChar              sipAPI_QtTextToSpeech->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtTextToSpeech->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtTextToSpeech->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtTextToSpeech->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtTextToSpeech->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtTextToSpeech->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtTextToSpeech->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtTextToSpeech->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtTextToSpeech->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtTextToSpeech->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtTextToSpeech->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtTextToSpeech->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtTextToSpeech->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtTextToSpeech->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtTextToSpeech->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtTextToSpeech->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtTextToSpeech->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtTextToSpeech->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtTextToSpeech->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtTextToSpeech->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtTextToSpeech->api_release_type_us
#define sipIsPyMethod               sipAPI_QtTextToSpeech->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtTextToSpeech[];

#define sipType_QTextToSpeech sipExportedTypes_QtTextToSpeech[2]

#define sipType_QTextToSpeech_Capability sipExportedTypes_QtTextToSpeech[4]

#define sipType_QTextToSpeech_State sipExportedTypes_QtTextToSpeech[6]

#define sipType_QTextToSpeech_ErrorReason sipExportedTypes_QtTextToSpeech[5]

#define sipType_QTextToSpeech_BoundaryHint sipExportedTypes_QtTextToSpeech[3]

extern sipClassTypeDef sipTypeDef_QtTextToSpeech_QTextToSpeech;

#define sipType_QVoice sipExportedTypes_QtTextToSpeech[7]

#define sipType_QVoice_Age sipExportedTypes_QtTextToSpeech[8]

#define sipType_QVoice_Gender sipExportedTypes_QtTextToSpeech[9]

extern sipClassTypeDef sipTypeDef_QtTextToSpeech_QVoice;

#define sipType_QList_0100QVoice sipExportedTypes_QtTextToSpeech[1]

extern sipMappedTypeDef sipTypeDef_QtTextToSpeech_QList_0100QVoice;

#define sipType_QFlags_0100QTextToSpeech_Capability sipExportedTypes_QtTextToSpeech[0]

extern sipMappedTypeDef sipTypeDef_QtTextToSpeech_QFlags_0100QTextToSpeech_Capability;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtTextToSpeech;
extern sipExportedModuleDef sipModuleAPI_QtTextToSpeech;
extern sipTypeDef *sipExportedTypes_QtTextToSpeech[];

#define sipType_QObject sipImportedTypes_QtTextToSpeech_QtCore[8].it_td

#define sipType_QEvent sipImportedTypes_QtTextToSpeech_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtTextToSpeech_QtCore[11].it_td

#define sipType_QChildEvent sipImportedTypes_QtTextToSpeech_QtCore[0].it_td

#define sipType_QDataStream sipImportedTypes_QtTextToSpeech_QtCore[1].it_td

#define sipType_QLocale sipImportedTypes_QtTextToSpeech_QtCore[4].it_td

#define sipType_QLocale_Language sipImportedTypes_QtTextToSpeech_QtCore[5].it_td

#define sipType_QMetaMethod sipImportedTypes_QtTextToSpeech_QtCore[7].it_td

#define sipType_QList_0100QLocale sipImportedTypes_QtTextToSpeech_QtCore[3].it_td

#define sipType_QMap_0100QString_0100QVariant sipImportedTypes_QtTextToSpeech_QtCore[6].it_td

#define sipType_QStringList sipImportedTypes_QtTextToSpeech_QtCore[10].it_td

#define sipType_QString sipImportedTypes_QtTextToSpeech_QtCore[9].it_td
extern sipImportedTypeDef sipImportedTypes_QtTextToSpeech_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtTextToSpeech_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtTextToSpeech_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtTextToSpeech_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtTextToSpeech_qt_metacast;

#endif
