/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/abstractformeditor.sip"
#include <abstractformeditor.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/abstractactioneditor.sip"
#include <abstractactioneditor.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/abstractobjectinspector.sip"
#include <abstractobjectinspector.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/abstractpropertyeditor.sip"
#include <abstractpropertyeditor.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/abstractwidgetbox.sip"
#include <abstractwidgetbox.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/abstractformwindowmanager.sip"
#include <abstractformwindowmanager.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/qextensionmanager.sip"
#include <qextensionmanager.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormEditorInterface.cpp"


class sipQDesignerFormEditorInterface : public ::QDesignerFormEditorInterface
{
public:
    sipQDesignerFormEditorInterface(::QObject*);
    virtual ~sipQDesignerFormEditorInterface();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQDesignerFormEditorInterface(const sipQDesignerFormEditorInterface &);
    sipQDesignerFormEditorInterface &operator = (const sipQDesignerFormEditorInterface &);

    char sipPyMethods[7];
};

sipQDesignerFormEditorInterface::sipQDesignerFormEditorInterface(::QObject*a0): ::QDesignerFormEditorInterface(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQDesignerFormEditorInterface::~sipQDesignerFormEditorInterface()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQDesignerFormEditorInterface::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDesigner_qt_metaobject(sipPySelf, sipType_QDesignerFormEditorInterface);

    return ::QDesignerFormEditorInterface::metaObject();
}

int sipQDesignerFormEditorInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QDesignerFormEditorInterface::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDesigner_qt_metacall(sipPySelf, sipType_QDesignerFormEditorInterface, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQDesignerFormEditorInterface::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDesigner_qt_metacast(sipPySelf, sipType_QDesignerFormEditorInterface, _clname, &sipCpp) ? sipCpp : ::QDesignerFormEditorInterface::qt_metacast(_clname));
}

bool sipQDesignerFormEditorInterface::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QDesignerFormEditorInterface::event(a0);

    extern bool sipVH_QtDesigner_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDesigner_32(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQDesignerFormEditorInterface::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QDesignerFormEditorInterface::eventFilter(a0, a1);

    extern bool sipVH_QtDesigner_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDesigner_33(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQDesignerFormEditorInterface::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QDesignerFormEditorInterface::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDesigner_34(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerFormEditorInterface::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QDesignerFormEditorInterface::childEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDesigner_35(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerFormEditorInterface::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QDesignerFormEditorInterface::customEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDesigner_7(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerFormEditorInterface::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QDesignerFormEditorInterface::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDesigner_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDesigner_36(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerFormEditorInterface::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QDesignerFormEditorInterface::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDesigner_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDesigner_36(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QDesignerFormEditorInterface_extensionManager, "extensionManager(self) -> QExtensionManager|None");

extern "C" {static PyObject *meth_QDesignerFormEditorInterface_extensionManager(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormEditorInterface_extensionManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDesignerFormEditorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormEditorInterface, &sipCpp))
        {
            ::QExtensionManager*sipRes;

            sipRes = sipCpp->extensionManager();

            return sipConvertFromType(sipRes, sipType_QExtensionManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormEditorInterface, sipName_extensionManager, doc_QDesignerFormEditorInterface_extensionManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormEditorInterface_topLevel, "topLevel(self) -> QWidget|None");

extern "C" {static PyObject *meth_QDesignerFormEditorInterface_topLevel(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormEditorInterface_topLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDesignerFormEditorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormEditorInterface, &sipCpp))
        {
            ::QWidget*sipRes;

            sipRes = sipCpp->topLevel();

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormEditorInterface, sipName_topLevel, doc_QDesignerFormEditorInterface_topLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormEditorInterface_widgetBox, "widgetBox(self) -> QDesignerWidgetBoxInterface|None");

extern "C" {static PyObject *meth_QDesignerFormEditorInterface_widgetBox(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormEditorInterface_widgetBox(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDesignerFormEditorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormEditorInterface, &sipCpp))
        {
            ::QDesignerWidgetBoxInterface*sipRes;

            sipRes = sipCpp->widgetBox();

            return sipConvertFromType(sipRes, sipType_QDesignerWidgetBoxInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormEditorInterface, sipName_widgetBox, doc_QDesignerFormEditorInterface_widgetBox);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormEditorInterface_propertyEditor, "propertyEditor(self) -> QDesignerPropertyEditorInterface|None");

extern "C" {static PyObject *meth_QDesignerFormEditorInterface_propertyEditor(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormEditorInterface_propertyEditor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDesignerFormEditorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormEditorInterface, &sipCpp))
        {
            ::QDesignerPropertyEditorInterface*sipRes;

            sipRes = sipCpp->propertyEditor();

            return sipConvertFromType(sipRes, sipType_QDesignerPropertyEditorInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormEditorInterface, sipName_propertyEditor, doc_QDesignerFormEditorInterface_propertyEditor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormEditorInterface_objectInspector, "objectInspector(self) -> QDesignerObjectInspectorInterface|None");

extern "C" {static PyObject *meth_QDesignerFormEditorInterface_objectInspector(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormEditorInterface_objectInspector(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDesignerFormEditorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormEditorInterface, &sipCpp))
        {
            ::QDesignerObjectInspectorInterface*sipRes;

            sipRes = sipCpp->objectInspector();

            return sipConvertFromType(sipRes, sipType_QDesignerObjectInspectorInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormEditorInterface, sipName_objectInspector, doc_QDesignerFormEditorInterface_objectInspector);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormEditorInterface_formWindowManager, "formWindowManager(self) -> QDesignerFormWindowManagerInterface|None");

extern "C" {static PyObject *meth_QDesignerFormEditorInterface_formWindowManager(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormEditorInterface_formWindowManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDesignerFormEditorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormEditorInterface, &sipCpp))
        {
            ::QDesignerFormWindowManagerInterface*sipRes;

            sipRes = sipCpp->formWindowManager();

            return sipConvertFromType(sipRes, sipType_QDesignerFormWindowManagerInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormEditorInterface, sipName_formWindowManager, doc_QDesignerFormEditorInterface_formWindowManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormEditorInterface_actionEditor, "actionEditor(self) -> QDesignerActionEditorInterface|None");

extern "C" {static PyObject *meth_QDesignerFormEditorInterface_actionEditor(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormEditorInterface_actionEditor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDesignerFormEditorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormEditorInterface, &sipCpp))
        {
            ::QDesignerActionEditorInterface*sipRes;

            sipRes = sipCpp->actionEditor();

            return sipConvertFromType(sipRes, sipType_QDesignerActionEditorInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormEditorInterface, sipName_actionEditor, doc_QDesignerFormEditorInterface_actionEditor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormEditorInterface_setWidgetBox, "setWidgetBox(self, widgetBox: QDesignerWidgetBoxInterface|None)");

extern "C" {static PyObject *meth_QDesignerFormEditorInterface_setWidgetBox(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormEditorInterface_setWidgetBox(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDesignerWidgetBoxInterface* a0;
        PyObject *a0Keep;
        ::QDesignerFormEditorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QDesignerFormEditorInterface, &sipCpp, &a0Keep, sipType_QDesignerWidgetBoxInterface, &a0))
        {
            sipCpp->setWidgetBox(a0);

            sipKeepReference(sipSelf, -2, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormEditorInterface, sipName_setWidgetBox, doc_QDesignerFormEditorInterface_setWidgetBox);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormEditorInterface_setPropertyEditor, "setPropertyEditor(self, propertyEditor: QDesignerPropertyEditorInterface|None)");

extern "C" {static PyObject *meth_QDesignerFormEditorInterface_setPropertyEditor(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormEditorInterface_setPropertyEditor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDesignerPropertyEditorInterface* a0;
        PyObject *a0Keep;
        ::QDesignerFormEditorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QDesignerFormEditorInterface, &sipCpp, &a0Keep, sipType_QDesignerPropertyEditorInterface, &a0))
        {
            sipCpp->setPropertyEditor(a0);

            sipKeepReference(sipSelf, -3, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormEditorInterface, sipName_setPropertyEditor, doc_QDesignerFormEditorInterface_setPropertyEditor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormEditorInterface_setObjectInspector, "setObjectInspector(self, objectInspector: QDesignerObjectInspectorInterface|None)");

extern "C" {static PyObject *meth_QDesignerFormEditorInterface_setObjectInspector(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormEditorInterface_setObjectInspector(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDesignerObjectInspectorInterface* a0;
        PyObject *a0Keep;
        ::QDesignerFormEditorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QDesignerFormEditorInterface, &sipCpp, &a0Keep, sipType_QDesignerObjectInspectorInterface, &a0))
        {
            sipCpp->setObjectInspector(a0);

            sipKeepReference(sipSelf, -4, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormEditorInterface, sipName_setObjectInspector, doc_QDesignerFormEditorInterface_setObjectInspector);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormEditorInterface_setActionEditor, "setActionEditor(self, actionEditor: QDesignerActionEditorInterface|None)");

extern "C" {static PyObject *meth_QDesignerFormEditorInterface_setActionEditor(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormEditorInterface_setActionEditor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDesignerActionEditorInterface* a0;
        PyObject *a0Keep;
        ::QDesignerFormEditorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QDesignerFormEditorInterface, &sipCpp, &a0Keep, sipType_QDesignerActionEditorInterface, &a0))
        {
            sipCpp->setActionEditor(a0);

            sipKeepReference(sipSelf, -5, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormEditorInterface, sipName_setActionEditor, doc_QDesignerFormEditorInterface_setActionEditor);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QDesignerFormEditorInterface(void *, const sipTypeDef *);}
static void *cast_QDesignerFormEditorInterface(void *sipCppV, const sipTypeDef *targetType)
{
    ::QDesignerFormEditorInterface *sipCpp = reinterpret_cast< ::QDesignerFormEditorInterface *>(sipCppV);

    if (targetType == sipType_QDesignerFormEditorInterface)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDesignerFormEditorInterface(void *, int);}
static void release_QDesignerFormEditorInterface(void *sipCppV, int)
{
    ::QDesignerFormEditorInterface *sipCpp = reinterpret_cast< ::QDesignerFormEditorInterface *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QDesignerFormEditorInterface(Py_ssize_t);}
static void *array_QDesignerFormEditorInterface(Py_ssize_t sipNrElem)
{
    return new ::QDesignerFormEditorInterface[sipNrElem];
}


extern "C" {static void array_delete_QDesignerFormEditorInterface(void *);}
static void array_delete_QDesignerFormEditorInterface(void *sipCpp)
{
    delete[] reinterpret_cast< ::QDesignerFormEditorInterface *>(sipCpp);
}


extern "C" {static void dealloc_QDesignerFormEditorInterface(sipSimpleWrapper *);}
static void dealloc_QDesignerFormEditorInterface(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQDesignerFormEditorInterface *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDesignerFormEditorInterface(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QDesignerFormEditorInterface(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDesignerFormEditorInterface(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQDesignerFormEditorInterface *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQDesignerFormEditorInterface(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QDesignerFormEditorInterface[] = {{8, 0, 1}};


static PyMethodDef methods_QDesignerFormEditorInterface[] = {
    {sipName_actionEditor, meth_QDesignerFormEditorInterface_actionEditor, METH_VARARGS, doc_QDesignerFormEditorInterface_actionEditor},
    {sipName_extensionManager, meth_QDesignerFormEditorInterface_extensionManager, METH_VARARGS, doc_QDesignerFormEditorInterface_extensionManager},
    {sipName_formWindowManager, meth_QDesignerFormEditorInterface_formWindowManager, METH_VARARGS, doc_QDesignerFormEditorInterface_formWindowManager},
    {sipName_objectInspector, meth_QDesignerFormEditorInterface_objectInspector, METH_VARARGS, doc_QDesignerFormEditorInterface_objectInspector},
    {sipName_propertyEditor, meth_QDesignerFormEditorInterface_propertyEditor, METH_VARARGS, doc_QDesignerFormEditorInterface_propertyEditor},
    {sipName_setActionEditor, meth_QDesignerFormEditorInterface_setActionEditor, METH_VARARGS, doc_QDesignerFormEditorInterface_setActionEditor},
    {sipName_setObjectInspector, meth_QDesignerFormEditorInterface_setObjectInspector, METH_VARARGS, doc_QDesignerFormEditorInterface_setObjectInspector},
    {sipName_setPropertyEditor, meth_QDesignerFormEditorInterface_setPropertyEditor, METH_VARARGS, doc_QDesignerFormEditorInterface_setPropertyEditor},
    {sipName_setWidgetBox, meth_QDesignerFormEditorInterface_setWidgetBox, METH_VARARGS, doc_QDesignerFormEditorInterface_setWidgetBox},
    {sipName_topLevel, meth_QDesignerFormEditorInterface_topLevel, METH_VARARGS, doc_QDesignerFormEditorInterface_topLevel},
    {sipName_widgetBox, meth_QDesignerFormEditorInterface_widgetBox, METH_VARARGS, doc_QDesignerFormEditorInterface_widgetBox}
};

PyDoc_STRVAR(doc_QDesignerFormEditorInterface, "\1QDesignerFormEditorInterface(parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QDesignerFormEditorInterface = {
    &::QDesignerFormEditorInterface::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormEditorInterface = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDesignerFormEditorInterface,
        SIP_NULLPTR,
        &plugin_QDesignerFormEditorInterface,
    },
    {
        sipNameNr_QDesignerFormEditorInterface,
        {0, 0, 1},
        11, methods_QDesignerFormEditorInterface,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDesignerFormEditorInterface,
    -1,
    -1,
    supers_QDesignerFormEditorInterface,
    SIP_NULLPTR,
    init_type_QDesignerFormEditorInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDesignerFormEditorInterface,
    SIP_NULLPTR,
    array_QDesignerFormEditorInterface,
    SIP_NULLPTR,
    release_QDesignerFormEditorInterface,
    cast_QDesignerFormEditorInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QDesignerFormEditorInterface,
    sizeof (::QDesignerFormEditorInterface),
};
