/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick3D.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3d.sip"
#include <qquick3d.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3D.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3D.cpp"


PyDoc_STRVAR(doc_QQuick3D_idealSurfaceFormat, "idealSurfaceFormat(samples: int = -1) -> QSurfaceFormat");

extern "C" {static PyObject *meth_QQuick3D_idealSurfaceFormat(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QQuick3D_idealSurfaceFormat(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = -1;

        static const char *sipKwdList[] = {
            sipName_samples,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "C|i", &sipSelf, &a0))
        {
            ::QSurfaceFormat*sipRes;

            sipRes = new ::QSurfaceFormat(::QQuick3D::idealSurfaceFormat(a0));

            return sipConvertFromNewType(sipRes, sipType_QSurfaceFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3D, sipName_idealSurfaceFormat, doc_QQuick3D_idealSurfaceFormat);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQuick3D(void *, int);}
static void release_QQuick3D(void *sipCppV, int)
{
    delete reinterpret_cast< ::QQuick3D *>(sipCppV);
}


extern "C" {static void *array_QQuick3D(Py_ssize_t);}
static void *array_QQuick3D(Py_ssize_t sipNrElem)
{
    return new ::QQuick3D[sipNrElem];
}


extern "C" {static void array_delete_QQuick3D(void *);}
static void array_delete_QQuick3D(void *sipCpp)
{
    delete[] reinterpret_cast< ::QQuick3D *>(sipCpp);
}


extern "C" {static void assign_QQuick3D(void *, Py_ssize_t, void *);}
static void assign_QQuick3D(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QQuick3D *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QQuick3D *>(sipSrc);
}


extern "C" {static void *copy_QQuick3D(const void *, Py_ssize_t);}
static void *copy_QQuick3D(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QQuick3D(reinterpret_cast<const ::QQuick3D *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QQuick3D(sipSimpleWrapper *);}
static void dealloc_QQuick3D(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuick3D(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QQuick3D(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuick3D(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QQuick3D *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QQuick3D();

            return sipCpp;
        }
    }

    {
        const ::QQuick3D* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QQuick3D, &a0))
        {
            sipCpp = new ::QQuick3D(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QQuick3D[] = {
    {sipName_idealSurfaceFormat, SIP_MLMETH_CAST(meth_QQuick3D_idealSurfaceFormat), METH_VARARGS|METH_KEYWORDS, doc_QQuick3D_idealSurfaceFormat}
};

PyDoc_STRVAR(doc_QQuick3D, "\1QQuick3D()\n"
"QQuick3D(a0: QQuick3D)");


sipClassTypeDef sipTypeDef_QtQuick3D_QQuick3D = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuick3D,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QQuick3D,
        {0, 0, 1},
        1, methods_QQuick3D,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuick3D,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQuick3D,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuick3D,
    assign_QQuick3D,
    array_QQuick3D,
    copy_QQuick3D,
    release_QQuick3D,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QQuick3D,
    sizeof (::QQuick3D),
};
