/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPdfWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdfWidgets/qpdfview.sip"
#include <qpdfview.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfsearchmodel.sip"
#include <qpdfsearchmodel.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfdocument.sip"
#include <qpdfdocument.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfpagenavigator.sip"
#include <qpdfpagenavigator.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractscrollarea.sip"
#include <qabstractscrollarea.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qscrollbar.sip"
#include <qscrollbar.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qframe.sip"
#include <qframe.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 215 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 221 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 224 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 227 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 230 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 233 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 236 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 242 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 247 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 250 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 253 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 256 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 259 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 262 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 265 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 268 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 271 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 274 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdfWidgets/sipQtPdfWidgetsQPdfView.cpp"


class sipQPdfView : public ::QPdfView
{
public:
    sipQPdfView(::QWidget*);
    virtual ~sipQPdfView();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void initStyleOption(::QStyleOptionFrame*) const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEnterEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;
    ::QSize viewportSizeHint() const SIP_OVERRIDE;
    bool viewportEvent(::QEvent*) SIP_OVERRIDE;
    void scrollContentsBy(int, int) SIP_OVERRIDE;
    void setupViewport(::QWidget*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPdfView(const sipQPdfView &);
    sipQPdfView &operator = (const sipQPdfView &);

    char sipPyMethods[51];
};

sipQPdfView::sipQPdfView(::QWidget*a0): ::QPdfView(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPdfView::~sipQPdfView()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQPdfView::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtPdfWidgets_qt_metaobject(sipPySelf, sipType_QPdfView);

    return ::QPdfView::metaObject();
}

int sipQPdfView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QPdfView::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtPdfWidgets_qt_metacall(sipPySelf, sipType_QPdfView, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQPdfView::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtPdfWidgets_qt_metacast(sipPySelf, sipType_QPdfView, _clname, &sipCpp) ? sipCpp : ::QPdfView::qt_metacast(_clname));
}

void sipQPdfView::initStyleOption(::QStyleOptionFrame*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initStyleOption);

    if (!sipMeth)
    {
        ::QPdfView::initStyleOption(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyleOptionFrame*);

    sipVH_QtPdfWidgets_39(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QPdfView::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPdfWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QPdfView::connectNotify(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPdfWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QPdfView::customEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPdfWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QPdfView::childEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtPdfWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QPdfView::timerEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtPdfWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPdfView::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QPdfView::eventFilter(a0, a1);

    extern bool sipVH_QtPdfWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtPdfWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQPdfView::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QPdfView::event(a0);

    extern bool sipVH_QtPdfWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtPdfWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQPdfView::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QPdfView::metric(a0);

    extern int sipVH_QtPdfWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtPdfWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQPdfView::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QPdfView::paintEngine();

    extern ::QPaintEngine* sipVH_QtPdfWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPdfWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQPdfView::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QPdfView::devType();

    extern int sipVH_QtPdfWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPdfWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQPdfView::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QPdfView::setVisible(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtPdfWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQPdfView::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QPdfView::sizeHint();

    extern ::QSize sipVH_QtPdfWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPdfWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQPdfView::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QPdfView::minimumSizeHint();

    extern ::QSize sipVH_QtPdfWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPdfWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQPdfView::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QPdfView::heightForWidth(a0);

    extern int sipVH_QtPdfWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtPdfWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QPdfView::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPdfWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QPdfView::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPdfWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QPdfView::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPdfWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QPdfView::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPdfWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QPdfView::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtPdfWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QPdfView::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtPdfWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QPdfView::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtPdfWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QPdfView::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtPdfWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QPdfView::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtPdfWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::enterEvent(::QEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QPdfView::enterEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEnterEvent*);

    sipVH_QtPdfWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QPdfView::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPdfWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QPdfView::paintEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtPdfWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QPdfView::moveEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtPdfWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QPdfView::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtPdfWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QPdfView::closeEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtPdfWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QPdfView::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtPdfWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QPdfView::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtPdfWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QPdfView::actionEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtPdfWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QPdfView::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtPdfWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QPdfView::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtPdfWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QPdfView::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtPdfWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QPdfView::dropEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtPdfWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QPdfView::showEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtPdfWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QPdfView::hideEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtPdfWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QPdfView::changeEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPdfWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QPdfView::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtPdfWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQPdfView::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QPdfView::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtPdfWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtPdfWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPdfView::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QPdfView::focusNextPrevChild(a0);

    extern bool sipVH_QtPdfWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtPdfWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPdfView::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[43]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QPdfView::hasHeightForWidth();

    extern bool sipVH_QtPdfWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPdfWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQPdfView::nativeEvent(const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QPdfView::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtPdfWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, ::qintptr*);

    return sipVH_QtPdfWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipQPdfView::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[45]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QPdfView::sharedPainter();

    extern ::QPainter* sipVH_QtPdfWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPdfWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQPdfView::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QPdfView::initPainter(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtPdfWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQPdfView::viewportSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[47]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_viewportSizeHint);

    if (!sipMeth)
        return ::QPdfView::viewportSizeHint();

    extern ::QSize sipVH_QtPdfWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPdfWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQPdfView::viewportEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[48], &sipPySelf, SIP_NULLPTR, sipName_viewportEvent);

    if (!sipMeth)
        return ::QPdfView::viewportEvent(a0);

    extern bool sipVH_QtPdfWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtPdfWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfView::scrollContentsBy(int a0, int a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[49], &sipPySelf, SIP_NULLPTR, sipName_scrollContentsBy);

    if (!sipMeth)
    {
        ::QPdfView::scrollContentsBy(a0, a1);
        return;
    }

    extern void sipVH_QtPdfWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int);

    sipVH_QtPdfWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQPdfView::setupViewport(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[50], &sipPySelf, SIP_NULLPTR, sipName_setupViewport);

    if (!sipMeth)
    {
        ::QPdfView::setupViewport(a0);
        return;
    }

    extern void sipVH_QtPdfWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_QtPdfWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QPdfView_setDocument, "setDocument(self, document: QPdfDocument|None)");

extern "C" {static PyObject *meth_QPdfView_setDocument(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_setDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfDocument* a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QPdfView, &sipCpp, sipType_QPdfDocument, &a0))
        {
            sipCpp->setDocument(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_setDocument, doc_QPdfView_setDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_document, "document(self) -> QPdfDocument|None");

extern "C" {static PyObject *meth_QPdfView_document(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_document(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfView, &sipCpp))
        {
            ::QPdfDocument*sipRes;

            sipRes = sipCpp->document();

            return sipConvertFromType(sipRes, sipType_QPdfDocument, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_document, doc_QPdfView_document);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_pageNavigator, "pageNavigator(self) -> QPdfPageNavigator|None");

extern "C" {static PyObject *meth_QPdfView_pageNavigator(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_pageNavigator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfView, &sipCpp))
        {
            ::QPdfPageNavigator*sipRes;

            sipRes = sipCpp->pageNavigator();

            return sipConvertFromType(sipRes, sipType_QPdfPageNavigator, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_pageNavigator, doc_QPdfView_pageNavigator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_pageMode, "pageMode(self) -> QPdfView.PageMode");

extern "C" {static PyObject *meth_QPdfView_pageMode(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_pageMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfView, &sipCpp))
        {
            ::QPdfView::PageMode sipRes;

            sipRes = sipCpp->pageMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPdfView_PageMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_pageMode, doc_QPdfView_pageMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_zoomMode, "zoomMode(self) -> QPdfView.ZoomMode");

extern "C" {static PyObject *meth_QPdfView_zoomMode(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_zoomMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfView, &sipCpp))
        {
            ::QPdfView::ZoomMode sipRes;

            sipRes = sipCpp->zoomMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPdfView_ZoomMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_zoomMode, doc_QPdfView_zoomMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_zoomFactor, "zoomFactor(self) -> float");

extern "C" {static PyObject *meth_QPdfView_zoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_zoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfView, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->zoomFactor();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_zoomFactor, doc_QPdfView_zoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_pageSpacing, "pageSpacing(self) -> int");

extern "C" {static PyObject *meth_QPdfView_pageSpacing(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_pageSpacing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfView, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->pageSpacing();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_pageSpacing, doc_QPdfView_pageSpacing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_setPageSpacing, "setPageSpacing(self, spacing: int)");

extern "C" {static PyObject *meth_QPdfView_setPageSpacing(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_setPageSpacing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QPdfView, &sipCpp, &a0))
        {
            sipCpp->setPageSpacing(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_setPageSpacing, doc_QPdfView_setPageSpacing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_documentMargins, "documentMargins(self) -> QMargins");

extern "C" {static PyObject *meth_QPdfView_documentMargins(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_documentMargins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfView, &sipCpp))
        {
            ::QMargins*sipRes;

            sipRes = new ::QMargins(sipCpp->documentMargins());

            return sipConvertFromNewType(sipRes, sipType_QMargins, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_documentMargins, doc_QPdfView_documentMargins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_setDocumentMargins, "setDocumentMargins(self, margins: QMargins)");

extern "C" {static PyObject *meth_QPdfView_setDocumentMargins(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_setDocumentMargins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMargins* a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPdfView, &sipCpp, sipType_QMargins, &a0))
        {
            sipCpp->setDocumentMargins(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_setDocumentMargins, doc_QPdfView_setDocumentMargins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_setPageMode, "setPageMode(self, mode: QPdfView.PageMode)");

extern "C" {static PyObject *meth_QPdfView_setPageMode(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_setPageMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfView::PageMode a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPdfView, &sipCpp, sipType_QPdfView_PageMode, &a0))
        {
            sipCpp->setPageMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_setPageMode, doc_QPdfView_setPageMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_setZoomMode, "setZoomMode(self, mode: QPdfView.ZoomMode)");

extern "C" {static PyObject *meth_QPdfView_setZoomMode(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_setZoomMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfView::ZoomMode a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPdfView, &sipCpp, sipType_QPdfView_ZoomMode, &a0))
        {
            sipCpp->setZoomMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_setZoomMode, doc_QPdfView_setZoomMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_setZoomFactor, "setZoomFactor(self, factor: float)");

extern "C" {static PyObject *meth_QPdfView_setZoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_setZoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QPdfView, &sipCpp, &a0))
        {
            sipCpp->setZoomFactor(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_setZoomFactor, doc_QPdfView_setZoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_paintEvent, "paintEvent(self, event: QPaintEvent|None)");

extern "C" {static PyObject *meth_QPdfView_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPdfView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QPdfView, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QPdfView::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_paintEvent, doc_QPdfView_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_resizeEvent, "resizeEvent(self, event: QResizeEvent|None)");

extern "C" {static PyObject *meth_QPdfView_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPdfView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QPdfView, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QPdfView::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_resizeEvent, doc_QPdfView_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_scrollContentsBy, "scrollContentsBy(self, dx: int, dy: int)");

extern "C" {static PyObject *meth_QPdfView_scrollContentsBy(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_scrollContentsBy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPdfView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pii", &sipSelf, sipType_QPdfView, &sipCpp, &a0, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QPdfView::scrollContentsBy(a0, a1) : sipCpp->scrollContentsBy(a0, a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_scrollContentsBy, doc_QPdfView_scrollContentsBy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_searchModel, "searchModel(self) -> QPdfSearchModel|None");

extern "C" {static PyObject *meth_QPdfView_searchModel(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_searchModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfView, &sipCpp))
        {
            ::QPdfSearchModel*sipRes;

            sipRes = sipCpp->searchModel();

            return sipConvertFromType(sipRes, sipType_QPdfSearchModel, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_searchModel, doc_QPdfView_searchModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_setSearchModel, "setSearchModel(self, searchModel: QPdfSearchModel|None)");

extern "C" {static PyObject *meth_QPdfView_setSearchModel(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_setSearchModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfSearchModel* a0;
        PyObject *a0Keep;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QPdfView, &sipCpp, &a0Keep, sipType_QPdfSearchModel, &a0))
        {
            sipCpp->setSearchModel(a0);

            sipKeepReference(sipSelf, -1, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_setSearchModel, doc_QPdfView_setSearchModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_currentSearchResultIndex, "currentSearchResultIndex(self) -> int");

extern "C" {static PyObject *meth_QPdfView_currentSearchResultIndex(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_currentSearchResultIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfView, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentSearchResultIndex();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_currentSearchResultIndex, doc_QPdfView_currentSearchResultIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_setCurrentSearchResultIndex, "setCurrentSearchResultIndex(self, currentResult: int)");

extern "C" {static PyObject *meth_QPdfView_setCurrentSearchResultIndex(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_setCurrentSearchResultIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QPdfView, &sipCpp, &a0))
        {
            sipCpp->setCurrentSearchResultIndex(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_setCurrentSearchResultIndex, doc_QPdfView_setCurrentSearchResultIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_mousePressEvent, "mousePressEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_QPdfView_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPdfView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QPdfView, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QPdfView::mousePressEvent(a0) : sipCpp->mousePressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_mousePressEvent, doc_QPdfView_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_mouseMoveEvent, "mouseMoveEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_QPdfView_mouseMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_mouseMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPdfView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QPdfView, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QPdfView::mouseMoveEvent(a0) : sipCpp->mouseMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_mouseMoveEvent, doc_QPdfView_mouseMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfView_mouseReleaseEvent, "mouseReleaseEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_QPdfView_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QPdfView_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPdfView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QPdfView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QPdfView, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QPdfView::mouseReleaseEvent(a0) : sipCpp->mouseReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfView, sipName_mouseReleaseEvent, doc_QPdfView_mouseReleaseEvent);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPdfView(void *, const sipTypeDef *);}
static void *cast_QPdfView(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPdfView *sipCpp = reinterpret_cast< ::QPdfView *>(sipCppV);

    if (targetType == sipType_QPdfView)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstractScrollArea)->ctd_cast(static_cast< ::QAbstractScrollArea *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPdfView(void *, int);}
static void release_QPdfView(void *sipCppV, int)
{
    ::QPdfView *sipCpp = reinterpret_cast< ::QPdfView *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QPdfView(sipSimpleWrapper *);}
static void dealloc_QPdfView(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPdfView *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPdfView(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPdfView(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPdfView(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQPdfView *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQPdfView(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPdfView[] = {{0, 3, 1}};


static PyMethodDef methods_QPdfView[] = {
    {sipName_currentSearchResultIndex, meth_QPdfView_currentSearchResultIndex, METH_VARARGS, doc_QPdfView_currentSearchResultIndex},
    {sipName_document, meth_QPdfView_document, METH_VARARGS, doc_QPdfView_document},
    {sipName_documentMargins, meth_QPdfView_documentMargins, METH_VARARGS, doc_QPdfView_documentMargins},
    {sipName_mouseMoveEvent, meth_QPdfView_mouseMoveEvent, METH_VARARGS, doc_QPdfView_mouseMoveEvent},
    {sipName_mousePressEvent, meth_QPdfView_mousePressEvent, METH_VARARGS, doc_QPdfView_mousePressEvent},
    {sipName_mouseReleaseEvent, meth_QPdfView_mouseReleaseEvent, METH_VARARGS, doc_QPdfView_mouseReleaseEvent},
    {sipName_pageMode, meth_QPdfView_pageMode, METH_VARARGS, doc_QPdfView_pageMode},
    {sipName_pageNavigator, meth_QPdfView_pageNavigator, METH_VARARGS, doc_QPdfView_pageNavigator},
    {sipName_pageSpacing, meth_QPdfView_pageSpacing, METH_VARARGS, doc_QPdfView_pageSpacing},
    {sipName_paintEvent, meth_QPdfView_paintEvent, METH_VARARGS, doc_QPdfView_paintEvent},
    {sipName_resizeEvent, meth_QPdfView_resizeEvent, METH_VARARGS, doc_QPdfView_resizeEvent},
    {sipName_scrollContentsBy, meth_QPdfView_scrollContentsBy, METH_VARARGS, doc_QPdfView_scrollContentsBy},
    {sipName_searchModel, meth_QPdfView_searchModel, METH_VARARGS, doc_QPdfView_searchModel},
    {sipName_setCurrentSearchResultIndex, meth_QPdfView_setCurrentSearchResultIndex, METH_VARARGS, doc_QPdfView_setCurrentSearchResultIndex},
    {sipName_setDocument, meth_QPdfView_setDocument, METH_VARARGS, doc_QPdfView_setDocument},
    {sipName_setDocumentMargins, meth_QPdfView_setDocumentMargins, METH_VARARGS, doc_QPdfView_setDocumentMargins},
    {sipName_setPageMode, meth_QPdfView_setPageMode, METH_VARARGS, doc_QPdfView_setPageMode},
    {sipName_setPageSpacing, meth_QPdfView_setPageSpacing, METH_VARARGS, doc_QPdfView_setPageSpacing},
    {sipName_setSearchModel, meth_QPdfView_setSearchModel, METH_VARARGS, doc_QPdfView_setSearchModel},
    {sipName_setZoomFactor, meth_QPdfView_setZoomFactor, METH_VARARGS, doc_QPdfView_setZoomFactor},
    {sipName_setZoomMode, meth_QPdfView_setZoomMode, METH_VARARGS, doc_QPdfView_setZoomMode},
    {sipName_zoomFactor, meth_QPdfView_zoomFactor, METH_VARARGS, doc_QPdfView_zoomFactor},
    {sipName_zoomMode, meth_QPdfView_zoomMode, METH_VARARGS, doc_QPdfView_zoomMode}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QPdfView[] = {
    {sipName_SinglePage, static_cast<int>(::QPdfView::PageMode::SinglePage)},
    {sipName_MultiPage, static_cast<int>(::QPdfView::PageMode::MultiPage)},
    {sipName_Custom, static_cast<int>(::QPdfView::ZoomMode::Custom)},
    {sipName_FitToWidth, static_cast<int>(::QPdfView::ZoomMode::FitToWidth)},
    {sipName_FitInView, static_cast<int>(::QPdfView::ZoomMode::FitInView)},
    {0, 0}
};

PyDoc_STRVAR(doc_QPdfView, "\1QPdfView(parent: QWidget|None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QPdfView[] = {
    {"currentSearchResultIndexChanged(int)", "\1currentSearchResultIndexChanged(self, currentResult: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"searchModelChanged(QPdfSearchModel*)", "\1searchModelChanged(self, searchModel: QPdfSearchModel|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"documentMarginsChanged(QMargins)", "\1documentMarginsChanged(self, documentMargins: QMargins)", SIP_NULLPTR, SIP_NULLPTR},
    {"pageSpacingChanged(int)", "\1pageSpacingChanged(self, pageSpacing: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"zoomFactorChanged(qreal)", "\1zoomFactorChanged(self, zoomFactor: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"zoomModeChanged(QPdfView::ZoomMode)", "\1zoomModeChanged(self, zoomMode: QPdfView.ZoomMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"pageModeChanged(QPdfView::PageMode)", "\1pageModeChanged(self, pageMode: QPdfView.PageMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"documentChanged(QPdfDocument*)", "\1documentChanged(self, document: QPdfDocument|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QPdfView = {
    &::QPdfView::staticMetaObject,
    signals_QPdfView,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPdfWidgets_QPdfView = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPdfView,
        SIP_NULLPTR,
        &plugin_QPdfView,
    },
    {
        sipNameNr_QPdfView,
        {0, 0, 1},
        23, methods_QPdfView,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QPdfView, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPdfView,
    -1,
    -1,
    supers_QPdfView,
    SIP_NULLPTR,
    init_type_QPdfView,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPdfView,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QPdfView,
    cast_QPdfView,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QPdfView),
};
