/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 716 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQSinglePointEvent.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQSinglePointEvent.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQSinglePointEvent.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQSinglePointEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQSinglePointEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qeventpoint.sip"
#include <qeventpoint.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQSinglePointEvent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQSinglePointEvent.cpp"
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpointingdevice.sip"
#include <qpointingdevice.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQSinglePointEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qinputdevice.sip"
#include <qinputdevice.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQSinglePointEvent.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQSinglePointEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQSinglePointEvent.cpp"


PyDoc_STRVAR(doc_QSinglePointEvent_button, "button(self) -> Qt.MouseButton");

extern "C" {static PyObject *meth_QSinglePointEvent_button(PyObject *, PyObject *);}
static PyObject *meth_QSinglePointEvent_button(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSinglePointEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSinglePointEvent, &sipCpp))
        {
            ::Qt::MouseButton sipRes;

            sipRes = sipCpp->button();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_MouseButton);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSinglePointEvent, sipName_button, doc_QSinglePointEvent_button);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSinglePointEvent_buttons, "buttons(self) -> Qt.MouseButton");

extern "C" {static PyObject *meth_QSinglePointEvent_buttons(PyObject *, PyObject *);}
static PyObject *meth_QSinglePointEvent_buttons(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSinglePointEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSinglePointEvent, &sipCpp))
        {
            ::Qt::MouseButtons*sipRes;

            sipRes = new ::Qt::MouseButtons(sipCpp->buttons());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_MouseButton, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSinglePointEvent, sipName_buttons, doc_QSinglePointEvent_buttons);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSinglePointEvent_position, "position(self) -> QPointF");

extern "C" {static PyObject *meth_QSinglePointEvent_position(PyObject *, PyObject *);}
static PyObject *meth_QSinglePointEvent_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSinglePointEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSinglePointEvent, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->position());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSinglePointEvent, sipName_position, doc_QSinglePointEvent_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSinglePointEvent_scenePosition, "scenePosition(self) -> QPointF");

extern "C" {static PyObject *meth_QSinglePointEvent_scenePosition(PyObject *, PyObject *);}
static PyObject *meth_QSinglePointEvent_scenePosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSinglePointEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSinglePointEvent, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->scenePosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSinglePointEvent, sipName_scenePosition, doc_QSinglePointEvent_scenePosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSinglePointEvent_globalPosition, "globalPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QSinglePointEvent_globalPosition(PyObject *, PyObject *);}
static PyObject *meth_QSinglePointEvent_globalPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSinglePointEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSinglePointEvent, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->globalPosition());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSinglePointEvent, sipName_globalPosition, doc_QSinglePointEvent_globalPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSinglePointEvent_isBeginEvent, "isBeginEvent(self) -> bool");

extern "C" {static PyObject *meth_QSinglePointEvent_isBeginEvent(PyObject *, PyObject *);}
static PyObject *meth_QSinglePointEvent_isBeginEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSinglePointEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QSinglePointEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSinglePointEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSinglePointEvent::isBeginEvent() : sipCpp->isBeginEvent());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSinglePointEvent, sipName_isBeginEvent, doc_QSinglePointEvent_isBeginEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSinglePointEvent_isUpdateEvent, "isUpdateEvent(self) -> bool");

extern "C" {static PyObject *meth_QSinglePointEvent_isUpdateEvent(PyObject *, PyObject *);}
static PyObject *meth_QSinglePointEvent_isUpdateEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSinglePointEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QSinglePointEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSinglePointEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSinglePointEvent::isUpdateEvent() : sipCpp->isUpdateEvent());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSinglePointEvent, sipName_isUpdateEvent, doc_QSinglePointEvent_isUpdateEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSinglePointEvent_isEndEvent, "isEndEvent(self) -> bool");

extern "C" {static PyObject *meth_QSinglePointEvent_isEndEvent(PyObject *, PyObject *);}
static PyObject *meth_QSinglePointEvent_isEndEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSinglePointEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QSinglePointEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSinglePointEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSinglePointEvent::isEndEvent() : sipCpp->isEndEvent());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSinglePointEvent, sipName_isEndEvent, doc_QSinglePointEvent_isEndEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSinglePointEvent_exclusivePointGrabber, "exclusivePointGrabber(self) -> QObject|None");

extern "C" {static PyObject *meth_QSinglePointEvent_exclusivePointGrabber(PyObject *, PyObject *);}
static PyObject *meth_QSinglePointEvent_exclusivePointGrabber(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSinglePointEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSinglePointEvent, &sipCpp))
        {
            ::QObject*sipRes;

            sipRes = sipCpp->exclusivePointGrabber();

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSinglePointEvent, sipName_exclusivePointGrabber, doc_QSinglePointEvent_exclusivePointGrabber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSinglePointEvent_setExclusivePointGrabber, "setExclusivePointGrabber(self, exclusiveGrabber: QObject|None)");

extern "C" {static PyObject *meth_QSinglePointEvent_setExclusivePointGrabber(PyObject *, PyObject *);}
static PyObject *meth_QSinglePointEvent_setExclusivePointGrabber(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        ::QSinglePointEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QSinglePointEvent, &sipCpp, sipType_QObject, &a0))
        {
            sipCpp->setExclusivePointGrabber(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSinglePointEvent, sipName_setExclusivePointGrabber, doc_QSinglePointEvent_setExclusivePointGrabber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSinglePointEvent_clone, "clone(self) -> QSinglePointEvent|None");

extern "C" {static PyObject *meth_QSinglePointEvent_clone(PyObject *, PyObject *);}
static PyObject *meth_QSinglePointEvent_clone(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSinglePointEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QSinglePointEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSinglePointEvent, &sipCpp))
        {
            ::QSinglePointEvent*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSinglePointEvent::clone() : sipCpp->clone());

            return sipConvertFromType(sipRes, sipType_QSinglePointEvent, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSinglePointEvent, sipName_clone, doc_QSinglePointEvent_clone);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSinglePointEvent(void *, const sipTypeDef *);}
static void *cast_QSinglePointEvent(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSinglePointEvent *sipCpp = reinterpret_cast< ::QSinglePointEvent *>(sipCppV);

    if (targetType == sipType_QSinglePointEvent)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QPointerEvent)->ctd_cast(static_cast< ::QPointerEvent *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSinglePointEvent(void *, int);}
static void release_QSinglePointEvent(void *sipCppV, int)
{
    delete reinterpret_cast< ::QSinglePointEvent *>(sipCppV);
}


extern "C" {static void dealloc_QSinglePointEvent(sipSimpleWrapper *);}
static void dealloc_QSinglePointEvent(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSinglePointEvent(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSinglePointEvent[] = {{245, 255, 1}};


static PyMethodDef methods_QSinglePointEvent[] = {
    {sipName_button, meth_QSinglePointEvent_button, METH_VARARGS, doc_QSinglePointEvent_button},
    {sipName_buttons, meth_QSinglePointEvent_buttons, METH_VARARGS, doc_QSinglePointEvent_buttons},
    {sipName_clone, meth_QSinglePointEvent_clone, METH_VARARGS, doc_QSinglePointEvent_clone},
    {sipName_exclusivePointGrabber, meth_QSinglePointEvent_exclusivePointGrabber, METH_VARARGS, doc_QSinglePointEvent_exclusivePointGrabber},
    {sipName_globalPosition, meth_QSinglePointEvent_globalPosition, METH_VARARGS, doc_QSinglePointEvent_globalPosition},
    {sipName_isBeginEvent, meth_QSinglePointEvent_isBeginEvent, METH_VARARGS, doc_QSinglePointEvent_isBeginEvent},
    {sipName_isEndEvent, meth_QSinglePointEvent_isEndEvent, METH_VARARGS, doc_QSinglePointEvent_isEndEvent},
    {sipName_isUpdateEvent, meth_QSinglePointEvent_isUpdateEvent, METH_VARARGS, doc_QSinglePointEvent_isUpdateEvent},
    {sipName_position, meth_QSinglePointEvent_position, METH_VARARGS, doc_QSinglePointEvent_position},
    {sipName_scenePosition, meth_QSinglePointEvent_scenePosition, METH_VARARGS, doc_QSinglePointEvent_scenePosition},
    {sipName_setExclusivePointGrabber, meth_QSinglePointEvent_setExclusivePointGrabber, METH_VARARGS, doc_QSinglePointEvent_setExclusivePointGrabber}
};


sipClassTypeDef sipTypeDef_QtGui_QSinglePointEvent = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSinglePointEvent,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QSinglePointEvent,
        {0, 0, 1},
        11, methods_QSinglePointEvent,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QSinglePointEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSinglePointEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QSinglePointEvent,
    cast_QSinglePointEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
