/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 161 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpermissions.sip"
#include <qpermissions.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocationPermission.cpp"



PyDoc_STRVAR(doc_QLocationPermission_setAccuracy, "setAccuracy(self, accuracy: QLocationPermission.Accuracy)");

extern "C" {static PyObject *meth_QLocationPermission_setAccuracy(PyObject *, PyObject *);}
static PyObject *meth_QLocationPermission_setAccuracy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocationPermission::Accuracy a0;
        ::QLocationPermission *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QLocationPermission, &sipCpp, sipType_QLocationPermission_Accuracy, &a0))
        {
            sipCpp->setAccuracy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocationPermission, sipName_setAccuracy, doc_QLocationPermission_setAccuracy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocationPermission_accuracy, "accuracy(self) -> QLocationPermission.Accuracy");

extern "C" {static PyObject *meth_QLocationPermission_accuracy(PyObject *, PyObject *);}
static PyObject *meth_QLocationPermission_accuracy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocationPermission *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocationPermission, &sipCpp))
        {
            ::QLocationPermission::Accuracy sipRes;

            sipRes = sipCpp->accuracy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocationPermission_Accuracy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocationPermission, sipName_accuracy, doc_QLocationPermission_accuracy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocationPermission_setAvailability, "setAvailability(self, availability: QLocationPermission.Availability)");

extern "C" {static PyObject *meth_QLocationPermission_setAvailability(PyObject *, PyObject *);}
static PyObject *meth_QLocationPermission_setAvailability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocationPermission::Availability a0;
        ::QLocationPermission *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QLocationPermission, &sipCpp, sipType_QLocationPermission_Availability, &a0))
        {
            sipCpp->setAvailability(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocationPermission, sipName_setAvailability, doc_QLocationPermission_setAvailability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocationPermission_availability, "availability(self) -> QLocationPermission.Availability");

extern "C" {static PyObject *meth_QLocationPermission_availability(PyObject *, PyObject *);}
static PyObject *meth_QLocationPermission_availability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocationPermission *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocationPermission, &sipCpp))
        {
            ::QLocationPermission::Availability sipRes;

            sipRes = sipCpp->availability();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocationPermission_Availability);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocationPermission, sipName_availability, doc_QLocationPermission_availability);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QLocationPermission(void *, int);}
static void release_QLocationPermission(void *sipCppV, int)
{
    delete reinterpret_cast< ::QLocationPermission *>(sipCppV);
}


extern "C" {static void *array_QLocationPermission(Py_ssize_t);}
static void *array_QLocationPermission(Py_ssize_t sipNrElem)
{
    return new ::QLocationPermission[sipNrElem];
}


extern "C" {static void array_delete_QLocationPermission(void *);}
static void array_delete_QLocationPermission(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLocationPermission *>(sipCpp);
}


extern "C" {static void assign_QLocationPermission(void *, Py_ssize_t, void *);}
static void assign_QLocationPermission(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QLocationPermission *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QLocationPermission *>(sipSrc);
}


extern "C" {static void *copy_QLocationPermission(const void *, Py_ssize_t);}
static void *copy_QLocationPermission(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QLocationPermission(reinterpret_cast<const ::QLocationPermission *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QLocationPermission(sipSimpleWrapper *);}
static void dealloc_QLocationPermission(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLocationPermission(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QLocationPermission(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLocationPermission(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QLocationPermission *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QLocationPermission();

            return sipCpp;
        }
    }

    {
        const ::QLocationPermission* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QLocationPermission, &a0))
        {
            sipCpp = new ::QLocationPermission(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QLocationPermission[] = {
    {sipName_accuracy, meth_QLocationPermission_accuracy, METH_VARARGS, doc_QLocationPermission_accuracy},
    {sipName_availability, meth_QLocationPermission_availability, METH_VARARGS, doc_QLocationPermission_availability},
    {sipName_setAccuracy, meth_QLocationPermission_setAccuracy, METH_VARARGS, doc_QLocationPermission_setAccuracy},
    {sipName_setAvailability, meth_QLocationPermission_setAvailability, METH_VARARGS, doc_QLocationPermission_setAvailability}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QLocationPermission[] = {
    {sipName_Approximate, static_cast<int>(::QLocationPermission::Approximate)},
    {sipName_Precise, static_cast<int>(::QLocationPermission::Precise)},
    {sipName_WhenInUse, static_cast<int>(::QLocationPermission::WhenInUse)},
    {sipName_Always, static_cast<int>(::QLocationPermission::Always)},
    {0, 0}
};

PyDoc_STRVAR(doc_QLocationPermission, "\1QLocationPermission()\n"
"QLocationPermission(other: QLocationPermission)");


sipClassTypeDef sipTypeDef_QtCore_QLocationPermission = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLocationPermission,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QLocationPermission,
        {0, 0, 1},
        4, methods_QLocationPermission,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QLocationPermission, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLocationPermission,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QLocationPermission,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLocationPermission,
    assign_QLocationPermission,
    array_QLocationPermission,
    copy_QLocationPermission,
    release_QLocationPermission,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLocationPermission,
    sizeof (::QLocationPermission),
};
