/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qlowenergyadvertisingdata.sip"
#include <qlowenergyadvertisingdata.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyAdvertisingData.cpp"

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyAdvertisingData.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyAdvertisingData.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothuuid.sip"
#include <qbluetoothuuid.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyAdvertisingData.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyAdvertisingData.cpp"


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_setLocalName, "setLocalName(self, name: str|None)");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_setLocalName(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_setLocalName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLocalName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_setLocalName, doc_QLowEnergyAdvertisingData_setLocalName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_localName, "localName(self) -> str");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_localName(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_localName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->localName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_localName, doc_QLowEnergyAdvertisingData_localName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_invalidManufacturerId, "invalidManufacturerId() -> int");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_invalidManufacturerId(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_invalidManufacturerId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::quint16 sipRes;

            sipRes = ::QLowEnergyAdvertisingData::invalidManufacturerId();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_invalidManufacturerId, doc_QLowEnergyAdvertisingData_invalidManufacturerId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_setManufacturerData, "setManufacturerData(self, id: int, data: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_setManufacturerData(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_setManufacturerData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint16 a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BtJ1", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp, &a0, sipType_QByteArray, &a1, &a1State))
        {
            sipCpp->setManufacturerData(a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_setManufacturerData, doc_QLowEnergyAdvertisingData_setManufacturerData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_manufacturerId, "manufacturerId(self) -> int");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_manufacturerId(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_manufacturerId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp))
        {
            ::quint16 sipRes;

            sipRes = sipCpp->manufacturerId();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_manufacturerId, doc_QLowEnergyAdvertisingData_manufacturerId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_manufacturerData, "manufacturerData(self) -> QByteArray");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_manufacturerData(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_manufacturerData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->manufacturerData());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_manufacturerData, doc_QLowEnergyAdvertisingData_manufacturerData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_setIncludePowerLevel, "setIncludePowerLevel(self, doInclude: bool)");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_setIncludePowerLevel(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_setIncludePowerLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp, &a0))
        {
            sipCpp->setIncludePowerLevel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_setIncludePowerLevel, doc_QLowEnergyAdvertisingData_setIncludePowerLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_includePowerLevel, "includePowerLevel(self) -> bool");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_includePowerLevel(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_includePowerLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->includePowerLevel();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_includePowerLevel, doc_QLowEnergyAdvertisingData_includePowerLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_setDiscoverability, "setDiscoverability(self, mode: QLowEnergyAdvertisingData.Discoverability)");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_setDiscoverability(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_setDiscoverability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLowEnergyAdvertisingData::Discoverability a0;
        ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp, sipType_QLowEnergyAdvertisingData_Discoverability, &a0))
        {
            sipCpp->setDiscoverability(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_setDiscoverability, doc_QLowEnergyAdvertisingData_setDiscoverability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_discoverability, "discoverability(self) -> QLowEnergyAdvertisingData.Discoverability");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_discoverability(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_discoverability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp))
        {
            ::QLowEnergyAdvertisingData::Discoverability sipRes;

            sipRes = sipCpp->discoverability();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLowEnergyAdvertisingData_Discoverability);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_discoverability, doc_QLowEnergyAdvertisingData_discoverability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_setServices, "setServices(self, services: Iterable[QBluetoothUuid])");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_setServices(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_setServices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QBluetoothUuid>* a0;
        int a0State = 0;
        ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp, sipType_QList_0100QBluetoothUuid, &a0, &a0State))
        {
            sipCpp->setServices(*a0);
            sipReleaseType(const_cast<QList< ::QBluetoothUuid> *>(a0), sipType_QList_0100QBluetoothUuid, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_setServices, doc_QLowEnergyAdvertisingData_setServices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_services, "services(self) -> list[QBluetoothUuid]");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_services(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_services(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp))
        {
            QList< ::QBluetoothUuid>*sipRes;

            sipRes = new QList< ::QBluetoothUuid>(sipCpp->services());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QBluetoothUuid, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_services, doc_QLowEnergyAdvertisingData_services);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_setRawData, "setRawData(self, data: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_setRawData(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_setRawData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setRawData(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_setRawData, doc_QLowEnergyAdvertisingData_setRawData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_rawData, "rawData(self) -> QByteArray");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_rawData(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_rawData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->rawData());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_rawData, doc_QLowEnergyAdvertisingData_rawData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyAdvertisingData_swap, "swap(self, other: QLowEnergyAdvertisingData)");

extern "C" {static PyObject *meth_QLowEnergyAdvertisingData_swap(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyAdvertisingData_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLowEnergyAdvertisingData* a0;
        ::QLowEnergyAdvertisingData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLowEnergyAdvertisingData, &sipCpp, sipType_QLowEnergyAdvertisingData, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyAdvertisingData, sipName_swap, doc_QLowEnergyAdvertisingData_swap);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QLowEnergyAdvertisingData___eq__(PyObject *, PyObject *);}
static PyObject *slot_QLowEnergyAdvertisingData___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLowEnergyAdvertisingData *sipCpp = reinterpret_cast< ::QLowEnergyAdvertisingData *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLowEnergyAdvertisingData));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyAdvertisingData* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLowEnergyAdvertisingData, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, eq_slot, sipType_QLowEnergyAdvertisingData, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QLowEnergyAdvertisingData___ne__(PyObject *, PyObject *);}
static PyObject *slot_QLowEnergyAdvertisingData___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLowEnergyAdvertisingData *sipCpp = reinterpret_cast< ::QLowEnergyAdvertisingData *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLowEnergyAdvertisingData));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyAdvertisingData* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLowEnergyAdvertisingData, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, ne_slot, sipType_QLowEnergyAdvertisingData, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QLowEnergyAdvertisingData(void *, int);}
static void release_QLowEnergyAdvertisingData(void *sipCppV, int)
{
    delete reinterpret_cast< ::QLowEnergyAdvertisingData *>(sipCppV);
}


extern "C" {static void *array_QLowEnergyAdvertisingData(Py_ssize_t);}
static void *array_QLowEnergyAdvertisingData(Py_ssize_t sipNrElem)
{
    return new ::QLowEnergyAdvertisingData[sipNrElem];
}


extern "C" {static void array_delete_QLowEnergyAdvertisingData(void *);}
static void array_delete_QLowEnergyAdvertisingData(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLowEnergyAdvertisingData *>(sipCpp);
}


extern "C" {static void assign_QLowEnergyAdvertisingData(void *, Py_ssize_t, void *);}
static void assign_QLowEnergyAdvertisingData(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QLowEnergyAdvertisingData *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QLowEnergyAdvertisingData *>(sipSrc);
}


extern "C" {static void *copy_QLowEnergyAdvertisingData(const void *, Py_ssize_t);}
static void *copy_QLowEnergyAdvertisingData(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QLowEnergyAdvertisingData(reinterpret_cast<const ::QLowEnergyAdvertisingData *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QLowEnergyAdvertisingData(sipSimpleWrapper *);}
static void dealloc_QLowEnergyAdvertisingData(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLowEnergyAdvertisingData(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QLowEnergyAdvertisingData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLowEnergyAdvertisingData(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QLowEnergyAdvertisingData *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QLowEnergyAdvertisingData();

            return sipCpp;
        }
    }

    {
        const ::QLowEnergyAdvertisingData* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QLowEnergyAdvertisingData, &a0))
        {
            sipCpp = new ::QLowEnergyAdvertisingData(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QLowEnergyAdvertisingData[] = {
    {(void *)slot_QLowEnergyAdvertisingData___eq__, eq_slot},
    {(void *)slot_QLowEnergyAdvertisingData___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QLowEnergyAdvertisingData[] = {
    {sipName_discoverability, meth_QLowEnergyAdvertisingData_discoverability, METH_VARARGS, doc_QLowEnergyAdvertisingData_discoverability},
    {sipName_includePowerLevel, meth_QLowEnergyAdvertisingData_includePowerLevel, METH_VARARGS, doc_QLowEnergyAdvertisingData_includePowerLevel},
    {sipName_invalidManufacturerId, meth_QLowEnergyAdvertisingData_invalidManufacturerId, METH_VARARGS, doc_QLowEnergyAdvertisingData_invalidManufacturerId},
    {sipName_localName, meth_QLowEnergyAdvertisingData_localName, METH_VARARGS, doc_QLowEnergyAdvertisingData_localName},
    {sipName_manufacturerData, meth_QLowEnergyAdvertisingData_manufacturerData, METH_VARARGS, doc_QLowEnergyAdvertisingData_manufacturerData},
    {sipName_manufacturerId, meth_QLowEnergyAdvertisingData_manufacturerId, METH_VARARGS, doc_QLowEnergyAdvertisingData_manufacturerId},
    {sipName_rawData, meth_QLowEnergyAdvertisingData_rawData, METH_VARARGS, doc_QLowEnergyAdvertisingData_rawData},
    {sipName_services, meth_QLowEnergyAdvertisingData_services, METH_VARARGS, doc_QLowEnergyAdvertisingData_services},
    {sipName_setDiscoverability, meth_QLowEnergyAdvertisingData_setDiscoverability, METH_VARARGS, doc_QLowEnergyAdvertisingData_setDiscoverability},
    {sipName_setIncludePowerLevel, meth_QLowEnergyAdvertisingData_setIncludePowerLevel, METH_VARARGS, doc_QLowEnergyAdvertisingData_setIncludePowerLevel},
    {sipName_setLocalName, meth_QLowEnergyAdvertisingData_setLocalName, METH_VARARGS, doc_QLowEnergyAdvertisingData_setLocalName},
    {sipName_setManufacturerData, meth_QLowEnergyAdvertisingData_setManufacturerData, METH_VARARGS, doc_QLowEnergyAdvertisingData_setManufacturerData},
    {sipName_setRawData, meth_QLowEnergyAdvertisingData_setRawData, METH_VARARGS, doc_QLowEnergyAdvertisingData_setRawData},
    {sipName_setServices, meth_QLowEnergyAdvertisingData_setServices, METH_VARARGS, doc_QLowEnergyAdvertisingData_setServices},
    {sipName_swap, meth_QLowEnergyAdvertisingData_swap, METH_VARARGS, doc_QLowEnergyAdvertisingData_swap}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QLowEnergyAdvertisingData[] = {
    {sipName_DiscoverabilityNone, static_cast<int>(::QLowEnergyAdvertisingData::DiscoverabilityNone)},
    {sipName_DiscoverabilityLimited, static_cast<int>(::QLowEnergyAdvertisingData::DiscoverabilityLimited)},
    {sipName_DiscoverabilityGeneral, static_cast<int>(::QLowEnergyAdvertisingData::DiscoverabilityGeneral)},
    {0, 0}
};

PyDoc_STRVAR(doc_QLowEnergyAdvertisingData, "\1QLowEnergyAdvertisingData()\n"
"QLowEnergyAdvertisingData(other: QLowEnergyAdvertisingData)");


sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyAdvertisingData = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLowEnergyAdvertisingData,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QLowEnergyAdvertisingData,
        {0, 0, 1},
        15, methods_QLowEnergyAdvertisingData,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QLowEnergyAdvertisingData, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLowEnergyAdvertisingData,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QLowEnergyAdvertisingData,
    init_type_QLowEnergyAdvertisingData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLowEnergyAdvertisingData,
    assign_QLowEnergyAdvertisingData,
    array_QLowEnergyAdvertisingData,
    copy_QLowEnergyAdvertisingData,
    release_QLowEnergyAdvertisingData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLowEnergyAdvertisingData,
    sizeof (::QLowEnergyAdvertisingData),
};
