/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtHelp.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 32 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
// The capsule destructor for a QModelRoleData array.
static void qpycore_gc_modelroledata(PyObject *mrd_obj);
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 271 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 612 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractitemview.sip"
#include <qabstractitemview.h>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 789 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 126 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractitemdelegate.sip"
#include <qabstractitemdelegate.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qcompressedhelpinfo.sip"
#include <qcompressedhelpinfo.h>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpfilterdata.sip"
#include <qhelpfilterdata.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpfiltersettingswidget.sip"
#include <qhelpfiltersettingswidget.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelplink.sip"
#include <qhelplink.h>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpsearchengine.sip"
#include <qhelpsearchengine.h>
#line 215 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpsearchquerywidget.sip"
#include <qhelpsearchquerywidget.h>
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpsearchresult.sip"
#include <qhelpsearchresult.h>
#line 221 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtHelp[] = {
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'S', 'c', 'r', 'o', 'l', 'l', 'b', 'a', 'r', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'F', 'o', 'r', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'S', 'c', 'r', 'o', 'l', 'l', 'b', 'a', 'r', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'M', 'a', 'p', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', ',', 'Q', 'V', 'e', 'r', 's', 'i', 'o', 'n', 'N', 'u', 'm', 'b', 'e', 'r', '>', 0,
    'Q', 'H', 'e', 'l', 'p', 'S', 'e', 'a', 'r', 'c', 'h', 'Q', 'u', 'e', 'r', 'y', ':', ':', 'F', 'i', 'e', 'l', 'd', 'N', 'a', 'm', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'I', 'n', 'd', 'e', 'x', 'F', 'o', 'r', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'H', 'e', 'l', 'p', 'F', 'i', 'l', 't', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'S', 'c', 'r', 'o', 'l', 'l', 'b', 'a', 'r', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'H', 'e', 'l', 'p', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', '>', 0,
    'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'e', 'd', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', 0,
    'v', 'i', 's', 'u', 'a', 'l', 'R', 'e', 'g', 'i', 'o', 'n', 'F', 'o', 'r', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'P', 'y', 'Q', 't', '6', '.', 's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 'H', 'e', 'l', 'p', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'C', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 'r', 't', 'e', 'd', 0,
    'u', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'S', 'c', 'r', 'o', 'l', 'l', 'b', 'a', 'r', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'H', 'e', 'l', 'p', 'S', 'e', 'a', 'r', 'c', 'h', 'Q', 'u', 'e', 'r', 'y', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'c', 'o', 'l', 'l', 'a', 'p', 's', 'e', 'E', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'S', 'e', 'a', 'r', 'c', 'h', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 's', 'F', 'o', 'r', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'f', 'r', 'o', 'm', 'C', 'o', 'm', 'p', 'r', 'e', 's', 's', 'e', 'd', 'H', 'e', 'l', 'p', 'F', 'i', 'l', 'e', 0,
    's', 'e', 't', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 's', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'E', 'd', 'i', 't', 'o', 'r', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'i', 'e', 's', 0,
    'Q', 'H', 'e', 'l', 'p', 'S', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'C', 'o', 'r', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'V', 'e', 'r', 's', 'i', 'o', 'n', 'N', 'u', 'm', 'b', 'e', 'r', '>', 0,
    'Q', 'M', 'a', 'p', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', ',', 'Q', 'S', 't', 'r', 'i', 'n', 'g', '>', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'x', 'p', 'a', 'n', 'd', 'E', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'S', 'e', 'a', 'r', 'c', 'h', 0,
    'i', 'n', 'd', 'e', 'x', 'C', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 'r', 't', 'e', 'd', 0,
    'i', 't', 'e', 'm', 'D', 'e', 'l', 'e', 'g', 'a', 't', 'e', 'F', 'o', 'r', 'I', 'n', 'd', 'e', 'x', 0,
    'n', 'a', 'm', 'e', 's', 'p', 'a', 'c', 'e', 'T', 'o', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'r', 'e', 'i', 'n', 'd', 'e', 'x', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'r', 'o', 'w', 's', 'A', 'b', 'o', 'u', 't', 'T', 'o', 'B', 'e', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    's', 'e', 't', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'V', 'e', 'r', 's', 'i', 'o', 'n', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'r', 'a', 'g', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'r', 'o', 'p', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'C', 'o', 'm', 'p', 'r', 'e', 's', 's', 'e', 'd', 'H', 'e', 'l', 'p', 'I', 'n', 'f', 'o', 0,
    'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'I', 't', 'e', 'm', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 's', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 's', 'F', 'o', 'r', 'K', 'e', 'y', 'w', 'o', 'r', 'd', 0,
    'n', 'a', 'm', 'e', 's', 'p', 'a', 'c', 'e', 's', 'F', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 0,
    's', 'e', 't', 'U', 's', 'e', 's', 'F', 'i', 'l', 't', 'e', 'r', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'H', 'e', 'l', 'p', 'C', 'o', 'n', 't', 'e', 'n', 't', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'c', 'o', 'p', 'y', 'C', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'F', 'i', 'l', 'e', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 's', 'A', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', 0,
    'f', 'o', 'c', 'u', 's', 'N', 'e', 'x', 't', 'P', 'r', 'e', 'v', 'C', 'h', 'i', 'l', 'd', 0,
    'i', 'n', 'i', 't', 'V', 'i', 'e', 'w', 'I', 't', 'e', 'm', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'i', 's', 'C', 'r', 'e', 'a', 't', 'i', 'n', 'g', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'n', 'a', 'm', 'e', 's', 'p', 'a', 'c', 'e', 'T', 'o', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'Q', 'H', 'e', 'l', 'p', 'C', 'o', 'n', 't', 'e', 'n', 't', 'M', 'o', 'd', 'e', 'l', 0,
    'Q', 'H', 'e', 'l', 'p', 'F', 'i', 'l', 't', 'e', 'r', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'H', 'e', 'l', 'p', 'S', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'H', 'e', 'l', 'p', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'V', 'e', 'r', 's', 'i', 'o', 'n', 's', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'A', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', 0,
    'h', 'a', 's', 'H', 'e', 'i', 'g', 'h', 't', 'F', 'o', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'm', 'o', 'u', 's', 'e', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'u', 's', 't', 'o', 'm', 'V', 'a', 'l', 'u', 'e', 0,
    'r', 'e', 's', 'e', 't', 'I', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'D', 'a', 't', 'a', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'i', 'n', 'g', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'S', 'a', 'v', 'e', 'F', 'i', 'l', 't', 'e', 'r', 0,
    's', 'e', 't', 'C', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'F', 'i', 'l', 'e', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 'l', 0,
    's', 'i', 'z', 'e', 'H', 'i', 'n', 't', 'F', 'o', 'r', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'Q', 'H', 'e', 'l', 'p', 'C', 'o', 'n', 't', 'e', 'n', 't', 'I', 't', 'e', 'm', 0,
    'Q', 'H', 'e', 'l', 'p', 'I', 'n', 'd', 'e', 'x', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'Q', 'H', 'e', 'l', 'p', 'S', 'e', 'a', 'r', 'c', 'h', 'Q', 'u', 'e', 'r', 'y', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'H', 'e', 'l', 'p', 'L', 'i', 'n', 'k', '>', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'O', 'f', 'f', 's', 'e', 't', 0,
    'i', 'n', 'd', 'e', 'x', 'i', 'n', 'g', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'Q', 'u', 'e', 'r', 'y', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'B', 'y', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'i', 'n', 'g', 'S', 't', 'a', 'r', 't', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'E', 'd', 'i', 't', 'o', 'r', 'D', 'a', 't', 'a', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'i', 'e', 's', 0,
    'u', 's', 'e', 's', 'F', 'i', 'l', 't', 'e', 'r', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'S', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'Q', 'H', 'e', 'l', 'p', 'E', 'n', 'g', 'i', 'n', 'e', 'C', 'o', 'r', 'e', 0,
    'Q', 'H', 'e', 'l', 'p', 'F', 'i', 'l', 't', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'Q', 'H', 'e', 'l', 'p', 'I', 'n', 'd', 'e', 'x', 'M', 'o', 'd', 'e', 'l', 0,
    'c', 'a', 'n', 'D', 'r', 'o', 'p', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'c', 'a', 'n', 'c', 'e', 'l', 'S', 'e', 'a', 'r', 'c', 'h', 'i', 'n', 'g', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'C', 'r', 'e', 'a', 't', 'e', 'd', 0,
    'e', 'd', 'i', 't', 'o', 'r', 'D', 'e', 's', 't', 'r', 'o', 'y', 'e', 'd', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'f', 'i', 'l', 't', 'e', 'r', 'A', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', 0,
    'i', 'n', 'd', 'e', 'x', 'i', 'n', 'g', 'S', 't', 'a', 'r', 't', 'e', 'd', 0,
    'i', 'n', 'i', 't', 'S', 't', 'y', 'l', 'e', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'i', 's', 'C', 'r', 'e', 'a', 't', 'i', 'n', 'g', 'I', 'n', 'd', 'e', 'x', 0,
    'k', 'e', 'y', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'S', 'h', 'o', 'w', 'L', 'i', 'n', 'k', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'I', 'n', 'd', 'e', 'x', 'e', 's', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'a', 'u', 't', 'o', 'S', 'a', 'v', 'e', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'c', 'a', 'n', 'c', 'e', 'l', 'I', 'n', 'd', 'e', 'x', 'i', 'n', 'g', 0,
    'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'F', 'i', 'l', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'r', 'a', 'g', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'r', 'a', 'g', 'L', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'F', 'o', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'S', 'e', 'a', 'r', 'c', 'h', 0,
    'm', 'o', 'u', 's', 'e', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'a', 'c', 't', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'C', 'u', 's', 't', 'o', 'm', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'S', 'e', 'a', 'r', 'c', 'h', 'I', 'n', 'p', 'u', 't', 0,
    's', 'i', 'z', 'e', 'H', 'i', 'n', 't', 'F', 'o', 'r', 'R', 'o', 'w', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'O', 'f', 'f', 's', 'e', 't', 0,
    'a', 'p', 'p', 'l', 'y', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'c', 'h', 'i', 'l', 'd', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'c', 'l', 'e', 'a', 'r', 'I', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'I', 't', 'e', 'm', 'A', 't', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'd', 'r', 'a', 'g', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'i', 'l', 't', 'e', 'r', 'I', 'n', 'd', 'i', 'c', 'e', 's', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'i', 's', 'C', 'o', 'm', 'p', 'a', 'c', 't', 'M', 'o', 'd', 'e', 0,
    'i', 's', 'I', 'n', 'd', 'e', 'x', 'H', 'i', 'd', 'd', 'e', 'n', 0,
    'k', 'e', 'y', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'i', 'n', 'k', 'A', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', 0,
    'n', 'a', 'm', 'e', 's', 'p', 'a', 'c', 'e', 'N', 'a', 'm', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', 's', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 's', 0,
    's', 'e', 't', 'F', 'i', 'l', 't', 'e', 'r', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'H', 'e', 'a', 'd', 'e', 'r', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'u', 'p', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    's', 'e', 't', 'u', 'p', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    's', 'h', 'a', 'r', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'E', 'v', 'e', 'n', 't', 0,
    'P', 'y', 'Q', 't', '6', '.', 'Q', 't', 'H', 'e', 'l', 'p', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'c', 'a', 'n', 'F', 'e', 't', 'c', 'h', 'M', 'o', 'r', 'e', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'M', 'o', 'd', 'e', 'l', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'V', 'a', 'l', 'u', 'e', 0,
    'd', 'r', 'a', 'w', 'B', 'r', 'a', 'n', 'c', 'h', 'e', 's', 0,
    'd', 'r', 'o', 'p', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'f', 'i', 'l', 't', 'e', 'r', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'f', 'o', 'c', 'u', 's', 'I', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 'd', 'e', 'x', 'C', 'r', 'e', 'a', 't', 'e', 'd', 0,
    'r', 'e', 'a', 'd', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'r', 'e', 's', 'u', 'l', 't', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'r', 'o', 'w', 's', 'I', 'n', 's', 'e', 'r', 't', 'e', 'd', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    's', 'e', 't', 'R', 'o', 'o', 't', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'u', 'p', 'S', 't', 'a', 'r', 't', 'e', 'd', 0,
    'Q', 'H', 'e', 'l', 'p', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'l', 'o', 's', 'e', 'E', 'd', 'i', 't', 'o', 'r', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'I', 'n', 'd', 'e', 'x', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'u', 's', 't', 'o', 'm', 'V', 'a', 'l', 'u', 'e', 0,
    'd', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'h', 'a', 's', 'C', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 0,
    'i', 'n', 'd', 'e', 'x', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'i', 'n', 'i', 't', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'q', 'u', 'e', 'r', 'y', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'I', 'n', 'p', 'u', 't', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    's', 'e', 't', 'V', 'e', 'r', 's', 'i', 'o', 'n', 's', 0,
    't', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'h', 'i', 'l', 'd', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'l', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'o', 'm', 'm', 'i', 't', 'D', 'a', 't', 'a', 0,
    'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 's', 0,
    'e', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'i', 'l', 't', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'h', 'e', 'a', 'd', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'h', 'e', 'l', 'p', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'i', 'n', 'd', 'e', 'x', 'M', 'o', 'd', 'e', 'l', 0,
    'i', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 's', 0,
    'i', 's', 'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    'l', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'o', 'v', 'e', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'R', 'o', 'w', 's', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'v', 'i', 's', 'u', 'a', 'l', 'R', 'e', 'c', 't', 0,
    'w', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'H', 'e', 'l', 'p', 'L', 'i', 'n', 'k', 0,
    'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'd', 'r', 'o', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'e', 't', 'c', 'h', 'M', 'o', 'r', 'e', 0,
    'h', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 's', 0,
    'm', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'u', 'l', 't', 'i', 'D', 'a', 't', 'a', 0,
    'r', 'o', 'l', 'e', 'N', 'a', 'm', 'e', 's', 0,
    's', 'e', 'l', 'e', 'c', 't', 'A', 'l', 'l', 0,
    's', 'e', 't', 'u', 'p', 'D', 'a', 't', 'a', 0,
    's', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    's', 't', 'a', 'r', 't', 'D', 'r', 'a', 'g', 0,
    'f', 'i', 'l', 'e', 'D', 'a', 't', 'a', 0,
    'f', 'i', 'n', 'd', 'F', 'i', 'l', 'e', 0,
    'i', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    'm', 'e', 't', 'a', 'D', 'a', 't', 'a', 0,
    'm', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'r', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'T', 'o', 0,
    's', 'e', 't', 'M', 'o', 'd', 'e', 'l', 0,
    's', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'v', 'e', 'r', 's', 'i', 'o', 'n', 's', 0,
    'w', 'i', 'l', 'd', 'c', 'a', 'r', 'd', 0,
    'A', 'T', 'L', 'E', 'A', 'S', 'T', 0,
    'D', 'E', 'F', 'A', 'U', 'L', 'T', 0,
    'W', 'I', 'T', 'H', 'O', 'U', 'T', 0,
    'd', 'e', 'v', 'T', 'y', 'p', 'e', 0,
    'd', 'r', 'a', 'w', 'R', 'o', 'w', 0,
    'f', 'i', 'l', 't', 'e', 'r', 's', 0,
    'i', 'n', 'd', 'e', 'x', 'A', 't', 0,
    'i', 'n', 'd', 'e', 'x', 'O', 'f', 0,
    'i', 'n', 'd', 'i', 'c', 'e', 's', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 0,
    's', 'i', 'b', 'l', 'i', 'n', 'g', 0,
    's', 'n', 'i', 'p', 'p', 'e', 't', 0,
    'v', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'w', 'a', 'r', 'n', 'i', 'n', 'g', 0,
    'P', 'H', 'R', 'A', 'S', 'E', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    'f', 'i', 'l', 't', 'e', 'r', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    'l', 'i', 'n', 'k', 'A', 't', 0,
    'm', 'e', 't', 'r', 'i', 'c', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'r', 'e', 'v', 'e', 'r', 't', 0,
    's', 'e', 'a', 'r', 'c', 'h', 0,
    's', 'u', 'b', 'm', 'i', 't', 0,
    'F', 'U', 'Z', 'Z', 'Y', 0,
    'b', 'u', 'd', 'd', 'y', 0,
    'c', 'h', 'i', 'l', 'd', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'i', 'l', 'e', 's', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'i', 'n', 'd', 'e', 'x', 0,
    'm', 'a', 't', 'c', 'h', 0,
    'r', 'e', 's', 'e', 't', 0,
    't', 'i', 't', 'l', 'e', 0,
    'd', 'a', 't', 'a', 0,
    'e', 'd', 'i', 't', 0,
    's', 'o', 'r', 't', 0,
    's', 'p', 'a', 'n', 0,
    's', 'w', 'a', 'p', 0,
    'A', 'L', 'L', 0,
    'r', 'o', 'w', 0,
    'u', 'r', 'l', 0,
};

void sipVH_QtHelp_87(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QStyleOptionViewItem*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QStyleOptionViewItem, SIP_NULLPTR);
}

::QAbstractItemDelegate* sipVH_QtHelp_86(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::QAbstractItemDelegate* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QAbstractItemDelegate, &sipRes);

    return sipRes;
}

void sipVH_QtHelp_85(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::Qt::DropActions a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::Qt::DropActions(a0), sipType_QFlags_0100Qt_DropAction, SIP_NULLPTR);
}

::QItemSelectionModel::SelectionFlags sipVH_QtHelp_84(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, const ::QEvent*a1)
{
    ::QItemSelectionModel::SelectionFlags sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "ND", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, const_cast< ::QEvent *>(a1), sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QFlags_0100QItemSelectionModel_SelectionFlag, &sipRes);

    return sipRes;
}

bool sipVH_QtHelp_83(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, ::QAbstractItemView::EditTrigger a1, ::QEvent*a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NFD", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, sipType_QAbstractItemView_EditTrigger, a2, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QModelIndexList sipVH_QtHelp_82(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QModelIndexList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QModelIndex, &sipRes);

    return sipRes;
}

::QRegion sipVH_QtHelp_81(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QItemSelection& a0)
{
    ::QRegion sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QItemSelection(a0), sipType_QItemSelection, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRegion, &sipRes);

    return sipRes;
}

void sipVH_QtHelp_80(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QRect& a0, ::QItemSelectionModel::SelectionFlags a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new ::QRect(a0), sipType_QRect, SIP_NULLPTR, new ::QItemSelectionModel::SelectionFlags(a1), sipType_QFlags_0100QItemSelectionModel_SelectionFlag, SIP_NULLPTR);
}

::QModelIndex sipVH_QtHelp_79(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAbstractItemView::CursorAction a0, ::Qt::KeyboardModifiers a1)
{
    ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FN", a0, sipType_QAbstractItemView_CursorAction, new ::Qt::KeyboardModifiers(a1), sipType_QFlags_0100Qt_KeyboardModifier, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

void sipVH_QtHelp_78(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QObject, SIP_NULLPTR);
}

void sipVH_QtHelp_77(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0, ::QAbstractItemDelegate::EndEditHint a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DF", a0, sipType_QWidget, SIP_NULLPTR, a1, sipType_QAbstractItemDelegate_EndEditHint);
}

void sipVH_QtHelp_76(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "i", a0);
}

void sipVH_QtHelp_75(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, const ::QModelIndex& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new ::QModelIndex(a1), sipType_QModelIndex, SIP_NULLPTR);
}

void sipVH_QtHelp_74(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QItemSelection& a0, const ::QItemSelection& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new ::QItemSelection(a0), sipType_QItemSelection, SIP_NULLPTR, new ::QItemSelection(a1), sipType_QItemSelection, SIP_NULLPTR);
}

void sipVH_QtHelp_73(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1, int a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "Nii", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, a2);
}

void sipVH_QtHelp_72(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, const ::QModelIndex& a1, const ::QList<int>& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NNN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new ::QModelIndex(a1), sipType_QModelIndex, SIP_NULLPTR, new ::QList<int>(a2), sipType_QList_1800, SIP_NULLPTR);
}

::QModelIndex sipVH_QtHelp_71(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPoint& a0)
{
    ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPoint(a0), sipType_QPoint, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

void sipVH_QtHelp_70(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, ::QAbstractItemView::ScrollHint a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NF", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, sipType_QAbstractItemView_ScrollHint);
}

::QRect sipVH_QtHelp_69(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::QRect sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRect, &sipRes);

    return sipRes;
}

void sipVH_QtHelp_68(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);
}

void sipVH_QtHelp_67(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QItemSelectionModel*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QItemSelectionModel, SIP_NULLPTR);
}

void sipVH_QtHelp_66(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAbstractItemModel*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QAbstractItemModel, SIP_NULLPTR);
}

void sipVH_QtHelp_65(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QStyleOptionFrame*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QStyleOptionFrame, SIP_NULLPTR);
}

int sipVH_QtHelp_64(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintDevice::PaintDeviceMetric a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QPaintDevice_PaintDeviceMetric);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QPaintEngine* sipVH_QtHelp_63(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPaintEngine* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPaintEngine, &sipRes);

    return sipRes;
}

int sipVH_QtHelp_62(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtHelp_61(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "b", a0);
}

int sipVH_QtHelp_60(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtHelp_59(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMouseEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_58(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWheelEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_57(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QKeyEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QKeyEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_56(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QFocusEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QFocusEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_55(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEnterEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEnterEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_54(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPaintEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_53(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMoveEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_52(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QResizeEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_51(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCloseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QCloseEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_50(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QContextMenuEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QContextMenuEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_49(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTabletEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTabletEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_48(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QActionEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QActionEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_47(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragEnterEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragEnterEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_46(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragMoveEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_45(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragLeaveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragLeaveEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_44(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDropEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDropEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_43(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QShowEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QShowEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_42(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QHideEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QHideEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_41(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QInputMethodEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QInputMethodEvent, SIP_NULLPTR);
}

::QVariant sipVH_QtHelp_40(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::Qt::InputMethodQuery a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_Qt_InputMethodQuery);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtHelp_39(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "b", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtHelp_38(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NV", new ::QByteArray(a0), sipType_QByteArray, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(bH4)", &sipRes, sipType_qintptr, a2);

    return sipRes;
}

::QPainter* sipVH_QtHelp_37(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPainter* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPainter, &sipRes);

    return sipRes;
}

void sipVH_QtHelp_36(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPainter, SIP_NULLPTR);
}

::QSize sipVH_QtHelp_35(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

void sipVH_QtHelp_34(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "ii", a0, a1);
}

void sipVH_QtHelp_33(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWidget, SIP_NULLPTR);
}

void sipVH_QtHelp_32(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QStyleOptionViewItem& a1, const ::QModelIndex& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DDN", a0, sipType_QPainter, SIP_NULLPTR, const_cast< ::QStyleOptionViewItem *>(&a1), sipType_QStyleOptionViewItem, SIP_NULLPTR, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);
}

void sipVH_QtHelp_31(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QRect& a1, const ::QModelIndex& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DNN", a0, sipType_QPainter, SIP_NULLPTR, new ::QRect(a1), sipType_QRect, SIP_NULLPTR, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);
}

void sipVH_QtHelp_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

void sipVH_QtHelp_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtHelp_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

bool sipVH_QtHelp_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtHelp_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QModelIndex sipVH_QtHelp_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1, const ::QModelIndex& a2)
{
    ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iiN", a0, a1, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

int sipVH_QtHelp_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtHelp_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "Ni", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtHelp_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, const ::QVariant& a1, int a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NNi", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR, a2);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtHelp_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::Orientation a1, int a2)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iFi", a0, a1, sipType_Qt_Orientation, a2);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtHelp_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::Orientation a1, const ::QVariant& a2, int a3)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iFNi", a0, a1, sipType_Qt_Orientation, new ::QVariant(a2), sipType_QVariant, SIP_NULLPTR, a3);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

QMap<int, ::QVariant> sipVH_QtHelp_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    QMap<int, ::QVariant> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QMap_1800_0100QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtHelp_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, const QMap<int, ::QVariant>& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new QMap<int, ::QVariant>(a1), sipType_QMap_1800_0100QVariant, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QStringList sipVH_QtHelp_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QStringList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QStringList, &sipRes);

    return sipRes;
}

::QMimeData* sipVH_QtHelp_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndexList& a0)
{
    ::QMimeData* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndexList(a0), sipType_QList_0100QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QMimeData, &sipRes);

    return sipRes;
}

bool sipVH_QtHelp_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1, const ::QModelIndex& a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iiN", a0, a1, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtHelp_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);
}

::Qt::ItemFlags sipVH_QtHelp_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::Qt::ItemFlags sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QFlags_0100Qt_ItemFlag, &sipRes);

    return sipRes;
}

void sipVH_QtHelp_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::SortOrder a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iF", a0, a1, sipType_Qt_SortOrder);
}

::QModelIndex sipVH_QtHelp_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

::QModelIndexList sipVH_QtHelp_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1, const ::QVariant& a2, int a3, ::Qt::MatchFlags a4)
{
    ::QModelIndexList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NiNiN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, new ::QVariant(a2), sipType_QVariant, SIP_NULLPTR, a3, new ::Qt::MatchFlags(a4), sipType_QFlags_0100Qt_MatchFlag, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QModelIndex, &sipRes);

    return sipRes;
}

::QSize sipVH_QtHelp_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

bool sipVH_QtHelp_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::Qt::DropActions sipVH_QtHelp_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::Qt::DropActions sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QFlags_0100Qt_DropAction, &sipRes);

    return sipRes;
}

QHash<int, ::QByteArray> sipVH_QtHelp_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    QHash<int, ::QByteArray> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QHash_1800_0100QByteArray, &sipRes);

    return sipRes;
}

void sipVH_QtHelp_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

bool sipVH_QtHelp_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DFiiN", const_cast< ::QMimeData *>(a0), sipType_QMimeData, SIP_NULLPTR, a1, sipType_Qt_DropAction, a2, a3, new ::QModelIndex(a4), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtHelp_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1, int a2, const ::QModelIndex& a3, int a4)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NiiNi", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, a2, new ::QModelIndex(a3), sipType_QModelIndex, SIP_NULLPTR, a4);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtHelp_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtHelp_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, ::QModelRoleDataSpan a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new ::QModelRoleDataSpan(a1), sipType_QModelRoleDataSpan, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QHelpEngineCore(void **);}
static const sipTypeDef *sipSubClass_QHelpEngineCore(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpenginecore.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QHelpContentModel, &sipType_QHelpContentModel, -1, 1},
        {sipName_QHelpContentWidget, &sipType_QHelpContentWidget, -1, 2},
        {sipName_QHelpEngineCore, &sipType_QHelpEngineCore, 11, 3},
        {sipName_QHelpFilterEngine, &sipType_QHelpFilterEngine, -1, 4},
        {sipName_QHelpFilterSettingsWidget, &sipType_QHelpFilterSettingsWidget, -1, 5},
        {sipName_QHelpIndexModel, &sipType_QHelpIndexModel, -1, 6},
        {sipName_QHelpIndexWidget, &sipType_QHelpIndexWidget, -1, 7},
        {sipName_QHelpSearchEngine, &sipType_QHelpSearchEngine, -1, 8},
    #if QT_VERSION >= 0x060800
        {sipName_QHelpSearchEngineCore, &sipType_QHelpSearchEngineCore, -1, 9},
    #else
        {0, 0, -1, 9},
    #endif
        {sipName_QHelpSearchQueryWidget, &sipType_QHelpSearchQueryWidget, -1, 10},
        {sipName_QHelpSearchResultWidget, &sipType_QHelpSearchResultWidget, -1, -1},
        {sipName_QHelpEngine, &sipType_QHelpEngine, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 1183 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpcmodule.cpp"

    return sipType;
}
static sipEnumTypeDef enumTypes[] = {
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QHelpSearchQuery__FieldName, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_FieldName, 14, 6, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtHelp[] = {
    &sipTypeDef_QtHelp_QCompressedHelpInfo.ctd_base,
    &sipTypeDef_QtHelp_QHelpContentItem.ctd_base,
    &sipTypeDef_QtHelp_QHelpContentModel.ctd_base,
    &sipTypeDef_QtHelp_QHelpContentWidget.ctd_base,
    &sipTypeDef_QtHelp_QHelpEngine.ctd_base,
    &sipTypeDef_QtHelp_QHelpEngineCore.ctd_base,
    &sipTypeDef_QtHelp_QHelpFilterData.ctd_base,
    &sipTypeDef_QtHelp_QHelpFilterEngine.ctd_base,
    &sipTypeDef_QtHelp_QHelpFilterSettingsWidget.ctd_base,
    &sipTypeDef_QtHelp_QHelpIndexModel.ctd_base,
    &sipTypeDef_QtHelp_QHelpIndexWidget.ctd_base,
    &sipTypeDef_QtHelp_QHelpLink.ctd_base,
    &sipTypeDef_QtHelp_QHelpSearchEngine.ctd_base,
    &sipTypeDef_QtHelp_QHelpSearchEngineCore.ctd_base,
    &sipTypeDef_QtHelp_QHelpSearchQuery.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtHelp_QHelpSearchQueryWidget.ctd_base,
    &sipTypeDef_QtHelp_QHelpSearchResult.ctd_base,
    &sipTypeDef_QtHelp_QHelpSearchResultWidget.ctd_base,
    &sipTypeDef_QtHelp_QList_0100QHelpLink.mtd_base,
    &sipTypeDef_QtHelp_QList_0100QHelpSearchResult.mtd_base,
    &sipTypeDef_QtHelp_QList_0100QVersionNumber.mtd_base,
    &sipTypeDef_QtHelp_QMap_0100QString_0100QString.mtd_base,
    &sipTypeDef_QtHelp_QMap_0100QString_0100QVersionNumber.mtd_base,
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtHelp_QtCore[] = {
    {"QAbstractItemModel"},
    {"QAbstractListModel"},
    {"QByteArray"},
    {"QChildEvent"},
    {"QEvent"},
    {"QFlags<QItemSelectionModel::SelectionFlag>"},
    {"QFlags<Qt::DropAction>"},
    {"QFlags<Qt::ItemFlag>"},
    {"QFlags<Qt::KeyboardModifier>"},
    {"QFlags<Qt::MatchFlag>"},
    {"QHash<int,QByteArray>"},
    {"QItemSelection"},
    {"QItemSelectionModel"},
    {"QList<QModelIndex>"},
    {"QList<QUrl>"},
    {"QList<int>"},
    {"QMap<int,QVariant>"},
    {"QMetaMethod"},
    {"QMimeData"},
    {"QModelIndex"},
    {"QModelRoleDataSpan"},
    {"QObject"},
    {"QPoint"},
    {"QRect"},
    {"QSize"},
    {"QString"},
    {"QStringList"},
    {"QStringListModel"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {"QVersionNumber"},
    {"Qt::DropAction"},
    {"Qt::InputMethodQuery"},
    {"Qt::Orientation"},
    {"Qt::SortOrder"},
    {"qintptr"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtHelp_QtCore[] = {
    {"PyQt6"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_QtHelp_QtGui[] = {
    {"QActionEvent"},
    {"QCloseEvent"},
    {"QContextMenuEvent"},
    {"QDragEnterEvent"},
    {"QDragLeaveEvent"},
    {"QDragMoveEvent"},
    {"QDropEvent"},
    {"QEnterEvent"},
    {"QFocusEvent"},
    {"QHideEvent"},
    {"QInputMethodEvent"},
    {"QKeyEvent"},
    {"QMouseEvent"},
    {"QMoveEvent"},
    {"QPaintDevice"},
    {"QPaintDevice::PaintDeviceMetric"},
    {"QPaintEngine"},
    {"QPaintEvent"},
    {"QPainter"},
    {"QRegion"},
    {"QResizeEvent"},
    {"QShowEvent"},
    {"QTabletEvent"},
    {"QWheelEvent"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtWidgets. */
sipImportedTypeDef sipImportedTypes_QtHelp_QtWidgets[] = {
    {"QAbstractItemDelegate"},
    {"QAbstractItemDelegate::EndEditHint"},
    {"QAbstractItemView"},
    {"QAbstractItemView::CursorAction"},
    {"QAbstractItemView::EditTrigger"},
    {"QAbstractItemView::ScrollHint"},
    {"QAbstractScrollArea"},
    {"QFrame"},
    {"QListView"},
    {"QStyleOptionFrame"},
    {"QStyleOptionViewItem"},
    {"QTreeView"},
    {"QWidget"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt6.QtCore", sipImportedTypes_QtHelp_QtCore, sipImportedVirtErrorHandlers_QtHelp_QtCore, SIP_NULLPTR},
    {"PyQt6.QtGui", sipImportedTypes_QtHelp_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt6.QtWidgets", sipImportedTypes_QtHelp_QtWidgets, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QHelpEngineCore, {21, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtHelp = {
    SIP_NULLPTR,
    8,
    sipNameNr_PyQt6_QtHelp,
    0,
    sipStrings_QtHelp,
    importsTable,
    24,
    sipExportedTypes_QtHelp,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtHelp;

sip_qt_metaobject_func sip_QtHelp_qt_metaobject;
sip_qt_metacall_func sip_QtHelp_qt_metacall;
sip_qt_metacast_func sip_QtHelp_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtHelp()
#else
PyMODINIT_FUNC PyInit_QtHelp()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt6.QtHelp",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt6.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt6.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtHelp = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt6.sip._C_API"));

    if (sipAPI_QtHelp == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtHelp, 13, 8, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtHelp_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtHelp_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtHelp_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtHelp_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtHelp, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }
    qMetaTypeId<::QHelpSearchQuery::FieldName>();

    return sipModule;
}
