/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFlags0100QDirFilter.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdir.sip"
#include <qdir.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFlags0100QDirFilter.cpp"


extern "C" {static void assign_QFlags_0100QDir_Filter(void *, Py_ssize_t, void *);}
static void assign_QFlags_0100QDir_Filter(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast<QFlags< ::QDir::Filter> *>(sipDst)[sipDstIdx] = *reinterpret_cast<QFlags< ::QDir::Filter> *>(sipSrc);
}


extern "C" {static void *array_QFlags_0100QDir_Filter(Py_ssize_t);}
static void *array_QFlags_0100QDir_Filter(Py_ssize_t sipNrElem)
{
    return new QFlags< ::QDir::Filter>[sipNrElem];
}


extern "C" {static void *copy_QFlags_0100QDir_Filter(const void *, Py_ssize_t);}
static void *copy_QFlags_0100QDir_Filter(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new QFlags< ::QDir::Filter>(reinterpret_cast<const QFlags< ::QDir::Filter> *>(sipSrc)[sipSrcIdx]);
}


/* Call the mapped type's destructor. */
extern "C" {static void release_QFlags_0100QDir_Filter(void *, int, void *);}
static void release_QFlags_0100QDir_Filter(void *sipCppV, int, void *)
{
    QFlags< ::QDir::Filter> *sipCpp = reinterpret_cast<QFlags< ::QDir::Filter> *>(sipCppV);
    delete sipCpp;
}



extern "C" {static int convertTo_QFlags_0100QDir_Filter(PyObject *, void **, int *, PyObject *, void **);}
static int convertTo_QFlags_0100QDir_Filter(PyObject *sipPy, void **sipCppPtrV, int *sipIsErr, PyObject *sipTransferObj, void **)
{
    QFlags< ::QDir::Filter> **sipCppPtr = reinterpret_cast<QFlags< ::QDir::Filter> **>(sipCppPtrV);

#line 29 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
bool is_enm = true;
unsigned enm = (unsigned)sipConvertToEnum(sipPy, sipType_QDir_Filter);

if (PyErr_Occurred())
{
    PyErr_Clear();
    is_enm = false;
}

if (sipIsErr == NULL)
    return is_enm;

*sipCppPtr = new QFlags<QDir::Filter>(static_cast<QDir::Filter>(enm));

return sipGetState(sipTransferObj);
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFlags0100QDirFilter.cpp"
}


extern "C" {static PyObject *convertFrom_QFlags_0100QDir_Filter(void *, PyObject *);}
static PyObject *convertFrom_QFlags_0100QDir_Filter(void *sipCppV, PyObject *)
{
    QFlags< ::QDir::Filter> *sipCpp = reinterpret_cast<QFlags< ::QDir::Filter> *>(sipCppV);

#line 47 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
return sipConvertFromEnum(sipCpp->operator::QFlags<QDir::Filter>::Int(), sipType_QDir_Filter);
#line 99 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFlags0100QDirFilter.cpp"
}


static pyqt6MappedTypePluginDef plugin_QFlags_0100QDir_Filter = {1};


sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QDir_Filter = {
    {
        SIP_NULLPTR,
        SIP_TYPE_MAPPED,
        sipNameNr_16737,
        SIP_NULLPTR,
        &plugin_QFlags_0100QDir_Filter,
    },
    {
        -1,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
    },
    assign_QFlags_0100QDir_Filter,
    array_QFlags_0100QDir_Filter,
    copy_QFlags_0100QDir_Filter,
    release_QFlags_0100QDir_Filter,
    convertTo_QFlags_0100QDir_Filter,
    convertFrom_QFlags_0100QDir_Filter
};
