/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 111 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 31 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQQuaternionAxis.cpp"

#line 81 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQQuaternionAxis.cpp"


PyDoc_STRVAR(doc_QQuaternion_Axis_fromVector3D, "fromVector3D(v: QVector3D) -> QQuaternion.Axis");

extern "C" {static PyObject *meth_QQuaternion_Axis_fromVector3D(PyObject *, PyObject *);}
static PyObject *meth_QQuaternion_Axis_fromVector3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVector3D* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ9", &sipSelf, sipType_QVector3D, &a0))
        {
            ::QQuaternion::Axis*sipRes;

            sipRes = new ::QQuaternion::Axis(::QQuaternion::Axis::fromVector3D(*a0));

            return sipConvertFromNewType(sipRes, sipType_QQuaternion_Axis, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Axis, sipName_fromVector3D, doc_QQuaternion_Axis_fromVector3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuaternion_Axis_toVector3D, "toVector3D(self) -> QVector3D");

extern "C" {static PyObject *meth_QQuaternion_Axis_toVector3D(PyObject *, PyObject *);}
static PyObject *meth_QQuaternion_Axis_toVector3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuaternion::Axis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuaternion_Axis, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->toVector3D());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Axis, sipName_toVector3D, doc_QQuaternion_Axis_toVector3D);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQuaternion_Axis(void *, int);}
static void release_QQuaternion_Axis(void *sipCppV, int)
{
    delete reinterpret_cast< ::QQuaternion::Axis *>(sipCppV);
}


extern "C" {static void *array_QQuaternion_Axis(Py_ssize_t);}
static void *array_QQuaternion_Axis(Py_ssize_t sipNrElem)
{
    return new ::QQuaternion::Axis[sipNrElem];
}


extern "C" {static void array_delete_QQuaternion_Axis(void *);}
static void array_delete_QQuaternion_Axis(void *sipCpp)
{
    delete[] reinterpret_cast< ::QQuaternion::Axis *>(sipCpp);
}


extern "C" {static void assign_QQuaternion_Axis(void *, Py_ssize_t, void *);}
static void assign_QQuaternion_Axis(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QQuaternion::Axis *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QQuaternion::Axis *>(sipSrc);
}


extern "C" {static void *copy_QQuaternion_Axis(const void *, Py_ssize_t);}
static void *copy_QQuaternion_Axis(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QQuaternion::Axis(reinterpret_cast<const ::QQuaternion::Axis *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QQuaternion_Axis(sipSimpleWrapper *);}
static void dealloc_QQuaternion_Axis(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuaternion_Axis(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QQuaternion_Axis(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuaternion_Axis(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QQuaternion::Axis *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QQuaternion::Axis();

            return sipCpp;
        }
    }

    {
        const ::QQuaternion::Axis* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QQuaternion_Axis, &a0))
        {
            sipCpp = new ::QQuaternion::Axis(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QQuaternion_Axis[] = {
    {sipName_fromVector3D, meth_QQuaternion_Axis_fromVector3D, METH_VARARGS, doc_QQuaternion_Axis_fromVector3D},
    {sipName_toVector3D, meth_QQuaternion_Axis_toVector3D, METH_VARARGS, doc_QQuaternion_Axis_toVector3D}
};


extern "C" {static PyObject *varget_QQuaternion_Axis_x(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuaternion_Axis_x(void *sipSelf, PyObject *, PyObject *)
{
    float sipVal;
    ::QQuaternion::Axis *sipCpp = reinterpret_cast< ::QQuaternion::Axis *>(sipSelf);

    sipVal = sipCpp->x;

    return PyFloat_FromDouble((double)sipVal);
}


extern "C" {static int varset_QQuaternion_Axis_x(void *, PyObject *, PyObject *);}
static int varset_QQuaternion_Axis_x(void *sipSelf, PyObject *sipPy, PyObject *)
{
    float sipVal;
    ::QQuaternion::Axis *sipCpp = reinterpret_cast< ::QQuaternion::Axis *>(sipSelf);

    sipVal = (float)PyFloat_AsDouble(sipPy);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->x = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QQuaternion_Axis_y(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuaternion_Axis_y(void *sipSelf, PyObject *, PyObject *)
{
    float sipVal;
    ::QQuaternion::Axis *sipCpp = reinterpret_cast< ::QQuaternion::Axis *>(sipSelf);

    sipVal = sipCpp->y;

    return PyFloat_FromDouble((double)sipVal);
}


extern "C" {static int varset_QQuaternion_Axis_y(void *, PyObject *, PyObject *);}
static int varset_QQuaternion_Axis_y(void *sipSelf, PyObject *sipPy, PyObject *)
{
    float sipVal;
    ::QQuaternion::Axis *sipCpp = reinterpret_cast< ::QQuaternion::Axis *>(sipSelf);

    sipVal = (float)PyFloat_AsDouble(sipPy);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->y = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QQuaternion_Axis_z(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuaternion_Axis_z(void *sipSelf, PyObject *, PyObject *)
{
    float sipVal;
    ::QQuaternion::Axis *sipCpp = reinterpret_cast< ::QQuaternion::Axis *>(sipSelf);

    sipVal = sipCpp->z;

    return PyFloat_FromDouble((double)sipVal);
}


extern "C" {static int varset_QQuaternion_Axis_z(void *, PyObject *, PyObject *);}
static int varset_QQuaternion_Axis_z(void *sipSelf, PyObject *sipPy, PyObject *)
{
    float sipVal;
    ::QQuaternion::Axis *sipCpp = reinterpret_cast< ::QQuaternion::Axis *>(sipSelf);

    sipVal = (float)PyFloat_AsDouble(sipPy);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->z = sipVal;

    return 0;
}

sipVariableDef variables_QQuaternion_Axis[] = {
    {InstanceVariable, sipName_x, (PyMethodDef *)varget_QQuaternion_Axis_x, (PyMethodDef *)varset_QQuaternion_Axis_x, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_y, (PyMethodDef *)varget_QQuaternion_Axis_y, (PyMethodDef *)varset_QQuaternion_Axis_y, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_z, (PyMethodDef *)varget_QQuaternion_Axis_z, (PyMethodDef *)varset_QQuaternion_Axis_z, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QQuaternion_Axis, "\1QQuaternion.Axis()\n"
"QQuaternion.Axis(a0: QQuaternion.Axis)");


sipClassTypeDef sipTypeDef_QtGui_QQuaternion_Axis = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuaternion__Axis,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_Axis,
        {251, 255, 0},
        2, methods_QQuaternion_Axis,
        3, variables_QQuaternion_Axis,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuaternion_Axis,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQuaternion_Axis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuaternion_Axis,
    assign_QQuaternion_Axis,
    array_QQuaternion_Axis,
    copy_QQuaternion_Axis,
    release_QQuaternion_Axis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QQuaternion_Axis,
    sizeof (::QQuaternion::Axis),
};
