/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 29 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslserver.sip"
#include <qsslserver.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslsocket.sip"
#include <qsslsocket.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslerror.sip"
#include <qsslerror.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qssl.sip"
#include <qssl.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslpresharedkeyauthenticator.sip"
#include <qsslpresharedkeyauthenticator.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslconfiguration.sip"
#include <qsslconfiguration.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qtcpsocket.sip"
#include <qtcpsocket.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qnetworkproxy.sip"
#include <qnetworkproxy.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qhostaddress.sip"
#include <qhostaddress.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 112 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 118 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSslServer.cpp"


class sipQSslServer : public ::QSslServer
{
public:
    sipQSslServer(::QObject*);
    virtual ~sipQSslServer();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool hasPendingConnections() const SIP_OVERRIDE;
    ::QTcpSocket* nextPendingConnection() SIP_OVERRIDE;
    void incomingConnection(::qintptr) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSslServer(const sipQSslServer &);
    sipQSslServer &operator = (const sipQSslServer &);

    char sipPyMethods[10];
};

sipQSslServer::sipQSslServer(::QObject*a0): ::QSslServer(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSslServer::~sipQSslServer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQSslServer::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtNetwork_qt_metaobject(sipPySelf, sipType_QSslServer);

    return ::QSslServer::metaObject();
}

int sipQSslServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QSslServer::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtNetwork_qt_metacall(sipPySelf, sipType_QSslServer, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQSslServer::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtNetwork_qt_metacast(sipPySelf, sipType_QSslServer, _clname, &sipCpp) ? sipCpp : ::QSslServer::qt_metacast(_clname));
}

void sipQSslServer::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QSslServer::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSslServer::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QSslServer::connectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSslServer::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QSslServer::customEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtNetwork_1(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSslServer::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QSslServer::childEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtNetwork_2(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSslServer::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QSslServer::timerEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtNetwork_3(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSslServer::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QSslServer::eventFilter(a0, a1);

    extern bool sipVH_QtNetwork_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtNetwork_4(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQSslServer::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QSslServer::event(a0);

    extern bool sipVH_QtNetwork_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtNetwork_5(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSslServer::hasPendingConnections() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasPendingConnections);

    if (!sipMeth)
        return ::QSslServer::hasPendingConnections();

    extern bool sipVH_QtNetwork_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_19(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QTcpSocket* sipQSslServer::nextPendingConnection()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_nextPendingConnection);

    if (!sipMeth)
        return ::QSslServer::nextPendingConnection();

    extern ::QTcpSocket* sipVH_QtNetwork_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_41(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSslServer::incomingConnection(::qintptr a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_incomingConnection);

    if (!sipMeth)
    {
        ::QSslServer::incomingConnection(a0);
        return;
    }

    extern void sipVH_QtNetwork_42(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qintptr);

    sipVH_QtNetwork_42(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSslServer_setSslConfiguration, "setSslConfiguration(self, sslConfiguration: QSslConfiguration)");

extern "C" {static PyObject *meth_QSslServer_setSslConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QSslServer_setSslConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSslConfiguration* a0;
        ::QSslServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSslServer, &sipCpp, sipType_QSslConfiguration, &a0))
        {
            sipCpp->setSslConfiguration(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslServer, sipName_setSslConfiguration, doc_QSslServer_setSslConfiguration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslServer_sslConfiguration, "sslConfiguration(self) -> QSslConfiguration");

extern "C" {static PyObject *meth_QSslServer_sslConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QSslServer_sslConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSslServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslServer, &sipCpp))
        {
            ::QSslConfiguration*sipRes;

            sipRes = new ::QSslConfiguration(sipCpp->sslConfiguration());

            return sipConvertFromNewType(sipRes, sipType_QSslConfiguration, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslServer, sipName_sslConfiguration, doc_QSslServer_sslConfiguration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslServer_setHandshakeTimeout, "setHandshakeTimeout(self, timeout: int)");

extern "C" {static PyObject *meth_QSslServer_setHandshakeTimeout(PyObject *, PyObject *);}
static PyObject *meth_QSslServer_setHandshakeTimeout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSslServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSslServer, &sipCpp, &a0))
        {
            sipCpp->setHandshakeTimeout(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslServer, sipName_setHandshakeTimeout, doc_QSslServer_setHandshakeTimeout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslServer_handshakeTimeout, "handshakeTimeout(self) -> int");

extern "C" {static PyObject *meth_QSslServer_handshakeTimeout(PyObject *, PyObject *);}
static PyObject *meth_QSslServer_handshakeTimeout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSslServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSslServer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->handshakeTimeout();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslServer, sipName_handshakeTimeout, doc_QSslServer_handshakeTimeout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSslServer_incomingConnection, "incomingConnection(self, socket: PyQt6.sip.voidptr)");

extern "C" {static PyObject *meth_QSslServer_incomingConnection(PyObject *, PyObject *);}
static PyObject *meth_QSslServer_incomingConnection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSslServer)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::qintptr* a0;
        int a0State = 0;
        ::QSslServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QSslServer, &sipCpp, sipType_qintptr, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QSslServer::incomingConnection(*a0) : sipCpp->incomingConnection(*a0));
            sipReleaseType(a0, sipType_qintptr, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSslServer, sipName_incomingConnection, doc_QSslServer_incomingConnection);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSslServer(void *, const sipTypeDef *);}
static void *cast_QSslServer(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSslServer *sipCpp = reinterpret_cast< ::QSslServer *>(sipCppV);

    if (targetType == sipType_QSslServer)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QTcpServer)->ctd_cast(static_cast< ::QTcpServer *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSslServer(void *, int);}
static void release_QSslServer(void *sipCppV, int)
{
    ::QSslServer *sipCpp = reinterpret_cast< ::QSslServer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QSslServer(Py_ssize_t);}
static void *array_QSslServer(Py_ssize_t sipNrElem)
{
    return new ::QSslServer[sipNrElem];
}


extern "C" {static void array_delete_QSslServer(void *);}
static void array_delete_QSslServer(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSslServer *>(sipCpp);
}


extern "C" {static void dealloc_QSslServer(sipSimpleWrapper *);}
static void dealloc_QSslServer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSslServer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSslServer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSslServer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSslServer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQSslServer *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQSslServer(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSslServer[] = {{153, 255, 1}};


static PyMethodDef methods_QSslServer[] = {
    {sipName_handshakeTimeout, meth_QSslServer_handshakeTimeout, METH_VARARGS, doc_QSslServer_handshakeTimeout},
    {sipName_incomingConnection, meth_QSslServer_incomingConnection, METH_VARARGS, doc_QSslServer_incomingConnection},
    {sipName_setHandshakeTimeout, meth_QSslServer_setHandshakeTimeout, METH_VARARGS, doc_QSslServer_setHandshakeTimeout},
    {sipName_setSslConfiguration, meth_QSslServer_setSslConfiguration, METH_VARARGS, doc_QSslServer_setSslConfiguration},
    {sipName_sslConfiguration, meth_QSslServer_sslConfiguration, METH_VARARGS, doc_QSslServer_sslConfiguration}
};

PyDoc_STRVAR(doc_QSslServer, "\1QSslServer(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QSslServer[] = {
    {"startedEncryptionHandshake(QSslSocket*)", "\1startedEncryptionHandshake(self, socket: QSslSocket|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"handshakeInterruptedOnError(QSslSocket*,QSslError)", "\1handshakeInterruptedOnError(self, socket: QSslSocket|None, error: QSslError)", SIP_NULLPTR, SIP_NULLPTR},
    {"alertReceived(QSslSocket*,QSsl::AlertLevel,QSsl::AlertType,QString)", "\1alertReceived(self, socket: QSslSocket|None, level: QSsl.AlertLevel, type: QSsl.AlertType, description: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"alertSent(QSslSocket*,QSsl::AlertLevel,QSsl::AlertType,QString)", "\1alertSent(self, socket: QSslSocket|None, level: QSsl.AlertLevel, type: QSsl.AlertType, description: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"preSharedKeyAuthenticationRequired(QSslSocket*,QSslPreSharedKeyAuthenticator*)", "\1preSharedKeyAuthenticationRequired(self, socket: QSslSocket|None, authenticator: QSslPreSharedKeyAuthenticator|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorOccurred(QSslSocket*,QAbstractSocket::SocketError)", "\1errorOccurred(self, socket: QSslSocket|None, error: QAbstractSocket.SocketError)", SIP_NULLPTR, SIP_NULLPTR},
    {"peerVerifyError(QSslSocket*,QSslError)", "\1peerVerifyError(self, socket: QSslSocket|None, error: QSslError)", SIP_NULLPTR, SIP_NULLPTR},
    {"sslErrors(QSslSocket*,QList<QSslError>)", "\1sslErrors(self, socket: QSslSocket|None, errors: Iterable[QSslError])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QSslServer = {
    &::QSslServer::staticMetaObject,
    signals_QSslServer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QSslServer = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSslServer,
        SIP_NULLPTR,
        &plugin_QSslServer,
    },
    {
        sipNameNr_QSslServer,
        {0, 0, 1},
        5, methods_QSslServer,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSslServer,
    -1,
    -1,
    supers_QSslServer,
    SIP_NULLPTR,
    init_type_QSslServer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSslServer,
    SIP_NULLPTR,
    array_QSslServer,
    SIP_NULLPTR,
    release_QSslServer,
    cast_QSslServer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSslServer,
    sizeof (::QSslServer),
};
