/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qnmeapositioninfosource.sip"
#include <qnmeapositioninfosource.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeopositioninfo.sip"
#include <qgeopositioninfo.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeopositioninfosource.sip"
#include <qgeopositioninfosource.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 27 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaPositionInfoSource.cpp"


class sipQNmeaPositionInfoSource : public ::QNmeaPositionInfoSource
{
public:
    sipQNmeaPositionInfoSource(::QNmeaPositionInfoSource::UpdateMode, ::QObject*);
    virtual ~sipQNmeaPositionInfoSource();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool parsePosInfoFromNmeaData(const char*, int, ::QGeoPositionInfo*, bool*) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void setUpdateInterval(int) SIP_OVERRIDE;
    void setPreferredPositioningMethods(::QGeoPositionInfoSource::PositioningMethods) SIP_OVERRIDE;
    ::QGeoPositionInfo lastKnownPosition(bool) const SIP_OVERRIDE;
    ::QGeoPositionInfoSource::PositioningMethods supportedPositioningMethods() const SIP_OVERRIDE;
    int minimumUpdateInterval() const SIP_OVERRIDE;
    ::QGeoPositionInfoSource::Error error() const SIP_OVERRIDE;
    void startUpdates() SIP_OVERRIDE;
    void stopUpdates() SIP_OVERRIDE;
    void requestUpdate(int) SIP_OVERRIDE;
    bool setBackendProperty(const ::QString&, const ::QVariant&) SIP_OVERRIDE;
    ::QVariant backendProperty(const ::QString&) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQNmeaPositionInfoSource(const sipQNmeaPositionInfoSource &);
    sipQNmeaPositionInfoSource &operator = (const sipQNmeaPositionInfoSource &);

    char sipPyMethods[19];
};

sipQNmeaPositionInfoSource::sipQNmeaPositionInfoSource(::QNmeaPositionInfoSource::UpdateMode a0, ::QObject*a1): ::QNmeaPositionInfoSource(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQNmeaPositionInfoSource::~sipQNmeaPositionInfoSource()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQNmeaPositionInfoSource::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtPositioning_qt_metaobject(sipPySelf, sipType_QNmeaPositionInfoSource);

    return ::QNmeaPositionInfoSource::metaObject();
}

int sipQNmeaPositionInfoSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QNmeaPositionInfoSource::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtPositioning_qt_metacall(sipPySelf, sipType_QNmeaPositionInfoSource, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQNmeaPositionInfoSource::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtPositioning_qt_metacast(sipPySelf, sipType_QNmeaPositionInfoSource, _clname, &sipCpp) ? sipCpp : ::QNmeaPositionInfoSource::qt_metacast(_clname));
}

bool sipQNmeaPositionInfoSource::parsePosInfoFromNmeaData(const char*a0, int a1, ::QGeoPositionInfo*a2, bool*a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_parsePosInfoFromNmeaData);

    if (!sipMeth)
        return ::QNmeaPositionInfoSource::parsePosInfoFromNmeaData(a0, a1, a2, a3);

    extern bool sipVH_QtPositioning_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const char*, int, ::QGeoPositionInfo*, bool*);

    return sipVH_QtPositioning_24(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQNmeaPositionInfoSource::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QNmeaPositionInfoSource::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtPositioning_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPositioning_0(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNmeaPositionInfoSource::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QNmeaPositionInfoSource::connectNotify(a0);
        return;
    }

    extern void sipVH_QtPositioning_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPositioning_0(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNmeaPositionInfoSource::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QNmeaPositionInfoSource::customEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPositioning_1(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNmeaPositionInfoSource::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QNmeaPositionInfoSource::childEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtPositioning_2(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNmeaPositionInfoSource::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QNmeaPositionInfoSource::timerEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtPositioning_3(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQNmeaPositionInfoSource::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QNmeaPositionInfoSource::eventFilter(a0, a1);

    extern bool sipVH_QtPositioning_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtPositioning_4(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQNmeaPositionInfoSource::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QNmeaPositionInfoSource::event(a0);

    extern bool sipVH_QtPositioning_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtPositioning_5(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNmeaPositionInfoSource::setUpdateInterval(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_setUpdateInterval);

    if (!sipMeth)
    {
        ::QNmeaPositionInfoSource::setUpdateInterval(a0);
        return;
    }

    extern void sipVH_QtPositioning_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtPositioning_16(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNmeaPositionInfoSource::setPreferredPositioningMethods(::QGeoPositionInfoSource::PositioningMethods a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_setPreferredPositioningMethods);

    if (!sipMeth)
    {
        ::QNmeaPositionInfoSource::setPreferredPositioningMethods(a0);
        return;
    }

    extern void sipVH_QtPositioning_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGeoPositionInfoSource::PositioningMethods);

    sipVH_QtPositioning_17(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QGeoPositionInfo sipQNmeaPositionInfoSource::lastKnownPosition(bool a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_lastKnownPosition);

    if (!sipMeth)
        return ::QNmeaPositionInfoSource::lastKnownPosition(a0);

    extern ::QGeoPositionInfo sipVH_QtPositioning_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtPositioning_18(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QGeoPositionInfoSource::PositioningMethods sipQNmeaPositionInfoSource::supportedPositioningMethods() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportedPositioningMethods);

    if (!sipMeth)
        return ::QNmeaPositionInfoSource::supportedPositioningMethods();

    extern ::QGeoPositionInfoSource::PositioningMethods sipVH_QtPositioning_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPositioning_19(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQNmeaPositionInfoSource::minimumUpdateInterval() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumUpdateInterval);

    if (!sipMeth)
        return ::QNmeaPositionInfoSource::minimumUpdateInterval();

    extern int sipVH_QtPositioning_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPositioning_20(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QGeoPositionInfoSource::Error sipQNmeaPositionInfoSource::error() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_error);

    if (!sipMeth)
        return ::QNmeaPositionInfoSource::error();

    extern ::QGeoPositionInfoSource::Error sipVH_QtPositioning_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPositioning_21(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQNmeaPositionInfoSource::startUpdates()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_startUpdates);

    if (!sipMeth)
    {
        ::QNmeaPositionInfoSource::startUpdates();
        return;
    }

    extern void sipVH_QtPositioning_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtPositioning_22(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQNmeaPositionInfoSource::stopUpdates()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_stopUpdates);

    if (!sipMeth)
    {
        ::QNmeaPositionInfoSource::stopUpdates();
        return;
    }

    extern void sipVH_QtPositioning_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtPositioning_22(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQNmeaPositionInfoSource::requestUpdate(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_requestUpdate);

    if (!sipMeth)
    {
        ::QNmeaPositionInfoSource::requestUpdate(a0);
        return;
    }

    extern void sipVH_QtPositioning_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtPositioning_16(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQNmeaPositionInfoSource::setBackendProperty(const ::QString& a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_setBackendProperty);

    if (!sipMeth)
        return ::QNmeaPositionInfoSource::setBackendProperty(a0, a1);

    extern bool sipVH_QtPositioning_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, const ::QVariant&);

    return sipVH_QtPositioning_14(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QVariant sipQNmeaPositionInfoSource::backendProperty(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[18]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_backendProperty);

    if (!sipMeth)
        return ::QNmeaPositionInfoSource::backendProperty(a0);

    extern ::QVariant sipVH_QtPositioning_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtPositioning_15(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_updateMode, "updateMode(self) -> QNmeaPositionInfoSource.UpdateMode");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_updateMode(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_updateMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp))
        {
            ::QNmeaPositionInfoSource::UpdateMode sipRes;

            sipRes = sipCpp->updateMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QNmeaPositionInfoSource_UpdateMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_updateMode, doc_QNmeaPositionInfoSource_updateMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_setDevice, "setDevice(self, source: QIODevice|None)");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_setDevice(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_setDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp, sipType_QIODevice, &a0))
        {
            sipCpp->setDevice(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_setDevice, doc_QNmeaPositionInfoSource_setDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_device, "device(self) -> QIODevice|None");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_device(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_device(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp))
        {
            ::QIODevice*sipRes;

            sipRes = sipCpp->device();

            return sipConvertFromType(sipRes, sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_device, doc_QNmeaPositionInfoSource_device);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_setUpdateInterval, "setUpdateInterval(self, msec: int)");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_setUpdateInterval(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_setUpdateInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaPositionInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QNmeaPositionInfoSource::setUpdateInterval(a0) : sipCpp->setUpdateInterval(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_setUpdateInterval, doc_QNmeaPositionInfoSource_setUpdateInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_lastKnownPosition, "lastKnownPosition(self, fromSatellitePositioningMethodsOnly: bool = False) -> QGeoPositionInfo");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_lastKnownPosition(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_lastKnownPosition(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaPositionInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0 = 0;
        const ::QNmeaPositionInfoSource *sipCpp;

        static const char *sipKwdList[] = {
            sipName_fromSatellitePositioningMethodsOnly,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp, &a0))
        {
            ::QGeoPositionInfo*sipRes;

            sipRes = new ::QGeoPositionInfo((sipSelfWasArg ? sipCpp->::QNmeaPositionInfoSource::lastKnownPosition(a0) : sipCpp->lastKnownPosition(a0)));

            return sipConvertFromNewType(sipRes, sipType_QGeoPositionInfo, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_lastKnownPosition, doc_QNmeaPositionInfoSource_lastKnownPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_supportedPositioningMethods, "supportedPositioningMethods(self) -> QGeoPositionInfoSource.PositioningMethod");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_supportedPositioningMethods(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_supportedPositioningMethods(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaPositionInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp))
        {
            ::QGeoPositionInfoSource::PositioningMethods*sipRes;

            sipRes = new ::QGeoPositionInfoSource::PositioningMethods((sipSelfWasArg ? sipCpp->::QNmeaPositionInfoSource::supportedPositioningMethods() : sipCpp->supportedPositioningMethods()));

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QGeoPositionInfoSource_PositioningMethod, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_supportedPositioningMethods, doc_QNmeaPositionInfoSource_supportedPositioningMethods);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_minimumUpdateInterval, "minimumUpdateInterval(self) -> int");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_minimumUpdateInterval(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_minimumUpdateInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaPositionInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QNmeaPositionInfoSource::minimumUpdateInterval() : sipCpp->minimumUpdateInterval());

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_minimumUpdateInterval, doc_QNmeaPositionInfoSource_minimumUpdateInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_error, "error(self) -> QGeoPositionInfoSource.Error");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_error(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaPositionInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp))
        {
            ::QGeoPositionInfoSource::Error sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QNmeaPositionInfoSource::error() : sipCpp->error());

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoPositionInfoSource_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_error, doc_QNmeaPositionInfoSource_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_startUpdates, "startUpdates(self)");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_startUpdates(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_startUpdates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaPositionInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QNmeaPositionInfoSource::startUpdates() : sipCpp->startUpdates());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_startUpdates, doc_QNmeaPositionInfoSource_startUpdates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_stopUpdates, "stopUpdates(self)");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_stopUpdates(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_stopUpdates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaPositionInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QNmeaPositionInfoSource::stopUpdates() : sipCpp->stopUpdates());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_stopUpdates, doc_QNmeaPositionInfoSource_stopUpdates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_requestUpdate, "requestUpdate(self, timeout: int = 0)");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_requestUpdate(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_requestUpdate(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaPositionInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0 = 0;
        ::QNmeaPositionInfoSource *sipCpp;

        static const char *sipKwdList[] = {
            sipName_timeout,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QNmeaPositionInfoSource::requestUpdate(a0) : sipCpp->requestUpdate(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_requestUpdate, doc_QNmeaPositionInfoSource_requestUpdate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_parsePosInfoFromNmeaData, "parsePosInfoFromNmeaData(self, data: bytes, size: int, posInfo: QGeoPositionInfo|None) -> (bool, bool)");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_parsePosInfoFromNmeaData(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_parsePosInfoFromNmeaData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaPositionInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const char* a0;
        int a1;
        ::QGeoPositionInfo* a2;
        bool a3;
        ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "psiJ8", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp, &a0, &a1, sipType_QGeoPositionInfo, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QNmeaPositionInfoSource::parsePosInfoFromNmeaData(a0, a1, a2, &a3) : sipCpp->parsePosInfoFromNmeaData(a0, a1, a2, &a3));

            return sipBuildResult(0, "(bb)", sipRes, a3);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_parsePosInfoFromNmeaData, doc_QNmeaPositionInfoSource_parsePosInfoFromNmeaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_setUserEquivalentRangeError, "setUserEquivalentRangeError(self, uere: float)");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_setUserEquivalentRangeError(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_setUserEquivalentRangeError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp, &a0))
        {
            sipCpp->setUserEquivalentRangeError(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_setUserEquivalentRangeError, doc_QNmeaPositionInfoSource_setUserEquivalentRangeError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaPositionInfoSource_userEquivalentRangeError, "userEquivalentRangeError(self) -> float");

extern "C" {static PyObject *meth_QNmeaPositionInfoSource_userEquivalentRangeError(PyObject *, PyObject *);}
static PyObject *meth_QNmeaPositionInfoSource_userEquivalentRangeError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNmeaPositionInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaPositionInfoSource, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->userEquivalentRangeError();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaPositionInfoSource, sipName_userEquivalentRangeError, doc_QNmeaPositionInfoSource_userEquivalentRangeError);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QNmeaPositionInfoSource(void *, const sipTypeDef *);}
static void *cast_QNmeaPositionInfoSource(void *sipCppV, const sipTypeDef *targetType)
{
    ::QNmeaPositionInfoSource *sipCpp = reinterpret_cast< ::QNmeaPositionInfoSource *>(sipCppV);

    if (targetType == sipType_QNmeaPositionInfoSource)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGeoPositionInfoSource)->ctd_cast(static_cast< ::QGeoPositionInfoSource *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNmeaPositionInfoSource(void *, int);}
static void release_QNmeaPositionInfoSource(void *sipCppV, int)
{
    ::QNmeaPositionInfoSource *sipCpp = reinterpret_cast< ::QNmeaPositionInfoSource *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QNmeaPositionInfoSource(sipSimpleWrapper *);}
static void dealloc_QNmeaPositionInfoSource(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQNmeaPositionInfoSource *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNmeaPositionInfoSource(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QNmeaPositionInfoSource(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QNmeaPositionInfoSource(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQNmeaPositionInfoSource *sipCpp = SIP_NULLPTR;

    {
        ::QNmeaPositionInfoSource::UpdateMode a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|JH", sipType_QNmeaPositionInfoSource_UpdateMode, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQNmeaPositionInfoSource(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QNmeaPositionInfoSource[] = {{16, 255, 1}};


static PyMethodDef methods_QNmeaPositionInfoSource[] = {
    {sipName_device, meth_QNmeaPositionInfoSource_device, METH_VARARGS, doc_QNmeaPositionInfoSource_device},
    {sipName_error, meth_QNmeaPositionInfoSource_error, METH_VARARGS, doc_QNmeaPositionInfoSource_error},
    {sipName_lastKnownPosition, SIP_MLMETH_CAST(meth_QNmeaPositionInfoSource_lastKnownPosition), METH_VARARGS|METH_KEYWORDS, doc_QNmeaPositionInfoSource_lastKnownPosition},
    {sipName_minimumUpdateInterval, meth_QNmeaPositionInfoSource_minimumUpdateInterval, METH_VARARGS, doc_QNmeaPositionInfoSource_minimumUpdateInterval},
    {sipName_parsePosInfoFromNmeaData, meth_QNmeaPositionInfoSource_parsePosInfoFromNmeaData, METH_VARARGS, doc_QNmeaPositionInfoSource_parsePosInfoFromNmeaData},
    {sipName_requestUpdate, SIP_MLMETH_CAST(meth_QNmeaPositionInfoSource_requestUpdate), METH_VARARGS|METH_KEYWORDS, doc_QNmeaPositionInfoSource_requestUpdate},
    {sipName_setDevice, meth_QNmeaPositionInfoSource_setDevice, METH_VARARGS, doc_QNmeaPositionInfoSource_setDevice},
    {sipName_setUpdateInterval, meth_QNmeaPositionInfoSource_setUpdateInterval, METH_VARARGS, doc_QNmeaPositionInfoSource_setUpdateInterval},
    {sipName_setUserEquivalentRangeError, meth_QNmeaPositionInfoSource_setUserEquivalentRangeError, METH_VARARGS, doc_QNmeaPositionInfoSource_setUserEquivalentRangeError},
    {sipName_startUpdates, meth_QNmeaPositionInfoSource_startUpdates, METH_VARARGS, doc_QNmeaPositionInfoSource_startUpdates},
    {sipName_stopUpdates, meth_QNmeaPositionInfoSource_stopUpdates, METH_VARARGS, doc_QNmeaPositionInfoSource_stopUpdates},
    {sipName_supportedPositioningMethods, meth_QNmeaPositionInfoSource_supportedPositioningMethods, METH_VARARGS, doc_QNmeaPositionInfoSource_supportedPositioningMethods},
    {sipName_updateMode, meth_QNmeaPositionInfoSource_updateMode, METH_VARARGS, doc_QNmeaPositionInfoSource_updateMode},
    {sipName_userEquivalentRangeError, meth_QNmeaPositionInfoSource_userEquivalentRangeError, METH_VARARGS, doc_QNmeaPositionInfoSource_userEquivalentRangeError}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QNmeaPositionInfoSource[] = {
    {sipName_RealTimeMode, static_cast<int>(::QNmeaPositionInfoSource::RealTimeMode)},
    {sipName_SimulationMode, static_cast<int>(::QNmeaPositionInfoSource::SimulationMode)},
    {0, 0}
};

PyDoc_STRVAR(doc_QNmeaPositionInfoSource, "\1QNmeaPositionInfoSource(updateMode: QNmeaPositionInfoSource.UpdateMode, parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QNmeaPositionInfoSource = {
    &::QNmeaPositionInfoSource::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPositioning_QNmeaPositionInfoSource = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNmeaPositionInfoSource,
        SIP_NULLPTR,
        &plugin_QNmeaPositionInfoSource,
    },
    {
        sipNameNr_QNmeaPositionInfoSource,
        {0, 0, 1},
        14, methods_QNmeaPositionInfoSource,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QNmeaPositionInfoSource, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QNmeaPositionInfoSource,
    -1,
    -1,
    supers_QNmeaPositionInfoSource,
    SIP_NULLPTR,
    init_type_QNmeaPositionInfoSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QNmeaPositionInfoSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QNmeaPositionInfoSource,
    cast_QNmeaPositionInfoSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QNmeaPositionInfoSource),
};
