/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickgraphicsconfiguration.sip"
#include <qquickgraphicsconfiguration.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickGraphicsConfiguration.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickGraphicsConfiguration.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearraylist.sip"
#include <qstringlist.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickGraphicsConfiguration.cpp"


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_setDeviceExtensions, "setDeviceExtensions(self, extensions: Iterable[QByteArray|bytes|bytearray|memoryview])");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_setDeviceExtensions(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_setDeviceExtensions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArrayList* a0;
        int a0State = 0;
        ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp, sipType_QByteArrayList, &a0, &a0State))
        {
            sipCpp->setDeviceExtensions(*a0);
            sipReleaseType(const_cast< ::QByteArrayList *>(a0), sipType_QByteArrayList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_setDeviceExtensions, doc_QQuickGraphicsConfiguration_setDeviceExtensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_deviceExtensions, "deviceExtensions(self) -> list[QByteArray]");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_deviceExtensions(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_deviceExtensions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp))
        {
            ::QByteArrayList*sipRes;

            sipRes = new ::QByteArrayList(sipCpp->deviceExtensions());

            return sipConvertFromNewType(sipRes, sipType_QByteArrayList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_deviceExtensions, doc_QQuickGraphicsConfiguration_deviceExtensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_setDepthBufferFor2D, "setDepthBufferFor2D(self, enable: bool)");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_setDepthBufferFor2D(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_setDepthBufferFor2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp, &a0))
        {
            sipCpp->setDepthBufferFor2D(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_setDepthBufferFor2D, doc_QQuickGraphicsConfiguration_setDepthBufferFor2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_isDepthBufferEnabledFor2D, "isDepthBufferEnabledFor2D(self) -> bool");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_isDepthBufferEnabledFor2D(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_isDepthBufferEnabledFor2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDepthBufferEnabledFor2D();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_isDepthBufferEnabledFor2D, doc_QQuickGraphicsConfiguration_isDepthBufferEnabledFor2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_preferredInstanceExtensions, "preferredInstanceExtensions() -> list[QByteArray]");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_preferredInstanceExtensions(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_preferredInstanceExtensions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QByteArrayList*sipRes;

            sipRes = new ::QByteArrayList(::QQuickGraphicsConfiguration::preferredInstanceExtensions());

            return sipConvertFromNewType(sipRes, sipType_QByteArrayList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_preferredInstanceExtensions, doc_QQuickGraphicsConfiguration_preferredInstanceExtensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_setDebugLayer, "setDebugLayer(self, enable: bool)");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_setDebugLayer(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_setDebugLayer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp, &a0))
        {
            sipCpp->setDebugLayer(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_setDebugLayer, doc_QQuickGraphicsConfiguration_setDebugLayer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_isDebugLayerEnabled, "isDebugLayerEnabled(self) -> bool");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_isDebugLayerEnabled(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_isDebugLayerEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDebugLayerEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_isDebugLayerEnabled, doc_QQuickGraphicsConfiguration_isDebugLayerEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_setDebugMarkers, "setDebugMarkers(self, enable: bool)");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_setDebugMarkers(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_setDebugMarkers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp, &a0))
        {
            sipCpp->setDebugMarkers(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_setDebugMarkers, doc_QQuickGraphicsConfiguration_setDebugMarkers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_isDebugMarkersEnabled, "isDebugMarkersEnabled(self) -> bool");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_isDebugMarkersEnabled(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_isDebugMarkersEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDebugMarkersEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_isDebugMarkersEnabled, doc_QQuickGraphicsConfiguration_isDebugMarkersEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_setPreferSoftwareDevice, "setPreferSoftwareDevice(self, enable: bool)");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_setPreferSoftwareDevice(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_setPreferSoftwareDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp, &a0))
        {
            sipCpp->setPreferSoftwareDevice(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_setPreferSoftwareDevice, doc_QQuickGraphicsConfiguration_setPreferSoftwareDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_prefersSoftwareDevice, "prefersSoftwareDevice(self) -> bool");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_prefersSoftwareDevice(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_prefersSoftwareDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->prefersSoftwareDevice();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_prefersSoftwareDevice, doc_QQuickGraphicsConfiguration_prefersSoftwareDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_setAutomaticPipelineCache, "setAutomaticPipelineCache(self, enable: bool)");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_setAutomaticPipelineCache(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_setAutomaticPipelineCache(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp, &a0))
        {
            sipCpp->setAutomaticPipelineCache(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_setAutomaticPipelineCache, doc_QQuickGraphicsConfiguration_setAutomaticPipelineCache);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_isAutomaticPipelineCacheEnabled, "isAutomaticPipelineCacheEnabled(self) -> bool");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_isAutomaticPipelineCacheEnabled(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_isAutomaticPipelineCacheEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAutomaticPipelineCacheEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_isAutomaticPipelineCacheEnabled, doc_QQuickGraphicsConfiguration_isAutomaticPipelineCacheEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_setPipelineCacheSaveFile, "setPipelineCacheSaveFile(self, filename: str|None)");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_setPipelineCacheSaveFile(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_setPipelineCacheSaveFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setPipelineCacheSaveFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_setPipelineCacheSaveFile, doc_QQuickGraphicsConfiguration_setPipelineCacheSaveFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_pipelineCacheSaveFile, "pipelineCacheSaveFile(self) -> str");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_pipelineCacheSaveFile(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_pipelineCacheSaveFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->pipelineCacheSaveFile());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_pipelineCacheSaveFile, doc_QQuickGraphicsConfiguration_pipelineCacheSaveFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_setPipelineCacheLoadFile, "setPipelineCacheLoadFile(self, filename: str|None)");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_setPipelineCacheLoadFile(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_setPipelineCacheLoadFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setPipelineCacheLoadFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_setPipelineCacheLoadFile, doc_QQuickGraphicsConfiguration_setPipelineCacheLoadFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_pipelineCacheLoadFile, "pipelineCacheLoadFile(self) -> str");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_pipelineCacheLoadFile(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_pipelineCacheLoadFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->pipelineCacheLoadFile());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_pipelineCacheLoadFile, doc_QQuickGraphicsConfiguration_pipelineCacheLoadFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_setTimestamps, "setTimestamps(self, enable: bool)");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_setTimestamps(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_setTimestamps(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp, &a0))
        {
            sipCpp->setTimestamps(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_setTimestamps, doc_QQuickGraphicsConfiguration_setTimestamps);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickGraphicsConfiguration_timestampsEnabled, "timestampsEnabled(self) -> bool");

extern "C" {static PyObject *meth_QQuickGraphicsConfiguration_timestampsEnabled(PyObject *, PyObject *);}
static PyObject *meth_QQuickGraphicsConfiguration_timestampsEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickGraphicsConfiguration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickGraphicsConfiguration, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->timestampsEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickGraphicsConfiguration, sipName_timestampsEnabled, doc_QQuickGraphicsConfiguration_timestampsEnabled);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQuickGraphicsConfiguration(void *, int);}
static void release_QQuickGraphicsConfiguration(void *sipCppV, int)
{
    delete reinterpret_cast< ::QQuickGraphicsConfiguration *>(sipCppV);
}


extern "C" {static void *array_QQuickGraphicsConfiguration(Py_ssize_t);}
static void *array_QQuickGraphicsConfiguration(Py_ssize_t sipNrElem)
{
    return new ::QQuickGraphicsConfiguration[sipNrElem];
}


extern "C" {static void array_delete_QQuickGraphicsConfiguration(void *);}
static void array_delete_QQuickGraphicsConfiguration(void *sipCpp)
{
    delete[] reinterpret_cast< ::QQuickGraphicsConfiguration *>(sipCpp);
}


extern "C" {static void assign_QQuickGraphicsConfiguration(void *, Py_ssize_t, void *);}
static void assign_QQuickGraphicsConfiguration(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QQuickGraphicsConfiguration *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QQuickGraphicsConfiguration *>(sipSrc);
}


extern "C" {static void *copy_QQuickGraphicsConfiguration(const void *, Py_ssize_t);}
static void *copy_QQuickGraphicsConfiguration(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QQuickGraphicsConfiguration(reinterpret_cast<const ::QQuickGraphicsConfiguration *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QQuickGraphicsConfiguration(sipSimpleWrapper *);}
static void dealloc_QQuickGraphicsConfiguration(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuickGraphicsConfiguration(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QQuickGraphicsConfiguration(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuickGraphicsConfiguration(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QQuickGraphicsConfiguration *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QQuickGraphicsConfiguration();

            return sipCpp;
        }
    }

    {
        const ::QQuickGraphicsConfiguration* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QQuickGraphicsConfiguration, &a0))
        {
            sipCpp = new ::QQuickGraphicsConfiguration(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QQuickGraphicsConfiguration[] = {
    {sipName_deviceExtensions, meth_QQuickGraphicsConfiguration_deviceExtensions, METH_VARARGS, doc_QQuickGraphicsConfiguration_deviceExtensions},
    {sipName_isAutomaticPipelineCacheEnabled, meth_QQuickGraphicsConfiguration_isAutomaticPipelineCacheEnabled, METH_VARARGS, doc_QQuickGraphicsConfiguration_isAutomaticPipelineCacheEnabled},
    {sipName_isDebugLayerEnabled, meth_QQuickGraphicsConfiguration_isDebugLayerEnabled, METH_VARARGS, doc_QQuickGraphicsConfiguration_isDebugLayerEnabled},
    {sipName_isDebugMarkersEnabled, meth_QQuickGraphicsConfiguration_isDebugMarkersEnabled, METH_VARARGS, doc_QQuickGraphicsConfiguration_isDebugMarkersEnabled},
    {sipName_isDepthBufferEnabledFor2D, meth_QQuickGraphicsConfiguration_isDepthBufferEnabledFor2D, METH_VARARGS, doc_QQuickGraphicsConfiguration_isDepthBufferEnabledFor2D},
    {sipName_pipelineCacheLoadFile, meth_QQuickGraphicsConfiguration_pipelineCacheLoadFile, METH_VARARGS, doc_QQuickGraphicsConfiguration_pipelineCacheLoadFile},
    {sipName_pipelineCacheSaveFile, meth_QQuickGraphicsConfiguration_pipelineCacheSaveFile, METH_VARARGS, doc_QQuickGraphicsConfiguration_pipelineCacheSaveFile},
    {sipName_preferredInstanceExtensions, meth_QQuickGraphicsConfiguration_preferredInstanceExtensions, METH_VARARGS, doc_QQuickGraphicsConfiguration_preferredInstanceExtensions},
    {sipName_prefersSoftwareDevice, meth_QQuickGraphicsConfiguration_prefersSoftwareDevice, METH_VARARGS, doc_QQuickGraphicsConfiguration_prefersSoftwareDevice},
    {sipName_setAutomaticPipelineCache, meth_QQuickGraphicsConfiguration_setAutomaticPipelineCache, METH_VARARGS, doc_QQuickGraphicsConfiguration_setAutomaticPipelineCache},
    {sipName_setDebugLayer, meth_QQuickGraphicsConfiguration_setDebugLayer, METH_VARARGS, doc_QQuickGraphicsConfiguration_setDebugLayer},
    {sipName_setDebugMarkers, meth_QQuickGraphicsConfiguration_setDebugMarkers, METH_VARARGS, doc_QQuickGraphicsConfiguration_setDebugMarkers},
    {sipName_setDepthBufferFor2D, meth_QQuickGraphicsConfiguration_setDepthBufferFor2D, METH_VARARGS, doc_QQuickGraphicsConfiguration_setDepthBufferFor2D},
    {sipName_setDeviceExtensions, meth_QQuickGraphicsConfiguration_setDeviceExtensions, METH_VARARGS, doc_QQuickGraphicsConfiguration_setDeviceExtensions},
    {sipName_setPipelineCacheLoadFile, meth_QQuickGraphicsConfiguration_setPipelineCacheLoadFile, METH_VARARGS, doc_QQuickGraphicsConfiguration_setPipelineCacheLoadFile},
    {sipName_setPipelineCacheSaveFile, meth_QQuickGraphicsConfiguration_setPipelineCacheSaveFile, METH_VARARGS, doc_QQuickGraphicsConfiguration_setPipelineCacheSaveFile},
    {sipName_setPreferSoftwareDevice, meth_QQuickGraphicsConfiguration_setPreferSoftwareDevice, METH_VARARGS, doc_QQuickGraphicsConfiguration_setPreferSoftwareDevice},
    {sipName_setTimestamps, meth_QQuickGraphicsConfiguration_setTimestamps, METH_VARARGS, doc_QQuickGraphicsConfiguration_setTimestamps},
    {sipName_timestampsEnabled, meth_QQuickGraphicsConfiguration_timestampsEnabled, METH_VARARGS, doc_QQuickGraphicsConfiguration_timestampsEnabled}
};

PyDoc_STRVAR(doc_QQuickGraphicsConfiguration, "\1QQuickGraphicsConfiguration()\n"
"QQuickGraphicsConfiguration(other: QQuickGraphicsConfiguration)");


sipClassTypeDef sipTypeDef_QtQuick_QQuickGraphicsConfiguration = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuickGraphicsConfiguration,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QQuickGraphicsConfiguration,
        {0, 0, 1},
        19, methods_QQuickGraphicsConfiguration,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuickGraphicsConfiguration,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQuickGraphicsConfiguration,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuickGraphicsConfiguration,
    assign_QQuickGraphicsConfiguration,
    array_QQuickGraphicsConfiguration,
    copy_QQuickGraphicsConfiguration,
    release_QQuickGraphicsConfiguration,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QQuickGraphicsConfiguration,
    sizeof (::QQuickGraphicsConfiguration),
};
