/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeoareamonitorinfo.sip"
#include <qgeoareamonitorinfo.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorInfo.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorInfo.cpp"
#line 27 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorInfo.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorInfo.cpp"
#line 262 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorInfo.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeoshape.sip"
#include <qgeoshape.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorInfo.cpp"


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_name, "name(self) -> str");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_name(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_name, doc_QGeoAreaMonitorInfo_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_setName, "setName(self, name: str|None)");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_setName(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_setName, doc_QGeoAreaMonitorInfo_setName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_identifier, "identifier(self) -> str");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_identifier(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_identifier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->identifier());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_identifier, doc_QGeoAreaMonitorInfo_identifier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_isValid(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_isValid, doc_QGeoAreaMonitorInfo_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_area, "area(self) -> QGeoShape");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_area(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_area(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp))
        {
            ::QGeoShape*sipRes;

            sipRes = new ::QGeoShape(sipCpp->area());

            return sipConvertFromNewType(sipRes, sipType_QGeoShape, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_area, doc_QGeoAreaMonitorInfo_area);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_setArea, "setArea(self, newShape: QGeoShape)");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_setArea(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_setArea(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoShape* a0;
        ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp, sipType_QGeoShape, &a0))
        {
            sipCpp->setArea(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_setArea, doc_QGeoAreaMonitorInfo_setArea);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_expiration, "expiration(self) -> QDateTime");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_expiration(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_expiration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->expiration());

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_expiration, doc_QGeoAreaMonitorInfo_expiration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_setExpiration, "setExpiration(self, expiry: QDateTime|datetime.datetime)");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_setExpiration(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_setExpiration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDateTime* a0;
        int a0State = 0;
        ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp, sipType_QDateTime, &a0, &a0State))
        {
            sipCpp->setExpiration(*a0);
            sipReleaseType(const_cast< ::QDateTime *>(a0), sipType_QDateTime, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_setExpiration, doc_QGeoAreaMonitorInfo_setExpiration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_isPersistent, "isPersistent(self) -> bool");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_isPersistent(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_isPersistent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isPersistent();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_isPersistent, doc_QGeoAreaMonitorInfo_isPersistent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_setPersistent, "setPersistent(self, isPersistent: bool)");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_setPersistent(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_setPersistent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp, &a0))
        {
            sipCpp->setPersistent(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_setPersistent, doc_QGeoAreaMonitorInfo_setPersistent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_notificationParameters, "notificationParameters(self) -> dict[str, Any]");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_notificationParameters(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_notificationParameters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp))
        {
            ::QVariantMap*sipRes;

            sipRes = new ::QVariantMap(sipCpp->notificationParameters());

            return sipConvertFromNewType(sipRes, sipType_QMap_0100QString_0100QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_notificationParameters, doc_QGeoAreaMonitorInfo_notificationParameters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_setNotificationParameters, "setNotificationParameters(self, parameters: dict[str|None, Any])");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_setNotificationParameters(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_setNotificationParameters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp, sipType_QMap_0100QString_0100QVariant, &a0, &a0State))
        {
            sipCpp->setNotificationParameters(*a0);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QMap_0100QString_0100QVariant, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_setNotificationParameters, doc_QGeoAreaMonitorInfo_setNotificationParameters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAreaMonitorInfo_swap, "swap(self, other: QGeoAreaMonitorInfo)");

extern "C" {static PyObject *meth_QGeoAreaMonitorInfo_swap(PyObject *, PyObject *);}
static PyObject *meth_QGeoAreaMonitorInfo_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoAreaMonitorInfo* a0;
        ::QGeoAreaMonitorInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoAreaMonitorInfo, &sipCpp, sipType_QGeoAreaMonitorInfo, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAreaMonitorInfo, sipName_swap, doc_QGeoAreaMonitorInfo_swap);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QGeoAreaMonitorInfo___eq__(PyObject *, PyObject *);}
static PyObject *slot_QGeoAreaMonitorInfo___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoAreaMonitorInfo *sipCpp = reinterpret_cast< ::QGeoAreaMonitorInfo *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoAreaMonitorInfo));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAreaMonitorInfo* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoAreaMonitorInfo, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPositioning, eq_slot, sipType_QGeoAreaMonitorInfo, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGeoAreaMonitorInfo___ne__(PyObject *, PyObject *);}
static PyObject *slot_QGeoAreaMonitorInfo___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoAreaMonitorInfo *sipCpp = reinterpret_cast< ::QGeoAreaMonitorInfo *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoAreaMonitorInfo));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAreaMonitorInfo* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoAreaMonitorInfo, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPositioning, ne_slot, sipType_QGeoAreaMonitorInfo, sipSelf, sipArg);
}


extern "C" {static Py_hash_t slot_QGeoAreaMonitorInfo___hash__(PyObject *);}
static Py_hash_t slot_QGeoAreaMonitorInfo___hash__(PyObject *sipSelf)
{
    ::QGeoAreaMonitorInfo *sipCpp = reinterpret_cast< ::QGeoAreaMonitorInfo *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoAreaMonitorInfo));

    if (!sipCpp)
        return 0;


    {
        {
            Py_hash_t sipRes = 0;

#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeoareamonitorinfo.sip"
        sipRes = qHash(*sipCpp);
#line 465 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoAreaMonitorInfo.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoAreaMonitorInfo(void *, int);}
static void release_QGeoAreaMonitorInfo(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGeoAreaMonitorInfo *>(sipCppV);
}


extern "C" {static void *array_QGeoAreaMonitorInfo(Py_ssize_t);}
static void *array_QGeoAreaMonitorInfo(Py_ssize_t sipNrElem)
{
    return new ::QGeoAreaMonitorInfo[sipNrElem];
}


extern "C" {static void array_delete_QGeoAreaMonitorInfo(void *);}
static void array_delete_QGeoAreaMonitorInfo(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoAreaMonitorInfo *>(sipCpp);
}


extern "C" {static void assign_QGeoAreaMonitorInfo(void *, Py_ssize_t, void *);}
static void assign_QGeoAreaMonitorInfo(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGeoAreaMonitorInfo *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGeoAreaMonitorInfo *>(sipSrc);
}


extern "C" {static void *copy_QGeoAreaMonitorInfo(const void *, Py_ssize_t);}
static void *copy_QGeoAreaMonitorInfo(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGeoAreaMonitorInfo(reinterpret_cast<const ::QGeoAreaMonitorInfo *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGeoAreaMonitorInfo(sipSimpleWrapper *);}
static void dealloc_QGeoAreaMonitorInfo(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoAreaMonitorInfo(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGeoAreaMonitorInfo(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoAreaMonitorInfo(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGeoAreaMonitorInfo *sipCpp = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;

        static const char *sipKwdList[] = {
            sipName_name,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|J1", sipType_QString, &a0, &a0State))
        {
            sipCpp = new ::QGeoAreaMonitorInfo(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipCpp;
        }
    }

    {
        const ::QGeoAreaMonitorInfo* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoAreaMonitorInfo, &a0))
        {
            sipCpp = new ::QGeoAreaMonitorInfo(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QGeoAreaMonitorInfo[] = {
    {(void *)slot_QGeoAreaMonitorInfo___eq__, eq_slot},
    {(void *)slot_QGeoAreaMonitorInfo___ne__, ne_slot},
    {(void *)slot_QGeoAreaMonitorInfo___hash__, hash_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QGeoAreaMonitorInfo[] = {
    {sipName_area, meth_QGeoAreaMonitorInfo_area, METH_VARARGS, doc_QGeoAreaMonitorInfo_area},
    {sipName_expiration, meth_QGeoAreaMonitorInfo_expiration, METH_VARARGS, doc_QGeoAreaMonitorInfo_expiration},
    {sipName_identifier, meth_QGeoAreaMonitorInfo_identifier, METH_VARARGS, doc_QGeoAreaMonitorInfo_identifier},
    {sipName_isPersistent, meth_QGeoAreaMonitorInfo_isPersistent, METH_VARARGS, doc_QGeoAreaMonitorInfo_isPersistent},
    {sipName_isValid, meth_QGeoAreaMonitorInfo_isValid, METH_VARARGS, doc_QGeoAreaMonitorInfo_isValid},
    {sipName_name, meth_QGeoAreaMonitorInfo_name, METH_VARARGS, doc_QGeoAreaMonitorInfo_name},
    {sipName_notificationParameters, meth_QGeoAreaMonitorInfo_notificationParameters, METH_VARARGS, doc_QGeoAreaMonitorInfo_notificationParameters},
    {sipName_setArea, meth_QGeoAreaMonitorInfo_setArea, METH_VARARGS, doc_QGeoAreaMonitorInfo_setArea},
    {sipName_setExpiration, meth_QGeoAreaMonitorInfo_setExpiration, METH_VARARGS, doc_QGeoAreaMonitorInfo_setExpiration},
    {sipName_setName, meth_QGeoAreaMonitorInfo_setName, METH_VARARGS, doc_QGeoAreaMonitorInfo_setName},
    {sipName_setNotificationParameters, meth_QGeoAreaMonitorInfo_setNotificationParameters, METH_VARARGS, doc_QGeoAreaMonitorInfo_setNotificationParameters},
    {sipName_setPersistent, meth_QGeoAreaMonitorInfo_setPersistent, METH_VARARGS, doc_QGeoAreaMonitorInfo_setPersistent},
    {sipName_swap, meth_QGeoAreaMonitorInfo_swap, METH_VARARGS, doc_QGeoAreaMonitorInfo_swap}
};

PyDoc_STRVAR(doc_QGeoAreaMonitorInfo, "\1QGeoAreaMonitorInfo(name: str|None = '')\n"
"QGeoAreaMonitorInfo(other: QGeoAreaMonitorInfo)");


sipClassTypeDef sipTypeDef_QtPositioning_QGeoAreaMonitorInfo = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoAreaMonitorInfo,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QGeoAreaMonitorInfo,
        {0, 0, 1},
        13, methods_QGeoAreaMonitorInfo,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoAreaMonitorInfo,
    -1,
    -1,
    SIP_NULLPTR,
    slots_QGeoAreaMonitorInfo,
    init_type_QGeoAreaMonitorInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoAreaMonitorInfo,
    assign_QGeoAreaMonitorInfo,
    array_QGeoAreaMonitorInfo,
    copy_QGeoAreaMonitorInfo,
    release_QGeoAreaMonitorInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoAreaMonitorInfo,
    sizeof (::QGeoAreaMonitorInfo),
};
