/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/abstractformwindowcursor.sip"
#include <abstractformwindowcursor.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowCursorInterface.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowCursorInterface.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowCursorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowCursorInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/abstractformwindow.sip"
#include <abstractformwindow.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowCursorInterface.cpp"


class sipQDesignerFormWindowCursorInterface : public ::QDesignerFormWindowCursorInterface
{
public:
    sipQDesignerFormWindowCursorInterface();
    virtual ~sipQDesignerFormWindowCursorInterface();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void resetWidgetProperty(::QWidget*, const ::QString&) SIP_OVERRIDE;
    void setWidgetProperty(::QWidget*, const ::QString&, const ::QVariant&) SIP_OVERRIDE;
    void setProperty(const ::QString&, const ::QVariant&) SIP_OVERRIDE;
    ::QWidget* selectedWidget(int) const SIP_OVERRIDE;
    int selectedWidgetCount() const SIP_OVERRIDE;
    bool hasSelection() const SIP_OVERRIDE;
    ::QWidget* widget(int) const SIP_OVERRIDE;
    int widgetCount() const SIP_OVERRIDE;
    ::QWidget* current() const SIP_OVERRIDE;
    void setPosition(int, ::QDesignerFormWindowCursorInterface::MoveMode) SIP_OVERRIDE;
    int position() const SIP_OVERRIDE;
    bool movePosition(::QDesignerFormWindowCursorInterface::MoveOperation, ::QDesignerFormWindowCursorInterface::MoveMode) SIP_OVERRIDE;
    ::QDesignerFormWindowInterface* formWindow() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQDesignerFormWindowCursorInterface(const sipQDesignerFormWindowCursorInterface &);
    sipQDesignerFormWindowCursorInterface &operator = (const sipQDesignerFormWindowCursorInterface &);

    char sipPyMethods[13];
};

sipQDesignerFormWindowCursorInterface::sipQDesignerFormWindowCursorInterface(): ::QDesignerFormWindowCursorInterface(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQDesignerFormWindowCursorInterface::~sipQDesignerFormWindowCursorInterface()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

void sipQDesignerFormWindowCursorInterface::resetWidgetProperty(::QWidget*a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QDesignerFormWindowCursorInterface, sipName_resetWidgetProperty);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_70(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*, const ::QString&);

    sipVH_QtDesigner_70(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQDesignerFormWindowCursorInterface::setWidgetProperty(::QWidget*a0, const ::QString& a1, const ::QVariant& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, sipName_QDesignerFormWindowCursorInterface, sipName_setWidgetProperty);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_69(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*, const ::QString&, const ::QVariant&);

    sipVH_QtDesigner_69(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQDesignerFormWindowCursorInterface::setProperty(const ::QString& a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, sipName_QDesignerFormWindowCursorInterface, sipName_setProperty);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_68(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, const ::QVariant&);

    sipVH_QtDesigner_68(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QWidget* sipQDesignerFormWindowCursorInterface::selectedWidget(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerFormWindowCursorInterface, sipName_selectedWidget);

    if (!sipMeth)
        return 0;

    extern ::QWidget* sipVH_QtDesigner_67(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_67(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQDesignerFormWindowCursorInterface::selectedWidgetCount() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerFormWindowCursorInterface, sipName_selectedWidgetCount);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtDesigner_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_29(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQDesignerFormWindowCursorInterface::hasSelection() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerFormWindowCursorInterface, sipName_hasSelection);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_3(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QWidget* sipQDesignerFormWindowCursorInterface::widget(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerFormWindowCursorInterface, sipName_widget);

    if (!sipMeth)
        return 0;

    extern ::QWidget* sipVH_QtDesigner_67(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_67(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQDesignerFormWindowCursorInterface::widgetCount() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerFormWindowCursorInterface, sipName_widgetCount);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtDesigner_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_29(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QWidget* sipQDesignerFormWindowCursorInterface::current() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerFormWindowCursorInterface, sipName_current);

    if (!sipMeth)
        return 0;

    extern ::QWidget* sipVH_QtDesigner_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_56(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQDesignerFormWindowCursorInterface::setPosition(int a0, ::QDesignerFormWindowCursorInterface::MoveMode a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, sipName_QDesignerFormWindowCursorInterface, sipName_setPosition);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_66(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::QDesignerFormWindowCursorInterface::MoveMode);

    sipVH_QtDesigner_66(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

int sipQDesignerFormWindowCursorInterface::position() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerFormWindowCursorInterface, sipName_position);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtDesigner_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_29(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQDesignerFormWindowCursorInterface::movePosition(::QDesignerFormWindowCursorInterface::MoveOperation a0, ::QDesignerFormWindowCursorInterface::MoveMode a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, sipName_QDesignerFormWindowCursorInterface, sipName_movePosition);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_65(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDesignerFormWindowCursorInterface::MoveOperation, ::QDesignerFormWindowCursorInterface::MoveMode);

    return sipVH_QtDesigner_65(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QDesignerFormWindowInterface* sipQDesignerFormWindowCursorInterface::formWindow() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerFormWindowCursorInterface, sipName_formWindow);

    if (!sipMeth)
        return 0;

    extern ::QDesignerFormWindowInterface* sipVH_QtDesigner_64(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_64(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_formWindow, "formWindow(self) -> QDesignerFormWindowInterface|None");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_formWindow(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_formWindow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp))
        {
            ::QDesignerFormWindowInterface*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_formWindow);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->formWindow();

            return sipConvertFromType(sipRes, sipType_QDesignerFormWindowInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_formWindow, doc_QDesignerFormWindowCursorInterface_formWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_movePosition, "movePosition(self, op: QDesignerFormWindowCursorInterface.MoveOperation, mode: QDesignerFormWindowCursorInterface.MoveMode = QDesignerFormWindowCursorInterface.MoveAnchor) -> bool");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_movePosition(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_movePosition(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowCursorInterface::MoveOperation a0;
        ::QDesignerFormWindowCursorInterface::MoveMode a1 = QDesignerFormWindowCursorInterface::MoveAnchor;
        ::QDesignerFormWindowCursorInterface *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|E", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp, sipType_QDesignerFormWindowCursorInterface_MoveOperation, &a0, sipType_QDesignerFormWindowCursorInterface_MoveMode, &a1))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_movePosition);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->movePosition(a0, a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_movePosition, doc_QDesignerFormWindowCursorInterface_movePosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_position, "position(self) -> int");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_position(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_position);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->position();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_position, doc_QDesignerFormWindowCursorInterface_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_setPosition, "setPosition(self, pos: int, mode: QDesignerFormWindowCursorInterface.MoveMode = QDesignerFormWindowCursorInterface.MoveAnchor)");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_setPosition(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_setPosition(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QDesignerFormWindowCursorInterface::MoveMode a1 = QDesignerFormWindowCursorInterface::MoveAnchor;
        ::QDesignerFormWindowCursorInterface *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp, &a0, sipType_QDesignerFormWindowCursorInterface_MoveMode, &a1))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_setPosition);
                return SIP_NULLPTR;
            }

            sipCpp->setPosition(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_setPosition, doc_QDesignerFormWindowCursorInterface_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_current, "current(self) -> QWidget|None");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_current(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_current(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp))
        {
            ::QWidget*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_current);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->current();

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_current, doc_QDesignerFormWindowCursorInterface_current);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_widgetCount, "widgetCount(self) -> int");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_widgetCount(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_widgetCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_widgetCount);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->widgetCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_widgetCount, doc_QDesignerFormWindowCursorInterface_widgetCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_widget, "widget(self, index: int) -> QWidget|None");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_widget(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_widget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp, &a0))
        {
            ::QWidget*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_widget);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->widget(a0);

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_widget, doc_QDesignerFormWindowCursorInterface_widget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_hasSelection, "hasSelection(self) -> bool");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_hasSelection(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_hasSelection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_hasSelection);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->hasSelection();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_hasSelection, doc_QDesignerFormWindowCursorInterface_hasSelection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_selectedWidgetCount, "selectedWidgetCount(self) -> int");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_selectedWidgetCount(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_selectedWidgetCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_selectedWidgetCount);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->selectedWidgetCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_selectedWidgetCount, doc_QDesignerFormWindowCursorInterface_selectedWidgetCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_selectedWidget, "selectedWidget(self, index: int) -> QWidget|None");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_selectedWidget(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_selectedWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp, &a0))
        {
            ::QWidget*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_selectedWidget);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->selectedWidget(a0);

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_selectedWidget, doc_QDesignerFormWindowCursorInterface_selectedWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_setProperty, "setProperty(self, name: str|None, value: Any)");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_setProperty(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_setProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_setProperty);
                return SIP_NULLPTR;
            }

            sipCpp->setProperty(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_setProperty, doc_QDesignerFormWindowCursorInterface_setProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_setWidgetProperty, "setWidgetProperty(self, widget: QWidget|None, name: str|None, value: Any)");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_setWidgetProperty(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_setWidgetProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QWidget* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QVariant* a2;
        int a2State = 0;
        ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J1J1", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp, sipType_QWidget, &a0, sipType_QString, &a1, &a1State, sipType_QVariant, &a2, &a2State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_setWidgetProperty);
                return SIP_NULLPTR;
            }

            sipCpp->setWidgetProperty(a0, *a1, *a2);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QVariant *>(a2), sipType_QVariant, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_setWidgetProperty, doc_QDesignerFormWindowCursorInterface_setWidgetProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_resetWidgetProperty, "resetWidgetProperty(self, widget: QWidget|None, name: str|None)");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_resetWidgetProperty(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_resetWidgetProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QWidget* a0;
        const ::QString* a1;
        int a1State = 0;
        ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J1", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp, sipType_QWidget, &a0, sipType_QString, &a1, &a1State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowCursorInterface, sipName_resetWidgetProperty);
                return SIP_NULLPTR;
            }

            sipCpp->resetWidgetProperty(a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_resetWidgetProperty, doc_QDesignerFormWindowCursorInterface_resetWidgetProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface_isWidgetSelected, "isWidgetSelected(self, widget: QWidget|None) -> bool");

extern "C" {static PyObject *meth_QDesignerFormWindowCursorInterface_isWidgetSelected(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowCursorInterface_isWidgetSelected(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        const ::QDesignerFormWindowCursorInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QDesignerFormWindowCursorInterface, &sipCpp, sipType_QWidget, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isWidgetSelected(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowCursorInterface, sipName_isWidgetSelected, doc_QDesignerFormWindowCursorInterface_isWidgetSelected);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDesignerFormWindowCursorInterface(void *, int);}
static void release_QDesignerFormWindowCursorInterface(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQDesignerFormWindowCursorInterface *>(sipCppV);
    else
        delete reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(sipCppV);
}


extern "C" {static void dealloc_QDesignerFormWindowCursorInterface(sipSimpleWrapper *);}
static void dealloc_QDesignerFormWindowCursorInterface(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQDesignerFormWindowCursorInterface *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDesignerFormWindowCursorInterface(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QDesignerFormWindowCursorInterface(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDesignerFormWindowCursorInterface(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQDesignerFormWindowCursorInterface *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQDesignerFormWindowCursorInterface();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QDesignerFormWindowCursorInterface[] = {
    {sipName_current, meth_QDesignerFormWindowCursorInterface_current, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_current},
    {sipName_formWindow, meth_QDesignerFormWindowCursorInterface_formWindow, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_formWindow},
    {sipName_hasSelection, meth_QDesignerFormWindowCursorInterface_hasSelection, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_hasSelection},
    {sipName_isWidgetSelected, meth_QDesignerFormWindowCursorInterface_isWidgetSelected, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_isWidgetSelected},
    {sipName_movePosition, SIP_MLMETH_CAST(meth_QDesignerFormWindowCursorInterface_movePosition), METH_VARARGS|METH_KEYWORDS, doc_QDesignerFormWindowCursorInterface_movePosition},
    {sipName_position, meth_QDesignerFormWindowCursorInterface_position, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_position},
    {sipName_resetWidgetProperty, meth_QDesignerFormWindowCursorInterface_resetWidgetProperty, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_resetWidgetProperty},
    {sipName_selectedWidget, meth_QDesignerFormWindowCursorInterface_selectedWidget, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_selectedWidget},
    {sipName_selectedWidgetCount, meth_QDesignerFormWindowCursorInterface_selectedWidgetCount, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_selectedWidgetCount},
    {sipName_setPosition, SIP_MLMETH_CAST(meth_QDesignerFormWindowCursorInterface_setPosition), METH_VARARGS|METH_KEYWORDS, doc_QDesignerFormWindowCursorInterface_setPosition},
    {sipName_setProperty, meth_QDesignerFormWindowCursorInterface_setProperty, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_setProperty},
    {sipName_setWidgetProperty, meth_QDesignerFormWindowCursorInterface_setWidgetProperty, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_setWidgetProperty},
    {sipName_widget, meth_QDesignerFormWindowCursorInterface_widget, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_widget},
    {sipName_widgetCount, meth_QDesignerFormWindowCursorInterface_widgetCount, METH_VARARGS, doc_QDesignerFormWindowCursorInterface_widgetCount}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QDesignerFormWindowCursorInterface[] = {
    {sipName_MoveAnchor, static_cast<int>(::QDesignerFormWindowCursorInterface::MoveAnchor)},
    {sipName_KeepAnchor, static_cast<int>(::QDesignerFormWindowCursorInterface::KeepAnchor)},
    {sipName_NoMove, static_cast<int>(::QDesignerFormWindowCursorInterface::NoMove)},
    {sipName_Start, static_cast<int>(::QDesignerFormWindowCursorInterface::Start)},
    {sipName_End, static_cast<int>(::QDesignerFormWindowCursorInterface::End)},
    {sipName_Next, static_cast<int>(::QDesignerFormWindowCursorInterface::Next)},
    {sipName_Prev, static_cast<int>(::QDesignerFormWindowCursorInterface::Prev)},
    {sipName_Left, static_cast<int>(::QDesignerFormWindowCursorInterface::Left)},
    {sipName_Right, static_cast<int>(::QDesignerFormWindowCursorInterface::Right)},
    {sipName_Up, static_cast<int>(::QDesignerFormWindowCursorInterface::Up)},
    {sipName_Down, static_cast<int>(::QDesignerFormWindowCursorInterface::Down)},
    {0, 0}
};

PyDoc_STRVAR(doc_QDesignerFormWindowCursorInterface, "\1QDesignerFormWindowCursorInterface()");


sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormWindowCursorInterface = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDesignerFormWindowCursorInterface,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QDesignerFormWindowCursorInterface,
        {0, 0, 1},
        14, methods_QDesignerFormWindowCursorInterface,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QDesignerFormWindowCursorInterface, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDesignerFormWindowCursorInterface,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QDesignerFormWindowCursorInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDesignerFormWindowCursorInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QDesignerFormWindowCursorInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QDesignerFormWindowCursorInterface),
};
