/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/abstractformwindowmanager.sip"
#include <abstractformwindowmanager.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qactiongroup.sip"
#include <qactiongroup.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/abstractformwindow.sip"
#include <abstractformwindow.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/abstractformeditor.sip"
#include <abstractformeditor.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 61 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 64 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 67 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerFormWindowManagerInterface.cpp"


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_actionFormLayout, "actionFormLayout(self) -> QAction|None");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_actionFormLayout(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_actionFormLayout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp))
        {
            ::QAction*sipRes;

            sipRes = sipCpp->actionFormLayout();

            return sipConvertFromType(sipRes, sipType_QAction, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_actionFormLayout, doc_QDesignerFormWindowManagerInterface_actionFormLayout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_actionSimplifyLayout, "actionSimplifyLayout(self) -> QAction|None");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_actionSimplifyLayout(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_actionSimplifyLayout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp))
        {
            ::QAction*sipRes;

            sipRes = sipCpp->actionSimplifyLayout();

            return sipConvertFromType(sipRes, sipType_QAction, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_actionSimplifyLayout, doc_QDesignerFormWindowManagerInterface_actionSimplifyLayout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_activeFormWindow, "activeFormWindow(self) -> QDesignerFormWindowInterface|None");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_activeFormWindow(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_activeFormWindow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp))
        {
            ::QDesignerFormWindowInterface*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_activeFormWindow);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->activeFormWindow();

            return sipConvertFromType(sipRes, sipType_QDesignerFormWindowInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_activeFormWindow, doc_QDesignerFormWindowManagerInterface_activeFormWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_formWindowCount, "formWindowCount(self) -> int");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_formWindowCount(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_formWindowCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_formWindowCount);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->formWindowCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_formWindowCount, doc_QDesignerFormWindowManagerInterface_formWindowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_formWindow, "formWindow(self, index: int) -> QDesignerFormWindowInterface|None");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_formWindow(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_formWindow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp, &a0))
        {
            ::QDesignerFormWindowInterface*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_formWindow);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->formWindow(a0);

            return sipConvertFromType(sipRes, sipType_QDesignerFormWindowInterface, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_formWindow, doc_QDesignerFormWindowManagerInterface_formWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_createFormWindow, "createFormWindow(self, parent: QWidget|None = None, flags: Qt.WindowType = Qt.WindowFlags()) -> QDesignerFormWindowInterface|None");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_createFormWindow(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_createFormWindow(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QWidget* a0 = 0;
        ::Qt::WindowFlags a1def = Qt::WindowFlags();
        ::Qt::WindowFlags* a1 = &a1def;
        int a1State = 0;
        sipWrapper *sipOwner = SIP_NULLPTR;
        ::QDesignerFormWindowManagerInterface *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|JHJ1", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp, sipType_QWidget, &a0, &sipOwner, sipType_QFlags_0100Qt_WindowType, &a1, &a1State))
        {
            ::QDesignerFormWindowInterface*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_createFormWindow);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->createFormWindow(a0, *a1);

            if (sipOwner)
                sipTransferTo(sipSelf, (PyObject *)sipOwner);
            else
                sipTransferBack(sipSelf);
            sipReleaseType(a1, sipType_QFlags_0100Qt_WindowType, a1State);

            return sipConvertFromType(sipRes, sipType_QDesignerFormWindowInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_createFormWindow, doc_QDesignerFormWindowManagerInterface_createFormWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_core, "core(self) -> QDesignerFormEditorInterface|None");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_core(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_core(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp))
        {
            ::QDesignerFormEditorInterface*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_core);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->core();

            return sipConvertFromType(sipRes, sipType_QDesignerFormEditorInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_core, doc_QDesignerFormWindowManagerInterface_core);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_addFormWindow, "addFormWindow(self, formWindow: QDesignerFormWindowInterface|None)");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_addFormWindow(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_addFormWindow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowInterface* a0;
        ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp, sipType_QDesignerFormWindowInterface, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_addFormWindow);
                return SIP_NULLPTR;
            }

            sipCpp->addFormWindow(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_addFormWindow, doc_QDesignerFormWindowManagerInterface_addFormWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_removeFormWindow, "removeFormWindow(self, formWindow: QDesignerFormWindowInterface|None)");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_removeFormWindow(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_removeFormWindow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowInterface* a0;
        ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp, sipType_QDesignerFormWindowInterface, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_removeFormWindow);
                return SIP_NULLPTR;
            }

            sipCpp->removeFormWindow(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_removeFormWindow, doc_QDesignerFormWindowManagerInterface_removeFormWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_setActiveFormWindow, "setActiveFormWindow(self, formWindow: QDesignerFormWindowInterface|None)");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_setActiveFormWindow(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_setActiveFormWindow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowInterface* a0;
        ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp, sipType_QDesignerFormWindowInterface, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_setActiveFormWindow);
                return SIP_NULLPTR;
            }

            sipCpp->setActiveFormWindow(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_setActiveFormWindow, doc_QDesignerFormWindowManagerInterface_setActiveFormWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_action, "action(self, action: QDesignerFormWindowManagerInterface.Action) -> QAction|None");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_action(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_action(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowManagerInterface::Action a0;
        const ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp, sipType_QDesignerFormWindowManagerInterface_Action, &a0))
        {
            ::QAction*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_action);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->action(a0);

            return sipConvertFromType(sipRes, sipType_QAction, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_action, doc_QDesignerFormWindowManagerInterface_action);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_actionGroup, "actionGroup(self, actionGroup: QDesignerFormWindowManagerInterface.ActionGroup) -> QActionGroup|None");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_actionGroup(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_actionGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowManagerInterface::ActionGroup a0;
        const ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp, sipType_QDesignerFormWindowManagerInterface_ActionGroup, &a0))
        {
            ::QActionGroup*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_actionGroup);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->actionGroup(a0);

            return sipConvertFromType(sipRes, sipType_QActionGroup, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_actionGroup, doc_QDesignerFormWindowManagerInterface_actionGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_showPreview, "showPreview(self)");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_showPreview(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_showPreview(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_showPreview);
                return SIP_NULLPTR;
            }

            sipCpp->showPreview();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_showPreview, doc_QDesignerFormWindowManagerInterface_showPreview);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_closeAllPreviews, "closeAllPreviews(self)");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_closeAllPreviews(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_closeAllPreviews(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_closeAllPreviews);
                return SIP_NULLPTR;
            }

            sipCpp->closeAllPreviews();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_closeAllPreviews, doc_QDesignerFormWindowManagerInterface_closeAllPreviews);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowManagerInterface_showPluginDialog, "showPluginDialog(self)");

extern "C" {static PyObject *meth_QDesignerFormWindowManagerInterface_showPluginDialog(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowManagerInterface_showPluginDialog(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowManagerInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowManagerInterface, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowManagerInterface, sipName_showPluginDialog);
                return SIP_NULLPTR;
            }

            sipCpp->showPluginDialog();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowManagerInterface, sipName_showPluginDialog, doc_QDesignerFormWindowManagerInterface_showPluginDialog);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QDesignerFormWindowManagerInterface(void *, const sipTypeDef *);}
static void *cast_QDesignerFormWindowManagerInterface(void *sipCppV, const sipTypeDef *targetType)
{
    ::QDesignerFormWindowManagerInterface *sipCpp = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(sipCppV);

    if (targetType == sipType_QDesignerFormWindowManagerInterface)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDesignerFormWindowManagerInterface(void *, int);}
static void release_QDesignerFormWindowManagerInterface(void *sipCppV, int)
{
    ::QDesignerFormWindowManagerInterface *sipCpp = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QDesignerFormWindowManagerInterface(sipSimpleWrapper *);}
static void dealloc_QDesignerFormWindowManagerInterface(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDesignerFormWindowManagerInterface(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QDesignerFormWindowManagerInterface[] = {{8, 0, 1}};


static PyMethodDef methods_QDesignerFormWindowManagerInterface[] = {
    {sipName_action, meth_QDesignerFormWindowManagerInterface_action, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_action},
    {sipName_actionFormLayout, meth_QDesignerFormWindowManagerInterface_actionFormLayout, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_actionFormLayout},
    {sipName_actionGroup, meth_QDesignerFormWindowManagerInterface_actionGroup, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_actionGroup},
    {sipName_actionSimplifyLayout, meth_QDesignerFormWindowManagerInterface_actionSimplifyLayout, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_actionSimplifyLayout},
    {sipName_activeFormWindow, meth_QDesignerFormWindowManagerInterface_activeFormWindow, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_activeFormWindow},
    {sipName_addFormWindow, meth_QDesignerFormWindowManagerInterface_addFormWindow, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_addFormWindow},
    {sipName_closeAllPreviews, meth_QDesignerFormWindowManagerInterface_closeAllPreviews, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_closeAllPreviews},
    {sipName_core, meth_QDesignerFormWindowManagerInterface_core, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_core},
    {sipName_createFormWindow, SIP_MLMETH_CAST(meth_QDesignerFormWindowManagerInterface_createFormWindow), METH_VARARGS|METH_KEYWORDS, doc_QDesignerFormWindowManagerInterface_createFormWindow},
    {sipName_formWindow, meth_QDesignerFormWindowManagerInterface_formWindow, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_formWindow},
    {sipName_formWindowCount, meth_QDesignerFormWindowManagerInterface_formWindowCount, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_formWindowCount},
    {sipName_removeFormWindow, meth_QDesignerFormWindowManagerInterface_removeFormWindow, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_removeFormWindow},
    {sipName_setActiveFormWindow, meth_QDesignerFormWindowManagerInterface_setActiveFormWindow, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_setActiveFormWindow},
    {sipName_showPluginDialog, meth_QDesignerFormWindowManagerInterface_showPluginDialog, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_showPluginDialog},
    {sipName_showPreview, meth_QDesignerFormWindowManagerInterface_showPreview, METH_VARARGS, doc_QDesignerFormWindowManagerInterface_showPreview}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QDesignerFormWindowManagerInterface[] = {
    {sipName_CutAction, static_cast<int>(::QDesignerFormWindowManagerInterface::CutAction)},
    {sipName_CopyAction, static_cast<int>(::QDesignerFormWindowManagerInterface::CopyAction)},
    {sipName_PasteAction, static_cast<int>(::QDesignerFormWindowManagerInterface::PasteAction)},
    {sipName_DeleteAction, static_cast<int>(::QDesignerFormWindowManagerInterface::DeleteAction)},
    {sipName_SelectAllAction, static_cast<int>(::QDesignerFormWindowManagerInterface::SelectAllAction)},
    {sipName_LowerAction, static_cast<int>(::QDesignerFormWindowManagerInterface::LowerAction)},
    {sipName_RaiseAction, static_cast<int>(::QDesignerFormWindowManagerInterface::RaiseAction)},
    {sipName_UndoAction, static_cast<int>(::QDesignerFormWindowManagerInterface::UndoAction)},
    {sipName_RedoAction, static_cast<int>(::QDesignerFormWindowManagerInterface::RedoAction)},
    {sipName_HorizontalLayoutAction, static_cast<int>(::QDesignerFormWindowManagerInterface::HorizontalLayoutAction)},
    {sipName_VerticalLayoutAction, static_cast<int>(::QDesignerFormWindowManagerInterface::VerticalLayoutAction)},
    {sipName_SplitHorizontalAction, static_cast<int>(::QDesignerFormWindowManagerInterface::SplitHorizontalAction)},
    {sipName_SplitVerticalAction, static_cast<int>(::QDesignerFormWindowManagerInterface::SplitVerticalAction)},
    {sipName_GridLayoutAction, static_cast<int>(::QDesignerFormWindowManagerInterface::GridLayoutAction)},
    {sipName_FormLayoutAction, static_cast<int>(::QDesignerFormWindowManagerInterface::FormLayoutAction)},
    {sipName_BreakLayoutAction, static_cast<int>(::QDesignerFormWindowManagerInterface::BreakLayoutAction)},
    {sipName_AdjustSizeAction, static_cast<int>(::QDesignerFormWindowManagerInterface::AdjustSizeAction)},
    {sipName_SimplifyLayoutAction, static_cast<int>(::QDesignerFormWindowManagerInterface::SimplifyLayoutAction)},
    {sipName_DefaultPreviewAction, static_cast<int>(::QDesignerFormWindowManagerInterface::DefaultPreviewAction)},
    {sipName_FormWindowSettingsDialogAction, static_cast<int>(::QDesignerFormWindowManagerInterface::FormWindowSettingsDialogAction)},
    {sipName_StyledPreviewActionGroup, static_cast<int>(::QDesignerFormWindowManagerInterface::StyledPreviewActionGroup)},
    {0, 0}
};


/* Define this type's signals. */
static const pyqt6QtSignal signals_QDesignerFormWindowManagerInterface[] = {
    {"formWindowSettingsChanged(QDesignerFormWindowInterface*)", "\1formWindowSettingsChanged(self, fw: QDesignerFormWindowInterface|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"activeFormWindowChanged(QDesignerFormWindowInterface*)", "\1activeFormWindowChanged(self, formWindow: QDesignerFormWindowInterface|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"formWindowRemoved(QDesignerFormWindowInterface*)", "\1formWindowRemoved(self, formWindow: QDesignerFormWindowInterface|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"formWindowAdded(QDesignerFormWindowInterface*)", "\1formWindowAdded(self, formWindow: QDesignerFormWindowInterface|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QDesignerFormWindowManagerInterface = {
    &::QDesignerFormWindowManagerInterface::staticMetaObject,
    signals_QDesignerFormWindowManagerInterface,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormWindowManagerInterface = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDesignerFormWindowManagerInterface,
        SIP_NULLPTR,
        &plugin_QDesignerFormWindowManagerInterface,
    },
    {
        sipNameNr_QDesignerFormWindowManagerInterface,
        {0, 0, 1},
        15, methods_QDesignerFormWindowManagerInterface,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QDesignerFormWindowManagerInterface, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QDesignerFormWindowManagerInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDesignerFormWindowManagerInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QDesignerFormWindowManagerInterface,
    cast_QDesignerFormWindowManagerInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
