/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNfc.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefnfcsmartposterrecord.sip"
#include <qndefnfcsmartposterrecord.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcIconRecord.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefrecord.sip"
#include <qndefrecord.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcIconRecord.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcIconRecord.cpp"


PyDoc_STRVAR(doc_QNdefNfcIconRecord_setData, "setData(self, data: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QNdefNfcIconRecord_setData(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcIconRecord_setData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QNdefNfcIconRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNdefNfcIconRecord, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setData(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcIconRecord, sipName_setData, doc_QNdefNfcIconRecord_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcIconRecord_data, "data(self) -> QByteArray");

extern "C" {static PyObject *meth_QNdefNfcIconRecord_data(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcIconRecord_data(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcIconRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcIconRecord, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->data());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcIconRecord, sipName_data, doc_QNdefNfcIconRecord_data);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QNdefNfcIconRecord(void *, const sipTypeDef *);}
static void *cast_QNdefNfcIconRecord(void *sipCppV, const sipTypeDef *targetType)
{
    ::QNdefNfcIconRecord *sipCpp = reinterpret_cast< ::QNdefNfcIconRecord *>(sipCppV);

    if (targetType == sipType_QNdefNfcIconRecord)
        return sipCppV;

    if (targetType == sipType_QNdefRecord)
        return static_cast< ::QNdefRecord *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNdefNfcIconRecord(void *, int);}
static void release_QNdefNfcIconRecord(void *sipCppV, int)
{
    delete reinterpret_cast< ::QNdefNfcIconRecord *>(sipCppV);
}


extern "C" {static void *array_QNdefNfcIconRecord(Py_ssize_t);}
static void *array_QNdefNfcIconRecord(Py_ssize_t sipNrElem)
{
    return new ::QNdefNfcIconRecord[sipNrElem];
}


extern "C" {static void array_delete_QNdefNfcIconRecord(void *);}
static void array_delete_QNdefNfcIconRecord(void *sipCpp)
{
    delete[] reinterpret_cast< ::QNdefNfcIconRecord *>(sipCpp);
}


extern "C" {static void assign_QNdefNfcIconRecord(void *, Py_ssize_t, void *);}
static void assign_QNdefNfcIconRecord(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QNdefNfcIconRecord *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QNdefNfcIconRecord *>(sipSrc);
}


extern "C" {static void *copy_QNdefNfcIconRecord(const void *, Py_ssize_t);}
static void *copy_QNdefNfcIconRecord(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QNdefNfcIconRecord(reinterpret_cast<const ::QNdefNfcIconRecord *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QNdefNfcIconRecord(sipSimpleWrapper *);}
static void dealloc_QNdefNfcIconRecord(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNdefNfcIconRecord(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QNdefNfcIconRecord(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QNdefNfcIconRecord(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QNdefNfcIconRecord *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QNdefNfcIconRecord();

            return sipCpp;
        }
    }

    {
        const ::QNdefRecord* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QNdefRecord, &a0))
        {
            sipCpp = new ::QNdefNfcIconRecord(*a0);

            return sipCpp;
        }
    }

    {
        const ::QNdefNfcIconRecord* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QNdefNfcIconRecord, &a0))
        {
            sipCpp = new ::QNdefNfcIconRecord(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QNdefNfcIconRecord[] = {{14, 255, 1}};


static PyMethodDef methods_QNdefNfcIconRecord[] = {
    {sipName_data, meth_QNdefNfcIconRecord_data, METH_VARARGS, doc_QNdefNfcIconRecord_data},
    {sipName_setData, meth_QNdefNfcIconRecord_setData, METH_VARARGS, doc_QNdefNfcIconRecord_setData}
};

PyDoc_STRVAR(doc_QNdefNfcIconRecord, "\1QNdefNfcIconRecord()\n"
"QNdefNfcIconRecord(other: QNdefRecord)\n"
"QNdefNfcIconRecord(a0: QNdefNfcIconRecord)");


sipClassTypeDef sipTypeDef_QtNfc_QNdefNfcIconRecord = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNdefNfcIconRecord,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QNdefNfcIconRecord,
        {0, 0, 1},
        2, methods_QNdefNfcIconRecord,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QNdefNfcIconRecord,
    -1,
    -1,
    supers_QNdefNfcIconRecord,
    SIP_NULLPTR,
    init_type_QNdefNfcIconRecord,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QNdefNfcIconRecord,
    assign_QNdefNfcIconRecord,
    array_QNdefNfcIconRecord,
    copy_QNdefNfcIconRecord,
    release_QNdefNfcIconRecord,
    cast_QNdefNfcIconRecord,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QNdefNfcIconRecord,
    sizeof (::QNdefNfcIconRecord),
};
