/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtHelp.h"

#line 47 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpcontentwidget.sip"
#include <qhelpcontentwidget.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpcontentitem.sip"
#include <qhelpcontentitem.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
// The capsule destructor for a QModelRoleData array.
static void qpycore_gc_modelroledata(PyObject *mrd_obj);
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 49 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 52 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 55 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 271 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 78 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 789 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 84 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 87 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 90 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 93 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 96 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 99 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpContentModel.cpp"


PyDoc_STRVAR(doc_QHelpContentModel_createContents, "createContents(self, customFilterName: str|None)");

extern "C" {static PyObject *meth_QHelpContentModel_createContents(PyObject *, PyObject *);}
static PyObject *meth_QHelpContentModel_createContents(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpContentModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpContentModel, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->createContents(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpContentModel, sipName_createContents, doc_QHelpContentModel_createContents);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpContentModel_createContentsForCurrentFilter, "createContentsForCurrentFilter(self)");

extern "C" {static PyObject *meth_QHelpContentModel_createContentsForCurrentFilter(PyObject *, PyObject *);}
static PyObject *meth_QHelpContentModel_createContentsForCurrentFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpContentModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpContentModel, &sipCpp))
        {
            sipCpp->createContentsForCurrentFilter();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpContentModel, sipName_createContentsForCurrentFilter, doc_QHelpContentModel_createContentsForCurrentFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpContentModel_contentItemAt, "contentItemAt(self, index: QModelIndex) -> QHelpContentItem|None");

extern "C" {static PyObject *meth_QHelpContentModel_contentItemAt(PyObject *, PyObject *);}
static PyObject *meth_QHelpContentModel_contentItemAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex* a0;
        const ::QHelpContentModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QHelpContentModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QHelpContentItem*sipRes;

            sipRes = sipCpp->contentItemAt(*a0);

            return sipConvertFromType(sipRes, sipType_QHelpContentItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpContentModel, sipName_contentItemAt, doc_QHelpContentModel_contentItemAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpContentModel_data, "data(self, index: QModelIndex, role: int) -> Any");

extern "C" {static PyObject *meth_QHelpContentModel_data(PyObject *, PyObject *);}
static PyObject *meth_QHelpContentModel_data(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QHelpContentModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        int a1;
        const ::QHelpContentModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9i", &sipSelf, sipType_QHelpContentModel, &sipCpp, sipType_QModelIndex, &a0, &a1))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QHelpContentModel::data(*a0, a1) : sipCpp->data(*a0, a1)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpContentModel, sipName_data, doc_QHelpContentModel_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpContentModel_index, "index(self, row: int, column: int, parent: QModelIndex = QModelIndex()) -> QModelIndex");

extern "C" {static PyObject *meth_QHelpContentModel_index(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QHelpContentModel_index(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QHelpContentModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = QModelIndex();
        const ::QModelIndex* a2 = &a2def;
        const ::QHelpContentModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QHelpContentModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex((sipSelfWasArg ? sipCpp->::QHelpContentModel::index(a0, a1, *a2) : sipCpp->index(a0, a1, *a2)));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpContentModel, sipName_index, doc_QHelpContentModel_index);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpContentModel_parent, "parent(self, index: QModelIndex) -> QModelIndex");

extern "C" {static PyObject *meth_QHelpContentModel_parent(PyObject *, PyObject *);}
static PyObject *meth_QHelpContentModel_parent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QHelpContentModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QHelpContentModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QHelpContentModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex((sipSelfWasArg ? sipCpp->::QHelpContentModel::parent(*a0) : sipCpp->parent(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpContentModel, sipName_parent, doc_QHelpContentModel_parent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpContentModel_rowCount, "rowCount(self, parent: QModelIndex = QModelIndex()) -> int");

extern "C" {static PyObject *meth_QHelpContentModel_rowCount(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QHelpContentModel_rowCount(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QHelpContentModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex& a0def = QModelIndex();
        const ::QModelIndex* a0 = &a0def;
        const ::QHelpContentModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QHelpContentModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QHelpContentModel::rowCount(*a0) : sipCpp->rowCount(*a0));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpContentModel, sipName_rowCount, doc_QHelpContentModel_rowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpContentModel_columnCount, "columnCount(self, parent: QModelIndex = QModelIndex()) -> int");

extern "C" {static PyObject *meth_QHelpContentModel_columnCount(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QHelpContentModel_columnCount(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QHelpContentModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex& a0def = QModelIndex();
        const ::QModelIndex* a0 = &a0def;
        const ::QHelpContentModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QHelpContentModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QHelpContentModel::columnCount(*a0) : sipCpp->columnCount(*a0));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpContentModel, sipName_columnCount, doc_QHelpContentModel_columnCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpContentModel_isCreatingContents, "isCreatingContents(self) -> bool");

extern "C" {static PyObject *meth_QHelpContentModel_isCreatingContents(PyObject *, PyObject *);}
static PyObject *meth_QHelpContentModel_isCreatingContents(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpContentModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpContentModel, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isCreatingContents();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpContentModel, sipName_isCreatingContents, doc_QHelpContentModel_isCreatingContents);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QHelpContentModel(void *, const sipTypeDef *);}
static void *cast_QHelpContentModel(void *sipCppV, const sipTypeDef *targetType)
{
    ::QHelpContentModel *sipCpp = reinterpret_cast< ::QHelpContentModel *>(sipCppV);

    if (targetType == sipType_QHelpContentModel)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstractItemModel)->ctd_cast(static_cast< ::QAbstractItemModel *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHelpContentModel(void *, int);}
static void release_QHelpContentModel(void *sipCppV, int)
{
    ::QHelpContentModel *sipCpp = reinterpret_cast< ::QHelpContentModel *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QHelpContentModel(sipSimpleWrapper *);}
static void dealloc_QHelpContentModel(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHelpContentModel(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QHelpContentModel[] = {{0, 0, 1}};


static PyMethodDef methods_QHelpContentModel[] = {
    {sipName_columnCount, SIP_MLMETH_CAST(meth_QHelpContentModel_columnCount), METH_VARARGS|METH_KEYWORDS, doc_QHelpContentModel_columnCount},
    {sipName_contentItemAt, meth_QHelpContentModel_contentItemAt, METH_VARARGS, doc_QHelpContentModel_contentItemAt},
    {sipName_createContents, meth_QHelpContentModel_createContents, METH_VARARGS, doc_QHelpContentModel_createContents},
    {sipName_createContentsForCurrentFilter, meth_QHelpContentModel_createContentsForCurrentFilter, METH_VARARGS, doc_QHelpContentModel_createContentsForCurrentFilter},
    {sipName_data, meth_QHelpContentModel_data, METH_VARARGS, doc_QHelpContentModel_data},
    {sipName_index, SIP_MLMETH_CAST(meth_QHelpContentModel_index), METH_VARARGS|METH_KEYWORDS, doc_QHelpContentModel_index},
    {sipName_isCreatingContents, meth_QHelpContentModel_isCreatingContents, METH_VARARGS, doc_QHelpContentModel_isCreatingContents},
    {sipName_parent, meth_QHelpContentModel_parent, METH_VARARGS, doc_QHelpContentModel_parent},
    {sipName_rowCount, SIP_MLMETH_CAST(meth_QHelpContentModel_rowCount), METH_VARARGS|METH_KEYWORDS, doc_QHelpContentModel_rowCount}
};


/* Define this type's signals. */
static const pyqt6QtSignal signals_QHelpContentModel[] = {
    {"contentsCreated()", "\1contentsCreated(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"contentsCreationStarted()", "\1contentsCreationStarted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QHelpContentModel = {
    &::QHelpContentModel::staticMetaObject,
    signals_QHelpContentModel,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtHelp_QHelpContentModel = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHelpContentModel,
        SIP_NULLPTR,
        &plugin_QHelpContentModel,
    },
    {
        sipNameNr_QHelpContentModel,
        {0, 0, 1},
        9, methods_QHelpContentModel,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QHelpContentModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHelpContentModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QHelpContentModel,
    cast_QHelpContentModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
