/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qimage.sip"
#include <qimage.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 114 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qimagereader.sip"
#include <qimagereader.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"


class sipQBitmap : public ::QBitmap
{
public:
    sipQBitmap();
    sipQBitmap(int, int);
    sipQBitmap(const ::QSize&);
    sipQBitmap(const ::QString&, const char*);
    sipQBitmap(const ::QBitmap&);
    virtual ~sipQBitmap();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQBitmap(const sipQBitmap &);
    sipQBitmap &operator = (const sipQBitmap &);

    char sipPyMethods[3];
};

sipQBitmap::sipQBitmap(): ::QBitmap(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBitmap::sipQBitmap(int a0, int a1): ::QBitmap(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBitmap::sipQBitmap(const ::QSize& a0): ::QBitmap(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBitmap::sipQBitmap(const ::QString& a0, const char*a1): ::QBitmap(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBitmap::sipQBitmap(const ::QBitmap& a0): ::QBitmap(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBitmap::~sipQBitmap()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

int sipQBitmap::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QBitmap::metric(a0);

    extern int sipVH_QtGui_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtGui_23(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQBitmap::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QBitmap::paintEngine();

    extern ::QPaintEngine* sipVH_QtGui_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_22(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQBitmap::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QBitmap::devType();

    extern int sipVH_QtGui_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_13(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QBitmap_clear, "clear(self)");

extern "C" {static PyObject *meth_QBitmap_clear(PyObject *, PyObject *);}
static PyObject *meth_QBitmap_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBitmap *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBitmap, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBitmap, sipName_clear, doc_QBitmap_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBitmap_fromImage, "fromImage(image: QImage, flags: Qt.ImageConversionFlag = Qt.AutoColor) -> QBitmap");

extern "C" {static PyObject *meth_QBitmap_fromImage(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QBitmap_fromImage(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImage* a0;
        ::Qt::ImageConversionFlags a1def = Qt::AutoColor;
        ::Qt::ImageConversionFlags* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "CJ9|J1", &sipSelf, sipType_QImage, &a0, sipType_QFlags_0100Qt_ImageConversionFlag, &a1, &a1State))
        {
            ::QBitmap*sipRes;

            sipRes = new ::QBitmap(::QBitmap::fromImage(*a0, *a1));
            sipReleaseType(a1, sipType_QFlags_0100Qt_ImageConversionFlag, a1State);

            return sipConvertFromNewType(sipRes, sipType_QBitmap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBitmap, sipName_fromImage, doc_QBitmap_fromImage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBitmap_fromPixmap, "fromPixmap(pixmap: QPixmap) -> QBitmap");

extern "C" {static PyObject *meth_QBitmap_fromPixmap(PyObject *, PyObject *);}
static PyObject *meth_QBitmap_fromPixmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPixmap* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ9", &sipSelf, sipType_QPixmap, &a0))
        {
            ::QBitmap*sipRes;

            sipRes = new ::QBitmap(::QBitmap::fromPixmap(*a0));

            return sipConvertFromNewType(sipRes, sipType_QBitmap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBitmap, sipName_fromPixmap, doc_QBitmap_fromPixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBitmap_fromData, "fromData(size: QSize, bits: bytes, format: QImage.Format = QImage.Format_MonoLSB) -> QBitmap");

extern "C" {static PyObject *meth_QBitmap_fromData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QBitmap_fromData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        const ::uchar* a1;
        ::QImage::Format a2 = QImage::Format_MonoLSB;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "CJ9s|E", &sipSelf, sipType_QSize, &a0, &a1, sipType_QImage_Format, &a2))
        {
            ::QBitmap*sipRes;

            sipRes = new ::QBitmap(::QBitmap::fromData(*a0, a1, a2));

            return sipConvertFromNewType(sipRes, sipType_QBitmap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBitmap, sipName_fromData, doc_QBitmap_fromData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBitmap_transformed, "transformed(self, matrix: QTransform) -> QBitmap");

extern "C" {static PyObject *meth_QBitmap_transformed(PyObject *, PyObject *);}
static PyObject *meth_QBitmap_transformed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTransform* a0;
        const ::QBitmap *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QBitmap, &sipCpp, sipType_QTransform, &a0))
        {
            ::QBitmap*sipRes;

            sipRes = new ::QBitmap(sipCpp->transformed(*a0));

            return sipConvertFromNewType(sipRes, sipType_QBitmap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBitmap, sipName_transformed, doc_QBitmap_transformed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBitmap_swap, "swap(self, other: QBitmap)");

extern "C" {static PyObject *meth_QBitmap_swap(PyObject *, PyObject *);}
static PyObject *meth_QBitmap_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBitmap* a0;
        ::QBitmap *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QBitmap, &sipCpp, sipType_QBitmap, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBitmap, sipName_swap, doc_QBitmap_swap);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QBitmap(void *, const sipTypeDef *);}
static void *cast_QBitmap(void *sipCppV, const sipTypeDef *targetType)
{
    ::QBitmap *sipCpp = reinterpret_cast< ::QBitmap *>(sipCppV);

    if (targetType == sipType_QBitmap)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QPixmap)->ctd_cast(static_cast< ::QPixmap *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QBitmap(void *, int);}
static void release_QBitmap(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQBitmap *>(sipCppV);
    else
        delete reinterpret_cast< ::QBitmap *>(sipCppV);
}


extern "C" {static void *array_QBitmap(Py_ssize_t);}
static void *array_QBitmap(Py_ssize_t sipNrElem)
{
    return new ::QBitmap[sipNrElem];
}


extern "C" {static void array_delete_QBitmap(void *);}
static void array_delete_QBitmap(void *sipCpp)
{
    delete[] reinterpret_cast< ::QBitmap *>(sipCpp);
}


extern "C" {static void assign_QBitmap(void *, Py_ssize_t, void *);}
static void assign_QBitmap(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QBitmap *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QBitmap *>(sipSrc);
}


extern "C" {static void *copy_QBitmap(const void *, Py_ssize_t);}
static void *copy_QBitmap(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QBitmap(reinterpret_cast<const ::QBitmap *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QBitmap(sipSimpleWrapper *);}
static void dealloc_QBitmap(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQBitmap *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QBitmap(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QBitmap(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QBitmap(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQBitmap *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQBitmap();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        int a0;
        int a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "ii", &a0, &a1))
        {
            sipCpp = new sipQBitmap(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QSize* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QSize, &a0))
        {
            sipCpp = new sipQBitmap(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const char* a1 = 0;
        PyObject *a1Keep = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|AA", sipType_QString, &a0, &a0State, &a1Keep, &a1))
        {
            sipCpp = new sipQBitmap(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            Py_XDECREF(a1Keep);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QVariant* a0;
        PyObject *a0Wrapper;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "@J1", &a0Wrapper, sipType_QVariant, &a0, &a0State))
        {
            sipErrorState sipError = sipErrorNone;

#line 36 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
        if (a0->canConvert<QBitmap>())
            sipCpp = new sipQBitmap(a0->value<QBitmap>());
        else
            sipError = sipBadCallableArg(0, a0Wrapper);
#line 513 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQBitmap.cpp"
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            if (sipError == sipErrorNone)
            {
                sipCpp->sipPySelf = sipSelf;

                return sipCpp;
            }

            if (sipUnused)
            {
                Py_XDECREF(*sipUnused);
            }

            sipAddException(sipError, sipParseErr);

            if (sipError == sipErrorFail)
                return SIP_NULLPTR;
        }
    }

    {
        const ::QBitmap* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QBitmap, &a0))
        {
            sipCpp = new sipQBitmap(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QBitmap[] = {{240, 255, 1}};


static PyMethodDef methods_QBitmap[] = {
    {sipName_clear, meth_QBitmap_clear, METH_VARARGS, doc_QBitmap_clear},
    {sipName_fromData, SIP_MLMETH_CAST(meth_QBitmap_fromData), METH_VARARGS|METH_KEYWORDS, doc_QBitmap_fromData},
    {sipName_fromImage, SIP_MLMETH_CAST(meth_QBitmap_fromImage), METH_VARARGS|METH_KEYWORDS, doc_QBitmap_fromImage},
    {sipName_fromPixmap, meth_QBitmap_fromPixmap, METH_VARARGS, doc_QBitmap_fromPixmap},
    {sipName_swap, meth_QBitmap_swap, METH_VARARGS, doc_QBitmap_swap},
    {sipName_transformed, meth_QBitmap_transformed, METH_VARARGS, doc_QBitmap_transformed}
};

PyDoc_STRVAR(doc_QBitmap, "\1QBitmap()\n"
"QBitmap(w: int, h: int)\n"
"QBitmap(a0: QSize)\n"
"QBitmap(fileName: str|None, format: str = None)\n"
"QBitmap(variant: Any)\n"
"QBitmap(a0: QBitmap)");


sipClassTypeDef sipTypeDef_QtGui_QBitmap = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QBitmap,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QBitmap,
        {0, 0, 1},
        6, methods_QBitmap,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QBitmap,
    -1,
    -1,
    supers_QBitmap,
    SIP_NULLPTR,
    init_type_QBitmap,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QBitmap,
    assign_QBitmap,
    array_QBitmap,
    copy_QBitmap,
    release_QBitmap,
    cast_QBitmap,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QBitmap,
    sizeof (::QBitmap),
};
