/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeocircle.sip"
#include <qgeocircle.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoCircle.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeocoordinate.sip"
#include <qgeocoordinate.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoCircle.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeoshape.sip"
#include <qgeoshape.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoCircle.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoCircle.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeorectangle.sip"
#include <qgeorectangle.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoCircle.cpp"


PyDoc_STRVAR(doc_QGeoCircle_setCenter, "setCenter(self, center: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoCircle_setCenter(PyObject *, PyObject *);}
static PyObject *meth_QGeoCircle_setCenter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        ::QGeoCircle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoCircle, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            sipCpp->setCenter(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCircle, sipName_setCenter, doc_QGeoCircle_setCenter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCircle_center, "center(self) -> QGeoCoordinate");

extern "C" {static PyObject *meth_QGeoCircle_center(PyObject *, PyObject *);}
static PyObject *meth_QGeoCircle_center(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCircle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCircle, &sipCpp))
        {
            ::QGeoCoordinate*sipRes;

            sipRes = new ::QGeoCoordinate(sipCpp->center());

            return sipConvertFromNewType(sipRes, sipType_QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCircle, sipName_center, doc_QGeoCircle_center);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCircle_setRadius, "setRadius(self, radius: float)");

extern "C" {static PyObject *meth_QGeoCircle_setRadius(PyObject *, PyObject *);}
static PyObject *meth_QGeoCircle_setRadius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QGeoCircle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGeoCircle, &sipCpp, &a0))
        {
            sipCpp->setRadius(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCircle, sipName_setRadius, doc_QGeoCircle_setRadius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCircle_radius, "radius(self) -> float");

extern "C" {static PyObject *meth_QGeoCircle_radius(PyObject *, PyObject *);}
static PyObject *meth_QGeoCircle_radius(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCircle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCircle, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->radius();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCircle, sipName_radius, doc_QGeoCircle_radius);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCircle_translate, "translate(self, degreesLatitude: float, degreesLongitude: float)");

extern "C" {static PyObject *meth_QGeoCircle_translate(PyObject *, PyObject *);}
static PyObject *meth_QGeoCircle_translate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        double a1;
        ::QGeoCircle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QGeoCircle, &sipCpp, &a0, &a1))
        {
            sipCpp->translate(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCircle, sipName_translate, doc_QGeoCircle_translate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCircle_translated, "translated(self, degreesLatitude: float, degreesLongitude: float) -> QGeoCircle");

extern "C" {static PyObject *meth_QGeoCircle_translated(PyObject *, PyObject *);}
static PyObject *meth_QGeoCircle_translated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        double a1;
        const ::QGeoCircle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QGeoCircle, &sipCpp, &a0, &a1))
        {
            ::QGeoCircle*sipRes;

            sipRes = new ::QGeoCircle(sipCpp->translated(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QGeoCircle, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCircle, sipName_translated, doc_QGeoCircle_translated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCircle_toString, "toString(self) -> str");

extern "C" {static PyObject *meth_QGeoCircle_toString(PyObject *, PyObject *);}
static PyObject *meth_QGeoCircle_toString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCircle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCircle, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCircle, sipName_toString, doc_QGeoCircle_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCircle_extendCircle, "extendCircle(self, coordinate: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoCircle_extendCircle(PyObject *, PyObject *);}
static PyObject *meth_QGeoCircle_extendCircle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        ::QGeoCircle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoCircle, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            sipCpp->extendCircle(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCircle, sipName_extendCircle, doc_QGeoCircle_extendCircle);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGeoCircle(void *, const sipTypeDef *);}
static void *cast_QGeoCircle(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGeoCircle *sipCpp = reinterpret_cast< ::QGeoCircle *>(sipCppV);

    if (targetType == sipType_QGeoCircle)
        return sipCppV;

    if (targetType == sipType_QGeoShape)
        return static_cast< ::QGeoShape *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoCircle(void *, int);}
static void release_QGeoCircle(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGeoCircle *>(sipCppV);
}


extern "C" {static void *array_QGeoCircle(Py_ssize_t);}
static void *array_QGeoCircle(Py_ssize_t sipNrElem)
{
    return new ::QGeoCircle[sipNrElem];
}


extern "C" {static void array_delete_QGeoCircle(void *);}
static void array_delete_QGeoCircle(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoCircle *>(sipCpp);
}


extern "C" {static void assign_QGeoCircle(void *, Py_ssize_t, void *);}
static void assign_QGeoCircle(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGeoCircle *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGeoCircle *>(sipSrc);
}


extern "C" {static void *copy_QGeoCircle(const void *, Py_ssize_t);}
static void *copy_QGeoCircle(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGeoCircle(reinterpret_cast<const ::QGeoCircle *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGeoCircle(sipSimpleWrapper *);}
static void dealloc_QGeoCircle(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoCircle(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGeoCircle(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoCircle(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGeoCircle *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QGeoCircle();

            return sipCpp;
        }
    }

    {
        const ::QGeoCoordinate* a0;
        ::qreal a1 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_radius,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|d", sipType_QGeoCoordinate, &a0, &a1))
        {
            sipCpp = new ::QGeoCircle(*a0, a1);

            return sipCpp;
        }
    }

    {
        const ::QGeoCircle* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoCircle, &a0))
        {
            sipCpp = new ::QGeoCircle(*a0);

            return sipCpp;
        }
    }

    {
        const ::QGeoShape* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoShape, &a0))
        {
            sipCpp = new ::QGeoCircle(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGeoCircle[] = {{25, 255, 1}};


static PyMethodDef methods_QGeoCircle[] = {
    {sipName_center, meth_QGeoCircle_center, METH_VARARGS, doc_QGeoCircle_center},
    {sipName_extendCircle, meth_QGeoCircle_extendCircle, METH_VARARGS, doc_QGeoCircle_extendCircle},
    {sipName_radius, meth_QGeoCircle_radius, METH_VARARGS, doc_QGeoCircle_radius},
    {sipName_setCenter, meth_QGeoCircle_setCenter, METH_VARARGS, doc_QGeoCircle_setCenter},
    {sipName_setRadius, meth_QGeoCircle_setRadius, METH_VARARGS, doc_QGeoCircle_setRadius},
    {sipName_toString, meth_QGeoCircle_toString, METH_VARARGS, doc_QGeoCircle_toString},
    {sipName_translate, meth_QGeoCircle_translate, METH_VARARGS, doc_QGeoCircle_translate},
    {sipName_translated, meth_QGeoCircle_translated, METH_VARARGS, doc_QGeoCircle_translated}
};

PyDoc_STRVAR(doc_QGeoCircle, "\1QGeoCircle()\n"
"QGeoCircle(center: QGeoCoordinate, radius: float = -1)\n"
"QGeoCircle(other: QGeoCircle)\n"
"QGeoCircle(other: QGeoShape)");


sipClassTypeDef sipTypeDef_QtPositioning_QGeoCircle = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoCircle,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QGeoCircle,
        {0, 0, 1},
        8, methods_QGeoCircle,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoCircle,
    -1,
    -1,
    supers_QGeoCircle,
    SIP_NULLPTR,
    init_type_QGeoCircle,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoCircle,
    assign_QGeoCircle,
    array_QGeoCircle,
    copy_QGeoCircle,
    release_QGeoCircle,
    cast_QGeoCircle,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoCircle,
    sizeof (::QGeoCircle),
};
