/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtMultimediaWidgetsAPI_H
#define _QtMultimediaWidgetsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_PyQt6_QtMultimediaWidgets 0
#define sipName_PyQt6_QtMultimediaWidgets &sipStrings_QtMultimediaWidgets[0]
#define sipNameNr_aspectRatioModeChanged 26
#define sipName_aspectRatioModeChanged &sipStrings_QtMultimediaWidgets[26]
#define sipNameNr_mouseDoubleClickEvent 49
#define sipName_mouseDoubleClickEvent &sipStrings_QtMultimediaWidgets[49]
#define sipNameNr_QGraphicsVideoItem 71
#define sipName_QGraphicsVideoItem &sipStrings_QtMultimediaWidgets[71]
#define sipNameNr_focusNextPrevChild 90
#define sipName_focusNextPrevChild &sipStrings_QtMultimediaWidgets[90]
#define sipNameNr_setAspectRatioMode 109
#define sipName_setAspectRatioMode &sipStrings_QtMultimediaWidgets[109]
#define sipNameNr_fullScreenChanged 128
#define sipName_fullScreenChanged &sipStrings_QtMultimediaWidgets[128]
#define sipNameNr_hasHeightForWidth 146
#define sipName_hasHeightForWidth &sipStrings_QtMultimediaWidgets[146]
#define sipNameNr_mouseReleaseEvent 164
#define sipName_mouseReleaseEvent &sipStrings_QtMultimediaWidgets[164]
#define sipNameNr_nativeSizeChanged 182
#define sipName_nativeSizeChanged &sipStrings_QtMultimediaWidgets[182]
#define sipNameNr_collidesWithItem 200
#define sipName_collidesWithItem &sipStrings_QtMultimediaWidgets[200]
#define sipNameNr_collidesWithPath 217
#define sipName_collidesWithPath &sipStrings_QtMultimediaWidgets[217]
#define sipNameNr_contextMenuEvent 234
#define sipName_contextMenuEvent &sipStrings_QtMultimediaWidgets[234]
#define sipNameNr_disconnectNotify 251
#define sipName_disconnectNotify &sipStrings_QtMultimediaWidgets[251]
#define sipNameNr_inputMethodEvent 268
#define sipName_inputMethodEvent &sipStrings_QtMultimediaWidgets[268]
#define sipNameNr_inputMethodQuery 285
#define sipName_inputMethodQuery &sipStrings_QtMultimediaWidgets[285]
#define sipNameNr_sceneEventFilter 302
#define sipName_sceneEventFilter &sipStrings_QtMultimediaWidgets[302]
#define sipNameNr_aspectRatioMode 319
#define sipName_aspectRatioMode &sipStrings_QtMultimediaWidgets[319]
#define sipNameNr_hoverEnterEvent 335
#define sipName_hoverEnterEvent &sipStrings_QtMultimediaWidgets[335]
#define sipNameNr_hoverLeaveEvent 351
#define sipName_hoverLeaveEvent &sipStrings_QtMultimediaWidgets[351]
#define sipNameNr_keyReleaseEvent 367
#define sipName_keyReleaseEvent &sipStrings_QtMultimediaWidgets[367]
#define sipNameNr_minimumSizeHint 383
#define sipName_minimumSizeHint &sipStrings_QtMultimediaWidgets[383]
#define sipNameNr_mousePressEvent 399
#define sipName_mousePressEvent &sipStrings_QtMultimediaWidgets[399]
#define sipNameNr_dragEnterEvent 415
#define sipName_dragEnterEvent &sipStrings_QtMultimediaWidgets[415]
#define sipNameNr_dragLeaveEvent 430
#define sipName_dragLeaveEvent &sipStrings_QtMultimediaWidgets[430]
#define sipNameNr_heightForWidth 445
#define sipName_heightForWidth &sipStrings_QtMultimediaWidgets[445]
#define sipNameNr_hoverMoveEvent 460
#define sipName_hoverMoveEvent &sipStrings_QtMultimediaWidgets[460]
#define sipNameNr_mouseMoveEvent 475
#define sipName_mouseMoveEvent &sipStrings_QtMultimediaWidgets[475]
#define sipNameNr_connectNotify 254
#define sipName_connectNotify &sipStrings_QtMultimediaWidgets[254]
#define sipNameNr_dragMoveEvent 490
#define sipName_dragMoveEvent &sipStrings_QtMultimediaWidgets[490]
#define sipNameNr_focusOutEvent 504
#define sipName_focusOutEvent &sipStrings_QtMultimediaWidgets[504]
#define sipNameNr_keyPressEvent 518
#define sipName_keyPressEvent &sipStrings_QtMultimediaWidgets[518]
#define sipNameNr_setFullScreen 532
#define sipName_setFullScreen &sipStrings_QtMultimediaWidgets[532]
#define sipNameNr_sharedPainter 546
#define sipName_sharedPainter &sipStrings_QtMultimediaWidgets[546]
#define sipNameNr_QVideoWidget 560
#define sipName_QVideoWidget &sipStrings_QtMultimediaWidgets[560]
#define sipNameNr_boundingRect 573
#define sipName_boundingRect &sipStrings_QtMultimediaWidgets[573]
#define sipNameNr_focusInEvent 586
#define sipName_focusInEvent &sipStrings_QtMultimediaWidgets[586]
#define sipNameNr_isFullScreen 599
#define sipName_isFullScreen &sipStrings_QtMultimediaWidgets[599]
#define sipNameNr_isObscuredBy 612
#define sipName_isObscuredBy &sipStrings_QtMultimediaWidgets[612]
#define sipNameNr_actionEvent 625
#define sipName_actionEvent &sipStrings_QtMultimediaWidgets[625]
#define sipNameNr_changeEvent 637
#define sipName_changeEvent &sipStrings_QtMultimediaWidgets[637]
#define sipNameNr_customEvent 649
#define sipName_customEvent &sipStrings_QtMultimediaWidgets[649]
#define sipNameNr_eventFilter 661
#define sipName_eventFilter &sipStrings_QtMultimediaWidgets[661]
#define sipNameNr_initPainter 673
#define sipName_initPainter &sipStrings_QtMultimediaWidgets[673]
#define sipNameNr_nativeEvent 685
#define sipName_nativeEvent &sipStrings_QtMultimediaWidgets[685]
#define sipNameNr_paintEngine 697
#define sipName_paintEngine &sipStrings_QtMultimediaWidgets[697]
#define sipNameNr_resizeEvent 709
#define sipName_resizeEvent &sipStrings_QtMultimediaWidgets[709]
#define sipNameNr_tabletEvent 721
#define sipName_tabletEvent &sipStrings_QtMultimediaWidgets[721]
#define sipNameNr_childEvent 733
#define sipName_childEvent &sipStrings_QtMultimediaWidgets[733]
#define sipNameNr_closeEvent 744
#define sipName_closeEvent &sipStrings_QtMultimediaWidgets[744]
#define sipNameNr_enterEvent 755
#define sipName_enterEvent &sipStrings_QtMultimediaWidgets[755]
#define sipNameNr_itemChange 766
#define sipName_itemChange &sipStrings_QtMultimediaWidgets[766]
#define sipNameNr_leaveEvent 777
#define sipName_leaveEvent &sipStrings_QtMultimediaWidgets[777]
#define sipNameNr_nativeSize 788
#define sipName_nativeSize &sipStrings_QtMultimediaWidgets[788]
#define sipNameNr_opaqueArea 799
#define sipName_opaqueArea &sipStrings_QtMultimediaWidgets[799]
#define sipNameNr_paintEvent 810
#define sipName_paintEvent &sipStrings_QtMultimediaWidgets[810]
#define sipNameNr_sceneEvent 821
#define sipName_sceneEvent &sipStrings_QtMultimediaWidgets[821]
#define sipNameNr_setVisible 832
#define sipName_setVisible &sipStrings_QtMultimediaWidgets[832]
#define sipNameNr_timerEvent 843
#define sipName_timerEvent &sipStrings_QtMultimediaWidgets[843]
#define sipNameNr_wheelEvent 854
#define sipName_wheelEvent &sipStrings_QtMultimediaWidgets[854]
#define sipNameNr_dropEvent 865
#define sipName_dropEvent &sipStrings_QtMultimediaWidgets[865]
#define sipNameNr_hideEvent 875
#define sipName_hideEvent &sipStrings_QtMultimediaWidgets[875]
#define sipNameNr_moveEvent 885
#define sipName_moveEvent &sipStrings_QtMultimediaWidgets[885]
#define sipNameNr_setOffset 895
#define sipName_setOffset &sipStrings_QtMultimediaWidgets[895]
#define sipNameNr_showEvent 905
#define sipName_showEvent &sipStrings_QtMultimediaWidgets[905]
#define sipNameNr_videoSink 915
#define sipName_videoSink &sipStrings_QtMultimediaWidgets[915]
#define sipNameNr_contains 925
#define sipName_contains &sipStrings_QtMultimediaWidgets[925]
#define sipNameNr_sizeHint 934
#define sipName_sizeHint &sipStrings_QtMultimediaWidgets[934]
#define sipNameNr_advance 943
#define sipName_advance &sipStrings_QtMultimediaWidgets[943]
#define sipNameNr_devType 951
#define sipName_devType &sipStrings_QtMultimediaWidgets[951]
#define sipNameNr_setSize 959
#define sipName_setSize &sipStrings_QtMultimediaWidgets[959]
#define sipNameNr_metric 967
#define sipName_metric &sipStrings_QtMultimediaWidgets[967]
#define sipNameNr_offset 974
#define sipName_offset &sipStrings_QtMultimediaWidgets[974]
#define sipNameNr_parent 981
#define sipName_parent &sipStrings_QtMultimediaWidgets[981]
#define sipNameNr_widget 988
#define sipName_widget &sipStrings_QtMultimediaWidgets[988]
#define sipNameNr_event 995
#define sipName_event &sipStrings_QtMultimediaWidgets[995]
#define sipNameNr_paint 1001
#define sipName_paint &sipStrings_QtMultimediaWidgets[1001]
#define sipNameNr_shape 1007
#define sipName_shape &sipStrings_QtMultimediaWidgets[1007]
#define sipNameNr_size 1013
#define sipName_size &sipStrings_QtMultimediaWidgets[1013]
#define sipNameNr_type 1018
#define sipName_type &sipStrings_QtMultimediaWidgets[1018]

#define sipMalloc                   sipAPI_QtMultimediaWidgets->api_malloc
#define sipFree                     sipAPI_QtMultimediaWidgets->api_free
#define sipBuildResult              sipAPI_QtMultimediaWidgets->api_build_result
#define sipCallMethod               sipAPI_QtMultimediaWidgets->api_call_method
#define sipCallProcedureMethod      sipAPI_QtMultimediaWidgets->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtMultimediaWidgets->api_call_error_handler
#define sipParseResultEx            sipAPI_QtMultimediaWidgets->api_parse_result_ex
#define sipParseResult              sipAPI_QtMultimediaWidgets->api_parse_result
#define sipParseArgs                sipAPI_QtMultimediaWidgets->api_parse_args
#define sipParseKwdArgs             sipAPI_QtMultimediaWidgets->api_parse_kwd_args
#define sipParsePair                sipAPI_QtMultimediaWidgets->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtMultimediaWidgets->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtMultimediaWidgets->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtMultimediaWidgets->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtMultimediaWidgets->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtMultimediaWidgets->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtMultimediaWidgets->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtMultimediaWidgets->api_add_exception
#define sipNoFunction               sipAPI_QtMultimediaWidgets->api_no_function
#define sipNoMethod                 sipAPI_QtMultimediaWidgets->api_no_method
#define sipAbstractMethod           sipAPI_QtMultimediaWidgets->api_abstract_method
#define sipBadClass                 sipAPI_QtMultimediaWidgets->api_bad_class
#define sipBadCatcherResult         sipAPI_QtMultimediaWidgets->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtMultimediaWidgets->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtMultimediaWidgets->api_bad_operator_arg
#define sipTrace                    sipAPI_QtMultimediaWidgets->api_trace
#define sipTransferBack             sipAPI_QtMultimediaWidgets->api_transfer_back
#define sipTransferTo               sipAPI_QtMultimediaWidgets->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtMultimediaWidgets->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtMultimediaWidgets->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtMultimediaWidgets->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtMultimediaWidgets->api_voidptr_type
#define sipGetPyObject              sipAPI_QtMultimediaWidgets->api_get_pyobject
#define sipGetAddress               sipAPI_QtMultimediaWidgets->api_get_address
#define sipGetMixinAddress          sipAPI_QtMultimediaWidgets->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtMultimediaWidgets->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtMultimediaWidgets->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtMultimediaWidgets->api_call_hook
#define sipEndThread                sipAPI_QtMultimediaWidgets->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtMultimediaWidgets->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtMultimediaWidgets->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtMultimediaWidgets->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtMultimediaWidgets->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtMultimediaWidgets->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtMultimediaWidgets->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtMultimediaWidgets->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtMultimediaWidgets->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtMultimediaWidgets->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtMultimediaWidgets->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtMultimediaWidgets->api_convert_to_bool
#define sipReleaseType              sipAPI_QtMultimediaWidgets->api_release_type
#define sipConvertFromType          sipAPI_QtMultimediaWidgets->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtMultimediaWidgets->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtMultimediaWidgets->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtMultimediaWidgets->api_convert_from_enum
#define sipGetState                 sipAPI_QtMultimediaWidgets->api_get_state
#define sipExportSymbol             sipAPI_QtMultimediaWidgets->api_export_symbol
#define sipImportSymbol             sipAPI_QtMultimediaWidgets->api_import_symbol
#define sipFindType                 sipAPI_QtMultimediaWidgets->api_find_type
#define sipBytes_AsChar             sipAPI_QtMultimediaWidgets->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtMultimediaWidgets->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtMultimediaWidgets->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtMultimediaWidgets->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtMultimediaWidgets->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtMultimediaWidgets->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtMultimediaWidgets->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtMultimediaWidgets->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtMultimediaWidgets->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtMultimediaWidgets->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtMultimediaWidgets->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtMultimediaWidgets->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtMultimediaWidgets->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtMultimediaWidgets->api_get_reference
#define sipKeepReference            sipAPI_QtMultimediaWidgets->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtMultimediaWidgets->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtMultimediaWidgets->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtMultimediaWidgets->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtMultimediaWidgets->api_type_scope
#define sipResolveTypedef           sipAPI_QtMultimediaWidgets->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtMultimediaWidgets->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtMultimediaWidgets->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtMultimediaWidgets->api_init_mixin
#define sipExportModule             sipAPI_QtMultimediaWidgets->api_export_module
#define sipInitModule               sipAPI_QtMultimediaWidgets->api_init_module
#define sipGetInterpreter           sipAPI_QtMultimediaWidgets->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtMultimediaWidgets->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtMultimediaWidgets->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtMultimediaWidgets->api_py_type_dict
#define sipPyTypeName               sipAPI_QtMultimediaWidgets->api_py_type_name
#define sipGetCFunction             sipAPI_QtMultimediaWidgets->api_get_c_function
#define sipGetMethod                sipAPI_QtMultimediaWidgets->api_get_method
#define sipFromMethod               sipAPI_QtMultimediaWidgets->api_from_method
#define sipGetDate                  sipAPI_QtMultimediaWidgets->api_get_date
#define sipFromDate                 sipAPI_QtMultimediaWidgets->api_from_date
#define sipGetDateTime              sipAPI_QtMultimediaWidgets->api_get_datetime
#define sipFromDateTime             sipAPI_QtMultimediaWidgets->api_from_datetime
#define sipGetTime                  sipAPI_QtMultimediaWidgets->api_get_time
#define sipFromTime                 sipAPI_QtMultimediaWidgets->api_from_time
#define sipIsUserType               sipAPI_QtMultimediaWidgets->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtMultimediaWidgets->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtMultimediaWidgets->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtMultimediaWidgets->api_unicode_write
#define sipUnicodeData              sipAPI_QtMultimediaWidgets->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtMultimediaWidgets->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtMultimediaWidgets->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtMultimediaWidgets->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtMultimediaWidgets->api_is_derived_class
#define sipGetUserObject            sipAPI_QtMultimediaWidgets->api_get_user_object
#define sipSetUserObject            sipAPI_QtMultimediaWidgets->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtMultimediaWidgets->api_register_event_handler
#define sipConvertToArray           sipAPI_QtMultimediaWidgets->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtMultimediaWidgets->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtMultimediaWidgets->api_enable_gc
#define sipPrintObject              sipAPI_QtMultimediaWidgets->api_print_object
#define sipLong_AsChar              sipAPI_QtMultimediaWidgets->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtMultimediaWidgets->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtMultimediaWidgets->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtMultimediaWidgets->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtMultimediaWidgets->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtMultimediaWidgets->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtMultimediaWidgets->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtMultimediaWidgets->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtMultimediaWidgets->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtMultimediaWidgets->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtMultimediaWidgets->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtMultimediaWidgets->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtMultimediaWidgets->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtMultimediaWidgets->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtMultimediaWidgets->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtMultimediaWidgets->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtMultimediaWidgets->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtMultimediaWidgets->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtMultimediaWidgets->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtMultimediaWidgets->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtMultimediaWidgets->api_release_type_us
#define sipIsPyMethod               sipAPI_QtMultimediaWidgets->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtMultimediaWidgets[];

#define sipType_QGraphicsVideoItem sipExportedTypes_QtMultimediaWidgets[0]

extern sipClassTypeDef sipTypeDef_QtMultimediaWidgets_QGraphicsVideoItem;

#define sipType_QVideoWidget sipExportedTypes_QtMultimediaWidgets[1]

extern sipClassTypeDef sipTypeDef_QtMultimediaWidgets_QVideoWidget;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtMultimediaWidgets;
extern sipExportedModuleDef sipModuleAPI_QtMultimediaWidgets;
extern sipTypeDef *sipExportedTypes_QtMultimediaWidgets[];

#define sipType_Qt_ItemSelectionMode sipImportedTypes_QtMultimediaWidgets_QtCore[13].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtMultimediaWidgets_QtCore[12].it_td

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtMultimediaWidgets_QtCore[11].it_td

#define sipType_QObject sipImportedTypes_QtMultimediaWidgets_QtCore[4].it_td

#define sipType_QByteArray sipImportedTypes_QtMultimediaWidgets_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtMultimediaWidgets_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtMultimediaWidgets_QtCore[9].it_td

#define sipType_QChildEvent sipImportedTypes_QtMultimediaWidgets_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtMultimediaWidgets_QtCore[3].it_td

#define sipType_QPointF sipImportedTypes_QtMultimediaWidgets_QtCore[5].it_td

#define sipType_QRectF sipImportedTypes_QtMultimediaWidgets_QtCore[6].it_td

#define sipType_QSize sipImportedTypes_QtMultimediaWidgets_QtCore[7].it_td

#define sipType_QSizeF sipImportedTypes_QtMultimediaWidgets_QtCore[8].it_td

#define sipType_QVariant sipImportedTypes_QtMultimediaWidgets_QtCore[10].it_td

#define sipType_qintptr sipImportedTypes_QtMultimediaWidgets_QtCore[14].it_td
extern sipImportedTypeDef sipImportedTypes_QtMultimediaWidgets_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtMultimediaWidgets_QtGui[14].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtMultimediaWidgets_QtGui[15].it_td

#define sipType_QKeyEvent sipImportedTypes_QtMultimediaWidgets_QtGui[11].it_td

#define sipType_QFocusEvent sipImportedTypes_QtMultimediaWidgets_QtGui[8].it_td

#define sipType_QPaintEvent sipImportedTypes_QtMultimediaWidgets_QtGui[17].it_td

#define sipType_QMoveEvent sipImportedTypes_QtMultimediaWidgets_QtGui[13].it_td

#define sipType_QResizeEvent sipImportedTypes_QtMultimediaWidgets_QtGui[20].it_td

#define sipType_QCloseEvent sipImportedTypes_QtMultimediaWidgets_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtMultimediaWidgets_QtGui[21].it_td

#define sipType_QHideEvent sipImportedTypes_QtMultimediaWidgets_QtGui[9].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtMultimediaWidgets_QtGui[2].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtMultimediaWidgets_QtGui[10].it_td

#define sipType_QDropEvent sipImportedTypes_QtMultimediaWidgets_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtMultimediaWidgets_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtMultimediaWidgets_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtMultimediaWidgets_QtGui[4].it_td

#define sipType_QActionEvent sipImportedTypes_QtMultimediaWidgets_QtGui[0].it_td

#define sipType_QEnterEvent sipImportedTypes_QtMultimediaWidgets_QtGui[7].it_td

#define sipType_QMouseEvent sipImportedTypes_QtMultimediaWidgets_QtGui[12].it_td

#define sipType_QWheelEvent sipImportedTypes_QtMultimediaWidgets_QtGui[23].it_td

#define sipType_QTabletEvent sipImportedTypes_QtMultimediaWidgets_QtGui[22].it_td

#define sipType_QPaintEngine sipImportedTypes_QtMultimediaWidgets_QtGui[16].it_td

#define sipType_QPainter sipImportedTypes_QtMultimediaWidgets_QtGui[18].it_td

#define sipType_QPainterPath sipImportedTypes_QtMultimediaWidgets_QtGui[19].it_td
extern sipImportedTypeDef sipImportedTypes_QtMultimediaWidgets_QtGui[];

#define sipType_QVideoSink sipImportedTypes_QtMultimediaWidgets_QtMultimedia[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtMultimediaWidgets_QtMultimedia[];

#define sipType_QWidget sipImportedTypes_QtMultimediaWidgets_QtWidgets[9].it_td

#define sipType_QGraphicsItem sipImportedTypes_QtMultimediaWidgets_QtWidgets[0].it_td

#define sipType_QGraphicsItem_GraphicsItemChange sipImportedTypes_QtMultimediaWidgets_QtWidgets[1].it_td

#define sipType_QGraphicsObject sipImportedTypes_QtMultimediaWidgets_QtWidgets[2].it_td

#define sipType_QGraphicsSceneMouseEvent sipImportedTypes_QtMultimediaWidgets_QtWidgets[6].it_td

#define sipType_QGraphicsSceneWheelEvent sipImportedTypes_QtMultimediaWidgets_QtWidgets[7].it_td

#define sipType_QGraphicsSceneContextMenuEvent sipImportedTypes_QtMultimediaWidgets_QtWidgets[3].it_td

#define sipType_QGraphicsSceneHoverEvent sipImportedTypes_QtMultimediaWidgets_QtWidgets[5].it_td

#define sipType_QGraphicsSceneDragDropEvent sipImportedTypes_QtMultimediaWidgets_QtWidgets[4].it_td

#define sipType_QStyleOptionGraphicsItem sipImportedTypes_QtMultimediaWidgets_QtWidgets[8].it_td
extern sipImportedTypeDef sipImportedTypes_QtMultimediaWidgets_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtMultimediaWidgets_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtMultimediaWidgets_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtMultimediaWidgets_qt_metacast;

#endif
