/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebChannel.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWebChannel/qwebchannel.sip"
#include <qwebchannel.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWebChannel/qwebchannelabstracttransport.sip"
#include <qwebchannelabstracttransport.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebChannel/sipQtWebChannelQWebChannel.cpp"


class sipQWebChannel : public ::QWebChannel
{
public:
    sipQWebChannel(::QObject*);
    virtual ~sipQWebChannel();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQWebChannel(const sipQWebChannel &);
    sipQWebChannel &operator = (const sipQWebChannel &);

    char sipPyMethods[7];
};

sipQWebChannel::sipQWebChannel(::QObject*a0): ::QWebChannel(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQWebChannel::~sipQWebChannel()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQWebChannel::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWebChannel_qt_metaobject(sipPySelf, sipType_QWebChannel);

    return ::QWebChannel::metaObject();
}

int sipQWebChannel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QWebChannel::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWebChannel_qt_metacall(sipPySelf, sipType_QWebChannel, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQWebChannel::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWebChannel_qt_metacast(sipPySelf, sipType_QWebChannel, _clname, &sipCpp) ? sipCpp : ::QWebChannel::qt_metacast(_clname));
}

bool sipQWebChannel::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QWebChannel::event(a0);

    extern bool sipVH_QtWebChannel_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWebChannel_5(sipGILState, sipImportedVirtErrorHandlers_QtWebChannel_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebChannel::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QWebChannel::eventFilter(a0, a1);

    extern bool sipVH_QtWebChannel_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWebChannel_4(sipGILState, sipImportedVirtErrorHandlers_QtWebChannel_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQWebChannel::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QWebChannel::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWebChannel_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWebChannel_3(sipGILState, sipImportedVirtErrorHandlers_QtWebChannel_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebChannel::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QWebChannel::childEvent(a0);
        return;
    }

    extern void sipVH_QtWebChannel_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWebChannel_2(sipGILState, sipImportedVirtErrorHandlers_QtWebChannel_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebChannel::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QWebChannel::customEvent(a0);
        return;
    }

    extern void sipVH_QtWebChannel_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebChannel_1(sipGILState, sipImportedVirtErrorHandlers_QtWebChannel_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebChannel::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QWebChannel::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWebChannel_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebChannel_0(sipGILState, sipImportedVirtErrorHandlers_QtWebChannel_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebChannel::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QWebChannel::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWebChannel_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebChannel_0(sipGILState, sipImportedVirtErrorHandlers_QtWebChannel_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QWebChannel_registerObjects, "registerObjects(self, objects: dict[str|None, QObject])");

extern "C" {static PyObject *meth_QWebChannel_registerObjects(PyObject *, PyObject *);}
static PyObject *meth_QWebChannel_registerObjects(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QHash< ::QString, ::QObject*>* a0;
        int a0State = 0;
        ::QWebChannel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebChannel, &sipCpp, sipType_QHash_0100QString_0101QObject, &a0, &a0State))
        {
            sipCpp->registerObjects(*a0);
            sipReleaseType(const_cast<QHash< ::QString, ::QObject*> *>(a0), sipType_QHash_0100QString_0101QObject, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebChannel, sipName_registerObjects, doc_QWebChannel_registerObjects);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebChannel_registeredObjects, "registeredObjects(self) -> dict[str, QObject]");

extern "C" {static PyObject *meth_QWebChannel_registeredObjects(PyObject *, PyObject *);}
static PyObject *meth_QWebChannel_registeredObjects(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebChannel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebChannel, &sipCpp))
        {
            QHash< ::QString, ::QObject*>*sipRes;

            sipRes = new QHash< ::QString, ::QObject*>(sipCpp->registeredObjects());

            return sipConvertFromNewType(sipRes, sipType_QHash_0100QString_0101QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebChannel, sipName_registeredObjects, doc_QWebChannel_registeredObjects);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebChannel_registerObject, "registerObject(self, id: str|None, object: QObject|None)");

extern "C" {static PyObject *meth_QWebChannel_registerObject(PyObject *, PyObject *);}
static PyObject *meth_QWebChannel_registerObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1;
        ::QWebChannel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J8", &sipSelf, sipType_QWebChannel, &sipCpp, sipType_QString, &a0, &a0State, sipType_QObject, &a1))
        {
            sipCpp->registerObject(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebChannel, sipName_registerObject, doc_QWebChannel_registerObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebChannel_deregisterObject, "deregisterObject(self, object: QObject|None)");

extern "C" {static PyObject *meth_QWebChannel_deregisterObject(PyObject *, PyObject *);}
static PyObject *meth_QWebChannel_deregisterObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        ::QWebChannel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebChannel, &sipCpp, sipType_QObject, &a0))
        {
            sipCpp->deregisterObject(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebChannel, sipName_deregisterObject, doc_QWebChannel_deregisterObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebChannel_blockUpdates, "blockUpdates(self) -> bool");

extern "C" {static PyObject *meth_QWebChannel_blockUpdates(PyObject *, PyObject *);}
static PyObject *meth_QWebChannel_blockUpdates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebChannel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebChannel, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->blockUpdates();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebChannel, sipName_blockUpdates, doc_QWebChannel_blockUpdates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebChannel_setBlockUpdates, "setBlockUpdates(self, block: bool)");

extern "C" {static PyObject *meth_QWebChannel_setBlockUpdates(PyObject *, PyObject *);}
static PyObject *meth_QWebChannel_setBlockUpdates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QWebChannel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWebChannel, &sipCpp, &a0))
        {
            sipCpp->setBlockUpdates(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebChannel, sipName_setBlockUpdates, doc_QWebChannel_setBlockUpdates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebChannel_propertyUpdateInterval, "propertyUpdateInterval(self) -> int");

extern "C" {static PyObject *meth_QWebChannel_propertyUpdateInterval(PyObject *, PyObject *);}
static PyObject *meth_QWebChannel_propertyUpdateInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebChannel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebChannel, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->propertyUpdateInterval();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebChannel, sipName_propertyUpdateInterval, doc_QWebChannel_propertyUpdateInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebChannel_setPropertyUpdateInterval, "setPropertyUpdateInterval(self, ms: int)");

extern "C" {static PyObject *meth_QWebChannel_setPropertyUpdateInterval(PyObject *, PyObject *);}
static PyObject *meth_QWebChannel_setPropertyUpdateInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QWebChannel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWebChannel, &sipCpp, &a0))
        {
            sipCpp->setPropertyUpdateInterval(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebChannel, sipName_setPropertyUpdateInterval, doc_QWebChannel_setPropertyUpdateInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebChannel_connectTo, "connectTo(self, transport: QWebChannelAbstractTransport|None)");

extern "C" {static PyObject *meth_QWebChannel_connectTo(PyObject *, PyObject *);}
static PyObject *meth_QWebChannel_connectTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebChannelAbstractTransport* a0;
        ::QWebChannel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebChannel, &sipCpp, sipType_QWebChannelAbstractTransport, &a0))
        {
            sipCpp->connectTo(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebChannel, sipName_connectTo, doc_QWebChannel_connectTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebChannel_disconnectFrom, "disconnectFrom(self, transport: QWebChannelAbstractTransport|None)");

extern "C" {static PyObject *meth_QWebChannel_disconnectFrom(PyObject *, PyObject *);}
static PyObject *meth_QWebChannel_disconnectFrom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebChannelAbstractTransport* a0;
        ::QWebChannel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebChannel, &sipCpp, sipType_QWebChannelAbstractTransport, &a0))
        {
            sipCpp->disconnectFrom(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebChannel, sipName_disconnectFrom, doc_QWebChannel_disconnectFrom);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWebChannel(void *, const sipTypeDef *);}
static void *cast_QWebChannel(void *sipCppV, const sipTypeDef *targetType)
{
    ::QWebChannel *sipCpp = reinterpret_cast< ::QWebChannel *>(sipCppV);

    if (targetType == sipType_QWebChannel)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebChannel(void *, int);}
static void release_QWebChannel(void *sipCppV, int)
{
    ::QWebChannel *sipCpp = reinterpret_cast< ::QWebChannel *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QWebChannel(Py_ssize_t);}
static void *array_QWebChannel(Py_ssize_t sipNrElem)
{
    return new ::QWebChannel[sipNrElem];
}


extern "C" {static void array_delete_QWebChannel(void *);}
static void array_delete_QWebChannel(void *sipCpp)
{
    delete[] reinterpret_cast< ::QWebChannel *>(sipCpp);
}


extern "C" {static void dealloc_QWebChannel(sipSimpleWrapper *);}
static void dealloc_QWebChannel(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQWebChannel *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebChannel(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QWebChannel(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebChannel(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQWebChannel *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQWebChannel(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWebChannel[] = {{4, 0, 1}};


static PyMethodDef methods_QWebChannel[] = {
    {sipName_blockUpdates, meth_QWebChannel_blockUpdates, METH_VARARGS, doc_QWebChannel_blockUpdates},
    {sipName_connectTo, meth_QWebChannel_connectTo, METH_VARARGS, doc_QWebChannel_connectTo},
    {sipName_deregisterObject, meth_QWebChannel_deregisterObject, METH_VARARGS, doc_QWebChannel_deregisterObject},
    {sipName_disconnectFrom, meth_QWebChannel_disconnectFrom, METH_VARARGS, doc_QWebChannel_disconnectFrom},
    {sipName_propertyUpdateInterval, meth_QWebChannel_propertyUpdateInterval, METH_VARARGS, doc_QWebChannel_propertyUpdateInterval},
    {sipName_registerObject, meth_QWebChannel_registerObject, METH_VARARGS, doc_QWebChannel_registerObject},
    {sipName_registerObjects, meth_QWebChannel_registerObjects, METH_VARARGS, doc_QWebChannel_registerObjects},
    {sipName_registeredObjects, meth_QWebChannel_registeredObjects, METH_VARARGS, doc_QWebChannel_registeredObjects},
    {sipName_setBlockUpdates, meth_QWebChannel_setBlockUpdates, METH_VARARGS, doc_QWebChannel_setBlockUpdates},
    {sipName_setPropertyUpdateInterval, meth_QWebChannel_setPropertyUpdateInterval, METH_VARARGS, doc_QWebChannel_setPropertyUpdateInterval}
};

PyDoc_STRVAR(doc_QWebChannel, "\1QWebChannel(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QWebChannel[] = {
    {"blockUpdatesChanged(bool)", "\1blockUpdatesChanged(self, block: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QWebChannel = {
    &::QWebChannel::staticMetaObject,
    signals_QWebChannel,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebChannel_QWebChannel = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebChannel,
        SIP_NULLPTR,
        &plugin_QWebChannel,
    },
    {
        sipNameNr_QWebChannel,
        {0, 0, 1},
        10, methods_QWebChannel,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebChannel,
    -1,
    -1,
    supers_QWebChannel,
    SIP_NULLPTR,
    init_type_QWebChannel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebChannel,
    SIP_NULLPTR,
    array_QWebChannel,
    SIP_NULLPTR,
    release_QWebChannel,
    cast_QWebChannel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QWebChannel,
    sizeof (::QWebChannel),
};
