/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 49 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qoperatingsystemversion.sip"
#include <qoperatingsystemversion.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQOperatingSystemVersion.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qoperatingsystemversion.sip"
#include <qoperatingsystemversion.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQOperatingSystemVersion.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQOperatingSystemVersion.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qversionnumber.sip"
#include <qversionnumber.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQOperatingSystemVersion.cpp"


PyDoc_STRVAR(doc_QOperatingSystemVersion_current, "current() -> QOperatingSystemVersion");

extern "C" {static PyObject *meth_QOperatingSystemVersion_current(PyObject *, PyObject *);}
static PyObject *meth_QOperatingSystemVersion_current(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QOperatingSystemVersion*sipRes;

            sipRes = new ::QOperatingSystemVersion(::QOperatingSystemVersion::current());

            return sipConvertFromNewType(sipRes, sipType_QOperatingSystemVersion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOperatingSystemVersion, sipName_current, doc_QOperatingSystemVersion_current);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOperatingSystemVersion_currentType, "currentType() -> QOperatingSystemVersion.OSType");

extern "C" {static PyObject *meth_QOperatingSystemVersion_currentType(PyObject *, PyObject *);}
static PyObject *meth_QOperatingSystemVersion_currentType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QOperatingSystemVersion::OSType sipRes;

            sipRes = ::QOperatingSystemVersion::currentType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QOperatingSystemVersion_OSType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOperatingSystemVersion, sipName_currentType, doc_QOperatingSystemVersion_currentType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOperatingSystemVersion_type, "type(self) -> QOperatingSystemVersion.OSType");

extern "C" {static PyObject *meth_QOperatingSystemVersion_type(PyObject *, PyObject *);}
static PyObject *meth_QOperatingSystemVersion_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOperatingSystemVersion *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOperatingSystemVersion, &sipCpp))
        {
            ::QOperatingSystemVersion::OSType sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QOperatingSystemVersion_OSType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOperatingSystemVersion, sipName_type, doc_QOperatingSystemVersion_type);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QOperatingSystemVersion(void *, const sipTypeDef *);}
static void *cast_QOperatingSystemVersion(void *sipCppV, const sipTypeDef *targetType)
{
    ::QOperatingSystemVersion *sipCpp = reinterpret_cast< ::QOperatingSystemVersion *>(sipCppV);

    if (targetType == sipType_QOperatingSystemVersion)
        return sipCppV;

    if (targetType == sipType_QOperatingSystemVersionBase)
        return static_cast< ::QOperatingSystemVersionBase *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QOperatingSystemVersion(void *, int);}
static void release_QOperatingSystemVersion(void *sipCppV, int)
{
    delete reinterpret_cast< ::QOperatingSystemVersion *>(sipCppV);
}


extern "C" {static void assign_QOperatingSystemVersion(void *, Py_ssize_t, void *);}
static void assign_QOperatingSystemVersion(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QOperatingSystemVersion *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QOperatingSystemVersion *>(sipSrc);
}


extern "C" {static void *copy_QOperatingSystemVersion(const void *, Py_ssize_t);}
static void *copy_QOperatingSystemVersion(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QOperatingSystemVersion(reinterpret_cast<const ::QOperatingSystemVersion *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QOperatingSystemVersion(sipSimpleWrapper *);}
static void dealloc_QOperatingSystemVersion(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QOperatingSystemVersion(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QOperatingSystemVersion(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QOperatingSystemVersion(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QOperatingSystemVersion *sipCpp = SIP_NULLPTR;

    {
        ::QOperatingSystemVersion::OSType a0;
        int a1;
        int a2 = -1;
        int a3 = -1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_vminor,
            sipName_vmicro,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "Ei|ii", sipType_QOperatingSystemVersion_OSType, &a0, &a1, &a2, &a3))
        {
            sipCpp = new ::QOperatingSystemVersion(a0, a1, a2, a3);

            return sipCpp;
        }
    }

    {
        const ::QOperatingSystemVersion* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QOperatingSystemVersion, &a0))
        {
            sipCpp = new ::QOperatingSystemVersion(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QOperatingSystemVersion[] = {{259, 255, 1}};


static PyMethodDef methods_QOperatingSystemVersion[] = {
    {sipName_current, meth_QOperatingSystemVersion_current, METH_VARARGS, doc_QOperatingSystemVersion_current},
    {sipName_currentType, meth_QOperatingSystemVersion_currentType, METH_VARARGS, doc_QOperatingSystemVersion_currentType},
    {sipName_type, meth_QOperatingSystemVersion_type, METH_VARARGS, doc_QOperatingSystemVersion_type}
};


extern "C" {static PyObject *varget_QOperatingSystemVersion_Android10(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Android10(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::Android10);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Android11(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Android11(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::Android11);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Android12(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Android12(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Android12);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Android12L(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Android12L(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Android12L);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Android13(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Android13(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Android13);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidJellyBean(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidJellyBean(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidJellyBean);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidJellyBean_MR1(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidJellyBean_MR1(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidJellyBean_MR1);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidJellyBean_MR2(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidJellyBean_MR2(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidJellyBean_MR2);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidKitKat(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidKitKat(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidKitKat);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidLollipop(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidLollipop(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidLollipop);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidLollipop_MR1(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidLollipop_MR1(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidLollipop_MR1);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidMarshmallow(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidMarshmallow(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidMarshmallow);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidNougat(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidNougat(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidNougat);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidNougat_MR1(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidNougat_MR1(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidNougat_MR1);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidOreo(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidOreo(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidOreo);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidOreo_MR1(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidOreo_MR1(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidOreo_MR1);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_AndroidPie(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_AndroidPie(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::AndroidPie);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_MacOSBigSur(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_MacOSBigSur(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::MacOSBigSur);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_MacOSCatalina(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_MacOSCatalina(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::MacOSCatalina);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_MacOSHighSierra(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_MacOSHighSierra(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::MacOSHighSierra);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_MacOSMojave(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_MacOSMojave(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::MacOSMojave);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_MacOSMonterey(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_MacOSMonterey(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::MacOSMonterey);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_MacOSSierra(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_MacOSSierra(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::MacOSSierra);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_MacOSSonoma(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_MacOSSonoma(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::MacOSSonoma);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_MacOSVentura(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_MacOSVentura(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::MacOSVentura);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_OSXElCapitan(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_OSXElCapitan(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::OSXElCapitan);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_OSXMavericks(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_OSXMavericks(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::OSXMavericks);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_OSXYosemite(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_OSXYosemite(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::OSXYosemite);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows10(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows10(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::Windows10);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows10_1809(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows10_1809(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Windows10_1809);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows10_1903(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows10_1903(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Windows10_1903);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows10_1909(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows10_1909(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Windows10_1909);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows10_2004(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows10_2004(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Windows10_2004);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows10_20H2(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows10_20H2(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Windows10_20H2);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows10_21H1(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows10_21H1(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Windows10_21H1);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows10_21H2(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows10_21H2(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Windows10_21H2);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows10_22H2(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows10_22H2(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Windows10_22H2);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows11(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows11(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Windows11);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows11_21H2(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows11_21H2(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Windows11_21H2);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows11_22H2(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows11_22H2(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersionBase*sipVal;

    sipVal = new ::QOperatingSystemVersionBase(::QOperatingSystemVersion::Windows11_22H2);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersionBase *>(sipVal), sipType_QOperatingSystemVersionBase, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows7(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows7(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::Windows7);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows8(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows8(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::Windows8);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QOperatingSystemVersion_Windows8_1(void *, PyObject *, PyObject *);}
static PyObject *varget_QOperatingSystemVersion_Windows8_1(void *, PyObject *, PyObject *)
{
    const ::QOperatingSystemVersion*sipVal;

    sipVal = new ::QOperatingSystemVersion(::QOperatingSystemVersion::Windows8_1);

    return sipConvertFromNewType(const_cast< ::QOperatingSystemVersion *>(sipVal), sipType_QOperatingSystemVersion, SIP_NULLPTR);
}

sipVariableDef variables_QOperatingSystemVersion[] = {
    {ClassVariable, sipName_Android10, (PyMethodDef *)varget_QOperatingSystemVersion_Android10, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Android11, (PyMethodDef *)varget_QOperatingSystemVersion_Android11, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Android12, (PyMethodDef *)varget_QOperatingSystemVersion_Android12, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Android12L, (PyMethodDef *)varget_QOperatingSystemVersion_Android12L, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Android13, (PyMethodDef *)varget_QOperatingSystemVersion_Android13, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidJellyBean, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidJellyBean, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidJellyBean_MR1, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidJellyBean_MR1, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidJellyBean_MR2, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidJellyBean_MR2, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidKitKat, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidKitKat, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidLollipop, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidLollipop, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidLollipop_MR1, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidLollipop_MR1, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidMarshmallow, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidMarshmallow, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidNougat, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidNougat, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidNougat_MR1, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidNougat_MR1, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidOreo, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidOreo, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidOreo_MR1, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidOreo_MR1, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AndroidPie, (PyMethodDef *)varget_QOperatingSystemVersion_AndroidPie, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_MacOSBigSur, (PyMethodDef *)varget_QOperatingSystemVersion_MacOSBigSur, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_MacOSCatalina, (PyMethodDef *)varget_QOperatingSystemVersion_MacOSCatalina, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_MacOSHighSierra, (PyMethodDef *)varget_QOperatingSystemVersion_MacOSHighSierra, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_MacOSMojave, (PyMethodDef *)varget_QOperatingSystemVersion_MacOSMojave, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_MacOSMonterey, (PyMethodDef *)varget_QOperatingSystemVersion_MacOSMonterey, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_MacOSSierra, (PyMethodDef *)varget_QOperatingSystemVersion_MacOSSierra, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_MacOSSonoma, (PyMethodDef *)varget_QOperatingSystemVersion_MacOSSonoma, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_MacOSVentura, (PyMethodDef *)varget_QOperatingSystemVersion_MacOSVentura, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_OSXElCapitan, (PyMethodDef *)varget_QOperatingSystemVersion_OSXElCapitan, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_OSXMavericks, (PyMethodDef *)varget_QOperatingSystemVersion_OSXMavericks, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_OSXYosemite, (PyMethodDef *)varget_QOperatingSystemVersion_OSXYosemite, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows10, (PyMethodDef *)varget_QOperatingSystemVersion_Windows10, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows10_1809, (PyMethodDef *)varget_QOperatingSystemVersion_Windows10_1809, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows10_1903, (PyMethodDef *)varget_QOperatingSystemVersion_Windows10_1903, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows10_1909, (PyMethodDef *)varget_QOperatingSystemVersion_Windows10_1909, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows10_2004, (PyMethodDef *)varget_QOperatingSystemVersion_Windows10_2004, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows10_20H2, (PyMethodDef *)varget_QOperatingSystemVersion_Windows10_20H2, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows10_21H1, (PyMethodDef *)varget_QOperatingSystemVersion_Windows10_21H1, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows10_21H2, (PyMethodDef *)varget_QOperatingSystemVersion_Windows10_21H2, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows10_22H2, (PyMethodDef *)varget_QOperatingSystemVersion_Windows10_22H2, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows11, (PyMethodDef *)varget_QOperatingSystemVersion_Windows11, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows11_21H2, (PyMethodDef *)varget_QOperatingSystemVersion_Windows11_21H2, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows11_22H2, (PyMethodDef *)varget_QOperatingSystemVersion_Windows11_22H2, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows7, (PyMethodDef *)varget_QOperatingSystemVersion_Windows7, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows8, (PyMethodDef *)varget_QOperatingSystemVersion_Windows8, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Windows8_1, (PyMethodDef *)varget_QOperatingSystemVersion_Windows8_1, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QOperatingSystemVersion[] = {
    {sipName_Unknown, static_cast<int>(::QOperatingSystemVersion::Unknown)},
    {sipName_Windows, static_cast<int>(::QOperatingSystemVersion::Windows)},
    {sipName_MacOS, static_cast<int>(::QOperatingSystemVersion::MacOS)},
    {sipName_IOS, static_cast<int>(::QOperatingSystemVersion::IOS)},
    {sipName_TvOS, static_cast<int>(::QOperatingSystemVersion::TvOS)},
    {sipName_WatchOS, static_cast<int>(::QOperatingSystemVersion::WatchOS)},
    {sipName_Android, static_cast<int>(::QOperatingSystemVersion::Android)},
    {0, 0}
};

PyDoc_STRVAR(doc_QOperatingSystemVersion, "\1QOperatingSystemVersion(osType: QOperatingSystemVersion.OSType, vmajor: int, vminor: int = -1, vmicro: int = -1)\n"
"QOperatingSystemVersion(a0: QOperatingSystemVersion)");


sipClassTypeDef sipTypeDef_QtCore_QOperatingSystemVersion = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QOperatingSystemVersion,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QOperatingSystemVersion,
        {0, 0, 1},
        3, methods_QOperatingSystemVersion,
        43, variables_QOperatingSystemVersion,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QOperatingSystemVersion, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QOperatingSystemVersion,
    -1,
    -1,
    supers_QOperatingSystemVersion,
    SIP_NULLPTR,
    init_type_QOperatingSystemVersion,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QOperatingSystemVersion,
    assign_QOperatingSystemVersion,
    SIP_NULLPTR,
    copy_QOperatingSystemVersion,
    release_QOperatingSystemVersion,
    cast_QOperatingSystemVersion,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QOperatingSystemVersion),
};
