/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtHelpAPI_H
#define _QtHelpAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_horizontalScrollbarValueChanged 0
#define sipName_horizontalScrollbarValueChanged &sipStrings_QtHelp[0]
#define sipNameNr_createContentsForCurrentFilter 32
#define sipName_createContentsForCurrentFilter &sipStrings_QtHelp[32]
#define sipNameNr_verticalScrollbarValueChanged 63
#define sipName_verticalScrollbarValueChanged &sipStrings_QtHelp[63]
#define sipNameNr_93 93
#define sipName_93 &sipStrings_QtHelp[93]
#define sipNameNr_QHelpSearchQuery__FieldName 122
#define sipName_QHelpSearchQuery__FieldName &sipStrings_QtHelp[122]
#define sipNameNr_createIndexForCurrentFilter 150
#define sipName_createIndexForCurrentFilter &sipStrings_QtHelp[150]
#define sipNameNr_QHelpFilterSettingsWidget 178
#define sipName_QHelpFilterSettingsWidget &sipStrings_QtHelp[178]
#define sipNameNr_horizontalScrollbarAction 204
#define sipName_horizontalScrollbarAction &sipStrings_QtHelp[204]
#define sipNameNr_230 230
#define sipName_230 &sipStrings_QtHelp[230]
#define sipNameNr_registeredDocumentations 255
#define sipName_registeredDocumentations &sipStrings_QtHelp[255]
#define sipNameNr_visualRegionForSelection 280
#define sipName_visualRegionForSelection &sipStrings_QtHelp[280]
#define sipNameNr_PyQt6_sip_simplewrapper 305
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtHelp[305]
#define sipNameNr_QHelpSearchResultWidget 329
#define sipName_QHelpSearchResultWidget &sipStrings_QtHelp[329]
#define sipNameNr_contentsCreationStarted 353
#define sipName_contentsCreationStarted &sipStrings_QtHelp[353]
#define sipNameNr_unregisterDocumentation 377
#define sipName_unregisterDocumentation &sipStrings_QtHelp[377]
#define sipNameNr_verticalScrollbarAction 401
#define sipName_verticalScrollbarAction &sipStrings_QtHelp[401]
#define sipNameNr_QHelpSearchQueryWidget 425
#define sipName_QHelpSearchQueryWidget &sipStrings_QtHelp[425]
#define sipNameNr_collapseExtendedSearch 448
#define sipName_collapseExtendedSearch &sipStrings_QtHelp[448]
#define sipNameNr_documentsForIdentifier 471
#define sipName_documentsForIdentifier &sipStrings_QtHelp[471]
#define sipNameNr_fromCompressedHelpFile 494
#define sipName_fromCompressedHelpFile &sipStrings_QtHelp[494]
#define sipNameNr_setAvailableComponents 517
#define sipName_setAvailableComponents &sipStrings_QtHelp[517]
#define sipNameNr_updateEditorGeometries 540
#define sipName_updateEditorGeometries &sipStrings_QtHelp[540]
#define sipNameNr_QHelpSearchEngineCore 563
#define sipName_QHelpSearchEngineCore &sipStrings_QtHelp[563]
#define sipNameNr_585 585
#define sipName_585 &sipStrings_QtHelp[585]
#define sipNameNr_607 607
#define sipName_607 &sipStrings_QtHelp[607]
#define sipNameNr_documentationFileName 629
#define sipName_documentationFileName &sipStrings_QtHelp[629]
#define sipNameNr_mouseDoubleClickEvent 651
#define sipName_mouseDoubleClickEvent &sipStrings_QtHelp[651]
#define sipNameNr_registerDocumentation 379
#define sipName_registerDocumentation &sipStrings_QtHelp[379]
#define sipNameNr_expandExtendedSearch 673
#define sipName_expandExtendedSearch &sipStrings_QtHelp[673]
#define sipNameNr_indexCreationStarted 694
#define sipName_indexCreationStarted &sipStrings_QtHelp[694]
#define sipNameNr_itemDelegateForIndex 715
#define sipName_itemDelegateForIndex &sipStrings_QtHelp[715]
#define sipNameNr_namespaceToComponent 736
#define sipName_namespaceToComponent &sipStrings_QtHelp[736]
#define sipNameNr_reindexDocumentation 757
#define sipName_reindexDocumentation &sipStrings_QtHelp[757]
#define sipNameNr_rowsAboutToBeRemoved 778
#define sipName_rowsAboutToBeRemoved &sipStrings_QtHelp[778]
#define sipNameNr_setAvailableVersions 799
#define sipName_setAvailableVersions &sipStrings_QtHelp[799]
#define sipNameNr_supportedDragActions 820
#define sipName_supportedDragActions &sipStrings_QtHelp[820]
#define sipNameNr_supportedDropActions 841
#define sipName_supportedDropActions &sipStrings_QtHelp[841]
#define sipNameNr_QCompressedHelpInfo 862
#define sipName_QCompressedHelpInfo &sipStrings_QtHelp[862]
#define sipNameNr_activateCurrentItem 882
#define sipName_activateCurrentItem &sipStrings_QtHelp[882]
#define sipNameNr_availableComponents 902
#define sipName_availableComponents &sipStrings_QtHelp[902]
#define sipNameNr_documentsForKeyword 922
#define sipName_documentsForKeyword &sipStrings_QtHelp[922]
#define sipNameNr_namespacesForFilter 942
#define sipName_namespacesForFilter &sipStrings_QtHelp[942]
#define sipNameNr_setUsesFilterEngine 962
#define sipName_setUsesFilterEngine &sipStrings_QtHelp[962]
#define sipNameNr_QHelpContentWidget 982
#define sipName_QHelpContentWidget &sipStrings_QtHelp[982]
#define sipNameNr_copyCollectionFile 1001
#define sipName_copyCollectionFile &sipStrings_QtHelp[1001]
#define sipNameNr_documentsActivated 1020
#define sipName_documentsActivated &sipStrings_QtHelp[1020]
#define sipNameNr_focusNextPrevChild 1039
#define sipName_focusNextPrevChild &sipStrings_QtHelp[1039]
#define sipNameNr_initViewItemOption 1058
#define sipName_initViewItemOption &sipStrings_QtHelp[1058]
#define sipNameNr_isCreatingContents 1077
#define sipName_isCreatingContents &sipStrings_QtHelp[1077]
#define sipNameNr_namespaceToVersion 1096
#define sipName_namespaceToVersion &sipStrings_QtHelp[1096]
#define sipNameNr_QHelpContentModel 1115
#define sipName_QHelpContentModel &sipStrings_QtHelp[1115]
#define sipNameNr_QHelpFilterEngine 1133
#define sipName_QHelpFilterEngine &sipStrings_QtHelp[1133]
#define sipNameNr_QHelpSearchEngine 1151
#define sipName_QHelpSearchEngine &sipStrings_QtHelp[1151]
#define sipNameNr_QHelpSearchResult 1169
#define sipName_QHelpSearchResult &sipStrings_QtHelp[1169]
#define sipNameNr_availableVersions 1187
#define sipName_availableVersions &sipStrings_QtHelp[1187]
#define sipNameNr_documentActivated 1205
#define sipName_documentActivated &sipStrings_QtHelp[1205]
#define sipNameNr_hasHeightForWidth 1223
#define sipName_hasHeightForWidth &sipStrings_QtHelp[1223]
#define sipNameNr_mouseReleaseEvent 1241
#define sipName_mouseReleaseEvent &sipStrings_QtHelp[1241]
#define sipNameNr_removeCustomValue 1259
#define sipName_removeCustomValue &sipStrings_QtHelp[1259]
#define sipNameNr_resetInternalData 1277
#define sipName_resetInternalData &sipStrings_QtHelp[1277]
#define sipNameNr_searchResultCount 1295
#define sipName_searchResultCount &sipStrings_QtHelp[1295]
#define sipNameNr_searchingFinished 1313
#define sipName_searchingFinished &sipStrings_QtHelp[1313]
#define sipNameNr_setAutoSaveFilter 1331
#define sipName_setAutoSaveFilter &sipStrings_QtHelp[1331]
#define sipNameNr_setCollectionFile 1349
#define sipName_setCollectionFile &sipStrings_QtHelp[1349]
#define sipNameNr_setSelectionModel 1367
#define sipName_setSelectionModel &sipStrings_QtHelp[1367]
#define sipNameNr_sizeHintForColumn 1385
#define sipName_sizeHintForColumn &sipStrings_QtHelp[1385]
#define sipNameNr_QHelpContentItem 1403
#define sipName_QHelpContentItem &sipStrings_QtHelp[1403]
#define sipNameNr_QHelpIndexWidget 1420
#define sipName_QHelpIndexWidget &sipStrings_QtHelp[1420]
#define sipNameNr_QHelpSearchQuery 1437
#define sipName_QHelpSearchQuery &sipStrings_QtHelp[1437]
#define sipNameNr_1454 1454
#define sipName_1454 &sipStrings_QtHelp[1454]
#define sipNameNr_contextMenuEvent 1471
#define sipName_contextMenuEvent &sipStrings_QtHelp[1471]
#define sipNameNr_disconnectNotify 1488
#define sipName_disconnectNotify &sipStrings_QtHelp[1488]
#define sipNameNr_horizontalOffset 1505
#define sipName_horizontalOffset &sipStrings_QtHelp[1505]
#define sipNameNr_indexingFinished 1522
#define sipName_indexingFinished &sipStrings_QtHelp[1522]
#define sipNameNr_inputMethodEvent 1539
#define sipName_inputMethodEvent &sipStrings_QtHelp[1539]
#define sipNameNr_inputMethodQuery 1556
#define sipName_inputMethodQuery &sipStrings_QtHelp[1556]
#define sipNameNr_scrollContentsBy 1573
#define sipName_scrollContentsBy &sipStrings_QtHelp[1573]
#define sipNameNr_searchingStarted 1590
#define sipName_searchingStarted &sipStrings_QtHelp[1590]
#define sipNameNr_selectionChanged 1607
#define sipName_selectionChanged &sipStrings_QtHelp[1607]
#define sipNameNr_selectionCommand 1624
#define sipName_selectionCommand &sipStrings_QtHelp[1624]
#define sipNameNr_updateEditorData 1641
#define sipName_updateEditorData &sipStrings_QtHelp[1641]
#define sipNameNr_updateGeometries 1658
#define sipName_updateGeometries &sipStrings_QtHelp[1658]
#define sipNameNr_usesFilterEngine 1675
#define sipName_usesFilterEngine &sipStrings_QtHelp[1675]
#define sipNameNr_viewportSizeHint 1692
#define sipName_viewportSizeHint &sipStrings_QtHelp[1692]
#define sipNameNr_QHelpEngineCore 1709
#define sipName_QHelpEngineCore &sipStrings_QtHelp[1709]
#define sipNameNr_QHelpFilterData 1725
#define sipName_QHelpFilterData &sipStrings_QtHelp[1725]
#define sipNameNr_QHelpIndexModel 1741
#define sipName_QHelpIndexModel &sipStrings_QtHelp[1741]
#define sipNameNr_canDropMimeData 1757
#define sipName_canDropMimeData &sipStrings_QtHelp[1757]
#define sipNameNr_cancelSearching 1773
#define sipName_cancelSearching &sipStrings_QtHelp[1773]
#define sipNameNr_contentsCreated 1789
#define sipName_contentsCreated &sipStrings_QtHelp[1789]
#define sipNameNr_editorDestroyed 1805
#define sipName_editorDestroyed &sipStrings_QtHelp[1805]
#define sipNameNr_extensionFilter 1821
#define sipName_extensionFilter &sipStrings_QtHelp[1821]
#define sipNameNr_filterActivated 1837
#define sipName_filterActivated &sipStrings_QtHelp[1837]
#define sipNameNr_indexingStarted 1853
#define sipName_indexingStarted &sipStrings_QtHelp[1853]
#define sipNameNr_initStyleOption 1869
#define sipName_initStyleOption &sipStrings_QtHelp[1869]
#define sipNameNr_isCreatingIndex 1885
#define sipName_isCreatingIndex &sipStrings_QtHelp[1885]
#define sipNameNr_keyReleaseEvent 1901
#define sipName_keyReleaseEvent &sipStrings_QtHelp[1901]
#define sipNameNr_minimumSizeHint 1917
#define sipName_minimumSizeHint &sipStrings_QtHelp[1917]
#define sipNameNr_mousePressEvent 1933
#define sipName_mousePressEvent &sipStrings_QtHelp[1933]
#define sipNameNr_requestShowLink 1949
#define sipName_requestShowLink &sipStrings_QtHelp[1949]
#define sipNameNr_selectedIndexes 1965
#define sipName_selectedIndexes &sipStrings_QtHelp[1965]
#define sipNameNr_setActiveFilter 1981
#define sipName_setActiveFilter &sipStrings_QtHelp[1981]
#define sipNameNr_autoSaveFilter 1997
#define sipName_autoSaveFilter &sipStrings_QtHelp[1997]
#define sipNameNr_cancelIndexing 2012
#define sipName_cancelIndexing &sipStrings_QtHelp[2012]
#define sipNameNr_collectionFile 2027
#define sipName_collectionFile &sipStrings_QtHelp[2027]
#define sipNameNr_createContents 2042
#define sipName_createContents &sipStrings_QtHelp[2042]
#define sipNameNr_currentChanged 2057
#define sipName_currentChanged &sipStrings_QtHelp[2057]
#define sipNameNr_dragEnterEvent 2072
#define sipName_dragEnterEvent &sipStrings_QtHelp[2072]
#define sipNameNr_dragLeaveEvent 2087
#define sipName_dragLeaveEvent &sipStrings_QtHelp[2087]
#define sipNameNr_heightForWidth 2102
#define sipName_heightForWidth &sipStrings_QtHelp[2102]
#define sipNameNr_keyboardSearch 2117
#define sipName_keyboardSearch &sipStrings_QtHelp[2117]
#define sipNameNr_mouseMoveEvent 2132
#define sipName_mouseMoveEvent &sipStrings_QtHelp[2132]
#define sipNameNr_setCompactMode 2147
#define sipName_setCompactMode &sipStrings_QtHelp[2147]
#define sipNameNr_setCustomValue 2162
#define sipName_setCustomValue &sipStrings_QtHelp[2162]
#define sipNameNr_setSearchInput 2177
#define sipName_setSearchInput &sipStrings_QtHelp[2177]
#define sipNameNr_sizeHintForRow 2192
#define sipName_sizeHintForRow &sipStrings_QtHelp[2192]
#define sipNameNr_verticalOffset 2207
#define sipName_verticalOffset &sipStrings_QtHelp[2207]
#define sipNameNr_applySettings 2222
#define sipName_applySettings &sipStrings_QtHelp[2222]
#define sipNameNr_childPosition 2236
#define sipName_childPosition &sipStrings_QtHelp[2236]
#define sipNameNr_clearItemData 2250
#define sipName_clearItemData &sipStrings_QtHelp[2250]
#define sipNameNr_connectNotify 1491
#define sipName_connectNotify &sipStrings_QtHelp[1491]
#define sipNameNr_contentItemAt 2264
#define sipName_contentItemAt &sipStrings_QtHelp[2264]
#define sipNameNr_contentWidget 2278
#define sipName_contentWidget &sipStrings_QtHelp[2278]
#define sipNameNr_dragMoveEvent 2292
#define sipName_dragMoveEvent &sipStrings_QtHelp[2292]
#define sipNameNr_filterIndices 2306
#define sipName_filterIndices &sipStrings_QtHelp[2306]
#define sipNameNr_focusOutEvent 2320
#define sipName_focusOutEvent &sipStrings_QtHelp[2320]
#define sipNameNr_insertColumns 2334
#define sipName_insertColumns &sipStrings_QtHelp[2334]
#define sipNameNr_isCompactMode 2348
#define sipName_isCompactMode &sipStrings_QtHelp[2348]
#define sipNameNr_isIndexHidden 2362
#define sipName_isIndexHidden &sipStrings_QtHelp[2362]
#define sipNameNr_keyPressEvent 2376
#define sipName_keyPressEvent &sipStrings_QtHelp[2376]
#define sipNameNr_linkActivated 2390
#define sipName_linkActivated &sipStrings_QtHelp[2390]
#define sipNameNr_namespaceName 2404
#define sipName_namespaceName &sipStrings_QtHelp[2404]
#define sipNameNr_removeColumns 2418
#define sipName_removeColumns &sipStrings_QtHelp[2418]
#define sipNameNr_searchResults 2432
#define sipName_searchResults &sipStrings_QtHelp[2432]
#define sipNameNr_setComponents 2446
#define sipName_setComponents &sipStrings_QtHelp[2446]
#define sipNameNr_setFilterData 2460
#define sipName_setFilterData &sipStrings_QtHelp[2460]
#define sipNameNr_setHeaderData 2474
#define sipName_setHeaderData &sipStrings_QtHelp[2474]
#define sipNameNr_setupFinished 2488
#define sipName_setupFinished &sipStrings_QtHelp[2488]
#define sipNameNr_setupViewport 2502
#define sipName_setupViewport &sipStrings_QtHelp[2502]
#define sipNameNr_sharedPainter 2516
#define sipName_sharedPainter &sipStrings_QtHelp[2516]
#define sipNameNr_viewportEvent 2530
#define sipName_viewportEvent &sipStrings_QtHelp[2530]
#define sipNameNr_PyQt6_QtHelp 2544
#define sipName_PyQt6_QtHelp &sipStrings_QtHelp[2544]
#define sipNameNr_activeFilter 2557
#define sipName_activeFilter &sipStrings_QtHelp[2557]
#define sipNameNr_canFetchMore 2570
#define sipName_canFetchMore &sipStrings_QtHelp[2570]
#define sipNameNr_contentModel 2583
#define sipName_contentModel &sipStrings_QtHelp[2583]
#define sipNameNr_defaultValue 2596
#define sipName_defaultValue &sipStrings_QtHelp[2596]
#define sipNameNr_drawBranches 2609
#define sipName_drawBranches &sipStrings_QtHelp[2609]
#define sipNameNr_dropMimeData 2622
#define sipName_dropMimeData &sipStrings_QtHelp[2622]
#define sipNameNr_filterEngine 2635
#define sipName_filterEngine &sipStrings_QtHelp[2635]
#define sipNameNr_focusInEvent 2648
#define sipName_focusInEvent &sipStrings_QtHelp[2648]
#define sipNameNr_indexCreated 2661
#define sipName_indexCreated &sipStrings_QtHelp[2661]
#define sipNameNr_readSettings 2674
#define sipName_readSettings &sipStrings_QtHelp[2674]
#define sipNameNr_removeFilter 2687
#define sipName_removeFilter &sipStrings_QtHelp[2687]
#define sipNameNr_resultWidget 2700
#define sipName_resultWidget &sipStrings_QtHelp[2700]
#define sipNameNr_rowsInserted 2713
#define sipName_rowsInserted &sipStrings_QtHelp[2713]
#define sipNameNr_searchEngine 2726
#define sipName_searchEngine &sipStrings_QtHelp[2726]
#define sipNameNr_setRootIndex 2739
#define sipName_setRootIndex &sipStrings_QtHelp[2739]
#define sipNameNr_setSelection 2752
#define sipName_setSelection &sipStrings_QtHelp[2752]
#define sipNameNr_setupStarted 2765
#define sipName_setupStarted &sipStrings_QtHelp[2765]
#define sipNameNr_QHelpEngine 2778
#define sipName_QHelpEngine &sipStrings_QtHelp[2778]
#define sipNameNr_actionEvent 2790
#define sipName_actionEvent &sipStrings_QtHelp[2790]
#define sipNameNr_changeEvent 2802
#define sipName_changeEvent &sipStrings_QtHelp[2802]
#define sipNameNr_closeEditor 2814
#define sipName_closeEditor &sipStrings_QtHelp[2814]
#define sipNameNr_columnCount 2826
#define sipName_columnCount &sipStrings_QtHelp[2826]
#define sipNameNr_createIndex 2838
#define sipName_createIndex &sipStrings_QtHelp[2838]
#define sipNameNr_customEvent 2850
#define sipName_customEvent &sipStrings_QtHelp[2850]
#define sipNameNr_customValue 2862
#define sipName_customValue &sipStrings_QtHelp[2862]
#define sipNameNr_dataChanged 2874
#define sipName_dataChanged &sipStrings_QtHelp[2874]
#define sipNameNr_eventFilter 2886
#define sipName_eventFilter &sipStrings_QtHelp[2886]
#define sipNameNr_hasChildren 2898
#define sipName_hasChildren &sipStrings_QtHelp[2898]
#define sipNameNr_indexWidget 2910
#define sipName_indexWidget &sipStrings_QtHelp[2910]
#define sipNameNr_initPainter 2922
#define sipName_initPainter &sipStrings_QtHelp[2922]
#define sipNameNr_moveColumns 2420
#define sipName_moveColumns &sipStrings_QtHelp[2420]
#define sipNameNr_nativeEvent 2934
#define sipName_nativeEvent &sipStrings_QtHelp[2934]
#define sipNameNr_paintEngine 2946
#define sipName_paintEngine &sipStrings_QtHelp[2946]
#define sipNameNr_queryWidget 2958
#define sipName_queryWidget &sipStrings_QtHelp[2958]
#define sipNameNr_resizeEvent 2970
#define sipName_resizeEvent &sipStrings_QtHelp[2970]
#define sipNameNr_searchInput 2982
#define sipName_searchInput &sipStrings_QtHelp[2982]
#define sipNameNr_setItemData 2994
#define sipName_setItemData &sipStrings_QtHelp[2994]
#define sipNameNr_setReadOnly 3006
#define sipName_setReadOnly &sipStrings_QtHelp[3006]
#define sipNameNr_setVersions 3018
#define sipName_setVersions &sipStrings_QtHelp[3018]
#define sipNameNr_tabletEvent 3030
#define sipName_tabletEvent &sipStrings_QtHelp[3030]
#define sipNameNr_childCount 3042
#define sipName_childCount &sipStrings_QtHelp[3042]
#define sipNameNr_childEvent 3053
#define sipName_childEvent &sipStrings_QtHelp[3053]
#define sipNameNr_closeEvent 3064
#define sipName_closeEvent &sipStrings_QtHelp[3064]
#define sipNameNr_commitData 3075
#define sipName_commitData &sipStrings_QtHelp[3075]
#define sipNameNr_components 3086
#define sipName_components &sipStrings_QtHelp[3086]
#define sipNameNr_enterEvent 3097
#define sipName_enterEvent &sipStrings_QtHelp[3097]
#define sipNameNr_filterData 3108
#define sipName_filterData &sipStrings_QtHelp[3108]
#define sipNameNr_headerData 3119
#define sipName_headerData &sipStrings_QtHelp[3119]
#define sipNameNr_helpEngine 3130
#define sipName_helpEngine &sipStrings_QtHelp[3130]
#define sipNameNr_indexModel 3141
#define sipName_indexModel &sipStrings_QtHelp[3141]
#define sipNameNr_insertRows 3152
#define sipName_insertRows &sipStrings_QtHelp[3152]
#define sipNameNr_isReadOnly 3163
#define sipName_isReadOnly &sipStrings_QtHelp[3163]
#define sipNameNr_leaveEvent 3174
#define sipName_leaveEvent &sipStrings_QtHelp[3174]
#define sipNameNr_moveCursor 3185
#define sipName_moveCursor &sipStrings_QtHelp[3185]
#define sipNameNr_paintEvent 3196
#define sipName_paintEvent &sipStrings_QtHelp[3196]
#define sipNameNr_removeRows 3207
#define sipName_removeRows &sipStrings_QtHelp[3207]
#define sipNameNr_setVisible 3218
#define sipName_setVisible &sipStrings_QtHelp[3218]
#define sipNameNr_timerEvent 3229
#define sipName_timerEvent &sipStrings_QtHelp[3229]
#define sipNameNr_visualRect 3240
#define sipName_visualRect &sipStrings_QtHelp[3240]
#define sipNameNr_wheelEvent 3251
#define sipName_wheelEvent &sipStrings_QtHelp[3251]
#define sipNameNr_FieldName 140
#define sipName_FieldName &sipStrings_QtHelp[140]
#define sipNameNr_QHelpLink 3262
#define sipName_QHelpLink &sipStrings_QtHelp[3262]
#define sipNameNr_component 3272
#define sipName_component &sipStrings_QtHelp[3272]
#define sipNameNr_dropEvent 3282
#define sipName_dropEvent &sipStrings_QtHelp[3282]
#define sipNameNr_fetchMore 3292
#define sipName_fetchMore &sipStrings_QtHelp[3292]
#define sipNameNr_hideEvent 3302
#define sipName_hideEvent &sipStrings_QtHelp[3302]
#define sipNameNr_mimeTypes 3312
#define sipName_mimeTypes &sipStrings_QtHelp[3312]
#define sipNameNr_moveEvent 3322
#define sipName_moveEvent &sipStrings_QtHelp[3322]
#define sipNameNr_multiData 3332
#define sipName_multiData &sipStrings_QtHelp[3332]
#define sipNameNr_roleNames 3342
#define sipName_roleNames &sipStrings_QtHelp[3342]
#define sipNameNr_selectAll 3352
#define sipName_selectAll &sipStrings_QtHelp[3352]
#define sipNameNr_setupData 3362
#define sipName_setupData &sipStrings_QtHelp[3362]
#define sipNameNr_showEvent 3372
#define sipName_showEvent &sipStrings_QtHelp[3372]
#define sipNameNr_startDrag 3382
#define sipName_startDrag &sipStrings_QtHelp[3382]
#define sipNameNr_fileData 3392
#define sipName_fileData &sipStrings_QtHelp[3392]
#define sipNameNr_findFile 3401
#define sipName_findFile &sipStrings_QtHelp[3401]
#define sipNameNr_itemData 3410
#define sipName_itemData &sipStrings_QtHelp[3410]
#define sipNameNr_metaData 3419
#define sipName_metaData &sipStrings_QtHelp[3419]
#define sipNameNr_mimeData 3428
#define sipName_mimeData &sipStrings_QtHelp[3428]
#define sipNameNr_moveRows 3209
#define sipName_moveRows &sipStrings_QtHelp[3209]
#define sipNameNr_rowCount 3437
#define sipName_rowCount &sipStrings_QtHelp[3437]
#define sipNameNr_scrollTo 3446
#define sipName_scrollTo &sipStrings_QtHelp[3446]
#define sipNameNr_setModel 3455
#define sipName_setModel &sipStrings_QtHelp[3455]
#define sipNameNr_sizeHint 3464
#define sipName_sizeHint &sipStrings_QtHelp[3464]
#define sipNameNr_versions 3473
#define sipName_versions &sipStrings_QtHelp[3473]
#define sipNameNr_wildcard 3482
#define sipName_wildcard &sipStrings_QtHelp[3482]
#define sipNameNr_ATLEAST 3491
#define sipName_ATLEAST &sipStrings_QtHelp[3491]
#define sipNameNr_DEFAULT 3499
#define sipName_DEFAULT &sipStrings_QtHelp[3499]
#define sipNameNr_WITHOUT 3507
#define sipName_WITHOUT &sipStrings_QtHelp[3507]
#define sipNameNr_devType 3515
#define sipName_devType &sipStrings_QtHelp[3515]
#define sipNameNr_drawRow 3523
#define sipName_drawRow &sipStrings_QtHelp[3523]
#define sipNameNr_filters 3531
#define sipName_filters &sipStrings_QtHelp[3531]
#define sipNameNr_indexAt 3539
#define sipName_indexAt &sipStrings_QtHelp[3539]
#define sipNameNr_indexOf 3547
#define sipName_indexOf &sipStrings_QtHelp[3547]
#define sipNameNr_indices 3555
#define sipName_indices &sipStrings_QtHelp[3555]
#define sipNameNr_setData 3563
#define sipName_setData &sipStrings_QtHelp[3563]
#define sipNameNr_sibling 3571
#define sipName_sibling &sipStrings_QtHelp[3571]
#define sipNameNr_snippet 3579
#define sipName_snippet &sipStrings_QtHelp[3579]
#define sipNameNr_version 3587
#define sipName_version &sipStrings_QtHelp[3587]
#define sipNameNr_warning 3595
#define sipName_warning &sipStrings_QtHelp[3595]
#define sipNameNr_PHRASE 3603
#define sipName_PHRASE &sipStrings_QtHelp[3603]
#define sipNameNr___eq__ 3610
#define sipName___eq__ &sipStrings_QtHelp[3610]
#define sipNameNr___ne__ 3617
#define sipName___ne__ &sipStrings_QtHelp[3617]
#define sipNameNr_filter 3624
#define sipName_filter &sipStrings_QtHelp[3624]
#define sipNameNr_isNull 3631
#define sipName_isNull &sipStrings_QtHelp[3631]
#define sipNameNr_linkAt 3638
#define sipName_linkAt &sipStrings_QtHelp[3638]
#define sipNameNr_metric 3645
#define sipName_metric &sipStrings_QtHelp[3645]
#define sipNameNr_parent 3652
#define sipName_parent &sipStrings_QtHelp[3652]
#define sipNameNr_revert 3659
#define sipName_revert &sipStrings_QtHelp[3659]
#define sipNameNr_search 3666
#define sipName_search &sipStrings_QtHelp[3666]
#define sipNameNr_submit 3673
#define sipName_submit &sipStrings_QtHelp[3673]
#define sipNameNr_FUZZY 3680
#define sipName_FUZZY &sipStrings_QtHelp[3680]
#define sipNameNr_buddy 3686
#define sipName_buddy &sipStrings_QtHelp[3686]
#define sipNameNr_child 3692
#define sipName_child &sipStrings_QtHelp[3692]
#define sipNameNr_error 3698
#define sipName_error &sipStrings_QtHelp[3698]
#define sipNameNr_event 3704
#define sipName_event &sipStrings_QtHelp[3704]
#define sipNameNr_files 3710
#define sipName_files &sipStrings_QtHelp[3710]
#define sipNameNr_flags 3716
#define sipName_flags &sipStrings_QtHelp[3716]
#define sipNameNr_index 3722
#define sipName_index &sipStrings_QtHelp[3722]
#define sipNameNr_match 3728
#define sipName_match &sipStrings_QtHelp[3728]
#define sipNameNr_reset 3734
#define sipName_reset &sipStrings_QtHelp[3734]
#define sipNameNr_title 3740
#define sipName_title &sipStrings_QtHelp[3740]
#define sipNameNr_data 3746
#define sipName_data &sipStrings_QtHelp[3746]
#define sipNameNr_edit 3751
#define sipName_edit &sipStrings_QtHelp[3751]
#define sipNameNr_sort 3756
#define sipName_sort &sipStrings_QtHelp[3756]
#define sipNameNr_span 3761
#define sipName_span &sipStrings_QtHelp[3761]
#define sipNameNr_swap 3766
#define sipName_swap &sipStrings_QtHelp[3766]
#define sipNameNr_ALL 3771
#define sipName_ALL &sipStrings_QtHelp[3771]
#define sipNameNr_row 3775
#define sipName_row &sipStrings_QtHelp[3775]
#define sipNameNr_url 3779
#define sipName_url &sipStrings_QtHelp[3779]

#define sipMalloc                   sipAPI_QtHelp->api_malloc
#define sipFree                     sipAPI_QtHelp->api_free
#define sipBuildResult              sipAPI_QtHelp->api_build_result
#define sipCallMethod               sipAPI_QtHelp->api_call_method
#define sipCallProcedureMethod      sipAPI_QtHelp->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtHelp->api_call_error_handler
#define sipParseResultEx            sipAPI_QtHelp->api_parse_result_ex
#define sipParseResult              sipAPI_QtHelp->api_parse_result
#define sipParseArgs                sipAPI_QtHelp->api_parse_args
#define sipParseKwdArgs             sipAPI_QtHelp->api_parse_kwd_args
#define sipParsePair                sipAPI_QtHelp->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtHelp->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtHelp->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtHelp->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtHelp->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtHelp->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtHelp->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtHelp->api_add_exception
#define sipNoFunction               sipAPI_QtHelp->api_no_function
#define sipNoMethod                 sipAPI_QtHelp->api_no_method
#define sipAbstractMethod           sipAPI_QtHelp->api_abstract_method
#define sipBadClass                 sipAPI_QtHelp->api_bad_class
#define sipBadCatcherResult         sipAPI_QtHelp->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtHelp->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtHelp->api_bad_operator_arg
#define sipTrace                    sipAPI_QtHelp->api_trace
#define sipTransferBack             sipAPI_QtHelp->api_transfer_back
#define sipTransferTo               sipAPI_QtHelp->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtHelp->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtHelp->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtHelp->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtHelp->api_voidptr_type
#define sipGetPyObject              sipAPI_QtHelp->api_get_pyobject
#define sipGetAddress               sipAPI_QtHelp->api_get_address
#define sipGetMixinAddress          sipAPI_QtHelp->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtHelp->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtHelp->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtHelp->api_call_hook
#define sipEndThread                sipAPI_QtHelp->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtHelp->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtHelp->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtHelp->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtHelp->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtHelp->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtHelp->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtHelp->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtHelp->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtHelp->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtHelp->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtHelp->api_convert_to_bool
#define sipReleaseType              sipAPI_QtHelp->api_release_type
#define sipConvertFromType          sipAPI_QtHelp->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtHelp->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtHelp->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtHelp->api_convert_from_enum
#define sipGetState                 sipAPI_QtHelp->api_get_state
#define sipExportSymbol             sipAPI_QtHelp->api_export_symbol
#define sipImportSymbol             sipAPI_QtHelp->api_import_symbol
#define sipFindType                 sipAPI_QtHelp->api_find_type
#define sipBytes_AsChar             sipAPI_QtHelp->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtHelp->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtHelp->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtHelp->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtHelp->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtHelp->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtHelp->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtHelp->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtHelp->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtHelp->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtHelp->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtHelp->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtHelp->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtHelp->api_get_reference
#define sipKeepReference            sipAPI_QtHelp->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtHelp->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtHelp->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtHelp->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtHelp->api_type_scope
#define sipResolveTypedef           sipAPI_QtHelp->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtHelp->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtHelp->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtHelp->api_init_mixin
#define sipExportModule             sipAPI_QtHelp->api_export_module
#define sipInitModule               sipAPI_QtHelp->api_init_module
#define sipGetInterpreter           sipAPI_QtHelp->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtHelp->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtHelp->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtHelp->api_py_type_dict
#define sipPyTypeName               sipAPI_QtHelp->api_py_type_name
#define sipGetCFunction             sipAPI_QtHelp->api_get_c_function
#define sipGetMethod                sipAPI_QtHelp->api_get_method
#define sipFromMethod               sipAPI_QtHelp->api_from_method
#define sipGetDate                  sipAPI_QtHelp->api_get_date
#define sipFromDate                 sipAPI_QtHelp->api_from_date
#define sipGetDateTime              sipAPI_QtHelp->api_get_datetime
#define sipFromDateTime             sipAPI_QtHelp->api_from_datetime
#define sipGetTime                  sipAPI_QtHelp->api_get_time
#define sipFromTime                 sipAPI_QtHelp->api_from_time
#define sipIsUserType               sipAPI_QtHelp->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtHelp->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtHelp->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtHelp->api_unicode_write
#define sipUnicodeData              sipAPI_QtHelp->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtHelp->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtHelp->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtHelp->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtHelp->api_is_derived_class
#define sipGetUserObject            sipAPI_QtHelp->api_get_user_object
#define sipSetUserObject            sipAPI_QtHelp->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtHelp->api_register_event_handler
#define sipConvertToArray           sipAPI_QtHelp->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtHelp->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtHelp->api_enable_gc
#define sipPrintObject              sipAPI_QtHelp->api_print_object
#define sipLong_AsChar              sipAPI_QtHelp->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtHelp->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtHelp->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtHelp->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtHelp->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtHelp->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtHelp->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtHelp->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtHelp->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtHelp->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtHelp->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtHelp->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtHelp->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtHelp->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtHelp->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtHelp->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtHelp->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtHelp->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtHelp->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtHelp->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtHelp->api_release_type_us
#define sipIsPyMethod               sipAPI_QtHelp->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtHelp[];

#define sipType_QCompressedHelpInfo sipExportedTypes_QtHelp[0]

extern sipClassTypeDef sipTypeDef_QtHelp_QCompressedHelpInfo;

#define sipType_QHelpContentItem sipExportedTypes_QtHelp[1]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpContentItem;

#define sipType_QHelpContentModel sipExportedTypes_QtHelp[2]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpContentModel;

#define sipType_QHelpContentWidget sipExportedTypes_QtHelp[3]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpContentWidget;

#define sipType_QHelpEngineCore sipExportedTypes_QtHelp[5]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpEngineCore;

#define sipType_QHelpEngine sipExportedTypes_QtHelp[4]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpEngine;

#define sipType_QHelpFilterData sipExportedTypes_QtHelp[6]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpFilterData;

#define sipType_QHelpFilterEngine sipExportedTypes_QtHelp[7]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpFilterEngine;

#define sipType_QHelpFilterSettingsWidget sipExportedTypes_QtHelp[8]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpFilterSettingsWidget;

#define sipType_QHelpIndexModel sipExportedTypes_QtHelp[9]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpIndexModel;

#define sipType_QHelpIndexWidget sipExportedTypes_QtHelp[10]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpIndexWidget;

#define sipType_QHelpLink sipExportedTypes_QtHelp[11]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpLink;

#define sipType_QHelpSearchQuery sipExportedTypes_QtHelp[14]

#define sipType_QHelpSearchQuery_FieldName sipExportedTypes_QtHelp[15]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchQuery;

#define sipType_QHelpSearchEngine sipExportedTypes_QtHelp[12]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchEngine;

#define sipType_QHelpSearchEngineCore sipExportedTypes_QtHelp[13]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchEngineCore;

#define sipType_QHelpSearchQueryWidget sipExportedTypes_QtHelp[16]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchQueryWidget;

#define sipType_QHelpSearchResult sipExportedTypes_QtHelp[17]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchResult;

#define sipType_QHelpSearchResultWidget sipExportedTypes_QtHelp[18]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchResultWidget;

#define sipType_QList_0100QHelpSearchResult sipExportedTypes_QtHelp[20]

extern sipMappedTypeDef sipTypeDef_QtHelp_QList_0100QHelpSearchResult;

#define sipType_QMap_0100QString_0100QVersionNumber sipExportedTypes_QtHelp[23]

extern sipMappedTypeDef sipTypeDef_QtHelp_QMap_0100QString_0100QVersionNumber;

#define sipType_QMap_0100QString_0100QString sipExportedTypes_QtHelp[22]

extern sipMappedTypeDef sipTypeDef_QtHelp_QMap_0100QString_0100QString;

#define sipType_QList_0100QVersionNumber sipExportedTypes_QtHelp[21]

extern sipMappedTypeDef sipTypeDef_QtHelp_QList_0100QVersionNumber;

#define sipType_QList_0100QHelpLink sipExportedTypes_QtHelp[19]

extern sipMappedTypeDef sipTypeDef_QtHelp_QList_0100QHelpLink;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtHelp;
extern sipExportedModuleDef sipModuleAPI_QtHelp;
extern sipTypeDef *sipExportedTypes_QtHelp[];

#define sipType_Qt_DropAction sipImportedTypes_QtHelp_QtCore[32].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtHelp_QtCore[33].it_td

#define sipType_Qt_SortOrder sipImportedTypes_QtHelp_QtCore[35].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtHelp_QtCore[34].it_td

#define sipType_QObject sipImportedTypes_QtHelp_QtCore[21].it_td

#define sipType_QModelIndex sipImportedTypes_QtHelp_QtCore[19].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtHelp_QtCore[0].it_td

#define sipType_QAbstractListModel sipImportedTypes_QtHelp_QtCore[1].it_td

#define sipType_QModelRoleDataSpan sipImportedTypes_QtHelp_QtCore[20].it_td

#define sipType_QByteArray sipImportedTypes_QtHelp_QtCore[2].it_td

#define sipType_QEvent sipImportedTypes_QtHelp_QtCore[4].it_td

#define sipType_QTimerEvent sipImportedTypes_QtHelp_QtCore[28].it_td

#define sipType_QChildEvent sipImportedTypes_QtHelp_QtCore[3].it_td

#define sipType_QItemSelectionModel sipImportedTypes_QtHelp_QtCore[12].it_td

#define sipType_QItemSelection sipImportedTypes_QtHelp_QtCore[11].it_td

#define sipType_QMetaMethod sipImportedTypes_QtHelp_QtCore[17].it_td

#define sipType_QMimeData sipImportedTypes_QtHelp_QtCore[18].it_td

#define sipType_QPoint sipImportedTypes_QtHelp_QtCore[22].it_td

#define sipType_QRect sipImportedTypes_QtHelp_QtCore[23].it_td

#define sipType_QSize sipImportedTypes_QtHelp_QtCore[24].it_td

#define sipType_QStringListModel sipImportedTypes_QtHelp_QtCore[27].it_td

#define sipType_QUrl sipImportedTypes_QtHelp_QtCore[29].it_td

#define sipType_QVariant sipImportedTypes_QtHelp_QtCore[30].it_td

#define sipType_QVersionNumber sipImportedTypes_QtHelp_QtCore[31].it_td

#define sipType_QList_0100QUrl sipImportedTypes_QtHelp_QtCore[14].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtHelp_QtCore[10].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtHelp_QtCore[16].it_td

#define sipType_QFlags_0100Qt_MatchFlag sipImportedTypes_QtHelp_QtCore[9].it_td

#define sipType_QFlags_0100Qt_KeyboardModifier sipImportedTypes_QtHelp_QtCore[8].it_td

#define sipType_QFlags_0100Qt_ItemFlag sipImportedTypes_QtHelp_QtCore[7].it_td

#define sipType_QFlags_0100Qt_DropAction sipImportedTypes_QtHelp_QtCore[6].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtHelp_QtCore[13].it_td

#define sipType_QFlags_0100QItemSelectionModel_SelectionFlag sipImportedTypes_QtHelp_QtCore[5].it_td

#define sipType_QStringList sipImportedTypes_QtHelp_QtCore[26].it_td

#define sipType_QList_1800 sipImportedTypes_QtHelp_QtCore[15].it_td

#define sipType_QString sipImportedTypes_QtHelp_QtCore[25].it_td

#define sipType_qintptr sipImportedTypes_QtHelp_QtCore[36].it_td
extern sipImportedTypeDef sipImportedTypes_QtHelp_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtHelp_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtHelp_QtGui[14].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtHelp_QtGui[15].it_td

#define sipType_QKeyEvent sipImportedTypes_QtHelp_QtGui[11].it_td

#define sipType_QFocusEvent sipImportedTypes_QtHelp_QtGui[8].it_td

#define sipType_QPaintEvent sipImportedTypes_QtHelp_QtGui[17].it_td

#define sipType_QMoveEvent sipImportedTypes_QtHelp_QtGui[13].it_td

#define sipType_QResizeEvent sipImportedTypes_QtHelp_QtGui[20].it_td

#define sipType_QCloseEvent sipImportedTypes_QtHelp_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtHelp_QtGui[21].it_td

#define sipType_QHideEvent sipImportedTypes_QtHelp_QtGui[9].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtHelp_QtGui[2].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtHelp_QtGui[10].it_td

#define sipType_QDropEvent sipImportedTypes_QtHelp_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtHelp_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtHelp_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtHelp_QtGui[4].it_td

#define sipType_QActionEvent sipImportedTypes_QtHelp_QtGui[0].it_td

#define sipType_QEnterEvent sipImportedTypes_QtHelp_QtGui[7].it_td

#define sipType_QMouseEvent sipImportedTypes_QtHelp_QtGui[12].it_td

#define sipType_QWheelEvent sipImportedTypes_QtHelp_QtGui[23].it_td

#define sipType_QTabletEvent sipImportedTypes_QtHelp_QtGui[22].it_td

#define sipType_QPaintEngine sipImportedTypes_QtHelp_QtGui[16].it_td

#define sipType_QPainter sipImportedTypes_QtHelp_QtGui[18].it_td

#define sipType_QRegion sipImportedTypes_QtHelp_QtGui[19].it_td
extern sipImportedTypeDef sipImportedTypes_QtHelp_QtGui[];

#define sipType_QWidget sipImportedTypes_QtHelp_QtWidgets[12].it_td

#define sipType_QAbstractItemDelegate sipImportedTypes_QtHelp_QtWidgets[0].it_td

#define sipType_QAbstractItemDelegate_EndEditHint sipImportedTypes_QtHelp_QtWidgets[1].it_td

#define sipType_QFrame sipImportedTypes_QtHelp_QtWidgets[7].it_td

#define sipType_QAbstractScrollArea sipImportedTypes_QtHelp_QtWidgets[6].it_td

#define sipType_QAbstractItemView sipImportedTypes_QtHelp_QtWidgets[2].it_td

#define sipType_QAbstractItemView_CursorAction sipImportedTypes_QtHelp_QtWidgets[3].it_td

#define sipType_QAbstractItemView_ScrollHint sipImportedTypes_QtHelp_QtWidgets[5].it_td

#define sipType_QAbstractItemView_EditTrigger sipImportedTypes_QtHelp_QtWidgets[4].it_td

#define sipType_QListView sipImportedTypes_QtHelp_QtWidgets[8].it_td

#define sipType_QStyleOptionFrame sipImportedTypes_QtHelp_QtWidgets[9].it_td

#define sipType_QStyleOptionViewItem sipImportedTypes_QtHelp_QtWidgets[10].it_td

#define sipType_QTreeView sipImportedTypes_QtHelp_QtWidgets[11].it_td
extern sipImportedTypeDef sipImportedTypes_QtHelp_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtHelp_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtHelp_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtHelp_qt_metacast;

#endif
