/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qprocess.sip"
#include <qprocess.h>
#line 235 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qprocess.sip"
#include <qprocess.h>
#line 31 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQProcessUnixProcessParameters.cpp"

#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQProcessUnixProcessParameters.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qprocess.sip"
#include <qprocess.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQProcessUnixProcessParameters.cpp"


/* Call the instance's destructor. */
extern "C" {static void release_QProcess_UnixProcessParameters(void *, int);}
static void release_QProcess_UnixProcessParameters(void *sipCppV, int)
{
    delete reinterpret_cast< ::QProcess::UnixProcessParameters *>(sipCppV);
}


extern "C" {static void *array_QProcess_UnixProcessParameters(Py_ssize_t);}
static void *array_QProcess_UnixProcessParameters(Py_ssize_t sipNrElem)
{
    return new ::QProcess::UnixProcessParameters[sipNrElem];
}


extern "C" {static void array_delete_QProcess_UnixProcessParameters(void *);}
static void array_delete_QProcess_UnixProcessParameters(void *sipCpp)
{
    delete[] reinterpret_cast< ::QProcess::UnixProcessParameters *>(sipCpp);
}


extern "C" {static void assign_QProcess_UnixProcessParameters(void *, Py_ssize_t, void *);}
static void assign_QProcess_UnixProcessParameters(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QProcess::UnixProcessParameters *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QProcess::UnixProcessParameters *>(sipSrc);
}


extern "C" {static void *copy_QProcess_UnixProcessParameters(const void *, Py_ssize_t);}
static void *copy_QProcess_UnixProcessParameters(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QProcess::UnixProcessParameters(reinterpret_cast<const ::QProcess::UnixProcessParameters *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QProcess_UnixProcessParameters(sipSimpleWrapper *);}
static void dealloc_QProcess_UnixProcessParameters(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QProcess_UnixProcessParameters(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QProcess_UnixProcessParameters(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QProcess_UnixProcessParameters(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QProcess::UnixProcessParameters *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QProcess::UnixProcessParameters();

            return sipCpp;
        }
    }

    {
        const ::QProcess::UnixProcessParameters* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QProcess_UnixProcessParameters, &a0))
        {
            sipCpp = new ::QProcess::UnixProcessParameters(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static PyObject *varget_QProcess_UnixProcessParameters_flags(void *, PyObject *, PyObject *);}
static PyObject *varget_QProcess_UnixProcessParameters_flags(void *sipSelf, PyObject *, PyObject *)
{
    ::QProcess::UnixProcessFlags*sipVal;
    ::QProcess::UnixProcessParameters *sipCpp = reinterpret_cast< ::QProcess::UnixProcessParameters *>(sipSelf);

    sipVal = &sipCpp->flags;

    return sipConvertFromType(sipVal, sipType_QFlags_0100QProcess_UnixProcessFlag, SIP_NULLPTR);
}


extern "C" {static int varset_QProcess_UnixProcessParameters_flags(void *, PyObject *, PyObject *);}
static int varset_QProcess_UnixProcessParameters_flags(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QProcess::UnixProcessFlags*sipVal;
    ::QProcess::UnixProcessParameters *sipCpp = reinterpret_cast< ::QProcess::UnixProcessParameters *>(sipSelf);

    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast< ::QProcess::UnixProcessFlags *>(sipForceConvertToType(sipPy, sipType_QFlags_0100QProcess_UnixProcessFlag, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->flags = *sipVal;

    sipReleaseType(sipVal, sipType_QFlags_0100QProcess_UnixProcessFlag, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_QProcess_UnixProcessParameters_lowestFileDescriptorToClose(void *, PyObject *, PyObject *);}
static PyObject *varget_QProcess_UnixProcessParameters_lowestFileDescriptorToClose(void *sipSelf, PyObject *, PyObject *)
{
    int sipVal;
    ::QProcess::UnixProcessParameters *sipCpp = reinterpret_cast< ::QProcess::UnixProcessParameters *>(sipSelf);

    sipVal = sipCpp->lowestFileDescriptorToClose;

    return PyLong_FromLong(sipVal);
}


extern "C" {static int varset_QProcess_UnixProcessParameters_lowestFileDescriptorToClose(void *, PyObject *, PyObject *);}
static int varset_QProcess_UnixProcessParameters_lowestFileDescriptorToClose(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
    ::QProcess::UnixProcessParameters *sipCpp = reinterpret_cast< ::QProcess::UnixProcessParameters *>(sipSelf);

    sipVal = sipLong_AsInt(sipPy);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->lowestFileDescriptorToClose = sipVal;

    return 0;
}

sipVariableDef variables_QProcess_UnixProcessParameters[] = {
    {InstanceVariable, sipName_flags, (PyMethodDef *)varget_QProcess_UnixProcessParameters_flags, (PyMethodDef *)varset_QProcess_UnixProcessParameters_flags, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_lowestFileDescriptorToClose, (PyMethodDef *)varget_QProcess_UnixProcessParameters_lowestFileDescriptorToClose, (PyMethodDef *)varset_QProcess_UnixProcessParameters_lowestFileDescriptorToClose, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QProcess_UnixProcessParameters, "\1QProcess.UnixProcessParameters()\n"
"QProcess.UnixProcessParameters(a0: QProcess.UnixProcessParameters)");


sipClassTypeDef sipTypeDef_QtCore_QProcess_UnixProcessParameters = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QProcess__UnixProcessParameters,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_UnixProcessParameters,
        {267, 255, 0},
        0, SIP_NULLPTR,
        2, variables_QProcess_UnixProcessParameters,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QProcess_UnixProcessParameters,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QProcess_UnixProcessParameters,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QProcess_UnixProcessParameters,
    assign_QProcess_UnixProcessParameters,
    array_QProcess_UnixProcessParameters,
    copy_QProcess_UnixProcessParameters,
    release_QProcess_UnixProcessParameters,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QProcess_UnixProcessParameters,
    sizeof (::QProcess::UnixProcessParameters),
};
