/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstandardpaths.sip"
#include <qstandardpaths.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQStandardPaths.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQStandardPaths.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQStandardPaths.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQStandardPaths.cpp"


PyDoc_STRVAR(doc_QStandardPaths_writableLocation, "writableLocation(type: QStandardPaths.StandardLocation) -> str");

extern "C" {static PyObject *meth_QStandardPaths_writableLocation(PyObject *, PyObject *);}
static PyObject *meth_QStandardPaths_writableLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStandardPaths::StandardLocation a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QStandardPaths_StandardLocation, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QStandardPaths::writableLocation(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardPaths, sipName_writableLocation, doc_QStandardPaths_writableLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardPaths_standardLocations, "standardLocations(type: QStandardPaths.StandardLocation) -> list[str]");

extern "C" {static PyObject *meth_QStandardPaths_standardLocations(PyObject *, PyObject *);}
static PyObject *meth_QStandardPaths_standardLocations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStandardPaths::StandardLocation a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QStandardPaths_StandardLocation, &a0))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QStandardPaths::standardLocations(a0));

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardPaths, sipName_standardLocations, doc_QStandardPaths_standardLocations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardPaths_locate, "locate(type: QStandardPaths.StandardLocation, fileName: str|None, options: QStandardPaths.LocateOption = QStandardPaths.LocateFile) -> str");

extern "C" {static PyObject *meth_QStandardPaths_locate(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardPaths_locate(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStandardPaths::StandardLocation a0;
        const ::QString* a1;
        int a1State = 0;
        ::QStandardPaths::LocateOptions a2def = QStandardPaths::LocateFile;
        ::QStandardPaths::LocateOptions* a2 = &a2def;
        int a2State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "CEJ1|J1", &sipSelf, sipType_QStandardPaths_StandardLocation, &a0, sipType_QString, &a1, &a1State, sipType_QFlags_0100QStandardPaths_LocateOption, &a2, &a2State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QStandardPaths::locate(a0, *a1, *a2));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(a2, sipType_QFlags_0100QStandardPaths_LocateOption, a2State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardPaths, sipName_locate, doc_QStandardPaths_locate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardPaths_locateAll, "locateAll(type: QStandardPaths.StandardLocation, fileName: str|None, options: QStandardPaths.LocateOption = QStandardPaths.LocateFile) -> list[str]");

extern "C" {static PyObject *meth_QStandardPaths_locateAll(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardPaths_locateAll(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStandardPaths::StandardLocation a0;
        const ::QString* a1;
        int a1State = 0;
        ::QStandardPaths::LocateOptions a2def = QStandardPaths::LocateFile;
        ::QStandardPaths::LocateOptions* a2 = &a2def;
        int a2State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "CEJ1|J1", &sipSelf, sipType_QStandardPaths_StandardLocation, &a0, sipType_QString, &a1, &a1State, sipType_QFlags_0100QStandardPaths_LocateOption, &a2, &a2State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QStandardPaths::locateAll(a0, *a1, *a2));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(a2, sipType_QFlags_0100QStandardPaths_LocateOption, a2State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardPaths, sipName_locateAll, doc_QStandardPaths_locateAll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardPaths_displayName, "displayName(type: QStandardPaths.StandardLocation) -> str");

extern "C" {static PyObject *meth_QStandardPaths_displayName(PyObject *, PyObject *);}
static PyObject *meth_QStandardPaths_displayName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStandardPaths::StandardLocation a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QStandardPaths_StandardLocation, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QStandardPaths::displayName(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardPaths, sipName_displayName, doc_QStandardPaths_displayName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardPaths_findExecutable, "findExecutable(executableName: str|None, paths: Iterable[str|None] = []) -> str");

extern "C" {static PyObject *meth_QStandardPaths_findExecutable(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardPaths_findExecutable(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QStringList& a1def = QStringList();
        const ::QStringList* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_paths,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "CJ1|J1", &sipSelf, sipType_QString, &a0, &a0State, sipType_QStringList, &a1, &a1State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QStandardPaths::findExecutable(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QStringList *>(a1), sipType_QStringList, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardPaths, sipName_findExecutable, doc_QStandardPaths_findExecutable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardPaths_setTestModeEnabled, "setTestModeEnabled(testMode: bool)");

extern "C" {static PyObject *meth_QStandardPaths_setTestModeEnabled(PyObject *, PyObject *);}
static PyObject *meth_QStandardPaths_setTestModeEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "Cb", &sipSelf, &a0))
        {
            ::QStandardPaths::setTestModeEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardPaths, sipName_setTestModeEnabled, doc_QStandardPaths_setTestModeEnabled);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QStandardPaths(void *, int);}
static void release_QStandardPaths(void *, int)
{
}


extern "C" {static void *init_type_QStandardPaths(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QStandardPaths(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QStandardPaths *sipCpp = SIP_NULLPTR;

    {
        const ::QStandardPaths* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QStandardPaths, &a0))
        {
            sipCpp = new ::QStandardPaths(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QStandardPaths[] = {
    {sipName_displayName, meth_QStandardPaths_displayName, METH_VARARGS, doc_QStandardPaths_displayName},
    {sipName_findExecutable, SIP_MLMETH_CAST(meth_QStandardPaths_findExecutable), METH_VARARGS|METH_KEYWORDS, doc_QStandardPaths_findExecutable},
    {sipName_locate, SIP_MLMETH_CAST(meth_QStandardPaths_locate), METH_VARARGS|METH_KEYWORDS, doc_QStandardPaths_locate},
    {sipName_locateAll, SIP_MLMETH_CAST(meth_QStandardPaths_locateAll), METH_VARARGS|METH_KEYWORDS, doc_QStandardPaths_locateAll},
    {sipName_setTestModeEnabled, meth_QStandardPaths_setTestModeEnabled, METH_VARARGS, doc_QStandardPaths_setTestModeEnabled},
    {sipName_standardLocations, meth_QStandardPaths_standardLocations, METH_VARARGS, doc_QStandardPaths_standardLocations},
    {sipName_writableLocation, meth_QStandardPaths_writableLocation, METH_VARARGS, doc_QStandardPaths_writableLocation}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QStandardPaths[] = {
    {sipName_LocateFile, static_cast<int>(::QStandardPaths::LocateFile)},
    {sipName_LocateDirectory, static_cast<int>(::QStandardPaths::LocateDirectory)},
    {sipName_DesktopLocation, static_cast<int>(::QStandardPaths::DesktopLocation)},
    {sipName_DocumentsLocation, static_cast<int>(::QStandardPaths::DocumentsLocation)},
    {sipName_FontsLocation, static_cast<int>(::QStandardPaths::FontsLocation)},
    {sipName_ApplicationsLocation, static_cast<int>(::QStandardPaths::ApplicationsLocation)},
    {sipName_MusicLocation, static_cast<int>(::QStandardPaths::MusicLocation)},
    {sipName_MoviesLocation, static_cast<int>(::QStandardPaths::MoviesLocation)},
    {sipName_PicturesLocation, static_cast<int>(::QStandardPaths::PicturesLocation)},
    {sipName_TempLocation, static_cast<int>(::QStandardPaths::TempLocation)},
    {sipName_HomeLocation, static_cast<int>(::QStandardPaths::HomeLocation)},
    {sipName_CacheLocation, static_cast<int>(::QStandardPaths::CacheLocation)},
    {sipName_GenericDataLocation, static_cast<int>(::QStandardPaths::GenericDataLocation)},
    {sipName_RuntimeLocation, static_cast<int>(::QStandardPaths::RuntimeLocation)},
    {sipName_ConfigLocation, static_cast<int>(::QStandardPaths::ConfigLocation)},
    {sipName_DownloadLocation, static_cast<int>(::QStandardPaths::DownloadLocation)},
    {sipName_GenericCacheLocation, static_cast<int>(::QStandardPaths::GenericCacheLocation)},
    {sipName_GenericConfigLocation, static_cast<int>(::QStandardPaths::GenericConfigLocation)},
    {sipName_AppDataLocation, static_cast<int>(::QStandardPaths::AppDataLocation)},
    {sipName_AppLocalDataLocation, static_cast<int>(::QStandardPaths::AppLocalDataLocation)},
    {sipName_AppConfigLocation, static_cast<int>(::QStandardPaths::AppConfigLocation)},
    {sipName_PublicShareLocation, static_cast<int>(::QStandardPaths::PublicShareLocation)},
    {sipName_TemplatesLocation, static_cast<int>(::QStandardPaths::TemplatesLocation)},
    {sipName_StateLocation, static_cast<int>(::QStandardPaths::StateLocation)},
    {sipName_GenericStateLocation, static_cast<int>(::QStandardPaths::GenericStateLocation)},
    {0, 0}
};

PyDoc_STRVAR(doc_QStandardPaths, "\1QStandardPaths(a0: QStandardPaths)");


sipClassTypeDef sipTypeDef_QtCore_QStandardPaths = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStandardPaths,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QStandardPaths,
        {0, 0, 1},
        7, methods_QStandardPaths,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QStandardPaths, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QStandardPaths,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QStandardPaths,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QStandardPaths,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QStandardPaths),
};
