/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 691 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointerEvent.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qeventpoint.sip"
#include <qeventpoint.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointerEvent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointerEvent.cpp"
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpointingdevice.sip"
#include <qpointingdevice.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointerEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qinputdevice.sip"
#include <qinputdevice.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointerEvent.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointerEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointerEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPointerEvent.cpp"


PyDoc_STRVAR(doc_QPointerEvent_pointingDevice, "pointingDevice(self) -> QPointingDevice|None");

extern "C" {static PyObject *meth_QPointerEvent_pointingDevice(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_pointingDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointerEvent, &sipCpp))
        {
            const ::QPointingDevice*sipRes;

            sipRes = sipCpp->pointingDevice();

            return sipConvertFromType(const_cast< ::QPointingDevice *>(sipRes), sipType_QPointingDevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_pointingDevice, doc_QPointerEvent_pointingDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointerEvent_pointerType, "pointerType(self) -> QPointingDevice.PointerType");

extern "C" {static PyObject *meth_QPointerEvent_pointerType(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_pointerType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointerEvent, &sipCpp))
        {
            ::QPointingDevice::PointerType sipRes;

            sipRes = sipCpp->pointerType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPointingDevice_PointerType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_pointerType, doc_QPointerEvent_pointerType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointerEvent_pointCount, "pointCount(self) -> int");

extern "C" {static PyObject *meth_QPointerEvent_pointCount(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_pointCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointerEvent, &sipCpp))
        {
            ::qsizetype sipRes;

            sipRes = sipCpp->pointCount();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_pointCount, doc_QPointerEvent_pointCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointerEvent_point, "point(self, i: int) -> QEventPoint");

extern "C" {static PyObject *meth_QPointerEvent_point(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_point(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QPointerEvent, &sipCpp, &a0))
        {
            ::QEventPoint*sipRes;

            sipRes = &sipCpp->point(a0);

            return sipConvertFromType(sipRes, sipType_QEventPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_point, doc_QPointerEvent_point);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointerEvent_points, "points(self) -> list[QEventPoint]");

extern "C" {static PyObject *meth_QPointerEvent_points(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_points(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointerEvent, &sipCpp))
        {
            QList< ::QEventPoint>*sipRes;

            sipRes = new QList< ::QEventPoint>(sipCpp->points());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QEventPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_points, doc_QPointerEvent_points);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointerEvent_pointById, "pointById(self, id: int) -> QEventPoint|None");

extern "C" {static PyObject *meth_QPointerEvent_pointById(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_pointById(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QPointerEvent, &sipCpp, &a0))
        {
            ::QEventPoint*sipRes;

            sipRes = sipCpp->pointById(a0);

            return sipConvertFromType(sipRes, sipType_QEventPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_pointById, doc_QPointerEvent_pointById);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointerEvent_isBeginEvent, "isBeginEvent(self) -> bool");

extern "C" {static PyObject *meth_QPointerEvent_isBeginEvent(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_isBeginEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPointerEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointerEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPointerEvent::isBeginEvent() : sipCpp->isBeginEvent());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_isBeginEvent, doc_QPointerEvent_isBeginEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointerEvent_isUpdateEvent, "isUpdateEvent(self) -> bool");

extern "C" {static PyObject *meth_QPointerEvent_isUpdateEvent(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_isUpdateEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPointerEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointerEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPointerEvent::isUpdateEvent() : sipCpp->isUpdateEvent());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_isUpdateEvent, doc_QPointerEvent_isUpdateEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointerEvent_isEndEvent, "isEndEvent(self) -> bool");

extern "C" {static PyObject *meth_QPointerEvent_isEndEvent(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_isEndEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPointerEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointerEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPointerEvent::isEndEvent() : sipCpp->isEndEvent());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_isEndEvent, doc_QPointerEvent_isEndEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointerEvent_allPointsAccepted, "allPointsAccepted(self) -> bool");

extern "C" {static PyObject *meth_QPointerEvent_allPointsAccepted(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_allPointsAccepted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointerEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->allPointsAccepted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_allPointsAccepted, doc_QPointerEvent_allPointsAccepted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointerEvent_setAccepted, "setAccepted(self, accepted: bool)");

extern "C" {static PyObject *meth_QPointerEvent_setAccepted(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_setAccepted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPointerEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
        ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QPointerEvent, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QPointerEvent::setAccepted(a0) : sipCpp->setAccepted(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_setAccepted, doc_QPointerEvent_setAccepted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPointerEvent_clone, "clone(self) -> QPointerEvent|None");

extern "C" {static PyObject *meth_QPointerEvent_clone(PyObject *, PyObject *);}
static PyObject *meth_QPointerEvent_clone(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPointerEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPointerEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPointerEvent, &sipCpp))
        {
            ::QPointerEvent*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPointerEvent::clone() : sipCpp->clone());

            return sipConvertFromType(sipRes, sipType_QPointerEvent, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPointerEvent, sipName_clone, doc_QPointerEvent_clone);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPointerEvent(void *, const sipTypeDef *);}
static void *cast_QPointerEvent(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPointerEvent *sipCpp = reinterpret_cast< ::QPointerEvent *>(sipCppV);

    if (targetType == sipType_QPointerEvent)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QInputEvent)->ctd_cast(static_cast< ::QInputEvent *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPointerEvent(void *, int);}
static void release_QPointerEvent(void *sipCppV, int)
{
    delete reinterpret_cast< ::QPointerEvent *>(sipCppV);
}


extern "C" {static void dealloc_QPointerEvent(sipSimpleWrapper *);}
static void dealloc_QPointerEvent(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPointerEvent(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPointerEvent[] = {{124, 255, 1}};


static PyMethodDef methods_QPointerEvent[] = {
    {sipName_allPointsAccepted, meth_QPointerEvent_allPointsAccepted, METH_VARARGS, doc_QPointerEvent_allPointsAccepted},
    {sipName_clone, meth_QPointerEvent_clone, METH_VARARGS, doc_QPointerEvent_clone},
    {sipName_isBeginEvent, meth_QPointerEvent_isBeginEvent, METH_VARARGS, doc_QPointerEvent_isBeginEvent},
    {sipName_isEndEvent, meth_QPointerEvent_isEndEvent, METH_VARARGS, doc_QPointerEvent_isEndEvent},
    {sipName_isUpdateEvent, meth_QPointerEvent_isUpdateEvent, METH_VARARGS, doc_QPointerEvent_isUpdateEvent},
    {sipName_point, meth_QPointerEvent_point, METH_VARARGS, doc_QPointerEvent_point},
    {sipName_pointById, meth_QPointerEvent_pointById, METH_VARARGS, doc_QPointerEvent_pointById},
    {sipName_pointCount, meth_QPointerEvent_pointCount, METH_VARARGS, doc_QPointerEvent_pointCount},
    {sipName_pointerType, meth_QPointerEvent_pointerType, METH_VARARGS, doc_QPointerEvent_pointerType},
    {sipName_pointingDevice, meth_QPointerEvent_pointingDevice, METH_VARARGS, doc_QPointerEvent_pointingDevice},
    {sipName_points, meth_QPointerEvent_points, METH_VARARGS, doc_QPointerEvent_points},
    {sipName_setAccepted, meth_QPointerEvent_setAccepted, METH_VARARGS, doc_QPointerEvent_setAccepted}
};


sipClassTypeDef sipTypeDef_QtGui_QPointerEvent = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPointerEvent,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QPointerEvent,
        {0, 0, 1},
        12, methods_QPointerEvent,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QPointerEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPointerEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QPointerEvent,
    cast_QPointerEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
