/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSensors.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSensors/qambienttemperaturesensor.sip"
#include <qambienttemperaturesensor.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSensors/sipQtSensorsQAmbientTemperatureReading.cpp"


PyDoc_STRVAR(doc_QAmbientTemperatureReading_temperature, "temperature(self) -> float");

extern "C" {static PyObject *meth_QAmbientTemperatureReading_temperature(PyObject *, PyObject *);}
static PyObject *meth_QAmbientTemperatureReading_temperature(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAmbientTemperatureReading *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAmbientTemperatureReading, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->temperature();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAmbientTemperatureReading, sipName_temperature, doc_QAmbientTemperatureReading_temperature);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAmbientTemperatureReading_setTemperature, "setTemperature(self, temperature: float)");

extern "C" {static PyObject *meth_QAmbientTemperatureReading_setTemperature(PyObject *, PyObject *);}
static PyObject *meth_QAmbientTemperatureReading_setTemperature(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QAmbientTemperatureReading *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QAmbientTemperatureReading, &sipCpp, &a0))
        {
            sipCpp->setTemperature(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAmbientTemperatureReading, sipName_setTemperature, doc_QAmbientTemperatureReading_setTemperature);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAmbientTemperatureReading(void *, const sipTypeDef *);}
static void *cast_QAmbientTemperatureReading(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAmbientTemperatureReading *sipCpp = reinterpret_cast< ::QAmbientTemperatureReading *>(sipCppV);

    if (targetType == sipType_QAmbientTemperatureReading)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QSensorReading)->ctd_cast(static_cast< ::QSensorReading *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAmbientTemperatureReading(void *, int);}
static void release_QAmbientTemperatureReading(void *sipCppV, int)
{
    ::QAmbientTemperatureReading *sipCpp = reinterpret_cast< ::QAmbientTemperatureReading *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QAmbientTemperatureReading(sipSimpleWrapper *);}
static void dealloc_QAmbientTemperatureReading(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAmbientTemperatureReading(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAmbientTemperatureReading[] = {{51, 255, 1}};


static PyMethodDef methods_QAmbientTemperatureReading[] = {
    {sipName_setTemperature, meth_QAmbientTemperatureReading_setTemperature, METH_VARARGS, doc_QAmbientTemperatureReading_setTemperature},
    {sipName_temperature, meth_QAmbientTemperatureReading_temperature, METH_VARARGS, doc_QAmbientTemperatureReading_temperature}
};


static pyqt6ClassPluginDef plugin_QAmbientTemperatureReading = {
    &::QAmbientTemperatureReading::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSensors_QAmbientTemperatureReading = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAmbientTemperatureReading,
        SIP_NULLPTR,
        &plugin_QAmbientTemperatureReading,
    },
    {
        sipNameNr_QAmbientTemperatureReading,
        {0, 0, 1},
        2, methods_QAmbientTemperatureReading,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QAmbientTemperatureReading,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAmbientTemperatureReading,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QAmbientTemperatureReading,
    cast_QAmbientTemperatureReading,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
