/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qlowenergydescriptordata.sip"
#include <qlowenergydescriptordata.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyDescriptorData.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothuuid.sip"
#include <qbluetoothuuid.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyDescriptorData.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyDescriptorData.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyDescriptorData.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetooth.sip"
#include <qbluetooth.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyDescriptorData.cpp"


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_value, "value(self) -> QByteArray");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_value(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptorData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->value());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_value, doc_QLowEnergyDescriptorData_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_setValue, "setValue(self, value: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_setValue(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_setValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QLowEnergyDescriptorData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setValue(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_setValue, doc_QLowEnergyDescriptorData_setValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_uuid, "uuid(self) -> QBluetoothUuid");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_uuid(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_uuid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptorData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp))
        {
            ::QBluetoothUuid*sipRes;

            sipRes = new ::QBluetoothUuid(sipCpp->uuid());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothUuid, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_uuid, doc_QLowEnergyDescriptorData_uuid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_setUuid, "setUuid(self, uuid: QBluetoothUuid)");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_setUuid(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_setUuid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothUuid* a0;
        ::QLowEnergyDescriptorData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp, sipType_QBluetoothUuid, &a0))
        {
            sipCpp->setUuid(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_setUuid, doc_QLowEnergyDescriptorData_setUuid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_isValid(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptorData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_isValid, doc_QLowEnergyDescriptorData_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_setReadPermissions, "setReadPermissions(self, readable: bool, constraints: QBluetooth.AttAccessConstraint = QBluetooth.AttAccessConstraints())");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_setReadPermissions(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_setReadPermissions(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QBluetooth::AttAccessConstraints a1def = QBluetooth::AttAccessConstraints();
        ::QBluetooth::AttAccessConstraints* a1 = &a1def;
        int a1State = 0;
        ::QLowEnergyDescriptorData *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_constraints,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bb|J1", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp, &a0, sipType_QFlags_0100QBluetooth_AttAccessConstraint, &a1, &a1State))
        {
            sipCpp->setReadPermissions(a0, *a1);
            sipReleaseType(a1, sipType_QFlags_0100QBluetooth_AttAccessConstraint, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_setReadPermissions, doc_QLowEnergyDescriptorData_setReadPermissions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_isReadable, "isReadable(self) -> bool");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_isReadable(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_isReadable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptorData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isReadable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_isReadable, doc_QLowEnergyDescriptorData_isReadable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_readConstraints, "readConstraints(self) -> QBluetooth.AttAccessConstraint");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_readConstraints(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_readConstraints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptorData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp))
        {
            ::QBluetooth::AttAccessConstraints*sipRes;

            sipRes = new ::QBluetooth::AttAccessConstraints(sipCpp->readConstraints());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QBluetooth_AttAccessConstraint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_readConstraints, doc_QLowEnergyDescriptorData_readConstraints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_setWritePermissions, "setWritePermissions(self, writable: bool, constraints: QBluetooth.AttAccessConstraint = QBluetooth.AttAccessConstraints())");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_setWritePermissions(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_setWritePermissions(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QBluetooth::AttAccessConstraints a1def = QBluetooth::AttAccessConstraints();
        ::QBluetooth::AttAccessConstraints* a1 = &a1def;
        int a1State = 0;
        ::QLowEnergyDescriptorData *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_constraints,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bb|J1", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp, &a0, sipType_QFlags_0100QBluetooth_AttAccessConstraint, &a1, &a1State))
        {
            sipCpp->setWritePermissions(a0, *a1);
            sipReleaseType(a1, sipType_QFlags_0100QBluetooth_AttAccessConstraint, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_setWritePermissions, doc_QLowEnergyDescriptorData_setWritePermissions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_isWritable, "isWritable(self) -> bool");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_isWritable(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_isWritable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptorData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isWritable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_isWritable, doc_QLowEnergyDescriptorData_isWritable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_writeConstraints, "writeConstraints(self) -> QBluetooth.AttAccessConstraint");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_writeConstraints(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_writeConstraints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptorData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp))
        {
            ::QBluetooth::AttAccessConstraints*sipRes;

            sipRes = new ::QBluetooth::AttAccessConstraints(sipCpp->writeConstraints());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QBluetooth_AttAccessConstraint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_writeConstraints, doc_QLowEnergyDescriptorData_writeConstraints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptorData_swap, "swap(self, other: QLowEnergyDescriptorData)");

extern "C" {static PyObject *meth_QLowEnergyDescriptorData_swap(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptorData_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLowEnergyDescriptorData* a0;
        ::QLowEnergyDescriptorData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLowEnergyDescriptorData, &sipCpp, sipType_QLowEnergyDescriptorData, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptorData, sipName_swap, doc_QLowEnergyDescriptorData_swap);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QLowEnergyDescriptorData___eq__(PyObject *, PyObject *);}
static PyObject *slot_QLowEnergyDescriptorData___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLowEnergyDescriptorData *sipCpp = reinterpret_cast< ::QLowEnergyDescriptorData *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLowEnergyDescriptorData));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptorData* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLowEnergyDescriptorData, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, eq_slot, sipType_QLowEnergyDescriptorData, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QLowEnergyDescriptorData___ne__(PyObject *, PyObject *);}
static PyObject *slot_QLowEnergyDescriptorData___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLowEnergyDescriptorData *sipCpp = reinterpret_cast< ::QLowEnergyDescriptorData *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLowEnergyDescriptorData));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptorData* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLowEnergyDescriptorData, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, ne_slot, sipType_QLowEnergyDescriptorData, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QLowEnergyDescriptorData(void *, int);}
static void release_QLowEnergyDescriptorData(void *sipCppV, int)
{
    delete reinterpret_cast< ::QLowEnergyDescriptorData *>(sipCppV);
}


extern "C" {static void *array_QLowEnergyDescriptorData(Py_ssize_t);}
static void *array_QLowEnergyDescriptorData(Py_ssize_t sipNrElem)
{
    return new ::QLowEnergyDescriptorData[sipNrElem];
}


extern "C" {static void array_delete_QLowEnergyDescriptorData(void *);}
static void array_delete_QLowEnergyDescriptorData(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLowEnergyDescriptorData *>(sipCpp);
}


extern "C" {static void assign_QLowEnergyDescriptorData(void *, Py_ssize_t, void *);}
static void assign_QLowEnergyDescriptorData(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QLowEnergyDescriptorData *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QLowEnergyDescriptorData *>(sipSrc);
}


extern "C" {static void *copy_QLowEnergyDescriptorData(const void *, Py_ssize_t);}
static void *copy_QLowEnergyDescriptorData(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QLowEnergyDescriptorData(reinterpret_cast<const ::QLowEnergyDescriptorData *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QLowEnergyDescriptorData(sipSimpleWrapper *);}
static void dealloc_QLowEnergyDescriptorData(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLowEnergyDescriptorData(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QLowEnergyDescriptorData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLowEnergyDescriptorData(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QLowEnergyDescriptorData *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QLowEnergyDescriptorData();

            return sipCpp;
        }
    }

    {
        const ::QBluetoothUuid* a0;
        const ::QByteArray* a1;
        int a1State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9J1", sipType_QBluetoothUuid, &a0, sipType_QByteArray, &a1, &a1State))
        {
            sipCpp = new ::QLowEnergyDescriptorData(*a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            return sipCpp;
        }
    }

    {
        const ::QLowEnergyDescriptorData* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QLowEnergyDescriptorData, &a0))
        {
            sipCpp = new ::QLowEnergyDescriptorData(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QLowEnergyDescriptorData[] = {
    {(void *)slot_QLowEnergyDescriptorData___eq__, eq_slot},
    {(void *)slot_QLowEnergyDescriptorData___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QLowEnergyDescriptorData[] = {
    {sipName_isReadable, meth_QLowEnergyDescriptorData_isReadable, METH_VARARGS, doc_QLowEnergyDescriptorData_isReadable},
    {sipName_isValid, meth_QLowEnergyDescriptorData_isValid, METH_VARARGS, doc_QLowEnergyDescriptorData_isValid},
    {sipName_isWritable, meth_QLowEnergyDescriptorData_isWritable, METH_VARARGS, doc_QLowEnergyDescriptorData_isWritable},
    {sipName_readConstraints, meth_QLowEnergyDescriptorData_readConstraints, METH_VARARGS, doc_QLowEnergyDescriptorData_readConstraints},
    {sipName_setReadPermissions, SIP_MLMETH_CAST(meth_QLowEnergyDescriptorData_setReadPermissions), METH_VARARGS|METH_KEYWORDS, doc_QLowEnergyDescriptorData_setReadPermissions},
    {sipName_setUuid, meth_QLowEnergyDescriptorData_setUuid, METH_VARARGS, doc_QLowEnergyDescriptorData_setUuid},
    {sipName_setValue, meth_QLowEnergyDescriptorData_setValue, METH_VARARGS, doc_QLowEnergyDescriptorData_setValue},
    {sipName_setWritePermissions, SIP_MLMETH_CAST(meth_QLowEnergyDescriptorData_setWritePermissions), METH_VARARGS|METH_KEYWORDS, doc_QLowEnergyDescriptorData_setWritePermissions},
    {sipName_swap, meth_QLowEnergyDescriptorData_swap, METH_VARARGS, doc_QLowEnergyDescriptorData_swap},
    {sipName_uuid, meth_QLowEnergyDescriptorData_uuid, METH_VARARGS, doc_QLowEnergyDescriptorData_uuid},
    {sipName_value, meth_QLowEnergyDescriptorData_value, METH_VARARGS, doc_QLowEnergyDescriptorData_value},
    {sipName_writeConstraints, meth_QLowEnergyDescriptorData_writeConstraints, METH_VARARGS, doc_QLowEnergyDescriptorData_writeConstraints}
};

PyDoc_STRVAR(doc_QLowEnergyDescriptorData, "\1QLowEnergyDescriptorData()\n"
"QLowEnergyDescriptorData(uuid: QBluetoothUuid, value: QByteArray|bytes|bytearray|memoryview)\n"
"QLowEnergyDescriptorData(other: QLowEnergyDescriptorData)");


sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyDescriptorData = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLowEnergyDescriptorData,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QLowEnergyDescriptorData,
        {0, 0, 1},
        12, methods_QLowEnergyDescriptorData,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLowEnergyDescriptorData,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QLowEnergyDescriptorData,
    init_type_QLowEnergyDescriptorData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLowEnergyDescriptorData,
    assign_QLowEnergyDescriptorData,
    array_QLowEnergyDescriptorData,
    copy_QLowEnergyDescriptorData,
    release_QLowEnergyDescriptorData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLowEnergyDescriptorData,
    sizeof (::QLowEnergyDescriptorData),
};
