/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 825 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeGestureEvent.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeGestureEvent.cpp"
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpointingdevice.sip"
#include <qpointingdevice.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeGestureEvent.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeGestureEvent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeGestureEvent.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeGestureEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qeventpoint.sip"
#include <qeventpoint.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeGestureEvent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeGestureEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qinputdevice.sip"
#include <qinputdevice.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeGestureEvent.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeGestureEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQNativeGestureEvent.cpp"


class sipQNativeGestureEvent : public ::QNativeGestureEvent
{
public:
    sipQNativeGestureEvent(::Qt::NativeGestureType, const ::QPointingDevice*, int, const ::QPointF&, const ::QPointF&, const ::QPointF&, ::qreal, const ::QPointF&, ::quint64);
    sipQNativeGestureEvent(::Qt::NativeGestureType, const ::QPointingDevice*, const ::QPointF&, const ::QPointF&, const ::QPointF&, ::qreal, ::quint64, ::quint64);
    virtual ~sipQNativeGestureEvent();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool isEndEvent() const SIP_OVERRIDE;
    bool isUpdateEvent() const SIP_OVERRIDE;
    bool isBeginEvent() const SIP_OVERRIDE;
    ::QNativeGestureEvent* clone() const SIP_OVERRIDE;
    void setAccepted(bool) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQNativeGestureEvent(const sipQNativeGestureEvent &);
    sipQNativeGestureEvent &operator = (const sipQNativeGestureEvent &);

    char sipPyMethods[5];
};

sipQNativeGestureEvent::sipQNativeGestureEvent(::Qt::NativeGestureType a0, const ::QPointingDevice*a1, int a2, const ::QPointF& a3, const ::QPointF& a4, const ::QPointF& a5, ::qreal a6, const ::QPointF& a7, ::quint64 a8): ::QNativeGestureEvent(a0, a1, a2, a3, a4, a5, a6, a7, a8), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQNativeGestureEvent::sipQNativeGestureEvent(::Qt::NativeGestureType a0, const ::QPointingDevice*a1, const ::QPointF& a2, const ::QPointF& a3, const ::QPointF& a4, ::qreal a5, ::quint64 a6, ::quint64 a7): ::QNativeGestureEvent(a0, a1, a2, a3, a4, a5, a6, a7), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQNativeGestureEvent::~sipQNativeGestureEvent()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

bool sipQNativeGestureEvent::isEndEvent() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isEndEvent);

    if (!sipMeth)
        return ::QNativeGestureEvent::isEndEvent();

    extern bool sipVH_QtGui_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_54(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQNativeGestureEvent::isUpdateEvent() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isUpdateEvent);

    if (!sipMeth)
        return ::QNativeGestureEvent::isUpdateEvent();

    extern bool sipVH_QtGui_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_54(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQNativeGestureEvent::isBeginEvent() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isBeginEvent);

    if (!sipMeth)
        return ::QNativeGestureEvent::isBeginEvent();

    extern bool sipVH_QtGui_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_54(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QNativeGestureEvent* sipQNativeGestureEvent::clone() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_clone);

    if (!sipMeth)
        return ::QNativeGestureEvent::clone();

    extern ::QNativeGestureEvent* sipVH_QtGui_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_61(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQNativeGestureEvent::setAccepted(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_setAccepted);

    if (!sipMeth)
    {
        ::QNativeGestureEvent::setAccepted(a0);
        return;
    }

    extern void sipVH_QtGui_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtGui_25(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QNativeGestureEvent_gestureType, "gestureType(self) -> Qt.NativeGestureType");

extern "C" {static PyObject *meth_QNativeGestureEvent_gestureType(PyObject *, PyObject *);}
static PyObject *meth_QNativeGestureEvent_gestureType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNativeGestureEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNativeGestureEvent, &sipCpp))
        {
            ::Qt::NativeGestureType sipRes;

            sipRes = sipCpp->gestureType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_NativeGestureType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeGestureEvent, sipName_gestureType, doc_QNativeGestureEvent_gestureType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeGestureEvent_value, "value(self) -> float");

extern "C" {static PyObject *meth_QNativeGestureEvent_value(PyObject *, PyObject *);}
static PyObject *meth_QNativeGestureEvent_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNativeGestureEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNativeGestureEvent, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->value();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeGestureEvent, sipName_value, doc_QNativeGestureEvent_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeGestureEvent_clone, "clone(self) -> QNativeGestureEvent|None");

extern "C" {static PyObject *meth_QNativeGestureEvent_clone(PyObject *, PyObject *);}
static PyObject *meth_QNativeGestureEvent_clone(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNativeGestureEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QNativeGestureEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNativeGestureEvent, &sipCpp))
        {
            ::QNativeGestureEvent*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QNativeGestureEvent::clone() : sipCpp->clone());

            return sipConvertFromType(sipRes, sipType_QNativeGestureEvent, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeGestureEvent, sipName_clone, doc_QNativeGestureEvent_clone);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeGestureEvent_fingerCount, "fingerCount(self) -> int");

extern "C" {static PyObject *meth_QNativeGestureEvent_fingerCount(PyObject *, PyObject *);}
static PyObject *meth_QNativeGestureEvent_fingerCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNativeGestureEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNativeGestureEvent, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->fingerCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeGestureEvent, sipName_fingerCount, doc_QNativeGestureEvent_fingerCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNativeGestureEvent_delta, "delta(self) -> QPointF");

extern "C" {static PyObject *meth_QNativeGestureEvent_delta(PyObject *, PyObject *);}
static PyObject *meth_QNativeGestureEvent_delta(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNativeGestureEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNativeGestureEvent, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->delta());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNativeGestureEvent, sipName_delta, doc_QNativeGestureEvent_delta);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QNativeGestureEvent(void *, const sipTypeDef *);}
static void *cast_QNativeGestureEvent(void *sipCppV, const sipTypeDef *targetType)
{
    ::QNativeGestureEvent *sipCpp = reinterpret_cast< ::QNativeGestureEvent *>(sipCppV);

    if (targetType == sipType_QNativeGestureEvent)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QSinglePointEvent)->ctd_cast(static_cast< ::QSinglePointEvent *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNativeGestureEvent(void *, int);}
static void release_QNativeGestureEvent(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQNativeGestureEvent *>(sipCppV);
    else
        delete reinterpret_cast< ::QNativeGestureEvent *>(sipCppV);
}


extern "C" {static void dealloc_QNativeGestureEvent(sipSimpleWrapper *);}
static void dealloc_QNativeGestureEvent(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQNativeGestureEvent *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNativeGestureEvent(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QNativeGestureEvent(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QNativeGestureEvent(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQNativeGestureEvent *sipCpp = SIP_NULLPTR;

    {
        ::Qt::NativeGestureType a0;
        const ::QPointingDevice* a1;
        int a2;
        const ::QPointF* a3;
        const ::QPointF* a4;
        const ::QPointF* a5;
        ::qreal a6;
        const ::QPointF* a7;
        ::quint64 a8 = UINT64_MAX;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_sequenceId,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "EJ8iJ9J9J9dJ9|o", sipType_Qt_NativeGestureType, &a0, sipType_QPointingDevice, &a1, &a2, sipType_QPointF, &a3, sipType_QPointF, &a4, sipType_QPointF, &a5, &a6, sipType_QPointF, &a7, &a8))
        {
            sipCpp = new sipQNativeGestureEvent(a0, a1, a2, *a3, *a4, *a5, a6, *a7, a8);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::Qt::NativeGestureType a0;
        const ::QPointingDevice* a1;
        const ::QPointF* a2;
        const ::QPointF* a3;
        const ::QPointF* a4;
        ::qreal a5;
        ::quint64 a6;
        ::quint64 a7;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "EJ8J9J9J9doo", sipType_Qt_NativeGestureType, &a0, sipType_QPointingDevice, &a1, sipType_QPointF, &a2, sipType_QPointF, &a3, sipType_QPointF, &a4, &a5, &a6, &a7))
        {
            sipCpp = new sipQNativeGestureEvent(a0, a1, *a2, *a3, *a4, a5, a6, a7);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QNativeGestureEvent[] = {{274, 255, 1}};


static PyMethodDef methods_QNativeGestureEvent[] = {
    {sipName_clone, meth_QNativeGestureEvent_clone, METH_VARARGS, doc_QNativeGestureEvent_clone},
    {sipName_delta, meth_QNativeGestureEvent_delta, METH_VARARGS, doc_QNativeGestureEvent_delta},
    {sipName_fingerCount, meth_QNativeGestureEvent_fingerCount, METH_VARARGS, doc_QNativeGestureEvent_fingerCount},
    {sipName_gestureType, meth_QNativeGestureEvent_gestureType, METH_VARARGS, doc_QNativeGestureEvent_gestureType},
    {sipName_value, meth_QNativeGestureEvent_value, METH_VARARGS, doc_QNativeGestureEvent_value}
};

PyDoc_STRVAR(doc_QNativeGestureEvent, "\1QNativeGestureEvent(type: Qt.NativeGestureType, dev: QPointingDevice|None, fingerCount: int, localPos: QPointF, scenePos: QPointF, globalPos: QPointF, value: float, delta: QPointF, sequenceId: int = UINT64_MAX)\n"
"QNativeGestureEvent(type: Qt.NativeGestureType, dev: QPointingDevice|None, localPos: QPointF, scenePos: QPointF, globalPos: QPointF, value: float, sequenceId: int, intArgument: int)");


sipClassTypeDef sipTypeDef_QtGui_QNativeGestureEvent = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNativeGestureEvent,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QNativeGestureEvent,
        {0, 0, 1},
        5, methods_QNativeGestureEvent,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QNativeGestureEvent,
    -1,
    -1,
    supers_QNativeGestureEvent,
    SIP_NULLPTR,
    init_type_QNativeGestureEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QNativeGestureEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QNativeGestureEvent,
    cast_QNativeGestureEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QNativeGestureEvent),
};
