/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick3D.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3dgeometry.sip"
#include <qquick3dgeometry.h>
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3dgeometry.sip"
#include <qquick3dgeometry.h>
#line 31 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DGeometryAttribute.cpp"



/* Call the instance's destructor. */
extern "C" {static void release_QQuick3DGeometry_Attribute(void *, int);}
static void release_QQuick3DGeometry_Attribute(void *sipCppV, int)
{
    delete reinterpret_cast< ::QQuick3DGeometry::Attribute *>(sipCppV);
}


extern "C" {static void *array_QQuick3DGeometry_Attribute(Py_ssize_t);}
static void *array_QQuick3DGeometry_Attribute(Py_ssize_t sipNrElem)
{
    return new ::QQuick3DGeometry::Attribute[sipNrElem];
}


extern "C" {static void array_delete_QQuick3DGeometry_Attribute(void *);}
static void array_delete_QQuick3DGeometry_Attribute(void *sipCpp)
{
    delete[] reinterpret_cast< ::QQuick3DGeometry::Attribute *>(sipCpp);
}


extern "C" {static void assign_QQuick3DGeometry_Attribute(void *, Py_ssize_t, void *);}
static void assign_QQuick3DGeometry_Attribute(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QQuick3DGeometry::Attribute *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QQuick3DGeometry::Attribute *>(sipSrc);
}


extern "C" {static void *copy_QQuick3DGeometry_Attribute(const void *, Py_ssize_t);}
static void *copy_QQuick3DGeometry_Attribute(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QQuick3DGeometry::Attribute(reinterpret_cast<const ::QQuick3DGeometry::Attribute *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QQuick3DGeometry_Attribute(sipSimpleWrapper *);}
static void dealloc_QQuick3DGeometry_Attribute(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuick3DGeometry_Attribute(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QQuick3DGeometry_Attribute(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuick3DGeometry_Attribute(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QQuick3DGeometry::Attribute *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QQuick3DGeometry::Attribute();

            return sipCpp;
        }
    }

    {
        const ::QQuick3DGeometry::Attribute* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QQuick3DGeometry_Attribute, &a0))
        {
            sipCpp = new ::QQuick3DGeometry::Attribute(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static PyObject *varget_QQuick3DGeometry_Attribute_componentType(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuick3DGeometry_Attribute_componentType(void *sipSelf, PyObject *, PyObject *)
{
    ::QQuick3DGeometry::Attribute::ComponentType sipVal;
    ::QQuick3DGeometry::Attribute *sipCpp = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(sipSelf);

    sipVal = sipCpp->componentType;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QQuick3DGeometry_Attribute_ComponentType);
}


extern "C" {static int varset_QQuick3DGeometry_Attribute_componentType(void *, PyObject *, PyObject *);}
static int varset_QQuick3DGeometry_Attribute_componentType(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QQuick3DGeometry::Attribute::ComponentType sipVal;
    ::QQuick3DGeometry::Attribute *sipCpp = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(sipSelf);

    sipVal = (::QQuick3DGeometry::Attribute::ComponentType)sipConvertToEnum(sipPy, sipType_QQuick3DGeometry_Attribute_ComponentType);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->componentType = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QQuick3DGeometry_Attribute_offset(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuick3DGeometry_Attribute_offset(void *sipSelf, PyObject *, PyObject *)
{
    int sipVal;
    ::QQuick3DGeometry::Attribute *sipCpp = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(sipSelf);

    sipVal = sipCpp->offset;

    return PyLong_FromLong(sipVal);
}


extern "C" {static int varset_QQuick3DGeometry_Attribute_offset(void *, PyObject *, PyObject *);}
static int varset_QQuick3DGeometry_Attribute_offset(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
    ::QQuick3DGeometry::Attribute *sipCpp = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(sipSelf);

    sipVal = sipLong_AsInt(sipPy);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->offset = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QQuick3DGeometry_Attribute_semantic(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuick3DGeometry_Attribute_semantic(void *sipSelf, PyObject *, PyObject *)
{
    ::QQuick3DGeometry::Attribute::Semantic sipVal;
    ::QQuick3DGeometry::Attribute *sipCpp = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(sipSelf);

    sipVal = sipCpp->semantic;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QQuick3DGeometry_Attribute_Semantic);
}


extern "C" {static int varset_QQuick3DGeometry_Attribute_semantic(void *, PyObject *, PyObject *);}
static int varset_QQuick3DGeometry_Attribute_semantic(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QQuick3DGeometry::Attribute::Semantic sipVal;
    ::QQuick3DGeometry::Attribute *sipCpp = reinterpret_cast< ::QQuick3DGeometry::Attribute *>(sipSelf);

    sipVal = (::QQuick3DGeometry::Attribute::Semantic)sipConvertToEnum(sipPy, sipType_QQuick3DGeometry_Attribute_Semantic);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->semantic = sipVal;

    return 0;
}

sipVariableDef variables_QQuick3DGeometry_Attribute[] = {
    {InstanceVariable, sipName_componentType, (PyMethodDef *)varget_QQuick3DGeometry_Attribute_componentType, (PyMethodDef *)varset_QQuick3DGeometry_Attribute_componentType, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_offset, (PyMethodDef *)varget_QQuick3DGeometry_Attribute_offset, (PyMethodDef *)varset_QQuick3DGeometry_Attribute_offset, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_semantic, (PyMethodDef *)varget_QQuick3DGeometry_Attribute_semantic, (PyMethodDef *)varset_QQuick3DGeometry_Attribute_semantic, SIP_NULLPTR, SIP_NULLPTR},
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QQuick3DGeometry_Attribute[] = {
    {sipName_U16Type, static_cast<int>(::QQuick3DGeometry::Attribute::U16Type)},
    {sipName_U32Type, static_cast<int>(::QQuick3DGeometry::Attribute::U32Type)},
    {sipName_F32Type, static_cast<int>(::QQuick3DGeometry::Attribute::F32Type)},
    {sipName_I32Type, static_cast<int>(::QQuick3DGeometry::Attribute::I32Type)},
    {sipName_IndexSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::IndexSemantic)},
    {sipName_PositionSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::PositionSemantic)},
    {sipName_NormalSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::NormalSemantic)},
    {sipName_TexCoordSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::TexCoordSemantic)},
    {sipName_TangentSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::TangentSemantic)},
    {sipName_BinormalSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::BinormalSemantic)},
    {sipName_JointSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::JointSemantic)},
    {sipName_WeightSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::WeightSemantic)},
    {sipName_ColorSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::ColorSemantic)},
    {sipName_TargetPositionSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::TargetPositionSemantic)},
    {sipName_TargetNormalSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::TargetNormalSemantic)},
    {sipName_TargetTangentSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::TargetTangentSemantic)},
    {sipName_TargetBinormalSemantic, static_cast<int>(::QQuick3DGeometry::Attribute::TargetBinormalSemantic)},
    {sipName_TexCoord1Semantic, static_cast<int>(::QQuick3DGeometry::Attribute::TexCoord1Semantic)},
    {sipName_TexCoord0Semantic, static_cast<int>(::QQuick3DGeometry::Attribute::TexCoord0Semantic)},
    {0, 0}
};

PyDoc_STRVAR(doc_QQuick3DGeometry_Attribute, "\1QQuick3DGeometry.Attribute()\n"
"QQuick3DGeometry.Attribute(a0: QQuick3DGeometry.Attribute)");


sipClassTypeDef sipTypeDef_QtQuick3D_QQuick3DGeometry_Attribute = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuick3DGeometry__Attribute,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_Attribute,
        {1, 255, 0},
        0, SIP_NULLPTR,
        3, variables_QQuick3DGeometry_Attribute,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QQuick3DGeometry_Attribute, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuick3DGeometry_Attribute,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQuick3DGeometry_Attribute,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuick3DGeometry_Attribute,
    assign_QQuick3DGeometry_Attribute,
    array_QQuick3DGeometry_Attribute,
    copy_QQuick3DGeometry_Attribute,
    release_QQuick3DGeometry_Attribute,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QQuick3DGeometry_Attribute,
    sizeof (::QQuick3DGeometry::Attribute),
};
