/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquicktextdocument.sip"
#include <qquicktextdocument.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextdocument.sip"
#include <qtextdocument.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQQuickTextDocument.cpp"


class sipQQuickTextDocument : public ::QQuickTextDocument
{
public:
    sipQQuickTextDocument(::QQuickItem*);
    virtual ~sipQQuickTextDocument();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickTextDocument(const sipQQuickTextDocument &);
    sipQQuickTextDocument &operator = (const sipQQuickTextDocument &);

    char sipPyMethods[7];
};

sipQQuickTextDocument::sipQQuickTextDocument(::QQuickItem*a0): ::QQuickTextDocument(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQuickTextDocument::~sipQQuickTextDocument()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQQuickTextDocument::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtQuick_qt_metaobject(sipPySelf, sipType_QQuickTextDocument);

    return ::QQuickTextDocument::metaObject();
}

int sipQQuickTextDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QQuickTextDocument::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtQuick_qt_metacall(sipPySelf, sipType_QQuickTextDocument, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQQuickTextDocument::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtQuick_qt_metacast(sipPySelf, sipType_QQuickTextDocument, _clname, &sipCpp) ? sipCpp : ::QQuickTextDocument::qt_metacast(_clname));
}

bool sipQQuickTextDocument::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QQuickTextDocument::event(a0);

    extern bool sipVH_QtQuick_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtQuick_5(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQuickTextDocument::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QQuickTextDocument::eventFilter(a0, a1);

    extern bool sipVH_QtQuick_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtQuick_4(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQQuickTextDocument::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QQuickTextDocument::timerEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtQuick_3(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickTextDocument::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QQuickTextDocument::childEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtQuick_2(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickTextDocument::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QQuickTextDocument::customEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtQuick_1(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickTextDocument::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QQuickTextDocument::connectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQuick_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickTextDocument::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QQuickTextDocument::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQuick_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QQuickTextDocument_textDocument, "textDocument(self) -> QTextDocument|None");

extern "C" {static PyObject *meth_QQuickTextDocument_textDocument(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextDocument_textDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickTextDocument *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickTextDocument, &sipCpp))
        {
            ::QTextDocument*sipRes;

            sipRes = sipCpp->textDocument();

            return sipConvertFromType(sipRes, sipType_QTextDocument, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextDocument, sipName_textDocument, doc_QQuickTextDocument_textDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextDocument_source, "source(self) -> QUrl");

extern "C" {static PyObject *meth_QQuickTextDocument_source(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextDocument_source(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickTextDocument *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickTextDocument, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->source());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextDocument, sipName_source, doc_QQuickTextDocument_source);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextDocument_setSource, "setSource(self, url: QUrl)");

extern "C" {static PyObject *meth_QQuickTextDocument_setSource(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextDocument_setSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QQuickTextDocument *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QQuickTextDocument, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setSource(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextDocument, sipName_setSource, doc_QQuickTextDocument_setSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextDocument_isModified, "isModified(self) -> bool");

extern "C" {static PyObject *meth_QQuickTextDocument_isModified(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextDocument_isModified(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickTextDocument *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickTextDocument, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isModified();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextDocument, sipName_isModified, doc_QQuickTextDocument_isModified);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextDocument_setModified, "setModified(self, modified: bool)");

extern "C" {static PyObject *meth_QQuickTextDocument_setModified(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextDocument_setModified(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QQuickTextDocument *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQuickTextDocument, &sipCpp, &a0))
        {
            sipCpp->setModified(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextDocument, sipName_setModified, doc_QQuickTextDocument_setModified);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextDocument_setTextDocument, "setTextDocument(self, document: QTextDocument|None)");

extern "C" {static PyObject *meth_QQuickTextDocument_setTextDocument(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextDocument_setTextDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextDocument* a0;
        ::QQuickTextDocument *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QQuickTextDocument, &sipCpp, sipType_QTextDocument, &a0))
        {
            sipCpp->setTextDocument(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextDocument, sipName_setTextDocument, doc_QQuickTextDocument_setTextDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextDocument_save, "save(self)");

extern "C" {static PyObject *meth_QQuickTextDocument_save(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextDocument_save(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QQuickTextDocument *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickTextDocument, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->save();
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextDocument, sipName_save, doc_QQuickTextDocument_save);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextDocument_saveAs, "saveAs(self, url: QUrl)");

extern "C" {static PyObject *meth_QQuickTextDocument_saveAs(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextDocument_saveAs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QQuickTextDocument *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QQuickTextDocument, &sipCpp, sipType_QUrl, &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->saveAs(*a0);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextDocument, sipName_saveAs, doc_QQuickTextDocument_saveAs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextDocument_status, "status(self) -> QQuickTextDocument.Status");

extern "C" {static PyObject *meth_QQuickTextDocument_status(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextDocument_status(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickTextDocument *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickTextDocument, &sipCpp))
        {
            ::QQuickTextDocument::Status sipRes;

            sipRes = sipCpp->status();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QQuickTextDocument_Status);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextDocument, sipName_status, doc_QQuickTextDocument_status);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickTextDocument_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QQuickTextDocument_errorString(PyObject *, PyObject *);}
static PyObject *meth_QQuickTextDocument_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuickTextDocument *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickTextDocument, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickTextDocument, sipName_errorString, doc_QQuickTextDocument_errorString);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQuickTextDocument(void *, const sipTypeDef *);}
static void *cast_QQuickTextDocument(void *sipCppV, const sipTypeDef *targetType)
{
    ::QQuickTextDocument *sipCpp = reinterpret_cast< ::QQuickTextDocument *>(sipCppV);

    if (targetType == sipType_QQuickTextDocument)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQuickTextDocument(void *, int);}
static void release_QQuickTextDocument(void *sipCppV, int)
{
    ::QQuickTextDocument *sipCpp = reinterpret_cast< ::QQuickTextDocument *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QQuickTextDocument(sipSimpleWrapper *);}
static void dealloc_QQuickTextDocument(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQuickTextDocument *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuickTextDocument(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQuickTextDocument(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuickTextDocument(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQQuickTextDocument *sipCpp = SIP_NULLPTR;

    {
        ::QQuickItem* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "JH", sipType_QQuickItem, &a0, sipOwner))
        {
            sipCpp = new sipQQuickTextDocument(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQuickTextDocument[] = {{11, 0, 1}};


static PyMethodDef methods_QQuickTextDocument[] = {
    {sipName_errorString, meth_QQuickTextDocument_errorString, METH_VARARGS, doc_QQuickTextDocument_errorString},
    {sipName_isModified, meth_QQuickTextDocument_isModified, METH_VARARGS, doc_QQuickTextDocument_isModified},
    {sipName_save, meth_QQuickTextDocument_save, METH_VARARGS, doc_QQuickTextDocument_save},
    {sipName_saveAs, meth_QQuickTextDocument_saveAs, METH_VARARGS, doc_QQuickTextDocument_saveAs},
    {sipName_setModified, meth_QQuickTextDocument_setModified, METH_VARARGS, doc_QQuickTextDocument_setModified},
    {sipName_setSource, meth_QQuickTextDocument_setSource, METH_VARARGS, doc_QQuickTextDocument_setSource},
    {sipName_setTextDocument, meth_QQuickTextDocument_setTextDocument, METH_VARARGS, doc_QQuickTextDocument_setTextDocument},
    {sipName_source, meth_QQuickTextDocument_source, METH_VARARGS, doc_QQuickTextDocument_source},
    {sipName_status, meth_QQuickTextDocument_status, METH_VARARGS, doc_QQuickTextDocument_status},
    {sipName_textDocument, meth_QQuickTextDocument_textDocument, METH_VARARGS, doc_QQuickTextDocument_textDocument}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QQuickTextDocument[] = {
    {sipName_Null, static_cast<int>(::QQuickTextDocument::Status::Null)},
    {sipName_Loading, static_cast<int>(::QQuickTextDocument::Status::Loading)},
    {sipName_Loaded, static_cast<int>(::QQuickTextDocument::Status::Loaded)},
    {sipName_Saving, static_cast<int>(::QQuickTextDocument::Status::Saving)},
    {sipName_Saved, static_cast<int>(::QQuickTextDocument::Status::Saved)},
    {sipName_ReadError, static_cast<int>(::QQuickTextDocument::Status::ReadError)},
    {sipName_WriteError, static_cast<int>(::QQuickTextDocument::Status::WriteError)},
    {sipName_NonLocalFileError, static_cast<int>(::QQuickTextDocument::Status::NonLocalFileError)},
    {0, 0}
};

PyDoc_STRVAR(doc_QQuickTextDocument, "\1QQuickTextDocument(parent: QQuickItem|None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QQuickTextDocument[] = {
    {"errorStringChanged()", "\1errorStringChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusChanged()", "\1statusChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"modifiedChanged()", "\1modifiedChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"sourceChanged()", "\1sourceChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"textDocumentChanged()", "\1textDocumentChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QQuickTextDocument = {
    &::QQuickTextDocument::staticMetaObject,
    signals_QQuickTextDocument,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QQuickTextDocument = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuickTextDocument,
        SIP_NULLPTR,
        &plugin_QQuickTextDocument,
    },
    {
        sipNameNr_QQuickTextDocument,
        {0, 0, 1},
        10, methods_QQuickTextDocument,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QQuickTextDocument, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuickTextDocument,
    -1,
    -1,
    supers_QQuickTextDocument,
    SIP_NULLPTR,
    init_type_QQuickTextDocument,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuickTextDocument,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQuickTextDocument,
    cast_QQuickTextDocument,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QQuickTextDocument),
};
