/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qssl.sip"
#include <qssl.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQSsl.cpp"



/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QSsl[] = {
    {sipName_Warning, static_cast<int>(::QSsl::AlertLevel::Warning)},
    {sipName_Fatal, static_cast<int>(::QSsl::AlertLevel::Fatal)},
    {sipName_Unknown, static_cast<int>(::QSsl::AlertLevel::Unknown)},
    {sipName_CloseNotify, static_cast<int>(::QSsl::AlertType::CloseNotify)},
    {sipName_UnexpectedMessage, static_cast<int>(::QSsl::AlertType::UnexpectedMessage)},
    {sipName_BadRecordMac, static_cast<int>(::QSsl::AlertType::BadRecordMac)},
    {sipName_RecordOverflow, static_cast<int>(::QSsl::AlertType::RecordOverflow)},
    {sipName_DecompressionFailure, static_cast<int>(::QSsl::AlertType::DecompressionFailure)},
    {sipName_HandshakeFailure, static_cast<int>(::QSsl::AlertType::HandshakeFailure)},
    {sipName_NoCertificate, static_cast<int>(::QSsl::AlertType::NoCertificate)},
    {sipName_BadCertificate, static_cast<int>(::QSsl::AlertType::BadCertificate)},
    {sipName_UnsupportedCertificate, static_cast<int>(::QSsl::AlertType::UnsupportedCertificate)},
    {sipName_CertificateRevoked, static_cast<int>(::QSsl::AlertType::CertificateRevoked)},
    {sipName_CertificateExpired, static_cast<int>(::QSsl::AlertType::CertificateExpired)},
    {sipName_CertificateUnknown, static_cast<int>(::QSsl::AlertType::CertificateUnknown)},
    {sipName_IllegalParameter, static_cast<int>(::QSsl::AlertType::IllegalParameter)},
    {sipName_UnknownCa, static_cast<int>(::QSsl::AlertType::UnknownCa)},
    {sipName_AccessDenied, static_cast<int>(::QSsl::AlertType::AccessDenied)},
    {sipName_DecodeError, static_cast<int>(::QSsl::AlertType::DecodeError)},
    {sipName_DecryptError, static_cast<int>(::QSsl::AlertType::DecryptError)},
    {sipName_ExportRestriction, static_cast<int>(::QSsl::AlertType::ExportRestriction)},
    {sipName_ProtocolVersion, static_cast<int>(::QSsl::AlertType::ProtocolVersion)},
    {sipName_InsufficientSecurity, static_cast<int>(::QSsl::AlertType::InsufficientSecurity)},
    {sipName_InternalError, static_cast<int>(::QSsl::AlertType::InternalError)},
    {sipName_InappropriateFallback, static_cast<int>(::QSsl::AlertType::InappropriateFallback)},
    {sipName_UserCancelled, static_cast<int>(::QSsl::AlertType::UserCancelled)},
    {sipName_NoRenegotiation, static_cast<int>(::QSsl::AlertType::NoRenegotiation)},
    {sipName_MissingExtension, static_cast<int>(::QSsl::AlertType::MissingExtension)},
    {sipName_UnsupportedExtension, static_cast<int>(::QSsl::AlertType::UnsupportedExtension)},
    {sipName_CertificateUnobtainable, static_cast<int>(::QSsl::AlertType::CertificateUnobtainable)},
    {sipName_UnrecognizedName, static_cast<int>(::QSsl::AlertType::UnrecognizedName)},
    {sipName_BadCertificateStatusResponse, static_cast<int>(::QSsl::AlertType::BadCertificateStatusResponse)},
    {sipName_BadCertificateHashValue, static_cast<int>(::QSsl::AlertType::BadCertificateHashValue)},
    {sipName_UnknownPskIdentity, static_cast<int>(::QSsl::AlertType::UnknownPskIdentity)},
    {sipName_CertificateRequired, static_cast<int>(::QSsl::AlertType::CertificateRequired)},
    {sipName_NoApplicationProtocol, static_cast<int>(::QSsl::AlertType::NoApplicationProtocol)},
    {sipName_UnknownAlertMessage, static_cast<int>(::QSsl::AlertType::UnknownAlertMessage)},
    {sipName_EmailEntry, static_cast<int>(::QSsl::EmailEntry)},
    {sipName_DnsEntry, static_cast<int>(::QSsl::DnsEntry)},
    {sipName_IpAddressEntry, static_cast<int>(::QSsl::IpAddressEntry)},
    {sipName_Pem, static_cast<int>(::QSsl::Pem)},
    {sipName_Der, static_cast<int>(::QSsl::Der)},
    {sipName_Key, static_cast<int>(::QSsl::ImplementedClass::Key)},
    {sipName_Certificate, static_cast<int>(::QSsl::ImplementedClass::Certificate)},
    {sipName_Socket, static_cast<int>(::QSsl::ImplementedClass::Socket)},
    {sipName_DiffieHellman, static_cast<int>(::QSsl::ImplementedClass::DiffieHellman)},
    {sipName_EllipticCurve, static_cast<int>(::QSsl::ImplementedClass::EllipticCurve)},
    {sipName_Dtls, static_cast<int>(::QSsl::ImplementedClass::Dtls)},
    {sipName_DtlsCookie, static_cast<int>(::QSsl::ImplementedClass::DtlsCookie)},
    {sipName_Opaque, static_cast<int>(::QSsl::Opaque)},
    {sipName_Rsa, static_cast<int>(::QSsl::Rsa)},
    {sipName_Dsa, static_cast<int>(::QSsl::Dsa)},
    {sipName_Ec, static_cast<int>(::QSsl::Ec)},
    {sipName_Dh, static_cast<int>(::QSsl::Dh)},
    {sipName_MlDsa, static_cast<int>(::QSsl::MlDsa)},
    {sipName_PrivateKey, static_cast<int>(::QSsl::PrivateKey)},
    {sipName_PublicKey, static_cast<int>(::QSsl::PublicKey)},
    {sipName_SslOptionDisableEmptyFragments, static_cast<int>(::QSsl::SslOptionDisableEmptyFragments)},
    {sipName_SslOptionDisableSessionTickets, static_cast<int>(::QSsl::SslOptionDisableSessionTickets)},
    {sipName_SslOptionDisableCompression, static_cast<int>(::QSsl::SslOptionDisableCompression)},
    {sipName_SslOptionDisableServerNameIndication, static_cast<int>(::QSsl::SslOptionDisableServerNameIndication)},
    {sipName_SslOptionDisableLegacyRenegotiation, static_cast<int>(::QSsl::SslOptionDisableLegacyRenegotiation)},
    {sipName_SslOptionDisableSessionSharing, static_cast<int>(::QSsl::SslOptionDisableSessionSharing)},
    {sipName_SslOptionDisableSessionPersistence, static_cast<int>(::QSsl::SslOptionDisableSessionPersistence)},
    {sipName_SslOptionDisableServerCipherPreference, static_cast<int>(::QSsl::SslOptionDisableServerCipherPreference)},
    {sipName_UnknownProtocol, static_cast<int>(::QSsl::UnknownProtocol)},
    {sipName_TlsV1_0, static_cast<int>(::QSsl::TlsV1_0)},
    {sipName_TlsV1_0OrLater, static_cast<int>(::QSsl::TlsV1_0OrLater)},
    {sipName_TlsV1_1, static_cast<int>(::QSsl::TlsV1_1)},
    {sipName_TlsV1_1OrLater, static_cast<int>(::QSsl::TlsV1_1OrLater)},
    {sipName_TlsV1_2, static_cast<int>(::QSsl::TlsV1_2)},
    {sipName_TlsV1_2OrLater, static_cast<int>(::QSsl::TlsV1_2OrLater)},
    {sipName_AnyProtocol, static_cast<int>(::QSsl::AnyProtocol)},
    {sipName_SecureProtocols, static_cast<int>(::QSsl::SecureProtocols)},
    {sipName_DtlsV1_0, static_cast<int>(::QSsl::DtlsV1_0)},
    {sipName_DtlsV1_0OrLater, static_cast<int>(::QSsl::DtlsV1_0OrLater)},
    {sipName_DtlsV1_2, static_cast<int>(::QSsl::DtlsV1_2)},
    {sipName_DtlsV1_2OrLater, static_cast<int>(::QSsl::DtlsV1_2OrLater)},
    {sipName_TlsV1_3, static_cast<int>(::QSsl::TlsV1_3)},
    {sipName_TlsV1_3OrLater, static_cast<int>(::QSsl::TlsV1_3OrLater)},
    {sipName_CertificateVerification, static_cast<int>(::QSsl::SupportedFeature::CertificateVerification)},
    {sipName_ClientSideAlpn, static_cast<int>(::QSsl::SupportedFeature::ClientSideAlpn)},
    {sipName_ServerSideAlpn, static_cast<int>(::QSsl::SupportedFeature::ServerSideAlpn)},
    {sipName_Ocsp, static_cast<int>(::QSsl::SupportedFeature::Ocsp)},
    {sipName_Psk, static_cast<int>(::QSsl::SupportedFeature::Psk)},
    {sipName_SessionTicket, static_cast<int>(::QSsl::SupportedFeature::SessionTicket)},
    {sipName_Alerts, static_cast<int>(::QSsl::SupportedFeature::Alerts)},
    {0, 0}
};


sipClassTypeDef sipTypeDef_QtNetwork_QSsl = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_NAMESPACE,
        sipNameNr_QSsl,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QSsl,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QSsl, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
