/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qstylehints.sip"
#include <qstylehints.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaccessibilityhints.sip"
#include <qaccessibilityhints.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qchar.sip"
#include <qchar.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 49 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 52 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 55 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 58 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 61 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 64 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 67 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStyleHints.cpp"


PyDoc_STRVAR(doc_QStyleHints_mouseDoubleClickInterval, "mouseDoubleClickInterval(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_mouseDoubleClickInterval(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_mouseDoubleClickInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->mouseDoubleClickInterval();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_mouseDoubleClickInterval, doc_QStyleHints_mouseDoubleClickInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_startDragDistance, "startDragDistance(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_startDragDistance(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_startDragDistance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->startDragDistance();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_startDragDistance, doc_QStyleHints_startDragDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_startDragTime, "startDragTime(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_startDragTime(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_startDragTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->startDragTime();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_startDragTime, doc_QStyleHints_startDragTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_startDragVelocity, "startDragVelocity(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_startDragVelocity(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_startDragVelocity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->startDragVelocity();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_startDragVelocity, doc_QStyleHints_startDragVelocity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_keyboardInputInterval, "keyboardInputInterval(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_keyboardInputInterval(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_keyboardInputInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->keyboardInputInterval();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_keyboardInputInterval, doc_QStyleHints_keyboardInputInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_keyboardAutoRepeatRate, "keyboardAutoRepeatRate(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_keyboardAutoRepeatRate(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_keyboardAutoRepeatRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->keyboardAutoRepeatRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_keyboardAutoRepeatRate, doc_QStyleHints_keyboardAutoRepeatRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_cursorFlashTime, "cursorFlashTime(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_cursorFlashTime(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_cursorFlashTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->cursorFlashTime();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_cursorFlashTime, doc_QStyleHints_cursorFlashTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_showIsFullScreen, "showIsFullScreen(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_showIsFullScreen(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_showIsFullScreen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->showIsFullScreen();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_showIsFullScreen, doc_QStyleHints_showIsFullScreen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_passwordMaskDelay, "passwordMaskDelay(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_passwordMaskDelay(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_passwordMaskDelay(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->passwordMaskDelay();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_passwordMaskDelay, doc_QStyleHints_passwordMaskDelay);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_fontSmoothingGamma, "fontSmoothingGamma(self) -> float");

extern "C" {static PyObject *meth_QStyleHints_fontSmoothingGamma(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_fontSmoothingGamma(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->fontSmoothingGamma();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_fontSmoothingGamma, doc_QStyleHints_fontSmoothingGamma);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_useRtlExtensions, "useRtlExtensions(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_useRtlExtensions(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_useRtlExtensions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->useRtlExtensions();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_useRtlExtensions, doc_QStyleHints_useRtlExtensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_passwordMaskCharacter, "passwordMaskCharacter(self) -> str");

extern "C" {static PyObject *meth_QStyleHints_passwordMaskCharacter(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_passwordMaskCharacter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            ::QChar*sipRes;

            sipRes = new ::QChar(sipCpp->passwordMaskCharacter());

            return sipConvertFromNewType(sipRes, sipType_QChar, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_passwordMaskCharacter, doc_QStyleHints_passwordMaskCharacter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_setFocusOnTouchRelease, "setFocusOnTouchRelease(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_setFocusOnTouchRelease(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_setFocusOnTouchRelease(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->setFocusOnTouchRelease();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_setFocusOnTouchRelease, doc_QStyleHints_setFocusOnTouchRelease);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_mousePressAndHoldInterval, "mousePressAndHoldInterval(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_mousePressAndHoldInterval(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_mousePressAndHoldInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->mousePressAndHoldInterval();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_mousePressAndHoldInterval, doc_QStyleHints_mousePressAndHoldInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_tabFocusBehavior, "tabFocusBehavior(self) -> Qt.TabFocusBehavior");

extern "C" {static PyObject *meth_QStyleHints_tabFocusBehavior(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_tabFocusBehavior(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            ::Qt::TabFocusBehavior sipRes;

            sipRes = sipCpp->tabFocusBehavior();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_TabFocusBehavior);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_tabFocusBehavior, doc_QStyleHints_tabFocusBehavior);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_singleClickActivation, "singleClickActivation(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_singleClickActivation(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_singleClickActivation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->singleClickActivation();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_singleClickActivation, doc_QStyleHints_singleClickActivation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_showIsMaximized, "showIsMaximized(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_showIsMaximized(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_showIsMaximized(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->showIsMaximized();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_showIsMaximized, doc_QStyleHints_showIsMaximized);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_useHoverEffects, "useHoverEffects(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_useHoverEffects(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_useHoverEffects(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->useHoverEffects();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_useHoverEffects, doc_QStyleHints_useHoverEffects);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_setUseHoverEffects, "setUseHoverEffects(self, useHoverEffects: bool)");

extern "C" {static PyObject *meth_QStyleHints_setUseHoverEffects(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_setUseHoverEffects(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStyleHints, &sipCpp, &a0))
        {
            sipCpp->setUseHoverEffects(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_setUseHoverEffects, doc_QStyleHints_setUseHoverEffects);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_wheelScrollLines, "wheelScrollLines(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_wheelScrollLines(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_wheelScrollLines(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->wheelScrollLines();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_wheelScrollLines, doc_QStyleHints_wheelScrollLines);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_showShortcutsInContextMenus, "showShortcutsInContextMenus(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_showShortcutsInContextMenus(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_showShortcutsInContextMenus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->showShortcutsInContextMenus();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_showShortcutsInContextMenus, doc_QStyleHints_showShortcutsInContextMenus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_mouseQuickSelectionThreshold, "mouseQuickSelectionThreshold(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_mouseQuickSelectionThreshold(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_mouseQuickSelectionThreshold(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->mouseQuickSelectionThreshold();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_mouseQuickSelectionThreshold, doc_QStyleHints_mouseQuickSelectionThreshold);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_setShowShortcutsInContextMenus, "setShowShortcutsInContextMenus(self, showShortcutsInContextMenus: bool)");

extern "C" {static PyObject *meth_QStyleHints_setShowShortcutsInContextMenus(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_setShowShortcutsInContextMenus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStyleHints, &sipCpp, &a0))
        {
            sipCpp->setShowShortcutsInContextMenus(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_setShowShortcutsInContextMenus, doc_QStyleHints_setShowShortcutsInContextMenus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_mouseDoubleClickDistance, "mouseDoubleClickDistance(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_mouseDoubleClickDistance(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_mouseDoubleClickDistance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->mouseDoubleClickDistance();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_mouseDoubleClickDistance, doc_QStyleHints_mouseDoubleClickDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_touchDoubleTapDistance, "touchDoubleTapDistance(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_touchDoubleTapDistance(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_touchDoubleTapDistance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->touchDoubleTapDistance();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_touchDoubleTapDistance, doc_QStyleHints_touchDoubleTapDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_keyboardAutoRepeatRateF, "keyboardAutoRepeatRateF(self) -> float");

extern "C" {static PyObject *meth_QStyleHints_keyboardAutoRepeatRateF(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_keyboardAutoRepeatRateF(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->keyboardAutoRepeatRateF();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_keyboardAutoRepeatRateF, doc_QStyleHints_keyboardAutoRepeatRateF);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_colorScheme, "colorScheme(self) -> Qt.ColorScheme");

extern "C" {static PyObject *meth_QStyleHints_colorScheme(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_colorScheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            ::Qt::ColorScheme sipRes;

            sipRes = sipCpp->colorScheme();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_ColorScheme);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_colorScheme, doc_QStyleHints_colorScheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_contextMenuTrigger, "contextMenuTrigger(self) -> Qt.ContextMenuTrigger");

extern "C" {static PyObject *meth_QStyleHints_contextMenuTrigger(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_contextMenuTrigger(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            ::Qt::ContextMenuTrigger sipRes;

            sipRes = sipCpp->contextMenuTrigger();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_ContextMenuTrigger);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_contextMenuTrigger, doc_QStyleHints_contextMenuTrigger);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_setContextMenuTrigger, "setContextMenuTrigger(self, contextMenuTrigger: Qt.ContextMenuTrigger)");

extern "C" {static PyObject *meth_QStyleHints_setContextMenuTrigger(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_setContextMenuTrigger(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::ContextMenuTrigger a0;
        ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QStyleHints, &sipCpp, sipType_Qt_ContextMenuTrigger, &a0))
        {
            sipCpp->setContextMenuTrigger(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_setContextMenuTrigger, doc_QStyleHints_setContextMenuTrigger);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_setColorScheme, "setColorScheme(self, scheme: Qt.ColorScheme)");

extern "C" {static PyObject *meth_QStyleHints_setColorScheme(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_setColorScheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::ColorScheme a0;
        ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QStyleHints, &sipCpp, sipType_Qt_ColorScheme, &a0))
        {
            sipCpp->setColorScheme(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_setColorScheme, doc_QStyleHints_setColorScheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_unsetColorScheme, "unsetColorScheme(self)");

extern "C" {static PyObject *meth_QStyleHints_unsetColorScheme(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_unsetColorScheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            sipCpp->unsetColorScheme();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_unsetColorScheme, doc_QStyleHints_unsetColorScheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_menuSelectionWraps, "menuSelectionWraps(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_menuSelectionWraps(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_menuSelectionWraps(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->menuSelectionWraps();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_menuSelectionWraps, doc_QStyleHints_menuSelectionWraps);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_accessibility, "accessibility(self) -> QAccessibilityHints|None");

extern "C" {static PyObject *meth_QStyleHints_accessibility(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_accessibility(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            const ::QAccessibilityHints*sipRes;

            sipRes = sipCpp->accessibility();

            return sipConvertFromType(const_cast< ::QAccessibilityHints *>(sipRes), sipType_QAccessibilityHints, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_accessibility, doc_QStyleHints_accessibility);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QStyleHints(void *, const sipTypeDef *);}
static void *cast_QStyleHints(void *sipCppV, const sipTypeDef *targetType)
{
    ::QStyleHints *sipCpp = reinterpret_cast< ::QStyleHints *>(sipCppV);

    if (targetType == sipType_QStyleHints)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QStyleHints(void *, int);}
static void release_QStyleHints(void *sipCppV, int)
{
    ::QStyleHints *sipCpp = reinterpret_cast< ::QStyleHints *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QStyleHints(sipSimpleWrapper *);}
static void dealloc_QStyleHints(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QStyleHints(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QStyleHints[] = {{53, 0, 1}};


static PyMethodDef methods_QStyleHints[] = {
    {sipName_accessibility, meth_QStyleHints_accessibility, METH_VARARGS, doc_QStyleHints_accessibility},
    {sipName_colorScheme, meth_QStyleHints_colorScheme, METH_VARARGS, doc_QStyleHints_colorScheme},
    {sipName_contextMenuTrigger, meth_QStyleHints_contextMenuTrigger, METH_VARARGS, doc_QStyleHints_contextMenuTrigger},
    {sipName_cursorFlashTime, meth_QStyleHints_cursorFlashTime, METH_VARARGS, doc_QStyleHints_cursorFlashTime},
    {sipName_fontSmoothingGamma, meth_QStyleHints_fontSmoothingGamma, METH_VARARGS, doc_QStyleHints_fontSmoothingGamma},
    {sipName_keyboardAutoRepeatRate, meth_QStyleHints_keyboardAutoRepeatRate, METH_VARARGS, doc_QStyleHints_keyboardAutoRepeatRate},
    {sipName_keyboardAutoRepeatRateF, meth_QStyleHints_keyboardAutoRepeatRateF, METH_VARARGS, doc_QStyleHints_keyboardAutoRepeatRateF},
    {sipName_keyboardInputInterval, meth_QStyleHints_keyboardInputInterval, METH_VARARGS, doc_QStyleHints_keyboardInputInterval},
    {sipName_menuSelectionWraps, meth_QStyleHints_menuSelectionWraps, METH_VARARGS, doc_QStyleHints_menuSelectionWraps},
    {sipName_mouseDoubleClickDistance, meth_QStyleHints_mouseDoubleClickDistance, METH_VARARGS, doc_QStyleHints_mouseDoubleClickDistance},
    {sipName_mouseDoubleClickInterval, meth_QStyleHints_mouseDoubleClickInterval, METH_VARARGS, doc_QStyleHints_mouseDoubleClickInterval},
    {sipName_mousePressAndHoldInterval, meth_QStyleHints_mousePressAndHoldInterval, METH_VARARGS, doc_QStyleHints_mousePressAndHoldInterval},
    {sipName_mouseQuickSelectionThreshold, meth_QStyleHints_mouseQuickSelectionThreshold, METH_VARARGS, doc_QStyleHints_mouseQuickSelectionThreshold},
    {sipName_passwordMaskCharacter, meth_QStyleHints_passwordMaskCharacter, METH_VARARGS, doc_QStyleHints_passwordMaskCharacter},
    {sipName_passwordMaskDelay, meth_QStyleHints_passwordMaskDelay, METH_VARARGS, doc_QStyleHints_passwordMaskDelay},
    {sipName_setColorScheme, meth_QStyleHints_setColorScheme, METH_VARARGS, doc_QStyleHints_setColorScheme},
    {sipName_setContextMenuTrigger, meth_QStyleHints_setContextMenuTrigger, METH_VARARGS, doc_QStyleHints_setContextMenuTrigger},
    {sipName_setFocusOnTouchRelease, meth_QStyleHints_setFocusOnTouchRelease, METH_VARARGS, doc_QStyleHints_setFocusOnTouchRelease},
    {sipName_setShowShortcutsInContextMenus, meth_QStyleHints_setShowShortcutsInContextMenus, METH_VARARGS, doc_QStyleHints_setShowShortcutsInContextMenus},
    {sipName_setUseHoverEffects, meth_QStyleHints_setUseHoverEffects, METH_VARARGS, doc_QStyleHints_setUseHoverEffects},
    {sipName_showIsFullScreen, meth_QStyleHints_showIsFullScreen, METH_VARARGS, doc_QStyleHints_showIsFullScreen},
    {sipName_showIsMaximized, meth_QStyleHints_showIsMaximized, METH_VARARGS, doc_QStyleHints_showIsMaximized},
    {sipName_showShortcutsInContextMenus, meth_QStyleHints_showShortcutsInContextMenus, METH_VARARGS, doc_QStyleHints_showShortcutsInContextMenus},
    {sipName_singleClickActivation, meth_QStyleHints_singleClickActivation, METH_VARARGS, doc_QStyleHints_singleClickActivation},
    {sipName_startDragDistance, meth_QStyleHints_startDragDistance, METH_VARARGS, doc_QStyleHints_startDragDistance},
    {sipName_startDragTime, meth_QStyleHints_startDragTime, METH_VARARGS, doc_QStyleHints_startDragTime},
    {sipName_startDragVelocity, meth_QStyleHints_startDragVelocity, METH_VARARGS, doc_QStyleHints_startDragVelocity},
    {sipName_tabFocusBehavior, meth_QStyleHints_tabFocusBehavior, METH_VARARGS, doc_QStyleHints_tabFocusBehavior},
    {sipName_touchDoubleTapDistance, meth_QStyleHints_touchDoubleTapDistance, METH_VARARGS, doc_QStyleHints_touchDoubleTapDistance},
    {sipName_unsetColorScheme, meth_QStyleHints_unsetColorScheme, METH_VARARGS, doc_QStyleHints_unsetColorScheme},
    {sipName_useHoverEffects, meth_QStyleHints_useHoverEffects, METH_VARARGS, doc_QStyleHints_useHoverEffects},
    {sipName_useRtlExtensions, meth_QStyleHints_useRtlExtensions, METH_VARARGS, doc_QStyleHints_useRtlExtensions},
    {sipName_wheelScrollLines, meth_QStyleHints_wheelScrollLines, METH_VARARGS, doc_QStyleHints_wheelScrollLines}
};


/* Define this type's signals. */
static const pyqt6QtSignal signals_QStyleHints[] = {
    {"contextMenuTriggerChanged(Qt::ContextMenuTrigger)", "\1contextMenuTriggerChanged(self, contextMenuTrigger: Qt.ContextMenuTrigger)", SIP_NULLPTR, SIP_NULLPTR},
    {"colorSchemeChanged(Qt::ColorScheme)", "\1colorSchemeChanged(self, colorScheme: Qt.ColorScheme)", SIP_NULLPTR, SIP_NULLPTR},
    {"showShortcutsInContextMenusChanged(bool)", "\1showShortcutsInContextMenusChanged(self, a0: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"mouseQuickSelectionThresholdChanged(int)", "\1mouseQuickSelectionThresholdChanged(self, threshold: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"wheelScrollLinesChanged(int)", "\1wheelScrollLinesChanged(self, scrollLines: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"useHoverEffectsChanged(bool)", "\1useHoverEffectsChanged(self, useHoverEffects: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"tabFocusBehaviorChanged(Qt::TabFocusBehavior)", "\1tabFocusBehaviorChanged(self, tabFocusBehavior: Qt.TabFocusBehavior)", SIP_NULLPTR, SIP_NULLPTR},
    {"mousePressAndHoldIntervalChanged(int)", "\1mousePressAndHoldIntervalChanged(self, mousePressAndHoldInterval: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"startDragTimeChanged(int)", "\1startDragTimeChanged(self, startDragTime: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"startDragDistanceChanged(int)", "\1startDragDistanceChanged(self, startDragDistance: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"mouseDoubleClickIntervalChanged(int)", "\1mouseDoubleClickIntervalChanged(self, mouseDoubleClickInterval: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"keyboardInputIntervalChanged(int)", "\1keyboardInputIntervalChanged(self, keyboardInputInterval: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"cursorFlashTimeChanged(int)", "\1cursorFlashTimeChanged(self, cursorFlashTime: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QStyleHints = {
    &::QStyleHints::staticMetaObject,
    signals_QStyleHints,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QStyleHints = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStyleHints,
        SIP_NULLPTR,
        &plugin_QStyleHints,
    },
    {
        sipNameNr_QStyleHints,
        {0, 0, 1},
        33, methods_QStyleHints,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QStyleHints,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QStyleHints,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QStyleHints,
    cast_QStyleHints,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
