/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qimagecapture.sip"
#include <qimagecapture.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qvideoframe.sip"
#include <qvideoframe.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qimage.sip"
#include <qimage.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediametadata.sip"
#include <qmediametadata.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qpymultimedia_qlist.sip"
#include <qaudioformat.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediacapturesession.sip"
#include <qmediacapturesession.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQImageCapture.cpp"


class sipQImageCapture : public ::QImageCapture
{
public:
    sipQImageCapture(::QObject*);
    virtual ~sipQImageCapture();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQImageCapture(const sipQImageCapture &);
    sipQImageCapture &operator = (const sipQImageCapture &);

    char sipPyMethods[7];
};

sipQImageCapture::sipQImageCapture(::QObject*a0): ::QImageCapture(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQImageCapture::~sipQImageCapture()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQImageCapture::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QImageCapture);

    return ::QImageCapture::metaObject();
}

int sipQImageCapture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QImageCapture::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QImageCapture, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQImageCapture::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QImageCapture, _clname, &sipCpp) ? sipCpp : ::QImageCapture::qt_metacast(_clname));
}

bool sipQImageCapture::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QImageCapture::event(a0);

    extern bool sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQImageCapture::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QImageCapture::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_4(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQImageCapture::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QImageCapture::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_3(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQImageCapture::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QImageCapture::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQImageCapture::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QImageCapture::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_1(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQImageCapture::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QImageCapture::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQImageCapture::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QImageCapture::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QImageCapture_isAvailable, "isAvailable(self) -> bool");

extern "C" {static PyObject *meth_QImageCapture_isAvailable(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_isAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QImageCapture, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_isAvailable, doc_QImageCapture_isAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_captureSession, "captureSession(self) -> QMediaCaptureSession|None");

extern "C" {static PyObject *meth_QImageCapture_captureSession(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_captureSession(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QImageCapture, &sipCpp))
        {
            ::QMediaCaptureSession*sipRes;

            sipRes = sipCpp->captureSession();

            return sipConvertFromType(sipRes, sipType_QMediaCaptureSession, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_captureSession, doc_QImageCapture_captureSession);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_error, "error(self) -> QImageCapture.Error");

extern "C" {static PyObject *meth_QImageCapture_error(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QImageCapture, &sipCpp))
        {
            ::QImageCapture::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QImageCapture_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_error, doc_QImageCapture_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QImageCapture_errorString(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QImageCapture, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_errorString, doc_QImageCapture_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_isReadyForCapture, "isReadyForCapture(self) -> bool");

extern "C" {static PyObject *meth_QImageCapture_isReadyForCapture(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_isReadyForCapture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QImageCapture, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isReadyForCapture();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_isReadyForCapture, doc_QImageCapture_isReadyForCapture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_fileFormat, "fileFormat(self) -> QImageCapture.FileFormat");

extern "C" {static PyObject *meth_QImageCapture_fileFormat(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_fileFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QImageCapture, &sipCpp))
        {
            ::QImageCapture::FileFormat sipRes;

            sipRes = sipCpp->fileFormat();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QImageCapture_FileFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_fileFormat, doc_QImageCapture_fileFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_setFileFormat, "setFileFormat(self, format: QImageCapture.FileFormat)");

extern "C" {static PyObject *meth_QImageCapture_setFileFormat(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_setFileFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QImageCapture::FileFormat a0;
        ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QImageCapture, &sipCpp, sipType_QImageCapture_FileFormat, &a0))
        {
            sipCpp->setFileFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_setFileFormat, doc_QImageCapture_setFileFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_supportedFormats, "supportedFormats() -> list[QImageCapture.FileFormat]");

extern "C" {static PyObject *meth_QImageCapture_supportedFormats(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_supportedFormats(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QList< ::QImageCapture::FileFormat>*sipRes;

            sipRes = new ::QList< ::QImageCapture::FileFormat>(::QImageCapture::supportedFormats());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QImageCapture_FileFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_supportedFormats, doc_QImageCapture_supportedFormats);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_fileFormatName, "fileFormatName(c: QImageCapture.FileFormat) -> str");

extern "C" {static PyObject *meth_QImageCapture_fileFormatName(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_fileFormatName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QImageCapture::FileFormat a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QImageCapture_FileFormat, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QImageCapture::fileFormatName(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_fileFormatName, doc_QImageCapture_fileFormatName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_fileFormatDescription, "fileFormatDescription(c: QImageCapture.FileFormat) -> str");

extern "C" {static PyObject *meth_QImageCapture_fileFormatDescription(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_fileFormatDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QImageCapture::FileFormat a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QImageCapture_FileFormat, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QImageCapture::fileFormatDescription(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_fileFormatDescription, doc_QImageCapture_fileFormatDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_resolution, "resolution(self) -> QSize");

extern "C" {static PyObject *meth_QImageCapture_resolution(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_resolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QImageCapture, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->resolution());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_resolution, doc_QImageCapture_resolution);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_setResolution, "setResolution(self, a0: QSize)\n"
"setResolution(self, width: int, height: int)");

extern "C" {static PyObject *meth_QImageCapture_setResolution(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_setResolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QImageCapture, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setResolution(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        int a1;
        ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QImageCapture, &sipCpp, &a0, &a1))
        {
            sipCpp->setResolution(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_setResolution, doc_QImageCapture_setResolution);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_quality, "quality(self) -> QImageCapture.Quality");

extern "C" {static PyObject *meth_QImageCapture_quality(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_quality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QImageCapture, &sipCpp))
        {
            ::QImageCapture::Quality sipRes;

            sipRes = sipCpp->quality();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QImageCapture_Quality);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_quality, doc_QImageCapture_quality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_setQuality, "setQuality(self, quality: QImageCapture.Quality)");

extern "C" {static PyObject *meth_QImageCapture_setQuality(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_setQuality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QImageCapture::Quality a0;
        ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QImageCapture, &sipCpp, sipType_QImageCapture_Quality, &a0))
        {
            sipCpp->setQuality(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_setQuality, doc_QImageCapture_setQuality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_metaData, "metaData(self) -> QMediaMetaData");

extern "C" {static PyObject *meth_QImageCapture_metaData(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_metaData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QImageCapture, &sipCpp))
        {
            ::QMediaMetaData*sipRes;

            sipRes = new ::QMediaMetaData(sipCpp->metaData());

            return sipConvertFromNewType(sipRes, sipType_QMediaMetaData, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_metaData, doc_QImageCapture_metaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_setMetaData, "setMetaData(self, metaData: QMediaMetaData)");

extern "C" {static PyObject *meth_QImageCapture_setMetaData(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_setMetaData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaMetaData* a0;
        ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QImageCapture, &sipCpp, sipType_QMediaMetaData, &a0))
        {
            sipCpp->setMetaData(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_setMetaData, doc_QImageCapture_setMetaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_addMetaData, "addMetaData(self, metaData: QMediaMetaData)");

extern "C" {static PyObject *meth_QImageCapture_addMetaData(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_addMetaData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaMetaData* a0;
        ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QImageCapture, &sipCpp, sipType_QMediaMetaData, &a0))
        {
            sipCpp->addMetaData(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_addMetaData, doc_QImageCapture_addMetaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_captureToFile, "captureToFile(self, location: str|None = '') -> int");

extern "C" {static PyObject *meth_QImageCapture_captureToFile(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_captureToFile(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;
        ::QImageCapture *sipCpp;

        static const char *sipKwdList[] = {
            sipName_location,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QImageCapture, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->captureToFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_captureToFile, doc_QImageCapture_captureToFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QImageCapture_capture, "capture(self) -> int");

extern "C" {static PyObject *meth_QImageCapture_capture(PyObject *, PyObject *);}
static PyObject *meth_QImageCapture_capture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QImageCapture, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->capture();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QImageCapture, sipName_capture, doc_QImageCapture_capture);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QImageCapture(void *, const sipTypeDef *);}
static void *cast_QImageCapture(void *sipCppV, const sipTypeDef *targetType)
{
    ::QImageCapture *sipCpp = reinterpret_cast< ::QImageCapture *>(sipCppV);

    if (targetType == sipType_QImageCapture)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QImageCapture(void *, int);}
static void release_QImageCapture(void *sipCppV, int)
{
    ::QImageCapture *sipCpp = reinterpret_cast< ::QImageCapture *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QImageCapture(Py_ssize_t);}
static void *array_QImageCapture(Py_ssize_t sipNrElem)
{
    return new ::QImageCapture[sipNrElem];
}


extern "C" {static void array_delete_QImageCapture(void *);}
static void array_delete_QImageCapture(void *sipCpp)
{
    delete[] reinterpret_cast< ::QImageCapture *>(sipCpp);
}


extern "C" {static void dealloc_QImageCapture(sipSimpleWrapper *);}
static void dealloc_QImageCapture(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQImageCapture *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QImageCapture(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QImageCapture(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QImageCapture(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQImageCapture *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQImageCapture(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QImageCapture[] = {{7, 0, 1}};


static PyMethodDef methods_QImageCapture[] = {
    {sipName_addMetaData, meth_QImageCapture_addMetaData, METH_VARARGS, doc_QImageCapture_addMetaData},
    {sipName_capture, meth_QImageCapture_capture, METH_VARARGS, doc_QImageCapture_capture},
    {sipName_captureSession, meth_QImageCapture_captureSession, METH_VARARGS, doc_QImageCapture_captureSession},
    {sipName_captureToFile, SIP_MLMETH_CAST(meth_QImageCapture_captureToFile), METH_VARARGS|METH_KEYWORDS, doc_QImageCapture_captureToFile},
    {sipName_error, meth_QImageCapture_error, METH_VARARGS, doc_QImageCapture_error},
    {sipName_errorString, meth_QImageCapture_errorString, METH_VARARGS, doc_QImageCapture_errorString},
    {sipName_fileFormat, meth_QImageCapture_fileFormat, METH_VARARGS, doc_QImageCapture_fileFormat},
    {sipName_fileFormatDescription, meth_QImageCapture_fileFormatDescription, METH_VARARGS, doc_QImageCapture_fileFormatDescription},
    {sipName_fileFormatName, meth_QImageCapture_fileFormatName, METH_VARARGS, doc_QImageCapture_fileFormatName},
    {sipName_isAvailable, meth_QImageCapture_isAvailable, METH_VARARGS, doc_QImageCapture_isAvailable},
    {sipName_isReadyForCapture, meth_QImageCapture_isReadyForCapture, METH_VARARGS, doc_QImageCapture_isReadyForCapture},
    {sipName_metaData, meth_QImageCapture_metaData, METH_VARARGS, doc_QImageCapture_metaData},
    {sipName_quality, meth_QImageCapture_quality, METH_VARARGS, doc_QImageCapture_quality},
    {sipName_resolution, meth_QImageCapture_resolution, METH_VARARGS, doc_QImageCapture_resolution},
    {sipName_setFileFormat, meth_QImageCapture_setFileFormat, METH_VARARGS, doc_QImageCapture_setFileFormat},
    {sipName_setMetaData, meth_QImageCapture_setMetaData, METH_VARARGS, doc_QImageCapture_setMetaData},
    {sipName_setQuality, meth_QImageCapture_setQuality, METH_VARARGS, doc_QImageCapture_setQuality},
    {sipName_setResolution, meth_QImageCapture_setResolution, METH_VARARGS, doc_QImageCapture_setResolution},
    {sipName_supportedFormats, meth_QImageCapture_supportedFormats, METH_VARARGS, doc_QImageCapture_supportedFormats}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QImageCapture[] = {
    {sipName_NoError, static_cast<int>(::QImageCapture::NoError)},
    {sipName_NotReadyError, static_cast<int>(::QImageCapture::NotReadyError)},
    {sipName_ResourceError, static_cast<int>(::QImageCapture::ResourceError)},
    {sipName_OutOfSpaceError, static_cast<int>(::QImageCapture::OutOfSpaceError)},
    {sipName_NotSupportedFeatureError, static_cast<int>(::QImageCapture::NotSupportedFeatureError)},
    {sipName_FormatError, static_cast<int>(::QImageCapture::FormatError)},
    {sipName_UnspecifiedFormat, static_cast<int>(::QImageCapture::UnspecifiedFormat)},
    {sipName_JPEG, static_cast<int>(::QImageCapture::JPEG)},
    {sipName_PNG, static_cast<int>(::QImageCapture::PNG)},
    {sipName_WebP, static_cast<int>(::QImageCapture::WebP)},
    {sipName_Tiff, static_cast<int>(::QImageCapture::Tiff)},
    {sipName_VeryLowQuality, static_cast<int>(::QImageCapture::VeryLowQuality)},
    {sipName_LowQuality, static_cast<int>(::QImageCapture::LowQuality)},
    {sipName_NormalQuality, static_cast<int>(::QImageCapture::NormalQuality)},
    {sipName_HighQuality, static_cast<int>(::QImageCapture::HighQuality)},
    {sipName_VeryHighQuality, static_cast<int>(::QImageCapture::VeryHighQuality)},
    {0, 0}
};

PyDoc_STRVAR(doc_QImageCapture, "\1QImageCapture(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QImageCapture[] = {
    {"imageSaved(int,QString)", "\1imageSaved(self, id: int, fileName: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"imageAvailable(int,QVideoFrame)", "\1imageAvailable(self, id: int, frame: QVideoFrame)", SIP_NULLPTR, SIP_NULLPTR},
    {"imageCaptured(int,QImage)", "\1imageCaptured(self, id: int, preview: QImage)", SIP_NULLPTR, SIP_NULLPTR},
    {"imageExposed(int)", "\1imageExposed(self, id: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"resolutionChanged()", "\1resolutionChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"qualityChanged()", "\1qualityChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"fileFormatChanged()", "\1fileFormatChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"metaDataChanged()", "\1metaDataChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"readyForCaptureChanged(bool)", "\1readyForCaptureChanged(self, ready: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorOccurred(int,QImageCapture::Error,QString)", "\1errorOccurred(self, id: int, error: QImageCapture.Error, errorString: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorChanged()", "\1errorChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QImageCapture = {
    &::QImageCapture::staticMetaObject,
    signals_QImageCapture,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QImageCapture = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QImageCapture,
        SIP_NULLPTR,
        &plugin_QImageCapture,
    },
    {
        sipNameNr_QImageCapture,
        {0, 0, 1},
        19, methods_QImageCapture,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QImageCapture, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QImageCapture,
    -1,
    -1,
    supers_QImageCapture,
    SIP_NULLPTR,
    init_type_QImageCapture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QImageCapture,
    SIP_NULLPTR,
    array_QImageCapture,
    SIP_NULLPTR,
    release_QImageCapture,
    cast_QImageCapture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QImageCapture,
    sizeof (::QImageCapture),
};
