/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtPrintSupportAPI_H
#define _QtPrintSupportAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtPrintSupport[0]
#define sipNameNr_QAbstractPrintDialog__PrintDialogOption 48
#define sipName_QAbstractPrintDialog__PrintDialogOption &sipStrings_QtPrintSupport[48]
#define sipNameNr_QPrintEngine__PrintEnginePropertyKey 88
#define sipName_QPrintEngine__PrintEnginePropertyKey &sipStrings_QtPrintSupport[88]
#define sipNameNr_QAbstractPrintDialog__PrintRange 125
#define sipName_QAbstractPrintDialog__PrintRange &sipStrings_QtPrintSupport[125]
#define sipNameNr_QPrintPreviewWidget__ViewMode 158
#define sipName_QPrintPreviewWidget__ViewMode &sipStrings_QtPrintSupport[158]
#define sipNameNr_QPrintPreviewWidget__ZoomMode 188
#define sipName_QPrintPreviewWidget__ZoomMode &sipStrings_QtPrintSupport[188]
#define sipNameNr_218 218
#define sipName_218 &sipStrings_QtPrintSupport[218]
#define sipNameNr_PPK_SupportsMultipleCopies 246
#define sipName_PPK_SupportsMultipleCopies &sipStrings_QtPrintSupport[246]
#define sipNameNr_273 273
#define sipName_273 &sipStrings_QtPrintSupport[273]
#define sipNameNr_setPrinterSelectionOption 300
#define sipName_setPrinterSelectionOption &sipStrings_QtPrintSupport[300]
#define sipNameNr_PPK_SupportedResolutions 326
#define sipName_PPK_SupportedResolutions &sipStrings_QtPrintSupport[326]
#define sipNameNr_PyQt6_sip_simplewrapper 351
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtPrintSupport[351]
#define sipNameNr_maximumPhysicalPageSize 375
#define sipName_maximumPhysicalPageSize &sipStrings_QtPrintSupport[375]
#define sipNameNr_minimumPhysicalPageSize 399
#define sipName_minimumPhysicalPageSize &sipStrings_QtPrintSupport[399]
#define sipNameNr_setFontEmbeddingEnabled 423
#define sipName_setFontEmbeddingEnabled &sipStrings_QtPrintSupport[423]
#define sipNameNr_setLandscapeOrientation 447
#define sipName_setLandscapeOrientation &sipStrings_QtPrintSupport[447]
#define sipNameNr_supportsCustomPageSizes 471
#define sipName_supportsCustomPageSizes &sipStrings_QtPrintSupport[471]
#define sipNameNr_PrintEnginePropertyKey 102
#define sipName_PrintEnginePropertyKey &sipStrings_QtPrintSupport[102]
#define sipNameNr_QPrinter__OutputFormat 495
#define sipName_QPrinter__OutputFormat &sipStrings_QtPrintSupport[495]
#define sipNameNr_QPrinter__PrinterState 518
#define sipName_QPrinter__PrinterState &sipStrings_QtPrintSupport[518]
#define sipNameNr_printerSelectionOption 541
#define sipName_printerSelectionOption &sipStrings_QtPrintSupport[541]
#define sipNameNr_setFacingPagesViewMode 564
#define sipName_setFacingPagesViewMode &sipStrings_QtPrintSupport[564]
#define sipNameNr_setPortraitOrientation 587
#define sipName_setPortraitOrientation &sipStrings_QtPrintSupport[587]
#define sipNameNr_supportsMultipleCopies 610
#define sipName_supportsMultipleCopies &sipStrings_QtPrintSupport[610]
#define sipNameNr_QPrinter__PaperSource 633
#define sipName_QPrinter__PaperSource &sipStrings_QtPrintSupport[633]
#define sipNameNr_QPrinter__PrinterMode 655
#define sipName_QPrinter__PrinterMode &sipStrings_QtPrintSupport[655]
#define sipNameNr_availablePrinterNames 677
#define sipName_availablePrinterNames &sipStrings_QtPrintSupport[677]
#define sipNameNr_mouseDoubleClickEvent 699
#define sipName_mouseDoubleClickEvent &sipStrings_QtPrintSupport[699]
#define sipNameNr_setSinglePageViewMode 721
#define sipName_setSinglePageViewMode &sipStrings_QtPrintSupport[721]
#define sipNameNr_PyQt6_QtPrintSupport 743
#define sipName_PyQt6_QtPrintSupport &sipStrings_QtPrintSupport[743]
#define sipNameNr_QAbstractPrintDialog 764
#define sipName_QAbstractPrintDialog &sipStrings_QtPrintSupport[764]
#define sipNameNr_QPrinter__DuplexMode 785
#define sipName_QPrinter__DuplexMode &sipStrings_QtPrintSupport[785]
#define sipNameNr_QPrinter__PrintRange 806
#define sipName_QPrinter__PrintRange &sipStrings_QtPrintSupport[806]
#define sipNameNr_fontEmbeddingEnabled 827
#define sipName_fontEmbeddingEnabled &sipStrings_QtPrintSupport[827]
#define sipNameNr_supportedDuplexModes 848
#define sipName_supportedDuplexModes &sipStrings_QtPrintSupport[848]
#define sipNameNr_supportedResolutions 869
#define sipName_supportedResolutions &sipStrings_QtPrintSupport[869]
#define sipNameNr_PPK_CustomPaperSize 890
#define sipName_PPK_CustomPaperSize &sipStrings_QtPrintSupport[890]
#define sipNameNr_PPK_SelectionOption 910
#define sipName_PPK_SelectionOption &sipStrings_QtPrintSupport[910]
#define sipNameNr_PPK_WindowsPageSize 930
#define sipName_PPK_WindowsPageSize &sipStrings_QtPrintSupport[930]
#define sipNameNr_950 950
#define sipName_950 &sipStrings_QtPrintSupport[950]
#define sipNameNr_QPrintPreviewDialog 970
#define sipName_QPrintPreviewDialog &sipStrings_QtPrintSupport[970]
#define sipNameNr_QPrintPreviewWidget 990
#define sipName_QPrintPreviewWidget &sipStrings_QtPrintSupport[990]
#define sipNameNr_QPrinter__ColorMode 1010
#define sipName_QPrinter__ColorMode &sipStrings_QtPrintSupport[1010]
#define sipNameNr_QPrinter__PageOrder 1030
#define sipName_QPrinter__PageOrder &sipStrings_QtPrintSupport[1030]
#define sipNameNr_setAllPagesViewMode 1050
#define sipName_setAllPagesViewMode &sipStrings_QtPrintSupport[1050]
#define sipNameNr_supportedColorModes 1070
#define sipName_supportedColorModes &sipStrings_QtPrintSupport[1070]
#define sipNameNr_PPK_NumberOfCopies 1090
#define sipName_PPK_NumberOfCopies &sipStrings_QtPrintSupport[1090]
#define sipNameNr_PPK_OutputFileName 1109
#define sipName_PPK_OutputFileName &sipStrings_QtPrintSupport[1109]
#define sipNameNr_PPK_PrinterProgram 1128
#define sipName_PPK_PrinterProgram &sipStrings_QtPrintSupport[1128]
#define sipNameNr_PrintCollateCopies 1147
#define sipName_PrintCollateCopies &sipStrings_QtPrintSupport[1147]
#define sipNameNr_defaultPrinterName 1166
#define sipName_defaultPrinterName &sipStrings_QtPrintSupport[1166]
#define sipNameNr_focusNextPrevChild 1185
#define sipName_focusNextPrevChild &sipStrings_QtPrintSupport[1185]
#define sipNameNr_setPageOrientation 1204
#define sipName_setPageOrientation &sipStrings_QtPrintSupport[1204]
#define sipNameNr_supportedPageSizes 1223
#define sipName_supportedPageSizes &sipStrings_QtPrintSupport[1223]
#define sipNameNr_PPK_CollateCopies 1242
#define sipName_PPK_CollateCopies &sipStrings_QtPrintSupport[1242]
#define sipNameNr_PPK_FontEmbedding 1260
#define sipName_PPK_FontEmbedding &sipStrings_QtPrintSupport[1260]
#define sipNameNr_PrintDialogOption 70
#define sipName_PrintDialogOption &sipStrings_QtPrintSupport[70]
#define sipNameNr_PrintShowPageSize 1278
#define sipName_PrintShowPageSize &sipStrings_QtPrintSupport[1278]
#define sipNameNr_PrinterResolution 1296
#define sipName_PrinterResolution &sipStrings_QtPrintSupport[1296]
#define sipNameNr_availablePrinters 1314
#define sipName_availablePrinters &sipStrings_QtPrintSupport[1314]
#define sipNameNr_defaultDuplexMode 1332
#define sipName_defaultDuplexMode &sipStrings_QtPrintSupport[1332]
#define sipNameNr_hasHeightForWidth 1350
#define sipName_hasHeightForWidth &sipStrings_QtPrintSupport[1350]
#define sipNameNr_mouseReleaseEvent 1368
#define sipName_mouseReleaseEvent &sipStrings_QtPrintSupport[1368]
#define sipNameNr_setOutputFileName 1386
#define sipName_setOutputFileName &sipStrings_QtPrintSupport[1386]
#define sipNameNr_PPK_DocumentName 1404
#define sipName_PPK_DocumentName &sipStrings_QtPrintSupport[1404]
#define sipNameNr_PPK_PaperSources 1421
#define sipName_PPK_PaperSources &sipStrings_QtPrintSupport[1421]
#define sipNameNr_PPK_QPageMargins 1438
#define sipName_PPK_QPageMargins &sipStrings_QtPrintSupport[1438]
#define sipNameNr_PrintCurrentPage 1455
#define sipName_PrintCurrentPage &sipStrings_QtPrintSupport[1455]
#define sipNameNr_1472 1472
#define sipName_1472 &sipStrings_QtPrintSupport[1472]
#define sipNameNr_QPageSetupDialog 1489
#define sipName_QPageSetupDialog &sipStrings_QtPrintSupport[1489]
#define sipNameNr_ScreenResolution 1506
#define sipName_ScreenResolution &sipStrings_QtPrintSupport[1506]
#define sipNameNr_contextMenuEvent 1523
#define sipName_contextMenuEvent &sipStrings_QtPrintSupport[1523]
#define sipNameNr_defaultColorMode 1540
#define sipName_defaultColorMode &sipStrings_QtPrintSupport[1540]
#define sipNameNr_disconnectNotify 1557
#define sipName_disconnectNotify &sipStrings_QtPrintSupport[1557]
#define sipNameNr_inputMethodEvent 1574
#define sipName_inputMethodEvent &sipStrings_QtPrintSupport[1574]
#define sipNameNr_inputMethodQuery 1591
#define sipName_inputMethodQuery &sipStrings_QtPrintSupport[1591]
#define sipNameNr_setCollateCopies 1608
#define sipName_setCollateCopies &sipStrings_QtPrintSupport[1608]
#define sipNameNr_DuplexShortSide 1625
#define sipName_DuplexShortSide &sipStrings_QtPrintSupport[1625]
#define sipNameNr_FacingPagesView 1641
#define sipName_FacingPagesView &sipStrings_QtPrintSupport[1641]
#define sipNameNr_LastPaperSource 1657
#define sipName_LastPaperSource &sipStrings_QtPrintSupport[1657]
#define sipNameNr_PPK_Orientation 1673
#define sipName_PPK_Orientation &sipStrings_QtPrintSupport[1673]
#define sipNameNr_PPK_PageMargins 1689
#define sipName_PPK_PageMargins &sipStrings_QtPrintSupport[1689]
#define sipNameNr_PPK_PaperSource 1705
#define sipName_PPK_PaperSource &sipStrings_QtPrintSupport[1705]
#define sipNameNr_PPK_PrinterName 1721
#define sipName_PPK_PrinterName &sipStrings_QtPrintSupport[1721]
#define sipNameNr_PPK_QPageLayout 1737
#define sipName_PPK_QPageLayout &sipStrings_QtPrintSupport[1737]
#define sipNameNr_defaultPageSize 1753
#define sipName_defaultPageSize &sipStrings_QtPrintSupport[1753]
#define sipNameNr_keyReleaseEvent 1769
#define sipName_keyReleaseEvent &sipStrings_QtPrintSupport[1769]
#define sipNameNr_minimumSizeHint 1785
#define sipName_minimumSizeHint &sipStrings_QtPrintSupport[1785]
#define sipNameNr_mousePressEvent 1801
#define sipName_mousePressEvent &sipStrings_QtPrintSupport[1801]
#define sipNameNr_setOutputFormat 1817
#define sipName_setOutputFormat &sipStrings_QtPrintSupport[1817]
#define sipNameNr_setPrintProgram 1833
#define sipName_setPrintProgram &sipStrings_QtPrintSupport[1833]
#define sipNameNr_DuplexLongSide 1849
#define sipName_DuplexLongSide &sipStrings_QtPrintSupport[1849]
#define sipNameNr_EnvelopeManual 1864
#define sipName_EnvelopeManual &sipStrings_QtPrintSupport[1864]
#define sipNameNr_FirstPageFirst 1879
#define sipName_FirstPageFirst &sipStrings_QtPrintSupport[1879]
#define sipNameNr_HighResolution 1894
#define sipName_HighResolution &sipStrings_QtPrintSupport[1894]
#define sipNameNr_PPK_CustomBase 1909
#define sipName_PPK_CustomBase &sipStrings_QtPrintSupport[1909]
#define sipNameNr_PPK_Resolution 1924
#define sipName_PPK_Resolution &sipStrings_QtPrintSupport[1924]
#define sipNameNr_PrintPageRange 1939
#define sipName_PrintPageRange &sipStrings_QtPrintSupport[1939]
#define sipNameNr_PrintSelection 1954
#define sipName_PrintSelection &sipStrings_QtPrintSupport[1954]
#define sipNameNr_QPrinter__Unit 1969
#define sipName_QPrinter__Unit &sipStrings_QtPrintSupport[1969]
#define sipNameNr_SinglePageView 1984
#define sipName_SinglePageView &sipStrings_QtPrintSupport[1984]
#define sipNameNr_defaultPrinter 1999
#define sipName_defaultPrinter &sipStrings_QtPrintSupport[1999]
#define sipNameNr_dragEnterEvent 2014
#define sipName_dragEnterEvent &sipStrings_QtPrintSupport[2014]
#define sipNameNr_dragLeaveEvent 2029
#define sipName_dragLeaveEvent &sipStrings_QtPrintSupport[2029]
#define sipNameNr_heightForWidth 2044
#define sipName_heightForWidth &sipStrings_QtPrintSupport[2044]
#define sipNameNr_mouseMoveEvent 2059
#define sipName_mouseMoveEvent &sipStrings_QtPrintSupport[2059]
#define sipNameNr_outputFileName 2074
#define sipName_outputFileName &sipStrings_QtPrintSupport[2074]
#define sipNameNr_paintRequested 2089
#define sipName_paintRequested &sipStrings_QtPrintSupport[2089]
#define sipNameNr_previewChanged 2104
#define sipName_previewChanged &sipStrings_QtPrintSupport[2104]
#define sipNameNr_setCurrentPage 2119
#define sipName_setCurrentPage &sipStrings_QtPrintSupport[2119]
#define sipNameNr_setOrientation 2134
#define sipName_setOrientation &sipStrings_QtPrintSupport[2134]
#define sipNameNr_setPageMargins 2149
#define sipName_setPageMargins &sipStrings_QtPrintSupport[2149]
#define sipNameNr_setPaperSource 2164
#define sipName_setPaperSource &sipStrings_QtPrintSupport[2164]
#define sipNameNr_setPrinterName 2179
#define sipName_setPrinterName &sipStrings_QtPrintSupport[2179]
#define sipNameNr_LargeCapacity 2194
#define sipName_LargeCapacity &sipStrings_QtPrintSupport[2194]
#define sipNameNr_LastPageFirst 2208
#define sipName_LastPageFirst &sipStrings_QtPrintSupport[2208]
#define sipNameNr_MaxPageSource 2222
#define sipName_MaxPageSource &sipStrings_QtPrintSupport[2222]
#define sipNameNr_PPK_ColorMode 2236
#define sipName_PPK_ColorMode &sipStrings_QtPrintSupport[2236]
#define sipNameNr_PPK_CopyCount 2250
#define sipName_PPK_CopyCount &sipStrings_QtPrintSupport[2250]
#define sipNameNr_PPK_PageOrder 2264
#define sipName_PPK_PageOrder &sipStrings_QtPrintSupport[2264]
#define sipNameNr_PPK_PaperName 2278
#define sipName_PPK_PaperName &sipStrings_QtPrintSupport[2278]
#define sipNameNr_PPK_PaperRect 2292
#define sipName_PPK_PaperRect &sipStrings_QtPrintSupport[2292]
#define sipNameNr_PPK_PaperSize 2306
#define sipName_PPK_PaperSize &sipStrings_QtPrintSupport[2306]
#define sipNameNr_PPK_QPageSize 2320
#define sipName_PPK_QPageSize &sipStrings_QtPrintSupport[2320]
#define sipNameNr_collateCopies 2334
#define sipName_collateCopies &sipStrings_QtPrintSupport[2334]
#define sipNameNr_connectNotify 1560
#define sipName_connectNotify &sipStrings_QtPrintSupport[1560]
#define sipNameNr_dragMoveEvent 2348
#define sipName_dragMoveEvent &sipStrings_QtPrintSupport[2348]
#define sipNameNr_focusOutEvent 2362
#define sipName_focusOutEvent &sipStrings_QtPrintSupport[2362]
#define sipNameNr_keyPressEvent 2376
#define sipName_keyPressEvent &sipStrings_QtPrintSupport[2376]
#define sipNameNr_setOptionTabs 2390
#define sipName_setOptionTabs &sipStrings_QtPrintSupport[2390]
#define sipNameNr_setPageLayout 2404
#define sipName_setPageLayout &sipStrings_QtPrintSupport[2404]
#define sipNameNr_setPageRanges 2418
#define sipName_setPageRanges &sipStrings_QtPrintSupport[2418]
#define sipNameNr_setPdfVersion 2432
#define sipName_setPdfVersion &sipStrings_QtPrintSupport[2432]
#define sipNameNr_setPrintRange 2446
#define sipName_setPrintRange &sipStrings_QtPrintSupport[2446]
#define sipNameNr_setResolution 2460
#define sipName_setResolution &sipStrings_QtPrintSupport[2460]
#define sipNameNr_setZoomFactor 2474
#define sipName_setZoomFactor &sipStrings_QtPrintSupport[2474]
#define sipNameNr_sharedPainter 2488
#define sipName_sharedPainter &sipStrings_QtPrintSupport[2488]
#define sipNameNr_updatePreview 2502
#define sipName_updatePreview &sipStrings_QtPrintSupport[2502]
#define sipNameNr_AllPagesView 2516
#define sipName_AllPagesView &sipStrings_QtPrintSupport[2516]
#define sipNameNr_CustomSource 2529
#define sipName_CustomSource &sipStrings_QtPrintSupport[2529]
#define sipNameNr_NativeFormat 2542
#define sipName_NativeFormat &sipStrings_QtPrintSupport[2542]
#define sipNameNr_OutputFormat 505
#define sipName_OutputFormat &sipStrings_QtPrintSupport[505]
#define sipNameNr_PPK_FullPage 2555
#define sipName_PPK_FullPage &sipStrings_QtPrintSupport[2555]
#define sipNameNr_PPK_PageRect 2568
#define sipName_PPK_PageRect &sipStrings_QtPrintSupport[2568]
#define sipNameNr_PPK_PageSize 2581
#define sipName_PPK_PageSize &sipStrings_QtPrintSupport[2581]
#define sipNameNr_PrinterState 528
#define sipName_PrinterState &sipStrings_QtPrintSupport[528]
#define sipNameNr_QPrintDialog 2594
#define sipName_QPrintDialog &sipStrings_QtPrintSupport[2594]
#define sipNameNr_QPrintEngine 2607
#define sipName_QPrintEngine &sipStrings_QtPrintSupport[2607]
#define sipNameNr_QPrinterInfo 2620
#define sipName_QPrinterInfo &sipStrings_QtPrintSupport[2620]
#define sipNameNr_focusInEvent 2633
#define sipName_focusInEvent &sipStrings_QtPrintSupport[2633]
#define sipNameNr_makeAndModel 2646
#define sipName_makeAndModel &sipStrings_QtPrintSupport[2646]
#define sipNameNr_outputFormat 2659
#define sipName_outputFormat &sipStrings_QtPrintSupport[2659]
#define sipNameNr_printProgram 2672
#define sipName_printProgram &sipStrings_QtPrintSupport[2672]
#define sipNameNr_printerState 2685
#define sipName_printerState &sipStrings_QtPrintSupport[2685]
#define sipNameNr_setColorMode 2698
#define sipName_setColorMode &sipStrings_QtPrintSupport[2698]
#define sipNameNr_setCopyCount 2711
#define sipName_setCopyCount &sipStrings_QtPrintSupport[2711]
#define sipNameNr_setPageOrder 2724
#define sipName_setPageOrder &sipStrings_QtPrintSupport[2724]
#define sipNameNr_CurrentPage 1460
#define sipName_CurrentPage &sipStrings_QtPrintSupport[1460]
#define sipNameNr_DevicePixel 2737
#define sipName_DevicePixel &sipStrings_QtPrintSupport[2737]
#define sipNameNr_LargeFormat 2749
#define sipName_LargeFormat &sipStrings_QtPrintSupport[2749]
#define sipNameNr_PPK_Creator 2761
#define sipName_PPK_Creator &sipStrings_QtPrintSupport[2761]
#define sipNameNr_PaperSource 643
#define sipName_PaperSource &sipStrings_QtPrintSupport[643]
#define sipNameNr_PrintToFile 2773
#define sipName_PrintToFile &sipStrings_QtPrintSupport[2773]
#define sipNameNr_PrinterMode 665
#define sipName_PrinterMode &sipStrings_QtPrintSupport[665]
#define sipNameNr_SmallFormat 2785
#define sipName_SmallFormat &sipStrings_QtPrintSupport[2785]
#define sipNameNr_actionEvent 2797
#define sipName_actionEvent &sipStrings_QtPrintSupport[2797]
#define sipNameNr_changeEvent 2809
#define sipName_changeEvent &sipStrings_QtPrintSupport[2809]
#define sipNameNr_currentPage 2821
#define sipName_currentPage &sipStrings_QtPrintSupport[2821]
#define sipNameNr_customEvent 2833
#define sipName_customEvent &sipStrings_QtPrintSupport[2833]
#define sipNameNr_description 2845
#define sipName_description &sipStrings_QtPrintSupport[2845]
#define sipNameNr_eventFilter 2857
#define sipName_eventFilter &sipStrings_QtPrintSupport[2857]
#define sipNameNr_initPainter 2869
#define sipName_initPainter &sipStrings_QtPrintSupport[2869]
#define sipNameNr_nativeEvent 2881
#define sipName_nativeEvent &sipStrings_QtPrintSupport[2881]
#define sipNameNr_orientation 2893
#define sipName_orientation &sipStrings_QtPrintSupport[2893]
#define sipNameNr_paintEngine 2905
#define sipName_paintEngine &sipStrings_QtPrintSupport[2905]
#define sipNameNr_paperSource 2917
#define sipName_paperSource &sipStrings_QtPrintSupport[2917]
#define sipNameNr_printEngine 2929
#define sipName_printEngine &sipStrings_QtPrintSupport[2929]
#define sipNameNr_printerInfo 2941
#define sipName_printerInfo &sipStrings_QtPrintSupport[2941]
#define sipNameNr_printerName 2953
#define sipName_printerName &sipStrings_QtPrintSupport[2953]
#define sipNameNr_resizeEvent 2965
#define sipName_resizeEvent &sipStrings_QtPrintSupport[2965]
#define sipNameNr_setFullPage 2977
#define sipName_setFullPage &sipStrings_QtPrintSupport[2977]
#define sipNameNr_setPageSize 2989
#define sipName_setPageSize &sipStrings_QtPrintSupport[2989]
#define sipNameNr_setProperty 3001
#define sipName_setProperty &sipStrings_QtPrintSupport[3001]
#define sipNameNr_setViewMode 3013
#define sipName_setViewMode &sipStrings_QtPrintSupport[3013]
#define sipNameNr_setZoomMode 3025
#define sipName_setZoomMode &sipStrings_QtPrintSupport[3025]
#define sipNameNr_tabletEvent 3037
#define sipName_tabletEvent &sipStrings_QtPrintSupport[3037]
#define sipNameNr_CustomZoom 3049
#define sipName_CustomZoom &sipStrings_QtPrintSupport[3049]
#define sipNameNr_DuplexAuto 3060
#define sipName_DuplexAuto &sipStrings_QtPrintSupport[3060]
#define sipNameNr_DuplexMode 795
#define sipName_DuplexMode &sipStrings_QtPrintSupport[795]
#define sipNameNr_DuplexNone 3071
#define sipName_DuplexNone &sipStrings_QtPrintSupport[3071]
#define sipNameNr_FitToWidth 3082
#define sipName_FitToWidth &sipStrings_QtPrintSupport[3082]
#define sipNameNr_FormSource 3093
#define sipName_FormSource &sipStrings_QtPrintSupport[3093]
#define sipNameNr_Millimeter 3104
#define sipName_Millimeter &sipStrings_QtPrintSupport[3104]
#define sipNameNr_PPK_Duplex 3115
#define sipName_PPK_Duplex &sipStrings_QtPrintSupport[3115]
#define sipNameNr_PrintRange 147
#define sipName_PrintRange &sipStrings_QtPrintSupport[147]
#define sipNameNr_childEvent 3126
#define sipName_childEvent &sipStrings_QtPrintSupport[3126]
#define sipNameNr_closeEvent 3137
#define sipName_closeEvent &sipStrings_QtPrintSupport[3137]
#define sipNameNr_enterEvent 3148
#define sipName_enterEvent &sipStrings_QtPrintSupport[3148]
#define sipNameNr_fitToWidth 3159
#define sipName_fitToWidth &sipStrings_QtPrintSupport[3159]
#define sipNameNr_leaveEvent 3170
#define sipName_leaveEvent &sipStrings_QtPrintSupport[3170]
#define sipNameNr_paintEvent 3181
#define sipName_paintEvent &sipStrings_QtPrintSupport[3181]
#define sipNameNr_pdfVersion 3192
#define sipName_pdfVersion &sipStrings_QtPrintSupport[3192]
#define sipNameNr_printRange 3203
#define sipName_printRange &sipStrings_QtPrintSupport[3203]
#define sipNameNr_resolution 3214
#define sipName_resolution &sipStrings_QtPrintSupport[3214]
#define sipNameNr_setCreator 3225
#define sipName_setCreator &sipStrings_QtPrintSupport[3225]
#define sipNameNr_setDocName 3236
#define sipName_setDocName &sipStrings_QtPrintSupport[3236]
#define sipNameNr_setEngines 3247
#define sipName_setEngines &sipStrings_QtPrintSupport[3247]
#define sipNameNr_setOptions 3258
#define sipName_setOptions &sipStrings_QtPrintSupport[3258]
#define sipNameNr_setVisible 3269
#define sipName_setVisible &sipStrings_QtPrintSupport[3269]
#define sipNameNr_testOption 3280
#define sipName_testOption &sipStrings_QtPrintSupport[3280]
#define sipNameNr_timerEvent 3291
#define sipName_timerEvent &sipStrings_QtPrintSupport[3291]
#define sipNameNr_wheelEvent 3302
#define sipName_wheelEvent &sipStrings_QtPrintSupport[3302]
#define sipNameNr_zoomFactor 3313
#define sipName_zoomFactor &sipStrings_QtPrintSupport[3313]
#define sipNameNr_ColorMode 1020
#define sipName_ColorMode &sipStrings_QtPrintSupport[1020]
#define sipNameNr_FitInView 3324
#define sipName_FitInView &sipStrings_QtPrintSupport[3324]
#define sipNameNr_GrayScale 3334
#define sipName_GrayScale &sipStrings_QtPrintSupport[3334]
#define sipNameNr_PageOrder 1040
#define sipName_PageOrder &sipStrings_QtPrintSupport[1040]
#define sipNameNr_PageRange 1944
#define sipName_PageRange &sipStrings_QtPrintSupport[1944]
#define sipNameNr_PdfFormat 3344
#define sipName_PdfFormat &sipStrings_QtPrintSupport[3344]
#define sipNameNr_Selection 1959
#define sipName_Selection &sipStrings_QtPrintSupport[1959]
#define sipNameNr_colorMode 3354
#define sipName_colorMode &sipStrings_QtPrintSupport[3354]
#define sipNameNr_copyCount 3364
#define sipName_copyCount &sipStrings_QtPrintSupport[3364]
#define sipNameNr_dropEvent 3374
#define sipName_dropEvent &sipStrings_QtPrintSupport[3374]
#define sipNameNr_fitInView 3384
#define sipName_fitInView &sipStrings_QtPrintSupport[3384]
#define sipNameNr_hideEvent 3394
#define sipName_hideEvent &sipStrings_QtPrintSupport[3394]
#define sipNameNr_isDefault 3404
#define sipName_isDefault &sipStrings_QtPrintSupport[3404]
#define sipNameNr_moveEvent 3414
#define sipName_moveEvent &sipStrings_QtPrintSupport[3414]
#define sipNameNr_pageCount 3424
#define sipName_pageCount &sipStrings_QtPrintSupport[3424]
#define sipNameNr_pageOrder 3434
#define sipName_pageOrder &sipStrings_QtPrintSupport[3434]
#define sipNameNr_paperRect 3444
#define sipName_paperRect &sipStrings_QtPrintSupport[3444]
#define sipNameNr_setDuplex 3454
#define sipName_setDuplex &sipStrings_QtPrintSupport[3454]
#define sipNameNr_setFromTo 3464
#define sipName_setFromTo &sipStrings_QtPrintSupport[3464]
#define sipNameNr_setMinMax 3474
#define sipName_setMinMax &sipStrings_QtPrintSupport[3474]
#define sipNameNr_setOption 3484
#define sipName_setOption &sipStrings_QtPrintSupport[3484]
#define sipNameNr_showEvent 3494
#define sipName_showEvent &sipStrings_QtPrintSupport[3494]
#define sipNameNr_AllPages 3504
#define sipName_AllPages &sipStrings_QtPrintSupport[3504]
#define sipNameNr_Cassette 3513
#define sipName_Cassette &sipStrings_QtPrintSupport[3513]
#define sipNameNr_Envelope 3522
#define sipName_Envelope &sipStrings_QtPrintSupport[3522]
#define sipNameNr_QPrinter 3531
#define sipName_QPrinter &sipStrings_QtPrintSupport[3531]
#define sipNameNr_ViewMode 179
#define sipName_ViewMode &sipStrings_QtPrintSupport[179]
#define sipNameNr_ZoomMode 209
#define sipName_ZoomMode &sipStrings_QtPrintSupport[209]
#define sipNameNr_accepted 3540
#define sipName_accepted &sipStrings_QtPrintSupport[3540]
#define sipNameNr_fromPage 3549
#define sipName_fromPage &sipStrings_QtPrintSupport[3549]
#define sipNameNr_fullPage 3558
#define sipName_fullPage &sipStrings_QtPrintSupport[3558]
#define sipNameNr_isRemote 3567
#define sipName_isRemote &sipStrings_QtPrintSupport[3567]
#define sipNameNr_location 3576
#define sipName_location &sipStrings_QtPrintSupport[3576]
#define sipNameNr_pageRect 3585
#define sipName_pageRect &sipStrings_QtPrintSupport[3585]
#define sipNameNr_property 3594
#define sipName_property &sipStrings_QtPrintSupport[3594]
#define sipNameNr_sizeHint 3603
#define sipName_sizeHint &sipStrings_QtPrintSupport[3603]
#define sipNameNr_viewMode 3612
#define sipName_viewMode &sipStrings_QtPrintSupport[3612]
#define sipNameNr_zoomMode 3621
#define sipName_zoomMode &sipStrings_QtPrintSupport[3621]
#define sipNameNr_Aborted 3630
#define sipName_Aborted &sipStrings_QtPrintSupport[3630]
#define sipNameNr_OnlyOne 3638
#define sipName_OnlyOne &sipStrings_QtPrintSupport[3638]
#define sipNameNr_Tractor 3646
#define sipName_Tractor &sipStrings_QtPrintSupport[3646]
#define sipNameNr_creator 3654
#define sipName_creator &sipStrings_QtPrintSupport[3654]
#define sipNameNr_devType 3662
#define sipName_devType &sipStrings_QtPrintSupport[3662]
#define sipNameNr_docName 3670
#define sipName_docName &sipStrings_QtPrintSupport[3670]
#define sipNameNr_isValid 3678
#define sipName_isValid &sipStrings_QtPrintSupport[3678]
#define sipNameNr_maxPage 3686
#define sipName_maxPage &sipStrings_QtPrintSupport[3686]
#define sipNameNr_minPage 3694
#define sipName_minPage &sipStrings_QtPrintSupport[3694]
#define sipNameNr_newPage 3702
#define sipName_newPage &sipStrings_QtPrintSupport[3702]
#define sipNameNr_options 3710
#define sipName_options &sipStrings_QtPrintSupport[3710]
#define sipNameNr_printer 3718
#define sipName_printer &sipStrings_QtPrintSupport[3718]
#define sipNameNr_zoomOut 3726
#define sipName_zoomOut &sipStrings_QtPrintSupport[3726]
#define sipNameNr_Active 3734
#define sipName_Active &sipStrings_QtPrintSupport[3734]
#define sipNameNr_Cicero 3741
#define sipName_Cicero &sipStrings_QtPrintSupport[3741]
#define sipNameNr_Manual 1872
#define sipName_Manual &sipStrings_QtPrintSupport[1872]
#define sipNameNr_Middle 3748
#define sipName_Middle &sipStrings_QtPrintSupport[3748]
#define sipNameNr_accept 3755
#define sipName_accept &sipStrings_QtPrintSupport[3755]
#define sipNameNr_duplex 3762
#define sipName_duplex &sipStrings_QtPrintSupport[3762]
#define sipNameNr_factor 3769
#define sipName_factor &sipStrings_QtPrintSupport[3769]
#define sipNameNr_isNull 3776
#define sipName_isNull &sipStrings_QtPrintSupport[3776]
#define sipNameNr_metric 3783
#define sipName_metric &sipStrings_QtPrintSupport[3783]
#define sipNameNr_parent 3790
#define sipName_parent &sipStrings_QtPrintSupport[3790]
#define sipNameNr_reject 3797
#define sipName_reject &sipStrings_QtPrintSupport[3797]
#define sipNameNr_toPage 3804
#define sipName_toPage &sipStrings_QtPrintSupport[3804]
#define sipNameNr_zoomIn 3811
#define sipName_zoomIn &sipStrings_QtPrintSupport[3811]
#define sipNameNr_Color 3818
#define sipName_Color &sipStrings_QtPrintSupport[3818]
#define sipNameNr_Didot 3824
#define sipName_Didot &sipStrings_QtPrintSupport[3824]
#define sipNameNr_Error 3830
#define sipName_Error &sipStrings_QtPrintSupport[3830]
#define sipNameNr_Lower 3836
#define sipName_Lower &sipStrings_QtPrintSupport[3836]
#define sipNameNr_Point 3842
#define sipName_Point &sipStrings_QtPrintSupport[3842]
#define sipNameNr_Upper 3848
#define sipName_Upper &sipStrings_QtPrintSupport[3848]
#define sipNameNr_abort 3854
#define sipName_abort &sipStrings_QtPrintSupport[3854]
#define sipNameNr_event 3860
#define sipName_event &sipStrings_QtPrintSupport[3860]
#define sipNameNr_flags 3866
#define sipName_flags &sipStrings_QtPrintSupport[3866]
#define sipNameNr_print 3872
#define sipName_print &sipStrings_QtPrintSupport[3872]
#define sipNameNr_state 3878
#define sipName_state &sipStrings_QtPrintSupport[3878]
#define sipNameNr_Auto 3066
#define sipName_Auto &sipStrings_QtPrintSupport[3066]
#define sipNameNr_Idle 3884
#define sipName_Idle &sipStrings_QtPrintSupport[3884]
#define sipNameNr_Inch 3889
#define sipName_Inch &sipStrings_QtPrintSupport[3889]
#define sipNameNr_Pica 3894
#define sipName_Pica &sipStrings_QtPrintSupport[3894]
#define sipNameNr_Unit 1979
#define sipName_Unit &sipStrings_QtPrintSupport[1979]
#define sipNameNr_done 3899
#define sipName_done &sipStrings_QtPrintSupport[3899]
#define sipNameNr_exec 3904
#define sipName_exec &sipStrings_QtPrintSupport[3904]
#define sipNameNr_mode 3909
#define sipName_mode &sipStrings_QtPrintSupport[3909]
#define sipNameNr_open 3914
#define sipName_open &sipStrings_QtPrintSupport[3914]
#define sipNameNr_on 85
#define sipName_on &sipStrings_QtPrintSupport[85]

#define sipMalloc                   sipAPI_QtPrintSupport->api_malloc
#define sipFree                     sipAPI_QtPrintSupport->api_free
#define sipBuildResult              sipAPI_QtPrintSupport->api_build_result
#define sipCallMethod               sipAPI_QtPrintSupport->api_call_method
#define sipCallProcedureMethod      sipAPI_QtPrintSupport->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtPrintSupport->api_call_error_handler
#define sipParseResultEx            sipAPI_QtPrintSupport->api_parse_result_ex
#define sipParseResult              sipAPI_QtPrintSupport->api_parse_result
#define sipParseArgs                sipAPI_QtPrintSupport->api_parse_args
#define sipParseKwdArgs             sipAPI_QtPrintSupport->api_parse_kwd_args
#define sipParsePair                sipAPI_QtPrintSupport->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtPrintSupport->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtPrintSupport->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtPrintSupport->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtPrintSupport->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtPrintSupport->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtPrintSupport->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtPrintSupport->api_add_exception
#define sipNoFunction               sipAPI_QtPrintSupport->api_no_function
#define sipNoMethod                 sipAPI_QtPrintSupport->api_no_method
#define sipAbstractMethod           sipAPI_QtPrintSupport->api_abstract_method
#define sipBadClass                 sipAPI_QtPrintSupport->api_bad_class
#define sipBadCatcherResult         sipAPI_QtPrintSupport->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtPrintSupport->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtPrintSupport->api_bad_operator_arg
#define sipTrace                    sipAPI_QtPrintSupport->api_trace
#define sipTransferBack             sipAPI_QtPrintSupport->api_transfer_back
#define sipTransferTo               sipAPI_QtPrintSupport->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtPrintSupport->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtPrintSupport->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtPrintSupport->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtPrintSupport->api_voidptr_type
#define sipGetPyObject              sipAPI_QtPrintSupport->api_get_pyobject
#define sipGetAddress               sipAPI_QtPrintSupport->api_get_address
#define sipGetMixinAddress          sipAPI_QtPrintSupport->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtPrintSupport->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtPrintSupport->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtPrintSupport->api_call_hook
#define sipEndThread                sipAPI_QtPrintSupport->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtPrintSupport->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtPrintSupport->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtPrintSupport->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtPrintSupport->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtPrintSupport->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtPrintSupport->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtPrintSupport->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtPrintSupport->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtPrintSupport->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtPrintSupport->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtPrintSupport->api_convert_to_bool
#define sipReleaseType              sipAPI_QtPrintSupport->api_release_type
#define sipConvertFromType          sipAPI_QtPrintSupport->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtPrintSupport->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtPrintSupport->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtPrintSupport->api_convert_from_enum
#define sipGetState                 sipAPI_QtPrintSupport->api_get_state
#define sipExportSymbol             sipAPI_QtPrintSupport->api_export_symbol
#define sipImportSymbol             sipAPI_QtPrintSupport->api_import_symbol
#define sipFindType                 sipAPI_QtPrintSupport->api_find_type
#define sipBytes_AsChar             sipAPI_QtPrintSupport->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtPrintSupport->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtPrintSupport->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtPrintSupport->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtPrintSupport->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtPrintSupport->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtPrintSupport->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtPrintSupport->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtPrintSupport->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtPrintSupport->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtPrintSupport->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtPrintSupport->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtPrintSupport->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtPrintSupport->api_get_reference
#define sipKeepReference            sipAPI_QtPrintSupport->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtPrintSupport->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtPrintSupport->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtPrintSupport->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtPrintSupport->api_type_scope
#define sipResolveTypedef           sipAPI_QtPrintSupport->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtPrintSupport->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtPrintSupport->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtPrintSupport->api_init_mixin
#define sipExportModule             sipAPI_QtPrintSupport->api_export_module
#define sipInitModule               sipAPI_QtPrintSupport->api_init_module
#define sipGetInterpreter           sipAPI_QtPrintSupport->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtPrintSupport->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtPrintSupport->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtPrintSupport->api_py_type_dict
#define sipPyTypeName               sipAPI_QtPrintSupport->api_py_type_name
#define sipGetCFunction             sipAPI_QtPrintSupport->api_get_c_function
#define sipGetMethod                sipAPI_QtPrintSupport->api_get_method
#define sipFromMethod               sipAPI_QtPrintSupport->api_from_method
#define sipGetDate                  sipAPI_QtPrintSupport->api_get_date
#define sipFromDate                 sipAPI_QtPrintSupport->api_from_date
#define sipGetDateTime              sipAPI_QtPrintSupport->api_get_datetime
#define sipFromDateTime             sipAPI_QtPrintSupport->api_from_datetime
#define sipGetTime                  sipAPI_QtPrintSupport->api_get_time
#define sipFromTime                 sipAPI_QtPrintSupport->api_from_time
#define sipIsUserType               sipAPI_QtPrintSupport->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtPrintSupport->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtPrintSupport->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtPrintSupport->api_unicode_write
#define sipUnicodeData              sipAPI_QtPrintSupport->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtPrintSupport->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtPrintSupport->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtPrintSupport->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtPrintSupport->api_is_derived_class
#define sipGetUserObject            sipAPI_QtPrintSupport->api_get_user_object
#define sipSetUserObject            sipAPI_QtPrintSupport->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtPrintSupport->api_register_event_handler
#define sipConvertToArray           sipAPI_QtPrintSupport->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtPrintSupport->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtPrintSupport->api_enable_gc
#define sipPrintObject              sipAPI_QtPrintSupport->api_print_object
#define sipLong_AsChar              sipAPI_QtPrintSupport->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtPrintSupport->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtPrintSupport->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtPrintSupport->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtPrintSupport->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtPrintSupport->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtPrintSupport->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtPrintSupport->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtPrintSupport->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtPrintSupport->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtPrintSupport->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtPrintSupport->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtPrintSupport->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtPrintSupport->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtPrintSupport->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtPrintSupport->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtPrintSupport->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtPrintSupport->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtPrintSupport->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtPrintSupport->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtPrintSupport->api_release_type_us
#define sipIsPyMethod               sipAPI_QtPrintSupport->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtPrintSupport[];

#define sipType_QAbstractPrintDialog sipExportedTypes_QtPrintSupport[0]

#define sipType_QAbstractPrintDialog_PrintDialogOption sipExportedTypes_QtPrintSupport[1]

#define sipType_QAbstractPrintDialog_PrintRange sipExportedTypes_QtPrintSupport[2]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QAbstractPrintDialog;

#define sipType_QPageSetupDialog sipExportedTypes_QtPrintSupport[8]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPageSetupDialog;

#define sipType_QPrintDialog sipExportedTypes_QtPrintSupport[9]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrintDialog;

#define sipType_QPrintEngine sipExportedTypes_QtPrintSupport[10]

#define sipType_QPrintEngine_PrintEnginePropertyKey sipExportedTypes_QtPrintSupport[11]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrintEngine;

#define sipType_QPrinter sipExportedTypes_QtPrintSupport[16]

#define sipType_QPrinter_DuplexMode sipExportedTypes_QtPrintSupport[18]

#define sipType_QPrinter_Unit sipExportedTypes_QtPrintSupport[25]

#define sipType_QPrinter_PrintRange sipExportedTypes_QtPrintSupport[22]

#define sipType_QPrinter_OutputFormat sipExportedTypes_QtPrintSupport[19]

#define sipType_QPrinter_PrinterState sipExportedTypes_QtPrintSupport[24]

#define sipType_QPrinter_PaperSource sipExportedTypes_QtPrintSupport[21]

#define sipType_QPrinter_ColorMode sipExportedTypes_QtPrintSupport[17]

#define sipType_QPrinter_PageOrder sipExportedTypes_QtPrintSupport[20]

#define sipType_QPrinter_PrinterMode sipExportedTypes_QtPrintSupport[23]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrinter;

#define sipType_QPrinterInfo sipExportedTypes_QtPrintSupport[26]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrinterInfo;

#define sipType_QPrintPreviewDialog sipExportedTypes_QtPrintSupport[12]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrintPreviewDialog;

#define sipType_QPrintPreviewWidget sipExportedTypes_QtPrintSupport[13]

#define sipType_QPrintPreviewWidget_ZoomMode sipExportedTypes_QtPrintSupport[15]

#define sipType_QPrintPreviewWidget_ViewMode sipExportedTypes_QtPrintSupport[14]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrintPreviewWidget;

#define sipType_QList_0100QPageSize sipExportedTypes_QtPrintSupport[4]

extern sipMappedTypeDef sipTypeDef_QtPrintSupport_QList_0100QPageSize;

#define sipType_QList_0100QPrinterInfo sipExportedTypes_QtPrintSupport[7]

extern sipMappedTypeDef sipTypeDef_QtPrintSupport_QList_0100QPrinterInfo;

#define sipType_QFlags_0100QAbstractPrintDialog_PrintDialogOption sipExportedTypes_QtPrintSupport[3]

extern sipMappedTypeDef sipTypeDef_QtPrintSupport_QFlags_0100QAbstractPrintDialog_PrintDialogOption;

#define sipType_QList_0100QPrinter_ColorMode sipExportedTypes_QtPrintSupport[5]

extern sipMappedTypeDef sipTypeDef_QtPrintSupport_QList_0100QPrinter_ColorMode;

#define sipType_QList_0100QPrinter_DuplexMode sipExportedTypes_QtPrintSupport[6]

extern sipMappedTypeDef sipTypeDef_QtPrintSupport_QList_0100QPrinter_DuplexMode;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtPrintSupport;
extern sipExportedModuleDef sipModuleAPI_QtPrintSupport;
extern sipTypeDef *sipExportedTypes_QtPrintSupport[];

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtPrintSupport_QtCore[14].it_td

#define sipType_QObject sipImportedTypes_QtPrintSupport_QtCore[7].it_td

#define sipType_QByteArray sipImportedTypes_QtPrintSupport_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtPrintSupport_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtPrintSupport_QtCore[12].it_td

#define sipType_QChildEvent sipImportedTypes_QtPrintSupport_QtCore[1].it_td

#define sipType_QMarginsF sipImportedTypes_QtPrintSupport_QtCore[5].it_td

#define sipType_QMetaMethod sipImportedTypes_QtPrintSupport_QtCore[6].it_td

#define sipType_QRectF sipImportedTypes_QtPrintSupport_QtCore[8].it_td

#define sipType_QSize sipImportedTypes_QtPrintSupport_QtCore[9].it_td

#define sipType_QVariant sipImportedTypes_QtPrintSupport_QtCore[13].it_td

#define sipType_QFlags_0100Qt_WindowType sipImportedTypes_QtPrintSupport_QtCore[3].it_td

#define sipType_QStringList sipImportedTypes_QtPrintSupport_QtCore[11].it_td

#define sipType_QList_1800 sipImportedTypes_QtPrintSupport_QtCore[4].it_td

#define sipType_QString sipImportedTypes_QtPrintSupport_QtCore[10].it_td

#define sipType_qintptr sipImportedTypes_QtPrintSupport_QtCore[15].it_td
extern sipImportedTypeDef sipImportedTypes_QtPrintSupport_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtPrintSupport_QtGui[21].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtPrintSupport_QtGui[22].it_td

#define sipType_QKeyEvent sipImportedTypes_QtPrintSupport_QtGui[11].it_td

#define sipType_QFocusEvent sipImportedTypes_QtPrintSupport_QtGui[8].it_td

#define sipType_QPaintEvent sipImportedTypes_QtPrintSupport_QtGui[24].it_td

#define sipType_QMoveEvent sipImportedTypes_QtPrintSupport_QtGui[13].it_td

#define sipType_QResizeEvent sipImportedTypes_QtPrintSupport_QtGui[26].it_td

#define sipType_QCloseEvent sipImportedTypes_QtPrintSupport_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtPrintSupport_QtGui[27].it_td

#define sipType_QHideEvent sipImportedTypes_QtPrintSupport_QtGui[9].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtPrintSupport_QtGui[2].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtPrintSupport_QtGui[10].it_td

#define sipType_QDropEvent sipImportedTypes_QtPrintSupport_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtPrintSupport_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtPrintSupport_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtPrintSupport_QtGui[4].it_td

#define sipType_QActionEvent sipImportedTypes_QtPrintSupport_QtGui[0].it_td

#define sipType_QEnterEvent sipImportedTypes_QtPrintSupport_QtGui[7].it_td

#define sipType_QMouseEvent sipImportedTypes_QtPrintSupport_QtGui[12].it_td

#define sipType_QWheelEvent sipImportedTypes_QtPrintSupport_QtGui[29].it_td

#define sipType_QTabletEvent sipImportedTypes_QtPrintSupport_QtGui[28].it_td

#define sipType_QPagedPaintDevice sipImportedTypes_QtPrintSupport_QtGui[19].it_td

#define sipType_QPagedPaintDevice_PdfVersion sipImportedTypes_QtPrintSupport_QtGui[20].it_td

#define sipType_QPageLayout sipImportedTypes_QtPrintSupport_QtGui[14].it_td

#define sipType_QPageLayout_Orientation sipImportedTypes_QtPrintSupport_QtGui[15].it_td

#define sipType_QPageLayout_Unit sipImportedTypes_QtPrintSupport_QtGui[16].it_td

#define sipType_QPageRanges sipImportedTypes_QtPrintSupport_QtGui[17].it_td

#define sipType_QPageSize sipImportedTypes_QtPrintSupport_QtGui[18].it_td

#define sipType_QPaintEngine sipImportedTypes_QtPrintSupport_QtGui[23].it_td

#define sipType_QPainter sipImportedTypes_QtPrintSupport_QtGui[25].it_td
extern sipImportedTypeDef sipImportedTypes_QtPrintSupport_QtGui[];

#define sipType_QWidget sipImportedTypes_QtPrintSupport_QtWidgets[2].it_td

#define sipType_QDialog sipImportedTypes_QtPrintSupport_QtWidgets[0].it_td

#define sipType_QList_0101QWidget sipImportedTypes_QtPrintSupport_QtWidgets[1].it_td
extern sipImportedTypeDef sipImportedTypes_QtPrintSupport_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtPrintSupport_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtPrintSupport_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtPrintSupport_qt_metacast;
#line 120 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPrintSupport/qabstractprintdialog.sip"
// Imports from QtCore.
typedef sipErrorState (*pyqt6_qtprintsupport_get_connection_parts_t)(PyObject *, QObject *, const char *, bool, QObject **, QByteArray &);
extern pyqt6_qtprintsupport_get_connection_parts_t pyqt6_qtprintsupport_get_connection_parts;
#line 999 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPrintSupport/sipAPIQtPrintSupport.h"

#endif
