/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qlowenergyservice.sip"
#include <qlowenergyservice.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qlowenergydescriptor.sip"
#include <qlowenergydescriptor.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qlowenergycharacteristic.sip"
#include <qlowenergycharacteristic.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothuuid.sip"
#include <qbluetoothuuid.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyService.cpp"


PyDoc_STRVAR(doc_QLowEnergyService_includedServices, "includedServices(self) -> list[QBluetoothUuid]");

extern "C" {static PyObject *meth_QLowEnergyService_includedServices(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_includedServices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyService, &sipCpp))
        {
            QList< ::QBluetoothUuid>*sipRes;

            sipRes = new QList< ::QBluetoothUuid>(sipCpp->includedServices());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QBluetoothUuid, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_includedServices, doc_QLowEnergyService_includedServices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_type, "type(self) -> QLowEnergyService.ServiceType");

extern "C" {static PyObject *meth_QLowEnergyService_type(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyService, &sipCpp))
        {
            ::QLowEnergyService::ServiceTypes*sipRes;

            sipRes = new ::QLowEnergyService::ServiceTypes(sipCpp->type());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QLowEnergyService_ServiceType, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_type, doc_QLowEnergyService_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_state, "state(self) -> QLowEnergyService.ServiceState");

extern "C" {static PyObject *meth_QLowEnergyService_state(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyService, &sipCpp))
        {
            ::QLowEnergyService::ServiceState sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLowEnergyService_ServiceState);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_state, doc_QLowEnergyService_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_characteristic, "characteristic(self, uuid: QBluetoothUuid) -> QLowEnergyCharacteristic");

extern "C" {static PyObject *meth_QLowEnergyService_characteristic(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_characteristic(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothUuid* a0;
        const ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLowEnergyService, &sipCpp, sipType_QBluetoothUuid, &a0))
        {
            ::QLowEnergyCharacteristic*sipRes;

            sipRes = new ::QLowEnergyCharacteristic(sipCpp->characteristic(*a0));

            return sipConvertFromNewType(sipRes, sipType_QLowEnergyCharacteristic, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_characteristic, doc_QLowEnergyService_characteristic);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_characteristics, "characteristics(self) -> list[QLowEnergyCharacteristic]");

extern "C" {static PyObject *meth_QLowEnergyService_characteristics(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_characteristics(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyService, &sipCpp))
        {
            QList< ::QLowEnergyCharacteristic>*sipRes;

            sipRes = new QList< ::QLowEnergyCharacteristic>(sipCpp->characteristics());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QLowEnergyCharacteristic, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_characteristics, doc_QLowEnergyService_characteristics);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_serviceUuid, "serviceUuid(self) -> QBluetoothUuid");

extern "C" {static PyObject *meth_QLowEnergyService_serviceUuid(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_serviceUuid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyService, &sipCpp))
        {
            ::QBluetoothUuid*sipRes;

            sipRes = new ::QBluetoothUuid(sipCpp->serviceUuid());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothUuid, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_serviceUuid, doc_QLowEnergyService_serviceUuid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_serviceName, "serviceName(self) -> str");

extern "C" {static PyObject *meth_QLowEnergyService_serviceName(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_serviceName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyService, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->serviceName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_serviceName, doc_QLowEnergyService_serviceName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_discoverDetails, "discoverDetails(self, mode: QLowEnergyService.DiscoveryMode = QLowEnergyService.FullDiscovery)");

extern "C" {static PyObject *meth_QLowEnergyService_discoverDetails(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_discoverDetails(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLowEnergyService::DiscoveryMode a0 = QLowEnergyService::FullDiscovery;
        ::QLowEnergyService *sipCpp;

        static const char *sipKwdList[] = {
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLowEnergyService, &sipCpp, sipType_QLowEnergyService_DiscoveryMode, &a0))
        {
            sipCpp->discoverDetails(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_discoverDetails, doc_QLowEnergyService_discoverDetails);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_error, "error(self) -> QLowEnergyService.ServiceError");

extern "C" {static PyObject *meth_QLowEnergyService_error(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyService, &sipCpp))
        {
            ::QLowEnergyService::ServiceError sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLowEnergyService_ServiceError);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_error, doc_QLowEnergyService_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_contains, "contains(self, characteristic: QLowEnergyCharacteristic) -> bool\n"
"contains(self, descriptor: QLowEnergyDescriptor) -> bool");

extern "C" {static PyObject *meth_QLowEnergyService_contains(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_contains(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic* a0;
        const ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLowEnergyService, &sipCpp, sipType_QLowEnergyCharacteristic, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->contains(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QLowEnergyDescriptor* a0;
        const ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLowEnergyService, &sipCpp, sipType_QLowEnergyDescriptor, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->contains(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_contains, doc_QLowEnergyService_contains);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_writeCharacteristic, "writeCharacteristic(self, characteristic: QLowEnergyCharacteristic, newValue: QByteArray|bytes|bytearray|memoryview, mode: QLowEnergyService.WriteMode = QLowEnergyService.WriteWithResponse)");

extern "C" {static PyObject *meth_QLowEnergyService_writeCharacteristic(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_writeCharacteristic(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic* a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QLowEnergyService::WriteMode a2 = QLowEnergyService::WriteWithResponse;
        ::QLowEnergyService *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9J1|E", &sipSelf, sipType_QLowEnergyService, &sipCpp, sipType_QLowEnergyCharacteristic, &a0, sipType_QByteArray, &a1, &a1State, sipType_QLowEnergyService_WriteMode, &a2))
        {
            sipCpp->writeCharacteristic(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_writeCharacteristic, doc_QLowEnergyService_writeCharacteristic);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_writeDescriptor, "writeDescriptor(self, descriptor: QLowEnergyDescriptor, newValue: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QLowEnergyService_writeDescriptor(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_writeDescriptor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptor* a0;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QLowEnergyService, &sipCpp, sipType_QLowEnergyDescriptor, &a0, sipType_QByteArray, &a1, &a1State))
        {
            sipCpp->writeDescriptor(*a0, *a1);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_writeDescriptor, doc_QLowEnergyService_writeDescriptor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_readCharacteristic, "readCharacteristic(self, characteristic: QLowEnergyCharacteristic)");

extern "C" {static PyObject *meth_QLowEnergyService_readCharacteristic(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_readCharacteristic(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic* a0;
        ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLowEnergyService, &sipCpp, sipType_QLowEnergyCharacteristic, &a0))
        {
            sipCpp->readCharacteristic(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_readCharacteristic, doc_QLowEnergyService_readCharacteristic);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyService_readDescriptor, "readDescriptor(self, descriptor: QLowEnergyDescriptor)");

extern "C" {static PyObject *meth_QLowEnergyService_readDescriptor(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyService_readDescriptor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptor* a0;
        ::QLowEnergyService *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLowEnergyService, &sipCpp, sipType_QLowEnergyDescriptor, &a0))
        {
            sipCpp->readDescriptor(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyService, sipName_readDescriptor, doc_QLowEnergyService_readDescriptor);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QLowEnergyService(void *, const sipTypeDef *);}
static void *cast_QLowEnergyService(void *sipCppV, const sipTypeDef *targetType)
{
    ::QLowEnergyService *sipCpp = reinterpret_cast< ::QLowEnergyService *>(sipCppV);

    if (targetType == sipType_QLowEnergyService)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QLowEnergyService(void *, int);}
static void release_QLowEnergyService(void *sipCppV, int)
{
    ::QLowEnergyService *sipCpp = reinterpret_cast< ::QLowEnergyService *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QLowEnergyService(sipSimpleWrapper *);}
static void dealloc_QLowEnergyService(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLowEnergyService(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QLowEnergyService[] = {{9, 0, 1}};


static PyMethodDef methods_QLowEnergyService[] = {
    {sipName_characteristic, meth_QLowEnergyService_characteristic, METH_VARARGS, doc_QLowEnergyService_characteristic},
    {sipName_characteristics, meth_QLowEnergyService_characteristics, METH_VARARGS, doc_QLowEnergyService_characteristics},
    {sipName_contains, meth_QLowEnergyService_contains, METH_VARARGS, doc_QLowEnergyService_contains},
    {sipName_discoverDetails, SIP_MLMETH_CAST(meth_QLowEnergyService_discoverDetails), METH_VARARGS|METH_KEYWORDS, doc_QLowEnergyService_discoverDetails},
    {sipName_error, meth_QLowEnergyService_error, METH_VARARGS, doc_QLowEnergyService_error},
    {sipName_includedServices, meth_QLowEnergyService_includedServices, METH_VARARGS, doc_QLowEnergyService_includedServices},
    {sipName_readCharacteristic, meth_QLowEnergyService_readCharacteristic, METH_VARARGS, doc_QLowEnergyService_readCharacteristic},
    {sipName_readDescriptor, meth_QLowEnergyService_readDescriptor, METH_VARARGS, doc_QLowEnergyService_readDescriptor},
    {sipName_serviceName, meth_QLowEnergyService_serviceName, METH_VARARGS, doc_QLowEnergyService_serviceName},
    {sipName_serviceUuid, meth_QLowEnergyService_serviceUuid, METH_VARARGS, doc_QLowEnergyService_serviceUuid},
    {sipName_state, meth_QLowEnergyService_state, METH_VARARGS, doc_QLowEnergyService_state},
    {sipName_type, meth_QLowEnergyService_type, METH_VARARGS, doc_QLowEnergyService_type},
    {sipName_writeCharacteristic, SIP_MLMETH_CAST(meth_QLowEnergyService_writeCharacteristic), METH_VARARGS|METH_KEYWORDS, doc_QLowEnergyService_writeCharacteristic},
    {sipName_writeDescriptor, meth_QLowEnergyService_writeDescriptor, METH_VARARGS, doc_QLowEnergyService_writeDescriptor}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QLowEnergyService[] = {
    {sipName_FullDiscovery, static_cast<int>(::QLowEnergyService::FullDiscovery)},
    {sipName_SkipValueDiscovery, static_cast<int>(::QLowEnergyService::SkipValueDiscovery)},
    {sipName_NoError, static_cast<int>(::QLowEnergyService::NoError)},
    {sipName_OperationError, static_cast<int>(::QLowEnergyService::OperationError)},
    {sipName_CharacteristicWriteError, static_cast<int>(::QLowEnergyService::CharacteristicWriteError)},
    {sipName_DescriptorWriteError, static_cast<int>(::QLowEnergyService::DescriptorWriteError)},
    {sipName_CharacteristicReadError, static_cast<int>(::QLowEnergyService::CharacteristicReadError)},
    {sipName_DescriptorReadError, static_cast<int>(::QLowEnergyService::DescriptorReadError)},
    {sipName_UnknownError, static_cast<int>(::QLowEnergyService::UnknownError)},
    {sipName_InvalidService, static_cast<int>(::QLowEnergyService::InvalidService)},
    {sipName_DiscoveryRequired, static_cast<int>(::QLowEnergyService::DiscoveryRequired)},
    {sipName_ServiceDiscovered, static_cast<int>(::QLowEnergyService::ServiceDiscovered)},
    {sipName_LocalService, static_cast<int>(::QLowEnergyService::LocalService)},
    {sipName_RemoteService, static_cast<int>(::QLowEnergyService::RemoteService)},
    {sipName_RemoteServiceDiscovering, static_cast<int>(::QLowEnergyService::RemoteServiceDiscovering)},
    {sipName_RemoteServiceDiscovered, static_cast<int>(::QLowEnergyService::RemoteServiceDiscovered)},
    {sipName_DiscoveringService, static_cast<int>(::QLowEnergyService::DiscoveringService)},
    {sipName_PrimaryService, static_cast<int>(::QLowEnergyService::PrimaryService)},
    {sipName_IncludedService, static_cast<int>(::QLowEnergyService::IncludedService)},
    {sipName_WriteWithResponse, static_cast<int>(::QLowEnergyService::WriteWithResponse)},
    {sipName_WriteWithoutResponse, static_cast<int>(::QLowEnergyService::WriteWithoutResponse)},
    {sipName_WriteSigned, static_cast<int>(::QLowEnergyService::WriteSigned)},
    {0, 0}
};


/* Define this type's signals. */
static const pyqt6QtSignal signals_QLowEnergyService[] = {
    {"descriptorRead(QLowEnergyDescriptor,QByteArray)", "\1descriptorRead(self, info: QLowEnergyDescriptor, value: QByteArray|bytes|bytearray|memoryview)", SIP_NULLPTR, SIP_NULLPTR},
    {"characteristicRead(QLowEnergyCharacteristic,QByteArray)", "\1characteristicRead(self, info: QLowEnergyCharacteristic, value: QByteArray|bytes|bytearray|memoryview)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorOccurred(QLowEnergyService::ServiceError)", "\1errorOccurred(self, error: QLowEnergyService.ServiceError)", SIP_NULLPTR, SIP_NULLPTR},
    {"descriptorWritten(QLowEnergyDescriptor,QByteArray)", "\1descriptorWritten(self, info: QLowEnergyDescriptor, value: QByteArray|bytes|bytearray|memoryview)", SIP_NULLPTR, SIP_NULLPTR},
    {"characteristicWritten(QLowEnergyCharacteristic,QByteArray)", "\1characteristicWritten(self, info: QLowEnergyCharacteristic, value: QByteArray|bytes|bytearray|memoryview)", SIP_NULLPTR, SIP_NULLPTR},
    {"characteristicChanged(QLowEnergyCharacteristic,QByteArray)", "\1characteristicChanged(self, info: QLowEnergyCharacteristic, value: QByteArray|bytes|bytearray|memoryview)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QLowEnergyService::ServiceState)", "\1stateChanged(self, newState: QLowEnergyService.ServiceState)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QLowEnergyService = {
    &::QLowEnergyService::staticMetaObject,
    signals_QLowEnergyService,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyService = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLowEnergyService,
        SIP_NULLPTR,
        &plugin_QLowEnergyService,
    },
    {
        sipNameNr_QLowEnergyService,
        {0, 0, 1},
        14, methods_QLowEnergyService,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QLowEnergyService, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QLowEnergyService,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLowEnergyService,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QLowEnergyService,
    cast_QLowEnergyService,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
