/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtStateMachine.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtStateMachine/qhistorystate.sip"
#include <qhistorystate.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtStateMachine/qstate.sip"
#include <qstate.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtStateMachine/qabstractstate.sip"
#include <qabstractstate.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtStateMachine/qabstracttransition.sip"
#include <qabstracttransition.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtStateMachine/qstatemachine.sip"
#include <qstatemachine.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQHistoryState.cpp"


class sipQHistoryState : public ::QHistoryState
{
public:
    sipQHistoryState(::QState*);
    sipQHistoryState(::QHistoryState::HistoryType, ::QState*);
    virtual ~sipQHistoryState();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void onEntry(::QEvent*) SIP_OVERRIDE;
    void onExit(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQHistoryState(const sipQHistoryState &);
    sipQHistoryState &operator = (const sipQHistoryState &);

    char sipPyMethods[9];
};

sipQHistoryState::sipQHistoryState(::QState*a0): ::QHistoryState(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQHistoryState::sipQHistoryState(::QHistoryState::HistoryType a0, ::QState*a1): ::QHistoryState(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQHistoryState::~sipQHistoryState()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQHistoryState::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtStateMachine_qt_metaobject(sipPySelf, sipType_QHistoryState);

    return ::QHistoryState::metaObject();
}

int sipQHistoryState::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QHistoryState::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtStateMachine_qt_metacall(sipPySelf, sipType_QHistoryState, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQHistoryState::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtStateMachine_qt_metacast(sipPySelf, sipType_QHistoryState, _clname, &sipCpp) ? sipCpp : ::QHistoryState::qt_metacast(_clname));
}

void sipQHistoryState::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QHistoryState::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtStateMachine_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtStateMachine_0(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHistoryState::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QHistoryState::connectNotify(a0);
        return;
    }

    extern void sipVH_QtStateMachine_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtStateMachine_0(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHistoryState::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QHistoryState::customEvent(a0);
        return;
    }

    extern void sipVH_QtStateMachine_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtStateMachine_1(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHistoryState::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QHistoryState::childEvent(a0);
        return;
    }

    extern void sipVH_QtStateMachine_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtStateMachine_2(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHistoryState::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QHistoryState::timerEvent(a0);
        return;
    }

    extern void sipVH_QtStateMachine_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtStateMachine_3(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQHistoryState::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QHistoryState::eventFilter(a0, a1);

    extern bool sipVH_QtStateMachine_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtStateMachine_4(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQHistoryState::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QHistoryState::event(a0);

    extern bool sipVH_QtStateMachine_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtStateMachine_5(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHistoryState::onEntry(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_onEntry);

    if (!sipMeth)
    {
        ::QHistoryState::onEntry(a0);
        return;
    }

    extern void sipVH_QtStateMachine_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtStateMachine_1(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHistoryState::onExit(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_onExit);

    if (!sipMeth)
    {
        ::QHistoryState::onExit(a0);
        return;
    }

    extern void sipVH_QtStateMachine_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtStateMachine_1(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QHistoryState_defaultTransition, "defaultTransition(self) -> QAbstractTransition|None");

extern "C" {static PyObject *meth_QHistoryState_defaultTransition(PyObject *, PyObject *);}
static PyObject *meth_QHistoryState_defaultTransition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHistoryState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHistoryState, &sipCpp))
        {
            ::QAbstractTransition*sipRes;

            sipRes = sipCpp->defaultTransition();

            return sipConvertFromType(sipRes, sipType_QAbstractTransition, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHistoryState, sipName_defaultTransition, doc_QHistoryState_defaultTransition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHistoryState_setDefaultTransition, "setDefaultTransition(self, transition: QAbstractTransition|None)");

extern "C" {static PyObject *meth_QHistoryState_setDefaultTransition(PyObject *, PyObject *);}
static PyObject *meth_QHistoryState_setDefaultTransition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractTransition* a0;
        ::QHistoryState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QHistoryState, &sipCpp, sipType_QAbstractTransition, &a0))
        {
            sipCpp->setDefaultTransition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHistoryState, sipName_setDefaultTransition, doc_QHistoryState_setDefaultTransition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHistoryState_defaultState, "defaultState(self) -> QAbstractState|None");

extern "C" {static PyObject *meth_QHistoryState_defaultState(PyObject *, PyObject *);}
static PyObject *meth_QHistoryState_defaultState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHistoryState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHistoryState, &sipCpp))
        {
            ::QAbstractState*sipRes;

            sipRes = sipCpp->defaultState();

            return sipConvertFromType(sipRes, sipType_QAbstractState, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHistoryState, sipName_defaultState, doc_QHistoryState_defaultState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHistoryState_setDefaultState, "setDefaultState(self, state: QAbstractState|None)");

extern "C" {static PyObject *meth_QHistoryState_setDefaultState(PyObject *, PyObject *);}
static PyObject *meth_QHistoryState_setDefaultState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractState* a0;
        ::QHistoryState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QHistoryState, &sipCpp, sipType_QAbstractState, &a0))
        {
            sipCpp->setDefaultState(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHistoryState, sipName_setDefaultState, doc_QHistoryState_setDefaultState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHistoryState_historyType, "historyType(self) -> QHistoryState.HistoryType");

extern "C" {static PyObject *meth_QHistoryState_historyType(PyObject *, PyObject *);}
static PyObject *meth_QHistoryState_historyType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHistoryState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHistoryState, &sipCpp))
        {
            ::QHistoryState::HistoryType sipRes;

            sipRes = sipCpp->historyType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QHistoryState_HistoryType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHistoryState, sipName_historyType, doc_QHistoryState_historyType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHistoryState_setHistoryType, "setHistoryType(self, type: QHistoryState.HistoryType)");

extern "C" {static PyObject *meth_QHistoryState_setHistoryType(PyObject *, PyObject *);}
static PyObject *meth_QHistoryState_setHistoryType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHistoryState::HistoryType a0;
        ::QHistoryState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QHistoryState, &sipCpp, sipType_QHistoryState_HistoryType, &a0))
        {
            sipCpp->setHistoryType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHistoryState, sipName_setHistoryType, doc_QHistoryState_setHistoryType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHistoryState_onEntry, "onEntry(self, event: QEvent|None)");

extern "C" {static PyObject *meth_QHistoryState_onEntry(PyObject *, PyObject *);}
static PyObject *meth_QHistoryState_onEntry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QHistoryState)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QHistoryState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QHistoryState, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QHistoryState::onEntry(a0) : sipCpp->onEntry(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHistoryState, sipName_onEntry, doc_QHistoryState_onEntry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHistoryState_onExit, "onExit(self, event: QEvent|None)");

extern "C" {static PyObject *meth_QHistoryState_onExit(PyObject *, PyObject *);}
static PyObject *meth_QHistoryState_onExit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QHistoryState)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QHistoryState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QHistoryState, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QHistoryState::onExit(a0) : sipCpp->onExit(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHistoryState, sipName_onExit, doc_QHistoryState_onExit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHistoryState_event, "event(self, e: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QHistoryState_event(PyObject *, PyObject *);}
static PyObject *meth_QHistoryState_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QHistoryState)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QHistoryState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QHistoryState, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QHistoryState::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHistoryState, sipName_event, doc_QHistoryState_event);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QHistoryState(void *, const sipTypeDef *);}
static void *cast_QHistoryState(void *sipCppV, const sipTypeDef *targetType)
{
    ::QHistoryState *sipCpp = reinterpret_cast< ::QHistoryState *>(sipCppV);

    if (targetType == sipType_QHistoryState)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstractState)->ctd_cast(static_cast< ::QAbstractState *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHistoryState(void *, int);}
static void release_QHistoryState(void *sipCppV, int)
{
    ::QHistoryState *sipCpp = reinterpret_cast< ::QHistoryState *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QHistoryState(Py_ssize_t);}
static void *array_QHistoryState(Py_ssize_t sipNrElem)
{
    return new ::QHistoryState[sipNrElem];
}


extern "C" {static void array_delete_QHistoryState(void *);}
static void array_delete_QHistoryState(void *sipCpp)
{
    delete[] reinterpret_cast< ::QHistoryState *>(sipCpp);
}


extern "C" {static void dealloc_QHistoryState(sipSimpleWrapper *);}
static void dealloc_QHistoryState(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQHistoryState *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHistoryState(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QHistoryState(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QHistoryState(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQHistoryState *sipCpp = SIP_NULLPTR;

    {
        ::QState* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QState, &a0, sipOwner))
        {
            sipCpp = new sipQHistoryState(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QHistoryState::HistoryType a0;
        ::QState* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|JH", sipType_QHistoryState_HistoryType, &a0, sipType_QState, &a1, sipOwner))
        {
            sipCpp = new sipQHistoryState(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QHistoryState[] = {{0, 255, 1}};


static PyMethodDef methods_QHistoryState[] = {
    {sipName_defaultState, meth_QHistoryState_defaultState, METH_VARARGS, doc_QHistoryState_defaultState},
    {sipName_defaultTransition, meth_QHistoryState_defaultTransition, METH_VARARGS, doc_QHistoryState_defaultTransition},
    {sipName_event, meth_QHistoryState_event, METH_VARARGS, doc_QHistoryState_event},
    {sipName_historyType, meth_QHistoryState_historyType, METH_VARARGS, doc_QHistoryState_historyType},
    {sipName_onEntry, meth_QHistoryState_onEntry, METH_VARARGS, doc_QHistoryState_onEntry},
    {sipName_onExit, meth_QHistoryState_onExit, METH_VARARGS, doc_QHistoryState_onExit},
    {sipName_setDefaultState, meth_QHistoryState_setDefaultState, METH_VARARGS, doc_QHistoryState_setDefaultState},
    {sipName_setDefaultTransition, meth_QHistoryState_setDefaultTransition, METH_VARARGS, doc_QHistoryState_setDefaultTransition},
    {sipName_setHistoryType, meth_QHistoryState_setHistoryType, METH_VARARGS, doc_QHistoryState_setHistoryType}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QHistoryState[] = {
    {sipName_ShallowHistory, static_cast<int>(::QHistoryState::ShallowHistory)},
    {sipName_DeepHistory, static_cast<int>(::QHistoryState::DeepHistory)},
    {0, 0}
};

PyDoc_STRVAR(doc_QHistoryState, "\1QHistoryState(parent: QState|None = None)\n"
"QHistoryState(type: QHistoryState.HistoryType, parent: QState|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QHistoryState[] = {
    {"historyTypeChanged()", "\1historyTypeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"defaultStateChanged()", "\1defaultStateChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"defaultTransitionChanged()", "\1defaultTransitionChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QHistoryState = {
    &::QHistoryState::staticMetaObject,
    signals_QHistoryState,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtStateMachine_QHistoryState = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHistoryState,
        SIP_NULLPTR,
        &plugin_QHistoryState,
    },
    {
        sipNameNr_QHistoryState,
        {0, 0, 1},
        9, methods_QHistoryState,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QHistoryState, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QHistoryState,
    -1,
    -1,
    supers_QHistoryState,
    SIP_NULLPTR,
    init_type_QHistoryState,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHistoryState,
    SIP_NULLPTR,
    array_QHistoryState,
    SIP_NULLPTR,
    release_QHistoryState,
    cast_QHistoryState,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QHistoryState,
    sizeof (::QHistoryState),
};
