/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtOpenGLWidgetsAPI_H
#define _QtOpenGLWidgetsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QOpenGLWidget__UpdateBehavior 0
#define sipName_QOpenGLWidget__UpdateBehavior &sipStrings_QtOpenGLWidgets[0]
#define sipNameNr_QOpenGLWidget__TargetBuffer 30
#define sipName_QOpenGLWidget__TargetBuffer &sipStrings_QtOpenGLWidgets[30]
#define sipNameNr_defaultFramebufferObject 58
#define sipName_defaultFramebufferObject &sipStrings_QtOpenGLWidgets[58]
#define sipNameNr_PyQt6_QtOpenGLWidgets 83
#define sipName_PyQt6_QtOpenGLWidgets &sipStrings_QtOpenGLWidgets[83]
#define sipNameNr_mouseDoubleClickEvent 105
#define sipName_mouseDoubleClickEvent &sipStrings_QtOpenGLWidgets[105]
#define sipNameNr_currentTargetBuffer 127
#define sipName_currentTargetBuffer &sipStrings_QtOpenGLWidgets[127]
#define sipNameNr_focusNextPrevChild 147
#define sipName_focusNextPrevChild &sipStrings_QtOpenGLWidgets[147]
#define sipNameNr_hasHeightForWidth 166
#define sipName_hasHeightForWidth &sipStrings_QtOpenGLWidgets[166]
#define sipNameNr_mouseReleaseEvent 184
#define sipName_mouseReleaseEvent &sipStrings_QtOpenGLWidgets[184]
#define sipNameNr_setUpdateBehavior 202
#define sipName_setUpdateBehavior &sipStrings_QtOpenGLWidgets[202]
#define sipNameNr_contextMenuEvent 220
#define sipName_contextMenuEvent &sipStrings_QtOpenGLWidgets[220]
#define sipNameNr_disconnectNotify 237
#define sipName_disconnectNotify &sipStrings_QtOpenGLWidgets[237]
#define sipNameNr_inputMethodEvent 254
#define sipName_inputMethodEvent &sipStrings_QtOpenGLWidgets[254]
#define sipNameNr_inputMethodQuery 271
#define sipName_inputMethodQuery &sipStrings_QtOpenGLWidgets[271]
#define sipNameNr_setTextureFormat 288
#define sipName_setTextureFormat &sipStrings_QtOpenGLWidgets[288]
#define sipNameNr_NoPartialUpdate 305
#define sipName_NoPartialUpdate &sipStrings_QtOpenGLWidgets[305]
#define sipNameNr_grabFramebuffer 321
#define sipName_grabFramebuffer &sipStrings_QtOpenGLWidgets[321]
#define sipNameNr_keyReleaseEvent 337
#define sipName_keyReleaseEvent &sipStrings_QtOpenGLWidgets[337]
#define sipNameNr_minimumSizeHint 353
#define sipName_minimumSizeHint &sipStrings_QtOpenGLWidgets[353]
#define sipNameNr_mousePressEvent 369
#define sipName_mousePressEvent &sipStrings_QtOpenGLWidgets[369]
#define sipNameNr_UpdateBehavior 15
#define sipName_UpdateBehavior &sipStrings_QtOpenGLWidgets[15]
#define sipNameNr_aboutToCompose 385
#define sipName_aboutToCompose &sipStrings_QtOpenGLWidgets[385]
#define sipNameNr_dragEnterEvent 400
#define sipName_dragEnterEvent &sipStrings_QtOpenGLWidgets[400]
#define sipNameNr_dragLeaveEvent 415
#define sipName_dragLeaveEvent &sipStrings_QtOpenGLWidgets[415]
#define sipNameNr_heightForWidth 430
#define sipName_heightForWidth &sipStrings_QtOpenGLWidgets[430]
#define sipNameNr_mouseMoveEvent 445
#define sipName_mouseMoveEvent &sipStrings_QtOpenGLWidgets[445]
#define sipNameNr_updateBehavior 460
#define sipName_updateBehavior &sipStrings_QtOpenGLWidgets[460]
#define sipNameNr_PartialUpdate 307
#define sipName_PartialUpdate &sipStrings_QtOpenGLWidgets[307]
#define sipNameNr_QOpenGLWidget 475
#define sipName_QOpenGLWidget &sipStrings_QtOpenGLWidgets[475]
#define sipNameNr_aboutToResize 489
#define sipName_aboutToResize &sipStrings_QtOpenGLWidgets[489]
#define sipNameNr_connectNotify 240
#define sipName_connectNotify &sipStrings_QtOpenGLWidgets[240]
#define sipNameNr_dragMoveEvent 503
#define sipName_dragMoveEvent &sipStrings_QtOpenGLWidgets[503]
#define sipNameNr_focusOutEvent 517
#define sipName_focusOutEvent &sipStrings_QtOpenGLWidgets[517]
#define sipNameNr_keyPressEvent 531
#define sipName_keyPressEvent &sipStrings_QtOpenGLWidgets[531]
#define sipNameNr_sharedPainter 545
#define sipName_sharedPainter &sipStrings_QtOpenGLWidgets[545]
#define sipNameNr_textureFormat 559
#define sipName_textureFormat &sipStrings_QtOpenGLWidgets[559]
#define sipNameNr_TargetBuffer 45
#define sipName_TargetBuffer &sipStrings_QtOpenGLWidgets[45]
#define sipNameNr_focusInEvent 573
#define sipName_focusInEvent &sipStrings_QtOpenGLWidgets[573]
#define sipNameNr_frameSwapped 586
#define sipName_frameSwapped &sipStrings_QtOpenGLWidgets[586]
#define sipNameNr_initializeGL 599
#define sipName_initializeGL &sipStrings_QtOpenGLWidgets[599]
#define sipNameNr_RightBuffer 612
#define sipName_RightBuffer &sipStrings_QtOpenGLWidgets[612]
#define sipNameNr_actionEvent 624
#define sipName_actionEvent &sipStrings_QtOpenGLWidgets[624]
#define sipNameNr_changeEvent 636
#define sipName_changeEvent &sipStrings_QtOpenGLWidgets[636]
#define sipNameNr_customEvent 648
#define sipName_customEvent &sipStrings_QtOpenGLWidgets[648]
#define sipNameNr_doneCurrent 660
#define sipName_doneCurrent &sipStrings_QtOpenGLWidgets[660]
#define sipNameNr_eventFilter 672
#define sipName_eventFilter &sipStrings_QtOpenGLWidgets[672]
#define sipNameNr_initPainter 684
#define sipName_initPainter &sipStrings_QtOpenGLWidgets[684]
#define sipNameNr_makeCurrent 696
#define sipName_makeCurrent &sipStrings_QtOpenGLWidgets[696]
#define sipNameNr_nativeEvent 708
#define sipName_nativeEvent &sipStrings_QtOpenGLWidgets[708]
#define sipNameNr_paintEngine 720
#define sipName_paintEngine &sipStrings_QtOpenGLWidgets[720]
#define sipNameNr_resizeEvent 732
#define sipName_resizeEvent &sipStrings_QtOpenGLWidgets[732]
#define sipNameNr_tabletEvent 744
#define sipName_tabletEvent &sipStrings_QtOpenGLWidgets[744]
#define sipNameNr_LeftBuffer 756
#define sipName_LeftBuffer &sipStrings_QtOpenGLWidgets[756]
#define sipNameNr_childEvent 767
#define sipName_childEvent &sipStrings_QtOpenGLWidgets[767]
#define sipNameNr_closeEvent 778
#define sipName_closeEvent &sipStrings_QtOpenGLWidgets[778]
#define sipNameNr_enterEvent 789
#define sipName_enterEvent &sipStrings_QtOpenGLWidgets[789]
#define sipNameNr_leaveEvent 800
#define sipName_leaveEvent &sipStrings_QtOpenGLWidgets[800]
#define sipNameNr_paintEvent 811
#define sipName_paintEvent &sipStrings_QtOpenGLWidgets[811]
#define sipNameNr_setVisible 822
#define sipName_setVisible &sipStrings_QtOpenGLWidgets[822]
#define sipNameNr_timerEvent 833
#define sipName_timerEvent &sipStrings_QtOpenGLWidgets[833]
#define sipNameNr_wheelEvent 844
#define sipName_wheelEvent &sipStrings_QtOpenGLWidgets[844]
#define sipNameNr_dropEvent 855
#define sipName_dropEvent &sipStrings_QtOpenGLWidgets[855]
#define sipNameNr_hideEvent 865
#define sipName_hideEvent &sipStrings_QtOpenGLWidgets[865]
#define sipNameNr_moveEvent 875
#define sipName_moveEvent &sipStrings_QtOpenGLWidgets[875]
#define sipNameNr_setFormat 885
#define sipName_setFormat &sipStrings_QtOpenGLWidgets[885]
#define sipNameNr_showEvent 895
#define sipName_showEvent &sipStrings_QtOpenGLWidgets[895]
#define sipNameNr_resizeGL 905
#define sipName_resizeGL &sipStrings_QtOpenGLWidgets[905]
#define sipNameNr_sizeHint 914
#define sipName_sizeHint &sipStrings_QtOpenGLWidgets[914]
#define sipNameNr_context 923
#define sipName_context &sipStrings_QtOpenGLWidgets[923]
#define sipNameNr_devType 931
#define sipName_devType &sipStrings_QtOpenGLWidgets[931]
#define sipNameNr_isValid 939
#define sipName_isValid &sipStrings_QtOpenGLWidgets[939]
#define sipNameNr_paintGL 947
#define sipName_paintGL &sipStrings_QtOpenGLWidgets[947]
#define sipNameNr_resized 955
#define sipName_resized &sipStrings_QtOpenGLWidgets[955]
#define sipNameNr_format 963
#define sipName_format &sipStrings_QtOpenGLWidgets[963]
#define sipNameNr_metric 970
#define sipName_metric &sipStrings_QtOpenGLWidgets[970]
#define sipNameNr_parent 977
#define sipName_parent &sipStrings_QtOpenGLWidgets[977]
#define sipNameNr_event 984
#define sipName_event &sipStrings_QtOpenGLWidgets[984]
#define sipNameNr_flags 990
#define sipName_flags &sipStrings_QtOpenGLWidgets[990]

#define sipMalloc                   sipAPI_QtOpenGLWidgets->api_malloc
#define sipFree                     sipAPI_QtOpenGLWidgets->api_free
#define sipBuildResult              sipAPI_QtOpenGLWidgets->api_build_result
#define sipCallMethod               sipAPI_QtOpenGLWidgets->api_call_method
#define sipCallProcedureMethod      sipAPI_QtOpenGLWidgets->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtOpenGLWidgets->api_call_error_handler
#define sipParseResultEx            sipAPI_QtOpenGLWidgets->api_parse_result_ex
#define sipParseResult              sipAPI_QtOpenGLWidgets->api_parse_result
#define sipParseArgs                sipAPI_QtOpenGLWidgets->api_parse_args
#define sipParseKwdArgs             sipAPI_QtOpenGLWidgets->api_parse_kwd_args
#define sipParsePair                sipAPI_QtOpenGLWidgets->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtOpenGLWidgets->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtOpenGLWidgets->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtOpenGLWidgets->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtOpenGLWidgets->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtOpenGLWidgets->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtOpenGLWidgets->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtOpenGLWidgets->api_add_exception
#define sipNoFunction               sipAPI_QtOpenGLWidgets->api_no_function
#define sipNoMethod                 sipAPI_QtOpenGLWidgets->api_no_method
#define sipAbstractMethod           sipAPI_QtOpenGLWidgets->api_abstract_method
#define sipBadClass                 sipAPI_QtOpenGLWidgets->api_bad_class
#define sipBadCatcherResult         sipAPI_QtOpenGLWidgets->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtOpenGLWidgets->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtOpenGLWidgets->api_bad_operator_arg
#define sipTrace                    sipAPI_QtOpenGLWidgets->api_trace
#define sipTransferBack             sipAPI_QtOpenGLWidgets->api_transfer_back
#define sipTransferTo               sipAPI_QtOpenGLWidgets->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtOpenGLWidgets->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtOpenGLWidgets->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtOpenGLWidgets->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtOpenGLWidgets->api_voidptr_type
#define sipGetPyObject              sipAPI_QtOpenGLWidgets->api_get_pyobject
#define sipGetAddress               sipAPI_QtOpenGLWidgets->api_get_address
#define sipGetMixinAddress          sipAPI_QtOpenGLWidgets->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtOpenGLWidgets->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtOpenGLWidgets->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtOpenGLWidgets->api_call_hook
#define sipEndThread                sipAPI_QtOpenGLWidgets->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtOpenGLWidgets->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtOpenGLWidgets->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtOpenGLWidgets->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtOpenGLWidgets->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtOpenGLWidgets->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtOpenGLWidgets->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtOpenGLWidgets->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtOpenGLWidgets->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtOpenGLWidgets->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtOpenGLWidgets->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtOpenGLWidgets->api_convert_to_bool
#define sipReleaseType              sipAPI_QtOpenGLWidgets->api_release_type
#define sipConvertFromType          sipAPI_QtOpenGLWidgets->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtOpenGLWidgets->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtOpenGLWidgets->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtOpenGLWidgets->api_convert_from_enum
#define sipGetState                 sipAPI_QtOpenGLWidgets->api_get_state
#define sipExportSymbol             sipAPI_QtOpenGLWidgets->api_export_symbol
#define sipImportSymbol             sipAPI_QtOpenGLWidgets->api_import_symbol
#define sipFindType                 sipAPI_QtOpenGLWidgets->api_find_type
#define sipBytes_AsChar             sipAPI_QtOpenGLWidgets->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtOpenGLWidgets->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtOpenGLWidgets->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtOpenGLWidgets->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtOpenGLWidgets->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtOpenGLWidgets->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtOpenGLWidgets->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtOpenGLWidgets->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtOpenGLWidgets->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtOpenGLWidgets->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtOpenGLWidgets->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtOpenGLWidgets->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtOpenGLWidgets->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtOpenGLWidgets->api_get_reference
#define sipKeepReference            sipAPI_QtOpenGLWidgets->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtOpenGLWidgets->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtOpenGLWidgets->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtOpenGLWidgets->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtOpenGLWidgets->api_type_scope
#define sipResolveTypedef           sipAPI_QtOpenGLWidgets->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtOpenGLWidgets->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtOpenGLWidgets->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtOpenGLWidgets->api_init_mixin
#define sipExportModule             sipAPI_QtOpenGLWidgets->api_export_module
#define sipInitModule               sipAPI_QtOpenGLWidgets->api_init_module
#define sipGetInterpreter           sipAPI_QtOpenGLWidgets->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtOpenGLWidgets->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtOpenGLWidgets->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtOpenGLWidgets->api_py_type_dict
#define sipPyTypeName               sipAPI_QtOpenGLWidgets->api_py_type_name
#define sipGetCFunction             sipAPI_QtOpenGLWidgets->api_get_c_function
#define sipGetMethod                sipAPI_QtOpenGLWidgets->api_get_method
#define sipFromMethod               sipAPI_QtOpenGLWidgets->api_from_method
#define sipGetDate                  sipAPI_QtOpenGLWidgets->api_get_date
#define sipFromDate                 sipAPI_QtOpenGLWidgets->api_from_date
#define sipGetDateTime              sipAPI_QtOpenGLWidgets->api_get_datetime
#define sipFromDateTime             sipAPI_QtOpenGLWidgets->api_from_datetime
#define sipGetTime                  sipAPI_QtOpenGLWidgets->api_get_time
#define sipFromTime                 sipAPI_QtOpenGLWidgets->api_from_time
#define sipIsUserType               sipAPI_QtOpenGLWidgets->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtOpenGLWidgets->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtOpenGLWidgets->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtOpenGLWidgets->api_unicode_write
#define sipUnicodeData              sipAPI_QtOpenGLWidgets->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtOpenGLWidgets->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtOpenGLWidgets->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtOpenGLWidgets->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtOpenGLWidgets->api_is_derived_class
#define sipGetUserObject            sipAPI_QtOpenGLWidgets->api_get_user_object
#define sipSetUserObject            sipAPI_QtOpenGLWidgets->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtOpenGLWidgets->api_register_event_handler
#define sipConvertToArray           sipAPI_QtOpenGLWidgets->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtOpenGLWidgets->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtOpenGLWidgets->api_enable_gc
#define sipPrintObject              sipAPI_QtOpenGLWidgets->api_print_object
#define sipLong_AsChar              sipAPI_QtOpenGLWidgets->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtOpenGLWidgets->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtOpenGLWidgets->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtOpenGLWidgets->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtOpenGLWidgets->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtOpenGLWidgets->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtOpenGLWidgets->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtOpenGLWidgets->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtOpenGLWidgets->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtOpenGLWidgets->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtOpenGLWidgets->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtOpenGLWidgets->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtOpenGLWidgets->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtOpenGLWidgets->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtOpenGLWidgets->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtOpenGLWidgets->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtOpenGLWidgets->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtOpenGLWidgets->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtOpenGLWidgets->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtOpenGLWidgets->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtOpenGLWidgets->api_release_type_us
#define sipIsPyMethod               sipAPI_QtOpenGLWidgets->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtOpenGLWidgets[];

#define sipType_QOpenGLWidget sipExportedTypes_QtOpenGLWidgets[0]

#define sipType_QOpenGLWidget_TargetBuffer sipExportedTypes_QtOpenGLWidgets[1]

#define sipType_QOpenGLWidget_UpdateBehavior sipExportedTypes_QtOpenGLWidgets[2]

extern sipClassTypeDef sipTypeDef_QtOpenGLWidgets_QOpenGLWidget;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtOpenGLWidgets;
extern sipExportedModuleDef sipModuleAPI_QtOpenGLWidgets;
extern sipTypeDef *sipExportedTypes_QtOpenGLWidgets[];

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtOpenGLWidgets_QtCore[9].it_td

#define sipType_QObject sipImportedTypes_QtOpenGLWidgets_QtCore[5].it_td

#define sipType_QByteArray sipImportedTypes_QtOpenGLWidgets_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtOpenGLWidgets_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtOpenGLWidgets_QtCore[7].it_td

#define sipType_QChildEvent sipImportedTypes_QtOpenGLWidgets_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtOpenGLWidgets_QtCore[4].it_td

#define sipType_QSize sipImportedTypes_QtOpenGLWidgets_QtCore[6].it_td

#define sipType_QVariant sipImportedTypes_QtOpenGLWidgets_QtCore[8].it_td

#define sipType_QFlags_0100Qt_WindowType sipImportedTypes_QtOpenGLWidgets_QtCore[3].it_td

#define sipType_qintptr sipImportedTypes_QtOpenGLWidgets_QtCore[10].it_td
extern sipImportedTypeDef sipImportedTypes_QtOpenGLWidgets_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtOpenGLWidgets_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtOpenGLWidgets_QtGui[16].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtOpenGLWidgets_QtGui[17].it_td

#define sipType_QKeyEvent sipImportedTypes_QtOpenGLWidgets_QtGui[12].it_td

#define sipType_QFocusEvent sipImportedTypes_QtOpenGLWidgets_QtGui[8].it_td

#define sipType_QPaintEvent sipImportedTypes_QtOpenGLWidgets_QtGui[19].it_td

#define sipType_QMoveEvent sipImportedTypes_QtOpenGLWidgets_QtGui[14].it_td

#define sipType_QResizeEvent sipImportedTypes_QtOpenGLWidgets_QtGui[21].it_td

#define sipType_QCloseEvent sipImportedTypes_QtOpenGLWidgets_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtOpenGLWidgets_QtGui[22].it_td

#define sipType_QHideEvent sipImportedTypes_QtOpenGLWidgets_QtGui[9].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtOpenGLWidgets_QtGui[2].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtOpenGLWidgets_QtGui[11].it_td

#define sipType_QDropEvent sipImportedTypes_QtOpenGLWidgets_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtOpenGLWidgets_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtOpenGLWidgets_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtOpenGLWidgets_QtGui[4].it_td

#define sipType_QActionEvent sipImportedTypes_QtOpenGLWidgets_QtGui[0].it_td

#define sipType_QEnterEvent sipImportedTypes_QtOpenGLWidgets_QtGui[7].it_td

#define sipType_QMouseEvent sipImportedTypes_QtOpenGLWidgets_QtGui[13].it_td

#define sipType_QWheelEvent sipImportedTypes_QtOpenGLWidgets_QtGui[25].it_td

#define sipType_QTabletEvent sipImportedTypes_QtOpenGLWidgets_QtGui[24].it_td

#define sipType_QImage sipImportedTypes_QtOpenGLWidgets_QtGui[10].it_td

#define sipType_QOpenGLContext sipImportedTypes_QtOpenGLWidgets_QtGui[15].it_td

#define sipType_QPaintEngine sipImportedTypes_QtOpenGLWidgets_QtGui[18].it_td

#define sipType_QPainter sipImportedTypes_QtOpenGLWidgets_QtGui[20].it_td

#define sipType_QSurfaceFormat sipImportedTypes_QtOpenGLWidgets_QtGui[23].it_td
extern sipImportedTypeDef sipImportedTypes_QtOpenGLWidgets_QtGui[];

#define sipType_QWidget sipImportedTypes_QtOpenGLWidgets_QtWidgets[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtOpenGLWidgets_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtOpenGLWidgets_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtOpenGLWidgets_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtOpenGLWidgets_qt_metacast;

#endif
