/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPdf.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfpagerenderer.sip"
#include <qpdfpagerenderer.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfdocument.sip"
#include <qpdfdocument.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfdocumentrenderoptions.sip"
#include <qpdfdocumentrenderoptions.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfPageRenderer.cpp"


class sipQPdfPageRenderer : public ::QPdfPageRenderer
{
public:
    sipQPdfPageRenderer(::QObject*);
    virtual ~sipQPdfPageRenderer();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPdfPageRenderer(const sipQPdfPageRenderer &);
    sipQPdfPageRenderer &operator = (const sipQPdfPageRenderer &);

    char sipPyMethods[7];
};

sipQPdfPageRenderer::sipQPdfPageRenderer(::QObject*a0): ::QPdfPageRenderer(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPdfPageRenderer::~sipQPdfPageRenderer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQPdfPageRenderer::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtPdf_qt_metaobject(sipPySelf, sipType_QPdfPageRenderer);

    return ::QPdfPageRenderer::metaObject();
}

int sipQPdfPageRenderer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QPdfPageRenderer::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtPdf_qt_metacall(sipPySelf, sipType_QPdfPageRenderer, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQPdfPageRenderer::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtPdf_qt_metacast(sipPySelf, sipType_QPdfPageRenderer, _clname, &sipCpp) ? sipCpp : ::QPdfPageRenderer::qt_metacast(_clname));
}

bool sipQPdfPageRenderer::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QPdfPageRenderer::event(a0);

    extern bool sipVH_QtPdf_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtPdf_25(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPdfPageRenderer::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QPdfPageRenderer::eventFilter(a0, a1);

    extern bool sipVH_QtPdf_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtPdf_26(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQPdfPageRenderer::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QPdfPageRenderer::timerEvent(a0);
        return;
    }

    extern void sipVH_QtPdf_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtPdf_27(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfPageRenderer::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QPdfPageRenderer::childEvent(a0);
        return;
    }

    extern void sipVH_QtPdf_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtPdf_28(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfPageRenderer::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QPdfPageRenderer::customEvent(a0);
        return;
    }

    extern void sipVH_QtPdf_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPdf_29(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfPageRenderer::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QPdfPageRenderer::connectNotify(a0);
        return;
    }

    extern void sipVH_QtPdf_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPdf_30(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfPageRenderer::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QPdfPageRenderer::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtPdf_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPdf_30(sipGILState, sipImportedVirtErrorHandlers_QtPdf_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QPdfPageRenderer_renderMode, "renderMode(self) -> QPdfPageRenderer.RenderMode");

extern "C" {static PyObject *meth_QPdfPageRenderer_renderMode(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageRenderer_renderMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfPageRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfPageRenderer, &sipCpp))
        {
            ::QPdfPageRenderer::RenderMode sipRes;

            sipRes = sipCpp->renderMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPdfPageRenderer_RenderMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageRenderer, sipName_renderMode, doc_QPdfPageRenderer_renderMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageRenderer_setRenderMode, "setRenderMode(self, mode: QPdfPageRenderer.RenderMode)");

extern "C" {static PyObject *meth_QPdfPageRenderer_setRenderMode(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageRenderer_setRenderMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfPageRenderer::RenderMode a0;
        ::QPdfPageRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPdfPageRenderer, &sipCpp, sipType_QPdfPageRenderer_RenderMode, &a0))
        {
            sipCpp->setRenderMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageRenderer, sipName_setRenderMode, doc_QPdfPageRenderer_setRenderMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageRenderer_document, "document(self) -> QPdfDocument|None");

extern "C" {static PyObject *meth_QPdfPageRenderer_document(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageRenderer_document(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfPageRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfPageRenderer, &sipCpp))
        {
            ::QPdfDocument*sipRes;

            sipRes = sipCpp->document();

            return sipConvertFromType(sipRes, sipType_QPdfDocument, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageRenderer, sipName_document, doc_QPdfPageRenderer_document);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageRenderer_setDocument, "setDocument(self, document: QPdfDocument|None)");

extern "C" {static PyObject *meth_QPdfPageRenderer_setDocument(PyObject *, PyObject *);}
static PyObject *meth_QPdfPageRenderer_setDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfDocument* a0;
        ::QPdfPageRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QPdfPageRenderer, &sipCpp, sipType_QPdfDocument, &a0))
        {
            sipCpp->setDocument(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageRenderer, sipName_setDocument, doc_QPdfPageRenderer_setDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfPageRenderer_requestPage, "requestPage(self, pageNumber: int, imageSize: QSize, options: QPdfDocumentRenderOptions = QPdfDocumentRenderOptions()) -> int");

extern "C" {static PyObject *meth_QPdfPageRenderer_requestPage(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPdfPageRenderer_requestPage(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSize* a1;
        ::QPdfDocumentRenderOptions a2def = QPdfDocumentRenderOptions();
        ::QPdfDocumentRenderOptions* a2 = &a2def;
        ::QPdfPageRenderer *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiJ9|J9", &sipSelf, sipType_QPdfPageRenderer, &sipCpp, &a0, sipType_QSize, &a1, sipType_QPdfDocumentRenderOptions, &a2))
        {
            ::quint64 sipRes;

            sipRes = sipCpp->requestPage(a0, *a1, *a2);

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfPageRenderer, sipName_requestPage, doc_QPdfPageRenderer_requestPage);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPdfPageRenderer(void *, const sipTypeDef *);}
static void *cast_QPdfPageRenderer(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPdfPageRenderer *sipCpp = reinterpret_cast< ::QPdfPageRenderer *>(sipCppV);

    if (targetType == sipType_QPdfPageRenderer)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPdfPageRenderer(void *, int);}
static void release_QPdfPageRenderer(void *sipCppV, int)
{
    ::QPdfPageRenderer *sipCpp = reinterpret_cast< ::QPdfPageRenderer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QPdfPageRenderer(sipSimpleWrapper *);}
static void dealloc_QPdfPageRenderer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPdfPageRenderer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPdfPageRenderer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPdfPageRenderer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPdfPageRenderer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQPdfPageRenderer *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQPdfPageRenderer(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPdfPageRenderer[] = {{15, 0, 1}};


static PyMethodDef methods_QPdfPageRenderer[] = {
    {sipName_document, meth_QPdfPageRenderer_document, METH_VARARGS, doc_QPdfPageRenderer_document},
    {sipName_renderMode, meth_QPdfPageRenderer_renderMode, METH_VARARGS, doc_QPdfPageRenderer_renderMode},
    {sipName_requestPage, SIP_MLMETH_CAST(meth_QPdfPageRenderer_requestPage), METH_VARARGS|METH_KEYWORDS, doc_QPdfPageRenderer_requestPage},
    {sipName_setDocument, meth_QPdfPageRenderer_setDocument, METH_VARARGS, doc_QPdfPageRenderer_setDocument},
    {sipName_setRenderMode, meth_QPdfPageRenderer_setRenderMode, METH_VARARGS, doc_QPdfPageRenderer_setRenderMode}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QPdfPageRenderer[] = {
    {sipName_MultiThreaded, static_cast<int>(::QPdfPageRenderer::RenderMode::MultiThreaded)},
    {sipName_SingleThreaded, static_cast<int>(::QPdfPageRenderer::RenderMode::SingleThreaded)},
    {0, 0}
};

PyDoc_STRVAR(doc_QPdfPageRenderer, "\1QPdfPageRenderer(parent: QObject|None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QPdfPageRenderer[] = {
    {"renderModeChanged(QPdfPageRenderer::RenderMode)", "\1renderModeChanged(self, renderMode: QPdfPageRenderer.RenderMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"documentChanged(QPdfDocument*)", "\1documentChanged(self, document: QPdfDocument|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QPdfPageRenderer = {
    &::QPdfPageRenderer::staticMetaObject,
    signals_QPdfPageRenderer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPdf_QPdfPageRenderer = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPdfPageRenderer,
        SIP_NULLPTR,
        &plugin_QPdfPageRenderer,
    },
    {
        sipNameNr_QPdfPageRenderer,
        {0, 0, 1},
        5, methods_QPdfPageRenderer,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QPdfPageRenderer, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPdfPageRenderer,
    -1,
    -1,
    supers_QPdfPageRenderer,
    SIP_NULLPTR,
    init_type_QPdfPageRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPdfPageRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QPdfPageRenderer,
    cast_QPdfPageRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QPdfPageRenderer),
};
