/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qlowenergydescriptor.sip"
#include <qlowenergydescriptor.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyDescriptor.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothuuid.sip"
#include <qbluetoothuuid.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyDescriptor.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyDescriptor.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyDescriptor.cpp"


PyDoc_STRVAR(doc_QLowEnergyDescriptor_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QLowEnergyDescriptor_isValid(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptor_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptor, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptor, sipName_isValid, doc_QLowEnergyDescriptor_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptor_value, "value(self) -> QByteArray");

extern "C" {static PyObject *meth_QLowEnergyDescriptor_value(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptor_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptor, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->value());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptor, sipName_value, doc_QLowEnergyDescriptor_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptor_uuid, "uuid(self) -> QBluetoothUuid");

extern "C" {static PyObject *meth_QLowEnergyDescriptor_uuid(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptor_uuid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptor, &sipCpp))
        {
            ::QBluetoothUuid*sipRes;

            sipRes = new ::QBluetoothUuid(sipCpp->uuid());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothUuid, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptor, sipName_uuid, doc_QLowEnergyDescriptor_uuid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptor_name, "name(self) -> str");

extern "C" {static PyObject *meth_QLowEnergyDescriptor_name(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptor_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptor, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptor, sipName_name, doc_QLowEnergyDescriptor_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyDescriptor_type, "type(self) -> QBluetoothUuid.DescriptorType");

extern "C" {static PyObject *meth_QLowEnergyDescriptor_type(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyDescriptor_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyDescriptor, &sipCpp))
        {
            ::QBluetoothUuid::DescriptorType sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QBluetoothUuid_DescriptorType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyDescriptor, sipName_type, doc_QLowEnergyDescriptor_type);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QLowEnergyDescriptor___eq__(PyObject *, PyObject *);}
static PyObject *slot_QLowEnergyDescriptor___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLowEnergyDescriptor *sipCpp = reinterpret_cast< ::QLowEnergyDescriptor *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLowEnergyDescriptor));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptor* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLowEnergyDescriptor, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, eq_slot, sipType_QLowEnergyDescriptor, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QLowEnergyDescriptor___ne__(PyObject *, PyObject *);}
static PyObject *slot_QLowEnergyDescriptor___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLowEnergyDescriptor *sipCpp = reinterpret_cast< ::QLowEnergyDescriptor *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLowEnergyDescriptor));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyDescriptor* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLowEnergyDescriptor, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, ne_slot, sipType_QLowEnergyDescriptor, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QLowEnergyDescriptor(void *, int);}
static void release_QLowEnergyDescriptor(void *sipCppV, int)
{
    delete reinterpret_cast< ::QLowEnergyDescriptor *>(sipCppV);
}


extern "C" {static void *array_QLowEnergyDescriptor(Py_ssize_t);}
static void *array_QLowEnergyDescriptor(Py_ssize_t sipNrElem)
{
    return new ::QLowEnergyDescriptor[sipNrElem];
}


extern "C" {static void array_delete_QLowEnergyDescriptor(void *);}
static void array_delete_QLowEnergyDescriptor(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLowEnergyDescriptor *>(sipCpp);
}


extern "C" {static void assign_QLowEnergyDescriptor(void *, Py_ssize_t, void *);}
static void assign_QLowEnergyDescriptor(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QLowEnergyDescriptor *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QLowEnergyDescriptor *>(sipSrc);
}


extern "C" {static void *copy_QLowEnergyDescriptor(const void *, Py_ssize_t);}
static void *copy_QLowEnergyDescriptor(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QLowEnergyDescriptor(reinterpret_cast<const ::QLowEnergyDescriptor *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QLowEnergyDescriptor(sipSimpleWrapper *);}
static void dealloc_QLowEnergyDescriptor(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLowEnergyDescriptor(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QLowEnergyDescriptor(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLowEnergyDescriptor(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QLowEnergyDescriptor *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QLowEnergyDescriptor();

            return sipCpp;
        }
    }

    {
        const ::QLowEnergyDescriptor* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QLowEnergyDescriptor, &a0))
        {
            sipCpp = new ::QLowEnergyDescriptor(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QLowEnergyDescriptor[] = {
    {(void *)slot_QLowEnergyDescriptor___eq__, eq_slot},
    {(void *)slot_QLowEnergyDescriptor___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QLowEnergyDescriptor[] = {
    {sipName_isValid, meth_QLowEnergyDescriptor_isValid, METH_VARARGS, doc_QLowEnergyDescriptor_isValid},
    {sipName_name, meth_QLowEnergyDescriptor_name, METH_VARARGS, doc_QLowEnergyDescriptor_name},
    {sipName_type, meth_QLowEnergyDescriptor_type, METH_VARARGS, doc_QLowEnergyDescriptor_type},
    {sipName_uuid, meth_QLowEnergyDescriptor_uuid, METH_VARARGS, doc_QLowEnergyDescriptor_uuid},
    {sipName_value, meth_QLowEnergyDescriptor_value, METH_VARARGS, doc_QLowEnergyDescriptor_value}
};

PyDoc_STRVAR(doc_QLowEnergyDescriptor, "\1QLowEnergyDescriptor()\n"
"QLowEnergyDescriptor(other: QLowEnergyDescriptor)");


sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyDescriptor = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLowEnergyDescriptor,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QLowEnergyDescriptor,
        {0, 0, 1},
        5, methods_QLowEnergyDescriptor,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLowEnergyDescriptor,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QLowEnergyDescriptor,
    init_type_QLowEnergyDescriptor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLowEnergyDescriptor,
    assign_QLowEnergyDescriptor,
    array_QLowEnergyDescriptor,
    copy_QLowEnergyDescriptor,
    release_QLowEnergyDescriptor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLowEnergyDescriptor,
    sizeof (::QLowEnergyDescriptor),
};
