/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPdf.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 32 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
// The capsule destructor for a QModelRoleData array.
static void qpycore_gc_modelroledata(PyObject *mrd_obj);
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 271 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfdocumentrenderoptions.sip"
#include <qpdfdocumentrenderoptions.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdflink.sip"
#include <qpdflink.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdflinkmodel.sip"
#include <qpdflinkmodel.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfselection.sip"
#include <qpdfselection.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfsearchmodel.sip"
#include <qpdfsearchmodel.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfpagerenderer.sip"
#include <qpdfpagerenderer.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfdocument.sip"
#include <qpdfdocument.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfbookmarkmodel.sip"
#include <qpdfbookmarkmodel.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtPdf[] = {
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'P', 'd', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'O', 'p', 't', 'i', 'o', 'n', 's', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'F', 'l', 'a', 'g', '>', 0,
    'Q', 'P', 'd', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'O', 'p', 't', 'i', 'o', 'n', 's', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'F', 'l', 'a', 'g', 0,
    'Q', 'P', 'd', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'O', 'p', 't', 'i', 'o', 'n', 's', ':', ':', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'P', 'd', 'f', 'P', 'a', 'g', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    'Q', 'P', 'd', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'M', 'e', 't', 'a', 'D', 'a', 't', 'a', 'F', 'i', 'e', 'l', 'd', 0,
    'Q', 'P', 'd', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'P', 'a', 'g', 'e', 'M', 'o', 'd', 'e', 'l', 'R', 'o', 'l', 'e', 0,
    'Q', 'P', 'd', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'S', 'c', 'h', 'e', 'm', 'e', 0,
    'P', 'y', 'Q', 't', '6', '.', 's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 'P', 'd', 'f', 'B', 'o', 'o', 'k', 'm', 'a', 'r', 'k', 'M', 'o', 'd', 'e', 'l', ':', ':', 'R', 'o', 'l', 'e', 0,
    'f', 'o', 'r', 'w', 'a', 'r', 'd', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'P', 'd', 'f', 'S', 'e', 'a', 'r', 'c', 'h', 'M', 'o', 'd', 'e', 'l', ':', ':', 'R', 'o', 'l', 'e', 0,
    'Q', 'P', 'd', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'b', 'a', 'c', 'k', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'r', 'a', 'g', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'r', 'o', 'p', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    'D', 'a', 't', 'a', 'N', 'o', 't', 'Y', 'e', 't', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'Q', 'P', 'd', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'P', 'd', 'f', 'L', 'i', 'n', 'k', 'M', 'o', 'd', 'e', 'l', ':', ':', 'R', 'o', 'l', 'e', 0,
    'g', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'A', 't', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'S', 't', 'r', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'P', 'a', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'Z', 'o', 'o', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'I', 'n', 'c', 'o', 'r', 'r', 'e', 'c', 't', 'P', 'a', 's', 's', 'w', 'o', 'r', 'd', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'F', 'i', 'l', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'P', 'd', 'f', 'B', 'o', 'o', 'k', 'm', 'a', 'r', 'k', 'M', 'o', 'd', 'e', 'l', 0,
    'Q', 'P', 'd', 'f', 'P', 'a', 'g', 'e', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'o', 'r', 0,
    'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'p', 'a', 'g', 'e', 'I', 'n', 'd', 'e', 'x', 'F', 'o', 'r', 'L', 'a', 'b', 'e', 'l', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 's', 'e', 't', 'I', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'e', 'd', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    'M', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'D', 'a', 't', 'e', 0,
    'Q', 'P', 'd', 'f', 'P', 'a', 'g', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'f', 'o', 'r', 'w', 'a', 'r', 'd', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'p', 'a', 'g', 'e', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'a', 'g', 'e', 'M', 'o', 'd', 'e', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'O', 'p', 't', 'i', 'm', 'i', 'z', 'e', 'd', 'F', 'o', 'r', 'L', 'c', 'd', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'd', 'f', 'L', 'i', 'n', 'k', '>', 0,
    'Q', 'P', 'd', 'f', 'S', 'e', 'a', 'r', 'c', 'h', 'M', 'o', 'd', 'e', 'l', 0,
    'c', 'a', 'n', 'D', 'r', 'o', 'p', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'c', 'o', 'p', 'y', 'T', 'o', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'a', 's', 's', 'w', 'o', 'r', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'S', 'e', 'a', 'r', 'c', 'h', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'S', 'i', 'n', 'g', 'l', 'e', 'T', 'h', 'r', 'e', 'a', 'd', 'e', 'd', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'F', 'l', 'a', 'g', 's', 0,
    'C', 'o', 'n', 't', 'e', 'x', 't', 'B', 'e', 'f', 'o', 'r', 'e', 0,
    'F', 'o', 'r', 'c', 'e', 'H', 'a', 'l', 'f', 't', 'o', 'n', 'e', 0,
    'M', 'u', 'l', 't', 'i', 'T', 'h', 'r', 'e', 'a', 'd', 'e', 'd', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'R', 'e', 'c', 't', 'F', '>', 0,
    'Q', 'P', 'd', 'f', 'L', 'i', 'n', 'k', 'M', 'o', 'd', 'e', 'l', 0,
    'Q', 'P', 'd', 'f', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'b', 'a', 'c', 'k', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'c', 'l', 'e', 'a', 'r', 'I', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'B', 'e', 'f', 'o', 'r', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'p', 'a', 'g', 'e', 'P', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'r', 'e', 's', 'u', 'l', 't', 'A', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'r', 'e', 's', 'u', 'l', 't', 's', 'O', 'n', 'P', 'a', 'g', 'e', 0,
    's', 'e', 't', 'H', 'e', 'a', 'd', 'e', 'r', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'e', 'd', 'S', 'i', 'z', 'e', 0,
    's', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'l', 'o', 'c', 'k', 'w', 'i', 's', 'e', '1', '8', '0', 0,
    'C', 'l', 'o', 'c', 'k', 'w', 'i', 's', 'e', '2', '7', '0', 0,
    'C', 'o', 'n', 't', 'e', 'x', 't', 'A', 'f', 't', 'e', 'r', 0,
    'C', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'D', 'a', 't', 'e', 0,
    'F', 'i', 'l', 'e', 'N', 'o', 't', 'F', 'o', 'u', 'n', 'd', 0,
    'I', 'm', 'a', 'g', 'e', 'A', 'l', 'i', 'a', 's', 'e', 'd', 0,
    'Q', 'P', 'd', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'c', 'a', 'n', 'F', 'e', 't', 'c', 'h', 'M', 'o', 'r', 'e', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'A', 'f', 't', 'e', 'r', 0,
    'c', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'r', 'o', 'p', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'g', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'A', 'n', 'n', 'o', 't', 'a', 't', 'i', 'o', 'n', 's', 0,
    'C', 'l', 'o', 'c', 'k', 'w', 'i', 's', 'e', '9', '0', 0,
    'I', 'n', 'd', 'e', 'x', 'O', 'n', 'P', 'a', 'g', 'e', 0,
    'P', 'a', 't', 'h', 'A', 'l', 'i', 'a', 's', 'e', 'd', 0,
    'P', 'y', 'Q', 't', '6', '.', 'Q', 't', 'P', 'd', 'f', 0,
    'T', 'e', 'x', 't', 'A', 'l', 'i', 'a', 's', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'P', 'a', 'g', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'Z', 'o', 'o', 'm', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'h', 'a', 's', 'C', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 0,
    'p', 'a', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'F', 'l', 'a', 'g', 's', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'P', 'a', 'g', 'e', 0,
    's', 'e', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'P', 'a', 's', 's', 'w', 'o', 'r', 'd', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'g', 'e', 't', 'A', 'l', 'l', 'T', 'e', 'x', 't', 0,
    'h', 'e', 'a', 'd', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'i', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 's', 0,
    'r', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'R', 'o', 'w', 's', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'S', 'i', 'z', 'e', 0,
    's', 't', 'a', 'r', 't', 'I', 'n', 'd', 'e', 'x', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'G', 'r', 'a', 'y', 's', 'c', 'a', 'l', 'e', 0,
    'U', 'n', 'l', 'o', 'a', 'd', 'i', 'n', 'g', 0,
    'f', 'e', 't', 'c', 'h', 'M', 'o', 'r', 'e', 0,
    'm', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 's', 0,
    'm', 'u', 'l', 't', 'i', 'D', 'a', 't', 'a', 0,
    'p', 'a', 'g', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'p', 'a', 'g', 'e', 'L', 'a', 'b', 'e', 'l', 0,
    'p', 'a', 'g', 'e', 'M', 'o', 'd', 'e', 'l', 0,
    'r', 'o', 'l', 'e', 'N', 'a', 'm', 'e', 's', 0,
    'K', 'e', 'y', 'w', 'o', 'r', 'd', 's', 0,
    'P', 'r', 'o', 'd', 'u', 'c', 'e', 'r', 0,
    'Q', 'P', 'd', 'f', 'L', 'i', 'n', 'k', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'e', 'n', 'd', 'I', 'n', 'd', 'e', 'x', 0,
    'i', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'm', 'e', 't', 'a', 'D', 'a', 't', 'a', 0,
    'm', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'p', 'a', 's', 's', 'w', 'o', 'r', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'r', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    't', 'o', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'C', 'r', 'e', 'a', 't', 'o', 'r', 0,
    'L', 'o', 'a', 'd', 'i', 'n', 'g', 0,
    'S', 'u', 'b', 'j', 'e', 'c', 't', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    '_', '_', 'l', 'e', 'n', '_', '_', 0,
    'f', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'o', 'p', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 0,
    's', 'i', 'b', 'l', 'i', 'n', 'g', 0,
    'A', 'u', 't', 'h', 'o', 'r', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    'b', 'o', 'u', 'n', 'd', 's', 0,
    'j', 'u', 'm', 'p', 'e', 'd', 0,
    'l', 'i', 'n', 'k', 'A', 't', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 0,
    'r', 'e', 'v', 'e', 'r', 't', 0,
    's', 't', 'a', 't', 'u', 's', 0,
    's', 'u', 'b', 'm', 'i', 't', 0,
    'u', 'p', 'd', 'a', 't', 'e', 0,
    'L', 'e', 'v', 'e', 'l', 0,
    'N', 'o', 'n', 'e', '_', 0,
    'R', 'e', 'a', 'd', 'y', 0,
    'T', 'i', 't', 'l', 'e', 0,
    'b', 'u', 'd', 'd', 'y', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'c', 'l', 'o', 's', 'e', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'i', 'n', 'd', 'e', 'x', 0,
    'm', 'a', 't', 'c', 'h', 0,
    'N', 'u', 'l', 'l', 0,
    'b', 'a', 'c', 'k', 0,
    'd', 'a', 't', 'a', 0,
    'j', 'u', 'm', 'p', 0,
    'l', 'o', 'a', 'd', 0,
    'm', 'o', 'd', 'e', 0,
    'p', 'a', 'g', 'e', 0,
    's', 'o', 'r', 't', 0,
    's', 'p', 'a', 'n', 0,
    's', 'w', 'a', 'p', 0,
    't', 'e', 'x', 't', 0,
    'z', 'o', 'o', 'm', 0,
    'U', 'r', 'l', 0,
    'u', 'r', 'l', 0,
};

void sipVH_QtPdf_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

void sipVH_QtPdf_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtPdf_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtPdf_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

bool sipVH_QtPdf_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtPdf_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QModelIndex sipVH_QtPdf_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1, const ::QModelIndex& a2)
{
    ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iiN", a0, a1, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

int sipVH_QtPdf_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtPdf_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "Ni", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtPdf_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, const ::QVariant& a1, int a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NNi", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR, a2);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtPdf_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::Orientation a1, int a2)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iFi", a0, a1, sipType_Qt_Orientation, a2);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtPdf_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::Orientation a1, const ::QVariant& a2, int a3)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iFNi", a0, a1, sipType_Qt_Orientation, new ::QVariant(a2), sipType_QVariant, SIP_NULLPTR, a3);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

QMap<int, ::QVariant> sipVH_QtPdf_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    QMap<int, ::QVariant> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QMap_1800_0100QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtPdf_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, const QMap<int, ::QVariant>& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new QMap<int, ::QVariant>(a1), sipType_QMap_1800_0100QVariant, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QStringList sipVH_QtPdf_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QStringList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QStringList, &sipRes);

    return sipRes;
}

::QMimeData* sipVH_QtPdf_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndexList& a0)
{
    ::QMimeData* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndexList(a0), sipType_QList_0100QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QMimeData, &sipRes);

    return sipRes;
}

bool sipVH_QtPdf_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1, const ::QModelIndex& a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iiN", a0, a1, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtPdf_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);
}

::Qt::ItemFlags sipVH_QtPdf_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::Qt::ItemFlags sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QFlags_0100Qt_ItemFlag, &sipRes);

    return sipRes;
}

void sipVH_QtPdf_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::SortOrder a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iF", a0, a1, sipType_Qt_SortOrder);
}

::QModelIndex sipVH_QtPdf_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

::QModelIndexList sipVH_QtPdf_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1, const ::QVariant& a2, int a3, ::Qt::MatchFlags a4)
{
    ::QModelIndexList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NiNiN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, new ::QVariant(a2), sipType_QVariant, SIP_NULLPTR, a3, new ::Qt::MatchFlags(a4), sipType_QFlags_0100Qt_MatchFlag, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QModelIndex, &sipRes);

    return sipRes;
}

::QSize sipVH_QtPdf_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

bool sipVH_QtPdf_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::Qt::DropActions sipVH_QtPdf_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::Qt::DropActions sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QFlags_0100Qt_DropAction, &sipRes);

    return sipRes;
}

QHash<int, ::QByteArray> sipVH_QtPdf_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    QHash<int, ::QByteArray> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QHash_1800_0100QByteArray, &sipRes);

    return sipRes;
}

void sipVH_QtPdf_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

bool sipVH_QtPdf_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DFiiN", const_cast< ::QMimeData *>(a0), sipType_QMimeData, SIP_NULLPTR, a1, sipType_Qt_DropAction, a2, a3, new ::QModelIndex(a4), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtPdf_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1, int a2, const ::QModelIndex& a3, int a4)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NiiNi", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, a2, new ::QModelIndex(a3), sipType_QModelIndex, SIP_NULLPTR, a4);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtPdf_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtPdf_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, ::QModelRoleDataSpan a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new ::QModelRoleDataSpan(a1), sipType_QModelRoleDataSpan, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QPdfDocument(void **);}
static const sipTypeDef *sipSubClass_QPdfDocument(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdfdocument.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QPdfBookmarkModel, &sipType_QPdfBookmarkModel, -1, 1},
        {sipName_QPdfDocument, &sipType_QPdfDocument, -1, 2},
    #if QT_VERSION >= 0x060600
        {sipName_QPdfLinkModel, &sipType_QPdfLinkModel, -1, 3},
    #else
        {0, 0, -1, 3},
    #endif
        {sipName_QPdfPageNavigator, &sipType_QPdfPageNavigator, -1, 4},
        {sipName_QPdfPageRenderer, &sipType_QPdfPageRenderer, -1, 5},
        {sipName_QPdfSearchModel, &sipType_QPdfSearchModel, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 612 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfcmodule.cpp"

    return sipType;
}
static sipEnumTypeDef enumTypes[] = {
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPdfBookmarkModel__Role, SIP_NULLPTR, 0}, SIP_ENUM_INT_ENUM, sipNameNr_Role, 3, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPdfDocument__Error, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Error, 5, 7, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPdfDocument__MetaDataField, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_MetaDataField, 5, 8, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPdfDocument__PageModelRole, SIP_NULLPTR, 0}, SIP_ENUM_INT_ENUM, sipNameNr_PageModelRole, 5, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPdfDocument__Status, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Status, 5, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPdfDocumentRenderOptions__RenderFlag, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_RenderFlag, 10, 8, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPdfDocumentRenderOptions__Rotation, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Rotation, 10, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPdfLinkModel__Role, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Role, 14, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPdfPageRenderer__RenderMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_RenderMode, 17, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPdfSearchModel__Role, SIP_NULLPTR, 0}, SIP_ENUM_INT_ENUM, sipNameNr_Role, 19, 5, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtPdf[] = {
    &sipTypeDef_QtPdf_QFlags_0100QPdfDocumentRenderOptions_RenderFlag.mtd_base,
    &sipTypeDef_QtPdf_QList_0100QPdfLink.mtd_base,
    &sipTypeDef_QtPdf_QList_0100QRectF.mtd_base,
    &sipTypeDef_QtPdf_QPdfBookmarkModel.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtPdf_QPdfDocument.ctd_base,
    &enumTypes[1].etd_base,
    &enumTypes[2].etd_base,
    &enumTypes[3].etd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtPdf_QPdfDocumentRenderOptions.ctd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &sipTypeDef_QtPdf_QPdfLink.ctd_base,
    &sipTypeDef_QtPdf_QPdfLinkModel.ctd_base,
    &enumTypes[7].etd_base,
    &sipTypeDef_QtPdf_QPdfPageNavigator.ctd_base,
    &sipTypeDef_QtPdf_QPdfPageRenderer.ctd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtPdf_QPdfSearchModel.ctd_base,
    &enumTypes[9].etd_base,
    &sipTypeDef_QtPdf_QPdfSelection.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"QPdfDocumentRenderOptions::RenderFlags", "QFlags<QPdfDocumentRenderOptions::RenderFlag>"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtPdf_QtCore[] = {
    {"QAbstractItemModel"},
    {"QAbstractListModel"},
    {"QChildEvent"},
    {"QEvent"},
    {"QFlags<Qt::DropAction>"},
    {"QFlags<Qt::ItemFlag>"},
    {"QFlags<Qt::MatchFlag>"},
    {"QHash<int,QByteArray>"},
    {"QIODevice"},
    {"QList<QModelIndex>"},
    {"QMap<int,QVariant>"},
    {"QMetaMethod"},
    {"QMimeData"},
    {"QModelIndex"},
    {"QModelRoleDataSpan"},
    {"QObject"},
    {"QPointF"},
    {"QRect"},
    {"QRectF"},
    {"QSize"},
    {"QSizeF"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {"Qt::DropAction"},
    {"Qt::Orientation"},
    {"Qt::SortOrder"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtPdf_QtCore[] = {
    {"PyQt6"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_QtPdf_QtGui[] = {
    {"QClipboard::Mode"},
    {"QImage"},
    {"QList<QPolygonF>"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt6.QtCore", sipImportedTypes_QtPdf_QtCore, sipImportedVirtErrorHandlers_QtPdf_QtCore, SIP_NULLPTR},
    {"PyQt6.QtGui", sipImportedTypes_QtPdf_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QPdfDocument, {15, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtPdf = {
    SIP_NULLPTR,
    8,
    sipNameNr_PyQt6_QtPdf,
    0,
    sipStrings_QtPdf,
    importsTable,
    22,
    sipExportedTypes_QtPdf,
    SIP_NULLPTR,
    1,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtPdf;

sip_qt_metaobject_func sip_QtPdf_qt_metaobject;
sip_qt_metacall_func sip_QtPdf_qt_metacall;
sip_qt_metacast_func sip_QtPdf_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtPdf()
#else
PyMODINIT_FUNC PyInit_QtPdf()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt6.QtPdf",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt6.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt6.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtPdf = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt6.sip._C_API"));

    if (sipAPI_QtPdf == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtPdf, 13, 8, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtPdf_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtPdf_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtPdf_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtPdf_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtPdf, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }
    qMetaTypeId<::QPdfSearchModel::Role>();
    qMetaTypeId<::QPdfPageRenderer::RenderMode>();
    qMetaTypeId<::QPdfLinkModel::Role>();
    qMetaTypeId<::QPdfDocumentRenderOptions::RenderFlag>();
    qMetaTypeId<::QPdfDocumentRenderOptions::Rotation>();
    qMetaTypeId<::QPdfDocument::PageModelRole>();
    qMetaTypeId<::QPdfDocument::MetaDataField>();
    qMetaTypeId<::QPdfDocument::Error>();
    qMetaTypeId<::QPdfDocument::Status>();
    qMetaTypeId<::QPdfBookmarkModel::Role>();
    qMetaTypeId<QFlags< ::QPdfDocumentRenderOptions::RenderFlag>>();

    return sipModule;
}
