/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNfc.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefnfctextrecord.sip"
#include <qndefnfctextrecord.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcTextRecord.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qndefrecord.sip"
#include <qndefrecord.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcTextRecord.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcTextRecord.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNdefNfcTextRecord.cpp"


PyDoc_STRVAR(doc_QNdefNfcTextRecord_locale, "locale(self) -> str");

extern "C" {static PyObject *meth_QNdefNfcTextRecord_locale(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcTextRecord_locale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcTextRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcTextRecord, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->locale());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcTextRecord, sipName_locale, doc_QNdefNfcTextRecord_locale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcTextRecord_setLocale, "setLocale(self, locale: str|None)");

extern "C" {static PyObject *meth_QNdefNfcTextRecord_setLocale(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcTextRecord_setLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QNdefNfcTextRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNdefNfcTextRecord, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLocale(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcTextRecord, sipName_setLocale, doc_QNdefNfcTextRecord_setLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcTextRecord_text, "text(self) -> str");

extern "C" {static PyObject *meth_QNdefNfcTextRecord_text(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcTextRecord_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcTextRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcTextRecord, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcTextRecord, sipName_text, doc_QNdefNfcTextRecord_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcTextRecord_setText, "setText(self, text: str|None)");

extern "C" {static PyObject *meth_QNdefNfcTextRecord_setText(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcTextRecord_setText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QNdefNfcTextRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNdefNfcTextRecord, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcTextRecord, sipName_setText, doc_QNdefNfcTextRecord_setText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcTextRecord_encoding, "encoding(self) -> QNdefNfcTextRecord.Encoding");

extern "C" {static PyObject *meth_QNdefNfcTextRecord_encoding(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcTextRecord_encoding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNdefNfcTextRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNdefNfcTextRecord, &sipCpp))
        {
            ::QNdefNfcTextRecord::Encoding sipRes;

            sipRes = sipCpp->encoding();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QNdefNfcTextRecord_Encoding);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcTextRecord, sipName_encoding, doc_QNdefNfcTextRecord_encoding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNdefNfcTextRecord_setEncoding, "setEncoding(self, encoding: QNdefNfcTextRecord.Encoding)");

extern "C" {static PyObject *meth_QNdefNfcTextRecord_setEncoding(PyObject *, PyObject *);}
static PyObject *meth_QNdefNfcTextRecord_setEncoding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNdefNfcTextRecord::Encoding a0;
        ::QNdefNfcTextRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QNdefNfcTextRecord, &sipCpp, sipType_QNdefNfcTextRecord_Encoding, &a0))
        {
            sipCpp->setEncoding(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNdefNfcTextRecord, sipName_setEncoding, doc_QNdefNfcTextRecord_setEncoding);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QNdefNfcTextRecord(void *, const sipTypeDef *);}
static void *cast_QNdefNfcTextRecord(void *sipCppV, const sipTypeDef *targetType)
{
    ::QNdefNfcTextRecord *sipCpp = reinterpret_cast< ::QNdefNfcTextRecord *>(sipCppV);

    if (targetType == sipType_QNdefNfcTextRecord)
        return sipCppV;

    if (targetType == sipType_QNdefRecord)
        return static_cast< ::QNdefRecord *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNdefNfcTextRecord(void *, int);}
static void release_QNdefNfcTextRecord(void *sipCppV, int)
{
    delete reinterpret_cast< ::QNdefNfcTextRecord *>(sipCppV);
}


extern "C" {static void *array_QNdefNfcTextRecord(Py_ssize_t);}
static void *array_QNdefNfcTextRecord(Py_ssize_t sipNrElem)
{
    return new ::QNdefNfcTextRecord[sipNrElem];
}


extern "C" {static void array_delete_QNdefNfcTextRecord(void *);}
static void array_delete_QNdefNfcTextRecord(void *sipCpp)
{
    delete[] reinterpret_cast< ::QNdefNfcTextRecord *>(sipCpp);
}


extern "C" {static void assign_QNdefNfcTextRecord(void *, Py_ssize_t, void *);}
static void assign_QNdefNfcTextRecord(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QNdefNfcTextRecord *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QNdefNfcTextRecord *>(sipSrc);
}


extern "C" {static void *copy_QNdefNfcTextRecord(const void *, Py_ssize_t);}
static void *copy_QNdefNfcTextRecord(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QNdefNfcTextRecord(reinterpret_cast<const ::QNdefNfcTextRecord *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QNdefNfcTextRecord(sipSimpleWrapper *);}
static void dealloc_QNdefNfcTextRecord(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNdefNfcTextRecord(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QNdefNfcTextRecord(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QNdefNfcTextRecord(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QNdefNfcTextRecord *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QNdefNfcTextRecord();

            return sipCpp;
        }
    }

    {
        const ::QNdefRecord* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QNdefRecord, &a0))
        {
            sipCpp = new ::QNdefNfcTextRecord(*a0);

            return sipCpp;
        }
    }

    {
        const ::QNdefNfcTextRecord* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QNdefNfcTextRecord, &a0))
        {
            sipCpp = new ::QNdefNfcTextRecord(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QNdefNfcTextRecord[] = {{14, 255, 1}};


static PyMethodDef methods_QNdefNfcTextRecord[] = {
    {sipName_encoding, meth_QNdefNfcTextRecord_encoding, METH_VARARGS, doc_QNdefNfcTextRecord_encoding},
    {sipName_locale, meth_QNdefNfcTextRecord_locale, METH_VARARGS, doc_QNdefNfcTextRecord_locale},
    {sipName_setEncoding, meth_QNdefNfcTextRecord_setEncoding, METH_VARARGS, doc_QNdefNfcTextRecord_setEncoding},
    {sipName_setLocale, meth_QNdefNfcTextRecord_setLocale, METH_VARARGS, doc_QNdefNfcTextRecord_setLocale},
    {sipName_setText, meth_QNdefNfcTextRecord_setText, METH_VARARGS, doc_QNdefNfcTextRecord_setText},
    {sipName_text, meth_QNdefNfcTextRecord_text, METH_VARARGS, doc_QNdefNfcTextRecord_text}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QNdefNfcTextRecord[] = {
    {sipName_Utf8, static_cast<int>(::QNdefNfcTextRecord::Utf8)},
    {sipName_Utf16, static_cast<int>(::QNdefNfcTextRecord::Utf16)},
    {0, 0}
};

PyDoc_STRVAR(doc_QNdefNfcTextRecord, "\1QNdefNfcTextRecord()\n"
"QNdefNfcTextRecord(other: QNdefRecord)\n"
"QNdefNfcTextRecord(a0: QNdefNfcTextRecord)");


sipClassTypeDef sipTypeDef_QtNfc_QNdefNfcTextRecord = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNdefNfcTextRecord,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QNdefNfcTextRecord,
        {0, 0, 1},
        6, methods_QNdefNfcTextRecord,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QNdefNfcTextRecord, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QNdefNfcTextRecord,
    -1,
    -1,
    supers_QNdefNfcTextRecord,
    SIP_NULLPTR,
    init_type_QNdefNfcTextRecord,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QNdefNfcTextRecord,
    assign_QNdefNfcTextRecord,
    array_QNdefNfcTextRecord,
    copy_QNdefNfcTextRecord,
    release_QNdefNfcTextRecord,
    cast_QNdefNfcTextRecord,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QNdefNfcTextRecord,
    sizeof (::QNdefNfcTextRecord),
};
