/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qnmeasatelliteinfosource.sip"
#include <qnmeasatelliteinfosource.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeosatelliteinfo.sip"
#include <qgeosatelliteinfo.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 789 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeosatelliteinfosource.sip"
#include <qgeosatelliteinfosource.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 27 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQNmeaSatelliteInfoSource.cpp"


class sipQNmeaSatelliteInfoSource : public ::QNmeaSatelliteInfoSource
{
public:
    sipQNmeaSatelliteInfoSource(::QNmeaSatelliteInfoSource::UpdateMode, ::QObject*);
    virtual ~sipQNmeaSatelliteInfoSource();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QNmeaSatelliteInfoSource::SatelliteInfoParseStatus parseSatelliteInfoFromNmea(const char*, int, QList< ::QGeoSatelliteInfo>&, ::QGeoSatelliteInfo::SatelliteSystem&) SIP_OVERRIDE;
    ::QGeoSatelliteInfo::SatelliteSystem parseSatellitesInUseFromNmea(const char*, int, ::QList<int>&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void setUpdateInterval(int) SIP_OVERRIDE;
    int minimumUpdateInterval() const SIP_OVERRIDE;
    ::QGeoSatelliteInfoSource::Error error() const SIP_OVERRIDE;
    void startUpdates() SIP_OVERRIDE;
    void stopUpdates() SIP_OVERRIDE;
    void requestUpdate(int) SIP_OVERRIDE;
    bool setBackendProperty(const ::QString&, const ::QVariant&) SIP_OVERRIDE;
    ::QVariant backendProperty(const ::QString&) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQNmeaSatelliteInfoSource(const sipQNmeaSatelliteInfoSource &);
    sipQNmeaSatelliteInfoSource &operator = (const sipQNmeaSatelliteInfoSource &);

    char sipPyMethods[17];
};

sipQNmeaSatelliteInfoSource::sipQNmeaSatelliteInfoSource(::QNmeaSatelliteInfoSource::UpdateMode a0, ::QObject*a1): ::QNmeaSatelliteInfoSource(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQNmeaSatelliteInfoSource::~sipQNmeaSatelliteInfoSource()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQNmeaSatelliteInfoSource::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtPositioning_qt_metaobject(sipPySelf, sipType_QNmeaSatelliteInfoSource);

    return ::QNmeaSatelliteInfoSource::metaObject();
}

int sipQNmeaSatelliteInfoSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QNmeaSatelliteInfoSource::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtPositioning_qt_metacall(sipPySelf, sipType_QNmeaSatelliteInfoSource, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQNmeaSatelliteInfoSource::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtPositioning_qt_metacast(sipPySelf, sipType_QNmeaSatelliteInfoSource, _clname, &sipCpp) ? sipCpp : ::QNmeaSatelliteInfoSource::qt_metacast(_clname));
}

::QNmeaSatelliteInfoSource::SatelliteInfoParseStatus sipQNmeaSatelliteInfoSource::parseSatelliteInfoFromNmea(const char*a0, int a1, QList< ::QGeoSatelliteInfo>& a2, ::QGeoSatelliteInfo::SatelliteSystem& a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_parseSatelliteInfoFromNmea);

    if (!sipMeth)
        return ::QNmeaSatelliteInfoSource::parseSatelliteInfoFromNmea(a0, a1, a2, a3);

    extern ::QNmeaSatelliteInfoSource::SatelliteInfoParseStatus sipVH_QtPositioning_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const char*, int, QList< ::QGeoSatelliteInfo>&, ::QGeoSatelliteInfo::SatelliteSystem&);

    return sipVH_QtPositioning_26(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QGeoSatelliteInfo::SatelliteSystem sipQNmeaSatelliteInfoSource::parseSatellitesInUseFromNmea(const char*a0, int a1, ::QList<int>& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_parseSatellitesInUseFromNmea);

    if (!sipMeth)
        return ::QNmeaSatelliteInfoSource::parseSatellitesInUseFromNmea(a0, a1, a2);

    extern ::QGeoSatelliteInfo::SatelliteSystem sipVH_QtPositioning_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const char*, int, ::QList<int>&);

    return sipVH_QtPositioning_25(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQNmeaSatelliteInfoSource::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QNmeaSatelliteInfoSource::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtPositioning_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPositioning_0(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNmeaSatelliteInfoSource::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QNmeaSatelliteInfoSource::connectNotify(a0);
        return;
    }

    extern void sipVH_QtPositioning_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPositioning_0(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNmeaSatelliteInfoSource::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QNmeaSatelliteInfoSource::customEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPositioning_1(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNmeaSatelliteInfoSource::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QNmeaSatelliteInfoSource::childEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtPositioning_2(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNmeaSatelliteInfoSource::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QNmeaSatelliteInfoSource::timerEvent(a0);
        return;
    }

    extern void sipVH_QtPositioning_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtPositioning_3(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQNmeaSatelliteInfoSource::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QNmeaSatelliteInfoSource::eventFilter(a0, a1);

    extern bool sipVH_QtPositioning_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtPositioning_4(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQNmeaSatelliteInfoSource::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QNmeaSatelliteInfoSource::event(a0);

    extern bool sipVH_QtPositioning_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtPositioning_5(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNmeaSatelliteInfoSource::setUpdateInterval(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_setUpdateInterval);

    if (!sipMeth)
    {
        ::QNmeaSatelliteInfoSource::setUpdateInterval(a0);
        return;
    }

    extern void sipVH_QtPositioning_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtPositioning_16(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQNmeaSatelliteInfoSource::minimumUpdateInterval() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumUpdateInterval);

    if (!sipMeth)
        return ::QNmeaSatelliteInfoSource::minimumUpdateInterval();

    extern int sipVH_QtPositioning_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPositioning_20(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QGeoSatelliteInfoSource::Error sipQNmeaSatelliteInfoSource::error() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_error);

    if (!sipMeth)
        return ::QNmeaSatelliteInfoSource::error();

    extern ::QGeoSatelliteInfoSource::Error sipVH_QtPositioning_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPositioning_23(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQNmeaSatelliteInfoSource::startUpdates()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_startUpdates);

    if (!sipMeth)
    {
        ::QNmeaSatelliteInfoSource::startUpdates();
        return;
    }

    extern void sipVH_QtPositioning_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtPositioning_22(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQNmeaSatelliteInfoSource::stopUpdates()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_stopUpdates);

    if (!sipMeth)
    {
        ::QNmeaSatelliteInfoSource::stopUpdates();
        return;
    }

    extern void sipVH_QtPositioning_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtPositioning_22(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQNmeaSatelliteInfoSource::requestUpdate(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_requestUpdate);

    if (!sipMeth)
    {
        ::QNmeaSatelliteInfoSource::requestUpdate(a0);
        return;
    }

    extern void sipVH_QtPositioning_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtPositioning_16(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQNmeaSatelliteInfoSource::setBackendProperty(const ::QString& a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_setBackendProperty);

    if (!sipMeth)
        return ::QNmeaSatelliteInfoSource::setBackendProperty(a0, a1);

    extern bool sipVH_QtPositioning_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, const ::QVariant&);

    return sipVH_QtPositioning_14(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QVariant sipQNmeaSatelliteInfoSource::backendProperty(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[16]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_backendProperty);

    if (!sipMeth)
        return ::QNmeaSatelliteInfoSource::backendProperty(a0);

    extern ::QVariant sipVH_QtPositioning_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtPositioning_15(sipGILState, sipImportedVirtErrorHandlers_QtPositioning_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_updateMode, "updateMode(self) -> QNmeaSatelliteInfoSource.UpdateMode");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_updateMode(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_updateMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp))
        {
            ::QNmeaSatelliteInfoSource::UpdateMode sipRes;

            sipRes = sipCpp->updateMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QNmeaSatelliteInfoSource_UpdateMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_updateMode, doc_QNmeaSatelliteInfoSource_updateMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_setDevice, "setDevice(self, source: QIODevice|None)");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_setDevice(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_setDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp, sipType_QIODevice, &a0))
        {
            sipCpp->setDevice(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_setDevice, doc_QNmeaSatelliteInfoSource_setDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_device, "device(self) -> QIODevice|None");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_device(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_device(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp))
        {
            ::QIODevice*sipRes;

            sipRes = sipCpp->device();

            return sipConvertFromType(sipRes, sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_device, doc_QNmeaSatelliteInfoSource_device);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_setUpdateInterval, "setUpdateInterval(self, msec: int)");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_setUpdateInterval(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_setUpdateInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QNmeaSatelliteInfoSource::setUpdateInterval(a0) : sipCpp->setUpdateInterval(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_setUpdateInterval, doc_QNmeaSatelliteInfoSource_setUpdateInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_minimumUpdateInterval, "minimumUpdateInterval(self) -> int");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_minimumUpdateInterval(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_minimumUpdateInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QNmeaSatelliteInfoSource::minimumUpdateInterval() : sipCpp->minimumUpdateInterval());

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_minimumUpdateInterval, doc_QNmeaSatelliteInfoSource_minimumUpdateInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_error, "error(self) -> QGeoSatelliteInfoSource.Error");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_error(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp))
        {
            ::QGeoSatelliteInfoSource::Error sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QNmeaSatelliteInfoSource::error() : sipCpp->error());

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoSatelliteInfoSource_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_error, doc_QNmeaSatelliteInfoSource_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_setBackendProperty, "setBackendProperty(self, name: str|None, value: Any) -> bool");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_setBackendProperty(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_setBackendProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QNmeaSatelliteInfoSource::setBackendProperty(*a0, *a1) : sipCpp->setBackendProperty(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_setBackendProperty, doc_QNmeaSatelliteInfoSource_setBackendProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_backendProperty, "backendProperty(self, name: str|None) -> Any");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_backendProperty(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_backendProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QNmeaSatelliteInfoSource::backendProperty(*a0) : sipCpp->backendProperty(*a0)));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_backendProperty, doc_QNmeaSatelliteInfoSource_backendProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_startUpdates, "startUpdates(self)");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_startUpdates(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_startUpdates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QNmeaSatelliteInfoSource::startUpdates() : sipCpp->startUpdates());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_startUpdates, doc_QNmeaSatelliteInfoSource_startUpdates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_stopUpdates, "stopUpdates(self)");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_stopUpdates(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_stopUpdates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QNmeaSatelliteInfoSource::stopUpdates() : sipCpp->stopUpdates());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_stopUpdates, doc_QNmeaSatelliteInfoSource_stopUpdates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_requestUpdate, "requestUpdate(self, timeout: int = 0)");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_requestUpdate(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_requestUpdate(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0 = 0;
        ::QNmeaSatelliteInfoSource *sipCpp;

        static const char *sipKwdList[] = {
            sipName_timeout,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QNmeaSatelliteInfoSource::requestUpdate(a0) : sipCpp->requestUpdate(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_requestUpdate, doc_QNmeaSatelliteInfoSource_requestUpdate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_parseSatellitesInUseFromNmea, "parseSatellitesInUseFromNmea(self, data: bytes, size: int, pnrsInUse: Iterable[int]) -> QGeoSatelliteInfo.SatelliteSystem");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_parseSatellitesInUseFromNmea(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_parseSatellitesInUseFromNmea(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const char* a0;
        int a1;
        ::QList<int>* a2;
        int a2State = 0;
        ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "psiJ1", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp, &a0, &a1, sipType_QList_1800, &a2, &a2State))
        {
            ::QGeoSatelliteInfo::SatelliteSystem sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QNmeaSatelliteInfoSource::parseSatellitesInUseFromNmea(a0, a1, *a2) : sipCpp->parseSatellitesInUseFromNmea(a0, a1, *a2));
            sipReleaseType(a2, sipType_QList_1800, a2State);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoSatelliteInfo_SatelliteSystem);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_parseSatellitesInUseFromNmea, doc_QNmeaSatelliteInfoSource_parseSatellitesInUseFromNmea);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource_parseSatelliteInfoFromNmea, "parseSatelliteInfoFromNmea(self, data: bytes, size: int, infos: Iterable[QGeoSatelliteInfo]) -> (QNmeaSatelliteInfoSource.SatelliteInfoParseStatus, QGeoSatelliteInfo.SatelliteSystem)");

extern "C" {static PyObject *meth_QNmeaSatelliteInfoSource_parseSatelliteInfoFromNmea(PyObject *, PyObject *);}
static PyObject *meth_QNmeaSatelliteInfoSource_parseSatelliteInfoFromNmea(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QNmeaSatelliteInfoSource)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const char* a0;
        int a1;
        QList< ::QGeoSatelliteInfo>* a2;
        int a2State = 0;
        ::QGeoSatelliteInfo::SatelliteSystem a3;
        ::QNmeaSatelliteInfoSource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "psiJ1", &sipSelf, sipType_QNmeaSatelliteInfoSource, &sipCpp, &a0, &a1, sipType_QList_0100QGeoSatelliteInfo, &a2, &a2State))
        {
            ::QNmeaSatelliteInfoSource::SatelliteInfoParseStatus sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QNmeaSatelliteInfoSource::parseSatelliteInfoFromNmea(a0, a1, *a2, a3) : sipCpp->parseSatelliteInfoFromNmea(a0, a1, *a2, a3));
            sipReleaseType(a2, sipType_QList_0100QGeoSatelliteInfo, a2State);

            return sipBuildResult(0, "(FF)", sipRes, sipType_QNmeaSatelliteInfoSource_SatelliteInfoParseStatus, a3, sipType_QGeoSatelliteInfo_SatelliteSystem);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNmeaSatelliteInfoSource, sipName_parseSatelliteInfoFromNmea, doc_QNmeaSatelliteInfoSource_parseSatelliteInfoFromNmea);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QNmeaSatelliteInfoSource(void *, const sipTypeDef *);}
static void *cast_QNmeaSatelliteInfoSource(void *sipCppV, const sipTypeDef *targetType)
{
    ::QNmeaSatelliteInfoSource *sipCpp = reinterpret_cast< ::QNmeaSatelliteInfoSource *>(sipCppV);

    if (targetType == sipType_QNmeaSatelliteInfoSource)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGeoSatelliteInfoSource)->ctd_cast(static_cast< ::QGeoSatelliteInfoSource *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNmeaSatelliteInfoSource(void *, int);}
static void release_QNmeaSatelliteInfoSource(void *sipCppV, int)
{
    ::QNmeaSatelliteInfoSource *sipCpp = reinterpret_cast< ::QNmeaSatelliteInfoSource *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QNmeaSatelliteInfoSource(sipSimpleWrapper *);}
static void dealloc_QNmeaSatelliteInfoSource(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQNmeaSatelliteInfoSource *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNmeaSatelliteInfoSource(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QNmeaSatelliteInfoSource(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QNmeaSatelliteInfoSource(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQNmeaSatelliteInfoSource *sipCpp = SIP_NULLPTR;

    {
        ::QNmeaSatelliteInfoSource::UpdateMode a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|JH", sipType_QNmeaSatelliteInfoSource_UpdateMode, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQNmeaSatelliteInfoSource(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QNmeaSatelliteInfoSource[] = {{23, 255, 1}};


static PyMethodDef methods_QNmeaSatelliteInfoSource[] = {
    {sipName_backendProperty, meth_QNmeaSatelliteInfoSource_backendProperty, METH_VARARGS, doc_QNmeaSatelliteInfoSource_backendProperty},
    {sipName_device, meth_QNmeaSatelliteInfoSource_device, METH_VARARGS, doc_QNmeaSatelliteInfoSource_device},
    {sipName_error, meth_QNmeaSatelliteInfoSource_error, METH_VARARGS, doc_QNmeaSatelliteInfoSource_error},
    {sipName_minimumUpdateInterval, meth_QNmeaSatelliteInfoSource_minimumUpdateInterval, METH_VARARGS, doc_QNmeaSatelliteInfoSource_minimumUpdateInterval},
    {sipName_parseSatelliteInfoFromNmea, meth_QNmeaSatelliteInfoSource_parseSatelliteInfoFromNmea, METH_VARARGS, doc_QNmeaSatelliteInfoSource_parseSatelliteInfoFromNmea},
    {sipName_parseSatellitesInUseFromNmea, meth_QNmeaSatelliteInfoSource_parseSatellitesInUseFromNmea, METH_VARARGS, doc_QNmeaSatelliteInfoSource_parseSatellitesInUseFromNmea},
    {sipName_requestUpdate, SIP_MLMETH_CAST(meth_QNmeaSatelliteInfoSource_requestUpdate), METH_VARARGS|METH_KEYWORDS, doc_QNmeaSatelliteInfoSource_requestUpdate},
    {sipName_setBackendProperty, meth_QNmeaSatelliteInfoSource_setBackendProperty, METH_VARARGS, doc_QNmeaSatelliteInfoSource_setBackendProperty},
    {sipName_setDevice, meth_QNmeaSatelliteInfoSource_setDevice, METH_VARARGS, doc_QNmeaSatelliteInfoSource_setDevice},
    {sipName_setUpdateInterval, meth_QNmeaSatelliteInfoSource_setUpdateInterval, METH_VARARGS, doc_QNmeaSatelliteInfoSource_setUpdateInterval},
    {sipName_startUpdates, meth_QNmeaSatelliteInfoSource_startUpdates, METH_VARARGS, doc_QNmeaSatelliteInfoSource_startUpdates},
    {sipName_stopUpdates, meth_QNmeaSatelliteInfoSource_stopUpdates, METH_VARARGS, doc_QNmeaSatelliteInfoSource_stopUpdates},
    {sipName_updateMode, meth_QNmeaSatelliteInfoSource_updateMode, METH_VARARGS, doc_QNmeaSatelliteInfoSource_updateMode}
};


extern "C" {static PyObject *varget_QNmeaSatelliteInfoSource_SimulationUpdateInterval(void *, PyObject *, PyObject *);}
static PyObject *varget_QNmeaSatelliteInfoSource_SimulationUpdateInterval(void *, PyObject *, PyObject *)
{
    ::QString*sipVal;

    sipVal = &::QNmeaSatelliteInfoSource::SimulationUpdateInterval;

    return sipConvertFromType(sipVal, sipType_QString, SIP_NULLPTR);
}


extern "C" {static int varset_QNmeaSatelliteInfoSource_SimulationUpdateInterval(void *, PyObject *, PyObject *);}
static int varset_QNmeaSatelliteInfoSource_SimulationUpdateInterval(void *, PyObject *sipPy, PyObject *)
{
    ::QString*sipVal;
    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast< ::QString *>(sipForceConvertToType(sipPy, sipType_QString, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    ::QNmeaSatelliteInfoSource::SimulationUpdateInterval = *sipVal;

    sipReleaseType(sipVal, sipType_QString, sipValState);

    return 0;
}

sipVariableDef variables_QNmeaSatelliteInfoSource[] = {
    {ClassVariable, sipName_SimulationUpdateInterval, (PyMethodDef *)varget_QNmeaSatelliteInfoSource_SimulationUpdateInterval, (PyMethodDef *)varset_QNmeaSatelliteInfoSource_SimulationUpdateInterval, SIP_NULLPTR, SIP_NULLPTR},
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QNmeaSatelliteInfoSource[] = {
    {sipName_NotParsed, static_cast<int>(::QNmeaSatelliteInfoSource::NotParsed)},
    {sipName_PartiallyParsed, static_cast<int>(::QNmeaSatelliteInfoSource::PartiallyParsed)},
    {sipName_FullyParsed, static_cast<int>(::QNmeaSatelliteInfoSource::FullyParsed)},
    {sipName_RealTimeMode, static_cast<int>(::QNmeaSatelliteInfoSource::UpdateMode::RealTimeMode)},
    {sipName_SimulationMode, static_cast<int>(::QNmeaSatelliteInfoSource::UpdateMode::SimulationMode)},
    {0, 0}
};

PyDoc_STRVAR(doc_QNmeaSatelliteInfoSource, "\1QNmeaSatelliteInfoSource(mode: QNmeaSatelliteInfoSource.UpdateMode, parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QNmeaSatelliteInfoSource = {
    &::QNmeaSatelliteInfoSource::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPositioning_QNmeaSatelliteInfoSource = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNmeaSatelliteInfoSource,
        SIP_NULLPTR,
        &plugin_QNmeaSatelliteInfoSource,
    },
    {
        sipNameNr_QNmeaSatelliteInfoSource,
        {0, 0, 1},
        13, methods_QNmeaSatelliteInfoSource,
        1, variables_QNmeaSatelliteInfoSource,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QNmeaSatelliteInfoSource, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QNmeaSatelliteInfoSource,
    -1,
    -1,
    supers_QNmeaSatelliteInfoSource,
    SIP_NULLPTR,
    init_type_QNmeaSatelliteInfoSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QNmeaSatelliteInfoSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QNmeaSatelliteInfoSource,
    cast_QNmeaSatelliteInfoSource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QNmeaSatelliteInfoSource),
};
