/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtHelp.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtHelp/qhelpsearchquerywidget.sip"
#include <qhelpsearchquerywidget.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 217 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 220 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 223 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 226 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 229 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 232 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 235 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 238 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 241 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 244 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 247 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 250 "/build/pyqt6/src/pyqt6-6.11.0/build/QtHelp/sipQtHelpQHelpSearchQueryWidget.cpp"


class sipQHelpSearchQueryWidget : public ::QHelpSearchQueryWidget
{
public:
    sipQHelpSearchQueryWidget(::QWidget*);
    virtual ~sipQHelpSearchQueryWidget();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEnterEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQHelpSearchQueryWidget(const sipQHelpSearchQueryWidget &);
    sipQHelpSearchQueryWidget &operator = (const sipQHelpSearchQueryWidget &);

    char sipPyMethods[44];
};

sipQHelpSearchQueryWidget::sipQHelpSearchQueryWidget(::QWidget*a0): ::QHelpSearchQueryWidget(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQHelpSearchQueryWidget::~sipQHelpSearchQueryWidget()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQHelpSearchQueryWidget::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtHelp_qt_metaobject(sipPySelf, sipType_QHelpSearchQueryWidget);

    return ::QHelpSearchQueryWidget::metaObject();
}

int sipQHelpSearchQueryWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QHelpSearchQueryWidget::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtHelp_qt_metacall(sipPySelf, sipType_QHelpSearchQueryWidget, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQHelpSearchQueryWidget::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtHelp_qt_metacast(sipPySelf, sipType_QHelpSearchQueryWidget, _clname, &sipCpp) ? sipCpp : ::QHelpSearchQueryWidget::qt_metacast(_clname));
}

void sipQHelpSearchQueryWidget::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtHelp_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtHelp_30(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::connectNotify(a0);
        return;
    }

    extern void sipVH_QtHelp_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtHelp_30(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::customEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtHelp_29(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::childEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtHelp_28(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::timerEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtHelp_27(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQHelpSearchQueryWidget::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::eventFilter(a0, a1);

    extern bool sipVH_QtHelp_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtHelp_26(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQHelpSearchQueryWidget::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::event(a0);

    extern bool sipVH_QtHelp_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtHelp_25(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQHelpSearchQueryWidget::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::metric(a0);

    extern int sipVH_QtHelp_64(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtHelp_64(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQHelpSearchQueryWidget::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::paintEngine();

    extern ::QPaintEngine* sipVH_QtHelp_63(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtHelp_63(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQHelpSearchQueryWidget::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::devType();

    extern int sipVH_QtHelp_62(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtHelp_62(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQHelpSearchQueryWidget::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::setVisible(a0);
        return;
    }

    extern void sipVH_QtHelp_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtHelp_61(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQHelpSearchQueryWidget::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::sizeHint();

    extern ::QSize sipVH_QtHelp_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtHelp_35(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQHelpSearchQueryWidget::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::minimumSizeHint();

    extern ::QSize sipVH_QtHelp_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtHelp_35(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQHelpSearchQueryWidget::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::heightForWidth(a0);

    extern int sipVH_QtHelp_60(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtHelp_60(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtHelp_59(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtHelp_59(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtHelp_59(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtHelp_59(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_58(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtHelp_58(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtHelp_57(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtHelp_57(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtHelp_56(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::enterEvent(::QEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::enterEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_55(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEnterEvent*);

    sipVH_QtHelp_55(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtHelp_29(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::paintEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtHelp_54(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::moveEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_53(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtHelp_53(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_52(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtHelp_52(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::closeEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_51(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtHelp_51(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtHelp_50(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtHelp_49(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::actionEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtHelp_48(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtHelp_47(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtHelp_46(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtHelp_45(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::dropEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_44(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtHelp_44(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::showEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_43(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtHelp_43(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::hideEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_42(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtHelp_42(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchQueryWidget::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtHelp_41(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQHelpSearchQueryWidget::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[38]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtHelp_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtHelp_40(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQHelpSearchQueryWidget::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::focusNextPrevChild(a0);

    extern bool sipVH_QtHelp_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtHelp_39(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQHelpSearchQueryWidget::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[40]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::hasHeightForWidth();

    extern bool sipVH_QtHelp_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtHelp_7(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQHelpSearchQueryWidget::nativeEvent(const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[41], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtHelp_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, ::qintptr*);

    return sipVH_QtHelp_38(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipQHelpSearchQueryWidget::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[42]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QHelpSearchQueryWidget::sharedPainter();

    extern ::QPainter* sipVH_QtHelp_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtHelp_37(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQHelpSearchQueryWidget::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[43]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QHelpSearchQueryWidget::initPainter(a0);
        return;
    }

    extern void sipVH_QtHelp_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtHelp_36(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QHelpSearchQueryWidget_expandExtendedSearch, "expandExtendedSearch(self)");

extern "C" {static PyObject *meth_QHelpSearchQueryWidget_expandExtendedSearch(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchQueryWidget_expandExtendedSearch(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpSearchQueryWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchQueryWidget, &sipCpp))
        {
            sipCpp->expandExtendedSearch();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchQueryWidget, sipName_expandExtendedSearch, doc_QHelpSearchQueryWidget_expandExtendedSearch);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchQueryWidget_collapseExtendedSearch, "collapseExtendedSearch(self)");

extern "C" {static PyObject *meth_QHelpSearchQueryWidget_collapseExtendedSearch(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchQueryWidget_collapseExtendedSearch(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpSearchQueryWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchQueryWidget, &sipCpp))
        {
            sipCpp->collapseExtendedSearch();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchQueryWidget, sipName_collapseExtendedSearch, doc_QHelpSearchQueryWidget_collapseExtendedSearch);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *meth_QHelpSearchQueryWidget_focusInEvent(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchQueryWidget_focusInEvent(PyObject *, PyObject *)
{

    sipNoMethod(SIP_NULLPTR, sipName_QHelpSearchQueryWidget, sipName_focusInEvent, SIP_NULLPTR);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *meth_QHelpSearchQueryWidget_changeEvent(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchQueryWidget_changeEvent(PyObject *, PyObject *)
{

    sipNoMethod(SIP_NULLPTR, sipName_QHelpSearchQueryWidget, sipName_changeEvent, SIP_NULLPTR);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchQueryWidget_isCompactMode, "isCompactMode(self) -> bool");

extern "C" {static PyObject *meth_QHelpSearchQueryWidget_isCompactMode(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchQueryWidget_isCompactMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpSearchQueryWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchQueryWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isCompactMode();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchQueryWidget, sipName_isCompactMode, doc_QHelpSearchQueryWidget_isCompactMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchQueryWidget_setCompactMode, "setCompactMode(self, on: bool)");

extern "C" {static PyObject *meth_QHelpSearchQueryWidget_setCompactMode(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchQueryWidget_setCompactMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QHelpSearchQueryWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QHelpSearchQueryWidget, &sipCpp, &a0))
        {
            sipCpp->setCompactMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchQueryWidget, sipName_setCompactMode, doc_QHelpSearchQueryWidget_setCompactMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchQueryWidget_searchInput, "searchInput(self) -> str");

extern "C" {static PyObject *meth_QHelpSearchQueryWidget_searchInput(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchQueryWidget_searchInput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpSearchQueryWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchQueryWidget, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->searchInput());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchQueryWidget, sipName_searchInput, doc_QHelpSearchQueryWidget_searchInput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchQueryWidget_setSearchInput, "setSearchInput(self, searchInput: str|None)");

extern "C" {static PyObject *meth_QHelpSearchQueryWidget_setSearchInput(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchQueryWidget_setSearchInput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpSearchQueryWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpSearchQueryWidget, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setSearchInput(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchQueryWidget, sipName_setSearchInput, doc_QHelpSearchQueryWidget_setSearchInput);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QHelpSearchQueryWidget(void *, const sipTypeDef *);}
static void *cast_QHelpSearchQueryWidget(void *sipCppV, const sipTypeDef *targetType)
{
    ::QHelpSearchQueryWidget *sipCpp = reinterpret_cast< ::QHelpSearchQueryWidget *>(sipCppV);

    if (targetType == sipType_QHelpSearchQueryWidget)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWidget)->ctd_cast(static_cast< ::QWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHelpSearchQueryWidget(void *, int);}
static void release_QHelpSearchQueryWidget(void *sipCppV, int)
{
    ::QHelpSearchQueryWidget *sipCpp = reinterpret_cast< ::QHelpSearchQueryWidget *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QHelpSearchQueryWidget(Py_ssize_t);}
static void *array_QHelpSearchQueryWidget(Py_ssize_t sipNrElem)
{
    return new ::QHelpSearchQueryWidget[sipNrElem];
}


extern "C" {static void array_delete_QHelpSearchQueryWidget(void *);}
static void array_delete_QHelpSearchQueryWidget(void *sipCpp)
{
    delete[] reinterpret_cast< ::QHelpSearchQueryWidget *>(sipCpp);
}


extern "C" {static void dealloc_QHelpSearchQueryWidget(sipSimpleWrapper *);}
static void dealloc_QHelpSearchQueryWidget(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQHelpSearchQueryWidget *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHelpSearchQueryWidget(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QHelpSearchQueryWidget(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QHelpSearchQueryWidget(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQHelpSearchQueryWidget *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQHelpSearchQueryWidget(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QHelpSearchQueryWidget[] = {{12, 2, 1}};


static PyMethodDef methods_QHelpSearchQueryWidget[] = {
    {sipName_changeEvent, meth_QHelpSearchQueryWidget_changeEvent, METH_VARARGS, SIP_NULLPTR},
    {sipName_collapseExtendedSearch, meth_QHelpSearchQueryWidget_collapseExtendedSearch, METH_VARARGS, doc_QHelpSearchQueryWidget_collapseExtendedSearch},
    {sipName_expandExtendedSearch, meth_QHelpSearchQueryWidget_expandExtendedSearch, METH_VARARGS, doc_QHelpSearchQueryWidget_expandExtendedSearch},
    {sipName_focusInEvent, meth_QHelpSearchQueryWidget_focusInEvent, METH_VARARGS, SIP_NULLPTR},
    {sipName_isCompactMode, meth_QHelpSearchQueryWidget_isCompactMode, METH_VARARGS, doc_QHelpSearchQueryWidget_isCompactMode},
    {sipName_searchInput, meth_QHelpSearchQueryWidget_searchInput, METH_VARARGS, doc_QHelpSearchQueryWidget_searchInput},
    {sipName_setCompactMode, meth_QHelpSearchQueryWidget_setCompactMode, METH_VARARGS, doc_QHelpSearchQueryWidget_setCompactMode},
    {sipName_setSearchInput, meth_QHelpSearchQueryWidget_setSearchInput, METH_VARARGS, doc_QHelpSearchQueryWidget_setSearchInput}
};

PyDoc_STRVAR(doc_QHelpSearchQueryWidget, "\1QHelpSearchQueryWidget(parent: QWidget|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QHelpSearchQueryWidget[] = {
    {"search()", "\1search(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QHelpSearchQueryWidget = {
    &::QHelpSearchQueryWidget::staticMetaObject,
    signals_QHelpSearchQueryWidget,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchQueryWidget = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHelpSearchQueryWidget,
        SIP_NULLPTR,
        &plugin_QHelpSearchQueryWidget,
    },
    {
        sipNameNr_QHelpSearchQueryWidget,
        {0, 0, 1},
        8, methods_QHelpSearchQueryWidget,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QHelpSearchQueryWidget,
    -1,
    -1,
    supers_QHelpSearchQueryWidget,
    SIP_NULLPTR,
    init_type_QHelpSearchQueryWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHelpSearchQueryWidget,
    SIP_NULLPTR,
    array_QHelpSearchQueryWidget,
    SIP_NULLPTR,
    release_QHelpSearchQueryWidget,
    cast_QHelpSearchQueryWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QHelpSearchQueryWidget,
    sizeof (::QHelpSearchQueryWidget),
};
