/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiodecoder.sip"
#include <qaudiodecoder.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudioformat.sip"
#include <qaudioformat.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiobuffer.sip"
#include <qaudiobuffer.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQAudioDecoder.cpp"


class sipQAudioDecoder : public ::QAudioDecoder
{
public:
    sipQAudioDecoder(::QObject*);
    virtual ~sipQAudioDecoder();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAudioDecoder(const sipQAudioDecoder &);
    sipQAudioDecoder &operator = (const sipQAudioDecoder &);

    char sipPyMethods[7];
};

sipQAudioDecoder::sipQAudioDecoder(::QObject*a0): ::QAudioDecoder(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioDecoder::~sipQAudioDecoder()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAudioDecoder::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QAudioDecoder);

    return ::QAudioDecoder::metaObject();
}

int sipQAudioDecoder::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAudioDecoder::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QAudioDecoder, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAudioDecoder::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QAudioDecoder, _clname, &sipCpp) ? sipCpp : ::QAudioDecoder::qt_metacast(_clname));
}

bool sipQAudioDecoder::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAudioDecoder::event(a0);

    extern bool sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAudioDecoder::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAudioDecoder::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_4(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAudioDecoder::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAudioDecoder::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_3(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioDecoder::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAudioDecoder::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioDecoder::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAudioDecoder::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_1(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioDecoder::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAudioDecoder::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioDecoder::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAudioDecoder::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAudioDecoder_isSupported, "isSupported(self) -> bool");

extern "C" {static PyObject *meth_QAudioDecoder_isSupported(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_isSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSupported();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_isSupported, doc_QAudioDecoder_isSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_isDecoding, "isDecoding(self) -> bool");

extern "C" {static PyObject *meth_QAudioDecoder_isDecoding(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_isDecoding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDecoding();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_isDecoding, doc_QAudioDecoder_isDecoding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_source, "source(self) -> QUrl");

extern "C" {static PyObject *meth_QAudioDecoder_source(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_source(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->source());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_source, doc_QAudioDecoder_source);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_setSource, "setSource(self, fileName: QUrl)");

extern "C" {static PyObject *meth_QAudioDecoder_setSource(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_setSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioDecoder, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setSource(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_setSource, doc_QAudioDecoder_setSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_sourceDevice, "sourceDevice(self) -> QIODevice|None");

extern "C" {static PyObject *meth_QAudioDecoder_sourceDevice(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_sourceDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            ::QIODevice*sipRes;

            sipRes = sipCpp->sourceDevice();

            return sipConvertFromType(sipRes, sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_sourceDevice, doc_QAudioDecoder_sourceDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_setSourceDevice, "setSourceDevice(self, device: QIODevice|None)");

extern "C" {static PyObject *meth_QAudioDecoder_setSourceDevice(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_setSourceDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QAudioDecoder, &sipCpp, sipType_QIODevice, &a0))
        {
            sipCpp->setSourceDevice(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_setSourceDevice, doc_QAudioDecoder_setSourceDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_error, "error(self) -> QAudioDecoder.Error");

extern "C" {static PyObject *meth_QAudioDecoder_error(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            ::QAudioDecoder::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAudioDecoder_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_error, doc_QAudioDecoder_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QAudioDecoder_errorString(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_errorString, doc_QAudioDecoder_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_read, "read(self) -> QAudioBuffer");

extern "C" {static PyObject *meth_QAudioDecoder_read(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_read(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            ::QAudioBuffer*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = new ::QAudioBuffer(sipCpp->read());
            Py_END_ALLOW_THREADS

            return sipConvertFromNewType(sipRes, sipType_QAudioBuffer, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_read, doc_QAudioDecoder_read);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_bufferAvailable, "bufferAvailable(self) -> bool");

extern "C" {static PyObject *meth_QAudioDecoder_bufferAvailable(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_bufferAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->bufferAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_bufferAvailable, doc_QAudioDecoder_bufferAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_position, "position(self) -> int");

extern "C" {static PyObject *meth_QAudioDecoder_position(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->position();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_position, doc_QAudioDecoder_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_duration, "duration(self) -> int");

extern "C" {static PyObject *meth_QAudioDecoder_duration(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_duration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->duration();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_duration, doc_QAudioDecoder_duration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_audioFormat, "audioFormat(self) -> QAudioFormat");

extern "C" {static PyObject *meth_QAudioDecoder_audioFormat(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_audioFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            ::QAudioFormat*sipRes;

            sipRes = new ::QAudioFormat(sipCpp->audioFormat());

            return sipConvertFromNewType(sipRes, sipType_QAudioFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_audioFormat, doc_QAudioDecoder_audioFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_setAudioFormat, "setAudioFormat(self, format: QAudioFormat)");

extern "C" {static PyObject *meth_QAudioDecoder_setAudioFormat(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_setAudioFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioFormat* a0;
        ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioDecoder, &sipCpp, sipType_QAudioFormat, &a0))
        {
            sipCpp->setAudioFormat(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_setAudioFormat, doc_QAudioDecoder_setAudioFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_start, "start(self)");

extern "C" {static PyObject *meth_QAudioDecoder_start(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            sipCpp->start();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_start, doc_QAudioDecoder_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoder_stop, "stop(self)");

extern "C" {static PyObject *meth_QAudioDecoder_stop(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoder_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioDecoder *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoder, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoder, sipName_stop, doc_QAudioDecoder_stop);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAudioDecoder(void *, const sipTypeDef *);}
static void *cast_QAudioDecoder(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAudioDecoder *sipCpp = reinterpret_cast< ::QAudioDecoder *>(sipCppV);

    if (targetType == sipType_QAudioDecoder)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAudioDecoder(void *, int);}
static void release_QAudioDecoder(void *sipCppV, int)
{
    ::QAudioDecoder *sipCpp = reinterpret_cast< ::QAudioDecoder *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QAudioDecoder(Py_ssize_t);}
static void *array_QAudioDecoder(Py_ssize_t sipNrElem)
{
    return new ::QAudioDecoder[sipNrElem];
}


extern "C" {static void array_delete_QAudioDecoder(void *);}
static void array_delete_QAudioDecoder(void *sipCpp)
{
    delete[] reinterpret_cast< ::QAudioDecoder *>(sipCpp);
}


extern "C" {static void dealloc_QAudioDecoder(sipSimpleWrapper *);}
static void dealloc_QAudioDecoder(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAudioDecoder *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAudioDecoder(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAudioDecoder(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAudioDecoder(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAudioDecoder *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQAudioDecoder(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAudioDecoder[] = {{7, 0, 1}};


static PyMethodDef methods_QAudioDecoder[] = {
    {sipName_audioFormat, meth_QAudioDecoder_audioFormat, METH_VARARGS, doc_QAudioDecoder_audioFormat},
    {sipName_bufferAvailable, meth_QAudioDecoder_bufferAvailable, METH_VARARGS, doc_QAudioDecoder_bufferAvailable},
    {sipName_duration, meth_QAudioDecoder_duration, METH_VARARGS, doc_QAudioDecoder_duration},
    {sipName_error, meth_QAudioDecoder_error, METH_VARARGS, doc_QAudioDecoder_error},
    {sipName_errorString, meth_QAudioDecoder_errorString, METH_VARARGS, doc_QAudioDecoder_errorString},
    {sipName_isDecoding, meth_QAudioDecoder_isDecoding, METH_VARARGS, doc_QAudioDecoder_isDecoding},
    {sipName_isSupported, meth_QAudioDecoder_isSupported, METH_VARARGS, doc_QAudioDecoder_isSupported},
    {sipName_position, meth_QAudioDecoder_position, METH_VARARGS, doc_QAudioDecoder_position},
    {sipName_read, meth_QAudioDecoder_read, METH_VARARGS, doc_QAudioDecoder_read},
    {sipName_setAudioFormat, meth_QAudioDecoder_setAudioFormat, METH_VARARGS, doc_QAudioDecoder_setAudioFormat},
    {sipName_setSource, meth_QAudioDecoder_setSource, METH_VARARGS, doc_QAudioDecoder_setSource},
    {sipName_setSourceDevice, meth_QAudioDecoder_setSourceDevice, METH_VARARGS, doc_QAudioDecoder_setSourceDevice},
    {sipName_source, meth_QAudioDecoder_source, METH_VARARGS, doc_QAudioDecoder_source},
    {sipName_sourceDevice, meth_QAudioDecoder_sourceDevice, METH_VARARGS, doc_QAudioDecoder_sourceDevice},
    {sipName_start, meth_QAudioDecoder_start, METH_VARARGS, doc_QAudioDecoder_start},
    {sipName_stop, meth_QAudioDecoder_stop, METH_VARARGS, doc_QAudioDecoder_stop}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QAudioDecoder[] = {
    {sipName_NoError, static_cast<int>(::QAudioDecoder::NoError)},
    {sipName_ResourceError, static_cast<int>(::QAudioDecoder::ResourceError)},
    {sipName_FormatError, static_cast<int>(::QAudioDecoder::FormatError)},
    {sipName_AccessDeniedError, static_cast<int>(::QAudioDecoder::AccessDeniedError)},
    {sipName_NotSupportedError, static_cast<int>(::QAudioDecoder::NotSupportedError)},
    {0, 0}
};

PyDoc_STRVAR(doc_QAudioDecoder, "\1QAudioDecoder(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QAudioDecoder[] = {
    {"formatChanged(QAudioFormat)", "\1formatChanged(self, format: QAudioFormat)", SIP_NULLPTR, SIP_NULLPTR},
    {"durationChanged(qint64)", "\1durationChanged(self, duration: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged(qint64)", "\1positionChanged(self, position: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"sourceChanged()", "\1sourceChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"isDecodingChanged(bool)", "\1isDecodingChanged(self, a0: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"finished()", "\1finished(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"bufferReady()", "\1bufferReady(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"bufferAvailableChanged(bool)", "\1bufferAvailableChanged(self, a0: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QAudioDecoder::Error)", "\1error(self, error: QAudioDecoder.Error)", &methods_QAudioDecoder[3], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QAudioDecoder = {
    &::QAudioDecoder::staticMetaObject,
    signals_QAudioDecoder,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QAudioDecoder = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAudioDecoder,
        SIP_NULLPTR,
        &plugin_QAudioDecoder,
    },
    {
        sipNameNr_QAudioDecoder,
        {0, 0, 1},
        16, methods_QAudioDecoder,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QAudioDecoder, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAudioDecoder,
    -1,
    -1,
    supers_QAudioDecoder,
    SIP_NULLPTR,
    init_type_QAudioDecoder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAudioDecoder,
    SIP_NULLPTR,
    array_QAudioDecoder,
    SIP_NULLPTR,
    release_QAudioDecoder,
    cast_QAudioDecoder,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAudioDecoder,
    sizeof (::QAudioDecoder),
};
