/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTabletEvent.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTabletEvent.cpp"
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpointingdevice.sip"
#include <qpointingdevice.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTabletEvent.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTabletEvent.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTabletEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTabletEvent.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTabletEvent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTabletEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qeventpoint.sip"
#include <qeventpoint.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTabletEvent.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTabletEvent.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qinputdevice.sip"
#include <qinputdevice.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQTabletEvent.cpp"


class sipQTabletEvent : public ::QTabletEvent
{
public:
    sipQTabletEvent(::QEvent::Type, const ::QPointingDevice*, const ::QPointF&, const ::QPointF&, ::qreal, float, float, float, ::qreal, float, ::Qt::KeyboardModifiers, ::Qt::MouseButton, ::Qt::MouseButtons);
    virtual ~sipQTabletEvent();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool isEndEvent() const SIP_OVERRIDE;
    bool isUpdateEvent() const SIP_OVERRIDE;
    bool isBeginEvent() const SIP_OVERRIDE;
    ::QTabletEvent* clone() const SIP_OVERRIDE;
    void setAccepted(bool) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQTabletEvent(const sipQTabletEvent &);
    sipQTabletEvent &operator = (const sipQTabletEvent &);

    char sipPyMethods[5];
};

sipQTabletEvent::sipQTabletEvent(::QEvent::Type a0, const ::QPointingDevice*a1, const ::QPointF& a2, const ::QPointF& a3, ::qreal a4, float a5, float a6, float a7, ::qreal a8, float a9, ::Qt::KeyboardModifiers a10, ::Qt::MouseButton a11, ::Qt::MouseButtons a12): ::QTabletEvent(a0, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQTabletEvent::~sipQTabletEvent()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

bool sipQTabletEvent::isEndEvent() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isEndEvent);

    if (!sipMeth)
        return ::QTabletEvent::isEndEvent();

    extern bool sipVH_QtGui_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_54(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQTabletEvent::isUpdateEvent() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isUpdateEvent);

    if (!sipMeth)
        return ::QTabletEvent::isUpdateEvent();

    extern bool sipVH_QtGui_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_54(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQTabletEvent::isBeginEvent() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isBeginEvent);

    if (!sipMeth)
        return ::QTabletEvent::isBeginEvent();

    extern bool sipVH_QtGui_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_54(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QTabletEvent* sipQTabletEvent::clone() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_clone);

    if (!sipMeth)
        return ::QTabletEvent::clone();

    extern ::QTabletEvent* sipVH_QtGui_60(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_60(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQTabletEvent::setAccepted(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_setAccepted);

    if (!sipMeth)
    {
        ::QTabletEvent::setAccepted(a0);
        return;
    }

    extern void sipVH_QtGui_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtGui_25(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QTabletEvent_pressure, "pressure(self) -> float");

extern "C" {static PyObject *meth_QTabletEvent_pressure(PyObject *, PyObject *);}
static PyObject *meth_QTabletEvent_pressure(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTabletEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTabletEvent, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->pressure();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTabletEvent, sipName_pressure, doc_QTabletEvent_pressure);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTabletEvent_rotation, "rotation(self) -> float");

extern "C" {static PyObject *meth_QTabletEvent_rotation(PyObject *, PyObject *);}
static PyObject *meth_QTabletEvent_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTabletEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTabletEvent, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->rotation();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTabletEvent, sipName_rotation, doc_QTabletEvent_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTabletEvent_z, "z(self) -> float");

extern "C" {static PyObject *meth_QTabletEvent_z(PyObject *, PyObject *);}
static PyObject *meth_QTabletEvent_z(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTabletEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTabletEvent, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->z();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTabletEvent, sipName_z, doc_QTabletEvent_z);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTabletEvent_tangentialPressure, "tangentialPressure(self) -> float");

extern "C" {static PyObject *meth_QTabletEvent_tangentialPressure(PyObject *, PyObject *);}
static PyObject *meth_QTabletEvent_tangentialPressure(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTabletEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTabletEvent, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->tangentialPressure();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTabletEvent, sipName_tangentialPressure, doc_QTabletEvent_tangentialPressure);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTabletEvent_xTilt, "xTilt(self) -> float");

extern "C" {static PyObject *meth_QTabletEvent_xTilt(PyObject *, PyObject *);}
static PyObject *meth_QTabletEvent_xTilt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTabletEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTabletEvent, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->xTilt();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTabletEvent, sipName_xTilt, doc_QTabletEvent_xTilt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTabletEvent_yTilt, "yTilt(self) -> float");

extern "C" {static PyObject *meth_QTabletEvent_yTilt(PyObject *, PyObject *);}
static PyObject *meth_QTabletEvent_yTilt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTabletEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTabletEvent, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->yTilt();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTabletEvent, sipName_yTilt, doc_QTabletEvent_yTilt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTabletEvent_clone, "clone(self) -> QTabletEvent|None");

extern "C" {static PyObject *meth_QTabletEvent_clone(PyObject *, PyObject *);}
static PyObject *meth_QTabletEvent_clone(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QTabletEvent)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QTabletEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTabletEvent, &sipCpp))
        {
            ::QTabletEvent*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QTabletEvent::clone() : sipCpp->clone());

            return sipConvertFromType(sipRes, sipType_QTabletEvent, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTabletEvent, sipName_clone, doc_QTabletEvent_clone);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QTabletEvent(void *, const sipTypeDef *);}
static void *cast_QTabletEvent(void *sipCppV, const sipTypeDef *targetType)
{
    ::QTabletEvent *sipCpp = reinterpret_cast< ::QTabletEvent *>(sipCppV);

    if (targetType == sipType_QTabletEvent)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QSinglePointEvent)->ctd_cast(static_cast< ::QSinglePointEvent *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QTabletEvent(void *, int);}
static void release_QTabletEvent(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQTabletEvent *>(sipCppV);
    else
        delete reinterpret_cast< ::QTabletEvent *>(sipCppV);
}


extern "C" {static void dealloc_QTabletEvent(sipSimpleWrapper *);}
static void dealloc_QTabletEvent(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQTabletEvent *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QTabletEvent(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QTabletEvent(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QTabletEvent(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQTabletEvent *sipCpp = SIP_NULLPTR;

    {
        ::QEvent::Type a0;
        const ::QPointingDevice* a1;
        const ::QPointF* a2;
        const ::QPointF* a3;
        ::qreal a4;
        float a5;
        float a6;
        float a7;
        ::qreal a8;
        float a9;
        ::Qt::KeyboardModifiers* a10;
        int a10State = 0;
        ::Qt::MouseButton a11;
        ::Qt::MouseButtons* a12;
        int a12State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "EJ8J9J9dfffdfJ1EJ1", sipType_QEvent_Type, &a0, sipType_QPointingDevice, &a1, sipType_QPointF, &a2, sipType_QPointF, &a3, &a4, &a5, &a6, &a7, &a8, &a9, sipType_QFlags_0100Qt_KeyboardModifier, &a10, &a10State, sipType_Qt_MouseButton, &a11, sipType_QFlags_0100Qt_MouseButton, &a12, &a12State))
        {
            sipCpp = new sipQTabletEvent(a0, a1, *a2, *a3, a4, a5, a6, a7, a8, a9, *a10, a11, *a12);
            sipReleaseType(a10, sipType_QFlags_0100Qt_KeyboardModifier, a10State);
            sipReleaseType(a12, sipType_QFlags_0100Qt_MouseButton, a12State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QTabletEvent[] = {{274, 255, 1}};


static PyMethodDef methods_QTabletEvent[] = {
    {sipName_clone, meth_QTabletEvent_clone, METH_VARARGS, doc_QTabletEvent_clone},
    {sipName_pressure, meth_QTabletEvent_pressure, METH_VARARGS, doc_QTabletEvent_pressure},
    {sipName_rotation, meth_QTabletEvent_rotation, METH_VARARGS, doc_QTabletEvent_rotation},
    {sipName_tangentialPressure, meth_QTabletEvent_tangentialPressure, METH_VARARGS, doc_QTabletEvent_tangentialPressure},
    {sipName_xTilt, meth_QTabletEvent_xTilt, METH_VARARGS, doc_QTabletEvent_xTilt},
    {sipName_yTilt, meth_QTabletEvent_yTilt, METH_VARARGS, doc_QTabletEvent_yTilt},
    {sipName_z, meth_QTabletEvent_z, METH_VARARGS, doc_QTabletEvent_z}
};

PyDoc_STRVAR(doc_QTabletEvent, "\1QTabletEvent(t: QEvent.Type, device: QPointingDevice|None, pos: QPointF, globalPos: QPointF, pressure: float, xTilt: float, yTilt: float, tangentialPressure: float, rotation: float, z: float, keyState: Qt.KeyboardModifier, button: Qt.MouseButton, buttons: Qt.MouseButton)");


sipClassTypeDef sipTypeDef_QtGui_QTabletEvent = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QTabletEvent,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QTabletEvent,
        {0, 0, 1},
        7, methods_QTabletEvent,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QTabletEvent,
    -1,
    -1,
    supers_QTabletEvent,
    SIP_NULLPTR,
    init_type_QTabletEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QTabletEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QTabletEvent,
    cast_QTabletEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QTabletEvent),
};
