/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtNfcAPI_H
#define _QtNfcAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtNfc[0]
#define sipNameNr_QNdefNfcSmartPosterRecord__Action 39
#define sipName_QNdefNfcSmartPosterRecord__Action &sipStrings_QtNfc[39]
#define sipNameNr_QNearFieldManager__AdapterState 73
#define sipName_QNearFieldManager__AdapterState &sipStrings_QtNfc[73]
#define sipNameNr_QNearFieldTarget__AccessMethod 105
#define sipName_QNearFieldTarget__AccessMethod &sipStrings_QtNfc[105]
#define sipNameNr_QNdefNfcTextRecord__Encoding 136
#define sipName_QNdefNfcTextRecord__Encoding &sipStrings_QtNfc[136]
#define sipNameNr_QNdefRecord__TypeNameFormat 165
#define sipName_QNdefRecord__TypeNameFormat &sipStrings_QtNfc[165]
#define sipNameNr_QNearFieldTarget__RequestId 193
#define sipName_QNearFieldTarget__RequestId &sipStrings_QtNfc[193]
#define sipNameNr_221 221
#define sipName_221 &sipStrings_QtNfc[221]
#define sipNameNr_247 247
#define sipName_247 &sipStrings_QtNfc[247]
#define sipNameNr_QNdefNfcSmartPosterRecord 273
#define sipName_QNdefNfcSmartPosterRecord &sipStrings_QtNfc[273]
#define sipNameNr_PyQt6_sip_simplewrapper 299
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtNfc[299]
#define sipNameNr_QNearFieldTarget__Error 323
#define sipName_QNearFieldTarget__Error &sipStrings_QtNfc[323]
#define sipNameNr_waitForRequestCompleted 347
#define sipName_waitForRequestCompleted &sipStrings_QtNfc[347]
#define sipNameNr_InvalidParametersError 371
#define sipName_InvalidParametersError &sipStrings_QtNfc[371]
#define sipNameNr_QNearFieldTarget__Type 394
#define sipName_QNearFieldTarget__Type &sipStrings_QtNfc[394]
#define sipNameNr_UnsupportedTargetError 417
#define sipName_UnsupportedTargetError &sipStrings_QtNfc[417]
#define sipNameNr_targetDetectionStopped 440
#define sipName_targetDetectionStopped &sipStrings_QtNfc[440]
#define sipNameNr_ChecksumMismatchError 463
#define sipName_ChecksumMismatchError &sipStrings_QtNfc[463]
#define sipNameNr_TagTypeSpecificAccess 485
#define sipName_TagTypeSpecificAccess &sipStrings_QtNfc[485]
#define sipNameNr_TargetOutOfRangeError 507
#define sipName_TargetOutOfRangeError &sipStrings_QtNfc[507]
#define sipNameNr_startTargetDetection 529
#define sipName_startTargetDetection &sipStrings_QtNfc[529]
#define sipNameNr_550 550
#define sipName_550 &sipStrings_QtNfc[550]
#define sipNameNr_QNdefFilter__Record 570
#define sipName_QNdefFilter__Record &sipStrings_QtNfc[570]
#define sipNameNr_adapterStateChanged 590
#define sipName_adapterStateChanged &sipStrings_QtNfc[590]
#define sipNameNr_stopTargetDetection 610
#define sipName_stopTargetDetection &sipStrings_QtNfc[610]
#define sipNameNr_630 630
#define sipName_630 &sipStrings_QtNfc[630]
#define sipNameNr_QNdefNfcIconRecord 649
#define sipName_QNdefNfcIconRecord &sipStrings_QtNfc[649]
#define sipNameNr_QNdefNfcTextRecord 668
#define sipName_QNdefNfcTextRecord &sipStrings_QtNfc[668]
#define sipNameNr_setUserInformation 687
#define sipName_setUserInformation &sipStrings_QtNfc[687]
#define sipNameNr_QNdefNfcUriRecord 706
#define sipName_QNdefNfcUriRecord &sipStrings_QtNfc[706]
#define sipNameNr_QNearFieldManager 724
#define sipName_QNearFieldManager &sipStrings_QtNfc[724]
#define sipNameNr_UnspecifiedAction 742
#define sipName_UnspecifiedAction &sipStrings_QtNfc[742]
#define sipNameNr_setTypeNameFormat 760
#define sipName_setTypeNameFormat &sipStrings_QtNfc[760]
#define sipNameNr_writeNdefMessages 778
#define sipName_writeNdefMessages &sipStrings_QtNfc[778]
#define sipNameNr_QNearFieldTarget 796
#define sipName_QNearFieldTarget &sipStrings_QtNfc[796]
#define sipNameNr_UnsupportedError 813
#define sipName_UnsupportedError &sipStrings_QtNfc[813]
#define sipNameNr_disconnectNotify 830
#define sipName_disconnectNotify &sipStrings_QtNfc[830]
#define sipNameNr_maxCommandLength 847
#define sipName_maxCommandLength &sipStrings_QtNfc[847]
#define sipNameNr_readNdefMessages 864
#define sipName_readNdefMessages &sipStrings_QtNfc[864]
#define sipNameNr_requestCompleted 881
#define sipName_requestCompleted &sipStrings_QtNfc[881]
#define sipNameNr_ConnectionError 898
#define sipName_ConnectionError &sipStrings_QtNfc[898]
#define sipNameNr_NoResponseError 914
#define sipName_NoResponseError &sipStrings_QtNfc[914]
#define sipNameNr_ndefMessageRead 930
#define sipName_ndefMessageRead &sipStrings_QtNfc[930]
#define sipNameNr_requestResponse 946
#define sipName_requestResponse &sipStrings_QtNfc[946]
#define sipNameNr_NdefWriteError 962
#define sipName_NdefWriteError &sipStrings_QtNfc[962]
#define sipNameNr_ProprietaryTag 977
#define sipName_ProprietaryTag &sipStrings_QtNfc[977]
#define sipNameNr_TypeNameFormat 178
#define sipName_TypeNameFormat &sipStrings_QtNfc[178]
#define sipNameNr_hasNdefMessage 992
#define sipName_hasNdefMessage &sipStrings_QtNfc[992]
#define sipNameNr_targetDetected 1007
#define sipName_targetDetected &sipStrings_QtNfc[1007]
#define sipNameNr_typeNameFormat 1022
#define sipName_typeNameFormat &sipStrings_QtNfc[1022]
#define sipNameNr_NdefReadError 1037
#define sipName_NdefReadError &sipStrings_QtNfc[1037]
#define sipNameNr_UnknownAccess 1051
#define sipName_UnknownAccess &sipStrings_QtNfc[1051]
#define sipNameNr_accessMethods 1065
#define sipName_accessMethods &sipStrings_QtNfc[1065]
#define sipNameNr_connectNotify 833
#define sipName_connectNotify &sipStrings_QtNfc[833]
#define sipNameNr_fromByteArray 1079
#define sipName_fromByteArray &sipStrings_QtNfc[1079]
#define sipNameNr_setOrderMatch 1093
#define sipName_setOrderMatch &sipStrings_QtNfc[1093]
#define sipNameNr_AccessMethod 123
#define sipName_AccessMethod &sipStrings_QtNfc[123]
#define sipNameNr_AdapterState 92
#define sipName_AdapterState &sipStrings_QtNfc[92]
#define sipNameNr_CommandError 1107
#define sipName_CommandError &sipStrings_QtNfc[1107]
#define sipNameNr_NfcTagType4A 1120
#define sipName_NfcTagType4A &sipStrings_QtNfc[1120]
#define sipNameNr_NfcTagType4B 1133
#define sipName_NfcTagType4B &sipStrings_QtNfc[1133]
#define sipNameNr_QNdefMessage 1146
#define sipName_QNdefMessage &sipStrings_QtNfc[1146]
#define sipNameNr_TimeoutError 1159
#define sipName_TimeoutError &sipStrings_QtNfc[1159]
#define sipNameNr_UnknownError 1172
#define sipName_UnknownError &sipStrings_QtNfc[1172]
#define sipNameNr_accessMethod 1185
#define sipName_accessMethod &sipStrings_QtNfc[1185]
#define sipNameNr_appendRecord 1198
#define sipName_appendRecord &sipStrings_QtNfc[1198]
#define sipNameNr_disconnected 1211
#define sipName_disconnected &sipStrings_QtNfc[1211]
#define sipNameNr_errorMessage 1224
#define sipName_errorMessage &sipStrings_QtNfc[1224]
#define sipNameNr_titleRecords 1237
#define sipName_titleRecords &sipStrings_QtNfc[1237]
#define sipNameNr_ExternalRtd 1250
#define sipName_ExternalRtd &sipStrings_QtNfc[1250]
#define sipNameNr_NfcTagType1 1262
#define sipName_NfcTagType1 &sipStrings_QtNfc[1262]
#define sipNameNr_NfcTagType2 1274
#define sipName_NfcTagType2 &sipStrings_QtNfc[1274]
#define sipNameNr_NfcTagType3 1286
#define sipName_NfcTagType3 &sipStrings_QtNfc[1286]
#define sipNameNr_NfcTagType4 1298
#define sipName_NfcTagType4 &sipStrings_QtNfc[1298]
#define sipNameNr_PyQt6_QtNfc 1310
#define sipName_PyQt6_QtNfc &sipStrings_QtNfc[1310]
#define sipNameNr_QNdefFilter 1322
#define sipName_QNdefFilter &sipStrings_QtNfc[1322]
#define sipNameNr_QNdefRecord 1334
#define sipName_QNdefRecord &sipStrings_QtNfc[1334]
#define sipNameNr___delitem__ 1346
#define sipName___delitem__ &sipStrings_QtNfc[1346]
#define sipNameNr___getitem__ 1358
#define sipName___getitem__ &sipStrings_QtNfc[1358]
#define sipNameNr___setitem__ 1370
#define sipName___setitem__ &sipStrings_QtNfc[1370]
#define sipNameNr_customEvent 1382
#define sipName_customEvent &sipStrings_QtNfc[1382]
#define sipNameNr_eventFilter 1394
#define sipName_eventFilter &sipStrings_QtNfc[1394]
#define sipNameNr_hasTypeInfo 1406
#define sipName_hasTypeInfo &sipStrings_QtNfc[1406]
#define sipNameNr_iconRecords 1418
#define sipName_iconRecords &sipStrings_QtNfc[1418]
#define sipNameNr_isSupported 1430
#define sipName_isSupported &sipStrings_QtNfc[1430]
#define sipNameNr_recordCount 1442
#define sipName_recordCount &sipStrings_QtNfc[1442]
#define sipNameNr_removeTitle 1454
#define sipName_removeTitle &sipStrings_QtNfc[1454]
#define sipNameNr_sendCommand 1466
#define sipName_sendCommand &sipStrings_QtNfc[1466]
#define sipNameNr_setEncoding 1478
#define sipName_setEncoding &sipStrings_QtNfc[1478]
#define sipNameNr_setTypeInfo 1490
#define sipName_setTypeInfo &sipStrings_QtNfc[1490]
#define sipNameNr_titleRecord 1502
#define sipName_titleRecord &sipStrings_QtNfc[1502]
#define sipNameNr_toByteArray 1514
#define sipName_toByteArray &sipStrings_QtNfc[1514]
#define sipNameNr_EditAction 1526
#define sipName_EditAction &sipStrings_QtNfc[1526]
#define sipNameNr_NdefAccess 1537
#define sipName_NdefAccess &sipStrings_QtNfc[1537]
#define sipNameNr_SaveAction 1548
#define sipName_SaveAction &sipStrings_QtNfc[1548]
#define sipNameNr_TurningOff 1559
#define sipName_TurningOff &sipStrings_QtNfc[1559]
#define sipNameNr_childEvent 1570
#define sipName_childEvent &sipStrings_QtNfc[1570]
#define sipNameNr_disconnect 1581
#define sipName_disconnect &sipStrings_QtNfc[1581]
#define sipNameNr_iconRecord 1592
#define sipName_iconRecord &sipStrings_QtNfc[1592]
#define sipNameNr_orderMatch 1603
#define sipName_orderMatch &sipStrings_QtNfc[1603]
#define sipNameNr_removeIcon 1614
#define sipName_removeIcon &sipStrings_QtNfc[1614]
#define sipNameNr_setPayload 1625
#define sipName_setPayload &sipStrings_QtNfc[1625]
#define sipNameNr_targetLost 1636
#define sipName_targetLost &sipStrings_QtNfc[1636]
#define sipNameNr_timerEvent 1647
#define sipName_timerEvent &sipStrings_QtNfc[1647]
#define sipNameNr_titleCount 1658
#define sipName_titleCount &sipStrings_QtNfc[1658]
#define sipNameNr_AnyAccess 1669
#define sipName_AnyAccess &sipStrings_QtNfc[1669]
#define sipNameNr_MifareTag 1679
#define sipName_MifareTag &sipStrings_QtNfc[1679]
#define sipNameNr_RequestId 211
#define sipName_RequestId &sipStrings_QtNfc[211]
#define sipNameNr_TurningOn 1689
#define sipName_TurningOn &sipStrings_QtNfc[1689]
#define sipNameNr_hasAction 1699
#define sipName_hasAction &sipStrings_QtNfc[1699]
#define sipNameNr_iconCount 1709
#define sipName_iconCount &sipStrings_QtNfc[1709]
#define sipNameNr_isEnabled 1719
#define sipName_isEnabled &sipStrings_QtNfc[1719]
#define sipNameNr_setAction 1729
#define sipName_setAction &sipStrings_QtNfc[1729]
#define sipNameNr_setLocale 1739
#define sipName_setLocale &sipStrings_QtNfc[1739]
#define sipNameNr_setTitles 1749
#define sipName_setTitles &sipStrings_QtNfc[1749]
#define sipNameNr_uriRecord 1759
#define sipName_uriRecord &sipStrings_QtNfc[1759]
#define sipNameNr_DoAction 1769
#define sipName_DoAction &sipStrings_QtNfc[1769]
#define sipNameNr_Encoding 156
#define sipName_Encoding &sipStrings_QtNfc[156]
#define sipNameNr___hash__ 1778
#define sipName___hash__ &sipStrings_QtNfc[1778]
#define sipNameNr_addTitle 1787
#define sipName_addTitle &sipStrings_QtNfc[1787]
#define sipNameNr_encoding 1796
#define sipName_encoding &sipStrings_QtNfc[1796]
#define sipNameNr_hasTitle 1805
#define sipName_hasTitle &sipStrings_QtNfc[1805]
#define sipNameNr_mimetype 1814
#define sipName_mimetype &sipStrings_QtNfc[1814]
#define sipNameNr_recordAt 1823
#define sipName_recordAt &sipStrings_QtNfc[1823]
#define sipNameNr_refCount 1832
#define sipName_refCount &sipStrings_QtNfc[1832]
#define sipNameNr_setIcons 1841
#define sipName_setIcons &sipStrings_QtNfc[1841]
#define sipNameNr_typeInfo 1850
#define sipName_typeInfo &sipStrings_QtNfc[1850]
#define sipNameNr_NoError 1859
#define sipName_NoError &sipStrings_QtNfc[1859]
#define sipNameNr_Offline 1867
#define sipName_Offline &sipStrings_QtNfc[1867]
#define sipNameNr_Unknown 1875
#define sipName_Unknown &sipStrings_QtNfc[1875]
#define sipNameNr___len__ 1883
#define sipName___len__ &sipStrings_QtNfc[1883]
#define sipNameNr_addIcon 1891
#define sipName_addIcon &sipStrings_QtNfc[1891]
#define sipNameNr_hasIcon 1899
#define sipName_hasIcon &sipStrings_QtNfc[1899]
#define sipNameNr_hasSize 1907
#define sipName_hasSize &sipStrings_QtNfc[1907]
#define sipNameNr_isEmpty 1915
#define sipName_isEmpty &sipStrings_QtNfc[1915]
#define sipNameNr_isValid 1923
#define sipName_isValid &sipStrings_QtNfc[1923]
#define sipNameNr_maximum 1931
#define sipName_maximum &sipStrings_QtNfc[1931]
#define sipNameNr_minimum 1939
#define sipName_minimum &sipStrings_QtNfc[1939]
#define sipNameNr_payload 1947
#define sipName_payload &sipStrings_QtNfc[1947]
#define sipNameNr_setData 1955
#define sipName_setData &sipStrings_QtNfc[1955]
#define sipNameNr_setSize 1963
#define sipName_setSize &sipStrings_QtNfc[1963]
#define sipNameNr_setText 1971
#define sipName_setText &sipStrings_QtNfc[1971]
#define sipNameNr_setType 1979
#define sipName_setType &sipStrings_QtNfc[1979]
#define sipNameNr_Action 66
#define sipName_Action &sipStrings_QtNfc[66]
#define sipNameNr_NfcRtd 1987
#define sipName_NfcRtd &sipStrings_QtNfc[1987]
#define sipNameNr_Online 1994
#define sipName_Online &sipStrings_QtNfc[1994]
#define sipNameNr_Record 292
#define sipName_Record &sipStrings_QtNfc[292]
#define sipNameNr___eq__ 2001
#define sipName___eq__ &sipStrings_QtNfc[2001]
#define sipNameNr___ge__ 2008
#define sipName___ge__ &sipStrings_QtNfc[2008]
#define sipNameNr___lt__ 2015
#define sipName___lt__ &sipStrings_QtNfc[2015]
#define sipNameNr___ne__ 2022
#define sipName___ne__ &sipStrings_QtNfc[2022]
#define sipNameNr_action 2029
#define sipName_action &sipStrings_QtNfc[2029]
#define sipNameNr_locale 2036
#define sipName_locale &sipStrings_QtNfc[2036]
#define sipNameNr_parent 2043
#define sipName_parent &sipStrings_QtNfc[2043]
#define sipNameNr_setUri 2050
#define sipName_setUri &sipStrings_QtNfc[2050]
#define sipNameNr_Empty 1917
#define sipName_Empty &sipStrings_QtNfc[1917]
#define sipNameNr_Error 341
#define sipName_Error &sipStrings_QtNfc[341]
#define sipNameNr_Utf16 2057
#define sipName_Utf16 &sipStrings_QtNfc[2057]
#define sipNameNr_clear 2063
#define sipName_clear &sipStrings_QtNfc[2063]
#define sipNameNr_error 2069
#define sipName_error &sipStrings_QtNfc[2069]
#define sipNameNr_event 2075
#define sipName_event &sipStrings_QtNfc[2075]
#define sipNameNr_match 2081
#define sipName_match &sipStrings_QtNfc[2081]
#define sipNameNr_msecs 2087
#define sipName_msecs &sipStrings_QtNfc[2087]
#define sipNameNr_setId 2093
#define sipName_setId &sipStrings_QtNfc[2093]
#define sipNameNr_title 2099
#define sipName_title &sipStrings_QtNfc[2099]
#define sipNameNr_Mime 2105
#define sipName_Mime &sipStrings_QtNfc[2105]
#define sipNameNr_Type 412
#define sipName_Type &sipStrings_QtNfc[412]
#define sipNameNr_Utf8 2110
#define sipName_Utf8 &sipStrings_QtNfc[2110]
#define sipNameNr_data 2115
#define sipName_data &sipStrings_QtNfc[2115]
#define sipNameNr_icon 2120
#define sipName_icon &sipStrings_QtNfc[2120]
#define sipNameNr_size 2125
#define sipName_size &sipStrings_QtNfc[2125]
#define sipNameNr_text 2130
#define sipName_text &sipStrings_QtNfc[2130]
#define sipNameNr_type 1818
#define sipName_type &sipStrings_QtNfc[1818]
#define sipNameNr_Uri 2053
#define sipName_Uri &sipStrings_QtNfc[2053]
#define sipNameNr_max 2135
#define sipName_max &sipStrings_QtNfc[2135]
#define sipNameNr_min 2139
#define sipName_min &sipStrings_QtNfc[2139]
#define sipNameNr_uid 2143
#define sipName_uid &sipStrings_QtNfc[2143]
#define sipNameNr_uri 2147
#define sipName_uri &sipStrings_QtNfc[2147]
#define sipNameNr_id 1928
#define sipName_id &sipStrings_QtNfc[1928]

#define sipMalloc                   sipAPI_QtNfc->api_malloc
#define sipFree                     sipAPI_QtNfc->api_free
#define sipBuildResult              sipAPI_QtNfc->api_build_result
#define sipCallMethod               sipAPI_QtNfc->api_call_method
#define sipCallProcedureMethod      sipAPI_QtNfc->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtNfc->api_call_error_handler
#define sipParseResultEx            sipAPI_QtNfc->api_parse_result_ex
#define sipParseResult              sipAPI_QtNfc->api_parse_result
#define sipParseArgs                sipAPI_QtNfc->api_parse_args
#define sipParseKwdArgs             sipAPI_QtNfc->api_parse_kwd_args
#define sipParsePair                sipAPI_QtNfc->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtNfc->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtNfc->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtNfc->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtNfc->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtNfc->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtNfc->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtNfc->api_add_exception
#define sipNoFunction               sipAPI_QtNfc->api_no_function
#define sipNoMethod                 sipAPI_QtNfc->api_no_method
#define sipAbstractMethod           sipAPI_QtNfc->api_abstract_method
#define sipBadClass                 sipAPI_QtNfc->api_bad_class
#define sipBadCatcherResult         sipAPI_QtNfc->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtNfc->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtNfc->api_bad_operator_arg
#define sipTrace                    sipAPI_QtNfc->api_trace
#define sipTransferBack             sipAPI_QtNfc->api_transfer_back
#define sipTransferTo               sipAPI_QtNfc->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtNfc->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtNfc->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtNfc->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtNfc->api_voidptr_type
#define sipGetPyObject              sipAPI_QtNfc->api_get_pyobject
#define sipGetAddress               sipAPI_QtNfc->api_get_address
#define sipGetMixinAddress          sipAPI_QtNfc->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtNfc->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtNfc->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtNfc->api_call_hook
#define sipEndThread                sipAPI_QtNfc->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtNfc->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtNfc->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtNfc->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtNfc->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtNfc->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtNfc->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtNfc->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtNfc->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtNfc->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtNfc->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtNfc->api_convert_to_bool
#define sipReleaseType              sipAPI_QtNfc->api_release_type
#define sipConvertFromType          sipAPI_QtNfc->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtNfc->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtNfc->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtNfc->api_convert_from_enum
#define sipGetState                 sipAPI_QtNfc->api_get_state
#define sipExportSymbol             sipAPI_QtNfc->api_export_symbol
#define sipImportSymbol             sipAPI_QtNfc->api_import_symbol
#define sipFindType                 sipAPI_QtNfc->api_find_type
#define sipBytes_AsChar             sipAPI_QtNfc->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtNfc->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtNfc->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtNfc->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtNfc->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtNfc->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtNfc->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtNfc->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtNfc->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtNfc->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtNfc->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtNfc->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtNfc->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtNfc->api_get_reference
#define sipKeepReference            sipAPI_QtNfc->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtNfc->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtNfc->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtNfc->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtNfc->api_type_scope
#define sipResolveTypedef           sipAPI_QtNfc->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtNfc->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtNfc->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtNfc->api_init_mixin
#define sipExportModule             sipAPI_QtNfc->api_export_module
#define sipInitModule               sipAPI_QtNfc->api_init_module
#define sipGetInterpreter           sipAPI_QtNfc->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtNfc->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtNfc->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtNfc->api_py_type_dict
#define sipPyTypeName               sipAPI_QtNfc->api_py_type_name
#define sipGetCFunction             sipAPI_QtNfc->api_get_c_function
#define sipGetMethod                sipAPI_QtNfc->api_get_method
#define sipFromMethod               sipAPI_QtNfc->api_from_method
#define sipGetDate                  sipAPI_QtNfc->api_get_date
#define sipFromDate                 sipAPI_QtNfc->api_from_date
#define sipGetDateTime              sipAPI_QtNfc->api_get_datetime
#define sipFromDateTime             sipAPI_QtNfc->api_from_datetime
#define sipGetTime                  sipAPI_QtNfc->api_get_time
#define sipFromTime                 sipAPI_QtNfc->api_from_time
#define sipIsUserType               sipAPI_QtNfc->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtNfc->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtNfc->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtNfc->api_unicode_write
#define sipUnicodeData              sipAPI_QtNfc->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtNfc->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtNfc->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtNfc->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtNfc->api_is_derived_class
#define sipGetUserObject            sipAPI_QtNfc->api_get_user_object
#define sipSetUserObject            sipAPI_QtNfc->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtNfc->api_register_event_handler
#define sipConvertToArray           sipAPI_QtNfc->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtNfc->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtNfc->api_enable_gc
#define sipPrintObject              sipAPI_QtNfc->api_print_object
#define sipLong_AsChar              sipAPI_QtNfc->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtNfc->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtNfc->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtNfc->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtNfc->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtNfc->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtNfc->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtNfc->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtNfc->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtNfc->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtNfc->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtNfc->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtNfc->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtNfc->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtNfc->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtNfc->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtNfc->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtNfc->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtNfc->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtNfc->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtNfc->api_release_type_us
#define sipIsPyMethod               sipAPI_QtNfc->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtNfc[];

#define sipType_QNdefFilter sipExportedTypes_QtNfc[5]

extern sipClassTypeDef sipTypeDef_QtNfc_QNdefFilter;

#define sipType_QNdefFilter_Record sipExportedTypes_QtNfc[6]

extern sipClassTypeDef sipTypeDef_QtNfc_QNdefFilter_Record;

#define sipType_QNdefMessage sipExportedTypes_QtNfc[7]

extern sipClassTypeDef sipTypeDef_QtNfc_QNdefMessage;

#define sipType_QNdefRecord sipExportedTypes_QtNfc[14]

#define sipType_QNdefRecord_TypeNameFormat sipExportedTypes_QtNfc[15]

extern sipClassTypeDef sipTypeDef_QtNfc_QNdefRecord;

#define sipType_QNdefNfcIconRecord sipExportedTypes_QtNfc[8]

extern sipClassTypeDef sipTypeDef_QtNfc_QNdefNfcIconRecord;

#define sipType_QNdefNfcSmartPosterRecord sipExportedTypes_QtNfc[9]

#define sipType_QNdefNfcSmartPosterRecord_Action sipExportedTypes_QtNfc[10]

extern sipClassTypeDef sipTypeDef_QtNfc_QNdefNfcSmartPosterRecord;

#define sipType_QNdefNfcTextRecord sipExportedTypes_QtNfc[11]

#define sipType_QNdefNfcTextRecord_Encoding sipExportedTypes_QtNfc[12]

extern sipClassTypeDef sipTypeDef_QtNfc_QNdefNfcTextRecord;

#define sipType_QNdefNfcUriRecord sipExportedTypes_QtNfc[13]

extern sipClassTypeDef sipTypeDef_QtNfc_QNdefNfcUriRecord;

#define sipType_QNearFieldManager sipExportedTypes_QtNfc[16]

#define sipType_QNearFieldManager_AdapterState sipExportedTypes_QtNfc[17]

extern sipClassTypeDef sipTypeDef_QtNfc_QNearFieldManager;

#define sipType_QNearFieldTarget sipExportedTypes_QtNfc[18]

#define sipType_QNearFieldTarget_Error sipExportedTypes_QtNfc[20]

#define sipType_QNearFieldTarget_AccessMethod sipExportedTypes_QtNfc[19]

#define sipType_QNearFieldTarget_Type sipExportedTypes_QtNfc[22]

extern sipClassTypeDef sipTypeDef_QtNfc_QNearFieldTarget;

#define sipType_QNearFieldTarget_RequestId sipExportedTypes_QtNfc[21]

extern sipClassTypeDef sipTypeDef_QtNfc_QNearFieldTarget_RequestId;

#define sipType_QList_0100QNdefMessage sipExportedTypes_QtNfc[1]

extern sipMappedTypeDef sipTypeDef_QtNfc_QList_0100QNdefMessage;

#define sipType_QList_0100QNdefNfcIconRecord sipExportedTypes_QtNfc[2]

extern sipMappedTypeDef sipTypeDef_QtNfc_QList_0100QNdefNfcIconRecord;

#define sipType_QList_0100QNdefNfcTextRecord sipExportedTypes_QtNfc[3]

extern sipMappedTypeDef sipTypeDef_QtNfc_QList_0100QNdefNfcTextRecord;

#define sipType_QList_0100QNdefRecord sipExportedTypes_QtNfc[4]

extern sipMappedTypeDef sipTypeDef_QtNfc_QList_0100QNdefRecord;

#define sipType_QFlags_0100QNearFieldTarget_AccessMethod sipExportedTypes_QtNfc[0]

extern sipMappedTypeDef sipTypeDef_QtNfc_QFlags_0100QNearFieldTarget_AccessMethod;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtNfc;
extern sipExportedModuleDef sipModuleAPI_QtNfc;
extern sipTypeDef *sipExportedTypes_QtNfc[];

#define sipType_QObject sipImportedTypes_QtNfc_QtCore[4].it_td

#define sipType_QByteArray sipImportedTypes_QtNfc_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtNfc_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtNfc_QtCore[6].it_td

#define sipType_QChildEvent sipImportedTypes_QtNfc_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtNfc_QtCore[3].it_td

#define sipType_QUrl sipImportedTypes_QtNfc_QtCore[7].it_td

#define sipType_QVariant sipImportedTypes_QtNfc_QtCore[8].it_td

#define sipType_QString sipImportedTypes_QtNfc_QtCore[5].it_td
extern sipImportedTypeDef sipImportedTypes_QtNfc_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtNfc_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtNfc_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtNfc_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtNfc_qt_metacast;
#line 93 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldmanager.sip"
// Imports from QtCore.
typedef sipErrorState (*pyqt6_qtnfc_get_pyqtslot_parts_t)(PyObject *, QObject **, QByteArray &);
extern pyqt6_qtnfc_get_pyqtslot_parts_t pyqt6_qtnfc_get_pyqtslot_parts;
#line 679 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipAPIQtNfc.h"

#endif
