/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSpatialAudio.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSpatialAudio/qaudiolistener.sip"
#include <qaudiolistener.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSpatialAudio/qaudioengine.sip"
#include <qaudioengine.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioListener.cpp"


class sipQAudioListener : public ::QAudioListener
{
public:
    sipQAudioListener(::QAudioEngine*);
    virtual ~sipQAudioListener();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAudioListener(const sipQAudioListener &);
    sipQAudioListener &operator = (const sipQAudioListener &);

    char sipPyMethods[7];
};

sipQAudioListener::sipQAudioListener(::QAudioEngine*a0): ::QAudioListener(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioListener::~sipQAudioListener()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAudioListener::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtSpatialAudio_qt_metaobject(sipPySelf, sipType_QAudioListener);

    return ::QAudioListener::metaObject();
}

int sipQAudioListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAudioListener::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtSpatialAudio_qt_metacall(sipPySelf, sipType_QAudioListener, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAudioListener::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtSpatialAudio_qt_metacast(sipPySelf, sipType_QAudioListener, _clname, &sipCpp) ? sipCpp : ::QAudioListener::qt_metacast(_clname));
}

bool sipQAudioListener::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAudioListener::event(a0);

    extern bool sipVH_QtSpatialAudio_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtSpatialAudio_5(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAudioListener::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAudioListener::eventFilter(a0, a1);

    extern bool sipVH_QtSpatialAudio_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtSpatialAudio_4(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAudioListener::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAudioListener::timerEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtSpatialAudio_3(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioListener::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAudioListener::childEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtSpatialAudio_2(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioListener::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAudioListener::customEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSpatialAudio_1(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioListener::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAudioListener::connectNotify(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSpatialAudio_0(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioListener::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAudioListener::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSpatialAudio_0(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAudioListener_setPosition, "setPosition(self, pos: QVector3D)");

extern "C" {static PyObject *meth_QAudioListener_setPosition(PyObject *, PyObject *);}
static PyObject *meth_QAudioListener_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVector3D* a0;
        ::QAudioListener *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioListener, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setPosition(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioListener, sipName_setPosition, doc_QAudioListener_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioListener_position, "position(self) -> QVector3D");

extern "C" {static PyObject *meth_QAudioListener_position(PyObject *, PyObject *);}
static PyObject *meth_QAudioListener_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioListener *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioListener, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->position());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioListener, sipName_position, doc_QAudioListener_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioListener_setRotation, "setRotation(self, q: QQuaternion)");

extern "C" {static PyObject *meth_QAudioListener_setRotation(PyObject *, PyObject *);}
static PyObject *meth_QAudioListener_setRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuaternion* a0;
        ::QAudioListener *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioListener, &sipCpp, sipType_QQuaternion, &a0))
        {
            sipCpp->setRotation(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioListener, sipName_setRotation, doc_QAudioListener_setRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioListener_rotation, "rotation(self) -> QQuaternion");

extern "C" {static PyObject *meth_QAudioListener_rotation(PyObject *, PyObject *);}
static PyObject *meth_QAudioListener_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioListener *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioListener, &sipCpp))
        {
            ::QQuaternion*sipRes;

            sipRes = new ::QQuaternion(sipCpp->rotation());

            return sipConvertFromNewType(sipRes, sipType_QQuaternion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioListener, sipName_rotation, doc_QAudioListener_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioListener_engine, "engine(self) -> QAudioEngine|None");

extern "C" {static PyObject *meth_QAudioListener_engine(PyObject *, PyObject *);}
static PyObject *meth_QAudioListener_engine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioListener *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioListener, &sipCpp))
        {
            ::QAudioEngine*sipRes;

            sipRes = sipCpp->engine();

            return sipConvertFromType(sipRes, sipType_QAudioEngine, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioListener, sipName_engine, doc_QAudioListener_engine);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAudioListener(void *, const sipTypeDef *);}
static void *cast_QAudioListener(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAudioListener *sipCpp = reinterpret_cast< ::QAudioListener *>(sipCppV);

    if (targetType == sipType_QAudioListener)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAudioListener(void *, int);}
static void release_QAudioListener(void *sipCppV, int)
{
    ::QAudioListener *sipCpp = reinterpret_cast< ::QAudioListener *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QAudioListener(sipSimpleWrapper *);}
static void dealloc_QAudioListener(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAudioListener *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAudioListener(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAudioListener(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAudioListener(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQAudioListener *sipCpp = SIP_NULLPTR;

    {
        ::QAudioEngine* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8", sipType_QAudioEngine, &a0))
        {
            sipCpp = new sipQAudioListener(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAudioListener[] = {{3, 0, 1}};


static PyMethodDef methods_QAudioListener[] = {
    {sipName_engine, meth_QAudioListener_engine, METH_VARARGS, doc_QAudioListener_engine},
    {sipName_position, meth_QAudioListener_position, METH_VARARGS, doc_QAudioListener_position},
    {sipName_rotation, meth_QAudioListener_rotation, METH_VARARGS, doc_QAudioListener_rotation},
    {sipName_setPosition, meth_QAudioListener_setPosition, METH_VARARGS, doc_QAudioListener_setPosition},
    {sipName_setRotation, meth_QAudioListener_setRotation, METH_VARARGS, doc_QAudioListener_setRotation}
};

PyDoc_STRVAR(doc_QAudioListener, "\1QAudioListener(engine: QAudioEngine|None)");


static pyqt6ClassPluginDef plugin_QAudioListener = {
    &::QAudioListener::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSpatialAudio_QAudioListener = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAudioListener,
        SIP_NULLPTR,
        &plugin_QAudioListener,
    },
    {
        sipNameNr_QAudioListener,
        {0, 0, 1},
        5, methods_QAudioListener,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAudioListener,
    -1,
    -1,
    supers_QAudioListener,
    SIP_NULLPTR,
    init_type_QAudioListener,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAudioListener,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QAudioListener,
    cast_QAudioListener,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QAudioListener),
};
