/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediametadata.sip"
#include <qmediametadata.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaMetaData.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetatype.sip"
#include <qmetatype.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaMetaData.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaMetaData.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaMetaData.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaMetaData.cpp"


PyDoc_STRVAR(doc_QMediaMetaData_value, "value(self, k: QMediaMetaData.Key) -> Any");

extern "C" {static PyObject *meth_QMediaMetaData_value(PyObject *, PyObject *);}
static PyObject *meth_QMediaMetaData_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaMetaData::Key a0;
        const ::QMediaMetaData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QMediaMetaData, &sipCpp, sipType_QMediaMetaData_Key, &a0))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->value(a0));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaMetaData, sipName_value, doc_QMediaMetaData_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaMetaData_insert, "insert(self, k: QMediaMetaData.Key, value: Any)");

extern "C" {static PyObject *meth_QMediaMetaData_insert(PyObject *, PyObject *);}
static PyObject *meth_QMediaMetaData_insert(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaMetaData::Key a0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QMediaMetaData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QMediaMetaData, &sipCpp, sipType_QMediaMetaData_Key, &a0, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->insert(a0, *a1);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaMetaData, sipName_insert, doc_QMediaMetaData_insert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaMetaData_keys, "keys(self) -> list[QMediaMetaData.Key]");

extern "C" {static PyObject *meth_QMediaMetaData_keys(PyObject *, PyObject *);}
static PyObject *meth_QMediaMetaData_keys(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaMetaData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaMetaData, &sipCpp))
        {
            QList< ::QMediaMetaData::Key>*sipRes;

            sipRes = new QList< ::QMediaMetaData::Key>(sipCpp->keys());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QMediaMetaData_Key, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaMetaData, sipName_keys, doc_QMediaMetaData_keys);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaMetaData_stringValue, "stringValue(self, k: QMediaMetaData.Key) -> str");

extern "C" {static PyObject *meth_QMediaMetaData_stringValue(PyObject *, PyObject *);}
static PyObject *meth_QMediaMetaData_stringValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaMetaData::Key a0;
        const ::QMediaMetaData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QMediaMetaData, &sipCpp, sipType_QMediaMetaData_Key, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->stringValue(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaMetaData, sipName_stringValue, doc_QMediaMetaData_stringValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaMetaData_metaDataKeyToString, "metaDataKeyToString(k: QMediaMetaData.Key) -> str");

extern "C" {static PyObject *meth_QMediaMetaData_metaDataKeyToString(PyObject *, PyObject *);}
static PyObject *meth_QMediaMetaData_metaDataKeyToString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaMetaData::Key a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QMediaMetaData_Key, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QMediaMetaData::metaDataKeyToString(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaMetaData, sipName_metaDataKeyToString, doc_QMediaMetaData_metaDataKeyToString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaMetaData_keyType, "keyType(key: QMediaMetaData.Key) -> QMetaType");

extern "C" {static PyObject *meth_QMediaMetaData_keyType(PyObject *, PyObject *);}
static PyObject *meth_QMediaMetaData_keyType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaMetaData::Key a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QMediaMetaData_Key, &a0))
        {
            ::QMetaType*sipRes;

            sipRes = reinterpret_cast< ::QMetaType *>(::operator new(sizeof (::QMetaType)));
            *sipRes = ::QMediaMetaData::keyType(a0);

            return sipConvertFromNewType(sipRes, sipType_QMetaType, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaMetaData, sipName_keyType, doc_QMediaMetaData_keyType);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QMediaMetaData___eq__(PyObject *, PyObject *);}
static PyObject *slot_QMediaMetaData___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QMediaMetaData *sipCpp = reinterpret_cast< ::QMediaMetaData *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QMediaMetaData));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaMetaData* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QMediaMetaData, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, eq_slot, sipType_QMediaMetaData, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QMediaMetaData___ne__(PyObject *, PyObject *);}
static PyObject *slot_QMediaMetaData___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QMediaMetaData *sipCpp = reinterpret_cast< ::QMediaMetaData *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QMediaMetaData));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaMetaData* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QMediaMetaData, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, ne_slot, sipType_QMediaMetaData, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QMediaMetaData(void *, int);}
static void release_QMediaMetaData(void *sipCppV, int)
{
    delete reinterpret_cast< ::QMediaMetaData *>(sipCppV);
}


extern "C" {static void *array_QMediaMetaData(Py_ssize_t);}
static void *array_QMediaMetaData(Py_ssize_t sipNrElem)
{
    return new ::QMediaMetaData[sipNrElem];
}


extern "C" {static void array_delete_QMediaMetaData(void *);}
static void array_delete_QMediaMetaData(void *sipCpp)
{
    delete[] reinterpret_cast< ::QMediaMetaData *>(sipCpp);
}


extern "C" {static void assign_QMediaMetaData(void *, Py_ssize_t, void *);}
static void assign_QMediaMetaData(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QMediaMetaData *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QMediaMetaData *>(sipSrc);
}


extern "C" {static void *copy_QMediaMetaData(const void *, Py_ssize_t);}
static void *copy_QMediaMetaData(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QMediaMetaData(reinterpret_cast<const ::QMediaMetaData *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QMediaMetaData(sipSimpleWrapper *);}
static void dealloc_QMediaMetaData(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMediaMetaData(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QMediaMetaData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMediaMetaData(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QMediaMetaData *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QMediaMetaData();

            return sipCpp;
        }
    }

    {
        const ::QMediaMetaData* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QMediaMetaData, &a0))
        {
            sipCpp = new ::QMediaMetaData(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QMediaMetaData[] = {
    {(void *)slot_QMediaMetaData___eq__, eq_slot},
    {(void *)slot_QMediaMetaData___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QMediaMetaData[] = {
    {sipName_insert, meth_QMediaMetaData_insert, METH_VARARGS, doc_QMediaMetaData_insert},
    {sipName_keyType, meth_QMediaMetaData_keyType, METH_VARARGS, doc_QMediaMetaData_keyType},
    {sipName_keys, meth_QMediaMetaData_keys, METH_VARARGS, doc_QMediaMetaData_keys},
    {sipName_metaDataKeyToString, meth_QMediaMetaData_metaDataKeyToString, METH_VARARGS, doc_QMediaMetaData_metaDataKeyToString},
    {sipName_stringValue, meth_QMediaMetaData_stringValue, METH_VARARGS, doc_QMediaMetaData_stringValue},
    {sipName_value, meth_QMediaMetaData_value, METH_VARARGS, doc_QMediaMetaData_value}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QMediaMetaData[] = {
    {sipName_Title, static_cast<int>(::QMediaMetaData::Title)},
    {sipName_Author, static_cast<int>(::QMediaMetaData::Author)},
    {sipName_Comment, static_cast<int>(::QMediaMetaData::Comment)},
    {sipName_Description, static_cast<int>(::QMediaMetaData::Description)},
    {sipName_Genre, static_cast<int>(::QMediaMetaData::Genre)},
    {sipName_Date, static_cast<int>(::QMediaMetaData::Date)},
    {sipName_Language, static_cast<int>(::QMediaMetaData::Language)},
    {sipName_Publisher, static_cast<int>(::QMediaMetaData::Publisher)},
    {sipName_Copyright, static_cast<int>(::QMediaMetaData::Copyright)},
    {sipName_Url, static_cast<int>(::QMediaMetaData::Url)},
    {sipName_Duration, static_cast<int>(::QMediaMetaData::Duration)},
    {sipName_MediaType, static_cast<int>(::QMediaMetaData::MediaType)},
    {sipName_FileFormat, static_cast<int>(::QMediaMetaData::FileFormat)},
    {sipName_AudioBitRate, static_cast<int>(::QMediaMetaData::AudioBitRate)},
    {sipName_AudioCodec, static_cast<int>(::QMediaMetaData::AudioCodec)},
    {sipName_VideoBitRate, static_cast<int>(::QMediaMetaData::VideoBitRate)},
    {sipName_VideoCodec, static_cast<int>(::QMediaMetaData::VideoCodec)},
    {sipName_VideoFrameRate, static_cast<int>(::QMediaMetaData::VideoFrameRate)},
    {sipName_AlbumTitle, static_cast<int>(::QMediaMetaData::AlbumTitle)},
    {sipName_AlbumArtist, static_cast<int>(::QMediaMetaData::AlbumArtist)},
    {sipName_ContributingArtist, static_cast<int>(::QMediaMetaData::ContributingArtist)},
    {sipName_TrackNumber, static_cast<int>(::QMediaMetaData::TrackNumber)},
    {sipName_Composer, static_cast<int>(::QMediaMetaData::Composer)},
    {sipName_LeadPerformer, static_cast<int>(::QMediaMetaData::LeadPerformer)},
    {sipName_ThumbnailImage, static_cast<int>(::QMediaMetaData::ThumbnailImage)},
    {sipName_CoverArtImage, static_cast<int>(::QMediaMetaData::CoverArtImage)},
    {sipName_Orientation, static_cast<int>(::QMediaMetaData::Orientation)},
    {sipName_Resolution, static_cast<int>(::QMediaMetaData::Resolution)},
    {sipName_HasHdrContent, static_cast<int>(::QMediaMetaData::HasHdrContent)},
    {0, 0}
};

PyDoc_STRVAR(doc_QMediaMetaData, "\1QMediaMetaData()\n"
"QMediaMetaData(a0: QMediaMetaData)");


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaMetaData = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMediaMetaData,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QMediaMetaData,
        {0, 0, 1},
        6, methods_QMediaMetaData,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QMediaMetaData, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMediaMetaData,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QMediaMetaData,
    init_type_QMediaMetaData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMediaMetaData,
    assign_QMediaMetaData,
    array_QMediaMetaData,
    copy_QMediaMetaData,
    release_QMediaMetaData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QMediaMetaData,
    sizeof (::QMediaMetaData),
};
