/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebSockets.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWebSockets/qwebsocketserver.sip"
#include <qwebsocketserver.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslsocket.sip"
#include <qsslsocket.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslerror.sip"
#include <qsslerror.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslpresharedkeyauthenticator.sip"
#include <qsslpresharedkeyauthenticator.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWebSockets/qwebsocketcorsauthenticator.sip"
#include <qwebsocketcorsauthenticator.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWebSockets/qwebsocketprotocol.sip"
#include <qwebsocketprotocol.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qtcpsocket.sip"
#include <qtcpsocket.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qsslconfiguration.sip"
#include <qsslconfiguration.h>
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qnetworkproxy.sip"
#include <qnetworkproxy.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWebSockets/qwebsocket.sip"
#include <qwebsocket.h>
#line 78 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qhostaddress.sip"
#include <qhostaddress.h>
#line 84 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 118 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 124 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 127 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 130 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 133 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWebSockets/sipQtWebSocketsQWebSocketServer.cpp"


class sipQWebSocketServer : public ::QWebSocketServer
{
public:
    sipQWebSocketServer(const ::QString&, ::QWebSocketServer::SslMode, ::QObject*);
    virtual ~sipQWebSocketServer();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QWebSocket* nextPendingConnection() SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQWebSocketServer(const sipQWebSocketServer &);
    sipQWebSocketServer &operator = (const sipQWebSocketServer &);

    char sipPyMethods[8];
};

sipQWebSocketServer::sipQWebSocketServer(const ::QString& a0, ::QWebSocketServer::SslMode a1, ::QObject*a2): ::QWebSocketServer(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQWebSocketServer::~sipQWebSocketServer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQWebSocketServer::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWebSockets_qt_metaobject(sipPySelf, sipType_QWebSocketServer);

    return ::QWebSocketServer::metaObject();
}

int sipQWebSocketServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QWebSocketServer::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWebSockets_qt_metacall(sipPySelf, sipType_QWebSocketServer, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQWebSocketServer::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWebSockets_qt_metacast(sipPySelf, sipType_QWebSocketServer, _clname, &sipCpp) ? sipCpp : ::QWebSocketServer::qt_metacast(_clname));
}

::QWebSocket* sipQWebSocketServer::nextPendingConnection()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_nextPendingConnection);

    if (!sipMeth)
        return ::QWebSocketServer::nextPendingConnection();

    extern ::QWebSocket* sipVH_QtWebSockets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebSockets_8(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQWebSocketServer::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QWebSocketServer::event(a0);

    extern bool sipVH_QtWebSockets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWebSockets_5(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebSocketServer::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QWebSocketServer::eventFilter(a0, a1);

    extern bool sipVH_QtWebSockets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWebSockets_4(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQWebSocketServer::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QWebSocketServer::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWebSockets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWebSockets_3(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebSocketServer::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QWebSocketServer::childEvent(a0);
        return;
    }

    extern void sipVH_QtWebSockets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWebSockets_2(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebSocketServer::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QWebSocketServer::customEvent(a0);
        return;
    }

    extern void sipVH_QtWebSockets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebSockets_1(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebSocketServer::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QWebSocketServer::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWebSockets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebSockets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebSocketServer::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QWebSocketServer::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWebSockets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebSockets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebSockets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QWebSocketServer_listen, "listen(self, address: QHostAddress|QHostAddress.SpecialAddress = QHostAddress.Any, port: int = 0) -> bool");

extern "C" {static PyObject *meth_QWebSocketServer_listen(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_listen(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHostAddress& a0def = QHostAddress::Any;
        const ::QHostAddress* a0 = &a0def;
        int a0State = 0;
        ::quint16 a1 = 0;
        ::QWebSocketServer *sipCpp;

        static const char *sipKwdList[] = {
            sipName_address,
            sipName_port,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1t", &sipSelf, sipType_QWebSocketServer, &sipCpp, sipType_QHostAddress, &a0, &a0State, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->listen(*a0, a1);
            sipReleaseType(const_cast< ::QHostAddress *>(a0), sipType_QHostAddress, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_listen, doc_QWebSocketServer_listen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_close, "close(self)");

extern "C" {static PyObject *meth_QWebSocketServer_close(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_close(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            sipCpp->close();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_close, doc_QWebSocketServer_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_isListening, "isListening(self) -> bool");

extern "C" {static PyObject *meth_QWebSocketServer_isListening(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_isListening(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isListening();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_isListening, doc_QWebSocketServer_isListening);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_setMaxPendingConnections, "setMaxPendingConnections(self, numConnections: int)");

extern "C" {static PyObject *meth_QWebSocketServer_setMaxPendingConnections(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_setMaxPendingConnections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWebSocketServer, &sipCpp, &a0))
        {
            sipCpp->setMaxPendingConnections(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_setMaxPendingConnections, doc_QWebSocketServer_setMaxPendingConnections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_maxPendingConnections, "maxPendingConnections(self) -> int");

extern "C" {static PyObject *meth_QWebSocketServer_maxPendingConnections(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_maxPendingConnections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxPendingConnections();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_maxPendingConnections, doc_QWebSocketServer_maxPendingConnections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_serverPort, "serverPort(self) -> int");

extern "C" {static PyObject *meth_QWebSocketServer_serverPort(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_serverPort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::quint16 sipRes;

            sipRes = sipCpp->serverPort();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_serverPort, doc_QWebSocketServer_serverPort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_serverAddress, "serverAddress(self) -> QHostAddress");

extern "C" {static PyObject *meth_QWebSocketServer_serverAddress(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_serverAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::QHostAddress*sipRes;

            sipRes = new ::QHostAddress(sipCpp->serverAddress());

            return sipConvertFromNewType(sipRes, sipType_QHostAddress, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_serverAddress, doc_QWebSocketServer_serverAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_secureMode, "secureMode(self) -> QWebSocketServer.SslMode");

extern "C" {static PyObject *meth_QWebSocketServer_secureMode(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_secureMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::QWebSocketServer::SslMode sipRes;

            sipRes = sipCpp->secureMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QWebSocketServer_SslMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_secureMode, doc_QWebSocketServer_secureMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_setSocketDescriptor, "setSocketDescriptor(self, socketDescriptor: PyQt6.sip.voidptr) -> bool");

extern "C" {static PyObject *meth_QWebSocketServer_setSocketDescriptor(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_setSocketDescriptor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qintptr* a0;
        int a0State = 0;
        ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebSocketServer, &sipCpp, sipType_qintptr, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->setSocketDescriptor(*a0);
            sipReleaseType(a0, sipType_qintptr, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_setSocketDescriptor, doc_QWebSocketServer_setSocketDescriptor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_socketDescriptor, "socketDescriptor(self) -> PyQt6.sip.voidptr");

extern "C" {static PyObject *meth_QWebSocketServer_socketDescriptor(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_socketDescriptor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::qintptr*sipRes;

            sipRes = new ::qintptr(sipCpp->socketDescriptor());

            return sipConvertFromNewType(sipRes, sipType_qintptr, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_socketDescriptor, doc_QWebSocketServer_socketDescriptor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_hasPendingConnections, "hasPendingConnections(self) -> bool");

extern "C" {static PyObject *meth_QWebSocketServer_hasPendingConnections(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_hasPendingConnections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasPendingConnections();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_hasPendingConnections, doc_QWebSocketServer_hasPendingConnections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_nextPendingConnection, "nextPendingConnection(self) -> QWebSocket|None");

extern "C" {static PyObject *meth_QWebSocketServer_nextPendingConnection(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_nextPendingConnection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QWebSocketServer)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::QWebSocket*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebSocketServer::nextPendingConnection() : sipCpp->nextPendingConnection());

            return sipConvertFromType(sipRes, sipType_QWebSocket, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_nextPendingConnection, doc_QWebSocketServer_nextPendingConnection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_error, "error(self) -> QWebSocketProtocol.CloseCode");

extern "C" {static PyObject *meth_QWebSocketServer_error(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::QWebSocketProtocol::CloseCode sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QWebSocketProtocol_CloseCode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_error, doc_QWebSocketServer_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QWebSocketServer_errorString(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_errorString, doc_QWebSocketServer_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_pauseAccepting, "pauseAccepting(self)");

extern "C" {static PyObject *meth_QWebSocketServer_pauseAccepting(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_pauseAccepting(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            sipCpp->pauseAccepting();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_pauseAccepting, doc_QWebSocketServer_pauseAccepting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_resumeAccepting, "resumeAccepting(self)");

extern "C" {static PyObject *meth_QWebSocketServer_resumeAccepting(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_resumeAccepting(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            sipCpp->resumeAccepting();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_resumeAccepting, doc_QWebSocketServer_resumeAccepting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_setServerName, "setServerName(self, serverName: str|None)");

extern "C" {static PyObject *meth_QWebSocketServer_setServerName(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_setServerName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebSocketServer, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setServerName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_setServerName, doc_QWebSocketServer_setServerName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_serverName, "serverName(self) -> str");

extern "C" {static PyObject *meth_QWebSocketServer_serverName(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_serverName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->serverName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_serverName, doc_QWebSocketServer_serverName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_setProxy, "setProxy(self, networkProxy: QNetworkProxy)");

extern "C" {static PyObject *meth_QWebSocketServer_setProxy(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_setProxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNetworkProxy* a0;
        ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebSocketServer, &sipCpp, sipType_QNetworkProxy, &a0))
        {
            sipCpp->setProxy(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_setProxy, doc_QWebSocketServer_setProxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_proxy, "proxy(self) -> QNetworkProxy");

extern "C" {static PyObject *meth_QWebSocketServer_proxy(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_proxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::QNetworkProxy*sipRes;

            sipRes = new ::QNetworkProxy(sipCpp->proxy());

            return sipConvertFromNewType(sipRes, sipType_QNetworkProxy, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_proxy, doc_QWebSocketServer_proxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_setSslConfiguration, "setSslConfiguration(self, sslConfiguration: QSslConfiguration)");

extern "C" {static PyObject *meth_QWebSocketServer_setSslConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_setSslConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSslConfiguration* a0;
        ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebSocketServer, &sipCpp, sipType_QSslConfiguration, &a0))
        {
            sipCpp->setSslConfiguration(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_setSslConfiguration, doc_QWebSocketServer_setSslConfiguration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_sslConfiguration, "sslConfiguration(self) -> QSslConfiguration");

extern "C" {static PyObject *meth_QWebSocketServer_sslConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_sslConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::QSslConfiguration*sipRes;

            sipRes = new ::QSslConfiguration(sipCpp->sslConfiguration());

            return sipConvertFromNewType(sipRes, sipType_QSslConfiguration, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_sslConfiguration, doc_QWebSocketServer_sslConfiguration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_supportedVersions, "supportedVersions(self) -> list[QWebSocketProtocol.Version]");

extern "C" {static PyObject *meth_QWebSocketServer_supportedVersions(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_supportedVersions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            QList< ::QWebSocketProtocol::Version>*sipRes;

            sipRes = new QList< ::QWebSocketProtocol::Version>(sipCpp->supportedVersions());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QWebSocketProtocol_Version, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_supportedVersions, doc_QWebSocketServer_supportedVersions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_serverUrl, "serverUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QWebSocketServer_serverUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_serverUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->serverUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_serverUrl, doc_QWebSocketServer_serverUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_handleConnection, "handleConnection(self, socket: QTcpSocket|None)");

extern "C" {static PyObject *meth_QWebSocketServer_handleConnection(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_handleConnection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTcpSocket* a0;
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebSocketServer, &sipCpp, sipType_QTcpSocket, &a0))
        {
            sipCpp->handleConnection(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_handleConnection, doc_QWebSocketServer_handleConnection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_setHandshakeTimeout, "setHandshakeTimeout(self, msec: int)");

extern "C" {static PyObject *meth_QWebSocketServer_setHandshakeTimeout(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_setHandshakeTimeout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWebSocketServer, &sipCpp, &a0))
        {
            sipCpp->setHandshakeTimeout(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_setHandshakeTimeout, doc_QWebSocketServer_setHandshakeTimeout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_handshakeTimeoutMS, "handshakeTimeoutMS(self) -> int");

extern "C" {static PyObject *meth_QWebSocketServer_handshakeTimeoutMS(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_handshakeTimeoutMS(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->handshakeTimeoutMS();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_handshakeTimeoutMS, doc_QWebSocketServer_handshakeTimeoutMS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_setSupportedSubprotocols, "setSupportedSubprotocols(self, protocols: Iterable[str|None])");

extern "C" {static PyObject *meth_QWebSocketServer_setSupportedSubprotocols(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_setSupportedSubprotocols(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebSocketServer, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setSupportedSubprotocols(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_setSupportedSubprotocols, doc_QWebSocketServer_setSupportedSubprotocols);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSocketServer_supportedSubprotocols, "supportedSubprotocols(self) -> list[str]");

extern "C" {static PyObject *meth_QWebSocketServer_supportedSubprotocols(PyObject *, PyObject *);}
static PyObject *meth_QWebSocketServer_supportedSubprotocols(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSocketServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSocketServer, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->supportedSubprotocols());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSocketServer, sipName_supportedSubprotocols, doc_QWebSocketServer_supportedSubprotocols);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWebSocketServer(void *, const sipTypeDef *);}
static void *cast_QWebSocketServer(void *sipCppV, const sipTypeDef *targetType)
{
    ::QWebSocketServer *sipCpp = reinterpret_cast< ::QWebSocketServer *>(sipCppV);

    if (targetType == sipType_QWebSocketServer)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebSocketServer(void *, int);}
static void release_QWebSocketServer(void *sipCppV, int)
{
    ::QWebSocketServer *sipCpp = reinterpret_cast< ::QWebSocketServer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QWebSocketServer(sipSimpleWrapper *);}
static void dealloc_QWebSocketServer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQWebSocketServer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebSocketServer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QWebSocketServer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebSocketServer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQWebSocketServer *sipCpp = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebSocketServer::SslMode a1;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1E|JH", sipType_QString, &a0, &a0State, sipType_QWebSocketServer_SslMode, &a1, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQWebSocketServer(*a0, a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWebSocketServer[] = {{4, 0, 1}};


static PyMethodDef methods_QWebSocketServer[] = {
    {sipName_close, meth_QWebSocketServer_close, METH_VARARGS, doc_QWebSocketServer_close},
    {sipName_error, meth_QWebSocketServer_error, METH_VARARGS, doc_QWebSocketServer_error},
    {sipName_errorString, meth_QWebSocketServer_errorString, METH_VARARGS, doc_QWebSocketServer_errorString},
    {sipName_handleConnection, meth_QWebSocketServer_handleConnection, METH_VARARGS, doc_QWebSocketServer_handleConnection},
    {sipName_handshakeTimeoutMS, meth_QWebSocketServer_handshakeTimeoutMS, METH_VARARGS, doc_QWebSocketServer_handshakeTimeoutMS},
    {sipName_hasPendingConnections, meth_QWebSocketServer_hasPendingConnections, METH_VARARGS, doc_QWebSocketServer_hasPendingConnections},
    {sipName_isListening, meth_QWebSocketServer_isListening, METH_VARARGS, doc_QWebSocketServer_isListening},
    {sipName_listen, SIP_MLMETH_CAST(meth_QWebSocketServer_listen), METH_VARARGS|METH_KEYWORDS, doc_QWebSocketServer_listen},
    {sipName_maxPendingConnections, meth_QWebSocketServer_maxPendingConnections, METH_VARARGS, doc_QWebSocketServer_maxPendingConnections},
    {sipName_nextPendingConnection, meth_QWebSocketServer_nextPendingConnection, METH_VARARGS, doc_QWebSocketServer_nextPendingConnection},
    {sipName_pauseAccepting, meth_QWebSocketServer_pauseAccepting, METH_VARARGS, doc_QWebSocketServer_pauseAccepting},
    {sipName_proxy, meth_QWebSocketServer_proxy, METH_VARARGS, doc_QWebSocketServer_proxy},
    {sipName_resumeAccepting, meth_QWebSocketServer_resumeAccepting, METH_VARARGS, doc_QWebSocketServer_resumeAccepting},
    {sipName_secureMode, meth_QWebSocketServer_secureMode, METH_VARARGS, doc_QWebSocketServer_secureMode},
    {sipName_serverAddress, meth_QWebSocketServer_serverAddress, METH_VARARGS, doc_QWebSocketServer_serverAddress},
    {sipName_serverName, meth_QWebSocketServer_serverName, METH_VARARGS, doc_QWebSocketServer_serverName},
    {sipName_serverPort, meth_QWebSocketServer_serverPort, METH_VARARGS, doc_QWebSocketServer_serverPort},
    {sipName_serverUrl, meth_QWebSocketServer_serverUrl, METH_VARARGS, doc_QWebSocketServer_serverUrl},
    {sipName_setHandshakeTimeout, meth_QWebSocketServer_setHandshakeTimeout, METH_VARARGS, doc_QWebSocketServer_setHandshakeTimeout},
    {sipName_setMaxPendingConnections, meth_QWebSocketServer_setMaxPendingConnections, METH_VARARGS, doc_QWebSocketServer_setMaxPendingConnections},
    {sipName_setProxy, meth_QWebSocketServer_setProxy, METH_VARARGS, doc_QWebSocketServer_setProxy},
    {sipName_setServerName, meth_QWebSocketServer_setServerName, METH_VARARGS, doc_QWebSocketServer_setServerName},
    {sipName_setSocketDescriptor, meth_QWebSocketServer_setSocketDescriptor, METH_VARARGS, doc_QWebSocketServer_setSocketDescriptor},
    {sipName_setSslConfiguration, meth_QWebSocketServer_setSslConfiguration, METH_VARARGS, doc_QWebSocketServer_setSslConfiguration},
    {sipName_setSupportedSubprotocols, meth_QWebSocketServer_setSupportedSubprotocols, METH_VARARGS, doc_QWebSocketServer_setSupportedSubprotocols},
    {sipName_socketDescriptor, meth_QWebSocketServer_socketDescriptor, METH_VARARGS, doc_QWebSocketServer_socketDescriptor},
    {sipName_sslConfiguration, meth_QWebSocketServer_sslConfiguration, METH_VARARGS, doc_QWebSocketServer_sslConfiguration},
    {sipName_supportedSubprotocols, meth_QWebSocketServer_supportedSubprotocols, METH_VARARGS, doc_QWebSocketServer_supportedSubprotocols},
    {sipName_supportedVersions, meth_QWebSocketServer_supportedVersions, METH_VARARGS, doc_QWebSocketServer_supportedVersions}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QWebSocketServer[] = {
    {sipName_SecureMode, static_cast<int>(::QWebSocketServer::SecureMode)},
    {sipName_NonSecureMode, static_cast<int>(::QWebSocketServer::NonSecureMode)},
    {0, 0}
};

PyDoc_STRVAR(doc_QWebSocketServer, "\1QWebSocketServer(serverName: str|None, secureMode: QWebSocketServer.SslMode, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QWebSocketServer[] = {
    {"sslErrorsOccurred(QSslSocket*,QList<QSslError>)", "\1sslErrorsOccurred(self, socket: QSslSocket|None, errors: Iterable[QSslError])", SIP_NULLPTR, SIP_NULLPTR},
    {"preSharedKeyAuthenticationRequired(QSslPreSharedKeyAuthenticator*)", "\1preSharedKeyAuthenticationRequired(self, authenticator: QSslPreSharedKeyAuthenticator|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"closed()", "\1closed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"sslErrors(QList<QSslError>)", "\1sslErrors(self, errors: Iterable[QSslError])", SIP_NULLPTR, SIP_NULLPTR},
    {"peerVerifyError(QSslError)", "\1peerVerifyError(self, error: QSslError)", SIP_NULLPTR, SIP_NULLPTR},
    {"newConnection()", "\1newConnection(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"originAuthenticationRequired(QWebSocketCorsAuthenticator*)", "\1originAuthenticationRequired(self, pAuthenticator: QWebSocketCorsAuthenticator|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"serverError(QWebSocketProtocol::CloseCode)", "\1serverError(self, closeCode: QWebSocketProtocol.CloseCode)", SIP_NULLPTR, SIP_NULLPTR},
    {"acceptError(QAbstractSocket::SocketError)", "\1acceptError(self, socketError: QAbstractSocket.SocketError)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QWebSocketServer = {
    &::QWebSocketServer::staticMetaObject,
    signals_QWebSocketServer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebSockets_QWebSocketServer = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebSocketServer,
        SIP_NULLPTR,
        &plugin_QWebSocketServer,
    },
    {
        sipNameNr_QWebSocketServer,
        {0, 0, 1},
        29, methods_QWebSocketServer,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QWebSocketServer, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebSocketServer,
    -1,
    -1,
    supers_QWebSocketServer,
    SIP_NULLPTR,
    init_type_QWebSocketServer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebSocketServer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QWebSocketServer,
    cast_QWebSocketServer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QWebSocketServer),
};
