/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qlowenergycharacteristic.sip"
#include <qlowenergycharacteristic.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyCharacteristic.cpp"

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyCharacteristic.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qlowenergydescriptor.sip"
#include <qlowenergydescriptor.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyCharacteristic.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyCharacteristic.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothuuid.sip"
#include <qbluetoothuuid.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyCharacteristic.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyCharacteristic.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQLowEnergyCharacteristic.cpp"


PyDoc_STRVAR(doc_QLowEnergyCharacteristic_name, "name(self) -> str");

extern "C" {static PyObject *meth_QLowEnergyCharacteristic_name(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyCharacteristic_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyCharacteristic, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyCharacteristic, sipName_name, doc_QLowEnergyCharacteristic_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyCharacteristic_uuid, "uuid(self) -> QBluetoothUuid");

extern "C" {static PyObject *meth_QLowEnergyCharacteristic_uuid(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyCharacteristic_uuid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyCharacteristic, &sipCpp))
        {
            ::QBluetoothUuid*sipRes;

            sipRes = new ::QBluetoothUuid(sipCpp->uuid());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothUuid, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyCharacteristic, sipName_uuid, doc_QLowEnergyCharacteristic_uuid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyCharacteristic_value, "value(self) -> QByteArray");

extern "C" {static PyObject *meth_QLowEnergyCharacteristic_value(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyCharacteristic_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyCharacteristic, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->value());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyCharacteristic, sipName_value, doc_QLowEnergyCharacteristic_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyCharacteristic_properties, "properties(self) -> QLowEnergyCharacteristic.PropertyType");

extern "C" {static PyObject *meth_QLowEnergyCharacteristic_properties(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyCharacteristic_properties(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyCharacteristic, &sipCpp))
        {
            ::QLowEnergyCharacteristic::PropertyTypes*sipRes;

            sipRes = new ::QLowEnergyCharacteristic::PropertyTypes(sipCpp->properties());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QLowEnergyCharacteristic_PropertyType, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyCharacteristic, sipName_properties, doc_QLowEnergyCharacteristic_properties);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyCharacteristic_descriptor, "descriptor(self, uuid: QBluetoothUuid) -> QLowEnergyDescriptor");

extern "C" {static PyObject *meth_QLowEnergyCharacteristic_descriptor(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyCharacteristic_descriptor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothUuid* a0;
        const ::QLowEnergyCharacteristic *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLowEnergyCharacteristic, &sipCpp, sipType_QBluetoothUuid, &a0))
        {
            ::QLowEnergyDescriptor*sipRes;

            sipRes = new ::QLowEnergyDescriptor(sipCpp->descriptor(*a0));

            return sipConvertFromNewType(sipRes, sipType_QLowEnergyDescriptor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyCharacteristic, sipName_descriptor, doc_QLowEnergyCharacteristic_descriptor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyCharacteristic_descriptors, "descriptors(self) -> list[QLowEnergyDescriptor]");

extern "C" {static PyObject *meth_QLowEnergyCharacteristic_descriptors(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyCharacteristic_descriptors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyCharacteristic, &sipCpp))
        {
            QList< ::QLowEnergyDescriptor>*sipRes;

            sipRes = new QList< ::QLowEnergyDescriptor>(sipCpp->descriptors());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QLowEnergyDescriptor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyCharacteristic, sipName_descriptors, doc_QLowEnergyCharacteristic_descriptors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyCharacteristic_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QLowEnergyCharacteristic_isValid(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyCharacteristic_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyCharacteristic, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyCharacteristic, sipName_isValid, doc_QLowEnergyCharacteristic_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLowEnergyCharacteristic_clientCharacteristicConfiguration, "clientCharacteristicConfiguration(self) -> QLowEnergyDescriptor");

extern "C" {static PyObject *meth_QLowEnergyCharacteristic_clientCharacteristicConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QLowEnergyCharacteristic_clientCharacteristicConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLowEnergyCharacteristic, &sipCpp))
        {
            ::QLowEnergyDescriptor*sipRes;

            sipRes = new ::QLowEnergyDescriptor(sipCpp->clientCharacteristicConfiguration());

            return sipConvertFromNewType(sipRes, sipType_QLowEnergyDescriptor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLowEnergyCharacteristic, sipName_clientCharacteristicConfiguration, doc_QLowEnergyCharacteristic_clientCharacteristicConfiguration);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QLowEnergyCharacteristic___eq__(PyObject *, PyObject *);}
static PyObject *slot_QLowEnergyCharacteristic___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLowEnergyCharacteristic *sipCpp = reinterpret_cast< ::QLowEnergyCharacteristic *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLowEnergyCharacteristic));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLowEnergyCharacteristic, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, eq_slot, sipType_QLowEnergyCharacteristic, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QLowEnergyCharacteristic___ne__(PyObject *, PyObject *);}
static PyObject *slot_QLowEnergyCharacteristic___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLowEnergyCharacteristic *sipCpp = reinterpret_cast< ::QLowEnergyCharacteristic *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLowEnergyCharacteristic));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLowEnergyCharacteristic* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLowEnergyCharacteristic, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, ne_slot, sipType_QLowEnergyCharacteristic, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QLowEnergyCharacteristic(void *, int);}
static void release_QLowEnergyCharacteristic(void *sipCppV, int)
{
    delete reinterpret_cast< ::QLowEnergyCharacteristic *>(sipCppV);
}


extern "C" {static void *array_QLowEnergyCharacteristic(Py_ssize_t);}
static void *array_QLowEnergyCharacteristic(Py_ssize_t sipNrElem)
{
    return new ::QLowEnergyCharacteristic[sipNrElem];
}


extern "C" {static void array_delete_QLowEnergyCharacteristic(void *);}
static void array_delete_QLowEnergyCharacteristic(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLowEnergyCharacteristic *>(sipCpp);
}


extern "C" {static void assign_QLowEnergyCharacteristic(void *, Py_ssize_t, void *);}
static void assign_QLowEnergyCharacteristic(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QLowEnergyCharacteristic *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QLowEnergyCharacteristic *>(sipSrc);
}


extern "C" {static void *copy_QLowEnergyCharacteristic(const void *, Py_ssize_t);}
static void *copy_QLowEnergyCharacteristic(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QLowEnergyCharacteristic(reinterpret_cast<const ::QLowEnergyCharacteristic *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QLowEnergyCharacteristic(sipSimpleWrapper *);}
static void dealloc_QLowEnergyCharacteristic(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLowEnergyCharacteristic(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QLowEnergyCharacteristic(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLowEnergyCharacteristic(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QLowEnergyCharacteristic *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QLowEnergyCharacteristic();

            return sipCpp;
        }
    }

    {
        const ::QLowEnergyCharacteristic* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QLowEnergyCharacteristic, &a0))
        {
            sipCpp = new ::QLowEnergyCharacteristic(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QLowEnergyCharacteristic[] = {
    {(void *)slot_QLowEnergyCharacteristic___eq__, eq_slot},
    {(void *)slot_QLowEnergyCharacteristic___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QLowEnergyCharacteristic[] = {
    {sipName_clientCharacteristicConfiguration, meth_QLowEnergyCharacteristic_clientCharacteristicConfiguration, METH_VARARGS, doc_QLowEnergyCharacteristic_clientCharacteristicConfiguration},
    {sipName_descriptor, meth_QLowEnergyCharacteristic_descriptor, METH_VARARGS, doc_QLowEnergyCharacteristic_descriptor},
    {sipName_descriptors, meth_QLowEnergyCharacteristic_descriptors, METH_VARARGS, doc_QLowEnergyCharacteristic_descriptors},
    {sipName_isValid, meth_QLowEnergyCharacteristic_isValid, METH_VARARGS, doc_QLowEnergyCharacteristic_isValid},
    {sipName_name, meth_QLowEnergyCharacteristic_name, METH_VARARGS, doc_QLowEnergyCharacteristic_name},
    {sipName_properties, meth_QLowEnergyCharacteristic_properties, METH_VARARGS, doc_QLowEnergyCharacteristic_properties},
    {sipName_uuid, meth_QLowEnergyCharacteristic_uuid, METH_VARARGS, doc_QLowEnergyCharacteristic_uuid},
    {sipName_value, meth_QLowEnergyCharacteristic_value, METH_VARARGS, doc_QLowEnergyCharacteristic_value}
};


extern "C" {static PyObject *varget_QLowEnergyCharacteristic_CCCDDisable(void *, PyObject *, PyObject *);}
static PyObject *varget_QLowEnergyCharacteristic_CCCDDisable(void *, PyObject *, PyObject *)
{
    const ::QByteArray*sipVal;

    sipVal = new ::QByteArray(::QLowEnergyCharacteristic::CCCDDisable);

    return sipConvertFromNewType(const_cast< ::QByteArray *>(sipVal), sipType_QByteArray, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QLowEnergyCharacteristic_CCCDEnableIndication(void *, PyObject *, PyObject *);}
static PyObject *varget_QLowEnergyCharacteristic_CCCDEnableIndication(void *, PyObject *, PyObject *)
{
    const ::QByteArray*sipVal;

    sipVal = new ::QByteArray(::QLowEnergyCharacteristic::CCCDEnableIndication);

    return sipConvertFromNewType(const_cast< ::QByteArray *>(sipVal), sipType_QByteArray, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QLowEnergyCharacteristic_CCCDEnableNotification(void *, PyObject *, PyObject *);}
static PyObject *varget_QLowEnergyCharacteristic_CCCDEnableNotification(void *, PyObject *, PyObject *)
{
    const ::QByteArray*sipVal;

    sipVal = new ::QByteArray(::QLowEnergyCharacteristic::CCCDEnableNotification);

    return sipConvertFromNewType(const_cast< ::QByteArray *>(sipVal), sipType_QByteArray, SIP_NULLPTR);
}

sipVariableDef variables_QLowEnergyCharacteristic[] = {
    {ClassVariable, sipName_CCCDDisable, (PyMethodDef *)varget_QLowEnergyCharacteristic_CCCDDisable, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_CCCDEnableIndication, (PyMethodDef *)varget_QLowEnergyCharacteristic_CCCDEnableIndication, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_CCCDEnableNotification, (PyMethodDef *)varget_QLowEnergyCharacteristic_CCCDEnableNotification, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QLowEnergyCharacteristic[] = {
    {sipName_Unknown, static_cast<int>(::QLowEnergyCharacteristic::Unknown)},
    {sipName_Broadcasting, static_cast<int>(::QLowEnergyCharacteristic::Broadcasting)},
    {sipName_Read, static_cast<int>(::QLowEnergyCharacteristic::Read)},
    {sipName_WriteNoResponse, static_cast<int>(::QLowEnergyCharacteristic::WriteNoResponse)},
    {sipName_Write, static_cast<int>(::QLowEnergyCharacteristic::Write)},
    {sipName_Notify, static_cast<int>(::QLowEnergyCharacteristic::Notify)},
    {sipName_Indicate, static_cast<int>(::QLowEnergyCharacteristic::Indicate)},
    {sipName_WriteSigned, static_cast<int>(::QLowEnergyCharacteristic::WriteSigned)},
    {sipName_ExtendedProperty, static_cast<int>(::QLowEnergyCharacteristic::ExtendedProperty)},
    {0, 0}
};

PyDoc_STRVAR(doc_QLowEnergyCharacteristic, "\1QLowEnergyCharacteristic()\n"
"QLowEnergyCharacteristic(other: QLowEnergyCharacteristic)");


sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyCharacteristic = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLowEnergyCharacteristic,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QLowEnergyCharacteristic,
        {0, 0, 1},
        8, methods_QLowEnergyCharacteristic,
        3, variables_QLowEnergyCharacteristic,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QLowEnergyCharacteristic, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLowEnergyCharacteristic,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QLowEnergyCharacteristic,
    init_type_QLowEnergyCharacteristic,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLowEnergyCharacteristic,
    assign_QLowEnergyCharacteristic,
    array_QLowEnergyCharacteristic,
    copy_QLowEnergyCharacteristic,
    release_QLowEnergyCharacteristic,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLowEnergyCharacteristic,
    sizeof (::QLowEnergyCharacteristic),
};
