/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/container.sip"
#include <container.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerContainerExtension.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerContainerExtension.cpp"


class sipQDesignerContainerExtension : public ::QDesignerContainerExtension
{
public:
    sipQDesignerContainerExtension();
    virtual ~sipQDesignerContainerExtension();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool canRemove(int) const SIP_OVERRIDE;
    bool canAddWidget() const SIP_OVERRIDE;
    void remove(int) SIP_OVERRIDE;
    void insertWidget(int, ::QWidget*) SIP_OVERRIDE;
    void addWidget(::QWidget*) SIP_OVERRIDE;
    void setCurrentIndex(int) SIP_OVERRIDE;
    int currentIndex() const SIP_OVERRIDE;
    ::QWidget* widget(int) const SIP_OVERRIDE;
    int count() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQDesignerContainerExtension(const sipQDesignerContainerExtension &);
    sipQDesignerContainerExtension &operator = (const sipQDesignerContainerExtension &);

    char sipPyMethods[9];
};

sipQDesignerContainerExtension::sipQDesignerContainerExtension(): ::QDesignerContainerExtension(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQDesignerContainerExtension::~sipQDesignerContainerExtension()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

bool sipQDesignerContainerExtension::canRemove(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerContainerExtension, sipName_canRemove);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQDesignerContainerExtension::canAddWidget() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerContainerExtension, sipName_canAddWidget);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_3(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQDesignerContainerExtension::remove(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, sipName_QDesignerContainerExtension, sipName_remove);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_78(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtDesigner_78(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerContainerExtension::insertWidget(int a0, ::QWidget*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, sipName_QDesignerContainerExtension, sipName_insertWidget);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_79(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::QWidget*);

    sipVH_QtDesigner_79(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQDesignerContainerExtension::addWidget(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, sipName_QDesignerContainerExtension, sipName_addWidget);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_QtDesigner_57(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDesignerContainerExtension::setCurrentIndex(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, sipName_QDesignerContainerExtension, sipName_setCurrentIndex);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_78(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtDesigner_78(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQDesignerContainerExtension::currentIndex() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerContainerExtension, sipName_currentIndex);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtDesigner_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_29(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QWidget* sipQDesignerContainerExtension::widget(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerContainerExtension, sipName_widget);

    if (!sipMeth)
        return 0;

    extern ::QWidget* sipVH_QtDesigner_67(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_67(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQDesignerContainerExtension::count() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerContainerExtension, sipName_count);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtDesigner_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_29(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QDesignerContainerExtension_count, "count(self) -> int");

extern "C" {static PyObject *meth_QDesignerContainerExtension_count(PyObject *, PyObject *);}
static PyObject *meth_QDesignerContainerExtension_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerContainerExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerContainerExtension, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerContainerExtension, sipName_count);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerContainerExtension, sipName_count, doc_QDesignerContainerExtension_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerContainerExtension_widget, "widget(self, index: int) -> QWidget|None");

extern "C" {static PyObject *meth_QDesignerContainerExtension_widget(PyObject *, PyObject *);}
static PyObject *meth_QDesignerContainerExtension_widget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerContainerExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerContainerExtension, &sipCpp, &a0))
        {
            ::QWidget*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerContainerExtension, sipName_widget);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->widget(a0);

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerContainerExtension, sipName_widget, doc_QDesignerContainerExtension_widget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerContainerExtension_currentIndex, "currentIndex(self) -> int");

extern "C" {static PyObject *meth_QDesignerContainerExtension_currentIndex(PyObject *, PyObject *);}
static PyObject *meth_QDesignerContainerExtension_currentIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerContainerExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerContainerExtension, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerContainerExtension, sipName_currentIndex);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->currentIndex();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerContainerExtension, sipName_currentIndex, doc_QDesignerContainerExtension_currentIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerContainerExtension_setCurrentIndex, "setCurrentIndex(self, index: int)");

extern "C" {static PyObject *meth_QDesignerContainerExtension_setCurrentIndex(PyObject *, PyObject *);}
static PyObject *meth_QDesignerContainerExtension_setCurrentIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QDesignerContainerExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerContainerExtension, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerContainerExtension, sipName_setCurrentIndex);
                return SIP_NULLPTR;
            }

            sipCpp->setCurrentIndex(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerContainerExtension, sipName_setCurrentIndex, doc_QDesignerContainerExtension_setCurrentIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerContainerExtension_addWidget, "addWidget(self, widget: QWidget|None)");

extern "C" {static PyObject *meth_QDesignerContainerExtension_addWidget(PyObject *, PyObject *);}
static PyObject *meth_QDesignerContainerExtension_addWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QWidget* a0;
        ::QDesignerContainerExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QDesignerContainerExtension, &sipCpp, sipType_QWidget, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerContainerExtension, sipName_addWidget);
                return SIP_NULLPTR;
            }

            sipCpp->addWidget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerContainerExtension, sipName_addWidget, doc_QDesignerContainerExtension_addWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerContainerExtension_insertWidget, "insertWidget(self, index: int, widget: QWidget|None)");

extern "C" {static PyObject *meth_QDesignerContainerExtension_insertWidget(PyObject *, PyObject *);}
static PyObject *meth_QDesignerContainerExtension_insertWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QWidget* a1;
        ::QDesignerContainerExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ8", &sipSelf, sipType_QDesignerContainerExtension, &sipCpp, &a0, sipType_QWidget, &a1))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerContainerExtension, sipName_insertWidget);
                return SIP_NULLPTR;
            }

            sipCpp->insertWidget(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerContainerExtension, sipName_insertWidget, doc_QDesignerContainerExtension_insertWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerContainerExtension_remove, "remove(self, index: int)");

extern "C" {static PyObject *meth_QDesignerContainerExtension_remove(PyObject *, PyObject *);}
static PyObject *meth_QDesignerContainerExtension_remove(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QDesignerContainerExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerContainerExtension, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerContainerExtension, sipName_remove);
                return SIP_NULLPTR;
            }

            sipCpp->remove(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerContainerExtension, sipName_remove, doc_QDesignerContainerExtension_remove);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerContainerExtension_canAddWidget, "canAddWidget(self) -> bool");

extern "C" {static PyObject *meth_QDesignerContainerExtension_canAddWidget(PyObject *, PyObject *);}
static PyObject *meth_QDesignerContainerExtension_canAddWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerContainerExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerContainerExtension, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerContainerExtension, sipName_canAddWidget);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->canAddWidget();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerContainerExtension, sipName_canAddWidget, doc_QDesignerContainerExtension_canAddWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerContainerExtension_canRemove, "canRemove(self, index: int) -> bool");

extern "C" {static PyObject *meth_QDesignerContainerExtension_canRemove(PyObject *, PyObject *);}
static PyObject *meth_QDesignerContainerExtension_canRemove(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const ::QDesignerContainerExtension *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QDesignerContainerExtension, &sipCpp, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerContainerExtension, sipName_canRemove);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->canRemove(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerContainerExtension, sipName_canRemove, doc_QDesignerContainerExtension_canRemove);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QDesignerContainerExtension___len__(PyObject *);}
static Py_ssize_t slot_QDesignerContainerExtension___len__(PyObject *sipSelf)
{
    ::QDesignerContainerExtension *sipCpp = reinterpret_cast< ::QDesignerContainerExtension *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QDesignerContainerExtension));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 528 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQDesignerContainerExtension.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDesignerContainerExtension(void *, int);}
static void release_QDesignerContainerExtension(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQDesignerContainerExtension *>(sipCppV);
    else
        delete reinterpret_cast< ::QDesignerContainerExtension *>(sipCppV);
}


extern "C" {static void dealloc_QDesignerContainerExtension(sipSimpleWrapper *);}
static void dealloc_QDesignerContainerExtension(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQDesignerContainerExtension *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDesignerContainerExtension(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QDesignerContainerExtension(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDesignerContainerExtension(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQDesignerContainerExtension *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQDesignerContainerExtension();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QDesignerContainerExtension[] = {
    {(void *)slot_QDesignerContainerExtension___len__, len_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QDesignerContainerExtension[] = {
    {sipName_addWidget, meth_QDesignerContainerExtension_addWidget, METH_VARARGS, doc_QDesignerContainerExtension_addWidget},
    {sipName_canAddWidget, meth_QDesignerContainerExtension_canAddWidget, METH_VARARGS, doc_QDesignerContainerExtension_canAddWidget},
    {sipName_canRemove, meth_QDesignerContainerExtension_canRemove, METH_VARARGS, doc_QDesignerContainerExtension_canRemove},
    {sipName_count, meth_QDesignerContainerExtension_count, METH_VARARGS, doc_QDesignerContainerExtension_count},
    {sipName_currentIndex, meth_QDesignerContainerExtension_currentIndex, METH_VARARGS, doc_QDesignerContainerExtension_currentIndex},
    {sipName_insertWidget, meth_QDesignerContainerExtension_insertWidget, METH_VARARGS, doc_QDesignerContainerExtension_insertWidget},
    {sipName_remove, meth_QDesignerContainerExtension_remove, METH_VARARGS, doc_QDesignerContainerExtension_remove},
    {sipName_setCurrentIndex, meth_QDesignerContainerExtension_setCurrentIndex, METH_VARARGS, doc_QDesignerContainerExtension_setCurrentIndex},
    {sipName_widget, meth_QDesignerContainerExtension_widget, METH_VARARGS, doc_QDesignerContainerExtension_widget}
};

PyDoc_STRVAR(doc_QDesignerContainerExtension, "\1QDesignerContainerExtension()");


sipClassTypeDef sipTypeDef_QtDesigner_QDesignerContainerExtension = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDesignerContainerExtension,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QDesignerContainerExtension,
        {0, 0, 1},
        9, methods_QDesignerContainerExtension,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDesignerContainerExtension,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QDesignerContainerExtension,
    init_type_QDesignerContainerExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDesignerContainerExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QDesignerContainerExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QDesignerContainerExtension),
};
