/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qoperatingsystemversion.sip"
#include <qoperatingsystemversion.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQOperatingSystemVersionBase.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQOperatingSystemVersionBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qversionnumber.sip"
#include <qversionnumber.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQOperatingSystemVersionBase.cpp"


PyDoc_STRVAR(doc_QOperatingSystemVersionBase_version, "version(self) -> QVersionNumber");

extern "C" {static PyObject *meth_QOperatingSystemVersionBase_version(PyObject *, PyObject *);}
static PyObject *meth_QOperatingSystemVersionBase_version(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOperatingSystemVersionBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOperatingSystemVersionBase, &sipCpp))
        {
            ::QVersionNumber*sipRes;

            sipRes = new ::QVersionNumber(sipCpp->version());

            return sipConvertFromNewType(sipRes, sipType_QVersionNumber, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOperatingSystemVersionBase, sipName_version, doc_QOperatingSystemVersionBase_version);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOperatingSystemVersionBase_majorVersion, "majorVersion(self) -> int");

extern "C" {static PyObject *meth_QOperatingSystemVersionBase_majorVersion(PyObject *, PyObject *);}
static PyObject *meth_QOperatingSystemVersionBase_majorVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOperatingSystemVersionBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOperatingSystemVersionBase, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->majorVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOperatingSystemVersionBase, sipName_majorVersion, doc_QOperatingSystemVersionBase_majorVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOperatingSystemVersionBase_minorVersion, "minorVersion(self) -> int");

extern "C" {static PyObject *meth_QOperatingSystemVersionBase_minorVersion(PyObject *, PyObject *);}
static PyObject *meth_QOperatingSystemVersionBase_minorVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOperatingSystemVersionBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOperatingSystemVersionBase, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->minorVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOperatingSystemVersionBase, sipName_minorVersion, doc_QOperatingSystemVersionBase_minorVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOperatingSystemVersionBase_microVersion, "microVersion(self) -> int");

extern "C" {static PyObject *meth_QOperatingSystemVersionBase_microVersion(PyObject *, PyObject *);}
static PyObject *meth_QOperatingSystemVersionBase_microVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOperatingSystemVersionBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOperatingSystemVersionBase, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->microVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOperatingSystemVersionBase, sipName_microVersion, doc_QOperatingSystemVersionBase_microVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOperatingSystemVersionBase_segmentCount, "segmentCount(self) -> int");

extern "C" {static PyObject *meth_QOperatingSystemVersionBase_segmentCount(PyObject *, PyObject *);}
static PyObject *meth_QOperatingSystemVersionBase_segmentCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOperatingSystemVersionBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOperatingSystemVersionBase, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->segmentCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOperatingSystemVersionBase, sipName_segmentCount, doc_QOperatingSystemVersionBase_segmentCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOperatingSystemVersionBase_name, "name(self) -> str");

extern "C" {static PyObject *meth_QOperatingSystemVersionBase_name(PyObject *, PyObject *);}
static PyObject *meth_QOperatingSystemVersionBase_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOperatingSystemVersionBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOperatingSystemVersionBase, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOperatingSystemVersionBase, sipName_name, doc_QOperatingSystemVersionBase_name);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QOperatingSystemVersionBase___ge__(PyObject *, PyObject *);}
static PyObject *slot_QOperatingSystemVersionBase___ge__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QOperatingSystemVersionBase *sipCpp = reinterpret_cast< ::QOperatingSystemVersionBase *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QOperatingSystemVersionBase));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOperatingSystemVersionBase* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QOperatingSystemVersionBase, &a0))
        {
            bool sipRes;

            sipRes = operator>=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ge_slot, sipType_QOperatingSystemVersionBase, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QOperatingSystemVersionBase___le__(PyObject *, PyObject *);}
static PyObject *slot_QOperatingSystemVersionBase___le__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QOperatingSystemVersionBase *sipCpp = reinterpret_cast< ::QOperatingSystemVersionBase *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QOperatingSystemVersionBase));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOperatingSystemVersionBase* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QOperatingSystemVersionBase, &a0))
        {
            bool sipRes;

            sipRes = operator<=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, le_slot, sipType_QOperatingSystemVersionBase, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QOperatingSystemVersionBase___gt__(PyObject *, PyObject *);}
static PyObject *slot_QOperatingSystemVersionBase___gt__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QOperatingSystemVersionBase *sipCpp = reinterpret_cast< ::QOperatingSystemVersionBase *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QOperatingSystemVersionBase));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOperatingSystemVersionBase* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QOperatingSystemVersionBase, &a0))
        {
            bool sipRes;

            sipRes = operator>((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, gt_slot, sipType_QOperatingSystemVersionBase, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QOperatingSystemVersionBase___lt__(PyObject *, PyObject *);}
static PyObject *slot_QOperatingSystemVersionBase___lt__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QOperatingSystemVersionBase *sipCpp = reinterpret_cast< ::QOperatingSystemVersionBase *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QOperatingSystemVersionBase));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOperatingSystemVersionBase* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QOperatingSystemVersionBase, &a0))
        {
            bool sipRes;

            sipRes = operator<((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, lt_slot, sipType_QOperatingSystemVersionBase, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QOperatingSystemVersionBase(void *, int);}
static void release_QOperatingSystemVersionBase(void *sipCppV, int)
{
    delete reinterpret_cast< ::QOperatingSystemVersionBase *>(sipCppV);
}


extern "C" {static void *array_QOperatingSystemVersionBase(Py_ssize_t);}
static void *array_QOperatingSystemVersionBase(Py_ssize_t sipNrElem)
{
    return new ::QOperatingSystemVersionBase[sipNrElem];
}


extern "C" {static void array_delete_QOperatingSystemVersionBase(void *);}
static void array_delete_QOperatingSystemVersionBase(void *sipCpp)
{
    delete[] reinterpret_cast< ::QOperatingSystemVersionBase *>(sipCpp);
}


extern "C" {static void assign_QOperatingSystemVersionBase(void *, Py_ssize_t, void *);}
static void assign_QOperatingSystemVersionBase(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QOperatingSystemVersionBase *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QOperatingSystemVersionBase *>(sipSrc);
}


extern "C" {static void *copy_QOperatingSystemVersionBase(const void *, Py_ssize_t);}
static void *copy_QOperatingSystemVersionBase(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QOperatingSystemVersionBase(reinterpret_cast<const ::QOperatingSystemVersionBase *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QOperatingSystemVersionBase(sipSimpleWrapper *);}
static void dealloc_QOperatingSystemVersionBase(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QOperatingSystemVersionBase(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QOperatingSystemVersionBase(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QOperatingSystemVersionBase(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QOperatingSystemVersionBase *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QOperatingSystemVersionBase();

            return sipCpp;
        }
    }

    {
        const ::QOperatingSystemVersionBase* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QOperatingSystemVersionBase, &a0))
        {
            sipCpp = new ::QOperatingSystemVersionBase(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QOperatingSystemVersionBase[] = {
    {(void *)slot_QOperatingSystemVersionBase___ge__, ge_slot},
    {(void *)slot_QOperatingSystemVersionBase___le__, le_slot},
    {(void *)slot_QOperatingSystemVersionBase___gt__, gt_slot},
    {(void *)slot_QOperatingSystemVersionBase___lt__, lt_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QOperatingSystemVersionBase[] = {
    {sipName_majorVersion, meth_QOperatingSystemVersionBase_majorVersion, METH_VARARGS, doc_QOperatingSystemVersionBase_majorVersion},
    {sipName_microVersion, meth_QOperatingSystemVersionBase_microVersion, METH_VARARGS, doc_QOperatingSystemVersionBase_microVersion},
    {sipName_minorVersion, meth_QOperatingSystemVersionBase_minorVersion, METH_VARARGS, doc_QOperatingSystemVersionBase_minorVersion},
    {sipName_name, meth_QOperatingSystemVersionBase_name, METH_VARARGS, doc_QOperatingSystemVersionBase_name},
    {sipName_segmentCount, meth_QOperatingSystemVersionBase_segmentCount, METH_VARARGS, doc_QOperatingSystemVersionBase_segmentCount},
    {sipName_version, meth_QOperatingSystemVersionBase_version, METH_VARARGS, doc_QOperatingSystemVersionBase_version}
};

PyDoc_STRVAR(doc_QOperatingSystemVersionBase, "\1QOperatingSystemVersionBase()\n"
"QOperatingSystemVersionBase(a0: QOperatingSystemVersionBase)");


sipClassTypeDef sipTypeDef_QtCore_QOperatingSystemVersionBase = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QOperatingSystemVersionBase,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QOperatingSystemVersionBase,
        {0, 0, 1},
        6, methods_QOperatingSystemVersionBase,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QOperatingSystemVersionBase,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QOperatingSystemVersionBase,
    init_type_QOperatingSystemVersionBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QOperatingSystemVersionBase,
    assign_QOperatingSystemVersionBase,
    array_QOperatingSystemVersionBase,
    copy_QOperatingSystemVersionBase,
    release_QOperatingSystemVersionBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QOperatingSystemVersionBase,
    sizeof (::QOperatingSystemVersionBase),
};
