/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtTestAPI_H
#define _QtTestAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QAbstractItemModelTester__FailureReportingMode 0
#define sipName_QAbstractItemModelTester__FailureReportingMode &sipStrings_QtTest[0]
#define sipNameNr_QAbstractItemModelTester 47
#define sipName_QAbstractItemModelTester &sipStrings_QtTest[47]
#define sipNameNr_PyQt6_sip_simplewrapper 72
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtTest[72]
#define sipNameNr_qWaitForWindowExposed 96
#define sipName_qWaitForWindowExposed &sipStrings_QtTest[96]
#define sipNameNr_FailureReportingMode 26
#define sipName_FailureReportingMode &sipStrings_QtTest[26]
#define sipNameNr_failureReportingMode 118
#define sipName_failureReportingMode &sipStrings_QtTest[118]
#define sipNameNr_qWaitForWindowActive 139
#define sipName_qWaitForWindowActive &sipStrings_QtTest[139]
#define sipNameNr_QTest__KeyAction 160
#define sipName_QTest__KeyAction &sipStrings_QtTest[160]
#define sipNameNr_disconnectNotify 177
#define sipName_disconnectNotify &sipStrings_QtTest[177]
#define sipNameNr_setUseFetchMore 194
#define sipName_setUseFetchMore &sipStrings_QtTest[194]
#define sipNameNr_connectNotify 180
#define sipName_connectNotify &sipStrings_QtTest[180]
#define sipNameNr_simulateEvent 210
#define sipName_simulateEvent &sipStrings_QtTest[210]
#define sipNameNr_PyQt6_QtTest 224
#define sipName_PyQt6_QtTest &sipStrings_QtTest[224]
#define sipNameNr_mouseRelease 237
#define sipName_mouseRelease &sipStrings_QtTest[237]
#define sipNameNr_sendKeyEvent 250
#define sipName_sendKeyEvent &sipStrings_QtTest[250]
#define sipNameNr___delitem__ 263
#define sipName___delitem__ &sipStrings_QtTest[263]
#define sipNameNr___getitem__ 275
#define sipName___getitem__ &sipStrings_QtTest[275]
#define sipNameNr___setitem__ 287
#define sipName___setitem__ &sipStrings_QtTest[287]
#define sipNameNr_customEvent 299
#define sipName_customEvent &sipStrings_QtTest[299]
#define sipNameNr_eventFilter 311
#define sipName_eventFilter &sipStrings_QtTest[311]
#define sipNameNr_keySequence 323
#define sipName_keySequence &sipStrings_QtTest[323]
#define sipNameNr_mouseDClick 335
#define sipName_mouseDClick &sipStrings_QtTest[335]
#define sipNameNr_QSignalSpy 347
#define sipName_QSignalSpy &sipStrings_QtTest[347]
#define sipNameNr_childEvent 358
#define sipName_childEvent &sipStrings_QtTest[358]
#define sipNameNr_keyRelease 369
#define sipName_keyRelease &sipStrings_QtTest[369]
#define sipNameNr_mouseClick 380
#define sipName_mouseClick &sipStrings_QtTest[380]
#define sipNameNr_mousePress 391
#define sipName_mousePress &sipStrings_QtTest[391]
#define sipNameNr_timerEvent 402
#define sipName_timerEvent &sipStrings_QtTest[402]
#define sipNameNr_KeyAction 167
#define sipName_KeyAction &sipStrings_QtTest[167]
#define sipNameNr_keyClicks 413
#define sipName_keyClicks &sipStrings_QtTest[413]
#define sipNameNr_mouseMove 423
#define sipName_mouseMove &sipStrings_QtTest[423]
#define sipNameNr_Shortcut 433
#define sipName_Shortcut &sipStrings_QtTest[433]
#define sipNameNr_keyClick 442
#define sipName_keyClick &sipStrings_QtTest[442]
#define sipNameNr_keyEvent 451
#define sipName_keyEvent &sipStrings_QtTest[451]
#define sipNameNr_keyPress 460
#define sipName_keyPress &sipStrings_QtTest[460]
#define sipNameNr_modifier 469
#define sipName_modifier &sipStrings_QtTest[469]
#define sipNameNr_Release 242
#define sipName_Release &sipStrings_QtTest[242]
#define sipNameNr_Warning 478
#define sipName_Warning &sipStrings_QtTest[478]
#define sipNameNr___len__ 486
#define sipName___len__ &sipStrings_QtTest[486]
#define sipNameNr_isValid 494
#define sipName_isValid &sipStrings_QtTest[494]
#define sipNameNr_timeout 502
#define sipName_timeout &sipStrings_QtTest[502]
#define sipNameNr_QtTest 230
#define sipName_QtTest &sipStrings_QtTest[230]
#define sipNameNr_parent 510
#define sipName_parent &sipStrings_QtTest[510]
#define sipNameNr_signal 517
#define sipName_signal &sipStrings_QtTest[517]
#define sipNameNr_Click 341
#define sipName_Click &sipStrings_QtTest[341]
#define sipNameNr_Fatal 524
#define sipName_Fatal &sipStrings_QtTest[524]
#define sipNameNr_Press 396
#define sipName_Press &sipStrings_QtTest[396]
#define sipNameNr_QTest 530
#define sipName_QTest &sipStrings_QtTest[530]
#define sipNameNr_delay 536
#define sipName_delay &sipStrings_QtTest[536]
#define sipNameNr_event 542
#define sipName_event &sipStrings_QtTest[542]
#define sipNameNr_model 548
#define sipName_model &sipStrings_QtTest[548]
#define sipNameNr_qWait 554
#define sipName_qWait &sipStrings_QtTest[554]
#define sipNameNr_wait 560
#define sipName_wait &sipStrings_QtTest[560]
#define sipNameNr_pos 565
#define sipName_pos &sipStrings_QtTest[565]

#define sipMalloc                   sipAPI_QtTest->api_malloc
#define sipFree                     sipAPI_QtTest->api_free
#define sipBuildResult              sipAPI_QtTest->api_build_result
#define sipCallMethod               sipAPI_QtTest->api_call_method
#define sipCallProcedureMethod      sipAPI_QtTest->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtTest->api_call_error_handler
#define sipParseResultEx            sipAPI_QtTest->api_parse_result_ex
#define sipParseResult              sipAPI_QtTest->api_parse_result
#define sipParseArgs                sipAPI_QtTest->api_parse_args
#define sipParseKwdArgs             sipAPI_QtTest->api_parse_kwd_args
#define sipParsePair                sipAPI_QtTest->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtTest->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtTest->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtTest->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtTest->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtTest->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtTest->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtTest->api_add_exception
#define sipNoFunction               sipAPI_QtTest->api_no_function
#define sipNoMethod                 sipAPI_QtTest->api_no_method
#define sipAbstractMethod           sipAPI_QtTest->api_abstract_method
#define sipBadClass                 sipAPI_QtTest->api_bad_class
#define sipBadCatcherResult         sipAPI_QtTest->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtTest->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtTest->api_bad_operator_arg
#define sipTrace                    sipAPI_QtTest->api_trace
#define sipTransferBack             sipAPI_QtTest->api_transfer_back
#define sipTransferTo               sipAPI_QtTest->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtTest->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtTest->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtTest->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtTest->api_voidptr_type
#define sipGetPyObject              sipAPI_QtTest->api_get_pyobject
#define sipGetAddress               sipAPI_QtTest->api_get_address
#define sipGetMixinAddress          sipAPI_QtTest->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtTest->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtTest->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtTest->api_call_hook
#define sipEndThread                sipAPI_QtTest->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtTest->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtTest->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtTest->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtTest->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtTest->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtTest->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtTest->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtTest->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtTest->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtTest->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtTest->api_convert_to_bool
#define sipReleaseType              sipAPI_QtTest->api_release_type
#define sipConvertFromType          sipAPI_QtTest->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtTest->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtTest->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtTest->api_convert_from_enum
#define sipGetState                 sipAPI_QtTest->api_get_state
#define sipExportSymbol             sipAPI_QtTest->api_export_symbol
#define sipImportSymbol             sipAPI_QtTest->api_import_symbol
#define sipFindType                 sipAPI_QtTest->api_find_type
#define sipBytes_AsChar             sipAPI_QtTest->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtTest->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtTest->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtTest->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtTest->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtTest->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtTest->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtTest->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtTest->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtTest->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtTest->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtTest->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtTest->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtTest->api_get_reference
#define sipKeepReference            sipAPI_QtTest->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtTest->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtTest->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtTest->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtTest->api_type_scope
#define sipResolveTypedef           sipAPI_QtTest->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtTest->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtTest->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtTest->api_init_mixin
#define sipExportModule             sipAPI_QtTest->api_export_module
#define sipInitModule               sipAPI_QtTest->api_init_module
#define sipGetInterpreter           sipAPI_QtTest->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtTest->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtTest->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtTest->api_py_type_dict
#define sipPyTypeName               sipAPI_QtTest->api_py_type_name
#define sipGetCFunction             sipAPI_QtTest->api_get_c_function
#define sipGetMethod                sipAPI_QtTest->api_get_method
#define sipFromMethod               sipAPI_QtTest->api_from_method
#define sipGetDate                  sipAPI_QtTest->api_get_date
#define sipFromDate                 sipAPI_QtTest->api_from_date
#define sipGetDateTime              sipAPI_QtTest->api_get_datetime
#define sipFromDateTime             sipAPI_QtTest->api_from_datetime
#define sipGetTime                  sipAPI_QtTest->api_get_time
#define sipFromTime                 sipAPI_QtTest->api_from_time
#define sipIsUserType               sipAPI_QtTest->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtTest->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtTest->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtTest->api_unicode_write
#define sipUnicodeData              sipAPI_QtTest->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtTest->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtTest->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtTest->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtTest->api_is_derived_class
#define sipGetUserObject            sipAPI_QtTest->api_get_user_object
#define sipSetUserObject            sipAPI_QtTest->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtTest->api_register_event_handler
#define sipConvertToArray           sipAPI_QtTest->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtTest->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtTest->api_enable_gc
#define sipPrintObject              sipAPI_QtTest->api_print_object
#define sipLong_AsChar              sipAPI_QtTest->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtTest->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtTest->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtTest->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtTest->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtTest->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtTest->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtTest->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtTest->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtTest->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtTest->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtTest->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtTest->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtTest->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtTest->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtTest->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtTest->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtTest->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtTest->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtTest->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtTest->api_release_type_us
#define sipIsPyMethod               sipAPI_QtTest->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtTest[];

#define sipType_QAbstractItemModelTester sipExportedTypes_QtTest[0]

#define sipType_QAbstractItemModelTester_FailureReportingMode sipExportedTypes_QtTest[1]

extern sipClassTypeDef sipTypeDef_QtTest_QAbstractItemModelTester;

#define sipType_QSignalSpy sipExportedTypes_QtTest[2]

extern sipClassTypeDef sipTypeDef_QtTest_QSignalSpy;

#define sipType_QTest sipExportedTypes_QtTest[3]

#define sipType_QTest_KeyAction sipExportedTypes_QtTest[4]

extern sipClassTypeDef sipTypeDef_QtTest_QTest;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtTest;
extern sipExportedModuleDef sipModuleAPI_QtTest;
extern sipTypeDef *sipExportedTypes_QtTest[];

#define sipType_Qt_Key sipImportedTypes_QtTest_QtCore[11].it_td

#define sipType_Qt_MouseButton sipImportedTypes_QtTest_QtCore[12].it_td

#define sipType_QObject sipImportedTypes_QtTest_QtCore[7].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtTest_QtCore[0].it_td

#define sipType_QByteArray sipImportedTypes_QtTest_QtCore[1].it_td

#define sipType_QEvent sipImportedTypes_QtTest_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtTest_QtCore[10].it_td

#define sipType_QChildEvent sipImportedTypes_QtTest_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtTest_QtCore[6].it_td

#define sipType_QPoint sipImportedTypes_QtTest_QtCore[8].it_td

#define sipType_QFlags_0100Qt_KeyboardModifier sipImportedTypes_QtTest_QtCore[4].it_td

#define sipType_QList_0100QVariant sipImportedTypes_QtTest_QtCore[5].it_td

#define sipType_QString sipImportedTypes_QtTest_QtCore[9].it_td
extern sipImportedTypeDef sipImportedTypes_QtTest_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtTest_QtCore[];

#define sipType_QKeySequence sipImportedTypes_QtTest_QtGui[0].it_td

#define sipType_QWindow sipImportedTypes_QtTest_QtGui[1].it_td
extern sipImportedTypeDef sipImportedTypes_QtTest_QtGui[];

#define sipType_QWidget sipImportedTypes_QtTest_QtWidgets[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtTest_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtTest_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtTest_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtTest_qt_metacast;
#line 147 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtTest/qsignalspy.sip"
// Imports from QtCore.
typedef sipErrorState (*pyqt6_qttest_get_pyqtsignal_parts_t)(PyObject *, QObject **, QByteArray &);
extern pyqt6_qttest_get_pyqtsignal_parts_t pyqt6_qttest_get_pyqtsignal_parts;
#line 381 "/build/pyqt6/src/pyqt6-6.11.0/build/QtTest/sipAPIQtTest.h"

#endif
