/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qcameradevice.sip"
#include <qcameradevice.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCameraDevice.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qtvideo.sip"
#include <qtvideo.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCameraDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCameraDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qcameradevice.sip"
#include <qcameradevice.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCameraDevice.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCameraDevice.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCameraDevice.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCameraDevice.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCameraDevice.cpp"


PyDoc_STRVAR(doc_QCameraDevice_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QCameraDevice_isNull(PyObject *, PyObject *);}
static PyObject *meth_QCameraDevice_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraDevice, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraDevice, sipName_isNull, doc_QCameraDevice_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraDevice_id, "id(self) -> QByteArray");

extern "C" {static PyObject *meth_QCameraDevice_id(PyObject *, PyObject *);}
static PyObject *meth_QCameraDevice_id(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraDevice, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->id());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraDevice, sipName_id, doc_QCameraDevice_id);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraDevice_description, "description(self) -> str");

extern "C" {static PyObject *meth_QCameraDevice_description(PyObject *, PyObject *);}
static PyObject *meth_QCameraDevice_description(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraDevice, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->description());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraDevice, sipName_description, doc_QCameraDevice_description);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraDevice_isDefault, "isDefault(self) -> bool");

extern "C" {static PyObject *meth_QCameraDevice_isDefault(PyObject *, PyObject *);}
static PyObject *meth_QCameraDevice_isDefault(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraDevice, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDefault();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraDevice, sipName_isDefault, doc_QCameraDevice_isDefault);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraDevice_position, "position(self) -> QCameraDevice.Position");

extern "C" {static PyObject *meth_QCameraDevice_position(PyObject *, PyObject *);}
static PyObject *meth_QCameraDevice_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraDevice, &sipCpp))
        {
            ::QCameraDevice::Position sipRes;

            sipRes = sipCpp->position();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCameraDevice_Position);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraDevice, sipName_position, doc_QCameraDevice_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraDevice_photoResolutions, "photoResolutions(self) -> list[QSize]");

extern "C" {static PyObject *meth_QCameraDevice_photoResolutions(PyObject *, PyObject *);}
static PyObject *meth_QCameraDevice_photoResolutions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraDevice, &sipCpp))
        {
            QList< ::QSize>*sipRes;

            sipRes = new QList< ::QSize>(sipCpp->photoResolutions());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraDevice, sipName_photoResolutions, doc_QCameraDevice_photoResolutions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraDevice_videoFormats, "videoFormats(self) -> list[QCameraFormat]");

extern "C" {static PyObject *meth_QCameraDevice_videoFormats(PyObject *, PyObject *);}
static PyObject *meth_QCameraDevice_videoFormats(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraDevice, &sipCpp))
        {
            QList< ::QCameraFormat>*sipRes;

            sipRes = new QList< ::QCameraFormat>(sipCpp->videoFormats());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QCameraFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraDevice, sipName_videoFormats, doc_QCameraDevice_videoFormats);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraDevice_correctionAngle, "correctionAngle(self) -> QtVideo.Rotation");

extern "C" {static PyObject *meth_QCameraDevice_correctionAngle(PyObject *, PyObject *);}
static PyObject *meth_QCameraDevice_correctionAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraDevice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraDevice, &sipCpp))
        {
            ::QtVideo::Rotation sipRes;

            sipRes = sipCpp->correctionAngle();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtVideo_Rotation);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraDevice, sipName_correctionAngle, doc_QCameraDevice_correctionAngle);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QCameraDevice___ne__(PyObject *, PyObject *);}
static PyObject *slot_QCameraDevice___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QCameraDevice *sipCpp = reinterpret_cast< ::QCameraDevice *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QCameraDevice));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraDevice* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QCameraDevice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QCameraDevice::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, ne_slot, sipType_QCameraDevice, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QCameraDevice___eq__(PyObject *, PyObject *);}
static PyObject *slot_QCameraDevice___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QCameraDevice *sipCpp = reinterpret_cast< ::QCameraDevice *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QCameraDevice));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraDevice* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QCameraDevice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QCameraDevice::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, eq_slot, sipType_QCameraDevice, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QCameraDevice(void *, int);}
static void release_QCameraDevice(void *sipCppV, int)
{
    delete reinterpret_cast< ::QCameraDevice *>(sipCppV);
}


extern "C" {static void *array_QCameraDevice(Py_ssize_t);}
static void *array_QCameraDevice(Py_ssize_t sipNrElem)
{
    return new ::QCameraDevice[sipNrElem];
}


extern "C" {static void array_delete_QCameraDevice(void *);}
static void array_delete_QCameraDevice(void *sipCpp)
{
    delete[] reinterpret_cast< ::QCameraDevice *>(sipCpp);
}


extern "C" {static void assign_QCameraDevice(void *, Py_ssize_t, void *);}
static void assign_QCameraDevice(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QCameraDevice *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QCameraDevice *>(sipSrc);
}


extern "C" {static void *copy_QCameraDevice(const void *, Py_ssize_t);}
static void *copy_QCameraDevice(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QCameraDevice(reinterpret_cast<const ::QCameraDevice *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QCameraDevice(sipSimpleWrapper *);}
static void dealloc_QCameraDevice(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCameraDevice(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QCameraDevice(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCameraDevice(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QCameraDevice *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QCameraDevice();

            return sipCpp;
        }
    }

    {
        const ::QCameraDevice* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QCameraDevice, &a0))
        {
            sipCpp = new ::QCameraDevice(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QCameraDevice[] = {
    {(void *)slot_QCameraDevice___ne__, ne_slot},
    {(void *)slot_QCameraDevice___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QCameraDevice[] = {
    {sipName_correctionAngle, meth_QCameraDevice_correctionAngle, METH_VARARGS, doc_QCameraDevice_correctionAngle},
    {sipName_description, meth_QCameraDevice_description, METH_VARARGS, doc_QCameraDevice_description},
    {sipName_id, meth_QCameraDevice_id, METH_VARARGS, doc_QCameraDevice_id},
    {sipName_isDefault, meth_QCameraDevice_isDefault, METH_VARARGS, doc_QCameraDevice_isDefault},
    {sipName_isNull, meth_QCameraDevice_isNull, METH_VARARGS, doc_QCameraDevice_isNull},
    {sipName_photoResolutions, meth_QCameraDevice_photoResolutions, METH_VARARGS, doc_QCameraDevice_photoResolutions},
    {sipName_position, meth_QCameraDevice_position, METH_VARARGS, doc_QCameraDevice_position},
    {sipName_videoFormats, meth_QCameraDevice_videoFormats, METH_VARARGS, doc_QCameraDevice_videoFormats}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QCameraDevice[] = {
    {sipName_UnspecifiedPosition, static_cast<int>(::QCameraDevice::UnspecifiedPosition)},
    {sipName_BackFace, static_cast<int>(::QCameraDevice::BackFace)},
    {sipName_FrontFace, static_cast<int>(::QCameraDevice::FrontFace)},
    {0, 0}
};

PyDoc_STRVAR(doc_QCameraDevice, "\1QCameraDevice()\n"
"QCameraDevice(other: QCameraDevice)");


sipClassTypeDef sipTypeDef_QtMultimedia_QCameraDevice = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCameraDevice,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QCameraDevice,
        {0, 0, 1},
        8, methods_QCameraDevice,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QCameraDevice, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCameraDevice,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QCameraDevice,
    init_type_QCameraDevice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCameraDevice,
    assign_QCameraDevice,
    array_QCameraDevice,
    copy_QCameraDevice,
    release_QCameraDevice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QCameraDevice,
    sizeof (::QCameraDevice),
};
