/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtPdfWidgetsAPI_H
#define _QtPdfWidgetsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_currentSearchResultIndexChanged 0
#define sipName_currentSearchResultIndexChanged &sipStrings_QtPdfWidgets[0]
#define sipNameNr_setCurrentSearchResultIndex 32
#define sipName_setCurrentSearchResultIndex &sipStrings_QtPdfWidgets[32]
#define sipNameNr_currentSearchResultIndex 60
#define sipName_currentSearchResultIndex &sipStrings_QtPdfWidgets[60]
#define sipNameNr_currentPageLabelChanged 85
#define sipName_currentPageLabelChanged &sipStrings_QtPdfWidgets[85]
#define sipNameNr_documentMarginsChanged 109
#define sipName_documentMarginsChanged &sipStrings_QtPdfWidgets[109]
#define sipNameNr_mouseDoubleClickEvent 132
#define sipName_mouseDoubleClickEvent &sipStrings_QtPdfWidgets[132]
#define sipNameNr_PyQt6_QtPdfWidgets 154
#define sipName_PyQt6_QtPdfWidgets &sipStrings_QtPdfWidgets[154]
#define sipNameNr_QPdfView__PageMode 173
#define sipName_QPdfView__PageMode &sipStrings_QtPdfWidgets[173]
#define sipNameNr_QPdfView__ZoomMode 192
#define sipName_QPdfView__ZoomMode &sipStrings_QtPdfWidgets[192]
#define sipNameNr_currentPageChanged 211
#define sipName_currentPageChanged &sipStrings_QtPdfWidgets[211]
#define sipNameNr_focusNextPrevChild 230
#define sipName_focusNextPrevChild &sipStrings_QtPdfWidgets[230]
#define sipNameNr_pageSpacingChanged 249
#define sipName_pageSpacingChanged &sipStrings_QtPdfWidgets[249]
#define sipNameNr_searchModelChanged 268
#define sipName_searchModelChanged &sipStrings_QtPdfWidgets[268]
#define sipNameNr_setDocumentMargins 287
#define sipName_setDocumentMargins &sipStrings_QtPdfWidgets[287]
#define sipNameNr_hasHeightForWidth 306
#define sipName_hasHeightForWidth &sipStrings_QtPdfWidgets[306]
#define sipNameNr_mouseReleaseEvent 324
#define sipName_mouseReleaseEvent &sipStrings_QtPdfWidgets[324]
#define sipNameNr_zoomFactorChanged 342
#define sipName_zoomFactorChanged &sipStrings_QtPdfWidgets[342]
#define sipNameNr_QPdfPageSelector 360
#define sipName_QPdfPageSelector &sipStrings_QtPdfWidgets[360]
#define sipNameNr_contextMenuEvent 377
#define sipName_contextMenuEvent &sipStrings_QtPdfWidgets[377]
#define sipNameNr_currentPageLabel 394
#define sipName_currentPageLabel &sipStrings_QtPdfWidgets[394]
#define sipNameNr_disconnectNotify 411
#define sipName_disconnectNotify &sipStrings_QtPdfWidgets[411]
#define sipNameNr_inputMethodEvent 428
#define sipName_inputMethodEvent &sipStrings_QtPdfWidgets[428]
#define sipNameNr_inputMethodQuery 445
#define sipName_inputMethodQuery &sipStrings_QtPdfWidgets[445]
#define sipNameNr_scrollContentsBy 462
#define sipName_scrollContentsBy &sipStrings_QtPdfWidgets[462]
#define sipNameNr_viewportSizeHint 479
#define sipName_viewportSizeHint &sipStrings_QtPdfWidgets[479]
#define sipNameNr_documentChanged 496
#define sipName_documentChanged &sipStrings_QtPdfWidgets[496]
#define sipNameNr_documentMargins 512
#define sipName_documentMargins &sipStrings_QtPdfWidgets[512]
#define sipNameNr_initStyleOption 528
#define sipName_initStyleOption &sipStrings_QtPdfWidgets[528]
#define sipNameNr_keyReleaseEvent 544
#define sipName_keyReleaseEvent &sipStrings_QtPdfWidgets[544]
#define sipNameNr_minimumSizeHint 560
#define sipName_minimumSizeHint &sipStrings_QtPdfWidgets[560]
#define sipNameNr_mousePressEvent 576
#define sipName_mousePressEvent &sipStrings_QtPdfWidgets[576]
#define sipNameNr_pageModeChanged 592
#define sipName_pageModeChanged &sipStrings_QtPdfWidgets[592]
#define sipNameNr_zoomModeChanged 608
#define sipName_zoomModeChanged &sipStrings_QtPdfWidgets[608]
#define sipNameNr_dragEnterEvent 624
#define sipName_dragEnterEvent &sipStrings_QtPdfWidgets[624]
#define sipNameNr_dragLeaveEvent 639
#define sipName_dragLeaveEvent &sipStrings_QtPdfWidgets[639]
#define sipNameNr_heightForWidth 654
#define sipName_heightForWidth &sipStrings_QtPdfWidgets[654]
#define sipNameNr_mouseMoveEvent 669
#define sipName_mouseMoveEvent &sipStrings_QtPdfWidgets[669]
#define sipNameNr_setCurrentPage 684
#define sipName_setCurrentPage &sipStrings_QtPdfWidgets[684]
#define sipNameNr_setPageSpacing 699
#define sipName_setPageSpacing &sipStrings_QtPdfWidgets[699]
#define sipNameNr_setSearchModel 714
#define sipName_setSearchModel &sipStrings_QtPdfWidgets[714]
#define sipNameNr_connectNotify 414
#define sipName_connectNotify &sipStrings_QtPdfWidgets[414]
#define sipNameNr_dragMoveEvent 729
#define sipName_dragMoveEvent &sipStrings_QtPdfWidgets[729]
#define sipNameNr_focusOutEvent 743
#define sipName_focusOutEvent &sipStrings_QtPdfWidgets[743]
#define sipNameNr_keyPressEvent 757
#define sipName_keyPressEvent &sipStrings_QtPdfWidgets[757]
#define sipNameNr_pageNavigator 771
#define sipName_pageNavigator &sipStrings_QtPdfWidgets[771]
#define sipNameNr_setZoomFactor 785
#define sipName_setZoomFactor &sipStrings_QtPdfWidgets[785]
#define sipNameNr_setupViewport 799
#define sipName_setupViewport &sipStrings_QtPdfWidgets[799]
#define sipNameNr_sharedPainter 813
#define sipName_sharedPainter &sipStrings_QtPdfWidgets[813]
#define sipNameNr_viewportEvent 827
#define sipName_viewportEvent &sipStrings_QtPdfWidgets[827]
#define sipNameNr_focusInEvent 841
#define sipName_focusInEvent &sipStrings_QtPdfWidgets[841]
#define sipNameNr_actionEvent 854
#define sipName_actionEvent &sipStrings_QtPdfWidgets[854]
#define sipNameNr_changeEvent 866
#define sipName_changeEvent &sipStrings_QtPdfWidgets[866]
#define sipNameNr_currentPage 878
#define sipName_currentPage &sipStrings_QtPdfWidgets[878]
#define sipNameNr_customEvent 890
#define sipName_customEvent &sipStrings_QtPdfWidgets[890]
#define sipNameNr_eventFilter 902
#define sipName_eventFilter &sipStrings_QtPdfWidgets[902]
#define sipNameNr_initPainter 914
#define sipName_initPainter &sipStrings_QtPdfWidgets[914]
#define sipNameNr_nativeEvent 926
#define sipName_nativeEvent &sipStrings_QtPdfWidgets[926]
#define sipNameNr_pageSpacing 938
#define sipName_pageSpacing &sipStrings_QtPdfWidgets[938]
#define sipNameNr_paintEngine 950
#define sipName_paintEngine &sipStrings_QtPdfWidgets[950]
#define sipNameNr_resizeEvent 962
#define sipName_resizeEvent &sipStrings_QtPdfWidgets[962]
#define sipNameNr_searchModel 974
#define sipName_searchModel &sipStrings_QtPdfWidgets[974]
#define sipNameNr_setDocument 986
#define sipName_setDocument &sipStrings_QtPdfWidgets[986]
#define sipNameNr_setPageMode 998
#define sipName_setPageMode &sipStrings_QtPdfWidgets[998]
#define sipNameNr_setZoomMode 1010
#define sipName_setZoomMode &sipStrings_QtPdfWidgets[1010]
#define sipNameNr_tabletEvent 1022
#define sipName_tabletEvent &sipStrings_QtPdfWidgets[1022]
#define sipNameNr_FitToWidth 1034
#define sipName_FitToWidth &sipStrings_QtPdfWidgets[1034]
#define sipNameNr_SinglePage 1045
#define sipName_SinglePage &sipStrings_QtPdfWidgets[1045]
#define sipNameNr_childEvent 1056
#define sipName_childEvent &sipStrings_QtPdfWidgets[1056]
#define sipNameNr_closeEvent 1067
#define sipName_closeEvent &sipStrings_QtPdfWidgets[1067]
#define sipNameNr_enterEvent 1078
#define sipName_enterEvent &sipStrings_QtPdfWidgets[1078]
#define sipNameNr_leaveEvent 1089
#define sipName_leaveEvent &sipStrings_QtPdfWidgets[1089]
#define sipNameNr_paintEvent 1100
#define sipName_paintEvent &sipStrings_QtPdfWidgets[1100]
#define sipNameNr_setVisible 1111
#define sipName_setVisible &sipStrings_QtPdfWidgets[1111]
#define sipNameNr_timerEvent 1122
#define sipName_timerEvent &sipStrings_QtPdfWidgets[1122]
#define sipNameNr_wheelEvent 1133
#define sipName_wheelEvent &sipStrings_QtPdfWidgets[1133]
#define sipNameNr_zoomFactor 1144
#define sipName_zoomFactor &sipStrings_QtPdfWidgets[1144]
#define sipNameNr_FitInView 1155
#define sipName_FitInView &sipStrings_QtPdfWidgets[1155]
#define sipNameNr_MultiPage 1165
#define sipName_MultiPage &sipStrings_QtPdfWidgets[1165]
#define sipNameNr_dropEvent 1175
#define sipName_dropEvent &sipStrings_QtPdfWidgets[1175]
#define sipNameNr_hideEvent 1185
#define sipName_hideEvent &sipStrings_QtPdfWidgets[1185]
#define sipNameNr_moveEvent 1195
#define sipName_moveEvent &sipStrings_QtPdfWidgets[1195]
#define sipNameNr_showEvent 1205
#define sipName_showEvent &sipStrings_QtPdfWidgets[1205]
#define sipNameNr_PageMode 183
#define sipName_PageMode &sipStrings_QtPdfWidgets[183]
#define sipNameNr_QPdfView 1215
#define sipName_QPdfView &sipStrings_QtPdfWidgets[1215]
#define sipNameNr_ZoomMode 202
#define sipName_ZoomMode &sipStrings_QtPdfWidgets[202]
#define sipNameNr_document 1224
#define sipName_document &sipStrings_QtPdfWidgets[1224]
#define sipNameNr_pageMode 1233
#define sipName_pageMode &sipStrings_QtPdfWidgets[1233]
#define sipNameNr_sizeHint 1242
#define sipName_sizeHint &sipStrings_QtPdfWidgets[1242]
#define sipNameNr_zoomMode 1251
#define sipName_zoomMode &sipStrings_QtPdfWidgets[1251]
#define sipNameNr_devType 1260
#define sipName_devType &sipStrings_QtPdfWidgets[1260]
#define sipNameNr_Custom 1268
#define sipName_Custom &sipStrings_QtPdfWidgets[1268]
#define sipNameNr_metric 1275
#define sipName_metric &sipStrings_QtPdfWidgets[1275]
#define sipNameNr_event 1282
#define sipName_event &sipStrings_QtPdfWidgets[1282]

#define sipMalloc                   sipAPI_QtPdfWidgets->api_malloc
#define sipFree                     sipAPI_QtPdfWidgets->api_free
#define sipBuildResult              sipAPI_QtPdfWidgets->api_build_result
#define sipCallMethod               sipAPI_QtPdfWidgets->api_call_method
#define sipCallProcedureMethod      sipAPI_QtPdfWidgets->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtPdfWidgets->api_call_error_handler
#define sipParseResultEx            sipAPI_QtPdfWidgets->api_parse_result_ex
#define sipParseResult              sipAPI_QtPdfWidgets->api_parse_result
#define sipParseArgs                sipAPI_QtPdfWidgets->api_parse_args
#define sipParseKwdArgs             sipAPI_QtPdfWidgets->api_parse_kwd_args
#define sipParsePair                sipAPI_QtPdfWidgets->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtPdfWidgets->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtPdfWidgets->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtPdfWidgets->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtPdfWidgets->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtPdfWidgets->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtPdfWidgets->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtPdfWidgets->api_add_exception
#define sipNoFunction               sipAPI_QtPdfWidgets->api_no_function
#define sipNoMethod                 sipAPI_QtPdfWidgets->api_no_method
#define sipAbstractMethod           sipAPI_QtPdfWidgets->api_abstract_method
#define sipBadClass                 sipAPI_QtPdfWidgets->api_bad_class
#define sipBadCatcherResult         sipAPI_QtPdfWidgets->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtPdfWidgets->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtPdfWidgets->api_bad_operator_arg
#define sipTrace                    sipAPI_QtPdfWidgets->api_trace
#define sipTransferBack             sipAPI_QtPdfWidgets->api_transfer_back
#define sipTransferTo               sipAPI_QtPdfWidgets->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtPdfWidgets->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtPdfWidgets->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtPdfWidgets->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtPdfWidgets->api_voidptr_type
#define sipGetPyObject              sipAPI_QtPdfWidgets->api_get_pyobject
#define sipGetAddress               sipAPI_QtPdfWidgets->api_get_address
#define sipGetMixinAddress          sipAPI_QtPdfWidgets->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtPdfWidgets->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtPdfWidgets->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtPdfWidgets->api_call_hook
#define sipEndThread                sipAPI_QtPdfWidgets->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtPdfWidgets->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtPdfWidgets->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtPdfWidgets->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtPdfWidgets->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtPdfWidgets->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtPdfWidgets->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtPdfWidgets->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtPdfWidgets->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtPdfWidgets->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtPdfWidgets->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtPdfWidgets->api_convert_to_bool
#define sipReleaseType              sipAPI_QtPdfWidgets->api_release_type
#define sipConvertFromType          sipAPI_QtPdfWidgets->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtPdfWidgets->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtPdfWidgets->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtPdfWidgets->api_convert_from_enum
#define sipGetState                 sipAPI_QtPdfWidgets->api_get_state
#define sipExportSymbol             sipAPI_QtPdfWidgets->api_export_symbol
#define sipImportSymbol             sipAPI_QtPdfWidgets->api_import_symbol
#define sipFindType                 sipAPI_QtPdfWidgets->api_find_type
#define sipBytes_AsChar             sipAPI_QtPdfWidgets->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtPdfWidgets->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtPdfWidgets->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtPdfWidgets->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtPdfWidgets->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtPdfWidgets->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtPdfWidgets->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtPdfWidgets->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtPdfWidgets->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtPdfWidgets->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtPdfWidgets->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtPdfWidgets->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtPdfWidgets->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtPdfWidgets->api_get_reference
#define sipKeepReference            sipAPI_QtPdfWidgets->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtPdfWidgets->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtPdfWidgets->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtPdfWidgets->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtPdfWidgets->api_type_scope
#define sipResolveTypedef           sipAPI_QtPdfWidgets->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtPdfWidgets->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtPdfWidgets->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtPdfWidgets->api_init_mixin
#define sipExportModule             sipAPI_QtPdfWidgets->api_export_module
#define sipInitModule               sipAPI_QtPdfWidgets->api_init_module
#define sipGetInterpreter           sipAPI_QtPdfWidgets->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtPdfWidgets->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtPdfWidgets->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtPdfWidgets->api_py_type_dict
#define sipPyTypeName               sipAPI_QtPdfWidgets->api_py_type_name
#define sipGetCFunction             sipAPI_QtPdfWidgets->api_get_c_function
#define sipGetMethod                sipAPI_QtPdfWidgets->api_get_method
#define sipFromMethod               sipAPI_QtPdfWidgets->api_from_method
#define sipGetDate                  sipAPI_QtPdfWidgets->api_get_date
#define sipFromDate                 sipAPI_QtPdfWidgets->api_from_date
#define sipGetDateTime              sipAPI_QtPdfWidgets->api_get_datetime
#define sipFromDateTime             sipAPI_QtPdfWidgets->api_from_datetime
#define sipGetTime                  sipAPI_QtPdfWidgets->api_get_time
#define sipFromTime                 sipAPI_QtPdfWidgets->api_from_time
#define sipIsUserType               sipAPI_QtPdfWidgets->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtPdfWidgets->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtPdfWidgets->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtPdfWidgets->api_unicode_write
#define sipUnicodeData              sipAPI_QtPdfWidgets->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtPdfWidgets->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtPdfWidgets->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtPdfWidgets->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtPdfWidgets->api_is_derived_class
#define sipGetUserObject            sipAPI_QtPdfWidgets->api_get_user_object
#define sipSetUserObject            sipAPI_QtPdfWidgets->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtPdfWidgets->api_register_event_handler
#define sipConvertToArray           sipAPI_QtPdfWidgets->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtPdfWidgets->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtPdfWidgets->api_enable_gc
#define sipPrintObject              sipAPI_QtPdfWidgets->api_print_object
#define sipLong_AsChar              sipAPI_QtPdfWidgets->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtPdfWidgets->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtPdfWidgets->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtPdfWidgets->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtPdfWidgets->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtPdfWidgets->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtPdfWidgets->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtPdfWidgets->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtPdfWidgets->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtPdfWidgets->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtPdfWidgets->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtPdfWidgets->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtPdfWidgets->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtPdfWidgets->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtPdfWidgets->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtPdfWidgets->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtPdfWidgets->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtPdfWidgets->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtPdfWidgets->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtPdfWidgets->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtPdfWidgets->api_release_type_us
#define sipIsPyMethod               sipAPI_QtPdfWidgets->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtPdfWidgets[];

#define sipType_QPdfPageSelector sipExportedTypes_QtPdfWidgets[0]

extern sipClassTypeDef sipTypeDef_QtPdfWidgets_QPdfPageSelector;

#define sipType_QPdfView sipExportedTypes_QtPdfWidgets[1]

#define sipType_QPdfView_ZoomMode sipExportedTypes_QtPdfWidgets[3]

#define sipType_QPdfView_PageMode sipExportedTypes_QtPdfWidgets[2]

extern sipClassTypeDef sipTypeDef_QtPdfWidgets_QPdfView;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtPdfWidgets;
extern sipExportedModuleDef sipModuleAPI_QtPdfWidgets;
extern sipTypeDef *sipExportedTypes_QtPdfWidgets[];

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtPdfWidgets_QtCore[10].it_td

#define sipType_QObject sipImportedTypes_QtPdfWidgets_QtCore[5].it_td

#define sipType_QByteArray sipImportedTypes_QtPdfWidgets_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtPdfWidgets_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtPdfWidgets_QtCore[8].it_td

#define sipType_QChildEvent sipImportedTypes_QtPdfWidgets_QtCore[1].it_td

#define sipType_QMargins sipImportedTypes_QtPdfWidgets_QtCore[3].it_td

#define sipType_QMetaMethod sipImportedTypes_QtPdfWidgets_QtCore[4].it_td

#define sipType_QSize sipImportedTypes_QtPdfWidgets_QtCore[6].it_td

#define sipType_QVariant sipImportedTypes_QtPdfWidgets_QtCore[9].it_td

#define sipType_QString sipImportedTypes_QtPdfWidgets_QtCore[7].it_td

#define sipType_qintptr sipImportedTypes_QtPdfWidgets_QtCore[11].it_td
extern sipImportedTypeDef sipImportedTypes_QtPdfWidgets_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtPdfWidgets_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtPdfWidgets_QtGui[14].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtPdfWidgets_QtGui[15].it_td

#define sipType_QKeyEvent sipImportedTypes_QtPdfWidgets_QtGui[11].it_td

#define sipType_QFocusEvent sipImportedTypes_QtPdfWidgets_QtGui[8].it_td

#define sipType_QPaintEvent sipImportedTypes_QtPdfWidgets_QtGui[17].it_td

#define sipType_QMoveEvent sipImportedTypes_QtPdfWidgets_QtGui[13].it_td

#define sipType_QResizeEvent sipImportedTypes_QtPdfWidgets_QtGui[19].it_td

#define sipType_QCloseEvent sipImportedTypes_QtPdfWidgets_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtPdfWidgets_QtGui[20].it_td

#define sipType_QHideEvent sipImportedTypes_QtPdfWidgets_QtGui[9].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtPdfWidgets_QtGui[2].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtPdfWidgets_QtGui[10].it_td

#define sipType_QDropEvent sipImportedTypes_QtPdfWidgets_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtPdfWidgets_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtPdfWidgets_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtPdfWidgets_QtGui[4].it_td

#define sipType_QActionEvent sipImportedTypes_QtPdfWidgets_QtGui[0].it_td

#define sipType_QEnterEvent sipImportedTypes_QtPdfWidgets_QtGui[7].it_td

#define sipType_QMouseEvent sipImportedTypes_QtPdfWidgets_QtGui[12].it_td

#define sipType_QWheelEvent sipImportedTypes_QtPdfWidgets_QtGui[22].it_td

#define sipType_QTabletEvent sipImportedTypes_QtPdfWidgets_QtGui[21].it_td

#define sipType_QPaintEngine sipImportedTypes_QtPdfWidgets_QtGui[16].it_td

#define sipType_QPainter sipImportedTypes_QtPdfWidgets_QtGui[18].it_td
extern sipImportedTypeDef sipImportedTypes_QtPdfWidgets_QtGui[];

#define sipType_QPdfDocument sipImportedTypes_QtPdfWidgets_QtPdf[0].it_td

#define sipType_QPdfPageNavigator sipImportedTypes_QtPdfWidgets_QtPdf[1].it_td

#define sipType_QPdfSearchModel sipImportedTypes_QtPdfWidgets_QtPdf[2].it_td
extern sipImportedTypeDef sipImportedTypes_QtPdfWidgets_QtPdf[];

#define sipType_QWidget sipImportedTypes_QtPdfWidgets_QtWidgets[3].it_td

#define sipType_QFrame sipImportedTypes_QtPdfWidgets_QtWidgets[1].it_td

#define sipType_QAbstractScrollArea sipImportedTypes_QtPdfWidgets_QtWidgets[0].it_td

#define sipType_QStyleOptionFrame sipImportedTypes_QtPdfWidgets_QtWidgets[2].it_td
extern sipImportedTypeDef sipImportedTypes_QtPdfWidgets_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtPdfWidgets_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtPdfWidgets_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtPdfWidgets_qt_metacast;

#endif
