/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtSvgWidgetsAPI_H
#define _QtSvgWidgetsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_mouseDoubleClickEvent 0
#define sipName_mouseDoubleClickEvent &sipStrings_QtSvgWidgets[0]
#define sipNameNr_setMaximumCacheSize 22
#define sipName_setMaximumCacheSize &sipStrings_QtSvgWidgets[22]
#define sipNameNr_PyQt6_QtSvgWidgets 42
#define sipName_PyQt6_QtSvgWidgets &sipStrings_QtSvgWidgets[42]
#define sipNameNr_focusNextPrevChild 61
#define sipName_focusNextPrevChild &sipStrings_QtSvgWidgets[61]
#define sipNameNr_hasHeightForWidth 80
#define sipName_hasHeightForWidth &sipStrings_QtSvgWidgets[80]
#define sipNameNr_mouseReleaseEvent 98
#define sipName_mouseReleaseEvent &sipStrings_QtSvgWidgets[98]
#define sipNameNr_setSharedRenderer 116
#define sipName_setSharedRenderer &sipStrings_QtSvgWidgets[116]
#define sipNameNr_QGraphicsSvgItem 134
#define sipName_QGraphicsSvgItem &sipStrings_QtSvgWidgets[134]
#define sipNameNr_collidesWithItem 151
#define sipName_collidesWithItem &sipStrings_QtSvgWidgets[151]
#define sipNameNr_collidesWithPath 168
#define sipName_collidesWithPath &sipStrings_QtSvgWidgets[168]
#define sipNameNr_contextMenuEvent 185
#define sipName_contextMenuEvent &sipStrings_QtSvgWidgets[185]
#define sipNameNr_disconnectNotify 202
#define sipName_disconnectNotify &sipStrings_QtSvgWidgets[202]
#define sipNameNr_inputMethodEvent 219
#define sipName_inputMethodEvent &sipStrings_QtSvgWidgets[219]
#define sipNameNr_inputMethodQuery 236
#define sipName_inputMethodQuery &sipStrings_QtSvgWidgets[236]
#define sipNameNr_maximumCacheSize 253
#define sipName_maximumCacheSize &sipStrings_QtSvgWidgets[253]
#define sipNameNr_sceneEventFilter 270
#define sipName_sceneEventFilter &sipStrings_QtSvgWidgets[270]
#define sipNameNr_hoverEnterEvent 287
#define sipName_hoverEnterEvent &sipStrings_QtSvgWidgets[287]
#define sipNameNr_hoverLeaveEvent 303
#define sipName_hoverLeaveEvent &sipStrings_QtSvgWidgets[303]
#define sipNameNr_keyReleaseEvent 319
#define sipName_keyReleaseEvent &sipStrings_QtSvgWidgets[319]
#define sipNameNr_minimumSizeHint 335
#define sipName_minimumSizeHint &sipStrings_QtSvgWidgets[335]
#define sipNameNr_mousePressEvent 351
#define sipName_mousePressEvent &sipStrings_QtSvgWidgets[351]
#define sipNameNr_dragEnterEvent 367
#define sipName_dragEnterEvent &sipStrings_QtSvgWidgets[367]
#define sipNameNr_dragLeaveEvent 382
#define sipName_dragLeaveEvent &sipStrings_QtSvgWidgets[382]
#define sipNameNr_heightForWidth 397
#define sipName_heightForWidth &sipStrings_QtSvgWidgets[397]
#define sipNameNr_hoverMoveEvent 412
#define sipName_hoverMoveEvent &sipStrings_QtSvgWidgets[412]
#define sipNameNr_mouseMoveEvent 427
#define sipName_mouseMoveEvent &sipStrings_QtSvgWidgets[427]
#define sipNameNr_connectNotify 205
#define sipName_connectNotify &sipStrings_QtSvgWidgets[205]
#define sipNameNr_dragMoveEvent 442
#define sipName_dragMoveEvent &sipStrings_QtSvgWidgets[442]
#define sipNameNr_focusOutEvent 456
#define sipName_focusOutEvent &sipStrings_QtSvgWidgets[456]
#define sipNameNr_keyPressEvent 470
#define sipName_keyPressEvent &sipStrings_QtSvgWidgets[470]
#define sipNameNr_sharedPainter 484
#define sipName_sharedPainter &sipStrings_QtSvgWidgets[484]
#define sipNameNr_boundingRect 498
#define sipName_boundingRect &sipStrings_QtSvgWidgets[498]
#define sipNameNr_focusInEvent 511
#define sipName_focusInEvent &sipStrings_QtSvgWidgets[511]
#define sipNameNr_isObscuredBy 524
#define sipName_isObscuredBy &sipStrings_QtSvgWidgets[524]
#define sipNameNr_setElementId 537
#define sipName_setElementId &sipStrings_QtSvgWidgets[537]
#define sipNameNr_actionEvent 550
#define sipName_actionEvent &sipStrings_QtSvgWidgets[550]
#define sipNameNr_changeEvent 562
#define sipName_changeEvent &sipStrings_QtSvgWidgets[562]
#define sipNameNr_customEvent 574
#define sipName_customEvent &sipStrings_QtSvgWidgets[574]
#define sipNameNr_eventFilter 586
#define sipName_eventFilter &sipStrings_QtSvgWidgets[586]
#define sipNameNr_initPainter 598
#define sipName_initPainter &sipStrings_QtSvgWidgets[598]
#define sipNameNr_nativeEvent 610
#define sipName_nativeEvent &sipStrings_QtSvgWidgets[610]
#define sipNameNr_paintEngine 622
#define sipName_paintEngine &sipStrings_QtSvgWidgets[622]
#define sipNameNr_resizeEvent 634
#define sipName_resizeEvent &sipStrings_QtSvgWidgets[634]
#define sipNameNr_tabletEvent 646
#define sipName_tabletEvent &sipStrings_QtSvgWidgets[646]
#define sipNameNr_QSvgWidget 658
#define sipName_QSvgWidget &sipStrings_QtSvgWidgets[658]
#define sipNameNr_childEvent 669
#define sipName_childEvent &sipStrings_QtSvgWidgets[669]
#define sipNameNr_closeEvent 680
#define sipName_closeEvent &sipStrings_QtSvgWidgets[680]
#define sipNameNr_enterEvent 691
#define sipName_enterEvent &sipStrings_QtSvgWidgets[691]
#define sipNameNr_itemChange 702
#define sipName_itemChange &sipStrings_QtSvgWidgets[702]
#define sipNameNr_leaveEvent 713
#define sipName_leaveEvent &sipStrings_QtSvgWidgets[713]
#define sipNameNr_opaqueArea 724
#define sipName_opaqueArea &sipStrings_QtSvgWidgets[724]
#define sipNameNr_paintEvent 735
#define sipName_paintEvent &sipStrings_QtSvgWidgets[735]
#define sipNameNr_sceneEvent 746
#define sipName_sceneEvent &sipStrings_QtSvgWidgets[746]
#define sipNameNr_setOptions 757
#define sipName_setOptions &sipStrings_QtSvgWidgets[757]
#define sipNameNr_setVisible 768
#define sipName_setVisible &sipStrings_QtSvgWidgets[768]
#define sipNameNr_timerEvent 779
#define sipName_timerEvent &sipStrings_QtSvgWidgets[779]
#define sipNameNr_wheelEvent 790
#define sipName_wheelEvent &sipStrings_QtSvgWidgets[790]
#define sipNameNr_dropEvent 801
#define sipName_dropEvent &sipStrings_QtSvgWidgets[801]
#define sipNameNr_elementId 811
#define sipName_elementId &sipStrings_QtSvgWidgets[811]
#define sipNameNr_hideEvent 821
#define sipName_hideEvent &sipStrings_QtSvgWidgets[821]
#define sipNameNr_moveEvent 831
#define sipName_moveEvent &sipStrings_QtSvgWidgets[831]
#define sipNameNr_showEvent 841
#define sipName_showEvent &sipStrings_QtSvgWidgets[841]
#define sipNameNr_contains 851
#define sipName_contains &sipStrings_QtSvgWidgets[851]
#define sipNameNr_renderer 860
#define sipName_renderer &sipStrings_QtSvgWidgets[860]
#define sipNameNr_sizeHint 869
#define sipName_sizeHint &sipStrings_QtSvgWidgets[869]
#define sipNameNr_advance 878
#define sipName_advance &sipStrings_QtSvgWidgets[878]
#define sipNameNr_devType 886
#define sipName_devType &sipStrings_QtSvgWidgets[886]
#define sipNameNr_options 894
#define sipName_options &sipStrings_QtSvgWidgets[894]
#define sipNameNr_metric 902
#define sipName_metric &sipStrings_QtSvgWidgets[902]
#define sipNameNr_parent 909
#define sipName_parent &sipStrings_QtSvgWidgets[909]
#define sipNameNr_widget 916
#define sipName_widget &sipStrings_QtSvgWidgets[916]
#define sipNameNr_event 923
#define sipName_event &sipStrings_QtSvgWidgets[923]
#define sipNameNr_paint 929
#define sipName_paint &sipStrings_QtSvgWidgets[929]
#define sipNameNr_shape 935
#define sipName_shape &sipStrings_QtSvgWidgets[935]
#define sipNameNr_load 941
#define sipName_load &sipStrings_QtSvgWidgets[941]
#define sipNameNr_type 946
#define sipName_type &sipStrings_QtSvgWidgets[946]

#define sipMalloc                   sipAPI_QtSvgWidgets->api_malloc
#define sipFree                     sipAPI_QtSvgWidgets->api_free
#define sipBuildResult              sipAPI_QtSvgWidgets->api_build_result
#define sipCallMethod               sipAPI_QtSvgWidgets->api_call_method
#define sipCallProcedureMethod      sipAPI_QtSvgWidgets->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtSvgWidgets->api_call_error_handler
#define sipParseResultEx            sipAPI_QtSvgWidgets->api_parse_result_ex
#define sipParseResult              sipAPI_QtSvgWidgets->api_parse_result
#define sipParseArgs                sipAPI_QtSvgWidgets->api_parse_args
#define sipParseKwdArgs             sipAPI_QtSvgWidgets->api_parse_kwd_args
#define sipParsePair                sipAPI_QtSvgWidgets->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtSvgWidgets->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtSvgWidgets->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtSvgWidgets->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtSvgWidgets->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtSvgWidgets->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtSvgWidgets->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtSvgWidgets->api_add_exception
#define sipNoFunction               sipAPI_QtSvgWidgets->api_no_function
#define sipNoMethod                 sipAPI_QtSvgWidgets->api_no_method
#define sipAbstractMethod           sipAPI_QtSvgWidgets->api_abstract_method
#define sipBadClass                 sipAPI_QtSvgWidgets->api_bad_class
#define sipBadCatcherResult         sipAPI_QtSvgWidgets->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtSvgWidgets->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtSvgWidgets->api_bad_operator_arg
#define sipTrace                    sipAPI_QtSvgWidgets->api_trace
#define sipTransferBack             sipAPI_QtSvgWidgets->api_transfer_back
#define sipTransferTo               sipAPI_QtSvgWidgets->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtSvgWidgets->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtSvgWidgets->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtSvgWidgets->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtSvgWidgets->api_voidptr_type
#define sipGetPyObject              sipAPI_QtSvgWidgets->api_get_pyobject
#define sipGetAddress               sipAPI_QtSvgWidgets->api_get_address
#define sipGetMixinAddress          sipAPI_QtSvgWidgets->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtSvgWidgets->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtSvgWidgets->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtSvgWidgets->api_call_hook
#define sipEndThread                sipAPI_QtSvgWidgets->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtSvgWidgets->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtSvgWidgets->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtSvgWidgets->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtSvgWidgets->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtSvgWidgets->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtSvgWidgets->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtSvgWidgets->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtSvgWidgets->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtSvgWidgets->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtSvgWidgets->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtSvgWidgets->api_convert_to_bool
#define sipReleaseType              sipAPI_QtSvgWidgets->api_release_type
#define sipConvertFromType          sipAPI_QtSvgWidgets->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtSvgWidgets->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtSvgWidgets->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtSvgWidgets->api_convert_from_enum
#define sipGetState                 sipAPI_QtSvgWidgets->api_get_state
#define sipExportSymbol             sipAPI_QtSvgWidgets->api_export_symbol
#define sipImportSymbol             sipAPI_QtSvgWidgets->api_import_symbol
#define sipFindType                 sipAPI_QtSvgWidgets->api_find_type
#define sipBytes_AsChar             sipAPI_QtSvgWidgets->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtSvgWidgets->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtSvgWidgets->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtSvgWidgets->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtSvgWidgets->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtSvgWidgets->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtSvgWidgets->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtSvgWidgets->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtSvgWidgets->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtSvgWidgets->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtSvgWidgets->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtSvgWidgets->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtSvgWidgets->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtSvgWidgets->api_get_reference
#define sipKeepReference            sipAPI_QtSvgWidgets->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtSvgWidgets->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtSvgWidgets->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtSvgWidgets->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtSvgWidgets->api_type_scope
#define sipResolveTypedef           sipAPI_QtSvgWidgets->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtSvgWidgets->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtSvgWidgets->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtSvgWidgets->api_init_mixin
#define sipExportModule             sipAPI_QtSvgWidgets->api_export_module
#define sipInitModule               sipAPI_QtSvgWidgets->api_init_module
#define sipGetInterpreter           sipAPI_QtSvgWidgets->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtSvgWidgets->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtSvgWidgets->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtSvgWidgets->api_py_type_dict
#define sipPyTypeName               sipAPI_QtSvgWidgets->api_py_type_name
#define sipGetCFunction             sipAPI_QtSvgWidgets->api_get_c_function
#define sipGetMethod                sipAPI_QtSvgWidgets->api_get_method
#define sipFromMethod               sipAPI_QtSvgWidgets->api_from_method
#define sipGetDate                  sipAPI_QtSvgWidgets->api_get_date
#define sipFromDate                 sipAPI_QtSvgWidgets->api_from_date
#define sipGetDateTime              sipAPI_QtSvgWidgets->api_get_datetime
#define sipFromDateTime             sipAPI_QtSvgWidgets->api_from_datetime
#define sipGetTime                  sipAPI_QtSvgWidgets->api_get_time
#define sipFromTime                 sipAPI_QtSvgWidgets->api_from_time
#define sipIsUserType               sipAPI_QtSvgWidgets->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtSvgWidgets->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtSvgWidgets->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtSvgWidgets->api_unicode_write
#define sipUnicodeData              sipAPI_QtSvgWidgets->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtSvgWidgets->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtSvgWidgets->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtSvgWidgets->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtSvgWidgets->api_is_derived_class
#define sipGetUserObject            sipAPI_QtSvgWidgets->api_get_user_object
#define sipSetUserObject            sipAPI_QtSvgWidgets->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtSvgWidgets->api_register_event_handler
#define sipConvertToArray           sipAPI_QtSvgWidgets->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtSvgWidgets->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtSvgWidgets->api_enable_gc
#define sipPrintObject              sipAPI_QtSvgWidgets->api_print_object
#define sipLong_AsChar              sipAPI_QtSvgWidgets->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtSvgWidgets->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtSvgWidgets->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtSvgWidgets->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtSvgWidgets->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtSvgWidgets->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtSvgWidgets->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtSvgWidgets->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtSvgWidgets->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtSvgWidgets->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtSvgWidgets->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtSvgWidgets->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtSvgWidgets->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtSvgWidgets->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtSvgWidgets->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtSvgWidgets->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtSvgWidgets->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtSvgWidgets->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtSvgWidgets->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtSvgWidgets->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtSvgWidgets->api_release_type_us
#define sipIsPyMethod               sipAPI_QtSvgWidgets->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtSvgWidgets[];

#define sipType_QGraphicsSvgItem sipExportedTypes_QtSvgWidgets[0]

extern sipClassTypeDef sipTypeDef_QtSvgWidgets_QGraphicsSvgItem;

#define sipType_QSvgWidget sipExportedTypes_QtSvgWidgets[1]

extern sipClassTypeDef sipTypeDef_QtSvgWidgets_QSvgWidget;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtSvgWidgets;
extern sipExportedModuleDef sipModuleAPI_QtSvgWidgets;
extern sipTypeDef *sipExportedTypes_QtSvgWidgets[];

#define sipType_Qt_ItemSelectionMode sipImportedTypes_QtSvgWidgets_QtCore[12].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtSvgWidgets_QtCore[11].it_td

#define sipType_QObject sipImportedTypes_QtSvgWidgets_QtCore[4].it_td

#define sipType_QByteArray sipImportedTypes_QtSvgWidgets_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtSvgWidgets_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtSvgWidgets_QtCore[9].it_td

#define sipType_QChildEvent sipImportedTypes_QtSvgWidgets_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtSvgWidgets_QtCore[3].it_td

#define sipType_QPointF sipImportedTypes_QtSvgWidgets_QtCore[5].it_td

#define sipType_QRectF sipImportedTypes_QtSvgWidgets_QtCore[6].it_td

#define sipType_QSize sipImportedTypes_QtSvgWidgets_QtCore[7].it_td

#define sipType_QVariant sipImportedTypes_QtSvgWidgets_QtCore[10].it_td

#define sipType_QString sipImportedTypes_QtSvgWidgets_QtCore[8].it_td

#define sipType_qintptr sipImportedTypes_QtSvgWidgets_QtCore[13].it_td
extern sipImportedTypeDef sipImportedTypes_QtSvgWidgets_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtSvgWidgets_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtSvgWidgets_QtGui[14].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtSvgWidgets_QtGui[15].it_td

#define sipType_QKeyEvent sipImportedTypes_QtSvgWidgets_QtGui[11].it_td

#define sipType_QFocusEvent sipImportedTypes_QtSvgWidgets_QtGui[8].it_td

#define sipType_QPaintEvent sipImportedTypes_QtSvgWidgets_QtGui[17].it_td

#define sipType_QMoveEvent sipImportedTypes_QtSvgWidgets_QtGui[13].it_td

#define sipType_QResizeEvent sipImportedTypes_QtSvgWidgets_QtGui[20].it_td

#define sipType_QCloseEvent sipImportedTypes_QtSvgWidgets_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtSvgWidgets_QtGui[21].it_td

#define sipType_QHideEvent sipImportedTypes_QtSvgWidgets_QtGui[9].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtSvgWidgets_QtGui[2].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtSvgWidgets_QtGui[10].it_td

#define sipType_QDropEvent sipImportedTypes_QtSvgWidgets_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtSvgWidgets_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtSvgWidgets_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtSvgWidgets_QtGui[4].it_td

#define sipType_QActionEvent sipImportedTypes_QtSvgWidgets_QtGui[0].it_td

#define sipType_QEnterEvent sipImportedTypes_QtSvgWidgets_QtGui[7].it_td

#define sipType_QMouseEvent sipImportedTypes_QtSvgWidgets_QtGui[12].it_td

#define sipType_QWheelEvent sipImportedTypes_QtSvgWidgets_QtGui[23].it_td

#define sipType_QTabletEvent sipImportedTypes_QtSvgWidgets_QtGui[22].it_td

#define sipType_QPaintEngine sipImportedTypes_QtSvgWidgets_QtGui[16].it_td

#define sipType_QPainter sipImportedTypes_QtSvgWidgets_QtGui[18].it_td

#define sipType_QPainterPath sipImportedTypes_QtSvgWidgets_QtGui[19].it_td
extern sipImportedTypeDef sipImportedTypes_QtSvgWidgets_QtGui[];

#define sipType_QSvgRenderer sipImportedTypes_QtSvgWidgets_QtSvg[1].it_td

#define sipType_QFlags_0100QtSvg_Option sipImportedTypes_QtSvgWidgets_QtSvg[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtSvgWidgets_QtSvg[];

#define sipType_QWidget sipImportedTypes_QtSvgWidgets_QtWidgets[9].it_td

#define sipType_QGraphicsItem sipImportedTypes_QtSvgWidgets_QtWidgets[0].it_td

#define sipType_QGraphicsItem_GraphicsItemChange sipImportedTypes_QtSvgWidgets_QtWidgets[1].it_td

#define sipType_QGraphicsObject sipImportedTypes_QtSvgWidgets_QtWidgets[2].it_td

#define sipType_QGraphicsSceneMouseEvent sipImportedTypes_QtSvgWidgets_QtWidgets[6].it_td

#define sipType_QGraphicsSceneWheelEvent sipImportedTypes_QtSvgWidgets_QtWidgets[7].it_td

#define sipType_QGraphicsSceneContextMenuEvent sipImportedTypes_QtSvgWidgets_QtWidgets[3].it_td

#define sipType_QGraphicsSceneHoverEvent sipImportedTypes_QtSvgWidgets_QtWidgets[5].it_td

#define sipType_QGraphicsSceneDragDropEvent sipImportedTypes_QtSvgWidgets_QtWidgets[4].it_td

#define sipType_QStyleOptionGraphicsItem sipImportedTypes_QtSvgWidgets_QtWidgets[8].it_td
extern sipImportedTypeDef sipImportedTypes_QtSvgWidgets_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtSvgWidgets_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtSvgWidgets_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtSvgWidgets_qt_metacast;

#endif
