/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtXml.h"

#line 455 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"

#line 54 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 343 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 520 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 479 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 493 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 442 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 508 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 178 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 196 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 66 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 331 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 69 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 467 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 72 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 363 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 305 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 78 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/build/QtXml/sipQtXmlQDomComment.cpp"


PyDoc_STRVAR(doc_QDomComment_nodeType, "nodeType(self) -> QDomNode.NodeType");

extern "C" {static PyObject *meth_QDomComment_nodeType(PyObject *, PyObject *);}
static PyObject *meth_QDomComment_nodeType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomComment *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomComment, &sipCpp))
        {
            ::QDomNode::NodeType sipRes;

            sipRes = sipCpp->nodeType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QDomNode_NodeType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomComment, sipName_nodeType, doc_QDomComment_nodeType);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QDomComment(void *, const sipTypeDef *);}
static void *cast_QDomComment(void *sipCppV, const sipTypeDef *targetType)
{
    ::QDomComment *sipCpp = reinterpret_cast< ::QDomComment *>(sipCppV);

    if (targetType == sipType_QDomComment)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QDomCharacterData)->ctd_cast(static_cast< ::QDomCharacterData *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDomComment(void *, int);}
static void release_QDomComment(void *sipCppV, int)
{
    delete reinterpret_cast< ::QDomComment *>(sipCppV);
}


extern "C" {static void *array_QDomComment(Py_ssize_t);}
static void *array_QDomComment(Py_ssize_t sipNrElem)
{
    return new ::QDomComment[sipNrElem];
}


extern "C" {static void array_delete_QDomComment(void *);}
static void array_delete_QDomComment(void *sipCpp)
{
    delete[] reinterpret_cast< ::QDomComment *>(sipCpp);
}


extern "C" {static void assign_QDomComment(void *, Py_ssize_t, void *);}
static void assign_QDomComment(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QDomComment *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QDomComment *>(sipSrc);
}


extern "C" {static void *copy_QDomComment(const void *, Py_ssize_t);}
static void *copy_QDomComment(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QDomComment(reinterpret_cast<const ::QDomComment *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QDomComment(sipSimpleWrapper *);}
static void dealloc_QDomComment(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDomComment(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QDomComment(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDomComment(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QDomComment *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QDomComment();

            return sipCpp;
        }
    }

    {
        const ::QDomComment* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDomComment, &a0))
        {
            sipCpp = new ::QDomComment(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QDomComment[] = {{2, 255, 1}};


static PyMethodDef methods_QDomComment[] = {
    {sipName_nodeType, meth_QDomComment_nodeType, METH_VARARGS, doc_QDomComment_nodeType}
};

PyDoc_STRVAR(doc_QDomComment, "\1QDomComment()\n"
"QDomComment(x: QDomComment)");


sipClassTypeDef sipTypeDef_QtXml_QDomComment = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDomComment,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QDomComment,
        {0, 0, 1},
        1, methods_QDomComment,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDomComment,
    -1,
    -1,
    supers_QDomComment,
    SIP_NULLPTR,
    init_type_QDomComment,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDomComment,
    assign_QDomComment,
    array_QDomComment,
    copy_QDomComment,
    release_QDomComment,
    cast_QDomComment,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QDomComment,
    sizeof (::QDomComment),
};
