/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSvg.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSvg/qsvgrenderer.sip"
#include <qsvgrenderer.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSvg/qtsvgglobal.sip"
#include <qtsvgglobal.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSvg/sipQtSvgQSvgRenderer.cpp"


class sipQSvgRenderer : public ::QSvgRenderer
{
public:
    sipQSvgRenderer(::QObject*);
    sipQSvgRenderer(const ::QString&, ::QObject*);
    sipQSvgRenderer(const ::QByteArray&, ::QObject*);
    sipQSvgRenderer(::QXmlStreamReader*, ::QObject*);
    virtual ~sipQSvgRenderer();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSvgRenderer(const sipQSvgRenderer &);
    sipQSvgRenderer &operator = (const sipQSvgRenderer &);

    char sipPyMethods[7];
};

sipQSvgRenderer::sipQSvgRenderer(::QObject*a0): ::QSvgRenderer(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSvgRenderer::sipQSvgRenderer(const ::QString& a0, ::QObject*a1): ::QSvgRenderer(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSvgRenderer::sipQSvgRenderer(const ::QByteArray& a0, ::QObject*a1): ::QSvgRenderer(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSvgRenderer::sipQSvgRenderer(::QXmlStreamReader*a0, ::QObject*a1): ::QSvgRenderer(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSvgRenderer::~sipQSvgRenderer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQSvgRenderer::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtSvg_qt_metaobject(sipPySelf, sipType_QSvgRenderer);

    return ::QSvgRenderer::metaObject();
}

int sipQSvgRenderer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QSvgRenderer::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtSvg_qt_metacall(sipPySelf, sipType_QSvgRenderer, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQSvgRenderer::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtSvg_qt_metacast(sipPySelf, sipType_QSvgRenderer, _clname, &sipCpp) ? sipCpp : ::QSvgRenderer::qt_metacast(_clname));
}

bool sipQSvgRenderer::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QSvgRenderer::event(a0);

    extern bool sipVH_QtSvg_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtSvg_8(sipGILState, sipImportedVirtErrorHandlers_QtSvg_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSvgRenderer::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QSvgRenderer::eventFilter(a0, a1);

    extern bool sipVH_QtSvg_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtSvg_7(sipGILState, sipImportedVirtErrorHandlers_QtSvg_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQSvgRenderer::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QSvgRenderer::timerEvent(a0);
        return;
    }

    extern void sipVH_QtSvg_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtSvg_6(sipGILState, sipImportedVirtErrorHandlers_QtSvg_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgRenderer::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QSvgRenderer::childEvent(a0);
        return;
    }

    extern void sipVH_QtSvg_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtSvg_5(sipGILState, sipImportedVirtErrorHandlers_QtSvg_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgRenderer::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QSvgRenderer::customEvent(a0);
        return;
    }

    extern void sipVH_QtSvg_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSvg_4(sipGILState, sipImportedVirtErrorHandlers_QtSvg_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgRenderer::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QSvgRenderer::connectNotify(a0);
        return;
    }

    extern void sipVH_QtSvg_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSvg_3(sipGILState, sipImportedVirtErrorHandlers_QtSvg_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSvgRenderer::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QSvgRenderer::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtSvg_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSvg_3(sipGILState, sipImportedVirtErrorHandlers_QtSvg_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSvgRenderer_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QSvgRenderer_isValid(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgRenderer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_isValid, doc_QSvgRenderer_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_defaultSize, "defaultSize(self) -> QSize");

extern "C" {static PyObject *meth_QSvgRenderer_defaultSize(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_defaultSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgRenderer, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->defaultSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_defaultSize, doc_QSvgRenderer_defaultSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_elementExists, "elementExists(self, id: str|None) -> bool");

extern "C" {static PyObject *meth_QSvgRenderer_elementExists(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_elementExists(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->elementExists(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_elementExists, doc_QSvgRenderer_elementExists);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_viewBox, "viewBox(self) -> QRect");

extern "C" {static PyObject *meth_QSvgRenderer_viewBox(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_viewBox(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgRenderer, &sipCpp))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->viewBox());

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_viewBox, doc_QSvgRenderer_viewBox);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_viewBoxF, "viewBoxF(self) -> QRectF");

extern "C" {static PyObject *meth_QSvgRenderer_viewBoxF(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_viewBoxF(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgRenderer, &sipCpp))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->viewBoxF());

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_viewBoxF, doc_QSvgRenderer_viewBoxF);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_setViewBox, "setViewBox(self, viewbox: QRect)\n"
"setViewBox(self, viewbox: QRectF)");

extern "C" {static PyObject *meth_QSvgRenderer_setViewBox(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_setViewBox(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRect* a0;
        ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->setViewBox(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QRectF* a0;
        ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QRectF, &a0))
        {
            sipCpp->setViewBox(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_setViewBox, doc_QSvgRenderer_setViewBox);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_animated, "animated(self) -> bool");

extern "C" {static PyObject *meth_QSvgRenderer_animated(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_animated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgRenderer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->animated();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_animated, doc_QSvgRenderer_animated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_boundsOnElement, "boundsOnElement(self, id: str|None) -> QRectF");

extern "C" {static PyObject *meth_QSvgRenderer_boundsOnElement(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_boundsOnElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->boundsOnElement(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_boundsOnElement, doc_QSvgRenderer_boundsOnElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_framesPerSecond, "framesPerSecond(self) -> int");

extern "C" {static PyObject *meth_QSvgRenderer_framesPerSecond(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_framesPerSecond(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgRenderer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->framesPerSecond();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_framesPerSecond, doc_QSvgRenderer_framesPerSecond);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_setFramesPerSecond, "setFramesPerSecond(self, num: int)");

extern "C" {static PyObject *meth_QSvgRenderer_setFramesPerSecond(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_setFramesPerSecond(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSvgRenderer, &sipCpp, &a0))
        {
            sipCpp->setFramesPerSecond(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_setFramesPerSecond, doc_QSvgRenderer_setFramesPerSecond);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_currentFrame, "currentFrame(self) -> int");

extern "C" {static PyObject *meth_QSvgRenderer_currentFrame(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_currentFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgRenderer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentFrame();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_currentFrame, doc_QSvgRenderer_currentFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_setCurrentFrame, "setCurrentFrame(self, a0: int)");

extern "C" {static PyObject *meth_QSvgRenderer_setCurrentFrame(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_setCurrentFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSvgRenderer, &sipCpp, &a0))
        {
            sipCpp->setCurrentFrame(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_setCurrentFrame, doc_QSvgRenderer_setCurrentFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_animationDuration, "animationDuration(self) -> int");

extern "C" {static PyObject *meth_QSvgRenderer_animationDuration(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_animationDuration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgRenderer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->animationDuration();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_animationDuration, doc_QSvgRenderer_animationDuration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_load, "load(self, filename: str|None) -> bool\n"
"load(self, contents: QByteArray|bytes|bytearray|memoryview) -> bool\n"
"load(self, contents: QXmlStreamReader|None) -> bool");

extern "C" {static PyObject *meth_QSvgRenderer_load(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_load(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->load(*a0);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->load(*a0);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QXmlStreamReader* a0;
        ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QXmlStreamReader, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->load(a0);
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_load, doc_QSvgRenderer_load);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_render, "render(self, p: QPainter|None)\n"
"render(self, p: QPainter|None, bounds: QRectF)\n"
"render(self, painter: QPainter|None, elementId: str|None, bounds: QRectF = QRectF())");

extern "C" {static PyObject *meth_QSvgRenderer_render(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_render(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter* a0;
        ::QSvgRenderer *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ8", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QPainter, &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->render(a0);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QPainter* a0;
        const ::QRectF* a1;
        ::QSvgRenderer *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ8J9", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QPainter, &a0, sipType_QRectF, &a1))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->render(a0, *a1);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QPainter* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QRectF& a2def = QRectF();
        const ::QRectF* a2 = &a2def;
        ::QSvgRenderer *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_bounds,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J1|J9", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QPainter, &a0, sipType_QString, &a1, &a1State, sipType_QRectF, &a2))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->render(a0, *a1, *a2);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_render, doc_QSvgRenderer_render);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_aspectRatioMode, "aspectRatioMode(self) -> Qt.AspectRatioMode");

extern "C" {static PyObject *meth_QSvgRenderer_aspectRatioMode(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_aspectRatioMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgRenderer, &sipCpp))
        {
            ::Qt::AspectRatioMode sipRes;

            sipRes = sipCpp->aspectRatioMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_AspectRatioMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_aspectRatioMode, doc_QSvgRenderer_aspectRatioMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_setAspectRatioMode, "setAspectRatioMode(self, mode: Qt.AspectRatioMode)");

extern "C" {static PyObject *meth_QSvgRenderer_setAspectRatioMode(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_setAspectRatioMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::AspectRatioMode a0;
        ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_Qt_AspectRatioMode, &a0))
        {
            sipCpp->setAspectRatioMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_setAspectRatioMode, doc_QSvgRenderer_setAspectRatioMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_transformForElement, "transformForElement(self, id: str|None) -> QTransform");

extern "C" {static PyObject *meth_QSvgRenderer_transformForElement(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_transformForElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QTransform*sipRes;

            sipRes = new ::QTransform(sipCpp->transformForElement(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QTransform, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_transformForElement, doc_QSvgRenderer_transformForElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_options, "options(self) -> QtSvg.Option");

extern "C" {static PyObject *meth_QSvgRenderer_options(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_options(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgRenderer, &sipCpp))
        {
            ::QtSvg::Options*sipRes;

            sipRes = new ::QtSvg::Options(sipCpp->options());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QtSvg_Option, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_options, doc_QSvgRenderer_options);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_setOptions, "setOptions(self, flags: QtSvg.Option)");

extern "C" {static PyObject *meth_QSvgRenderer_setOptions(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_setOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtSvg::Options* a0;
        int a0State = 0;
        ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgRenderer, &sipCpp, sipType_QFlags_0100QtSvg_Option, &a0, &a0State))
        {
            sipCpp->setOptions(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QtSvg_Option, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_setOptions, doc_QSvgRenderer_setOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_isAnimationEnabled, "isAnimationEnabled(self) -> bool");

extern "C" {static PyObject *meth_QSvgRenderer_isAnimationEnabled(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_isAnimationEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgRenderer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAnimationEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_isAnimationEnabled, doc_QSvgRenderer_isAnimationEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_setAnimationEnabled, "setAnimationEnabled(self, enable: bool)");

extern "C" {static PyObject *meth_QSvgRenderer_setAnimationEnabled(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_setAnimationEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QSvgRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QSvgRenderer, &sipCpp, &a0))
        {
            sipCpp->setAnimationEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_setAnimationEnabled, doc_QSvgRenderer_setAnimationEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgRenderer_setDefaultOptions, "setDefaultOptions(flags: QtSvg.Option)");

extern "C" {static PyObject *meth_QSvgRenderer_setDefaultOptions(PyObject *, PyObject *);}
static PyObject *meth_QSvgRenderer_setDefaultOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtSvg::Options* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QFlags_0100QtSvg_Option, &a0, &a0State))
        {
            ::QSvgRenderer::setDefaultOptions(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QtSvg_Option, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgRenderer, sipName_setDefaultOptions, doc_QSvgRenderer_setDefaultOptions);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSvgRenderer(void *, const sipTypeDef *);}
static void *cast_QSvgRenderer(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSvgRenderer *sipCpp = reinterpret_cast< ::QSvgRenderer *>(sipCppV);

    if (targetType == sipType_QSvgRenderer)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSvgRenderer(void *, int);}
static void release_QSvgRenderer(void *sipCppV, int)
{
    ::QSvgRenderer *sipCpp = reinterpret_cast< ::QSvgRenderer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QSvgRenderer(Py_ssize_t);}
static void *array_QSvgRenderer(Py_ssize_t sipNrElem)
{
    return new ::QSvgRenderer[sipNrElem];
}


extern "C" {static void array_delete_QSvgRenderer(void *);}
static void array_delete_QSvgRenderer(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSvgRenderer *>(sipCpp);
}


extern "C" {static void dealloc_QSvgRenderer(sipSimpleWrapper *);}
static void dealloc_QSvgRenderer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSvgRenderer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSvgRenderer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSvgRenderer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSvgRenderer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQSvgRenderer *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQSvgRenderer(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QString, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp = new sipQSvgRenderer(*a0, a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QByteArray, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp = new sipQSvgRenderer(*a0, a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QXmlStreamReader* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QXmlStreamReader, &a0, sipType_QObject, &a1, sipOwner))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp = new sipQSvgRenderer(a0, a1);
            Py_END_ALLOW_THREADS

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSvgRenderer[] = {{5, 0, 1}};


static PyMethodDef methods_QSvgRenderer[] = {
    {sipName_animated, meth_QSvgRenderer_animated, METH_VARARGS, doc_QSvgRenderer_animated},
    {sipName_animationDuration, meth_QSvgRenderer_animationDuration, METH_VARARGS, doc_QSvgRenderer_animationDuration},
    {sipName_aspectRatioMode, meth_QSvgRenderer_aspectRatioMode, METH_VARARGS, doc_QSvgRenderer_aspectRatioMode},
    {sipName_boundsOnElement, meth_QSvgRenderer_boundsOnElement, METH_VARARGS, doc_QSvgRenderer_boundsOnElement},
    {sipName_currentFrame, meth_QSvgRenderer_currentFrame, METH_VARARGS, doc_QSvgRenderer_currentFrame},
    {sipName_defaultSize, meth_QSvgRenderer_defaultSize, METH_VARARGS, doc_QSvgRenderer_defaultSize},
    {sipName_elementExists, meth_QSvgRenderer_elementExists, METH_VARARGS, doc_QSvgRenderer_elementExists},
    {sipName_framesPerSecond, meth_QSvgRenderer_framesPerSecond, METH_VARARGS, doc_QSvgRenderer_framesPerSecond},
    {sipName_isAnimationEnabled, meth_QSvgRenderer_isAnimationEnabled, METH_VARARGS, doc_QSvgRenderer_isAnimationEnabled},
    {sipName_isValid, meth_QSvgRenderer_isValid, METH_VARARGS, doc_QSvgRenderer_isValid},
    {sipName_load, meth_QSvgRenderer_load, METH_VARARGS, doc_QSvgRenderer_load},
    {sipName_options, meth_QSvgRenderer_options, METH_VARARGS, doc_QSvgRenderer_options},
    {sipName_render, SIP_MLMETH_CAST(meth_QSvgRenderer_render), METH_VARARGS|METH_KEYWORDS, doc_QSvgRenderer_render},
    {sipName_setAnimationEnabled, meth_QSvgRenderer_setAnimationEnabled, METH_VARARGS, doc_QSvgRenderer_setAnimationEnabled},
    {sipName_setAspectRatioMode, meth_QSvgRenderer_setAspectRatioMode, METH_VARARGS, doc_QSvgRenderer_setAspectRatioMode},
    {sipName_setCurrentFrame, meth_QSvgRenderer_setCurrentFrame, METH_VARARGS, doc_QSvgRenderer_setCurrentFrame},
    {sipName_setDefaultOptions, meth_QSvgRenderer_setDefaultOptions, METH_VARARGS, doc_QSvgRenderer_setDefaultOptions},
    {sipName_setFramesPerSecond, meth_QSvgRenderer_setFramesPerSecond, METH_VARARGS, doc_QSvgRenderer_setFramesPerSecond},
    {sipName_setOptions, meth_QSvgRenderer_setOptions, METH_VARARGS, doc_QSvgRenderer_setOptions},
    {sipName_setViewBox, meth_QSvgRenderer_setViewBox, METH_VARARGS, doc_QSvgRenderer_setViewBox},
    {sipName_transformForElement, meth_QSvgRenderer_transformForElement, METH_VARARGS, doc_QSvgRenderer_transformForElement},
    {sipName_viewBox, meth_QSvgRenderer_viewBox, METH_VARARGS, doc_QSvgRenderer_viewBox},
    {sipName_viewBoxF, meth_QSvgRenderer_viewBoxF, METH_VARARGS, doc_QSvgRenderer_viewBoxF}
};

PyDoc_STRVAR(doc_QSvgRenderer, "\1QSvgRenderer(parent: QObject|None = None)\n"
"QSvgRenderer(filename: str|None, parent: QObject|None = None)\n"
"QSvgRenderer(contents: QByteArray|bytes|bytearray|memoryview, parent: QObject|None = None)\n"
"QSvgRenderer(contents: QXmlStreamReader|None, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QSvgRenderer[] = {
    {"repaintNeeded()", "\1repaintNeeded(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QSvgRenderer = {
    &::QSvgRenderer::staticMetaObject,
    signals_QSvgRenderer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSvg_QSvgRenderer = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSvgRenderer,
        SIP_NULLPTR,
        &plugin_QSvgRenderer,
    },
    {
        sipNameNr_QSvgRenderer,
        {0, 0, 1},
        23, methods_QSvgRenderer,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSvgRenderer,
    -1,
    -1,
    supers_QSvgRenderer,
    SIP_NULLPTR,
    init_type_QSvgRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSvgRenderer,
    SIP_NULLPTR,
    array_QSvgRenderer,
    SIP_NULLPTR,
    release_QSvgRenderer,
    cast_QSvgRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSvgRenderer,
    sizeof (::QSvgRenderer),
};
