/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qfile.sip"
#include <qfile.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qfiledevice.sip"
#include <qfiledevice.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevicebase.sip"
#include <qiodevicebase.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 262 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQFile.cpp"


class sipQFile : public ::QFile
{
public:
    sipQFile();
    sipQFile(const ::QString&);
    sipQFile(::QObject*);
    sipQFile(const ::QString&, ::QObject*);
    virtual ~sipQFile();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::qint64 skipData(::qint64) SIP_OVERRIDE;
    ::qint64 writeData(const char*, ::qint64) SIP_OVERRIDE;
    ::qint64 readLineData(char*, ::qint64) SIP_OVERRIDE;
    ::qint64 readData(char*, ::qint64) SIP_OVERRIDE;
    bool waitForBytesWritten(int) SIP_OVERRIDE;
    bool waitForReadyRead(int) SIP_OVERRIDE;
    bool canReadLine() const SIP_OVERRIDE;
    ::qint64 bytesToWrite() const SIP_OVERRIDE;
    ::qint64 bytesAvailable() const SIP_OVERRIDE;
    bool reset() SIP_OVERRIDE;
    bool atEnd() const SIP_OVERRIDE;
    bool seek(::qint64) SIP_OVERRIDE;
    ::qint64 size() const SIP_OVERRIDE;
    ::qint64 pos() const SIP_OVERRIDE;
    void close() SIP_OVERRIDE;
    bool open(::QIODeviceBase::OpenMode) SIP_OVERRIDE;
    bool isSequential() const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    ::QString fileName() const SIP_OVERRIDE;
    bool resize(::qint64) SIP_OVERRIDE;
    ::QFileDevice::Permissions permissions() const SIP_OVERRIDE;
    bool setPermissions(::QFileDevice::Permissions) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQFile(const sipQFile &);
    sipQFile &operator = (const sipQFile &);

    char sipPyMethods[28];
};

sipQFile::sipQFile(): ::QFile(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQFile::sipQFile(const ::QString& a0): ::QFile(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQFile::sipQFile(::QObject*a0): ::QFile(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQFile::sipQFile(const ::QString& a0, ::QObject*a1): ::QFile(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQFile::~sipQFile()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQFile::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtCore_qt_metaobject(sipPySelf, sipType_QFile);

    return ::QFile::metaObject();
}

int sipQFile::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QFile::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtCore_qt_metacall(sipPySelf, sipType_QFile, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQFile::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtCore_qt_metacast(sipPySelf, sipType_QFile, _clname, &sipCpp) ? sipCpp : ::QFile::qt_metacast(_clname));
}

::qint64 sipQFile::skipData(::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_skipData);

    if (!sipMeth)
        return ::QFile::skipData(a0);

    extern ::qint64 sipVH_QtCore_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qint64);

    return sipVH_QtCore_50(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

::qint64 sipQFile::writeData(const char*a0, ::qint64 a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_writeData);

    if (!sipMeth)
        return ::QFile::writeData(a0, a1);

    extern ::qint64 sipVH_QtCore_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const char*, ::qint64);

    return sipVH_QtCore_49(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1);
}

::qint64 sipQFile::readLineData(char*a0, ::qint64 a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_readLineData);

    if (!sipMeth)
        return ::QFile::readLineData(a0, a1);

    extern ::qint64 sipVH_QtCore_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, char*, ::qint64);

    return sipVH_QtCore_48(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1);
}

::qint64 sipQFile::readData(char*a0, ::qint64 a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_readData);

    if (!sipMeth)
        return ::QFile::readData(a0, a1);

    extern ::qint64 sipVH_QtCore_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, char*, ::qint64);

    return sipVH_QtCore_47(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1);
}

bool sipQFile::waitForBytesWritten(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_waitForBytesWritten);

    if (!sipMeth)
        return ::QFile::waitForBytesWritten(a0);

    extern bool sipVH_QtCore_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtCore_12(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

bool sipQFile::waitForReadyRead(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_waitForReadyRead);

    if (!sipMeth)
        return ::QFile::waitForReadyRead(a0);

    extern bool sipVH_QtCore_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtCore_12(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

bool sipQFile::canReadLine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_canReadLine);

    if (!sipMeth)
        return ::QFile::canReadLine();

    extern bool sipVH_QtCore_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_37(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

::qint64 sipQFile::bytesToWrite() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_bytesToWrite);

    if (!sipMeth)
        return ::QFile::bytesToWrite();

    extern ::qint64 sipVH_QtCore_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_45(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

::qint64 sipQFile::bytesAvailable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_bytesAvailable);

    if (!sipMeth)
        return ::QFile::bytesAvailable();

    extern ::qint64 sipVH_QtCore_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_45(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

bool sipQFile::reset()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_reset);

    if (!sipMeth)
        return ::QFile::reset();

    extern bool sipVH_QtCore_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_37(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

bool sipQFile::atEnd() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_atEnd);

    if (!sipMeth)
        return ::QFile::atEnd();

    extern bool sipVH_QtCore_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_37(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

bool sipQFile::seek(::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_seek);

    if (!sipMeth)
        return ::QFile::seek(a0);

    extern bool sipVH_QtCore_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qint64);

    return sipVH_QtCore_46(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

::qint64 sipQFile::size() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_size);

    if (!sipMeth)
        return ::QFile::size();

    extern ::qint64 sipVH_QtCore_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_45(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

::qint64 sipQFile::pos() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_pos);

    if (!sipMeth)
        return ::QFile::pos();

    extern ::qint64 sipVH_QtCore_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_45(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

void sipQFile::close()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_close);

    if (!sipMeth)
    {
        ::QFile::close();
        return;
    }

    extern void sipVH_QtCore_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtCore_15(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

bool sipQFile::open(::QIODeviceBase::OpenMode a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_open);

    if (!sipMeth)
        return ::QFile::open(a0);

    extern bool sipVH_QtCore_44(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QIODeviceBase::OpenMode);

    return sipVH_QtCore_44(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

bool sipQFile::isSequential() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[16]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isSequential);

    if (!sipMeth)
        return ::QFile::isSequential();

    extern bool sipVH_QtCore_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_37(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

bool sipQFile::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QFile::event(a0);

    extern bool sipVH_QtCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtCore_0(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

bool sipQFile::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QFile::eventFilter(a0, a1);

    extern bool sipVH_QtCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtCore_1(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0, a1);
}

void sipQFile::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QFile::timerEvent(a0);
        return;
    }

    extern void sipVH_QtCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtCore_2(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQFile::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QFile::childEvent(a0);
        return;
    }

    extern void sipVH_QtCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtCore_3(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQFile::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QFile::customEvent(a0);
        return;
    }

    extern void sipVH_QtCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtCore_4(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQFile::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QFile::connectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

void sipQFile::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QFile::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

::QString sipQFile::fileName() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[24]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_fileName);

    if (!sipMeth)
        return ::QFile::fileName();

    extern ::QString sipVH_QtCore_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_56(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

bool sipQFile::resize(::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_resize);

    if (!sipMeth)
        return ::QFile::resize(a0);

    extern bool sipVH_QtCore_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qint64);

    return sipVH_QtCore_46(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}

::QFileDevice::Permissions sipQFile::permissions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[26]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_permissions);

    if (!sipMeth)
        return ::QFile::permissions();

    extern ::QFileDevice::Permissions sipVH_QtCore_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_57(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth);
}

bool sipQFile::setPermissions(::QFileDevice::Permissions a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_setPermissions);

    if (!sipMeth)
        return ::QFile::setPermissions(a0);

    extern bool sipVH_QtCore_58(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFileDevice::Permissions);

    return sipVH_QtCore_58(sipGILState, sipVEH_QtCore_PyQt6, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QFile_fileName, "fileName(self) -> str");

extern "C" {static PyObject *meth_QFile_fileName(PyObject *, PyObject *);}
static PyObject *meth_QFile_fileName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QFile)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFile, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QFile::fileName() : sipCpp->fileName()));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_fileName, doc_QFile_fileName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_setFileName, "setFileName(self, name: str|None)");

extern "C" {static PyObject *meth_QFile_setFileName(PyObject *, PyObject *);}
static PyObject *meth_QFile_setFileName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFile, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setFileName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_setFileName, doc_QFile_setFileName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_encodeName, "encodeName(fileName: str|None) -> QByteArray");

extern "C" {static PyObject *meth_QFile_encodeName(PyObject *, PyObject *);}
static PyObject *meth_QFile_encodeName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(::QFile::encodeName(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_encodeName, doc_QFile_encodeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_decodeName, "decodeName(localFileName: QByteArray|bytes|bytearray|memoryview) -> str\n"
"decodeName(localFileName: str) -> str");

extern "C" {static PyObject *meth_QFile_decodeName(PyObject *, PyObject *);}
static PyObject *meth_QFile_decodeName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QByteArray, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QFile::decodeName(*a0));
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const char* a0;
        PyObject *a0Keep;

        if (sipParseArgs(&sipParseErr, sipArgs, "CAA", &sipSelf, &a0Keep, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QFile::decodeName(a0));
            Py_DECREF(a0Keep);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_decodeName, doc_QFile_decodeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_exists, "exists(self) -> bool\n"
"exists(fileName: str|None) -> bool");

extern "C" {static PyObject *meth_QFile_exists(PyObject *, PyObject *);}
static PyObject *meth_QFile_exists(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFile, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->exists();

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = ::QFile::exists(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_exists, doc_QFile_exists);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_symLinkTarget, "symLinkTarget(self) -> str\n"
"symLinkTarget(fileName: str|None) -> str");

extern "C" {static PyObject *meth_QFile_symLinkTarget(PyObject *, PyObject *);}
static PyObject *meth_QFile_symLinkTarget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFile, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->symLinkTarget());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QFile::symLinkTarget(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_symLinkTarget, doc_QFile_symLinkTarget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_remove, "remove(self) -> bool\n"
"remove(fileName: str|None) -> bool");

extern "C" {static PyObject *meth_QFile_remove(PyObject *, PyObject *);}
static PyObject *meth_QFile_remove(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFile, &sipCpp))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->remove();
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = ::QFile::remove(*a0);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_remove, doc_QFile_remove);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_rename, "rename(self, newName: str|None) -> bool\n"
"rename(oldName: str|None, newName: str|None) -> bool");

extern "C" {static PyObject *meth_QFile_rename(PyObject *, PyObject *);}
static PyObject *meth_QFile_rename(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFile, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->rename(*a0);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1J1", &sipSelf, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = ::QFile::rename(*a0, *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_rename, doc_QFile_rename);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_link, "link(self, newName: str|None) -> bool\n"
"link(oldname: str|None, newName: str|None) -> bool");

extern "C" {static PyObject *meth_QFile_link(PyObject *, PyObject *);}
static PyObject *meth_QFile_link(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFile, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->link(*a0);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1J1", &sipSelf, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = ::QFile::link(*a0, *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_link, doc_QFile_link);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_copy, "copy(self, newName: str|None) -> bool\n"
"copy(fileName: str|None, newName: str|None) -> bool");

extern "C" {static PyObject *meth_QFile_copy(PyObject *, PyObject *);}
static PyObject *meth_QFile_copy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFile, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->copy(*a0);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1J1", &sipSelf, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = ::QFile::copy(*a0, *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_copy, doc_QFile_copy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_open, "open(self, flags: QIODeviceBase.OpenModeFlag, permissions: QFileDevice.Permission) -> bool\n"
"open(self, flags: QIODeviceBase.OpenModeFlag) -> bool\n"
"open(self, fd: int, ioFlags: QIODeviceBase.OpenModeFlag, handleFlags: QFileDevice.FileHandleFlag = QFileDevice.DontCloseHandle) -> bool");

extern "C" {static PyObject *meth_QFile_open(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QFile_open(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QFile)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QIODeviceBase::OpenMode* a0;
        int a0State = 0;
        ::QFileDevice::Permissions* a1;
        int a1State = 0;
        ::QFile *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1", &sipSelf, sipType_QFile, &sipCpp, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, &a0, &a0State, sipType_QFlags_0100QFileDevice_Permission, &a1, &a1State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->open(*a0, *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(a0, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, a0State);
            sipReleaseType(a1, sipType_QFlags_0100QFileDevice_Permission, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QIODeviceBase::OpenMode* a0;
        int a0State = 0;
        ::QFile *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QFile, &sipCpp, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, &a0, &a0State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp->::QFile::open(*a0) : sipCpp->open(*a0));
            Py_END_ALLOW_THREADS
            sipReleaseType(a0, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        int a0;
        ::QIODeviceBase::OpenMode* a1;
        int a1State = 0;
        ::QFileDevice::FileHandleFlags a2def = QFileDevice::DontCloseHandle;
        ::QFileDevice::FileHandleFlags* a2 = &a2def;
        int a2State = 0;
        ::QFile *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_handleFlags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiJ1|J1", &sipSelf, sipType_QFile, &sipCpp, &a0, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, &a1, &a1State, sipType_QFlags_0100QFileDevice_FileHandleFlag, &a2, &a2State))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->open(a0, *a1, *a2);
            Py_END_ALLOW_THREADS
            sipReleaseType(a1, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, a1State);
            sipReleaseType(a2, sipType_QFlags_0100QFileDevice_FileHandleFlag, a2State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_open, doc_QFile_open);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_size, "size(self) -> int");

extern "C" {static PyObject *meth_QFile_size(PyObject *, PyObject *);}
static PyObject *meth_QFile_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QFile)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFile, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QFile::size() : sipCpp->size());

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_size, doc_QFile_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_resize, "resize(self, sz: int) -> bool\n"
"resize(filename: str|None, sz: int) -> bool");

extern "C" {static PyObject *meth_QFile_resize(PyObject *, PyObject *);}
static PyObject *meth_QFile_resize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QFile)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::qint64 a0;
        ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QFile, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QFile::resize(a0) : sipCpp->resize(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::qint64 a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1n", &sipSelf, sipType_QString, &a0, &a0State, &a1))
        {
            bool sipRes;

            sipRes = ::QFile::resize(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_resize, doc_QFile_resize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_permissions, "permissions(self) -> QFileDevice.Permission\n"
"permissions(filename: str|None) -> QFileDevice.Permission");

extern "C" {static PyObject *meth_QFile_permissions(PyObject *, PyObject *);}
static PyObject *meth_QFile_permissions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QFile)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFile, &sipCpp))
        {
            ::QFileDevice::Permissions*sipRes;

            sipRes = new ::QFileDevice::Permissions((sipSelfWasArg ? sipCpp->::QFile::permissions() : sipCpp->permissions()));

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QFileDevice_Permission, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            ::QFileDevice::Permissions*sipRes;

            sipRes = new ::QFileDevice::Permissions(::QFile::permissions(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QFileDevice_Permission, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_permissions, doc_QFile_permissions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_setPermissions, "setPermissions(self, permissionSpec: QFileDevice.Permission) -> bool\n"
"setPermissions(filename: str|None, permissionSpec: QFileDevice.Permission) -> bool");

extern "C" {static PyObject *meth_QFile_setPermissions(PyObject *, PyObject *);}
static PyObject *meth_QFile_setPermissions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QFile)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QFileDevice::Permissions* a0;
        int a0State = 0;
        ::QFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFile, &sipCpp, sipType_QFlags_0100QFileDevice_Permission, &a0, &a0State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QFile::setPermissions(*a0) : sipCpp->setPermissions(*a0));
            sipReleaseType(a0, sipType_QFlags_0100QFileDevice_Permission, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QFileDevice::Permissions* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1J1", &sipSelf, sipType_QString, &a0, &a0State, sipType_QFlags_0100QFileDevice_Permission, &a1, &a1State))
        {
            bool sipRes;

            sipRes = ::QFile::setPermissions(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(a1, sipType_QFlags_0100QFileDevice_Permission, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_setPermissions, doc_QFile_setPermissions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_moveToTrash, "moveToTrash(self) -> bool\n"
"moveToTrash(fileName: str|None) -> (bool, str)");

extern "C" {static PyObject *meth_QFile_moveToTrash(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QFile_moveToTrash(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QFile *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "B", &sipSelf, sipType_QFile, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->moveToTrash();

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QString* a1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "CJ1", &sipSelf, sipType_QString, &a0, &a0State))
        {
            bool sipRes;
            a1 = new ::QString();

            sipRes = ::QFile::moveToTrash(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(bN)", sipRes, a1, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_moveToTrash, doc_QFile_moveToTrash);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFile_supportsMoveToTrash, "supportsMoveToTrash() -> bool");

extern "C" {static PyObject *meth_QFile_supportsMoveToTrash(PyObject *, PyObject *);}
static PyObject *meth_QFile_supportsMoveToTrash(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            bool sipRes;

            sipRes = ::QFile::supportsMoveToTrash();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFile, sipName_supportsMoveToTrash, doc_QFile_supportsMoveToTrash);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QFile(void *, const sipTypeDef *);}
static void *cast_QFile(void *sipCppV, const sipTypeDef *targetType)
{
    ::QFile *sipCpp = reinterpret_cast< ::QFile *>(sipCppV);

    if (targetType == sipType_QFile)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QFileDevice)->ctd_cast(static_cast< ::QFileDevice *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QFile(void *, int);}
static void release_QFile(void *sipCppV, int)
{
    ::QFile *sipCpp = reinterpret_cast< ::QFile *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QFile(Py_ssize_t);}
static void *array_QFile(Py_ssize_t sipNrElem)
{
    return new ::QFile[sipNrElem];
}


extern "C" {static void array_delete_QFile(void *);}
static void array_delete_QFile(void *sipCpp)
{
    delete[] reinterpret_cast< ::QFile *>(sipCpp);
}


extern "C" {static void dealloc_QFile(sipSimpleWrapper *);}
static void dealloc_QFile(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQFile *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QFile(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QFile(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QFile(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQFile *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQFile();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QString, &a0, &a0State))
        {
            sipCpp = new sipQFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQFile(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1JH", sipType_QString, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQFile(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QFile[] = {{86, 255, 1}};


static PyMethodDef methods_QFile[] = {
    {sipName_copy, meth_QFile_copy, METH_VARARGS, doc_QFile_copy},
    {sipName_decodeName, meth_QFile_decodeName, METH_VARARGS, doc_QFile_decodeName},
    {sipName_encodeName, meth_QFile_encodeName, METH_VARARGS, doc_QFile_encodeName},
    {sipName_exists, meth_QFile_exists, METH_VARARGS, doc_QFile_exists},
    {sipName_fileName, meth_QFile_fileName, METH_VARARGS, doc_QFile_fileName},
    {sipName_link, meth_QFile_link, METH_VARARGS, doc_QFile_link},
    {sipName_moveToTrash, SIP_MLMETH_CAST(meth_QFile_moveToTrash), METH_VARARGS|METH_KEYWORDS, doc_QFile_moveToTrash},
    {sipName_open, SIP_MLMETH_CAST(meth_QFile_open), METH_VARARGS|METH_KEYWORDS, doc_QFile_open},
    {sipName_permissions, meth_QFile_permissions, METH_VARARGS, doc_QFile_permissions},
    {sipName_remove, meth_QFile_remove, METH_VARARGS, doc_QFile_remove},
    {sipName_rename, meth_QFile_rename, METH_VARARGS, doc_QFile_rename},
    {sipName_resize, meth_QFile_resize, METH_VARARGS, doc_QFile_resize},
    {sipName_setFileName, meth_QFile_setFileName, METH_VARARGS, doc_QFile_setFileName},
    {sipName_setPermissions, meth_QFile_setPermissions, METH_VARARGS, doc_QFile_setPermissions},
    {sipName_size, meth_QFile_size, METH_VARARGS, doc_QFile_size},
    {sipName_supportsMoveToTrash, meth_QFile_supportsMoveToTrash, METH_VARARGS, doc_QFile_supportsMoveToTrash},
    {sipName_symLinkTarget, meth_QFile_symLinkTarget, METH_VARARGS, doc_QFile_symLinkTarget}
};

PyDoc_STRVAR(doc_QFile, "\1QFile()\n"
"QFile(name: str|None)\n"
"QFile(parent: QObject|None)\n"
"QFile(name: str|None, parent: QObject|None)");


static pyqt6ClassPluginDef plugin_QFile = {
    &::QFile::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QFile = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QFile,
        SIP_NULLPTR,
        &plugin_QFile,
    },
    {
        sipNameNr_QFile,
        {0, 0, 1},
        17, methods_QFile,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QFile,
    -1,
    -1,
    supers_QFile,
    SIP_NULLPTR,
    init_type_QFile,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QFile,
    SIP_NULLPTR,
    array_QFile,
    SIP_NULLPTR,
    release_QFile,
    cast_QFile,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QFile,
    sizeof (::QFile),
};
