/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtPositioningAPI_H
#define _QtPositioningAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QNmeaSatelliteInfoSource__SatelliteInfoParseStatus 0
#define sipName_QNmeaSatelliteInfoSource__SatelliteInfoParseStatus &sipStrings_QtPositioning[0]
#define sipNameNr_51 51
#define sipName_51 &sipStrings_QtPositioning[51]
#define sipNameNr_101 101
#define sipName_101 &sipStrings_QtPositioning[101]
#define sipNameNr_QGeoAreaMonitorSource__AreaMonitorFeature 151
#define sipName_QGeoAreaMonitorSource__AreaMonitorFeature &sipStrings_QtPositioning[151]
#define sipNameNr_QGeoPositionInfoSource__PositioningMethod 193
#define sipName_QGeoPositionInfoSource__PositioningMethod &sipStrings_QtPositioning[193]
#define sipNameNr_QNmeaSatelliteInfoSource__UpdateMode 235
#define sipName_QNmeaSatelliteInfoSource__UpdateMode &sipStrings_QtPositioning[235]
#define sipNameNr_DegreesMinutesSecondsWithHemisphere 272
#define sipName_DegreesMinutesSecondsWithHemisphere &sipStrings_QtPositioning[272]
#define sipNameNr_QNmeaPositionInfoSource__UpdateMode 308
#define sipName_QNmeaPositionInfoSource__UpdateMode &sipStrings_QtPositioning[308]
#define sipNameNr_fromSatellitePositioningMethodsOnly 344
#define sipName_fromSatellitePositioningMethodsOnly &sipStrings_QtPositioning[344]
#define sipNameNr_QGeoSatelliteInfo__SatelliteSystem 380
#define sipName_QGeoSatelliteInfo__SatelliteSystem &sipStrings_QtPositioning[380]
#define sipNameNr_supportedPositioningMethodsChanged 415
#define sipName_supportedPositioningMethodsChanged &sipStrings_QtPositioning[415]
#define sipNameNr_QGeoCoordinate__CoordinateFormat 450
#define sipName_QGeoCoordinate__CoordinateFormat &sipStrings_QtPositioning[450]
#define sipNameNr_NonSatellitePositioningMethods 483
#define sipName_NonSatellitePositioningMethods &sipStrings_QtPositioning[483]
#define sipNameNr_QGeoCoordinate__CoordinateType 514
#define sipName_QGeoCoordinate__CoordinateType &sipStrings_QtPositioning[514]
#define sipNameNr_QGeoSatelliteInfoSource__Error 545
#define sipName_QGeoSatelliteInfoSource__Error &sipStrings_QtPositioning[545]
#define sipNameNr_setPreferredPositioningMethods 576
#define sipName_setPreferredPositioningMethods &sipStrings_QtPositioning[576]
#define sipNameNr_QGeoPositionInfoSource__Error 607
#define sipName_QGeoPositionInfoSource__Error &sipStrings_QtPositioning[607]
#define sipNameNr_DegreesMinutesWithHemisphere 637
#define sipName_DegreesMinutesWithHemisphere &sipStrings_QtPositioning[637]
#define sipNameNr_PersistentAreaMonitorFeature 666
#define sipName_PersistentAreaMonitorFeature &sipStrings_QtPositioning[666]
#define sipNameNr_QGeoAreaMonitorSource__Error 695
#define sipName_QGeoAreaMonitorSource__Error &sipStrings_QtPositioning[695]
#define sipNameNr_QGeoSatelliteInfo__Attribute 724
#define sipName_QGeoSatelliteInfo__Attribute &sipStrings_QtPositioning[724]
#define sipNameNr_parseSatellitesInUseFromNmea 753
#define sipName_parseSatellitesInUseFromNmea &sipStrings_QtPositioning[753]
#define sipNameNr_supportedAreaMonitorFeatures 782
#define sipName_supportedAreaMonitorFeatures &sipStrings_QtPositioning[782]
#define sipNameNr_QGeoPositionInfo__Attribute 811
#define sipName_QGeoPositionInfo__Attribute &sipStrings_QtPositioning[811]
#define sipNameNr_SatellitePositioningMethods 486
#define sipName_SatellitePositioningMethods &sipStrings_QtPositioning[486]
#define sipNameNr_preferredPositioningMethods 839
#define sipName_preferredPositioningMethods &sipStrings_QtPositioning[839]
#define sipNameNr_setUserEquivalentRangeError 867
#define sipName_setUserEquivalentRangeError &sipStrings_QtPositioning[867]
#define sipNameNr_supportedPositioningMethods 895
#define sipName_supportedPositioningMethods &sipStrings_QtPositioning[895]
#define sipNameNr_923 923
#define sipName_923 &sipStrings_QtPositioning[923]
#define sipNameNr_parseSatelliteInfoFromNmea 950
#define sipName_parseSatelliteInfoFromNmea &sipStrings_QtPositioning[950]
#define sipNameNr_setNotificationParameters 977
#define sipName_setNotificationParameters &sipStrings_QtPositioning[977]
#define sipNameNr_InsufficientPositionInfo 1003
#define sipName_InsufficientPositionInfo &sipStrings_QtPositioning[1003]
#define sipNameNr_1028 1028
#define sipName_1028 &sipStrings_QtPositioning[1028]
#define sipNameNr_QNmeaSatelliteInfoSource 1053
#define sipName_QNmeaSatelliteInfoSource &sipStrings_QtPositioning[1053]
#define sipNameNr_SatelliteInfoParseStatus 26
#define sipName_SatelliteInfoParseStatus &sipStrings_QtPositioning[26]
#define sipNameNr_SimulationUpdateInterval 1078
#define sipName_SimulationUpdateInterval &sipStrings_QtPositioning[1078]
#define sipNameNr_parsePosInfoFromNmeaData 1103
#define sipName_parsePosInfoFromNmeaData &sipStrings_QtPositioning[1103]
#define sipNameNr_userEquivalentRangeError 1128
#define sipName_userEquivalentRangeError &sipStrings_QtPositioning[1128]
#define sipNameNr_QGeoSatelliteInfoSource 1153
#define sipName_QGeoSatelliteInfoSource &sipStrings_QtPositioning[1153]
#define sipNameNr_QNmeaPositionInfoSource 1177
#define sipName_QNmeaPositionInfoSource &sipStrings_QtPositioning[1177]
#define sipNameNr_satellitesInViewUpdated 1201
#define sipName_satellitesInViewUpdated &sipStrings_QtPositioning[1201]
#define sipNameNr_QGeoPositionInfoSource 1225
#define sipName_QGeoPositionInfoSource &sipStrings_QtPositioning[1225]
#define sipNameNr_notificationParameters 1248
#define sipName_notificationParameters &sipStrings_QtPositioning[1248]
#define sipNameNr_satellitesInUseUpdated 1271
#define sipName_satellitesInUseUpdated &sipStrings_QtPositioning[1271]
#define sipNameNr_setSatelliteIdentifier 1294
#define sipName_setSatelliteIdentifier &sipStrings_QtPositioning[1294]
#define sipNameNr_AllPositioningMethods 1317
#define sipName_AllPositioningMethods &sipStrings_QtPositioning[1317]
#define sipNameNr_AnyAreaMonitorFeature 1339
#define sipName_AnyAreaMonitorFeature &sipStrings_QtPositioning[1339]
#define sipNameNr_DegreesMinutesSeconds 1361
#define sipName_DegreesMinutesSeconds &sipStrings_QtPositioning[1361]
#define sipNameNr_DegreesWithHemisphere 1383
#define sipName_DegreesWithHemisphere &sipStrings_QtPositioning[1383]
#define sipNameNr_QGeoAreaMonitorSource 1405
#define sipName_QGeoAreaMonitorSource &sipStrings_QtPositioning[1405]
#define sipNameNr_1427 1427
#define sipName_1427 &sipStrings_QtPositioning[1427]
#define sipNameNr_minimumUpdateInterval 1449
#define sipName_minimumUpdateInterval &sipStrings_QtPositioning[1449]
#define sipNameNr_setExtendedAttributes 1471
#define sipName_setExtendedAttributes &sipStrings_QtPositioning[1471]
#define sipNameNr_setPositionInfoSource 1493
#define sipName_setPositionInfoSource &sipStrings_QtPositioning[1493]
#define sipNameNr_NoPositioningMethods 1515
#define sipName_NoPositioningMethods &sipStrings_QtPositioning[1515]
#define sipNameNr_QGeoShape__ShapeType 1536
#define sipName_QGeoShape__ShapeType &sipStrings_QtPositioning[1536]
#define sipNameNr_atDistanceAndAzimuth 1557
#define sipName_atDistanceAndAzimuth &sipStrings_QtPositioning[1557]
#define sipNameNr_boundingGeoRectangle 1578
#define sipName_boundingGeoRectangle &sipStrings_QtPositioning[1578]
#define sipNameNr_PyQt6_QtPositioning 1599
#define sipName_PyQt6_QtPositioning &sipStrings_QtPositioning[1599]
#define sipNameNr_QGeoAreaMonitorInfo 1619
#define sipName_QGeoAreaMonitorInfo &sipStrings_QtPositioning[1619]
#define sipNameNr_createDefaultSource 1639
#define sipName_createDefaultSource &sipStrings_QtPositioning[1639]
#define sipNameNr_satelliteIdentifier 1659
#define sipName_satelliteIdentifier &sipStrings_QtPositioning[1659]
#define sipNameNr_AreaMonitorFeature 174
#define sipName_AreaMonitorFeature &sipStrings_QtPositioning[174]
#define sipNameNr_HorizontalAccuracy 1679
#define sipName_HorizontalAccuracy &sipStrings_QtPositioning[1679]
#define sipNameNr_UnknownSourceError 1698
#define sipName_UnknownSourceError &sipStrings_QtPositioning[1698]
#define sipNameNr_UpdateTimeoutError 1717
#define sipName_UpdateTimeoutError &sipStrings_QtPositioning[1717]
#define sipNameNr_containsCoordinate 1736
#define sipName_containsCoordinate &sipStrings_QtPositioning[1736]
#define sipNameNr_extendedAttributes 1755
#define sipName_extendedAttributes &sipStrings_QtPositioning[1755]
#define sipNameNr_positionInfoSource 1774
#define sipName_positionInfoSource &sipStrings_QtPositioning[1774]
#define sipNameNr_setBackendProperty 1793
#define sipName_setBackendProperty &sipStrings_QtPositioning[1793]
#define sipNameNr_setSatelliteSystem 1812
#define sipName_setSatelliteSystem &sipStrings_QtPositioning[1812]
#define sipNameNr_DirectionAccuracy 1831
#define sipName_DirectionAccuracy &sipStrings_QtPositioning[1831]
#define sipNameNr_InvalidCoordinate 1849
#define sipName_InvalidCoordinate &sipStrings_QtPositioning[1849]
#define sipNameNr_MagneticVariation 1867
#define sipName_MagneticVariation &sipStrings_QtPositioning[1867]
#define sipNameNr_PositioningMethod 217
#define sipName_PositioningMethod &sipStrings_QtPositioning[217]
#define sipNameNr_QGeoSatelliteInfo 1885
#define sipName_QGeoSatelliteInfo &sipStrings_QtPositioning[1885]
#define sipNameNr_lastKnownPosition 1903
#define sipName_lastKnownPosition &sipStrings_QtPositioning[1903]
#define sipNameNr_replaceCoordinate 1921
#define sipName_replaceCoordinate &sipStrings_QtPositioning[1921]
#define sipNameNr_setSignalStrength 1939
#define sipName_setSignalStrength &sipStrings_QtPositioning[1939]
#define sipNameNr_setUpdateInterval 1957
#define sipName_setUpdateInterval &sipStrings_QtPositioning[1957]
#define sipNameNr_CoordinateFormat 466
#define sipName_CoordinateFormat &sipStrings_QtPositioning[466]
#define sipNameNr_QGeoPositionInfo 1975
#define sipName_QGeoPositionInfo &sipStrings_QtPositioning[1975]
#define sipNameNr_VerticalAccuracy 1992
#define sipName_VerticalAccuracy &sipStrings_QtPositioning[1992]
#define sipNameNr_availableSources 2009
#define sipName_availableSources &sipStrings_QtPositioning[2009]
#define sipNameNr_disconnectNotify 2026
#define sipName_disconnectNotify &sipStrings_QtPositioning[2026]
#define sipNameNr_insertCoordinate 2043
#define sipName_insertCoordinate &sipStrings_QtPositioning[2043]
#define sipNameNr_removeCoordinate 2060
#define sipName_removeCoordinate &sipStrings_QtPositioning[2060]
#define sipNameNr_setBoundingShape 2077
#define sipName_setBoundingShape &sipStrings_QtPositioning[2077]
#define sipNameNr_PartiallyParsed 2094
#define sipName_PartiallyParsed &sipStrings_QtPositioning[2094]
#define sipNameNr_SatelliteSystem 399
#define sipName_SatelliteSystem &sipStrings_QtPositioning[399]
#define sipNameNr_backendProperty 2110
#define sipName_backendProperty &sipStrings_QtPositioning[2110]
#define sipNameNr_extendRectangle 2126
#define sipName_extendRectangle &sipStrings_QtPositioning[2126]
#define sipNameNr_isTextGenerated 2142
#define sipName_isTextGenerated &sipStrings_QtPositioning[2142]
#define sipNameNr_positionUpdated 2158
#define sipName_positionUpdated &sipStrings_QtPositioning[2158]
#define sipNameNr_removeAttribute 2174
#define sipName_removeAttribute &sipStrings_QtPositioning[2174]
#define sipNameNr_satelliteSystem 2190
#define sipName_satelliteSystem &sipStrings_QtPositioning[2190]
#define sipNameNr_setStreetNumber 2206
#define sipName_setStreetNumber &sipStrings_QtPositioning[2206]
#define sipNameNr_startMonitoring 2222
#define sipName_startMonitoring &sipStrings_QtPositioning[2222]
#define sipNameNr_CoordinateType 530
#define sipName_CoordinateType &sipStrings_QtPositioning[530]
#define sipNameNr_DegreesMinutes 2238
#define sipName_DegreesMinutes &sipStrings_QtPositioning[2238]
#define sipNameNr_QGeoCoordinate 2253
#define sipName_QGeoCoordinate &sipStrings_QtPositioning[2253]
#define sipNameNr_SimulationMode 2268
#define sipName_SimulationMode &sipStrings_QtPositioning[2268]
#define sipNameNr_activeMonitors 2283
#define sipName_activeMonitors &sipStrings_QtPositioning[2283]
#define sipNameNr_monitorExpired 2298
#define sipName_monitorExpired &sipStrings_QtPositioning[2298]
#define sipNameNr_setBottomRight 2313
#define sipName_setBottomRight &sipStrings_QtPositioning[2313]
#define sipNameNr_setCountryCode 2328
#define sipName_setCountryCode &sipStrings_QtPositioning[2328]
#define sipNameNr_signalStrength 2343
#define sipName_signalStrength &sipStrings_QtPositioning[2343]
#define sipNameNr_stopMonitoring 2358
#define sipName_stopMonitoring &sipStrings_QtPositioning[2358]
#define sipNameNr_updateInterval 2373
#define sipName_updateInterval &sipStrings_QtPositioning[2373]
#define sipNameNr_QGeoRectangle 2388
#define sipName_QGeoRectangle &sipStrings_QtPositioning[2388]
#define sipNameNr_RectangleType 2402
#define sipName_RectangleType &sipStrings_QtPositioning[2402]
#define sipNameNr_VerticalSpeed 2416
#define sipName_VerticalSpeed &sipStrings_QtPositioning[2416]
#define sipNameNr_addCoordinate 2430
#define sipName_addCoordinate &sipStrings_QtPositioning[2430]
#define sipNameNr_boundingShape 2444
#define sipName_boundingShape &sipStrings_QtPositioning[2444]
#define sipNameNr_connectNotify 2029
#define sipName_connectNotify &sipStrings_QtPositioning[2029]
#define sipNameNr_errorOccurred 2458
#define sipName_errorOccurred &sipStrings_QtPositioning[2458]
#define sipNameNr_requestUpdate 2472
#define sipName_requestUpdate &sipStrings_QtPositioning[2472]
#define sipNameNr_setBottomLeft 2486
#define sipName_setBottomLeft &sipStrings_QtPositioning[2486]
#define sipNameNr_setCoordinate 2500
#define sipName_setCoordinate &sipStrings_QtPositioning[2500]
#define sipNameNr_setExpiration 2514
#define sipName_setExpiration &sipStrings_QtPositioning[2514]
#define sipNameNr_setPersistent 2528
#define sipName_setPersistent &sipStrings_QtPositioning[2528]
#define sipNameNr_setPostalCode 2542
#define sipName_setPostalCode &sipStrings_QtPositioning[2542]
#define sipNameNr_Coordinate2D 2556
#define sipName_Coordinate2D &sipStrings_QtPositioning[2556]
#define sipNameNr_Coordinate3D 2569
#define sipName_Coordinate3D &sipStrings_QtPositioning[2569]
#define sipNameNr_QGeoLocation 2582
#define sipName_QGeoLocation &sipStrings_QtPositioning[2582]
#define sipNameNr_RealTimeMode 2595
#define sipName_RealTimeMode &sipStrings_QtPositioning[2595]
#define sipNameNr_coordinateAt 2608
#define sipName_coordinateAt &sipStrings_QtPositioning[2608]
#define sipNameNr_createSource 2621
#define sipName_createSource &sipStrings_QtPositioning[2621]
#define sipNameNr_extendCircle 2634
#define sipName_extendCircle &sipStrings_QtPositioning[2634]
#define sipNameNr_hasAttribute 2647
#define sipName_hasAttribute &sipStrings_QtPositioning[2647]
#define sipNameNr_isPersistent 2660
#define sipName_isPersistent &sipStrings_QtPositioning[2660]
#define sipNameNr_setAttribute 2673
#define sipName_setAttribute &sipStrings_QtPositioning[2673]
#define sipNameNr_setLongitude 2686
#define sipName_setLongitude &sipStrings_QtPositioning[2686]
#define sipNameNr_setPerimeter 2699
#define sipName_setPerimeter &sipStrings_QtPositioning[2699]
#define sipNameNr_setTimestamp 2712
#define sipName_setTimestamp &sipStrings_QtPositioning[2712]
#define sipNameNr_startUpdates 2725
#define sipName_startUpdates &sipStrings_QtPositioning[2725]
#define sipNameNr_streetNumber 2738
#define sipName_streetNumber &sipStrings_QtPositioning[2738]
#define sipNameNr_AccessError 2751
#define sipName_AccessError &sipStrings_QtPositioning[2751]
#define sipNameNr_ClosedError 2763
#define sipName_ClosedError &sipStrings_QtPositioning[2763]
#define sipNameNr_FullyParsed 2775
#define sipName_FullyParsed &sipStrings_QtPositioning[2775]
#define sipNameNr_GroundSpeed 2787
#define sipName_GroundSpeed &sipStrings_QtPositioning[2787]
#define sipNameNr_PolygonType 2799
#define sipName_PolygonType &sipStrings_QtPositioning[2799]
#define sipNameNr_QGeoAddress 2811
#define sipName_QGeoAddress &sipStrings_QtPositioning[2811]
#define sipNameNr_QGeoPolygon 2823
#define sipName_QGeoPolygon &sipStrings_QtPositioning[2823]
#define sipNameNr_UnknownType 2835
#define sipName_UnknownType &sipStrings_QtPositioning[2835]
#define sipNameNr_areaEntered 2847
#define sipName_areaEntered &sipStrings_QtPositioning[2847]
#define sipNameNr_bottomRight 2859
#define sipName_bottomRight &sipStrings_QtPositioning[2859]
#define sipNameNr_countryCode 2871
#define sipName_countryCode &sipStrings_QtPositioning[2871]
#define sipNameNr_customEvent 2883
#define sipName_customEvent &sipStrings_QtPositioning[2883]
#define sipNameNr_eventFilter 2895
#define sipName_eventFilter &sipStrings_QtPositioning[2895]
#define sipNameNr_setAltitude 2907
#define sipName_setAltitude &sipStrings_QtPositioning[2907]
#define sipNameNr_setDistrict 2919
#define sipName_setDistrict &sipStrings_QtPositioning[2919]
#define sipNameNr_setLatitude 2931
#define sipName_setLatitude &sipStrings_QtPositioning[2931]
#define sipNameNr_setTopRight 2943
#define sipName_setTopRight &sipStrings_QtPositioning[2943]
#define sipNameNr_stopUpdates 2955
#define sipName_stopUpdates &sipStrings_QtPositioning[2955]
#define sipNameNr_CircleType 2967
#define sipName_CircleType &sipStrings_QtPositioning[2967]
#define sipNameNr_CustomType 2978
#define sipName_CustomType &sipStrings_QtPositioning[2978]
#define sipNameNr_QGeoCircle 2989
#define sipName_QGeoCircle &sipStrings_QtPositioning[2989]
#define sipNameNr_UpdateMode 261
#define sipName_UpdateMode &sipStrings_QtPositioning[261]
#define sipNameNr___lshift__ 3000
#define sipName___lshift__ &sipStrings_QtPositioning[3000]
#define sipNameNr___rshift__ 3011
#define sipName___rshift__ &sipStrings_QtPositioning[3011]
#define sipNameNr_areaExited 3022
#define sipName_areaExited &sipStrings_QtPositioning[3022]
#define sipNameNr_bottomLeft 3033
#define sipName_bottomLeft &sipStrings_QtPositioning[3033]
#define sipNameNr_childEvent 3044
#define sipName_childEvent &sipStrings_QtPositioning[3044]
#define sipNameNr_coordinate 3055
#define sipName_coordinate &sipStrings_QtPositioning[3055]
#define sipNameNr_distanceTo 3066
#define sipName_distanceTo &sipStrings_QtPositioning[3066]
#define sipNameNr_distanceUp 3077
#define sipName_distanceUp &sipStrings_QtPositioning[3077]
#define sipNameNr_expiration 3088
#define sipName_expiration &sipStrings_QtPositioning[3088]
#define sipNameNr_holesCount 3099
#define sipName_holesCount &sipStrings_QtPositioning[3099]
#define sipNameNr_identifier 3110
#define sipName_identifier &sipStrings_QtPositioning[3110]
#define sipNameNr_intersects 3121
#define sipName_intersects &sipStrings_QtPositioning[3121]
#define sipNameNr_postalCode 3132
#define sipName_postalCode &sipStrings_QtPositioning[3132]
#define sipNameNr_removeHole 3143
#define sipName_removeHole &sipStrings_QtPositioning[3143]
#define sipNameNr_setAddress 3154
#define sipName_setAddress &sipStrings_QtPositioning[3154]
#define sipNameNr_setCountry 3165
#define sipName_setCountry &sipStrings_QtPositioning[3165]
#define sipNameNr_setTopLeft 3176
#define sipName_setTopLeft &sipStrings_QtPositioning[3176]
#define sipNameNr_sourceName 3187
#define sipName_sourceName &sipStrings_QtPositioning[3187]
#define sipNameNr_timerEvent 3198
#define sipName_timerEvent &sipStrings_QtPositioning[3198]
#define sipNameNr_translated 3209
#define sipName_translated &sipStrings_QtPositioning[3209]
#define sipNameNr_updateMode 3220
#define sipName_updateMode &sipStrings_QtPositioning[3220]
#define sipNameNr_Attribute 743
#define sipName_Attribute &sipStrings_QtPositioning[743]
#define sipNameNr_Direction 3231
#define sipName_Direction &sipStrings_QtPositioning[3231]
#define sipNameNr_Elevation 3241
#define sipName_Elevation &sipStrings_QtPositioning[3241]
#define sipNameNr_NotParsed 3251
#define sipName_NotParsed &sipStrings_QtPositioning[3251]
#define sipNameNr_QGeoShape 3261
#define sipName_QGeoShape &sipStrings_QtPositioning[3261]
#define sipNameNr_ShapeType 1547
#define sipName_ShapeType &sipStrings_QtPositioning[1547]
#define sipNameNr_Undefined 3271
#define sipName_Undefined &sipStrings_QtPositioning[3271]
#define sipNameNr_attribute 3281
#define sipName_attribute &sipStrings_QtPositioning[3281]
#define sipNameNr_azimuthTo 3291
#define sipName_azimuthTo &sipStrings_QtPositioning[3291]
#define sipNameNr_clearPath 3301
#define sipName_clearPath &sipStrings_QtPositioning[3301]
#define sipNameNr_indexFrom 3311
#define sipName_indexFrom &sipStrings_QtPositioning[3311]
#define sipNameNr_longitude 3321
#define sipName_longitude &sipStrings_QtPositioning[3321]
#define sipNameNr_perimeter 3331
#define sipName_perimeter &sipStrings_QtPositioning[3331]
#define sipNameNr_setCenter 3341
#define sipName_setCenter &sipStrings_QtPositioning[3341]
#define sipNameNr_setCounty 3351
#define sipName_setCounty &sipStrings_QtPositioning[3351]
#define sipNameNr_setDevice 3361
#define sipName_setDevice &sipStrings_QtPositioning[3361]
#define sipNameNr_setHeight 3371
#define sipName_setHeight &sipStrings_QtPositioning[3371]
#define sipNameNr_setRadius 3381
#define sipName_setRadius &sipStrings_QtPositioning[3381]
#define sipNameNr_setStreet 3391
#define sipName_setStreet &sipStrings_QtPositioning[3391]
#define sipNameNr_timestamp 3401
#define sipName_timestamp &sipStrings_QtPositioning[3401]
#define sipNameNr_translate 3411
#define sipName_translate &sipStrings_QtPositioning[3411]
#define sipNameNr_Multiple 3421
#define sipName_Multiple &sipStrings_QtPositioning[3421]
#define sipNameNr_PathType 3430
#define sipName_PathType &sipStrings_QtPositioning[3430]
#define sipNameNr_QGeoPath 3439
#define sipName_QGeoPath &sipStrings_QtPositioning[3439]
#define sipNameNr___hash__ 3448
#define sipName___hash__ &sipStrings_QtPositioning[3448]
#define sipNameNr_altitude 3457
#define sipName_altitude &sipStrings_QtPositioning[3457]
#define sipNameNr_contains 3466
#define sipName_contains &sipStrings_QtPositioning[3466]
#define sipNameNr_district 3475
#define sipName_district &sipStrings_QtPositioning[3475]
#define sipNameNr_holePath 3484
#define sipName_holePath &sipStrings_QtPositioning[3484]
#define sipNameNr_latitude 3493
#define sipName_latitude &sipStrings_QtPositioning[3493]
#define sipNameNr_setState 3502
#define sipName_setState &sipStrings_QtPositioning[3502]
#define sipNameNr_setWidth 3511
#define sipName_setWidth &sipStrings_QtPositioning[3511]
#define sipNameNr_toString 3520
#define sipName_toString &sipStrings_QtPositioning[3520]
#define sipNameNr_topRight 3529
#define sipName_topRight &sipStrings_QtPositioning[3529]
#define sipNameNr_Azimuth 1570
#define sipName_Azimuth &sipStrings_QtPositioning[1570]
#define sipNameNr_Degrees 3538
#define sipName_Degrees &sipStrings_QtPositioning[3538]
#define sipNameNr_GALILEO 3546
#define sipName_GALILEO &sipStrings_QtPositioning[3546]
#define sipNameNr_GLONASS 3554
#define sipName_GLONASS &sipStrings_QtPositioning[3554]
#define sipNameNr_NoError 3562
#define sipName_NoError &sipStrings_QtPositioning[3562]
#define sipNameNr___ior__ 3570
#define sipName___ior__ &sipStrings_QtPositioning[3570]
#define sipNameNr_addHole 3578
#define sipName_addHole &sipStrings_QtPositioning[3578]
#define sipNameNr_address 3586
#define sipName_address &sipStrings_QtPositioning[3586]
#define sipNameNr_country 3594
#define sipName_country &sipStrings_QtPositioning[3594]
#define sipNameNr_indexTo 3602
#define sipName_indexTo &sipStrings_QtPositioning[3602]
#define sipNameNr_isEmpty 3610
#define sipName_isEmpty &sipStrings_QtPositioning[3610]
#define sipNameNr_isValid 3618
#define sipName_isValid &sipStrings_QtPositioning[3618]
#define sipNameNr_setArea 3626
#define sipName_setArea &sipStrings_QtPositioning[3626]
#define sipNameNr_setCity 3634
#define sipName_setCity &sipStrings_QtPositioning[3634]
#define sipNameNr_setName 3642
#define sipName_setName &sipStrings_QtPositioning[3642]
#define sipNameNr_setPath 3650
#define sipName_setPath &sipStrings_QtPositioning[3650]
#define sipNameNr_setText 3658
#define sipName_setText &sipStrings_QtPositioning[3658]
#define sipNameNr_timeout 3666
#define sipName_timeout &sipStrings_QtPositioning[3666]
#define sipNameNr_topLeft 3674
#define sipName_topLeft &sipStrings_QtPositioning[3674]
#define sipNameNr_BEIDOU 3682
#define sipName_BEIDOU &sipStrings_QtPositioning[3682]
#define sipNameNr___eq__ 3689
#define sipName___eq__ &sipStrings_QtPositioning[3689]
#define sipNameNr___ne__ 3696
#define sipName___ne__ &sipStrings_QtPositioning[3696]
#define sipNameNr___or__ 3703
#define sipName___or__ &sipStrings_QtPositioning[3703]
#define sipNameNr_center 3710
#define sipName_center &sipStrings_QtPositioning[3710]
#define sipNameNr_county 3717
#define sipName_county &sipStrings_QtPositioning[3717]
#define sipNameNr_device 3724
#define sipName_device &sipStrings_QtPositioning[3724]
#define sipNameNr_format 3731
#define sipName_format &sipStrings_QtPositioning[3731]
#define sipNameNr_height 3738
#define sipName_height &sipStrings_QtPositioning[3738]
#define sipNameNr_length 3745
#define sipName_length &sipStrings_QtPositioning[3745]
#define sipNameNr_parent 3752
#define sipName_parent &sipStrings_QtPositioning[3752]
#define sipNameNr_radius 3759
#define sipName_radius &sipStrings_QtPositioning[3759]
#define sipNameNr_street 3766
#define sipName_street &sipStrings_QtPositioning[3766]
#define sipNameNr_united 3773
#define sipName_united &sipStrings_QtPositioning[3773]
#define sipNameNr_Error 570
#define sipName_Error &sipStrings_QtPositioning[570]
#define sipNameNr_clear 3780
#define sipName_clear &sipStrings_QtPositioning[3780]
#define sipNameNr_error 3786
#define sipName_error &sipStrings_QtPositioning[3786]
#define sipNameNr_event 3792
#define sipName_event &sipStrings_QtPositioning[3792]
#define sipNameNr_state 3798
#define sipName_state &sipStrings_QtPositioning[3798]
#define sipNameNr_width 3804
#define sipName_width &sipStrings_QtPositioning[3804]
#define sipNameNr_QZSS 3810
#define sipName_QZSS &sipStrings_QtPositioning[3810]
#define sipNameNr_area 3815
#define sipName_area &sipStrings_QtPositioning[3815]
#define sipNameNr_city 3820
#define sipName_city &sipStrings_QtPositioning[3820]
#define sipNameNr_hole 3825
#define sipName_hole &sipStrings_QtPositioning[3825]
#define sipNameNr_name 3830
#define sipName_name &sipStrings_QtPositioning[3830]
#define sipNameNr_path 3835
#define sipName_path &sipStrings_QtPositioning[3835]
#define sipNameNr_size 3840
#define sipName_size &sipStrings_QtPositioning[3840]
#define sipNameNr_swap 3845
#define sipName_swap &sipStrings_QtPositioning[3845]
#define sipNameNr_text 3850
#define sipName_text &sipStrings_QtPositioning[3850]
#define sipNameNr_type 3855
#define sipName_type &sipStrings_QtPositioning[3855]
#define sipNameNr_GPS 3860
#define sipName_GPS &sipStrings_QtPositioning[3860]

#define sipMalloc                   sipAPI_QtPositioning->api_malloc
#define sipFree                     sipAPI_QtPositioning->api_free
#define sipBuildResult              sipAPI_QtPositioning->api_build_result
#define sipCallMethod               sipAPI_QtPositioning->api_call_method
#define sipCallProcedureMethod      sipAPI_QtPositioning->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtPositioning->api_call_error_handler
#define sipParseResultEx            sipAPI_QtPositioning->api_parse_result_ex
#define sipParseResult              sipAPI_QtPositioning->api_parse_result
#define sipParseArgs                sipAPI_QtPositioning->api_parse_args
#define sipParseKwdArgs             sipAPI_QtPositioning->api_parse_kwd_args
#define sipParsePair                sipAPI_QtPositioning->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtPositioning->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtPositioning->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtPositioning->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtPositioning->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtPositioning->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtPositioning->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtPositioning->api_add_exception
#define sipNoFunction               sipAPI_QtPositioning->api_no_function
#define sipNoMethod                 sipAPI_QtPositioning->api_no_method
#define sipAbstractMethod           sipAPI_QtPositioning->api_abstract_method
#define sipBadClass                 sipAPI_QtPositioning->api_bad_class
#define sipBadCatcherResult         sipAPI_QtPositioning->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtPositioning->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtPositioning->api_bad_operator_arg
#define sipTrace                    sipAPI_QtPositioning->api_trace
#define sipTransferBack             sipAPI_QtPositioning->api_transfer_back
#define sipTransferTo               sipAPI_QtPositioning->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtPositioning->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtPositioning->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtPositioning->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtPositioning->api_voidptr_type
#define sipGetPyObject              sipAPI_QtPositioning->api_get_pyobject
#define sipGetAddress               sipAPI_QtPositioning->api_get_address
#define sipGetMixinAddress          sipAPI_QtPositioning->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtPositioning->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtPositioning->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtPositioning->api_call_hook
#define sipEndThread                sipAPI_QtPositioning->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtPositioning->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtPositioning->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtPositioning->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtPositioning->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtPositioning->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtPositioning->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtPositioning->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtPositioning->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtPositioning->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtPositioning->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtPositioning->api_convert_to_bool
#define sipReleaseType              sipAPI_QtPositioning->api_release_type
#define sipConvertFromType          sipAPI_QtPositioning->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtPositioning->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtPositioning->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtPositioning->api_convert_from_enum
#define sipGetState                 sipAPI_QtPositioning->api_get_state
#define sipExportSymbol             sipAPI_QtPositioning->api_export_symbol
#define sipImportSymbol             sipAPI_QtPositioning->api_import_symbol
#define sipFindType                 sipAPI_QtPositioning->api_find_type
#define sipBytes_AsChar             sipAPI_QtPositioning->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtPositioning->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtPositioning->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtPositioning->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtPositioning->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtPositioning->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtPositioning->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtPositioning->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtPositioning->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtPositioning->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtPositioning->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtPositioning->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtPositioning->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtPositioning->api_get_reference
#define sipKeepReference            sipAPI_QtPositioning->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtPositioning->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtPositioning->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtPositioning->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtPositioning->api_type_scope
#define sipResolveTypedef           sipAPI_QtPositioning->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtPositioning->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtPositioning->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtPositioning->api_init_mixin
#define sipExportModule             sipAPI_QtPositioning->api_export_module
#define sipInitModule               sipAPI_QtPositioning->api_init_module
#define sipGetInterpreter           sipAPI_QtPositioning->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtPositioning->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtPositioning->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtPositioning->api_py_type_dict
#define sipPyTypeName               sipAPI_QtPositioning->api_py_type_name
#define sipGetCFunction             sipAPI_QtPositioning->api_get_c_function
#define sipGetMethod                sipAPI_QtPositioning->api_get_method
#define sipFromMethod               sipAPI_QtPositioning->api_from_method
#define sipGetDate                  sipAPI_QtPositioning->api_get_date
#define sipFromDate                 sipAPI_QtPositioning->api_from_date
#define sipGetDateTime              sipAPI_QtPositioning->api_get_datetime
#define sipFromDateTime             sipAPI_QtPositioning->api_from_datetime
#define sipGetTime                  sipAPI_QtPositioning->api_get_time
#define sipFromTime                 sipAPI_QtPositioning->api_from_time
#define sipIsUserType               sipAPI_QtPositioning->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtPositioning->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtPositioning->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtPositioning->api_unicode_write
#define sipUnicodeData              sipAPI_QtPositioning->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtPositioning->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtPositioning->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtPositioning->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtPositioning->api_is_derived_class
#define sipGetUserObject            sipAPI_QtPositioning->api_get_user_object
#define sipSetUserObject            sipAPI_QtPositioning->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtPositioning->api_register_event_handler
#define sipConvertToArray           sipAPI_QtPositioning->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtPositioning->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtPositioning->api_enable_gc
#define sipPrintObject              sipAPI_QtPositioning->api_print_object
#define sipLong_AsChar              sipAPI_QtPositioning->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtPositioning->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtPositioning->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtPositioning->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtPositioning->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtPositioning->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtPositioning->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtPositioning->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtPositioning->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtPositioning->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtPositioning->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtPositioning->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtPositioning->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtPositioning->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtPositioning->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtPositioning->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtPositioning->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtPositioning->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtPositioning->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtPositioning->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtPositioning->api_release_type_us
#define sipIsPyMethod               sipAPI_QtPositioning->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtPositioning[];

#define sipType_QGeoAddress sipExportedTypes_QtPositioning[2]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoAddress;

#define sipType_QGeoAreaMonitorInfo sipExportedTypes_QtPositioning[3]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoAreaMonitorInfo;

#define sipType_QGeoAreaMonitorSource sipExportedTypes_QtPositioning[4]

#define sipType_QGeoAreaMonitorSource_AreaMonitorFeature sipExportedTypes_QtPositioning[5]

#define sipType_QGeoAreaMonitorSource_Error sipExportedTypes_QtPositioning[6]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoAreaMonitorSource;

#define sipType_QGeoShape sipExportedTypes_QtPositioning[25]

#define sipType_QGeoShape_ShapeType sipExportedTypes_QtPositioning[26]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoShape;

#define sipType_QGeoCircle sipExportedTypes_QtPositioning[7]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoCircle;

#define sipType_QGeoCoordinate sipExportedTypes_QtPositioning[8]

#define sipType_QGeoCoordinate_CoordinateFormat sipExportedTypes_QtPositioning[9]

#define sipType_QGeoCoordinate_CoordinateType sipExportedTypes_QtPositioning[10]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoCoordinate;

#define sipType_QGeoLocation sipExportedTypes_QtPositioning[11]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoLocation;

#define sipType_QGeoPath sipExportedTypes_QtPositioning[12]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoPath;

#define sipType_QGeoPolygon sipExportedTypes_QtPositioning[13]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoPolygon;

#define sipType_QGeoPositionInfo sipExportedTypes_QtPositioning[14]

#define sipType_QGeoPositionInfo_Attribute sipExportedTypes_QtPositioning[15]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoPositionInfo;

#define sipType_QGeoPositionInfoSource sipExportedTypes_QtPositioning[16]

#define sipType_QGeoPositionInfoSource_PositioningMethod sipExportedTypes_QtPositioning[18]

#define sipType_QGeoPositionInfoSource_Error sipExportedTypes_QtPositioning[17]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoPositionInfoSource;

#define sipType_QGeoRectangle sipExportedTypes_QtPositioning[19]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoRectangle;

#define sipType_QGeoSatelliteInfo sipExportedTypes_QtPositioning[20]

#define sipType_QGeoSatelliteInfo_SatelliteSystem sipExportedTypes_QtPositioning[22]

#define sipType_QGeoSatelliteInfo_Attribute sipExportedTypes_QtPositioning[21]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoSatelliteInfo;

#define sipType_QGeoSatelliteInfoSource sipExportedTypes_QtPositioning[23]

#define sipType_QGeoSatelliteInfoSource_Error sipExportedTypes_QtPositioning[24]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoSatelliteInfoSource;

#define sipType_QNmeaPositionInfoSource sipExportedTypes_QtPositioning[30]

#define sipType_QNmeaPositionInfoSource_UpdateMode sipExportedTypes_QtPositioning[31]

extern sipClassTypeDef sipTypeDef_QtPositioning_QNmeaPositionInfoSource;

#define sipType_QNmeaSatelliteInfoSource sipExportedTypes_QtPositioning[32]

#define sipType_QNmeaSatelliteInfoSource_SatelliteInfoParseStatus sipExportedTypes_QtPositioning[33]

#define sipType_QNmeaSatelliteInfoSource_UpdateMode sipExportedTypes_QtPositioning[34]

extern sipClassTypeDef sipTypeDef_QtPositioning_QNmeaSatelliteInfoSource;

#define sipType_QList_0100QGeoSatelliteInfo sipExportedTypes_QtPositioning[29]

extern sipMappedTypeDef sipTypeDef_QtPositioning_QList_0100QGeoSatelliteInfo;

#define sipType_QList_0100QGeoCoordinate sipExportedTypes_QtPositioning[28]

extern sipMappedTypeDef sipTypeDef_QtPositioning_QList_0100QGeoCoordinate;

#define sipType_QList_0100QGeoAreaMonitorInfo sipExportedTypes_QtPositioning[27]

extern sipMappedTypeDef sipTypeDef_QtPositioning_QList_0100QGeoAreaMonitorInfo;

#define sipType_QFlags_0100QGeoPositionInfoSource_PositioningMethod sipExportedTypes_QtPositioning[1]

extern sipMappedTypeDef sipTypeDef_QtPositioning_QFlags_0100QGeoPositionInfoSource_PositioningMethod;

#define sipType_QFlags_0100QGeoAreaMonitorSource_AreaMonitorFeature sipExportedTypes_QtPositioning[0]

extern sipMappedTypeDef sipTypeDef_QtPositioning_QFlags_0100QGeoAreaMonitorSource_AreaMonitorFeature;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtPositioning;
extern sipExportedModuleDef sipModuleAPI_QtPositioning;
extern sipTypeDef *sipExportedTypes_QtPositioning[];

#define sipType_QObject sipImportedTypes_QtPositioning_QtCore[9].it_td

#define sipType_QIODevice sipImportedTypes_QtPositioning_QtCore[4].it_td

#define sipType_QEvent sipImportedTypes_QtPositioning_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtPositioning_QtCore[12].it_td

#define sipType_QChildEvent sipImportedTypes_QtPositioning_QtCore[0].it_td

#define sipType_QDataStream sipImportedTypes_QtPositioning_QtCore[1].it_td

#define sipType_QDateTime sipImportedTypes_QtPositioning_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtPositioning_QtCore[8].it_td

#define sipType_QVariant sipImportedTypes_QtPositioning_QtCore[13].it_td

#define sipType_QMap_0100QString_0100QVariant sipImportedTypes_QtPositioning_QtCore[7].it_td

#define sipType_QList_0100QVariant sipImportedTypes_QtPositioning_QtCore[5].it_td

#define sipType_QStringList sipImportedTypes_QtPositioning_QtCore[11].it_td

#define sipType_QList_1800 sipImportedTypes_QtPositioning_QtCore[6].it_td

#define sipType_QString sipImportedTypes_QtPositioning_QtCore[10].it_td
extern sipImportedTypeDef sipImportedTypes_QtPositioning_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtPositioning_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtPositioning_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtPositioning_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtPositioning_qt_metacast;

#endif
