/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick3D.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3dtexturedata.sip"
#include <qquick3dtexturedata.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick3D/qquick3dobject.sip"
#include <qquick3dobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick3D/sipQtQuick3DQQuick3DTextureData.cpp"


class sipQQuick3DTextureData : public ::QQuick3DTextureData
{
public:
    sipQQuick3DTextureData(::QQuick3DObject*);
    virtual ~sipQQuick3DTextureData();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void componentComplete() SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuick3DTextureData(const sipQQuick3DTextureData &);
    sipQQuick3DTextureData &operator = (const sipQQuick3DTextureData &);

    char sipPyMethods[9];
};

sipQQuick3DTextureData::sipQQuick3DTextureData(::QQuick3DObject*a0): ::QQuick3DTextureData(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQuick3DTextureData::~sipQQuick3DTextureData()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQQuick3DTextureData::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtQuick3D_qt_metaobject(sipPySelf, sipType_QQuick3DTextureData);

    return ::QQuick3DTextureData::metaObject();
}

int sipQQuick3DTextureData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QQuick3DTextureData::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtQuick3D_qt_metacall(sipPySelf, sipType_QQuick3DTextureData, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQQuick3DTextureData::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtQuick3D_qt_metacast(sipPySelf, sipType_QQuick3DTextureData, _clname, &sipCpp) ? sipCpp : ::QQuick3DTextureData::qt_metacast(_clname));
}

void sipQQuick3DTextureData::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QQuick3DTextureData::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick3D_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQuick3D_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuick3DTextureData::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QQuick3DTextureData::connectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick3D_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQuick3D_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuick3DTextureData::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QQuick3DTextureData::customEvent(a0);
        return;
    }

    extern void sipVH_QtQuick3D_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtQuick3D_1(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuick3DTextureData::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QQuick3DTextureData::childEvent(a0);
        return;
    }

    extern void sipVH_QtQuick3D_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtQuick3D_2(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuick3DTextureData::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QQuick3DTextureData::timerEvent(a0);
        return;
    }

    extern void sipVH_QtQuick3D_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtQuick3D_3(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQuick3DTextureData::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QQuick3DTextureData::eventFilter(a0, a1);

    extern bool sipVH_QtQuick3D_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtQuick3D_4(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQQuick3DTextureData::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QQuick3DTextureData::event(a0);

    extern bool sipVH_QtQuick3D_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtQuick3D_5(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuick3DTextureData::componentComplete()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_componentComplete);

    if (!sipMeth)
    {
        ::QQuick3DTextureData::componentComplete();
        return;
    }

    extern void sipVH_QtQuick3D_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick3D_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQQuick3DTextureData::classBegin()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_classBegin);

    if (!sipMeth)
    {
        ::QQuick3DTextureData::classBegin();
        return;
    }

    extern void sipVH_QtQuick3D_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick3D_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick3D_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QQuick3DTextureData_textureData, "textureData(self) -> QByteArray");

extern "C" {static PyObject *meth_QQuick3DTextureData_textureData(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DTextureData_textureData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DTextureData, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->textureData());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DTextureData, sipName_textureData, doc_QQuick3DTextureData_textureData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DTextureData_setTextureData, "setTextureData(self, data: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QQuick3DTextureData_setTextureData(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DTextureData_setTextureData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QQuick3DTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQuick3DTextureData, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setTextureData(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DTextureData, sipName_setTextureData, doc_QQuick3DTextureData_setTextureData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DTextureData_size, "size(self) -> QSize");

extern "C" {static PyObject *meth_QQuick3DTextureData_size(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DTextureData_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DTextureData, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->size());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DTextureData, sipName_size, doc_QQuick3DTextureData_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DTextureData_setSize, "setSize(self, size: QSize)");

extern "C" {static PyObject *meth_QQuick3DTextureData_setSize(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DTextureData_setSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QQuick3DTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QQuick3DTextureData, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DTextureData, sipName_setSize, doc_QQuick3DTextureData_setSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DTextureData_format, "format(self) -> QQuick3DTextureData.Format");

extern "C" {static PyObject *meth_QQuick3DTextureData_format(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DTextureData_format(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DTextureData, &sipCpp))
        {
            ::QQuick3DTextureData::Format sipRes;

            sipRes = sipCpp->format();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QQuick3DTextureData_Format);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DTextureData, sipName_format, doc_QQuick3DTextureData_format);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DTextureData_setFormat, "setFormat(self, format: QQuick3DTextureData.Format)");

extern "C" {static PyObject *meth_QQuick3DTextureData_setFormat(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DTextureData_setFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QQuick3DTextureData::Format a0;
        ::QQuick3DTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QQuick3DTextureData, &sipCpp, sipType_QQuick3DTextureData_Format, &a0))
        {
            sipCpp->setFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DTextureData, sipName_setFormat, doc_QQuick3DTextureData_setFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DTextureData_hasTransparency, "hasTransparency(self) -> bool");

extern "C" {static PyObject *meth_QQuick3DTextureData_hasTransparency(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DTextureData_hasTransparency(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DTextureData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasTransparency();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DTextureData, sipName_hasTransparency, doc_QQuick3DTextureData_hasTransparency);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DTextureData_setHasTransparency, "setHasTransparency(self, hasTransparency: bool)");

extern "C" {static PyObject *meth_QQuick3DTextureData_setHasTransparency(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DTextureData_setHasTransparency(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QQuick3DTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQuick3DTextureData, &sipCpp, &a0))
        {
            sipCpp->setHasTransparency(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DTextureData, sipName_setHasTransparency, doc_QQuick3DTextureData_setHasTransparency);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DTextureData_depth, "depth(self) -> int");

extern "C" {static PyObject *meth_QQuick3DTextureData_depth(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DTextureData_depth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuick3DTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuick3DTextureData, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->depth();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DTextureData, sipName_depth, doc_QQuick3DTextureData_depth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuick3DTextureData_setDepth, "setDepth(self, depth: int)");

extern "C" {static PyObject *meth_QQuick3DTextureData_setDepth(PyObject *, PyObject *);}
static PyObject *meth_QQuick3DTextureData_setDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QQuick3DTextureData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQuick3DTextureData, &sipCpp, &a0))
        {
            sipCpp->setDepth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuick3DTextureData, sipName_setDepth, doc_QQuick3DTextureData_setDepth);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQuick3DTextureData(void *, const sipTypeDef *);}
static void *cast_QQuick3DTextureData(void *sipCppV, const sipTypeDef *targetType)
{
    ::QQuick3DTextureData *sipCpp = reinterpret_cast< ::QQuick3DTextureData *>(sipCppV);

    if (targetType == sipType_QQuick3DTextureData)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QQuick3DObject)->ctd_cast(static_cast< ::QQuick3DObject *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQuick3DTextureData(void *, int);}
static void release_QQuick3DTextureData(void *sipCppV, int)
{
    ::QQuick3DTextureData *sipCpp = reinterpret_cast< ::QQuick3DTextureData *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QQuick3DTextureData(Py_ssize_t);}
static void *array_QQuick3DTextureData(Py_ssize_t sipNrElem)
{
    return new ::QQuick3DTextureData[sipNrElem];
}


extern "C" {static void array_delete_QQuick3DTextureData(void *);}
static void array_delete_QQuick3DTextureData(void *sipCpp)
{
    delete[] reinterpret_cast< ::QQuick3DTextureData *>(sipCpp);
}


extern "C" {static void dealloc_QQuick3DTextureData(sipSimpleWrapper *);}
static void dealloc_QQuick3DTextureData(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQuick3DTextureData *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuick3DTextureData(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQuick3DTextureData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuick3DTextureData(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQQuick3DTextureData *sipCpp = SIP_NULLPTR;

    {
        ::QQuick3DObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QQuick3DObject, &a0, sipOwner))
        {
            sipCpp = new sipQQuick3DTextureData(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQuick3DTextureData[] = {{7, 255, 1}};


static PyMethodDef methods_QQuick3DTextureData[] = {
    {sipName_depth, meth_QQuick3DTextureData_depth, METH_VARARGS, doc_QQuick3DTextureData_depth},
    {sipName_format, meth_QQuick3DTextureData_format, METH_VARARGS, doc_QQuick3DTextureData_format},
    {sipName_hasTransparency, meth_QQuick3DTextureData_hasTransparency, METH_VARARGS, doc_QQuick3DTextureData_hasTransparency},
    {sipName_setDepth, meth_QQuick3DTextureData_setDepth, METH_VARARGS, doc_QQuick3DTextureData_setDepth},
    {sipName_setFormat, meth_QQuick3DTextureData_setFormat, METH_VARARGS, doc_QQuick3DTextureData_setFormat},
    {sipName_setHasTransparency, meth_QQuick3DTextureData_setHasTransparency, METH_VARARGS, doc_QQuick3DTextureData_setHasTransparency},
    {sipName_setSize, meth_QQuick3DTextureData_setSize, METH_VARARGS, doc_QQuick3DTextureData_setSize},
    {sipName_setTextureData, meth_QQuick3DTextureData_setTextureData, METH_VARARGS, doc_QQuick3DTextureData_setTextureData},
    {sipName_size, meth_QQuick3DTextureData_size, METH_VARARGS, doc_QQuick3DTextureData_size},
    {sipName_textureData, meth_QQuick3DTextureData_textureData, METH_VARARGS, doc_QQuick3DTextureData_textureData}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QQuick3DTextureData[] = {
    {sipName_None_, static_cast<int>(::QQuick3DTextureData::None)},
    {sipName_RGBA8, static_cast<int>(::QQuick3DTextureData::RGBA8)},
    {sipName_RGBA16F, static_cast<int>(::QQuick3DTextureData::RGBA16F)},
    {sipName_RGBA32F, static_cast<int>(::QQuick3DTextureData::RGBA32F)},
    {sipName_RGBE8, static_cast<int>(::QQuick3DTextureData::RGBE8)},
    {sipName_R8, static_cast<int>(::QQuick3DTextureData::R8)},
    {sipName_R16, static_cast<int>(::QQuick3DTextureData::R16)},
    {sipName_R16F, static_cast<int>(::QQuick3DTextureData::R16F)},
    {sipName_R32F, static_cast<int>(::QQuick3DTextureData::R32F)},
    {sipName_BC1, static_cast<int>(::QQuick3DTextureData::BC1)},
    {sipName_BC2, static_cast<int>(::QQuick3DTextureData::BC2)},
    {sipName_BC3, static_cast<int>(::QQuick3DTextureData::BC3)},
    {sipName_BC4, static_cast<int>(::QQuick3DTextureData::BC4)},
    {sipName_BC5, static_cast<int>(::QQuick3DTextureData::BC5)},
    {sipName_BC6H, static_cast<int>(::QQuick3DTextureData::BC6H)},
    {sipName_BC7, static_cast<int>(::QQuick3DTextureData::BC7)},
    {sipName_DXT1_RGBA, static_cast<int>(::QQuick3DTextureData::DXT1_RGBA)},
    {sipName_DXT1_RGB, static_cast<int>(::QQuick3DTextureData::DXT1_RGB)},
    {sipName_DXT3_RGBA, static_cast<int>(::QQuick3DTextureData::DXT3_RGBA)},
    {sipName_DXT5_RGBA, static_cast<int>(::QQuick3DTextureData::DXT5_RGBA)},
    {sipName_ETC2_RGB8, static_cast<int>(::QQuick3DTextureData::ETC2_RGB8)},
    {sipName_ETC2_RGB8A1, static_cast<int>(::QQuick3DTextureData::ETC2_RGB8A1)},
    {sipName_ETC2_RGBA8, static_cast<int>(::QQuick3DTextureData::ETC2_RGBA8)},
    {sipName_ASTC_4x4, static_cast<int>(::QQuick3DTextureData::ASTC_4x4)},
    {sipName_ASTC_5x4, static_cast<int>(::QQuick3DTextureData::ASTC_5x4)},
    {sipName_ASTC_5x5, static_cast<int>(::QQuick3DTextureData::ASTC_5x5)},
    {sipName_ASTC_6x5, static_cast<int>(::QQuick3DTextureData::ASTC_6x5)},
    {sipName_ASTC_6x6, static_cast<int>(::QQuick3DTextureData::ASTC_6x6)},
    {sipName_ASTC_8x5, static_cast<int>(::QQuick3DTextureData::ASTC_8x5)},
    {sipName_ASTC_8x6, static_cast<int>(::QQuick3DTextureData::ASTC_8x6)},
    {sipName_ASTC_8x8, static_cast<int>(::QQuick3DTextureData::ASTC_8x8)},
    {sipName_ASTC_10x5, static_cast<int>(::QQuick3DTextureData::ASTC_10x5)},
    {sipName_ASTC_10x6, static_cast<int>(::QQuick3DTextureData::ASTC_10x6)},
    {sipName_ASTC_10x8, static_cast<int>(::QQuick3DTextureData::ASTC_10x8)},
    {sipName_ASTC_10x10, static_cast<int>(::QQuick3DTextureData::ASTC_10x10)},
    {sipName_ASTC_12x10, static_cast<int>(::QQuick3DTextureData::ASTC_12x10)},
    {sipName_ASTC_12x12, static_cast<int>(::QQuick3DTextureData::ASTC_12x12)},
    {0, 0}
};

PyDoc_STRVAR(doc_QQuick3DTextureData, "\1QQuick3DTextureData(parent: QQuick3DObject|None = None)");


static pyqt6ClassPluginDef plugin_QQuick3DTextureData = {
    &::QQuick3DTextureData::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick3D_QQuick3DTextureData = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuick3DTextureData,
        SIP_NULLPTR,
        &plugin_QQuick3DTextureData,
    },
    {
        sipNameNr_QQuick3DTextureData,
        {0, 0, 1},
        10, methods_QQuick3DTextureData,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QQuick3DTextureData, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuick3DTextureData,
    -1,
    -1,
    supers_QQuick3DTextureData,
    SIP_NULLPTR,
    init_type_QQuick3DTextureData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuick3DTextureData,
    SIP_NULLPTR,
    array_QQuick3DTextureData,
    SIP_NULLPTR,
    release_QQuick3DTextureData,
    cast_QQuick3DTextureData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QQuick3DTextureData,
    sizeof (::QQuick3DTextureData),
};
