/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtRemoteObjects.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectregistry.sip"
#include <qremoteobjectregistry.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_std_pair.sip"
#include <utility>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qtremoteobjectglobal.sip"
#include <qtremoteobjectglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 27 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectreplica.sip"
#include <qremoteobjectreplica.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectnode.sip"
#include <qremoteobjectnode.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectRegistry.cpp"


PyDoc_STRVAR(doc_QRemoteObjectRegistry_sourceLocations, "sourceLocations(self) -> dict[str, QRemoteObjectSourceLocationInfo]");

extern "C" {static PyObject *meth_QRemoteObjectRegistry_sourceLocations(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectRegistry_sourceLocations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectRegistry *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRemoteObjectRegistry, &sipCpp))
        {
            ::QRemoteObjectSourceLocations*sipRes;

            sipRes = new ::QRemoteObjectSourceLocations(sipCpp->sourceLocations());

            return sipConvertFromNewType(sipRes, sipType_QHash_0100QString_0100QRemoteObjectSourceLocationInfo, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectRegistry, sipName_sourceLocations, doc_QRemoteObjectRegistry_sourceLocations);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRemoteObjectRegistry(void *, const sipTypeDef *);}
static void *cast_QRemoteObjectRegistry(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRemoteObjectRegistry *sipCpp = reinterpret_cast< ::QRemoteObjectRegistry *>(sipCppV);

    if (targetType == sipType_QRemoteObjectRegistry)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QRemoteObjectReplica)->ctd_cast(static_cast< ::QRemoteObjectReplica *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRemoteObjectRegistry(void *, int);}
static void release_QRemoteObjectRegistry(void *sipCppV, int)
{
    ::QRemoteObjectRegistry *sipCpp = reinterpret_cast< ::QRemoteObjectRegistry *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QRemoteObjectRegistry(sipSimpleWrapper *);}
static void dealloc_QRemoteObjectRegistry(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRemoteObjectRegistry(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRemoteObjectRegistry[] = {{11, 255, 1}};


static PyMethodDef methods_QRemoteObjectRegistry[] = {
    {sipName_sourceLocations, meth_QRemoteObjectRegistry_sourceLocations, METH_VARARGS, doc_QRemoteObjectRegistry_sourceLocations}
};


/* Define this type's signals. */
static const pyqt6QtSignal signals_QRemoteObjectRegistry[] = {
    {"remoteObjectRemoved(QRemoteObjectSourceLocation)", "\1remoteObjectRemoved(self, entry: tuple[str|None, QRemoteObjectSourceLocationInfo])", SIP_NULLPTR, SIP_NULLPTR},
    {"remoteObjectAdded(QRemoteObjectSourceLocation)", "\1remoteObjectAdded(self, entry: tuple[str|None, QRemoteObjectSourceLocationInfo])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QRemoteObjectRegistry = {
    &::QRemoteObjectRegistry::staticMetaObject,
    signals_QRemoteObjectRegistry,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectRegistry = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRemoteObjectRegistry,
        SIP_NULLPTR,
        &plugin_QRemoteObjectRegistry,
    },
    {
        sipNameNr_QRemoteObjectRegistry,
        {0, 0, 1},
        1, methods_QRemoteObjectRegistry,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QRemoteObjectRegistry,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRemoteObjectRegistry,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QRemoteObjectRegistry,
    cast_QRemoteObjectRegistry,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
