/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtQuickWidgetsAPI_H
#define _QtQuickWidgetsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QQuickWidget__ResizeMode 0
#define sipName_QQuickWidget__ResizeMode &sipStrings_QtQuickWidgets[0]
#define sipNameNr_mouseDoubleClickEvent 25
#define sipName_mouseDoubleClickEvent &sipStrings_QtQuickWidgets[25]
#define sipNameNr_PyQt6_QtQuickWidgets 47
#define sipName_PyQt6_QtQuickWidgets &sipStrings_QtQuickWidgets[47]
#define sipNameNr_QQuickWidget__Status 68
#define sipName_QQuickWidget__Status &sipStrings_QtQuickWidgets[68]
#define sipNameNr_SizeRootObjectToView 89
#define sipName_SizeRootObjectToView &sipStrings_QtQuickWidgets[89]
#define sipNameNr_SizeViewToRootObject 110
#define sipName_SizeViewToRootObject &sipStrings_QtQuickWidgets[110]
#define sipNameNr_setInitialProperties 131
#define sipName_setInitialProperties &sipStrings_QtQuickWidgets[131]
#define sipNameNr_focusNextPrevChild 152
#define sipName_focusNextPrevChild &sipStrings_QtQuickWidgets[152]
#define sipNameNr_hasHeightForWidth 171
#define sipName_hasHeightForWidth &sipStrings_QtQuickWidgets[171]
#define sipNameNr_mouseReleaseEvent 189
#define sipName_mouseReleaseEvent &sipStrings_QtQuickWidgets[189]
#define sipNameNr_contextMenuEvent 207
#define sipName_contextMenuEvent &sipStrings_QtQuickWidgets[207]
#define sipNameNr_disconnectNotify 224
#define sipName_disconnectNotify &sipStrings_QtQuickWidgets[224]
#define sipNameNr_inputMethodEvent 241
#define sipName_inputMethodEvent &sipStrings_QtQuickWidgets[241]
#define sipNameNr_inputMethodQuery 258
#define sipName_inputMethodQuery &sipStrings_QtQuickWidgets[258]
#define sipNameNr_grabFramebuffer 275
#define sipName_grabFramebuffer &sipStrings_QtQuickWidgets[275]
#define sipNameNr_keyReleaseEvent 291
#define sipName_keyReleaseEvent &sipStrings_QtQuickWidgets[291]
#define sipNameNr_minimumSizeHint 307
#define sipName_minimumSizeHint &sipStrings_QtQuickWidgets[307]
#define sipNameNr_mousePressEvent 323
#define sipName_mousePressEvent &sipStrings_QtQuickWidgets[323]
#define sipNameNr_sceneGraphError 339
#define sipName_sceneGraphError &sipStrings_QtQuickWidgets[339]
#define sipNameNr_dragEnterEvent 355
#define sipName_dragEnterEvent &sipStrings_QtQuickWidgets[355]
#define sipNameNr_dragLeaveEvent 370
#define sipName_dragLeaveEvent &sipStrings_QtQuickWidgets[370]
#define sipNameNr_heightForWidth 385
#define sipName_heightForWidth &sipStrings_QtQuickWidgets[385]
#define sipNameNr_loadFromModule 400
#define sipName_loadFromModule &sipStrings_QtQuickWidgets[400]
#define sipNameNr_mouseMoveEvent 415
#define sipName_mouseMoveEvent &sipStrings_QtQuickWidgets[415]
#define sipNameNr_connectNotify 227
#define sipName_connectNotify &sipStrings_QtQuickWidgets[227]
#define sipNameNr_dragMoveEvent 430
#define sipName_dragMoveEvent &sipStrings_QtQuickWidgets[430]
#define sipNameNr_focusOutEvent 444
#define sipName_focusOutEvent &sipStrings_QtQuickWidgets[444]
#define sipNameNr_keyPressEvent 458
#define sipName_keyPressEvent &sipStrings_QtQuickWidgets[458]
#define sipNameNr_setClearColor 472
#define sipName_setClearColor &sipStrings_QtQuickWidgets[472]
#define sipNameNr_setResizeMode 486
#define sipName_setResizeMode &sipStrings_QtQuickWidgets[486]
#define sipNameNr_sharedPainter 500
#define sipName_sharedPainter &sipStrings_QtQuickWidgets[500]
#define sipNameNr_statusChanged 514
#define sipName_statusChanged &sipStrings_QtQuickWidgets[514]
#define sipNameNr_QQuickWidget 528
#define sipName_QQuickWidget &sipStrings_QtQuickWidgets[528]
#define sipNameNr_focusInEvent 541
#define sipName_focusInEvent &sipStrings_QtQuickWidgets[541]
#define sipNameNr_actionEvent 554
#define sipName_actionEvent &sipStrings_QtQuickWidgets[554]
#define sipNameNr_changeEvent 566
#define sipName_changeEvent &sipStrings_QtQuickWidgets[566]
#define sipNameNr_customEvent 578
#define sipName_customEvent &sipStrings_QtQuickWidgets[578]
#define sipNameNr_eventFilter 590
#define sipName_eventFilter &sipStrings_QtQuickWidgets[590]
#define sipNameNr_initPainter 602
#define sipName_initPainter &sipStrings_QtQuickWidgets[602]
#define sipNameNr_initialSize 614
#define sipName_initialSize &sipStrings_QtQuickWidgets[614]
#define sipNameNr_nativeEvent 626
#define sipName_nativeEvent &sipStrings_QtQuickWidgets[626]
#define sipNameNr_paintEngine 638
#define sipName_paintEngine &sipStrings_QtQuickWidgets[638]
#define sipNameNr_quickWindow 650
#define sipName_quickWindow &sipStrings_QtQuickWidgets[650]
#define sipNameNr_resizeEvent 662
#define sipName_resizeEvent &sipStrings_QtQuickWidgets[662]
#define sipNameNr_rootContext 674
#define sipName_rootContext &sipStrings_QtQuickWidgets[674]
#define sipNameNr_tabletEvent 686
#define sipName_tabletEvent &sipStrings_QtQuickWidgets[686]
#define sipNameNr_ResizeMode 14
#define sipName_ResizeMode &sipStrings_QtQuickWidgets[14]
#define sipNameNr_childEvent 698
#define sipName_childEvent &sipStrings_QtQuickWidgets[698]
#define sipNameNr_closeEvent 709
#define sipName_closeEvent &sipStrings_QtQuickWidgets[709]
#define sipNameNr_enterEvent 720
#define sipName_enterEvent &sipStrings_QtQuickWidgets[720]
#define sipNameNr_leaveEvent 731
#define sipName_leaveEvent &sipStrings_QtQuickWidgets[731]
#define sipNameNr_paintEvent 742
#define sipName_paintEvent &sipStrings_QtQuickWidgets[742]
#define sipNameNr_resizeMode 753
#define sipName_resizeMode &sipStrings_QtQuickWidgets[753]
#define sipNameNr_rootObject 764
#define sipName_rootObject &sipStrings_QtQuickWidgets[764]
#define sipNameNr_setVisible 775
#define sipName_setVisible &sipStrings_QtQuickWidgets[775]
#define sipNameNr_timerEvent 786
#define sipName_timerEvent &sipStrings_QtQuickWidgets[786]
#define sipNameNr_wheelEvent 797
#define sipName_wheelEvent &sipStrings_QtQuickWidgets[797]
#define sipNameNr_dropEvent 808
#define sipName_dropEvent &sipStrings_QtQuickWidgets[808]
#define sipNameNr_hideEvent 818
#define sipName_hideEvent &sipStrings_QtQuickWidgets[818]
#define sipNameNr_moveEvent 828
#define sipName_moveEvent &sipStrings_QtQuickWidgets[828]
#define sipNameNr_setFormat 838
#define sipName_setFormat &sipStrings_QtQuickWidgets[838]
#define sipNameNr_setSource 848
#define sipName_setSource &sipStrings_QtQuickWidgets[848]
#define sipNameNr_showEvent 858
#define sipName_showEvent &sipStrings_QtQuickWidgets[858]
#define sipNameNr_sizeHint 868
#define sipName_sizeHint &sipStrings_QtQuickWidgets[868]
#define sipNameNr_Loading 877
#define sipName_Loading &sipStrings_QtQuickWidgets[877]
#define sipNameNr_devType 885
#define sipName_devType &sipStrings_QtQuickWidgets[885]
#define sipNameNr_Status 82
#define sipName_Status &sipStrings_QtQuickWidgets[82]
#define sipNameNr_engine 893
#define sipName_engine &sipStrings_QtQuickWidgets[893]
#define sipNameNr_errors 900
#define sipName_errors &sipStrings_QtQuickWidgets[900]
#define sipNameNr_format 907
#define sipName_format &sipStrings_QtQuickWidgets[907]
#define sipNameNr_metric 914
#define sipName_metric &sipStrings_QtQuickWidgets[914]
#define sipNameNr_parent 921
#define sipName_parent &sipStrings_QtQuickWidgets[921]
#define sipNameNr_source 928
#define sipName_source &sipStrings_QtQuickWidgets[928]
#define sipNameNr_status 935
#define sipName_status &sipStrings_QtQuickWidgets[935]
#define sipNameNr_Error 349
#define sipName_Error &sipStrings_QtQuickWidgets[349]
#define sipNameNr_Ready 942
#define sipName_Ready &sipStrings_QtQuickWidgets[942]
#define sipNameNr_event 948
#define sipName_event &sipStrings_QtQuickWidgets[948]
#define sipNameNr_Null 954
#define sipName_Null &sipStrings_QtQuickWidgets[954]

#define sipMalloc                   sipAPI_QtQuickWidgets->api_malloc
#define sipFree                     sipAPI_QtQuickWidgets->api_free
#define sipBuildResult              sipAPI_QtQuickWidgets->api_build_result
#define sipCallMethod               sipAPI_QtQuickWidgets->api_call_method
#define sipCallProcedureMethod      sipAPI_QtQuickWidgets->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtQuickWidgets->api_call_error_handler
#define sipParseResultEx            sipAPI_QtQuickWidgets->api_parse_result_ex
#define sipParseResult              sipAPI_QtQuickWidgets->api_parse_result
#define sipParseArgs                sipAPI_QtQuickWidgets->api_parse_args
#define sipParseKwdArgs             sipAPI_QtQuickWidgets->api_parse_kwd_args
#define sipParsePair                sipAPI_QtQuickWidgets->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtQuickWidgets->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtQuickWidgets->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtQuickWidgets->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtQuickWidgets->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtQuickWidgets->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtQuickWidgets->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtQuickWidgets->api_add_exception
#define sipNoFunction               sipAPI_QtQuickWidgets->api_no_function
#define sipNoMethod                 sipAPI_QtQuickWidgets->api_no_method
#define sipAbstractMethod           sipAPI_QtQuickWidgets->api_abstract_method
#define sipBadClass                 sipAPI_QtQuickWidgets->api_bad_class
#define sipBadCatcherResult         sipAPI_QtQuickWidgets->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtQuickWidgets->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtQuickWidgets->api_bad_operator_arg
#define sipTrace                    sipAPI_QtQuickWidgets->api_trace
#define sipTransferBack             sipAPI_QtQuickWidgets->api_transfer_back
#define sipTransferTo               sipAPI_QtQuickWidgets->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtQuickWidgets->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtQuickWidgets->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtQuickWidgets->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtQuickWidgets->api_voidptr_type
#define sipGetPyObject              sipAPI_QtQuickWidgets->api_get_pyobject
#define sipGetAddress               sipAPI_QtQuickWidgets->api_get_address
#define sipGetMixinAddress          sipAPI_QtQuickWidgets->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtQuickWidgets->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtQuickWidgets->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtQuickWidgets->api_call_hook
#define sipEndThread                sipAPI_QtQuickWidgets->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtQuickWidgets->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtQuickWidgets->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtQuickWidgets->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtQuickWidgets->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtQuickWidgets->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtQuickWidgets->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtQuickWidgets->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtQuickWidgets->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtQuickWidgets->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtQuickWidgets->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtQuickWidgets->api_convert_to_bool
#define sipReleaseType              sipAPI_QtQuickWidgets->api_release_type
#define sipConvertFromType          sipAPI_QtQuickWidgets->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtQuickWidgets->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtQuickWidgets->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtQuickWidgets->api_convert_from_enum
#define sipGetState                 sipAPI_QtQuickWidgets->api_get_state
#define sipExportSymbol             sipAPI_QtQuickWidgets->api_export_symbol
#define sipImportSymbol             sipAPI_QtQuickWidgets->api_import_symbol
#define sipFindType                 sipAPI_QtQuickWidgets->api_find_type
#define sipBytes_AsChar             sipAPI_QtQuickWidgets->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtQuickWidgets->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtQuickWidgets->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtQuickWidgets->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtQuickWidgets->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtQuickWidgets->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtQuickWidgets->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtQuickWidgets->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtQuickWidgets->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtQuickWidgets->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtQuickWidgets->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtQuickWidgets->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtQuickWidgets->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtQuickWidgets->api_get_reference
#define sipKeepReference            sipAPI_QtQuickWidgets->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtQuickWidgets->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtQuickWidgets->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtQuickWidgets->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtQuickWidgets->api_type_scope
#define sipResolveTypedef           sipAPI_QtQuickWidgets->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtQuickWidgets->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtQuickWidgets->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtQuickWidgets->api_init_mixin
#define sipExportModule             sipAPI_QtQuickWidgets->api_export_module
#define sipInitModule               sipAPI_QtQuickWidgets->api_init_module
#define sipGetInterpreter           sipAPI_QtQuickWidgets->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtQuickWidgets->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtQuickWidgets->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtQuickWidgets->api_py_type_dict
#define sipPyTypeName               sipAPI_QtQuickWidgets->api_py_type_name
#define sipGetCFunction             sipAPI_QtQuickWidgets->api_get_c_function
#define sipGetMethod                sipAPI_QtQuickWidgets->api_get_method
#define sipFromMethod               sipAPI_QtQuickWidgets->api_from_method
#define sipGetDate                  sipAPI_QtQuickWidgets->api_get_date
#define sipFromDate                 sipAPI_QtQuickWidgets->api_from_date
#define sipGetDateTime              sipAPI_QtQuickWidgets->api_get_datetime
#define sipFromDateTime             sipAPI_QtQuickWidgets->api_from_datetime
#define sipGetTime                  sipAPI_QtQuickWidgets->api_get_time
#define sipFromTime                 sipAPI_QtQuickWidgets->api_from_time
#define sipIsUserType               sipAPI_QtQuickWidgets->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtQuickWidgets->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtQuickWidgets->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtQuickWidgets->api_unicode_write
#define sipUnicodeData              sipAPI_QtQuickWidgets->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtQuickWidgets->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtQuickWidgets->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtQuickWidgets->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtQuickWidgets->api_is_derived_class
#define sipGetUserObject            sipAPI_QtQuickWidgets->api_get_user_object
#define sipSetUserObject            sipAPI_QtQuickWidgets->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtQuickWidgets->api_register_event_handler
#define sipConvertToArray           sipAPI_QtQuickWidgets->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtQuickWidgets->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtQuickWidgets->api_enable_gc
#define sipPrintObject              sipAPI_QtQuickWidgets->api_print_object
#define sipLong_AsChar              sipAPI_QtQuickWidgets->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtQuickWidgets->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtQuickWidgets->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtQuickWidgets->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtQuickWidgets->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtQuickWidgets->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtQuickWidgets->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtQuickWidgets->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtQuickWidgets->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtQuickWidgets->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtQuickWidgets->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtQuickWidgets->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtQuickWidgets->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtQuickWidgets->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtQuickWidgets->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtQuickWidgets->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtQuickWidgets->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtQuickWidgets->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtQuickWidgets->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtQuickWidgets->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtQuickWidgets->api_release_type_us
#define sipIsPyMethod               sipAPI_QtQuickWidgets->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtQuickWidgets[];
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 361 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuickWidgets/sipAPIQtQuickWidgets.h"


class sipQQuickItem : public ::QQuickItem
{
public:
    sipQQuickItem(::QQuickItem*);
    virtual ~sipQQuickItem();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void updatePolish() SIP_OVERRIDE;
    void releaseResources() SIP_OVERRIDE;
    ::QSGNode* updatePaintNode(::QSGNode*, ::QQuickItem::UpdatePaintNodeData*) SIP_OVERRIDE;
    void geometryChange(const ::QRectF&, const ::QRectF&) SIP_OVERRIDE;
    bool childMouseEventFilter(::QQuickItem*, ::QEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverEnterEvent(::QHoverEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void touchUngrabEvent() SIP_OVERRIDE;
    void mouseUngrabEvent() SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void itemChange(::QQuickItem::ItemChange, const ::QQuickItem::ItemChangeData&) SIP_OVERRIDE;
    ::QSGTextureProvider* textureProvider() const SIP_OVERRIDE;
    bool isTextureProvider() const SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool contains(const ::QPointF&) const SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;
    void componentComplete() SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickItem(const sipQQuickItem &);
    sipQQuickItem &operator = (const sipQQuickItem &);

    char sipPyMethods[39];
};
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickframebufferobject.sip"
#include <qquickframebufferobject.h>
#line 430 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuickWidgets/sipAPIQtQuickWidgets.h"


class sipQQuickFramebufferObject : public ::QQuickFramebufferObject
{
public:
    sipQQuickFramebufferObject(::QQuickItem*);
    virtual ~sipQQuickFramebufferObject();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QQuickFramebufferObject::Renderer* createRenderer() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void componentComplete() SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;
    bool contains(const ::QPointF&) const SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool isTextureProvider() const SIP_OVERRIDE;
    ::QSGTextureProvider* textureProvider() const SIP_OVERRIDE;
    void itemChange(::QQuickItem::ItemChange, const ::QQuickItem::ItemChangeData&) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseUngrabEvent() SIP_OVERRIDE;
    void touchUngrabEvent() SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void hoverEnterEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    bool childMouseEventFilter(::QQuickItem*, ::QEvent*) SIP_OVERRIDE;
    void geometryChange(const ::QRectF&, const ::QRectF&) SIP_OVERRIDE;
    ::QSGNode* updatePaintNode(::QSGNode*, ::QQuickItem::UpdatePaintNodeData*) SIP_OVERRIDE;
    void releaseResources() SIP_OVERRIDE;
    void updatePolish() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickFramebufferObject(const sipQQuickFramebufferObject &);
    sipQQuickFramebufferObject &operator = (const sipQQuickFramebufferObject &);

    char sipPyMethods[40];
};
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickpainteditem.sip"
#include <qquickpainteditem.h>
#line 500 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuickWidgets/sipAPIQtQuickWidgets.h"


class sipQQuickPaintedItem : public ::QQuickPaintedItem
{
public:
    sipQQuickPaintedItem(::QQuickItem*);
    virtual ~sipQQuickPaintedItem();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void paint(::QPainter*) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void componentComplete() SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;
    bool contains(const ::QPointF&) const SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool isTextureProvider() const SIP_OVERRIDE;
    ::QSGTextureProvider* textureProvider() const SIP_OVERRIDE;
    void itemChange(::QQuickItem::ItemChange, const ::QQuickItem::ItemChangeData&) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseUngrabEvent() SIP_OVERRIDE;
    void touchUngrabEvent() SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void hoverEnterEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent(::QHoverEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    bool childMouseEventFilter(::QQuickItem*, ::QEvent*) SIP_OVERRIDE;
    void geometryChange(const ::QRectF&, const ::QRectF&) SIP_OVERRIDE;
    ::QSGNode* updatePaintNode(::QSGNode*, ::QQuickItem::UpdatePaintNodeData*) SIP_OVERRIDE;
    void releaseResources() SIP_OVERRIDE;
    void updatePolish() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickPaintedItem(const sipQQuickPaintedItem &);
    sipQQuickPaintedItem &operator = (const sipQQuickPaintedItem &);

    char sipPyMethods[40];
};
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickwindow.sip"
#include <qquickwindow.h>
#line 570 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuickWidgets/sipAPIQtQuickWidgets.h"


class sipQQuickWindow : public ::QQuickWindow
{
public:
    sipQQuickWindow(::QWindow*);
    virtual ~sipQQuickWindow();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QSize size() const SIP_OVERRIDE;
    ::QSurface::SurfaceType surfaceType() const SIP_OVERRIDE;
    ::QSurfaceFormat format() const SIP_OVERRIDE;
    ::QObject* focusObject() const SIP_OVERRIDE;
    void exposeEvent(::QExposeEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickWindow(const sipQQuickWindow &);
    sipQQuickWindow &operator = (const sipQQuickWindow &);

    char sipPyMethods[30];
};
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qquickview.sip"
#include <qquickview.h>
#line 630 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuickWidgets/sipAPIQtQuickWidgets.h"


class sipQQuickView : public ::QQuickView
{
public:
    sipQQuickView(::QWindow*);
    sipQQuickView(::QQmlEngine*, ::QWindow*);
    sipQQuickView(const ::QUrl&, ::QWindow*);
    sipQQuickView(::QAnyStringView, ::QAnyStringView, ::QWindow*);
    virtual ~sipQQuickView();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void exposeEvent(::QExposeEvent*) SIP_OVERRIDE;
    ::QObject* focusObject() const SIP_OVERRIDE;
    ::QSurfaceFormat format() const SIP_OVERRIDE;
    ::QSurface::SurfaceType surfaceType() const SIP_OVERRIDE;
    ::QSize size() const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickView(const sipQQuickView &);
    sipQQuickView &operator = (const sipQQuickView &);

    char sipPyMethods[30];
};

#define sipType_QQuickWidget sipExportedTypes_QtQuickWidgets[0]

#define sipType_QQuickWidget_Status sipExportedTypes_QtQuickWidgets[2]

#define sipType_QQuickWidget_ResizeMode sipExportedTypes_QtQuickWidgets[1]

extern sipClassTypeDef sipTypeDef_QtQuickWidgets_QQuickWidget;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtQuickWidgets;
extern sipExportedModuleDef sipModuleAPI_QtQuickWidgets;
extern sipTypeDef *sipExportedTypes_QtQuickWidgets[];

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtQuickWidgets_QtCore[12].it_td

#define sipType_QObject sipImportedTypes_QtQuickWidgets_QtCore[6].it_td

#define sipType_QByteArray sipImportedTypes_QtQuickWidgets_QtCore[1].it_td

#define sipType_QEvent sipImportedTypes_QtQuickWidgets_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtQuickWidgets_QtCore[9].it_td

#define sipType_QChildEvent sipImportedTypes_QtQuickWidgets_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtQuickWidgets_QtCore[5].it_td

#define sipType_QSize sipImportedTypes_QtQuickWidgets_QtCore[7].it_td

#define sipType_QUrl sipImportedTypes_QtQuickWidgets_QtCore[10].it_td

#define sipType_QVariant sipImportedTypes_QtQuickWidgets_QtCore[11].it_td

#define sipType_QMap_0100QString_0100QVariant sipImportedTypes_QtQuickWidgets_QtCore[4].it_td

#define sipType_QString sipImportedTypes_QtQuickWidgets_QtCore[8].it_td

#define sipType_QAnyStringView sipImportedTypes_QtQuickWidgets_QtCore[0].it_td

#define sipType_qintptr sipImportedTypes_QtQuickWidgets_QtCore[13].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuickWidgets_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtQuickWidgets_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtQuickWidgets_QtGui[16].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtQuickWidgets_QtGui[17].it_td

#define sipType_QColor sipImportedTypes_QtQuickWidgets_QtGui[2].it_td

#define sipType_QKeyEvent sipImportedTypes_QtQuickWidgets_QtGui[13].it_td

#define sipType_QFocusEvent sipImportedTypes_QtQuickWidgets_QtGui[9].it_td

#define sipType_QPaintEvent sipImportedTypes_QtQuickWidgets_QtGui[19].it_td

#define sipType_QMoveEvent sipImportedTypes_QtQuickWidgets_QtGui[15].it_td

#define sipType_QResizeEvent sipImportedTypes_QtQuickWidgets_QtGui[21].it_td

#define sipType_QCloseEvent sipImportedTypes_QtQuickWidgets_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtQuickWidgets_QtGui[22].it_td

#define sipType_QHideEvent sipImportedTypes_QtQuickWidgets_QtGui[10].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtQuickWidgets_QtGui[3].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtQuickWidgets_QtGui[12].it_td

#define sipType_QDropEvent sipImportedTypes_QtQuickWidgets_QtGui[7].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtQuickWidgets_QtGui[6].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtQuickWidgets_QtGui[4].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtQuickWidgets_QtGui[5].it_td

#define sipType_QActionEvent sipImportedTypes_QtQuickWidgets_QtGui[0].it_td

#define sipType_QEnterEvent sipImportedTypes_QtQuickWidgets_QtGui[8].it_td

#define sipType_QMouseEvent sipImportedTypes_QtQuickWidgets_QtGui[14].it_td

#define sipType_QWheelEvent sipImportedTypes_QtQuickWidgets_QtGui[25].it_td

#define sipType_QTabletEvent sipImportedTypes_QtQuickWidgets_QtGui[24].it_td

#define sipType_QImage sipImportedTypes_QtQuickWidgets_QtGui[11].it_td

#define sipType_QPaintEngine sipImportedTypes_QtQuickWidgets_QtGui[18].it_td

#define sipType_QPainter sipImportedTypes_QtQuickWidgets_QtGui[20].it_td

#define sipType_QSurfaceFormat sipImportedTypes_QtQuickWidgets_QtGui[23].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuickWidgets_QtGui[];

#define sipType_QQmlEngine sipImportedTypes_QtQuickWidgets_QtQml[2].it_td

#define sipType_QQmlContext sipImportedTypes_QtQuickWidgets_QtQml[1].it_td

#define sipType_QList_0100QQmlError sipImportedTypes_QtQuickWidgets_QtQml[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuickWidgets_QtQml[];

#define sipType_QQuickItem sipImportedTypes_QtQuickWidgets_QtQuick[0].it_td

#define sipType_QQuickWindow sipImportedTypes_QtQuickWidgets_QtQuick[1].it_td

#define sipType_QQuickWindow_SceneGraphError sipImportedTypes_QtQuickWidgets_QtQuick[2].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuickWidgets_QtQuick[];

#define sipType_QWidget sipImportedTypes_QtQuickWidgets_QtWidgets[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuickWidgets_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtQuickWidgets_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtQuickWidgets_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtQuickWidgets_qt_metacast;

#endif
