/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSpatialAudio.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSpatialAudio/qspatialsound.sip"
#include <qspatialsound.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSpatialAudio/qaudioengine.sip"
#include <qaudioengine.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQSpatialSound.cpp"


class sipQSpatialSound : public ::QSpatialSound
{
public:
    sipQSpatialSound(::QAudioEngine*);
    virtual ~sipQSpatialSound();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSpatialSound(const sipQSpatialSound &);
    sipQSpatialSound &operator = (const sipQSpatialSound &);

    char sipPyMethods[7];
};

sipQSpatialSound::sipQSpatialSound(::QAudioEngine*a0): ::QSpatialSound(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSpatialSound::~sipQSpatialSound()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQSpatialSound::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtSpatialAudio_qt_metaobject(sipPySelf, sipType_QSpatialSound);

    return ::QSpatialSound::metaObject();
}

int sipQSpatialSound::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QSpatialSound::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtSpatialAudio_qt_metacall(sipPySelf, sipType_QSpatialSound, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQSpatialSound::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtSpatialAudio_qt_metacast(sipPySelf, sipType_QSpatialSound, _clname, &sipCpp) ? sipCpp : ::QSpatialSound::qt_metacast(_clname));
}

bool sipQSpatialSound::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QSpatialSound::event(a0);

    extern bool sipVH_QtSpatialAudio_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtSpatialAudio_5(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSpatialSound::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QSpatialSound::eventFilter(a0, a1);

    extern bool sipVH_QtSpatialAudio_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtSpatialAudio_4(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQSpatialSound::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QSpatialSound::timerEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtSpatialAudio_3(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSpatialSound::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QSpatialSound::childEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtSpatialAudio_2(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSpatialSound::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QSpatialSound::customEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSpatialAudio_1(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSpatialSound::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QSpatialSound::connectNotify(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSpatialAudio_0(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSpatialSound::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QSpatialSound::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSpatialAudio_0(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSpatialSound_setSource, "setSource(self, url: QUrl)");

extern "C" {static PyObject *meth_QSpatialSound_setSource(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSpatialSound, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setSource(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setSource, doc_QSpatialSound_setSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_source, "source(self) -> QUrl");

extern "C" {static PyObject *meth_QSpatialSound_source(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_source(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->source());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_source, doc_QSpatialSound_source);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_loops, "loops(self) -> int");

extern "C" {static PyObject *meth_QSpatialSound_loops(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_loops(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->loops();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_loops, doc_QSpatialSound_loops);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setLoops, "setLoops(self, loops: int)");

extern "C" {static PyObject *meth_QSpatialSound_setLoops(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setLoops(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSpatialSound, &sipCpp, &a0))
        {
            sipCpp->setLoops(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setLoops, doc_QSpatialSound_setLoops);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_autoPlay, "autoPlay(self) -> bool");

extern "C" {static PyObject *meth_QSpatialSound_autoPlay(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_autoPlay(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoPlay();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_autoPlay, doc_QSpatialSound_autoPlay);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setAutoPlay, "setAutoPlay(self, autoPlay: bool)");

extern "C" {static PyObject *meth_QSpatialSound_setAutoPlay(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setAutoPlay(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QSpatialSound, &sipCpp, &a0))
        {
            sipCpp->setAutoPlay(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setAutoPlay, doc_QSpatialSound_setAutoPlay);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setPosition, "setPosition(self, pos: QVector3D)");

extern "C" {static PyObject *meth_QSpatialSound_setPosition(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVector3D* a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSpatialSound, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setPosition(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setPosition, doc_QSpatialSound_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_position, "position(self) -> QVector3D");

extern "C" {static PyObject *meth_QSpatialSound_position(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->position());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_position, doc_QSpatialSound_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setRotation, "setRotation(self, q: QQuaternion)");

extern "C" {static PyObject *meth_QSpatialSound_setRotation(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuaternion* a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSpatialSound, &sipCpp, sipType_QQuaternion, &a0))
        {
            sipCpp->setRotation(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setRotation, doc_QSpatialSound_setRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_rotation, "rotation(self) -> QQuaternion");

extern "C" {static PyObject *meth_QSpatialSound_rotation(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            ::QQuaternion*sipRes;

            sipRes = new ::QQuaternion(sipCpp->rotation());

            return sipConvertFromNewType(sipRes, sipType_QQuaternion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_rotation, doc_QSpatialSound_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setVolume, "setVolume(self, volume: float)");

extern "C" {static PyObject *meth_QSpatialSound_setVolume(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QSpatialSound, &sipCpp, &a0))
        {
            sipCpp->setVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setVolume, doc_QSpatialSound_setVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_volume, "volume(self) -> float");

extern "C" {static PyObject *meth_QSpatialSound_volume(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_volume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->volume();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_volume, doc_QSpatialSound_volume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setDistanceModel, "setDistanceModel(self, model: QSpatialSound.DistanceModel)");

extern "C" {static PyObject *meth_QSpatialSound_setDistanceModel(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setDistanceModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSpatialSound::DistanceModel a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSpatialSound, &sipCpp, sipType_QSpatialSound_DistanceModel, &a0))
        {
            sipCpp->setDistanceModel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setDistanceModel, doc_QSpatialSound_setDistanceModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_distanceModel, "distanceModel(self) -> QSpatialSound.DistanceModel");

extern "C" {static PyObject *meth_QSpatialSound_distanceModel(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_distanceModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            ::QSpatialSound::DistanceModel sipRes;

            sipRes = sipCpp->distanceModel();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSpatialSound_DistanceModel);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_distanceModel, doc_QSpatialSound_distanceModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setSize, "setSize(self, size: float)");

extern "C" {static PyObject *meth_QSpatialSound_setSize(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QSpatialSound, &sipCpp, &a0))
        {
            sipCpp->setSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setSize, doc_QSpatialSound_setSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_size, "size(self) -> float");

extern "C" {static PyObject *meth_QSpatialSound_size(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->size();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_size, doc_QSpatialSound_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setDistanceCutoff, "setDistanceCutoff(self, cutoff: float)");

extern "C" {static PyObject *meth_QSpatialSound_setDistanceCutoff(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setDistanceCutoff(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QSpatialSound, &sipCpp, &a0))
        {
            sipCpp->setDistanceCutoff(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setDistanceCutoff, doc_QSpatialSound_setDistanceCutoff);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_distanceCutoff, "distanceCutoff(self) -> float");

extern "C" {static PyObject *meth_QSpatialSound_distanceCutoff(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_distanceCutoff(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->distanceCutoff();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_distanceCutoff, doc_QSpatialSound_distanceCutoff);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setManualAttenuation, "setManualAttenuation(self, attenuation: float)");

extern "C" {static PyObject *meth_QSpatialSound_setManualAttenuation(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setManualAttenuation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QSpatialSound, &sipCpp, &a0))
        {
            sipCpp->setManualAttenuation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setManualAttenuation, doc_QSpatialSound_setManualAttenuation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_manualAttenuation, "manualAttenuation(self) -> float");

extern "C" {static PyObject *meth_QSpatialSound_manualAttenuation(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_manualAttenuation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->manualAttenuation();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_manualAttenuation, doc_QSpatialSound_manualAttenuation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setOcclusionIntensity, "setOcclusionIntensity(self, occlusion: float)");

extern "C" {static PyObject *meth_QSpatialSound_setOcclusionIntensity(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setOcclusionIntensity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QSpatialSound, &sipCpp, &a0))
        {
            sipCpp->setOcclusionIntensity(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setOcclusionIntensity, doc_QSpatialSound_setOcclusionIntensity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_occlusionIntensity, "occlusionIntensity(self) -> float");

extern "C" {static PyObject *meth_QSpatialSound_occlusionIntensity(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_occlusionIntensity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->occlusionIntensity();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_occlusionIntensity, doc_QSpatialSound_occlusionIntensity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setDirectivity, "setDirectivity(self, alpha: float)");

extern "C" {static PyObject *meth_QSpatialSound_setDirectivity(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setDirectivity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QSpatialSound, &sipCpp, &a0))
        {
            sipCpp->setDirectivity(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setDirectivity, doc_QSpatialSound_setDirectivity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_directivity, "directivity(self) -> float");

extern "C" {static PyObject *meth_QSpatialSound_directivity(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_directivity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->directivity();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_directivity, doc_QSpatialSound_directivity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setDirectivityOrder, "setDirectivityOrder(self, alpha: float)");

extern "C" {static PyObject *meth_QSpatialSound_setDirectivityOrder(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setDirectivityOrder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QSpatialSound, &sipCpp, &a0))
        {
            sipCpp->setDirectivityOrder(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setDirectivityOrder, doc_QSpatialSound_setDirectivityOrder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_directivityOrder, "directivityOrder(self) -> float");

extern "C" {static PyObject *meth_QSpatialSound_directivityOrder(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_directivityOrder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->directivityOrder();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_directivityOrder, doc_QSpatialSound_directivityOrder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_setNearFieldGain, "setNearFieldGain(self, gain: float)");

extern "C" {static PyObject *meth_QSpatialSound_setNearFieldGain(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_setNearFieldGain(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QSpatialSound, &sipCpp, &a0))
        {
            sipCpp->setNearFieldGain(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_setNearFieldGain, doc_QSpatialSound_setNearFieldGain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_nearFieldGain, "nearFieldGain(self) -> float");

extern "C" {static PyObject *meth_QSpatialSound_nearFieldGain(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_nearFieldGain(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->nearFieldGain();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_nearFieldGain, doc_QSpatialSound_nearFieldGain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_engine, "engine(self) -> QAudioEngine|None");

extern "C" {static PyObject *meth_QSpatialSound_engine(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_engine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            ::QAudioEngine*sipRes;

            sipRes = sipCpp->engine();

            return sipConvertFromType(sipRes, sipType_QAudioEngine, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_engine, doc_QSpatialSound_engine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_play, "play(self)");

extern "C" {static PyObject *meth_QSpatialSound_play(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_play(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            sipCpp->play();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_play, doc_QSpatialSound_play);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_pause, "pause(self)");

extern "C" {static PyObject *meth_QSpatialSound_pause(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_pause(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            sipCpp->pause();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_pause, doc_QSpatialSound_pause);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSpatialSound_stop, "stop(self)");

extern "C" {static PyObject *meth_QSpatialSound_stop(PyObject *, PyObject *);}
static PyObject *meth_QSpatialSound_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSpatialSound *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSpatialSound, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSpatialSound, sipName_stop, doc_QSpatialSound_stop);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSpatialSound(void *, const sipTypeDef *);}
static void *cast_QSpatialSound(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSpatialSound *sipCpp = reinterpret_cast< ::QSpatialSound *>(sipCppV);

    if (targetType == sipType_QSpatialSound)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSpatialSound(void *, int);}
static void release_QSpatialSound(void *sipCppV, int)
{
    ::QSpatialSound *sipCpp = reinterpret_cast< ::QSpatialSound *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QSpatialSound(sipSimpleWrapper *);}
static void dealloc_QSpatialSound(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSpatialSound *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSpatialSound(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSpatialSound(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSpatialSound(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQSpatialSound *sipCpp = SIP_NULLPTR;

    {
        ::QAudioEngine* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8", sipType_QAudioEngine, &a0))
        {
            sipCpp = new sipQSpatialSound(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSpatialSound[] = {{3, 0, 1}};


static PyMethodDef methods_QSpatialSound[] = {
    {sipName_autoPlay, meth_QSpatialSound_autoPlay, METH_VARARGS, doc_QSpatialSound_autoPlay},
    {sipName_directivity, meth_QSpatialSound_directivity, METH_VARARGS, doc_QSpatialSound_directivity},
    {sipName_directivityOrder, meth_QSpatialSound_directivityOrder, METH_VARARGS, doc_QSpatialSound_directivityOrder},
    {sipName_distanceCutoff, meth_QSpatialSound_distanceCutoff, METH_VARARGS, doc_QSpatialSound_distanceCutoff},
    {sipName_distanceModel, meth_QSpatialSound_distanceModel, METH_VARARGS, doc_QSpatialSound_distanceModel},
    {sipName_engine, meth_QSpatialSound_engine, METH_VARARGS, doc_QSpatialSound_engine},
    {sipName_loops, meth_QSpatialSound_loops, METH_VARARGS, doc_QSpatialSound_loops},
    {sipName_manualAttenuation, meth_QSpatialSound_manualAttenuation, METH_VARARGS, doc_QSpatialSound_manualAttenuation},
    {sipName_nearFieldGain, meth_QSpatialSound_nearFieldGain, METH_VARARGS, doc_QSpatialSound_nearFieldGain},
    {sipName_occlusionIntensity, meth_QSpatialSound_occlusionIntensity, METH_VARARGS, doc_QSpatialSound_occlusionIntensity},
    {sipName_pause, meth_QSpatialSound_pause, METH_VARARGS, doc_QSpatialSound_pause},
    {sipName_play, meth_QSpatialSound_play, METH_VARARGS, doc_QSpatialSound_play},
    {sipName_position, meth_QSpatialSound_position, METH_VARARGS, doc_QSpatialSound_position},
    {sipName_rotation, meth_QSpatialSound_rotation, METH_VARARGS, doc_QSpatialSound_rotation},
    {sipName_setAutoPlay, meth_QSpatialSound_setAutoPlay, METH_VARARGS, doc_QSpatialSound_setAutoPlay},
    {sipName_setDirectivity, meth_QSpatialSound_setDirectivity, METH_VARARGS, doc_QSpatialSound_setDirectivity},
    {sipName_setDirectivityOrder, meth_QSpatialSound_setDirectivityOrder, METH_VARARGS, doc_QSpatialSound_setDirectivityOrder},
    {sipName_setDistanceCutoff, meth_QSpatialSound_setDistanceCutoff, METH_VARARGS, doc_QSpatialSound_setDistanceCutoff},
    {sipName_setDistanceModel, meth_QSpatialSound_setDistanceModel, METH_VARARGS, doc_QSpatialSound_setDistanceModel},
    {sipName_setLoops, meth_QSpatialSound_setLoops, METH_VARARGS, doc_QSpatialSound_setLoops},
    {sipName_setManualAttenuation, meth_QSpatialSound_setManualAttenuation, METH_VARARGS, doc_QSpatialSound_setManualAttenuation},
    {sipName_setNearFieldGain, meth_QSpatialSound_setNearFieldGain, METH_VARARGS, doc_QSpatialSound_setNearFieldGain},
    {sipName_setOcclusionIntensity, meth_QSpatialSound_setOcclusionIntensity, METH_VARARGS, doc_QSpatialSound_setOcclusionIntensity},
    {sipName_setPosition, meth_QSpatialSound_setPosition, METH_VARARGS, doc_QSpatialSound_setPosition},
    {sipName_setRotation, meth_QSpatialSound_setRotation, METH_VARARGS, doc_QSpatialSound_setRotation},
    {sipName_setSize, meth_QSpatialSound_setSize, METH_VARARGS, doc_QSpatialSound_setSize},
    {sipName_setSource, meth_QSpatialSound_setSource, METH_VARARGS, doc_QSpatialSound_setSource},
    {sipName_setVolume, meth_QSpatialSound_setVolume, METH_VARARGS, doc_QSpatialSound_setVolume},
    {sipName_size, meth_QSpatialSound_size, METH_VARARGS, doc_QSpatialSound_size},
    {sipName_source, meth_QSpatialSound_source, METH_VARARGS, doc_QSpatialSound_source},
    {sipName_stop, meth_QSpatialSound_stop, METH_VARARGS, doc_QSpatialSound_stop},
    {sipName_volume, meth_QSpatialSound_volume, METH_VARARGS, doc_QSpatialSound_volume}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QSpatialSound[] = {
    {sipName_Logarithmic, static_cast<int>(::QSpatialSound::DistanceModel::Logarithmic)},
    {sipName_Linear, static_cast<int>(::QSpatialSound::DistanceModel::Linear)},
    {sipName_ManualAttenuation, static_cast<int>(::QSpatialSound::DistanceModel::ManualAttenuation)},
    {sipName_Infinite, static_cast<int>(::QSpatialSound::Infinite)},
    {sipName_Once, static_cast<int>(::QSpatialSound::Once)},
    {0, 0}
};

PyDoc_STRVAR(doc_QSpatialSound, "\1QSpatialSound(engine: QAudioEngine|None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QSpatialSound[] = {
    {"nearFieldGainChanged()", "\1nearFieldGainChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"directivityOrderChanged()", "\1directivityOrderChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"directivityChanged()", "\1directivityChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"occlusionIntensityChanged()", "\1occlusionIntensityChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"manualAttenuationChanged()", "\1manualAttenuationChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"distanceCutoffChanged()", "\1distanceCutoffChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"sizeChanged()", "\1sizeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"distanceModelChanged()", "\1distanceModelChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"volumeChanged()", "\1volumeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"rotationChanged()", "\1rotationChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged()", "\1positionChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"autoPlayChanged()", "\1autoPlayChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"loopsChanged()", "\1loopsChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"sourceChanged()", "\1sourceChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QSpatialSound = {
    &::QSpatialSound::staticMetaObject,
    signals_QSpatialSound,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSpatialAudio_QSpatialSound = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSpatialSound,
        SIP_NULLPTR,
        &plugin_QSpatialSound,
    },
    {
        sipNameNr_QSpatialSound,
        {0, 0, 1},
        32, methods_QSpatialSound,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QSpatialSound, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSpatialSound,
    -1,
    -1,
    supers_QSpatialSound,
    SIP_NULLPTR,
    init_type_QSpatialSound,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSpatialSound,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QSpatialSound,
    cast_QSpatialSound,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QSpatialSound),
};
