/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qhttp1configuration.sip"
#include <qhttp1configuration.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttp1Configuration.cpp"



PyDoc_STRVAR(doc_QHttp1Configuration_setNumberOfConnectionsPerHost, "setNumberOfConnectionsPerHost(self, amount: int)");

extern "C" {static PyObject *meth_QHttp1Configuration_setNumberOfConnectionsPerHost(PyObject *, PyObject *);}
static PyObject *meth_QHttp1Configuration_setNumberOfConnectionsPerHost(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qsizetype a0;
        ::QHttp1Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QHttp1Configuration, &sipCpp, &a0))
        {
            sipCpp->setNumberOfConnectionsPerHost(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp1Configuration, sipName_setNumberOfConnectionsPerHost, doc_QHttp1Configuration_setNumberOfConnectionsPerHost);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp1Configuration_numberOfConnectionsPerHost, "numberOfConnectionsPerHost(self) -> int");

extern "C" {static PyObject *meth_QHttp1Configuration_numberOfConnectionsPerHost(PyObject *, PyObject *);}
static PyObject *meth_QHttp1Configuration_numberOfConnectionsPerHost(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHttp1Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHttp1Configuration, &sipCpp))
        {
            ::qsizetype sipRes;

            sipRes = sipCpp->numberOfConnectionsPerHost();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp1Configuration, sipName_numberOfConnectionsPerHost, doc_QHttp1Configuration_numberOfConnectionsPerHost);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp1Configuration_swap, "swap(self, other: QHttp1Configuration)");

extern "C" {static PyObject *meth_QHttp1Configuration_swap(PyObject *, PyObject *);}
static PyObject *meth_QHttp1Configuration_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHttp1Configuration* a0;
        ::QHttp1Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QHttp1Configuration, &sipCpp, sipType_QHttp1Configuration, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp1Configuration, sipName_swap, doc_QHttp1Configuration_swap);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QHttp1Configuration___eq__(PyObject *, PyObject *);}
static PyObject *slot_QHttp1Configuration___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QHttp1Configuration *sipCpp = reinterpret_cast< ::QHttp1Configuration *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QHttp1Configuration));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHttp1Configuration* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QHttp1Configuration, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtNetwork, eq_slot, sipType_QHttp1Configuration, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QHttp1Configuration___ne__(PyObject *, PyObject *);}
static PyObject *slot_QHttp1Configuration___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QHttp1Configuration *sipCpp = reinterpret_cast< ::QHttp1Configuration *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QHttp1Configuration));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHttp1Configuration* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QHttp1Configuration, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtNetwork, ne_slot, sipType_QHttp1Configuration, sipSelf, sipArg);
}


extern "C" {static Py_hash_t slot_QHttp1Configuration___hash__(PyObject *);}
static Py_hash_t slot_QHttp1Configuration___hash__(PyObject *sipSelf)
{
    ::QHttp1Configuration *sipCpp = reinterpret_cast< ::QHttp1Configuration *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QHttp1Configuration));

    if (!sipCpp)
        return 0;


    {
        {
            Py_hash_t sipRes = 0;

#line 40 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qhttp1configuration.sip"
        sipRes = qHash(*sipCpp);
#line 184 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQHttp1Configuration.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHttp1Configuration(void *, int);}
static void release_QHttp1Configuration(void *sipCppV, int)
{
    delete reinterpret_cast< ::QHttp1Configuration *>(sipCppV);
}


extern "C" {static void *array_QHttp1Configuration(Py_ssize_t);}
static void *array_QHttp1Configuration(Py_ssize_t sipNrElem)
{
    return new ::QHttp1Configuration[sipNrElem];
}


extern "C" {static void array_delete_QHttp1Configuration(void *);}
static void array_delete_QHttp1Configuration(void *sipCpp)
{
    delete[] reinterpret_cast< ::QHttp1Configuration *>(sipCpp);
}


extern "C" {static void assign_QHttp1Configuration(void *, Py_ssize_t, void *);}
static void assign_QHttp1Configuration(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QHttp1Configuration *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QHttp1Configuration *>(sipSrc);
}


extern "C" {static void *copy_QHttp1Configuration(const void *, Py_ssize_t);}
static void *copy_QHttp1Configuration(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QHttp1Configuration(reinterpret_cast<const ::QHttp1Configuration *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QHttp1Configuration(sipSimpleWrapper *);}
static void dealloc_QHttp1Configuration(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHttp1Configuration(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QHttp1Configuration(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QHttp1Configuration(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QHttp1Configuration *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QHttp1Configuration();

            return sipCpp;
        }
    }

    {
        const ::QHttp1Configuration* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QHttp1Configuration, &a0))
        {
            sipCpp = new ::QHttp1Configuration(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QHttp1Configuration[] = {
    {(void *)slot_QHttp1Configuration___eq__, eq_slot},
    {(void *)slot_QHttp1Configuration___ne__, ne_slot},
    {(void *)slot_QHttp1Configuration___hash__, hash_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QHttp1Configuration[] = {
    {sipName_numberOfConnectionsPerHost, meth_QHttp1Configuration_numberOfConnectionsPerHost, METH_VARARGS, doc_QHttp1Configuration_numberOfConnectionsPerHost},
    {sipName_setNumberOfConnectionsPerHost, meth_QHttp1Configuration_setNumberOfConnectionsPerHost, METH_VARARGS, doc_QHttp1Configuration_setNumberOfConnectionsPerHost},
    {sipName_swap, meth_QHttp1Configuration_swap, METH_VARARGS, doc_QHttp1Configuration_swap}
};

PyDoc_STRVAR(doc_QHttp1Configuration, "\1QHttp1Configuration()\n"
"QHttp1Configuration(other: QHttp1Configuration)");


sipClassTypeDef sipTypeDef_QtNetwork_QHttp1Configuration = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHttp1Configuration,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QHttp1Configuration,
        {0, 0, 1},
        3, methods_QHttp1Configuration,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QHttp1Configuration,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QHttp1Configuration,
    init_type_QHttp1Configuration,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHttp1Configuration,
    assign_QHttp1Configuration,
    array_QHttp1Configuration,
    copy_QHttp1Configuration,
    release_QHttp1Configuration,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QHttp1Configuration,
    sizeof (::QHttp1Configuration),
};
