/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSpatialAudio.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSpatialAudio/qaudioengine.sip"
#include <qaudioengine.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiodevice.sip"
#include <qaudiodevice.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSpatialAudio/sipQtSpatialAudioQAudioEngine.cpp"


class sipQAudioEngine : public ::QAudioEngine
{
public:
    sipQAudioEngine();
    sipQAudioEngine(::QObject*);
    sipQAudioEngine(int, ::QObject*);
    virtual ~sipQAudioEngine();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAudioEngine(const sipQAudioEngine &);
    sipQAudioEngine &operator = (const sipQAudioEngine &);

    char sipPyMethods[7];
};

sipQAudioEngine::sipQAudioEngine(): ::QAudioEngine(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioEngine::sipQAudioEngine(::QObject*a0): ::QAudioEngine(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioEngine::sipQAudioEngine(int a0, ::QObject*a1): ::QAudioEngine(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioEngine::~sipQAudioEngine()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAudioEngine::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtSpatialAudio_qt_metaobject(sipPySelf, sipType_QAudioEngine);

    return ::QAudioEngine::metaObject();
}

int sipQAudioEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAudioEngine::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtSpatialAudio_qt_metacall(sipPySelf, sipType_QAudioEngine, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAudioEngine::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtSpatialAudio_qt_metacast(sipPySelf, sipType_QAudioEngine, _clname, &sipCpp) ? sipCpp : ::QAudioEngine::qt_metacast(_clname));
}

bool sipQAudioEngine::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAudioEngine::event(a0);

    extern bool sipVH_QtSpatialAudio_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtSpatialAudio_5(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAudioEngine::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAudioEngine::eventFilter(a0, a1);

    extern bool sipVH_QtSpatialAudio_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtSpatialAudio_4(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAudioEngine::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAudioEngine::timerEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtSpatialAudio_3(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioEngine::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAudioEngine::childEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtSpatialAudio_2(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioEngine::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAudioEngine::customEvent(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSpatialAudio_1(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioEngine::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAudioEngine::connectNotify(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSpatialAudio_0(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioEngine::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAudioEngine::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtSpatialAudio_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSpatialAudio_0(sipGILState, sipImportedVirtErrorHandlers_QtSpatialAudio_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAudioEngine_setOutputMode, "setOutputMode(self, mode: QAudioEngine.OutputMode)");

extern "C" {static PyObject *meth_QAudioEngine_setOutputMode(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_setOutputMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioEngine::OutputMode a0;
        ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAudioEngine, &sipCpp, sipType_QAudioEngine_OutputMode, &a0))
        {
            sipCpp->setOutputMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_setOutputMode, doc_QAudioEngine_setOutputMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_outputMode, "outputMode(self) -> QAudioEngine.OutputMode");

extern "C" {static PyObject *meth_QAudioEngine_outputMode(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_outputMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEngine, &sipCpp))
        {
            ::QAudioEngine::OutputMode sipRes;

            sipRes = sipCpp->outputMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAudioEngine_OutputMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_outputMode, doc_QAudioEngine_outputMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_sampleRate, "sampleRate(self) -> int");

extern "C" {static PyObject *meth_QAudioEngine_sampleRate(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_sampleRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEngine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->sampleRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_sampleRate, doc_QAudioEngine_sampleRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_setOutputDevice, "setOutputDevice(self, device: QAudioDevice)");

extern "C" {static PyObject *meth_QAudioEngine_setOutputDevice(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_setOutputDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioDevice* a0;
        ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioEngine, &sipCpp, sipType_QAudioDevice, &a0))
        {
            sipCpp->setOutputDevice(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_setOutputDevice, doc_QAudioEngine_setOutputDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_outputDevice, "outputDevice(self) -> QAudioDevice");

extern "C" {static PyObject *meth_QAudioEngine_outputDevice(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_outputDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEngine, &sipCpp))
        {
            ::QAudioDevice*sipRes;

            sipRes = new ::QAudioDevice(sipCpp->outputDevice());

            return sipConvertFromNewType(sipRes, sipType_QAudioDevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_outputDevice, doc_QAudioEngine_outputDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_setMasterVolume, "setMasterVolume(self, volume: float)");

extern "C" {static PyObject *meth_QAudioEngine_setMasterVolume(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_setMasterVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QAudioEngine, &sipCpp, &a0))
        {
            sipCpp->setMasterVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_setMasterVolume, doc_QAudioEngine_setMasterVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_masterVolume, "masterVolume(self) -> float");

extern "C" {static PyObject *meth_QAudioEngine_masterVolume(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_masterVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEngine, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->masterVolume();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_masterVolume, doc_QAudioEngine_masterVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_setPaused, "setPaused(self, paused: bool)");

extern "C" {static PyObject *meth_QAudioEngine_setPaused(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_setPaused(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAudioEngine, &sipCpp, &a0))
        {
            sipCpp->setPaused(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_setPaused, doc_QAudioEngine_setPaused);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_paused, "paused(self) -> bool");

extern "C" {static PyObject *meth_QAudioEngine_paused(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_paused(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEngine, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->paused();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_paused, doc_QAudioEngine_paused);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_setRoomEffectsEnabled, "setRoomEffectsEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QAudioEngine_setRoomEffectsEnabled(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_setRoomEffectsEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAudioEngine, &sipCpp, &a0))
        {
            sipCpp->setRoomEffectsEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_setRoomEffectsEnabled, doc_QAudioEngine_setRoomEffectsEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_roomEffectsEnabled, "roomEffectsEnabled(self) -> bool");

extern "C" {static PyObject *meth_QAudioEngine_roomEffectsEnabled(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_roomEffectsEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEngine, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->roomEffectsEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_roomEffectsEnabled, doc_QAudioEngine_roomEffectsEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_setDistanceScale, "setDistanceScale(self, scale: float)");

extern "C" {static PyObject *meth_QAudioEngine_setDistanceScale(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_setDistanceScale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QAudioEngine, &sipCpp, &a0))
        {
            sipCpp->setDistanceScale(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_setDistanceScale, doc_QAudioEngine_setDistanceScale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_distanceScale, "distanceScale(self) -> float");

extern "C" {static PyObject *meth_QAudioEngine_distanceScale(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_distanceScale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEngine, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->distanceScale();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_distanceScale, doc_QAudioEngine_distanceScale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_start, "start(self)");

extern "C" {static PyObject *meth_QAudioEngine_start(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEngine, &sipCpp))
        {
            sipCpp->start();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_start, doc_QAudioEngine_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_stop, "stop(self)");

extern "C" {static PyObject *meth_QAudioEngine_stop(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEngine, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_stop, doc_QAudioEngine_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_pause, "pause(self)");

extern "C" {static PyObject *meth_QAudioEngine_pause(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_pause(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEngine, &sipCpp))
        {
            sipCpp->pause();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_pause, doc_QAudioEngine_pause);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEngine_resume, "resume(self)");

extern "C" {static PyObject *meth_QAudioEngine_resume(PyObject *, PyObject *);}
static PyObject *meth_QAudioEngine_resume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEngine, &sipCpp))
        {
            sipCpp->resume();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEngine, sipName_resume, doc_QAudioEngine_resume);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAudioEngine(void *, const sipTypeDef *);}
static void *cast_QAudioEngine(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAudioEngine *sipCpp = reinterpret_cast< ::QAudioEngine *>(sipCppV);

    if (targetType == sipType_QAudioEngine)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAudioEngine(void *, int);}
static void release_QAudioEngine(void *sipCppV, int)
{
    ::QAudioEngine *sipCpp = reinterpret_cast< ::QAudioEngine *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QAudioEngine(Py_ssize_t);}
static void *array_QAudioEngine(Py_ssize_t sipNrElem)
{
    return new ::QAudioEngine[sipNrElem];
}


extern "C" {static void array_delete_QAudioEngine(void *);}
static void array_delete_QAudioEngine(void *sipCpp)
{
    delete[] reinterpret_cast< ::QAudioEngine *>(sipCpp);
}


extern "C" {static void dealloc_QAudioEngine(sipSimpleWrapper *);}
static void dealloc_QAudioEngine(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAudioEngine *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAudioEngine(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAudioEngine(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAudioEngine(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAudioEngine *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQAudioEngine();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQAudioEngine(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        int a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "i|JH", &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQAudioEngine(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAudioEngine[] = {{3, 0, 1}};


static PyMethodDef methods_QAudioEngine[] = {
    {sipName_distanceScale, meth_QAudioEngine_distanceScale, METH_VARARGS, doc_QAudioEngine_distanceScale},
    {sipName_masterVolume, meth_QAudioEngine_masterVolume, METH_VARARGS, doc_QAudioEngine_masterVolume},
    {sipName_outputDevice, meth_QAudioEngine_outputDevice, METH_VARARGS, doc_QAudioEngine_outputDevice},
    {sipName_outputMode, meth_QAudioEngine_outputMode, METH_VARARGS, doc_QAudioEngine_outputMode},
    {sipName_pause, meth_QAudioEngine_pause, METH_VARARGS, doc_QAudioEngine_pause},
    {sipName_paused, meth_QAudioEngine_paused, METH_VARARGS, doc_QAudioEngine_paused},
    {sipName_resume, meth_QAudioEngine_resume, METH_VARARGS, doc_QAudioEngine_resume},
    {sipName_roomEffectsEnabled, meth_QAudioEngine_roomEffectsEnabled, METH_VARARGS, doc_QAudioEngine_roomEffectsEnabled},
    {sipName_sampleRate, meth_QAudioEngine_sampleRate, METH_VARARGS, doc_QAudioEngine_sampleRate},
    {sipName_setDistanceScale, meth_QAudioEngine_setDistanceScale, METH_VARARGS, doc_QAudioEngine_setDistanceScale},
    {sipName_setMasterVolume, meth_QAudioEngine_setMasterVolume, METH_VARARGS, doc_QAudioEngine_setMasterVolume},
    {sipName_setOutputDevice, meth_QAudioEngine_setOutputDevice, METH_VARARGS, doc_QAudioEngine_setOutputDevice},
    {sipName_setOutputMode, meth_QAudioEngine_setOutputMode, METH_VARARGS, doc_QAudioEngine_setOutputMode},
    {sipName_setPaused, meth_QAudioEngine_setPaused, METH_VARARGS, doc_QAudioEngine_setPaused},
    {sipName_setRoomEffectsEnabled, meth_QAudioEngine_setRoomEffectsEnabled, METH_VARARGS, doc_QAudioEngine_setRoomEffectsEnabled},
    {sipName_start, meth_QAudioEngine_start, METH_VARARGS, doc_QAudioEngine_start},
    {sipName_stop, meth_QAudioEngine_stop, METH_VARARGS, doc_QAudioEngine_stop}
};


extern "C" {static PyObject *varget_QAudioEngine_DistanceScaleCentimeter(void *, PyObject *, PyObject *);}
static PyObject *varget_QAudioEngine_DistanceScaleCentimeter(void *, PyObject *, PyObject *)
{
    float sipVal;

    sipVal = ::QAudioEngine::DistanceScaleCentimeter;

    return PyFloat_FromDouble((double)sipVal);
}


extern "C" {static PyObject *varget_QAudioEngine_DistanceScaleMeter(void *, PyObject *, PyObject *);}
static PyObject *varget_QAudioEngine_DistanceScaleMeter(void *, PyObject *, PyObject *)
{
    float sipVal;

    sipVal = ::QAudioEngine::DistanceScaleMeter;

    return PyFloat_FromDouble((double)sipVal);
}

sipVariableDef variables_QAudioEngine[] = {
    {ClassVariable, sipName_DistanceScaleCentimeter, (PyMethodDef *)varget_QAudioEngine_DistanceScaleCentimeter, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DistanceScaleMeter, (PyMethodDef *)varget_QAudioEngine_DistanceScaleMeter, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QAudioEngine[] = {
    {sipName_Surround, static_cast<int>(::QAudioEngine::Surround)},
    {sipName_Stereo, static_cast<int>(::QAudioEngine::Stereo)},
    {sipName_Headphone, static_cast<int>(::QAudioEngine::Headphone)},
    {0, 0}
};

PyDoc_STRVAR(doc_QAudioEngine, "\1QAudioEngine()\n"
"QAudioEngine(parent: QObject|None)\n"
"QAudioEngine(sampleRate: int, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QAudioEngine[] = {
    {"distanceScaleChanged()", "\1distanceScaleChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"pausedChanged()", "\1pausedChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"masterVolumeChanged()", "\1masterVolumeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"outputDeviceChanged()", "\1outputDeviceChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"outputModeChanged()", "\1outputModeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QAudioEngine = {
    &::QAudioEngine::staticMetaObject,
    signals_QAudioEngine,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSpatialAudio_QAudioEngine = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAudioEngine,
        SIP_NULLPTR,
        &plugin_QAudioEngine,
    },
    {
        sipNameNr_QAudioEngine,
        {0, 0, 1},
        17, methods_QAudioEngine,
        2, variables_QAudioEngine,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QAudioEngine, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAudioEngine,
    -1,
    -1,
    supers_QAudioEngine,
    SIP_NULLPTR,
    init_type_QAudioEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAudioEngine,
    SIP_NULLPTR,
    array_QAudioEngine,
    SIP_NULLPTR,
    release_QAudioEngine,
    cast_QAudioEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAudioEngine,
    sizeof (::QAudioEngine),
};
