/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qsgmaterialshader.sip"
#include <qsgmaterialshader.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQuick/qsgmaterialshader.sip"
#include <qsgmaterialshader.h>
#line 31 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGMaterialShaderGraphicsPipelineState.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGMaterialShaderGraphicsPipelineState.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQuick/sipQtQuickQSGMaterialShaderGraphicsPipelineState.cpp"


/* Call the instance's destructor. */
extern "C" {static void release_QSGMaterialShader_GraphicsPipelineState(void *, int);}
static void release_QSGMaterialShader_GraphicsPipelineState(void *sipCppV, int)
{
    delete reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipCppV);
}


extern "C" {static void *array_QSGMaterialShader_GraphicsPipelineState(Py_ssize_t);}
static void *array_QSGMaterialShader_GraphicsPipelineState(Py_ssize_t sipNrElem)
{
    return new ::QSGMaterialShader::GraphicsPipelineState[sipNrElem];
}


extern "C" {static void array_delete_QSGMaterialShader_GraphicsPipelineState(void *);}
static void array_delete_QSGMaterialShader_GraphicsPipelineState(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipCpp);
}


extern "C" {static void assign_QSGMaterialShader_GraphicsPipelineState(void *, Py_ssize_t, void *);}
static void assign_QSGMaterialShader_GraphicsPipelineState(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSrc);
}


extern "C" {static void *copy_QSGMaterialShader_GraphicsPipelineState(const void *, Py_ssize_t);}
static void *copy_QSGMaterialShader_GraphicsPipelineState(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QSGMaterialShader::GraphicsPipelineState(reinterpret_cast<const ::QSGMaterialShader::GraphicsPipelineState *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QSGMaterialShader_GraphicsPipelineState(sipSimpleWrapper *);}
static void dealloc_QSGMaterialShader_GraphicsPipelineState(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGMaterialShader_GraphicsPipelineState(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QSGMaterialShader_GraphicsPipelineState(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSGMaterialShader_GraphicsPipelineState(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QSGMaterialShader::GraphicsPipelineState();

            return sipCpp;
        }
    }

    {
        const ::QSGMaterialShader::GraphicsPipelineState* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QSGMaterialShader_GraphicsPipelineState, &a0))
        {
            sipCpp = new ::QSGMaterialShader::GraphicsPipelineState(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_blendConstant(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_blendConstant(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
    ::QColor*sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -3);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->blendConstant;

    sipPy = sipConvertFromType(sipVal, sipType_QColor, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -8, sipPySelf);
        sipKeepReference(sipPySelf, -3, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_blendConstant(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_blendConstant(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QColor*sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast< ::QColor *>(sipForceConvertToType(sipPy, sipType_QColor, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->blendConstant = *sipVal;

    sipReleaseType(sipVal, sipType_QColor, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_blendEnable(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_blendEnable(void *sipSelf, PyObject *, PyObject *)
{
    bool sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipCpp->blendEnable;

    return PyBool_FromLong(sipVal);
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_blendEnable(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_blendEnable(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipConvertToBool(sipPy);

    if (sipVal < 0)
        return -1;

    sipCpp->blendEnable = static_cast<bool>(sipVal);

    return 0;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_colorWrite(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_colorWrite(void *sipSelf, PyObject *, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::ColorMask*sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = &sipCpp->colorWrite;

    return sipConvertFromType(sipVal, sipType_QFlags_0100QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent, SIP_NULLPTR);
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_colorWrite(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_colorWrite(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::ColorMask*sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState::ColorMask *>(sipForceConvertToType(sipPy, sipType_QFlags_0100QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->colorWrite = *sipVal;

    sipReleaseType(sipVal, sipType_QFlags_0100QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_cullMode(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_cullMode(void *sipSelf, PyObject *, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::CullMode sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipCpp->cullMode;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QSGMaterialShader_GraphicsPipelineState_CullMode);
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_cullMode(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_cullMode(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::CullMode sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = (::QSGMaterialShader::GraphicsPipelineState::CullMode)sipConvertToEnum(sipPy, sipType_QSGMaterialShader_GraphicsPipelineState_CullMode);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->cullMode = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_dstAlpha(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_dstAlpha(void *sipSelf, PyObject *, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendFactor sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipCpp->dstAlpha;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QSGMaterialShader_GraphicsPipelineState_BlendFactor);
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_dstAlpha(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_dstAlpha(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendFactor sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = (::QSGMaterialShader::GraphicsPipelineState::BlendFactor)sipConvertToEnum(sipPy, sipType_QSGMaterialShader_GraphicsPipelineState_BlendFactor);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->dstAlpha = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_dstColor(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_dstColor(void *sipSelf, PyObject *, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendFactor sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipCpp->dstColor;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QSGMaterialShader_GraphicsPipelineState_BlendFactor);
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_dstColor(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_dstColor(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendFactor sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = (::QSGMaterialShader::GraphicsPipelineState::BlendFactor)sipConvertToEnum(sipPy, sipType_QSGMaterialShader_GraphicsPipelineState_BlendFactor);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->dstColor = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_opAlpha(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_opAlpha(void *sipSelf, PyObject *, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendOp sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipCpp->opAlpha;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QSGMaterialShader_GraphicsPipelineState_BlendOp);
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_opAlpha(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_opAlpha(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendOp sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = (::QSGMaterialShader::GraphicsPipelineState::BlendOp)sipConvertToEnum(sipPy, sipType_QSGMaterialShader_GraphicsPipelineState_BlendOp);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->opAlpha = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_opColor(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_opColor(void *sipSelf, PyObject *, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendOp sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipCpp->opColor;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QSGMaterialShader_GraphicsPipelineState_BlendOp);
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_opColor(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_opColor(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendOp sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = (::QSGMaterialShader::GraphicsPipelineState::BlendOp)sipConvertToEnum(sipPy, sipType_QSGMaterialShader_GraphicsPipelineState_BlendOp);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->opColor = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_polygonMode(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_polygonMode(void *sipSelf, PyObject *, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::PolygonMode sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipCpp->polygonMode;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QSGMaterialShader_GraphicsPipelineState_PolygonMode);
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_polygonMode(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_polygonMode(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::PolygonMode sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = (::QSGMaterialShader::GraphicsPipelineState::PolygonMode)sipConvertToEnum(sipPy, sipType_QSGMaterialShader_GraphicsPipelineState_PolygonMode);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->polygonMode = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_separateBlendFactors(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_separateBlendFactors(void *sipSelf, PyObject *, PyObject *)
{
    bool sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipCpp->separateBlendFactors;

    return PyBool_FromLong(sipVal);
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_separateBlendFactors(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_separateBlendFactors(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipConvertToBool(sipPy);

    if (sipVal < 0)
        return -1;

    sipCpp->separateBlendFactors = static_cast<bool>(sipVal);

    return 0;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_srcAlpha(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_srcAlpha(void *sipSelf, PyObject *, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendFactor sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipCpp->srcAlpha;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QSGMaterialShader_GraphicsPipelineState_BlendFactor);
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_srcAlpha(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_srcAlpha(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendFactor sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = (::QSGMaterialShader::GraphicsPipelineState::BlendFactor)sipConvertToEnum(sipPy, sipType_QSGMaterialShader_GraphicsPipelineState_BlendFactor);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->srcAlpha = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_srcColor(void *, PyObject *, PyObject *);}
static PyObject *varget_QSGMaterialShader_GraphicsPipelineState_srcColor(void *sipSelf, PyObject *, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendFactor sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = sipCpp->srcColor;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QSGMaterialShader_GraphicsPipelineState_BlendFactor);
}


extern "C" {static int varset_QSGMaterialShader_GraphicsPipelineState_srcColor(void *, PyObject *, PyObject *);}
static int varset_QSGMaterialShader_GraphicsPipelineState_srcColor(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QSGMaterialShader::GraphicsPipelineState::BlendFactor sipVal;
    ::QSGMaterialShader::GraphicsPipelineState *sipCpp = reinterpret_cast< ::QSGMaterialShader::GraphicsPipelineState *>(sipSelf);

    sipVal = (::QSGMaterialShader::GraphicsPipelineState::BlendFactor)sipConvertToEnum(sipPy, sipType_QSGMaterialShader_GraphicsPipelineState_BlendFactor);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->srcColor = sipVal;

    return 0;
}

sipVariableDef variables_QSGMaterialShader_GraphicsPipelineState[] = {
    {InstanceVariable, sipName_blendConstant, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_blendConstant, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_blendConstant, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_blendEnable, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_blendEnable, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_blendEnable, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_colorWrite, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_colorWrite, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_colorWrite, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_cullMode, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_cullMode, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_cullMode, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_dstAlpha, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_dstAlpha, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_dstAlpha, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_dstColor, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_dstColor, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_dstColor, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_opAlpha, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_opAlpha, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_opAlpha, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_opColor, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_opColor, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_opColor, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_polygonMode, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_polygonMode, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_polygonMode, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_separateBlendFactors, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_separateBlendFactors, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_separateBlendFactors, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_srcAlpha, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_srcAlpha, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_srcAlpha, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_srcColor, (PyMethodDef *)varget_QSGMaterialShader_GraphicsPipelineState_srcColor, (PyMethodDef *)varset_QSGMaterialShader_GraphicsPipelineState_srcColor, SIP_NULLPTR, SIP_NULLPTR},
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QSGMaterialShader_GraphicsPipelineState[] = {
    {sipName_Zero, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::Zero)},
    {sipName_One, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::One)},
    {sipName_SrcColor, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::SrcColor)},
    {sipName_OneMinusSrcColor, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::OneMinusSrcColor)},
    {sipName_DstColor, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::DstColor)},
    {sipName_OneMinusDstColor, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::OneMinusDstColor)},
    {sipName_SrcAlpha, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::SrcAlpha)},
    {sipName_OneMinusSrcAlpha, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::OneMinusSrcAlpha)},
    {sipName_DstAlpha, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::DstAlpha)},
    {sipName_OneMinusDstAlpha, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::OneMinusDstAlpha)},
    {sipName_ConstantColor, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::ConstantColor)},
    {sipName_OneMinusConstantColor, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::OneMinusConstantColor)},
    {sipName_ConstantAlpha, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::ConstantAlpha)},
    {sipName_OneMinusConstantAlpha, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::OneMinusConstantAlpha)},
    {sipName_SrcAlphaSaturate, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::SrcAlphaSaturate)},
    {sipName_Src1Color, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::Src1Color)},
    {sipName_OneMinusSrc1Color, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::OneMinusSrc1Color)},
    {sipName_Src1Alpha, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::Src1Alpha)},
    {sipName_OneMinusSrc1Alpha, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::OneMinusSrc1Alpha)},
    {sipName_Add, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::BlendOp::Add)},
    {sipName_Subtract, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::BlendOp::Subtract)},
    {sipName_ReverseSubtract, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::BlendOp::ReverseSubtract)},
    {sipName_Min, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::BlendOp::Min)},
    {sipName_Max, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::BlendOp::Max)},
    {sipName_R, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::R)},
    {sipName_G, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::G)},
    {sipName_B, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::B)},
    {sipName_A, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::A)},
    {sipName_CullNone, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::CullNone)},
    {sipName_CullFront, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::CullFront)},
    {sipName_CullBack, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::CullBack)},
    {sipName_Fill, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::Fill)},
    {sipName_Line, static_cast<int>(::QSGMaterialShader::GraphicsPipelineState::Line)},
    {0, 0}
};

PyDoc_STRVAR(doc_QSGMaterialShader_GraphicsPipelineState, "\1QSGMaterialShader.GraphicsPipelineState()\n"
"QSGMaterialShader.GraphicsPipelineState(a0: QSGMaterialShader.GraphicsPipelineState)");


sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialShader_GraphicsPipelineState = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGMaterialShader__GraphicsPipelineState,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_GraphicsPipelineState,
        {71, 255, 0},
        0, SIP_NULLPTR,
        12, variables_QSGMaterialShader_GraphicsPipelineState,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QSGMaterialShader_GraphicsPipelineState, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSGMaterialShader_GraphicsPipelineState,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QSGMaterialShader_GraphicsPipelineState,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSGMaterialShader_GraphicsPipelineState,
    assign_QSGMaterialShader_GraphicsPipelineState,
    array_QSGMaterialShader_GraphicsPipelineState,
    copy_QSGMaterialShader_GraphicsPipelineState,
    release_QSGMaterialShader_GraphicsPipelineState,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSGMaterialShader_GraphicsPipelineState,
    sizeof (::QSGMaterialShader::GraphicsPipelineState),
};
