/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qabstractfileiconprovider.sip"
#include <qabstractfileiconprovider.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQAbstractFileIconProvider.cpp"

#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQAbstractFileIconProvider.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQAbstractFileIconProvider.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qfileinfo.sip"
#include <qfileinfo.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQAbstractFileIconProvider.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQAbstractFileIconProvider.cpp"


class sipQAbstractFileIconProvider : public ::QAbstractFileIconProvider
{
public:
    sipQAbstractFileIconProvider();
    virtual ~sipQAbstractFileIconProvider();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QAbstractFileIconProvider::Options options() const SIP_OVERRIDE;
    void setOptions(::QAbstractFileIconProvider::Options) SIP_OVERRIDE;
    ::QString type(const ::QFileInfo&) const SIP_OVERRIDE;
    ::QIcon icon(const ::QFileInfo&) const SIP_OVERRIDE;
    ::QIcon icon(::QAbstractFileIconProvider::IconType) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAbstractFileIconProvider(const sipQAbstractFileIconProvider &);
    sipQAbstractFileIconProvider &operator = (const sipQAbstractFileIconProvider &);

    char sipPyMethods[5];
};

sipQAbstractFileIconProvider::sipQAbstractFileIconProvider(): ::QAbstractFileIconProvider(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAbstractFileIconProvider::~sipQAbstractFileIconProvider()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

::QAbstractFileIconProvider::Options sipQAbstractFileIconProvider::options() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_options);

    if (!sipMeth)
        return ::QAbstractFileIconProvider::options();

    extern ::QAbstractFileIconProvider::Options sipVH_QtGui_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_4(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractFileIconProvider::setOptions(::QAbstractFileIconProvider::Options a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_setOptions);

    if (!sipMeth)
    {
        ::QAbstractFileIconProvider::setOptions(a0);
        return;
    }

    extern void sipVH_QtGui_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractFileIconProvider::Options);

    sipVH_QtGui_3(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQAbstractFileIconProvider::type(const ::QFileInfo& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QAbstractFileIconProvider::type(a0);

    extern ::QString sipVH_QtGui_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QFileInfo&);

    return sipVH_QtGui_2(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QIcon sipQAbstractFileIconProvider::icon(const ::QFileInfo& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_icon);

    if (!sipMeth)
        return ::QAbstractFileIconProvider::icon(a0);

    extern ::QIcon sipVH_QtGui_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QFileInfo&);

    return sipVH_QtGui_1(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QIcon sipQAbstractFileIconProvider::icon(::QAbstractFileIconProvider::IconType a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_icon);

    if (!sipMeth)
        return ::QAbstractFileIconProvider::icon(a0);

    extern ::QIcon sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractFileIconProvider::IconType);

    return sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAbstractFileIconProvider_icon, "icon(self, a0: QAbstractFileIconProvider.IconType) -> QIcon\n"
"icon(self, a0: QFileInfo) -> QIcon");

extern "C" {static PyObject *meth_QAbstractFileIconProvider_icon(PyObject *, PyObject *);}
static PyObject *meth_QAbstractFileIconProvider_icon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractFileIconProvider)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QAbstractFileIconProvider::IconType a0;
        const ::QAbstractFileIconProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractFileIconProvider, &sipCpp, sipType_QAbstractFileIconProvider_IconType, &a0))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon((sipSelfWasArg ? sipCpp->::QAbstractFileIconProvider::icon(a0) : sipCpp->icon(a0)));

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    {
        const ::QFileInfo* a0;
        const ::QAbstractFileIconProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractFileIconProvider, &sipCpp, sipType_QFileInfo, &a0))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon((sipSelfWasArg ? sipCpp->::QAbstractFileIconProvider::icon(*a0) : sipCpp->icon(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractFileIconProvider, sipName_icon, doc_QAbstractFileIconProvider_icon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractFileIconProvider_type, "type(self, a0: QFileInfo) -> str");

extern "C" {static PyObject *meth_QAbstractFileIconProvider_type(PyObject *, PyObject *);}
static PyObject *meth_QAbstractFileIconProvider_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractFileIconProvider)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QFileInfo* a0;
        const ::QAbstractFileIconProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractFileIconProvider, &sipCpp, sipType_QFileInfo, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QAbstractFileIconProvider::type(*a0) : sipCpp->type(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractFileIconProvider, sipName_type, doc_QAbstractFileIconProvider_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractFileIconProvider_setOptions, "setOptions(self, a0: QAbstractFileIconProvider.Option)");

extern "C" {static PyObject *meth_QAbstractFileIconProvider_setOptions(PyObject *, PyObject *);}
static PyObject *meth_QAbstractFileIconProvider_setOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractFileIconProvider)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QAbstractFileIconProvider::Options* a0;
        int a0State = 0;
        ::QAbstractFileIconProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAbstractFileIconProvider, &sipCpp, sipType_QFlags_0100QAbstractFileIconProvider_Option, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractFileIconProvider::setOptions(*a0) : sipCpp->setOptions(*a0));
            sipReleaseType(a0, sipType_QFlags_0100QAbstractFileIconProvider_Option, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractFileIconProvider, sipName_setOptions, doc_QAbstractFileIconProvider_setOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractFileIconProvider_options, "options(self) -> QAbstractFileIconProvider.Option");

extern "C" {static PyObject *meth_QAbstractFileIconProvider_options(PyObject *, PyObject *);}
static PyObject *meth_QAbstractFileIconProvider_options(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractFileIconProvider)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QAbstractFileIconProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractFileIconProvider, &sipCpp))
        {
            ::QAbstractFileIconProvider::Options*sipRes;

            sipRes = new ::QAbstractFileIconProvider::Options((sipSelfWasArg ? sipCpp->::QAbstractFileIconProvider::options() : sipCpp->options()));

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QAbstractFileIconProvider_Option, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractFileIconProvider, sipName_options, doc_QAbstractFileIconProvider_options);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAbstractFileIconProvider(void *, int);}
static void release_QAbstractFileIconProvider(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQAbstractFileIconProvider *>(sipCppV);
    else
        delete reinterpret_cast< ::QAbstractFileIconProvider *>(sipCppV);
}


extern "C" {static void *array_QAbstractFileIconProvider(Py_ssize_t);}
static void *array_QAbstractFileIconProvider(Py_ssize_t sipNrElem)
{
    return new ::QAbstractFileIconProvider[sipNrElem];
}


extern "C" {static void array_delete_QAbstractFileIconProvider(void *);}
static void array_delete_QAbstractFileIconProvider(void *sipCpp)
{
    delete[] reinterpret_cast< ::QAbstractFileIconProvider *>(sipCpp);
}


extern "C" {static void dealloc_QAbstractFileIconProvider(sipSimpleWrapper *);}
static void dealloc_QAbstractFileIconProvider(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAbstractFileIconProvider *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAbstractFileIconProvider(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAbstractFileIconProvider(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAbstractFileIconProvider(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQAbstractFileIconProvider *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQAbstractFileIconProvider();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QAbstractFileIconProvider[] = {
    {sipName_icon, meth_QAbstractFileIconProvider_icon, METH_VARARGS, doc_QAbstractFileIconProvider_icon},
    {sipName_options, meth_QAbstractFileIconProvider_options, METH_VARARGS, doc_QAbstractFileIconProvider_options},
    {sipName_setOptions, meth_QAbstractFileIconProvider_setOptions, METH_VARARGS, doc_QAbstractFileIconProvider_setOptions},
    {sipName_type, meth_QAbstractFileIconProvider_type, METH_VARARGS, doc_QAbstractFileIconProvider_type}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QAbstractFileIconProvider[] = {
    {sipName_Computer, static_cast<int>(::QAbstractFileIconProvider::Computer)},
    {sipName_Desktop, static_cast<int>(::QAbstractFileIconProvider::Desktop)},
    {sipName_Trashcan, static_cast<int>(::QAbstractFileIconProvider::Trashcan)},
    {sipName_Network, static_cast<int>(::QAbstractFileIconProvider::Network)},
    {sipName_Drive, static_cast<int>(::QAbstractFileIconProvider::Drive)},
    {sipName_Folder, static_cast<int>(::QAbstractFileIconProvider::Folder)},
    {sipName_File, static_cast<int>(::QAbstractFileIconProvider::File)},
    {sipName_DontUseCustomDirectoryIcons, static_cast<int>(::QAbstractFileIconProvider::DontUseCustomDirectoryIcons)},
    {0, 0}
};

PyDoc_STRVAR(doc_QAbstractFileIconProvider, "\1QAbstractFileIconProvider()");


sipClassTypeDef sipTypeDef_QtGui_QAbstractFileIconProvider = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAbstractFileIconProvider,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QAbstractFileIconProvider,
        {0, 0, 1},
        4, methods_QAbstractFileIconProvider,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QAbstractFileIconProvider, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAbstractFileIconProvider,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QAbstractFileIconProvider,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAbstractFileIconProvider,
    SIP_NULLPTR,
    array_QAbstractFileIconProvider,
    SIP_NULLPTR,
    release_QAbstractFileIconProvider,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAbstractFileIconProvider,
    sizeof (::QAbstractFileIconProvider),
};
