/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 112 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQDnsTlsAssociationRecord.cpp"

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQDnsTlsAssociationRecord.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipQtNetworkQDnsTlsAssociationRecord.cpp"


PyDoc_STRVAR(doc_QDnsTlsAssociationRecord_swap, "swap(self, other: QDnsTlsAssociationRecord)");

extern "C" {static PyObject *meth_QDnsTlsAssociationRecord_swap(PyObject *, PyObject *);}
static PyObject *meth_QDnsTlsAssociationRecord_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDnsTlsAssociationRecord* a0;
        ::QDnsTlsAssociationRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QDnsTlsAssociationRecord, &sipCpp, sipType_QDnsTlsAssociationRecord, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsTlsAssociationRecord, sipName_swap, doc_QDnsTlsAssociationRecord_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsTlsAssociationRecord_name, "name(self) -> str");

extern "C" {static PyObject *meth_QDnsTlsAssociationRecord_name(PyObject *, PyObject *);}
static PyObject *meth_QDnsTlsAssociationRecord_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDnsTlsAssociationRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsTlsAssociationRecord, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsTlsAssociationRecord, sipName_name, doc_QDnsTlsAssociationRecord_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsTlsAssociationRecord_timeToLive, "timeToLive(self) -> int");

extern "C" {static PyObject *meth_QDnsTlsAssociationRecord_timeToLive(PyObject *, PyObject *);}
static PyObject *meth_QDnsTlsAssociationRecord_timeToLive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDnsTlsAssociationRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsTlsAssociationRecord, &sipCpp))
        {
            ::quint32 sipRes;

            sipRes = sipCpp->timeToLive();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsTlsAssociationRecord, sipName_timeToLive, doc_QDnsTlsAssociationRecord_timeToLive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsTlsAssociationRecord_usage, "usage(self) -> QDnsTlsAssociationRecord.CertificateUsage");

extern "C" {static PyObject *meth_QDnsTlsAssociationRecord_usage(PyObject *, PyObject *);}
static PyObject *meth_QDnsTlsAssociationRecord_usage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDnsTlsAssociationRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsTlsAssociationRecord, &sipCpp))
        {
            ::QDnsTlsAssociationRecord::CertificateUsage sipRes;

            sipRes = sipCpp->usage();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QDnsTlsAssociationRecord_CertificateUsage);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsTlsAssociationRecord, sipName_usage, doc_QDnsTlsAssociationRecord_usage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsTlsAssociationRecord_selector, "selector(self) -> QDnsTlsAssociationRecord.Selector");

extern "C" {static PyObject *meth_QDnsTlsAssociationRecord_selector(PyObject *, PyObject *);}
static PyObject *meth_QDnsTlsAssociationRecord_selector(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDnsTlsAssociationRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsTlsAssociationRecord, &sipCpp))
        {
            ::QDnsTlsAssociationRecord::Selector sipRes;

            sipRes = sipCpp->selector();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QDnsTlsAssociationRecord_Selector);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsTlsAssociationRecord, sipName_selector, doc_QDnsTlsAssociationRecord_selector);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsTlsAssociationRecord_matchType, "matchType(self) -> QDnsTlsAssociationRecord.MatchingType");

extern "C" {static PyObject *meth_QDnsTlsAssociationRecord_matchType(PyObject *, PyObject *);}
static PyObject *meth_QDnsTlsAssociationRecord_matchType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDnsTlsAssociationRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsTlsAssociationRecord, &sipCpp))
        {
            ::QDnsTlsAssociationRecord::MatchingType sipRes;

            sipRes = sipCpp->matchType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QDnsTlsAssociationRecord_MatchingType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsTlsAssociationRecord, sipName_matchType, doc_QDnsTlsAssociationRecord_matchType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsTlsAssociationRecord_value, "value(self) -> QByteArray");

extern "C" {static PyObject *meth_QDnsTlsAssociationRecord_value(PyObject *, PyObject *);}
static PyObject *meth_QDnsTlsAssociationRecord_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDnsTlsAssociationRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsTlsAssociationRecord, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->value());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsTlsAssociationRecord, sipName_value, doc_QDnsTlsAssociationRecord_value);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDnsTlsAssociationRecord(void *, int);}
static void release_QDnsTlsAssociationRecord(void *sipCppV, int)
{
    delete reinterpret_cast< ::QDnsTlsAssociationRecord *>(sipCppV);
}


extern "C" {static void *array_QDnsTlsAssociationRecord(Py_ssize_t);}
static void *array_QDnsTlsAssociationRecord(Py_ssize_t sipNrElem)
{
    return new ::QDnsTlsAssociationRecord[sipNrElem];
}


extern "C" {static void array_delete_QDnsTlsAssociationRecord(void *);}
static void array_delete_QDnsTlsAssociationRecord(void *sipCpp)
{
    delete[] reinterpret_cast< ::QDnsTlsAssociationRecord *>(sipCpp);
}


extern "C" {static void assign_QDnsTlsAssociationRecord(void *, Py_ssize_t, void *);}
static void assign_QDnsTlsAssociationRecord(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QDnsTlsAssociationRecord *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QDnsTlsAssociationRecord *>(sipSrc);
}


extern "C" {static void *copy_QDnsTlsAssociationRecord(const void *, Py_ssize_t);}
static void *copy_QDnsTlsAssociationRecord(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QDnsTlsAssociationRecord(reinterpret_cast<const ::QDnsTlsAssociationRecord *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QDnsTlsAssociationRecord(sipSimpleWrapper *);}
static void dealloc_QDnsTlsAssociationRecord(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDnsTlsAssociationRecord(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QDnsTlsAssociationRecord(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDnsTlsAssociationRecord(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QDnsTlsAssociationRecord *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QDnsTlsAssociationRecord();

            return sipCpp;
        }
    }

    {
        const ::QDnsTlsAssociationRecord* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDnsTlsAssociationRecord, &a0))
        {
            sipCpp = new ::QDnsTlsAssociationRecord(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QDnsTlsAssociationRecord[] = {
    {sipName_matchType, meth_QDnsTlsAssociationRecord_matchType, METH_VARARGS, doc_QDnsTlsAssociationRecord_matchType},
    {sipName_name, meth_QDnsTlsAssociationRecord_name, METH_VARARGS, doc_QDnsTlsAssociationRecord_name},
    {sipName_selector, meth_QDnsTlsAssociationRecord_selector, METH_VARARGS, doc_QDnsTlsAssociationRecord_selector},
    {sipName_swap, meth_QDnsTlsAssociationRecord_swap, METH_VARARGS, doc_QDnsTlsAssociationRecord_swap},
    {sipName_timeToLive, meth_QDnsTlsAssociationRecord_timeToLive, METH_VARARGS, doc_QDnsTlsAssociationRecord_timeToLive},
    {sipName_usage, meth_QDnsTlsAssociationRecord_usage, METH_VARARGS, doc_QDnsTlsAssociationRecord_usage},
    {sipName_value, meth_QDnsTlsAssociationRecord_value, METH_VARARGS, doc_QDnsTlsAssociationRecord_value}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QDnsTlsAssociationRecord[] = {
    {sipName_CertificateAuthorityConstrait, static_cast<int>(::QDnsTlsAssociationRecord::CertificateUsage::CertificateAuthorityConstrait)},
    {sipName_ServiceCertificateConstraint, static_cast<int>(::QDnsTlsAssociationRecord::CertificateUsage::ServiceCertificateConstraint)},
    {sipName_TrustAnchorAssertion, static_cast<int>(::QDnsTlsAssociationRecord::CertificateUsage::TrustAnchorAssertion)},
    {sipName_DomainIssuedCertificate, static_cast<int>(::QDnsTlsAssociationRecord::CertificateUsage::DomainIssuedCertificate)},
    {sipName_PrivateUse, static_cast<int>(::QDnsTlsAssociationRecord::CertificateUsage::PrivateUse)},
    {sipName_PKIX_TA, static_cast<int>(::QDnsTlsAssociationRecord::CertificateUsage::PKIX_TA)},
    {sipName_PKIX_EE, static_cast<int>(::QDnsTlsAssociationRecord::CertificateUsage::PKIX_EE)},
    {sipName_DANE_TA, static_cast<int>(::QDnsTlsAssociationRecord::CertificateUsage::DANE_TA)},
    {sipName_DANE_EE, static_cast<int>(::QDnsTlsAssociationRecord::CertificateUsage::DANE_EE)},
    {sipName_PrivCert, static_cast<int>(::QDnsTlsAssociationRecord::CertificateUsage::PrivCert)},
    {sipName_Exact, static_cast<int>(::QDnsTlsAssociationRecord::MatchingType::Exact)},
    {sipName_Sha256, static_cast<int>(::QDnsTlsAssociationRecord::MatchingType::Sha256)},
    {sipName_Sha512, static_cast<int>(::QDnsTlsAssociationRecord::MatchingType::Sha512)},
    {sipName_PrivateUse, static_cast<int>(::QDnsTlsAssociationRecord::MatchingType::PrivateUse)},
    {sipName_PrivMatch, static_cast<int>(::QDnsTlsAssociationRecord::MatchingType::PrivMatch)},
    {sipName_FullCertificate, static_cast<int>(::QDnsTlsAssociationRecord::Selector::FullCertificate)},
    {sipName_SubjectPublicKeyInfo, static_cast<int>(::QDnsTlsAssociationRecord::Selector::SubjectPublicKeyInfo)},
    {sipName_PrivateUse, static_cast<int>(::QDnsTlsAssociationRecord::Selector::PrivateUse)},
    {sipName_Cert, static_cast<int>(::QDnsTlsAssociationRecord::Selector::Cert)},
    {sipName_SPKI, static_cast<int>(::QDnsTlsAssociationRecord::Selector::SPKI)},
    {sipName_PrivSel, static_cast<int>(::QDnsTlsAssociationRecord::Selector::PrivSel)},
    {0, 0}
};

PyDoc_STRVAR(doc_QDnsTlsAssociationRecord, "\1QDnsTlsAssociationRecord()\n"
"QDnsTlsAssociationRecord(other: QDnsTlsAssociationRecord)");


sipClassTypeDef sipTypeDef_QtNetwork_QDnsTlsAssociationRecord = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDnsTlsAssociationRecord,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QDnsTlsAssociationRecord,
        {0, 0, 1},
        7, methods_QDnsTlsAssociationRecord,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QDnsTlsAssociationRecord, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDnsTlsAssociationRecord,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QDnsTlsAssociationRecord,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDnsTlsAssociationRecord,
    assign_QDnsTlsAssociationRecord,
    array_QDnsTlsAssociationRecord,
    copy_QDnsTlsAssociationRecord,
    release_QDnsTlsAssociationRecord,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QDnsTlsAssociationRecord,
    sizeof (::QDnsTlsAssociationRecord),
};
