/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 127 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 31 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQQuaternionAxes.cpp"

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 111 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 37 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQQuaternionAxes.cpp"


/* Call the instance's destructor. */
extern "C" {static void release_QQuaternion_Axes(void *, int);}
static void release_QQuaternion_Axes(void *sipCppV, int)
{
    delete reinterpret_cast< ::QQuaternion::Axes *>(sipCppV);
}


extern "C" {static void *array_QQuaternion_Axes(Py_ssize_t);}
static void *array_QQuaternion_Axes(Py_ssize_t sipNrElem)
{
    return new ::QQuaternion::Axes[sipNrElem];
}


extern "C" {static void array_delete_QQuaternion_Axes(void *);}
static void array_delete_QQuaternion_Axes(void *sipCpp)
{
    delete[] reinterpret_cast< ::QQuaternion::Axes *>(sipCpp);
}


extern "C" {static void assign_QQuaternion_Axes(void *, Py_ssize_t, void *);}
static void assign_QQuaternion_Axes(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QQuaternion::Axes *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QQuaternion::Axes *>(sipSrc);
}


extern "C" {static void *copy_QQuaternion_Axes(const void *, Py_ssize_t);}
static void *copy_QQuaternion_Axes(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QQuaternion::Axes(reinterpret_cast<const ::QQuaternion::Axes *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QQuaternion_Axes(sipSimpleWrapper *);}
static void dealloc_QQuaternion_Axes(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuaternion_Axes(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QQuaternion_Axes(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuaternion_Axes(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QQuaternion::Axes *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QQuaternion::Axes();

            return sipCpp;
        }
    }

    {
        const ::QQuaternion::Axes* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QQuaternion_Axes, &a0))
        {
            sipCpp = new ::QQuaternion::Axes(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static PyObject *varget_QQuaternion_Axes_x(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuaternion_Axes_x(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
    ::QQuaternion::Axis*sipVal;
    ::QQuaternion::Axes *sipCpp = reinterpret_cast< ::QQuaternion::Axes *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -12);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->x;

    sipPy = sipConvertFromType(sipVal, sipType_QQuaternion_Axis, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -11, sipPySelf);
        sipKeepReference(sipPySelf, -12, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QQuaternion_Axes_x(void *, PyObject *, PyObject *);}
static int varset_QQuaternion_Axes_x(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QQuaternion::Axis*sipVal;
    ::QQuaternion::Axes *sipCpp = reinterpret_cast< ::QQuaternion::Axes *>(sipSelf);

    int sipIsErr = 0;
    sipVal = reinterpret_cast< ::QQuaternion::Axis *>(sipForceConvertToType(sipPy, sipType_QQuaternion_Axis, SIP_NULLPTR, SIP_NOT_NONE, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->x = *sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QQuaternion_Axes_y(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuaternion_Axes_y(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
    ::QQuaternion::Axis*sipVal;
    ::QQuaternion::Axes *sipCpp = reinterpret_cast< ::QQuaternion::Axes *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -14);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->y;

    sipPy = sipConvertFromType(sipVal, sipType_QQuaternion_Axis, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -13, sipPySelf);
        sipKeepReference(sipPySelf, -14, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QQuaternion_Axes_y(void *, PyObject *, PyObject *);}
static int varset_QQuaternion_Axes_y(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QQuaternion::Axis*sipVal;
    ::QQuaternion::Axes *sipCpp = reinterpret_cast< ::QQuaternion::Axes *>(sipSelf);

    int sipIsErr = 0;
    sipVal = reinterpret_cast< ::QQuaternion::Axis *>(sipForceConvertToType(sipPy, sipType_QQuaternion_Axis, SIP_NULLPTR, SIP_NOT_NONE, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->y = *sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QQuaternion_Axes_z(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuaternion_Axes_z(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
    ::QQuaternion::Axis*sipVal;
    ::QQuaternion::Axes *sipCpp = reinterpret_cast< ::QQuaternion::Axes *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -16);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->z;

    sipPy = sipConvertFromType(sipVal, sipType_QQuaternion_Axis, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -15, sipPySelf);
        sipKeepReference(sipPySelf, -16, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QQuaternion_Axes_z(void *, PyObject *, PyObject *);}
static int varset_QQuaternion_Axes_z(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QQuaternion::Axis*sipVal;
    ::QQuaternion::Axes *sipCpp = reinterpret_cast< ::QQuaternion::Axes *>(sipSelf);

    int sipIsErr = 0;
    sipVal = reinterpret_cast< ::QQuaternion::Axis *>(sipForceConvertToType(sipPy, sipType_QQuaternion_Axis, SIP_NULLPTR, SIP_NOT_NONE, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->z = *sipVal;

    return 0;
}

sipVariableDef variables_QQuaternion_Axes[] = {
    {InstanceVariable, sipName_x, (PyMethodDef *)varget_QQuaternion_Axes_x, (PyMethodDef *)varset_QQuaternion_Axes_x, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_y, (PyMethodDef *)varget_QQuaternion_Axes_y, (PyMethodDef *)varset_QQuaternion_Axes_y, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_z, (PyMethodDef *)varget_QQuaternion_Axes_z, (PyMethodDef *)varset_QQuaternion_Axes_z, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QQuaternion_Axes, "\1QQuaternion.Axes()\n"
"QQuaternion.Axes(a0: QQuaternion.Axes)");


sipClassTypeDef sipTypeDef_QtGui_QQuaternion_Axes = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuaternion__Axes,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_Axes,
        {251, 255, 0},
        0, SIP_NULLPTR,
        3, variables_QQuaternion_Axes,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuaternion_Axes,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQuaternion_Axes,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuaternion_Axes,
    assign_QQuaternion_Axes,
    array_QQuaternion_Axes,
    copy_QQuaternion_Axes,
    release_QQuaternion_Axes,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QQuaternion_Axes,
    sizeof (::QQuaternion::Axes),
};
