/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNfc.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldmanager.sip"
#include <qnearfieldmanager.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNfc/qnearfieldtarget.sip"
#include <qnearfieldtarget.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNfc/sipQtNfcQNearFieldManager.cpp"


class sipQNearFieldManager : public ::QNearFieldManager
{
public:
    sipQNearFieldManager(::QObject*);
    virtual ~sipQNearFieldManager();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQNearFieldManager(const sipQNearFieldManager &);
    sipQNearFieldManager &operator = (const sipQNearFieldManager &);

    char sipPyMethods[7];
};

sipQNearFieldManager::sipQNearFieldManager(::QObject*a0): ::QNearFieldManager(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQNearFieldManager::~sipQNearFieldManager()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQNearFieldManager::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtNfc_qt_metaobject(sipPySelf, sipType_QNearFieldManager);

    return ::QNearFieldManager::metaObject();
}

int sipQNearFieldManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QNearFieldManager::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtNfc_qt_metacall(sipPySelf, sipType_QNearFieldManager, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQNearFieldManager::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtNfc_qt_metacast(sipPySelf, sipType_QNearFieldManager, _clname, &sipCpp) ? sipCpp : ::QNearFieldManager::qt_metacast(_clname));
}

bool sipQNearFieldManager::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QNearFieldManager::event(a0);

    extern bool sipVH_QtNfc_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtNfc_5(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQNearFieldManager::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QNearFieldManager::eventFilter(a0, a1);

    extern bool sipVH_QtNfc_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtNfc_4(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQNearFieldManager::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QNearFieldManager::timerEvent(a0);
        return;
    }

    extern void sipVH_QtNfc_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtNfc_3(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNearFieldManager::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QNearFieldManager::childEvent(a0);
        return;
    }

    extern void sipVH_QtNfc_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtNfc_2(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNearFieldManager::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QNearFieldManager::customEvent(a0);
        return;
    }

    extern void sipVH_QtNfc_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtNfc_1(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNearFieldManager::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QNearFieldManager::connectNotify(a0);
        return;
    }

    extern void sipVH_QtNfc_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNfc_0(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNearFieldManager::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QNearFieldManager::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtNfc_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNfc_0(sipGILState, sipImportedVirtErrorHandlers_QtNfc_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QNearFieldManager_startTargetDetection, "startTargetDetection(self, accessMethod: QNearFieldTarget.AccessMethod) -> bool");

extern "C" {static PyObject *meth_QNearFieldManager_startTargetDetection(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldManager_startTargetDetection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNearFieldTarget::AccessMethod a0;
        ::QNearFieldManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QNearFieldManager, &sipCpp, sipType_QNearFieldTarget_AccessMethod, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->startTargetDetection(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldManager, sipName_startTargetDetection, doc_QNearFieldManager_startTargetDetection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldManager_stopTargetDetection, "stopTargetDetection(self, errorMessage: str|None = '')");

extern "C" {static PyObject *meth_QNearFieldManager_stopTargetDetection(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QNearFieldManager_stopTargetDetection(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;
        ::QNearFieldManager *sipCpp;

        static const char *sipKwdList[] = {
            sipName_errorMessage,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QNearFieldManager, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->stopTargetDetection(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldManager, sipName_stopTargetDetection, doc_QNearFieldManager_stopTargetDetection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldManager_isSupported, "isSupported(self, accessMethod: QNearFieldTarget.AccessMethod = QNearFieldTarget.AnyAccess) -> bool");

extern "C" {static PyObject *meth_QNearFieldManager_isSupported(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QNearFieldManager_isSupported(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNearFieldTarget::AccessMethod a0 = QNearFieldTarget::AnyAccess;
        const ::QNearFieldManager *sipCpp;

        static const char *sipKwdList[] = {
            sipName_accessMethod,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QNearFieldManager, &sipCpp, sipType_QNearFieldTarget_AccessMethod, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldManager, sipName_isSupported, doc_QNearFieldManager_isSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldManager_isEnabled, "isEnabled(self) -> bool");

extern "C" {static PyObject *meth_QNearFieldManager_isEnabled(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldManager_isEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNearFieldManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNearFieldManager, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldManager, sipName_isEnabled, doc_QNearFieldManager_isEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNearFieldManager_setUserInformation, "setUserInformation(self, message: str|None)");

extern "C" {static PyObject *meth_QNearFieldManager_setUserInformation(PyObject *, PyObject *);}
static PyObject *meth_QNearFieldManager_setUserInformation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QNearFieldManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNearFieldManager, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setUserInformation(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNearFieldManager, sipName_setUserInformation, doc_QNearFieldManager_setUserInformation);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QNearFieldManager(void *, const sipTypeDef *);}
static void *cast_QNearFieldManager(void *sipCppV, const sipTypeDef *targetType)
{
    ::QNearFieldManager *sipCpp = reinterpret_cast< ::QNearFieldManager *>(sipCppV);

    if (targetType == sipType_QNearFieldManager)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNearFieldManager(void *, int);}
static void release_QNearFieldManager(void *sipCppV, int)
{
    ::QNearFieldManager *sipCpp = reinterpret_cast< ::QNearFieldManager *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QNearFieldManager(Py_ssize_t);}
static void *array_QNearFieldManager(Py_ssize_t sipNrElem)
{
    return new ::QNearFieldManager[sipNrElem];
}


extern "C" {static void array_delete_QNearFieldManager(void *);}
static void array_delete_QNearFieldManager(void *sipCpp)
{
    delete[] reinterpret_cast< ::QNearFieldManager *>(sipCpp);
}


extern "C" {static void dealloc_QNearFieldManager(sipSimpleWrapper *);}
static void dealloc_QNearFieldManager(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQNearFieldManager *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNearFieldManager(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QNearFieldManager(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QNearFieldManager(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQNearFieldManager *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQNearFieldManager(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QNearFieldManager[] = {{4, 0, 1}};


static PyMethodDef methods_QNearFieldManager[] = {
    {sipName_isEnabled, meth_QNearFieldManager_isEnabled, METH_VARARGS, doc_QNearFieldManager_isEnabled},
    {sipName_isSupported, SIP_MLMETH_CAST(meth_QNearFieldManager_isSupported), METH_VARARGS|METH_KEYWORDS, doc_QNearFieldManager_isSupported},
    {sipName_setUserInformation, meth_QNearFieldManager_setUserInformation, METH_VARARGS, doc_QNearFieldManager_setUserInformation},
    {sipName_startTargetDetection, meth_QNearFieldManager_startTargetDetection, METH_VARARGS, doc_QNearFieldManager_startTargetDetection},
    {sipName_stopTargetDetection, SIP_MLMETH_CAST(meth_QNearFieldManager_stopTargetDetection), METH_VARARGS|METH_KEYWORDS, doc_QNearFieldManager_stopTargetDetection}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QNearFieldManager[] = {
    {sipName_Offline, static_cast<int>(::QNearFieldManager::AdapterState::Offline)},
    {sipName_TurningOn, static_cast<int>(::QNearFieldManager::AdapterState::TurningOn)},
    {sipName_Online, static_cast<int>(::QNearFieldManager::AdapterState::Online)},
    {sipName_TurningOff, static_cast<int>(::QNearFieldManager::AdapterState::TurningOff)},
    {0, 0}
};

PyDoc_STRVAR(doc_QNearFieldManager, "\1QNearFieldManager(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QNearFieldManager[] = {
    {"adapterStateChanged(QNearFieldManager::AdapterState)", "\1adapterStateChanged(self, state: QNearFieldManager.AdapterState)", SIP_NULLPTR, SIP_NULLPTR},
    {"targetDetectionStopped()", "\1targetDetectionStopped(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"targetLost(QNearFieldTarget*)", "\1targetLost(self, target: QNearFieldTarget|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"targetDetected(QNearFieldTarget*)", "\1targetDetected(self, target: QNearFieldTarget|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QNearFieldManager = {
    &::QNearFieldManager::staticMetaObject,
    signals_QNearFieldManager,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNfc_QNearFieldManager = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNearFieldManager,
        SIP_NULLPTR,
        &plugin_QNearFieldManager,
    },
    {
        sipNameNr_QNearFieldManager,
        {0, 0, 1},
        5, methods_QNearFieldManager,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QNearFieldManager, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QNearFieldManager,
    -1,
    -1,
    supers_QNearFieldManager,
    SIP_NULLPTR,
    init_type_QNearFieldManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QNearFieldManager,
    SIP_NULLPTR,
    array_QNearFieldManager,
    SIP_NULLPTR,
    release_QNearFieldManager,
    cast_QNearFieldManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QNearFieldManager,
    sizeof (::QNearFieldManager),
};
