/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtSqlAPI_H
#define _QtSqlAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QSqlRelationalTableModel__JoinMode 0
#define sipName_QSqlRelationalTableModel__JoinMode &sipStrings_QtSql[0]
#define sipNameNr_QSql__NumericalPrecisionPolicy 35
#define sipName_QSql__NumericalPrecisionPolicy &sipStrings_QtSql[35]
#define sipNameNr_QSqlDriver__NotificationSource 66
#define sipName_QSqlDriver__NotificationSource &sipStrings_QtSql[66]
#define sipNameNr_QSqlQuery__BatchExecutionMode 97
#define sipName_QSqlQuery__BatchExecutionMode &sipStrings_QtSql[97]
#define sipNameNr_QSqlTableModel__EditStrategy 127
#define sipName_QSqlTableModel__EditStrategy &sipStrings_QtSql[127]
#define sipNameNr_156 156
#define sipName_156 &sipStrings_QtSql[156]
#define sipNameNr_setNumericalPrecisionPolicy 184
#define sipName_setNumericalPrecisionPolicy &sipStrings_QtSql[184]
#define sipNameNr_setPositionalBindingEnabled 212
#define sipName_setPositionalBindingEnabled &sipStrings_QtSql[212]
#define sipNameNr_unsubscribeFromNotification 240
#define sipName_unsubscribeFromNotification &sipStrings_QtSql[240]
#define sipNameNr_QSqlDriver__IdentifierType 268
#define sipName_QSqlDriver__IdentifierType &sipStrings_QtSql[268]
#define sipNameNr_isPositionalBindingEnabled 295
#define sipName_isPositionalBindingEnabled &sipStrings_QtSql[295]
#define sipNameNr_QSqlDriver__DriverFeature 322
#define sipName_QSqlDriver__DriverFeature &sipStrings_QtSql[322]
#define sipNameNr_QSqlDriver__StatementType 348
#define sipName_QSqlDriver__StatementType &sipStrings_QtSql[348]
#define sipNameNr_QSqlField__RequiredStatus 374
#define sipName_QSqlField__RequiredStatus &sipStrings_QtSql[374]
#define sipNameNr_QSqlResult__BindingSyntax 400
#define sipName_QSqlResult__BindingSyntax &sipStrings_QtSql[400]
#define sipNameNr_subscribedToNotifications 426
#define sipName_subscribedToNotifications &sipStrings_QtSql[426]
#define sipNameNr_NumericalPrecisionPolicy 41
#define sipName_NumericalPrecisionPolicy &sipStrings_QtSql[41]
#define sipNameNr_QSqlRelationalTableModel 452
#define sipName_QSqlRelationalTableModel &sipStrings_QtSql[452]
#define sipNameNr_numericalPrecisionPolicy 477
#define sipName_numericalPrecisionPolicy &sipStrings_QtSql[477]
#define sipNameNr_PyQt6_sip_simplewrapper 502
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtSql[502]
#define sipNameNr_maximumIdentifierLength 526
#define sipName_maximumIdentifierLength &sipStrings_QtSql[526]
#define sipNameNr_subscribeToNotification 550
#define sipName_subscribeToNotification &sipStrings_QtSql[550]
#define sipNameNr_PositionalPlaceholders 574
#define sipName_PositionalPlaceholders &sipStrings_QtSql[574]
#define sipNameNr_QSqlRelationalDelegate 597
#define sipName_QSqlRelationalDelegate &sipStrings_QtSql[597]
#define sipNameNr_QSqlDriverCreatorBase 620
#define sipName_QSqlDriverCreatorBase &sipStrings_QtSql[620]
#define sipNameNr_QSqlDriver__DbmsType 642
#define sipName_QSqlDriver__DbmsType &sipStrings_QtSql[642]
#define sipNameNr_QSqlError__ErrorType 663
#define sipName_QSqlError__ErrorType &sipStrings_QtSql[663]
#define sipNameNr_supportedDragActions 684
#define sipName_supportedDragActions &sipStrings_QtSql[684]
#define sipNameNr_supportedDropActions 705
#define sipName_supportedDropActions &sipStrings_QtSql[705]
#define sipNameNr_updateEditorGeometry 726
#define sipName_updateEditorGeometry &sipStrings_QtSql[726]
#define sipNameNr_LowPrecisionNumbers 747
#define sipName_LowPrecisionNumbers &sipStrings_QtSql[747]
#define sipNameNr_QSql__ParamTypeFlag 767
#define sipName_QSql__ParamTypeFlag &sipStrings_QtSql[767]
#define sipNameNr_isIdentifierEscaped 787
#define sipName_isIdentifierEscaped &sipStrings_QtSql[787]
#define sipNameNr_rollbackTransaction 807
#define sipName_rollbackTransaction &sipStrings_QtSql[807]
#define sipNameNr_BatchExecutionMode 108
#define sipName_BatchExecutionMode &sipStrings_QtSql[108]
#define sipNameNr_EventNotifications 827
#define sipName_EventNotifications &sipStrings_QtSql[827]
#define sipNameNr_LowPrecisionDouble 846
#define sipName_LowPrecisionDouble &sipStrings_QtSql[846]
#define sipNameNr_MultipleResultSets 865
#define sipName_MultipleResultSets &sipStrings_QtSql[865]
#define sipNameNr_NotificationSource 78
#define sipName_NotificationSource &sipStrings_QtSql[78]
#define sipNameNr_beginInsertColumns 884
#define sipName_beginInsertColumns &sipStrings_QtSql[884]
#define sipNameNr_beginRemoveColumns 903
#define sipName_beginRemoveColumns &sipStrings_QtSql[903]
#define sipNameNr_deleteRowFromTable 922
#define sipName_deleteRowFromTable &sipStrings_QtSql[922]
#define sipNameNr_insertRowIntoTable 941
#define sipName_insertRowIntoTable &sipStrings_QtSql[941]
#define sipNameNr_LowPrecisionInt32 960
#define sipName_LowPrecisionInt32 &sipStrings_QtSql[960]
#define sipNameNr_LowPrecisionInt64 978
#define sipName_LowPrecisionInt64 &sipStrings_QtSql[978]
#define sipNameNr_NamedPlaceholders 996
#define sipName_NamedPlaceholders &sipStrings_QtSql[996]
#define sipNameNr_PositionalBinding 1014
#define sipName_PositionalBinding &sipStrings_QtSql[1014]
#define sipNameNr_commitTransaction 1032
#define sipName_commitTransaction &sipStrings_QtSql[1032]
#define sipNameNr_isDriverAvailable 1050
#define sipName_isDriverAvailable &sipStrings_QtSql[1050]
#define sipNameNr_registerSqlDriver 1068
#define sipName_registerSqlDriver &sipStrings_QtSql[1068]
#define sipNameNr_resetInternalData 1086
#define sipName_resetInternalData &sipStrings_QtSql[1086]
#define sipNameNr_setConnectOptions 1104
#define sipName_setConnectOptions &sipStrings_QtSql[1104]
#define sipNameNr_setRequiredStatus 1122
#define sipName_setRequiredStatus &sipStrings_QtSql[1122]
#define sipNameNr_TransactionError 1140
#define sipName_TransactionError &sipStrings_QtSql[1140]
#define sipNameNr_beginTransaction 1157
#define sipName_beginTransaction &sipStrings_QtSql[1157]
#define sipNameNr_disconnectNotify 1174
#define sipName_disconnectNotify &sipStrings_QtSql[1174]
#define sipNameNr_endInsertColumns 1191
#define sipName_endInsertColumns &sipStrings_QtSql[1191]
#define sipNameNr_endRemoveColumns 1208
#define sipName_endRemoveColumns &sipStrings_QtSql[1208]
#define sipNameNr_escapeIdentifier 1225
#define sipName_escapeIdentifier &sipStrings_QtSql[1225]
#define sipNameNr_updateRowInTable 1242
#define sipName_updateRowInTable &sipStrings_QtSql[1242]
#define sipNameNr_BatchOperations 1259
#define sipName_BatchOperations &sipStrings_QtSql[1259]
#define sipNameNr_ConnectionError 1275
#define sipName_ConnectionError &sipStrings_QtSql[1275]
#define sipNameNr_DeleteStatement 1291
#define sipName_DeleteStatement &sipStrings_QtSql[1291]
#define sipNameNr_InsertStatement 1307
#define sipName_InsertStatement &sipStrings_QtSql[1307]
#define sipNameNr_PreparedQueries 1323
#define sipName_PreparedQueries &sipStrings_QtSql[1323]
#define sipNameNr_QSql__TableType 1339
#define sipName_QSql__TableType &sipStrings_QtSql[1339]
#define sipNameNr_SelectStatement 1355
#define sipName_SelectStatement &sipStrings_QtSql[1355]
#define sipNameNr_UpdateStatement 1371
#define sipName_UpdateStatement &sipStrings_QtSql[1371]
#define sipNameNr_ValuesAsColumns 1387
#define sipName_ValuesAsColumns &sipStrings_QtSql[1387]
#define sipNameNr_beginInsertRows 1403
#define sipName_beginInsertRows &sipStrings_QtSql[1403]
#define sipNameNr_beginRemoveRows 1419
#define sipName_beginRemoveRows &sipStrings_QtSql[1419]
#define sipNameNr_beginResetModel 1435
#define sipName_beginResetModel &sipStrings_QtSql[1435]
#define sipNameNr_boundValueCount 1451
#define sipName_boundValueCount &sipStrings_QtSql[1451]
#define sipNameNr_boundValueNames 1467
#define sipName_boundValueNames &sipStrings_QtSql[1467]
#define sipNameNr_canDropMimeData 1483
#define sipName_canDropMimeData &sipStrings_QtSql[1483]
#define sipNameNr_connectionNames 1499
#define sipName_connectionNames &sipStrings_QtSql[1499]
#define sipNameNr_initStyleOption 1515
#define sipName_initStyleOption &sipStrings_QtSql[1515]
#define sipNameNr_nativeErrorCode 1531
#define sipName_nativeErrorCode &sipStrings_QtSql[1531]
#define sipNameNr_numRowsAffected 1547
#define sipName_numRowsAffected &sipStrings_QtSql[1547]
#define sipNameNr_selectStatement 1563
#define sipName_selectStatement &sipStrings_QtSql[1563]
#define sipNameNr_setDatabaseName 1579
#define sipName_setDatabaseName &sipStrings_QtSql[1579]
#define sipNameNr_setDefaultValue 1595
#define sipName_setDefaultValue &sipStrings_QtSql[1595]
#define sipNameNr_setEditStrategy 1611
#define sipName_setEditStrategy &sipStrings_QtSql[1611]
#define sipNameNr_stripDelimiters 1627
#define sipName_stripDelimiters &sipStrings_QtSql[1627]
#define sipNameNr_BeforeFirstRow 1643
#define sipName_BeforeFirstRow &sipStrings_QtSql[1643]
#define sipNameNr_IdentifierType 280
#define sipName_IdentifierType &sipStrings_QtSql[280]
#define sipNameNr_OnManualSubmit 1658
#define sipName_OnManualSubmit &sipStrings_QtSql[1658]
#define sipNameNr_QSql__Location 1673
#define sipName_QSql__Location &sipStrings_QtSql[1673]
#define sipNameNr_QSqlQueryModel 1688
#define sipName_QSqlQueryModel &sipStrings_QtSql[1688]
#define sipNameNr_QSqlTableModel 1703
#define sipName_QSqlTableModel &sipStrings_QtSql[1703]
#define sipNameNr_RequiredStatus 385
#define sipName_RequiredStatus &sipStrings_QtSql[385]
#define sipNameNr_StatementError 1718
#define sipName_StatementError &sipStrings_QtSql[1718]
#define sipNameNr_WhereStatement 1733
#define sipName_WhereStatement &sipStrings_QtSql[1733]
#define sipNameNr_boundValueName 1748
#define sipName_boundValueName &sipStrings_QtSql[1748]
#define sipNameNr_connectOptions 1763
#define sipName_connectOptions &sipStrings_QtSql[1763]
#define sipNameNr_connectionName 1778
#define sipName_connectionName &sipStrings_QtSql[1778]
#define sipNameNr_removeDatabase 1793
#define sipName_removeDatabase &sipStrings_QtSql[1793]
#define sipNameNr_requiredStatus 1808
#define sipName_requiredStatus &sipStrings_QtSql[1808]
#define sipNameNr_setForwardOnly 1823
#define sipName_setForwardOnly &sipStrings_QtSql[1823]
#define sipNameNr_BindingSyntax 412
#define sipName_BindingSyntax &sipStrings_QtSql[412]
#define sipNameNr_DriverFeature 334
#define sipName_DriverFeature &sipStrings_QtSql[334]
#define sipNameNr_HighPrecision 1838
#define sipName_HighPrecision &sipStrings_QtSql[1838]
#define sipNameNr_OnFieldChange 1852
#define sipName_OnFieldChange &sipStrings_QtSql[1852]
#define sipNameNr_ParamTypeFlag 773
#define sipName_ParamTypeFlag &sipStrings_QtSql[773]
#define sipNameNr_SimpleLocking 1866
#define sipName_SimpleLocking &sipStrings_QtSql[1866]
#define sipNameNr_StatementType 360
#define sipName_StatementType &sipStrings_QtSql[360]
#define sipNameNr_UnknownSource 1880
#define sipName_UnknownSource &sipStrings_QtSql[1880]
#define sipNameNr_bindValueType 1894
#define sipName_bindValueType &sipStrings_QtSql[1894]
#define sipNameNr_bindingSyntax 1908
#define sipName_bindingSyntax &sipStrings_QtSql[1908]
#define sipNameNr_clearItemData 1922
#define sipName_clearItemData &sipStrings_QtSql[1922]
#define sipNameNr_cloneDatabase 1936
#define sipName_cloneDatabase &sipStrings_QtSql[1936]
#define sipNameNr_connectNotify 1177
#define sipName_connectNotify &sipStrings_QtSql[1177]
#define sipNameNr_destroyEditor 1950
#define sipName_destroyEditor &sipStrings_QtSql[1950]
#define sipNameNr_displayColumn 1964
#define sipName_displayColumn &sipStrings_QtSql[1964]
#define sipNameNr_endInsertRows 1978
#define sipName_endInsertRows &sipStrings_QtSql[1978]
#define sipNameNr_endRemoveRows 1992
#define sipName_endRemoveRows &sipStrings_QtSql[1992]
#define sipNameNr_endResetModel 2006
#define sipName_endResetModel &sipStrings_QtSql[2006]
#define sipNameNr_executedQuery 2020
#define sipName_executedQuery &sipStrings_QtSql[2020]
#define sipNameNr_fetchPrevious 2034
#define sipName_fetchPrevious &sipStrings_QtSql[2034]
#define sipNameNr_insertColumns 2048
#define sipName_insertColumns &sipStrings_QtSql[2048]
#define sipNameNr_isForwardOnly 2062
#define sipName_isForwardOnly &sipStrings_QtSql[2062]
#define sipNameNr_orderByClause 2076
#define sipName_orderByClause &sipStrings_QtSql[2076]
#define sipNameNr_primaryValues 2090
#define sipName_primaryValues &sipStrings_QtSql[2090]
#define sipNameNr_relationModel 2104
#define sipName_relationModel &sipStrings_QtSql[2104]
#define sipNameNr_removeColumns 2118
#define sipName_removeColumns &sipStrings_QtSql[2118]
#define sipNameNr_setCursorName 2132
#define sipName_setCursorName &sipStrings_QtSql[2132]
#define sipNameNr_setDescending 2146
#define sipName_setDescending &sipStrings_QtSql[2146]
#define sipNameNr_setEditorData 2160
#define sipName_setEditorData &sipStrings_QtSql[2160]
#define sipNameNr_setHeaderData 2174
#define sipName_setHeaderData &sipStrings_QtSql[2174]
#define sipNameNr_setPrimaryKey 2188
#define sipName_setPrimaryKey &sipStrings_QtSql[2188]
#define sipNameNr_AfterLastRow 2202
#define sipName_AfterLastRow &sipStrings_QtSql[2202]
#define sipNameNr_EditStrategy 143
#define sipName_EditStrategy &sipStrings_QtSql[143]
#define sipNameNr_LastInsertId 2215
#define sipName_LastInsertId &sipStrings_QtSql[2215]
#define sipNameNr_NamedBinding 2228
#define sipName_NamedBinding &sipStrings_QtSql[2228]
#define sipNameNr_QSqlDatabase 2241
#define sipName_QSqlDatabase &sipStrings_QtSql[2241]
#define sipNameNr_QSqlRelation 2254
#define sipName_QSqlRelation &sipStrings_QtSql[2254]
#define sipNameNr_SystemTables 2267
#define sipName_SystemTables &sipStrings_QtSql[2267]
#define sipNameNr_Transactions 2280
#define sipName_Transactions &sipStrings_QtSql[2280]
#define sipNameNr_UnknownError 2293
#define sipName_UnknownError &sipStrings_QtSql[2293]
#define sipNameNr_ValuesAsRows 2306
#define sipName_ValuesAsRows &sipStrings_QtSql[2306]
#define sipNameNr_addBindValue 2319
#define sipName_addBindValue &sipStrings_QtSql[2319]
#define sipNameNr_beforeDelete 2332
#define sipName_beforeDelete &sipStrings_QtSql[2332]
#define sipNameNr_beforeInsert 2345
#define sipName_beforeInsert &sipStrings_QtSql[2345]
#define sipNameNr_beforeUpdate 2358
#define sipName_beforeUpdate &sipStrings_QtSql[2358]
#define sipNameNr_canFetchMore 2371
#define sipName_canFetchMore &sipStrings_QtSql[2371]
#define sipNameNr_createEditor 2384
#define sipName_createEditor &sipStrings_QtSql[2384]
#define sipNameNr_createObject 2397
#define sipName_createObject &sipStrings_QtSql[2397]
#define sipNameNr_createResult 2410
#define sipName_createResult &sipStrings_QtSql[2410]
#define sipNameNr_databaseName 2423
#define sipName_databaseName &sipStrings_QtSql[2423]
#define sipNameNr_databaseText 2436
#define sipName_databaseText &sipStrings_QtSql[2436]
#define sipNameNr_defaultValue 2449
#define sipName_defaultValue &sipStrings_QtSql[2449]
#define sipNameNr_dropMimeData 2462
#define sipName_dropMimeData &sipStrings_QtSql[2462]
#define sipNameNr_editStrategy 2475
#define sipName_editStrategy &sipStrings_QtSql[2475]
#define sipNameNr_hasOutValues 2488
#define sipName_hasOutValues &sipStrings_QtSql[2488]
#define sipNameNr_indexInQuery 2501
#define sipName_indexInQuery &sipStrings_QtSql[2501]
#define sipNameNr_insertRecord 2514
#define sipName_insertRecord &sipStrings_QtSql[2514]
#define sipNameNr_isDescending 2527
#define sipName_isDescending &sipStrings_QtSql[2527]
#define sipNameNr_lastInsertId 2540
#define sipName_lastInsertId &sipStrings_QtSql[2540]
#define sipNameNr_moveToThread 2553
#define sipName_moveToThread &sipStrings_QtSql[2553]
#define sipNameNr_notification 2566
#define sipName_notification &sipStrings_QtSql[2566]
#define sipNameNr_primaryIndex 2579
#define sipName_primaryIndex &sipStrings_QtSql[2579]
#define sipNameNr_setAutoValue 2592
#define sipName_setAutoValue &sipStrings_QtSql[2592]
#define sipNameNr_setGenerated 2605
#define sipName_setGenerated &sipStrings_QtSql[2605]
#define sipNameNr_setLastError 2618
#define sipName_setLastError &sipStrings_QtSql[2618]
#define sipNameNr_setModelData 2631
#define sipName_setModelData &sipStrings_QtSql[2631]
#define sipNameNr_setOpenError 2644
#define sipName_setOpenError &sipStrings_QtSql[2644]
#define sipNameNr_setPrecision 2657
#define sipName_setPrecision &sipStrings_QtSql[2657]
#define sipNameNr_setTableName 2670
#define sipName_setTableName &sipStrings_QtSql[2670]
#define sipNameNr_sqlStatement 2683
#define sipName_sqlStatement &sipStrings_QtSql[2683]
#define sipNameNr_FinishQuery 2696
#define sipName_FinishQuery &sipStrings_QtSql[2696]
#define sipNameNr_MSSqlServer 2708
#define sipName_MSSqlServer &sipStrings_QtSql[2708]
#define sipNameNr_MySqlServer 2720
#define sipName_MySqlServer &sipStrings_QtSql[2720]
#define sipNameNr_OnRowChange 2732
#define sipName_OnRowChange &sipStrings_QtSql[2732]
#define sipNameNr_OtherSource 2744
#define sipName_OtherSource &sipStrings_QtSql[2744]
#define sipNameNr_PyQt6_QtSql 2756
#define sipName_PyQt6_QtSql &sipStrings_QtSql[2756]
#define sipNameNr_UnknownDbms 2768
#define sipName_UnknownDbms &sipStrings_QtSql[2768]
#define sipNameNr_addDatabase 2780
#define sipName_addDatabase &sipStrings_QtSql[2780]
#define sipNameNr_boundValues 2792
#define sipName_boundValues &sipStrings_QtSql[2792]
#define sipNameNr_clearValues 2804
#define sipName_clearValues &sipStrings_QtSql[2804]
#define sipNameNr_columnCount 2816
#define sipName_columnCount &sipStrings_QtSql[2816]
#define sipNameNr_customEvent 2828
#define sipName_customEvent &sipStrings_QtSql[2828]
#define sipNameNr_displayText 2840
#define sipName_displayText &sipStrings_QtSql[2840]
#define sipNameNr_editorEvent 2852
#define sipName_editorEvent &sipStrings_QtSql[2852]
#define sipNameNr_eventFilter 2864
#define sipName_eventFilter &sipStrings_QtSql[2864]
#define sipNameNr_formatValue 2876
#define sipName_formatValue &sipStrings_QtSql[2876]
#define sipNameNr_hasChildren 2888
#define sipName_hasChildren &sipStrings_QtSql[2888]
#define sipNameNr_indexColumn 2900
#define sipName_indexColumn &sipStrings_QtSql[2900]
#define sipNameNr_isAutoValue 2912
#define sipName_isAutoValue &sipStrings_QtSql[2912]
#define sipNameNr_isGenerated 2924
#define sipName_isGenerated &sipStrings_QtSql[2924]
#define sipNameNr_isOpenError 2936
#define sipName_isOpenError &sipStrings_QtSql[2936]
#define sipNameNr_moveColumns 910
#define sipName_moveColumns &sipStrings_QtSql[910]
#define sipNameNr_primeInsert 2948
#define sipName_primeInsert &sipStrings_QtSql[2948]
#define sipNameNr_queryChange 2960
#define sipName_queryChange &sipStrings_QtSql[2960]
#define sipNameNr_savePrepare 2972
#define sipName_savePrepare &sipStrings_QtSql[2972]
#define sipNameNr_setHostName 2984
#define sipName_setHostName &sipStrings_QtSql[2984]
#define sipNameNr_setItemData 2996
#define sipName_setItemData &sipStrings_QtSql[2996]
#define sipNameNr_setJoinMode 3008
#define sipName_setJoinMode &sipStrings_QtSql[3008]
#define sipNameNr_setMetaType 3020
#define sipName_setMetaType &sipStrings_QtSql[3020]
#define sipNameNr_setPassword 3032
#define sipName_setPassword &sipStrings_QtSql[3032]
#define sipNameNr_setReadOnly 3044
#define sipName_setReadOnly &sipStrings_QtSql[3044]
#define sipNameNr_setRelation 3056
#define sipName_setRelation &sipStrings_QtSql[3056]
#define sipNameNr_setRequired 3068
#define sipName_setRequired &sipStrings_QtSql[3068]
#define sipNameNr_setUserName 3080
#define sipName_setUserName &sipStrings_QtSql[3080]
#define sipNameNr_transaction 3092
#define sipName_transaction &sipStrings_QtSql[3092]
#define sipNameNr_trimStrings 3104
#define sipName_trimStrings &sipStrings_QtSql[3104]
#define sipNameNr_PostgreSQL 3116
#define sipName_PostgreSQL &sipStrings_QtSql[3116]
#define sipNameNr_QSqlDriver 3127
#define sipName_QSqlDriver &sipStrings_QtSql[3127]
#define sipNameNr_QSqlRecord 3138
#define sipName_QSqlRecord &sipStrings_QtSql[3138]
#define sipNameNr_QSqlResult 3149
#define sipName_QSqlResult &sipStrings_QtSql[3149]
#define sipNameNr_SelfSource 3160
#define sipName_SelfSource &sipStrings_QtSql[3160]
#define sipNameNr_boundValue 3171
#define sipName_boundValue &sipStrings_QtSql[3171]
#define sipNameNr_childEvent 3182
#define sipName_childEvent &sipStrings_QtSql[3182]
#define sipNameNr_cursorName 3193
#define sipName_cursorName &sipStrings_QtSql[3193]
#define sipNameNr_driverName 3204
#define sipName_driverName &sipStrings_QtSql[3204]
#define sipNameNr_driverText 3215
#define sipName_driverText &sipStrings_QtSql[3215]
#define sipNameNr_fetchFirst 3226
#define sipName_fetchFirst &sipStrings_QtSql[3226]
#define sipNameNr_fieldIndex 3237
#define sipName_fieldIndex &sipStrings_QtSql[3237]
#define sipNameNr_hasFeature 3248
#define sipName_hasFeature &sipStrings_QtSql[3248]
#define sipNameNr_headerData 3259
#define sipName_headerData &sipStrings_QtSql[3259]
#define sipNameNr_insertRows 3270
#define sipName_insertRows &sipStrings_QtSql[3270]
#define sipNameNr_isReadOnly 3281
#define sipName_isReadOnly &sipStrings_QtSql[3281]
#define sipNameNr_nextResult 3292
#define sipName_nextResult &sipStrings_QtSql[3292]
#define sipNameNr_primaryKey 3303
#define sipName_primaryKey &sipStrings_QtSql[3303]
#define sipNameNr_removeRows 3314
#define sipName_removeRows &sipStrings_QtSql[3314]
#define sipNameNr_setSqlType 3325
#define sipName_setSqlType &sipStrings_QtSql[3325]
#define sipNameNr_timerEvent 3336
#define sipName_timerEvent &sipStrings_QtSql[3336]
#define sipNameNr_AllTables 3347
#define sipName_AllTables &sipStrings_QtSql[3347]
#define sipNameNr_ErrorType 674
#define sipName_ErrorType &sipStrings_QtSql[674]
#define sipNameNr_FieldName 3357
#define sipName_FieldName &sipStrings_QtSql[3357]
#define sipNameNr_InnerJoin 3367
#define sipName_InnerJoin &sipStrings_QtSql[3367]
#define sipNameNr_Interbase 3377
#define sipName_Interbase &sipStrings_QtSql[3377]
#define sipNameNr_QSqlError 3387
#define sipName_QSqlError &sipStrings_QtSql[3387]
#define sipNameNr_QSqlField 3397
#define sipName_QSqlField &sipStrings_QtSql[3397]
#define sipNameNr_QSqlIndex 3407
#define sipName_QSqlIndex &sipStrings_QtSql[3407]
#define sipNameNr_QSqlQuery 3417
#define sipName_QSqlQuery &sipStrings_QtSql[3417]
#define sipNameNr_QuerySize 3427
#define sipName_QuerySize &sipStrings_QtSql[3427]
#define sipNameNr_TableName 2673
#define sipName_TableName &sipStrings_QtSql[2673]
#define sipNameNr_TableType 1345
#define sipName_TableType &sipStrings_QtSql[1345]
#define sipNameNr_bindValue 3437
#define sipName_bindValue &sipStrings_QtSql[3437]
#define sipNameNr_errorCode 3447
#define sipName_errorCode &sipStrings_QtSql[3447]
#define sipNameNr_execBatch 3457
#define sipName_execBatch &sipStrings_QtSql[3457]
#define sipNameNr_fetchLast 3467
#define sipName_fetchLast &sipStrings_QtSql[3467]
#define sipNameNr_fetchMore 3477
#define sipName_fetchMore &sipStrings_QtSql[3477]
#define sipNameNr_fetchNext 3487
#define sipName_fetchNext &sipStrings_QtSql[3487]
#define sipNameNr_fieldName 3497
#define sipName_fieldName &sipStrings_QtSql[3497]
#define sipNameNr_helpEvent 3507
#define sipName_helpEvent &sipStrings_QtSql[3507]
#define sipNameNr_keyValues 3517
#define sipName_keyValues &sipStrings_QtSql[3517]
#define sipNameNr_lastError 3527
#define sipName_lastError &sipStrings_QtSql[3527]
#define sipNameNr_lastQuery 3537
#define sipName_lastQuery &sipStrings_QtSql[3537]
#define sipNameNr_mimeTypes 3547
#define sipName_mimeTypes &sipStrings_QtSql[3547]
#define sipNameNr_multiData 3557
#define sipName_multiData &sipStrings_QtSql[3557]
#define sipNameNr_precision 3567
#define sipName_precision &sipStrings_QtSql[3567]
#define sipNameNr_revertAll 3577
#define sipName_revertAll &sipStrings_QtSql[3577]
#define sipNameNr_revertRow 3587
#define sipName_revertRow &sipStrings_QtSql[3587]
#define sipNameNr_roleNames 3597
#define sipName_roleNames &sipStrings_QtSql[3597]
#define sipNameNr_selectRow 3607
#define sipName_selectRow &sipStrings_QtSql[3607]
#define sipNameNr_setActive 3617
#define sipName_setActive &sipStrings_QtSql[3617]
#define sipNameNr_setFilter 3627
#define sipName_setFilter &sipStrings_QtSql[3627]
#define sipNameNr_setLength 3637
#define sipName_setLength &sipStrings_QtSql[3637]
#define sipNameNr_setRecord 3647
#define sipName_setRecord &sipStrings_QtSql[3647]
#define sipNameNr_setSelect 3657
#define sipName_setSelect &sipStrings_QtSql[3657]
#define sipNameNr_submitAll 3667
#define sipName_submitAll &sipStrings_QtSql[3667]
#define sipNameNr_tableName 3677
#define sipName_tableName &sipStrings_QtSql[3677]
#define sipNameNr_DbmsType 654
#define sipName_DbmsType &sipStrings_QtSql[654]
#define sipNameNr_JoinMode 26
#define sipName_JoinMode &sipStrings_QtSql[26]
#define sipNameNr_LeftJoin 3687
#define sipName_LeftJoin &sipStrings_QtSql[3687]
#define sipNameNr_Location 1679
#define sipName_Location &sipStrings_QtSql[1679]
#define sipNameNr_MimerSQL 3696
#define sipName_MimerSQL &sipStrings_QtSql[3696]
#define sipNameNr_Optional 3705
#define sipName_Optional &sipStrings_QtSql[3705]
#define sipNameNr_Required 3071
#define sipName_Required &sipStrings_QtSql[3071]
#define sipNameNr_contains 3714
#define sipName_contains &sipStrings_QtSql[3714]
#define sipNameNr_database 3723
#define sipName_database &sipStrings_QtSql[3723]
#define sipNameNr_dbmsType 3732
#define sipName_dbmsType &sipStrings_QtSql[3732]
#define sipNameNr_hostName 3741
#define sipName_hostName &sipStrings_QtSql[3741]
#define sipNameNr_isActive 3750
#define sipName_isActive &sipStrings_QtSql[3750]
#define sipNameNr_isSelect 3759
#define sipName_isSelect &sipStrings_QtSql[3759]
#define sipNameNr_itemData 3768
#define sipName_itemData &sipStrings_QtSql[3768]
#define sipNameNr_metaType 3777
#define sipName_metaType &sipStrings_QtSql[3777]
#define sipNameNr_mimeData 3786
#define sipName_mimeData &sipStrings_QtSql[3786]
#define sipNameNr_moveRows 1426
#define sipName_moveRows &sipStrings_QtSql[1426]
#define sipNameNr_password 3795
#define sipName_password &sipStrings_QtSql[3795]
#define sipNameNr_previous 3804
#define sipName_previous &sipStrings_QtSql[3804]
#define sipNameNr_relation 3813
#define sipName_relation &sipStrings_QtSql[3813]
#define sipNameNr_relative 3822
#define sipName_relative &sipStrings_QtSql[3822]
#define sipNameNr_rollback 3831
#define sipName_rollback &sipStrings_QtSql[3831]
#define sipNameNr_rowCount 3840
#define sipName_rowCount &sipStrings_QtSql[3840]
#define sipNameNr_setQuery 3849
#define sipName_setQuery &sipStrings_QtSql[3849]
#define sipNameNr_setTable 3858
#define sipName_setTable &sipStrings_QtSql[3858]
#define sipNameNr_setValue 3867
#define sipName_setValue &sipStrings_QtSql[3867]
#define sipNameNr_sizeHint 3876
#define sipName_sizeHint &sipStrings_QtSql[3876]
#define sipNameNr_userName 3885
#define sipName_userName &sipStrings_QtSql[3885]
#define sipNameNr_NoError 3894
#define sipName_NoError &sipStrings_QtSql[3894]
#define sipNameNr_Unicode 3902
#define sipName_Unicode &sipStrings_QtSql[3902]
#define sipNameNr_Unknown 3910
#define sipName_Unknown &sipStrings_QtSql[3910]
#define sipNameNr___len__ 3918
#define sipName___len__ &sipStrings_QtSql[3918]
#define sipNameNr_drivers 3926
#define sipName_drivers &sipStrings_QtSql[3926]
#define sipNameNr_indexOf 3934
#define sipName_indexOf &sipStrings_QtSql[3934]
#define sipNameNr_isDirty 3942
#define sipName_isDirty &sipStrings_QtSql[3942]
#define sipNameNr_isEmpty 3950
#define sipName_isEmpty &sipStrings_QtSql[3950]
#define sipNameNr_isValid 3958
#define sipName_isValid &sipStrings_QtSql[3958]
#define sipNameNr_options 3966
#define sipName_options &sipStrings_QtSql[3966]
#define sipNameNr_prepare 3974
#define sipName_prepare &sipStrings_QtSql[3974]
#define sipNameNr_refresh 3982
#define sipName_refresh &sipStrings_QtSql[3982]
#define sipNameNr_replace 3990
#define sipName_replace &sipStrings_QtSql[3990]
#define sipNameNr_setData 3998
#define sipName_setData &sipStrings_QtSql[3998]
#define sipNameNr_setName 4006
#define sipName_setName &sipStrings_QtSql[4006]
#define sipNameNr_setNull 4014
#define sipName_setNull &sipStrings_QtSql[4014]
#define sipNameNr_setOpen 4022
#define sipName_setOpen &sipStrings_QtSql[4022]
#define sipNameNr_setPort 4030
#define sipName_setPort &sipStrings_QtSql[4030]
#define sipNameNr_setSort 4038
#define sipName_setSort &sipStrings_QtSql[4038]
#define sipNameNr_sibling 4046
#define sipName_sibling &sipStrings_QtSql[4046]
#define sipNameNr_Binary 4054
#define sipName_Binary &sipStrings_QtSql[4054]
#define sipNameNr_Oracle 4061
#define sipName_Oracle &sipStrings_QtSql[4061]
#define sipNameNr_SQLite 4068
#define sipName_SQLite &sipStrings_QtSql[4068]
#define sipNameNr_Sybase 4075
#define sipName_Sybase &sipStrings_QtSql[4075]
#define sipNameNr_Tables 2273
#define sipName_Tables &sipStrings_QtSql[2273]
#define sipNameNr___eq__ 4082
#define sipName___eq__ &sipStrings_QtSql[4082]
#define sipNameNr___ne__ 4089
#define sipName___ne__ &sipStrings_QtSql[4089]
#define sipNameNr_append 4096
#define sipName_append &sipStrings_QtSql[4096]
#define sipNameNr_commit 4103
#define sipName_commit &sipStrings_QtSql[4103]
#define sipNameNr_driver 4110
#define sipName_driver &sipStrings_QtSql[4110]
#define sipNameNr_filter 4117
#define sipName_filter &sipStrings_QtSql[4117]
#define sipNameNr_finish 4124
#define sipName_finish &sipStrings_QtSql[4124]
#define sipNameNr_handle 4131
#define sipName_handle &sipStrings_QtSql[4131]
#define sipNameNr_insert 4138
#define sipName_insert &sipStrings_QtSql[4138]
#define sipNameNr_isNull 4145
#define sipName_isNull &sipStrings_QtSql[4145]
#define sipNameNr_isOpen 4152
#define sipName_isOpen &sipStrings_QtSql[4152]
#define sipNameNr_length 4159
#define sipName_length &sipStrings_QtSql[4159]
#define sipNameNr_parent 4166
#define sipName_parent &sipStrings_QtSql[4166]
#define sipNameNr_record 4173
#define sipName_record &sipStrings_QtSql[4173]
#define sipNameNr_remove 4180
#define sipName_remove &sipStrings_QtSql[4180]
#define sipNameNr_result 4187
#define sipName_result &sipStrings_QtSql[4187]
#define sipNameNr_revert 4194
#define sipName_revert &sipStrings_QtSql[4194]
#define sipNameNr_select 4201
#define sipName_select &sipStrings_QtSql[4201]
#define sipNameNr_submit 4208
#define sipName_submit &sipStrings_QtSql[4208]
#define sipNameNr_tables 4215
#define sipName_tables &sipStrings_QtSql[4215]
#define sipNameNr_thread 4222
#define sipName_thread &sipStrings_QtSql[4222]
#define sipNameNr_typeID 4229
#define sipName_typeID &sipStrings_QtSql[4229]
#define sipNameNr_InOut 4236
#define sipName_InOut &sipStrings_QtSql[4236]
#define sipNameNr_Views 4242
#define sipName_Views &sipStrings_QtSql[4242]
#define sipNameNr_buddy 4248
#define sipName_buddy &sipStrings_QtSql[4248]
#define sipNameNr_clear 4254
#define sipName_clear &sipStrings_QtSql[4254]
#define sipNameNr_close 4260
#define sipName_close &sipStrings_QtSql[4260]
#define sipNameNr_count 4266
#define sipName_count &sipStrings_QtSql[4266]
#define sipNameNr_event 4272
#define sipName_event &sipStrings_QtSql[4272]
#define sipNameNr_fetch 4278
#define sipName_fetch &sipStrings_QtSql[4278]
#define sipNameNr_field 4284
#define sipName_field &sipStrings_QtSql[4284]
#define sipNameNr_first 4290
#define sipName_first &sipStrings_QtSql[4290]
#define sipNameNr_flags 4296
#define sipName_flags &sipStrings_QtSql[4296]
#define sipNameNr_index 4302
#define sipName_index &sipStrings_QtSql[4302]
#define sipNameNr_match 4308
#define sipName_match &sipStrings_QtSql[4308]
#define sipNameNr_paint 4314
#define sipName_paint &sipStrings_QtSql[4314]
#define sipNameNr_query 4320
#define sipName_query &sipStrings_QtSql[4320]
#define sipNameNr_reset 4326
#define sipName_reset &sipStrings_QtSql[4326]
#define sipNameNr_setAt 4332
#define sipName_setAt &sipStrings_QtSql[4332]
#define sipNameNr_value 4338
#define sipName_value &sipStrings_QtSql[4338]
#define sipNameNr_BLOB 4344
#define sipName_BLOB &sipStrings_QtSql[4344]
#define sipNameNr_QSql 4349
#define sipName_QSql &sipStrings_QtSql[4349]
#define sipNameNr_data 4354
#define sipName_data &sipStrings_QtSql[4354]
#define sipNameNr_exec 4359
#define sipName_exec &sipStrings_QtSql[4359]
#define sipNameNr_host 4364
#define sipName_host &sipStrings_QtSql[4364]
#define sipNameNr_last 4369
#define sipName_last &sipStrings_QtSql[4369]
#define sipNameNr_mode 4374
#define sipName_mode &sipStrings_QtSql[4374]
#define sipNameNr_name 4379
#define sipName_name &sipStrings_QtSql[4379]
#define sipNameNr_next 4384
#define sipName_next &sipStrings_QtSql[4384]
#define sipNameNr_open 4389
#define sipName_open &sipStrings_QtSql[4389]
#define sipNameNr_port 4394
#define sipName_port &sipStrings_QtSql[4394]
#define sipNameNr_role 4399
#define sipName_role &sipStrings_QtSql[4399]
#define sipNameNr_seek 4404
#define sipName_seek &sipStrings_QtSql[4404]
#define sipNameNr_size 4409
#define sipName_size &sipStrings_QtSql[4409]
#define sipNameNr_sort 4414
#define sipName_sort &sipStrings_QtSql[4414]
#define sipNameNr_span 4419
#define sipName_span &sipStrings_QtSql[4419]
#define sipNameNr_swap 4424
#define sipName_swap &sipStrings_QtSql[4424]
#define sipNameNr_text 4429
#define sipName_text &sipStrings_QtSql[4429]
#define sipNameNr_type 4434
#define sipName_type &sipStrings_QtSql[4434]
#define sipNameNr_user 4439
#define sipName_user &sipStrings_QtSql[4439]
#define sipNameNr_DB2 4444
#define sipName_DB2 &sipStrings_QtSql[4444]
#define sipNameNr_Out 4238
#define sipName_Out &sipStrings_QtSql[4238]
#define sipNameNr_In 4448
#define sipName_In &sipStrings_QtSql[4448]
#define sipNameNr_at 4451
#define sipName_at &sipStrings_QtSql[4451]
#define sipNameNr_db 4454
#define sipName_db &sipStrings_QtSql[4454]

#define sipMalloc                   sipAPI_QtSql->api_malloc
#define sipFree                     sipAPI_QtSql->api_free
#define sipBuildResult              sipAPI_QtSql->api_build_result
#define sipCallMethod               sipAPI_QtSql->api_call_method
#define sipCallProcedureMethod      sipAPI_QtSql->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtSql->api_call_error_handler
#define sipParseResultEx            sipAPI_QtSql->api_parse_result_ex
#define sipParseResult              sipAPI_QtSql->api_parse_result
#define sipParseArgs                sipAPI_QtSql->api_parse_args
#define sipParseKwdArgs             sipAPI_QtSql->api_parse_kwd_args
#define sipParsePair                sipAPI_QtSql->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtSql->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtSql->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtSql->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtSql->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtSql->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtSql->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtSql->api_add_exception
#define sipNoFunction               sipAPI_QtSql->api_no_function
#define sipNoMethod                 sipAPI_QtSql->api_no_method
#define sipAbstractMethod           sipAPI_QtSql->api_abstract_method
#define sipBadClass                 sipAPI_QtSql->api_bad_class
#define sipBadCatcherResult         sipAPI_QtSql->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtSql->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtSql->api_bad_operator_arg
#define sipTrace                    sipAPI_QtSql->api_trace
#define sipTransferBack             sipAPI_QtSql->api_transfer_back
#define sipTransferTo               sipAPI_QtSql->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtSql->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtSql->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtSql->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtSql->api_voidptr_type
#define sipGetPyObject              sipAPI_QtSql->api_get_pyobject
#define sipGetAddress               sipAPI_QtSql->api_get_address
#define sipGetMixinAddress          sipAPI_QtSql->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtSql->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtSql->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtSql->api_call_hook
#define sipEndThread                sipAPI_QtSql->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtSql->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtSql->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtSql->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtSql->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtSql->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtSql->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtSql->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtSql->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtSql->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtSql->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtSql->api_convert_to_bool
#define sipReleaseType              sipAPI_QtSql->api_release_type
#define sipConvertFromType          sipAPI_QtSql->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtSql->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtSql->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtSql->api_convert_from_enum
#define sipGetState                 sipAPI_QtSql->api_get_state
#define sipExportSymbol             sipAPI_QtSql->api_export_symbol
#define sipImportSymbol             sipAPI_QtSql->api_import_symbol
#define sipFindType                 sipAPI_QtSql->api_find_type
#define sipBytes_AsChar             sipAPI_QtSql->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtSql->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtSql->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtSql->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtSql->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtSql->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtSql->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtSql->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtSql->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtSql->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtSql->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtSql->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtSql->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtSql->api_get_reference
#define sipKeepReference            sipAPI_QtSql->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtSql->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtSql->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtSql->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtSql->api_type_scope
#define sipResolveTypedef           sipAPI_QtSql->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtSql->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtSql->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtSql->api_init_mixin
#define sipExportModule             sipAPI_QtSql->api_export_module
#define sipInitModule               sipAPI_QtSql->api_init_module
#define sipGetInterpreter           sipAPI_QtSql->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtSql->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtSql->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtSql->api_py_type_dict
#define sipPyTypeName               sipAPI_QtSql->api_py_type_name
#define sipGetCFunction             sipAPI_QtSql->api_get_c_function
#define sipGetMethod                sipAPI_QtSql->api_get_method
#define sipFromMethod               sipAPI_QtSql->api_from_method
#define sipGetDate                  sipAPI_QtSql->api_get_date
#define sipFromDate                 sipAPI_QtSql->api_from_date
#define sipGetDateTime              sipAPI_QtSql->api_get_datetime
#define sipFromDateTime             sipAPI_QtSql->api_from_datetime
#define sipGetTime                  sipAPI_QtSql->api_get_time
#define sipFromTime                 sipAPI_QtSql->api_from_time
#define sipIsUserType               sipAPI_QtSql->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtSql->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtSql->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtSql->api_unicode_write
#define sipUnicodeData              sipAPI_QtSql->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtSql->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtSql->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtSql->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtSql->api_is_derived_class
#define sipGetUserObject            sipAPI_QtSql->api_get_user_object
#define sipSetUserObject            sipAPI_QtSql->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtSql->api_register_event_handler
#define sipConvertToArray           sipAPI_QtSql->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtSql->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtSql->api_enable_gc
#define sipPrintObject              sipAPI_QtSql->api_print_object
#define sipLong_AsChar              sipAPI_QtSql->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtSql->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtSql->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtSql->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtSql->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtSql->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtSql->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtSql->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtSql->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtSql->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtSql->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtSql->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtSql->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtSql->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtSql->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtSql->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtSql->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtSql->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtSql->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtSql->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtSql->api_release_type_us
#define sipIsPyMethod               sipAPI_QtSql->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtSql[];

#define sipType_QSqlDriverCreatorBase sipExportedTypes_QtSql[13]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlDriverCreatorBase;

#define sipType_QSqlDatabase sipExportedTypes_QtSql[6]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlDatabase;

#define sipType_QSqlDriver sipExportedTypes_QtSql[7]

#define sipType_QSqlDriver_DbmsType sipExportedTypes_QtSql[8]

#define sipType_QSqlDriver_NotificationSource sipExportedTypes_QtSql[11]

#define sipType_QSqlDriver_IdentifierType sipExportedTypes_QtSql[10]

#define sipType_QSqlDriver_StatementType sipExportedTypes_QtSql[12]

#define sipType_QSqlDriver_DriverFeature sipExportedTypes_QtSql[9]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlDriver;

#define sipType_QSqlError sipExportedTypes_QtSql[14]

#define sipType_QSqlError_ErrorType sipExportedTypes_QtSql[15]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlError;

#define sipType_QSqlField sipExportedTypes_QtSql[16]

#define sipType_QSqlField_RequiredStatus sipExportedTypes_QtSql[17]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlField;

#define sipType_QSqlRecord sipExportedTypes_QtSql[22]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlRecord;

#define sipType_QSqlIndex sipExportedTypes_QtSql[18]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlIndex;

#define sipType_QSqlQuery sipExportedTypes_QtSql[19]

#define sipType_QSqlQuery_BatchExecutionMode sipExportedTypes_QtSql[20]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlQuery;

#define sipType_QSqlQueryModel sipExportedTypes_QtSql[21]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlQueryModel;

#define sipType_QSqlRelationalDelegate sipExportedTypes_QtSql[24]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlRelationalDelegate;

#define sipType_QSqlRelation sipExportedTypes_QtSql[23]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlRelation;

#define sipType_QSqlTableModel sipExportedTypes_QtSql[29]

#define sipType_QSqlTableModel_EditStrategy sipExportedTypes_QtSql[30]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlTableModel;

#define sipType_QSqlRelationalTableModel sipExportedTypes_QtSql[25]

#define sipType_QSqlRelationalTableModel_JoinMode sipExportedTypes_QtSql[26]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlRelationalTableModel;

#define sipType_QSqlResult sipExportedTypes_QtSql[27]

#define sipType_QSqlResult_BindingSyntax sipExportedTypes_QtSql[28]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlResult;

#define sipType_QSql sipExportedTypes_QtSql[1]

#define sipType_QSql_NumericalPrecisionPolicy sipExportedTypes_QtSql[3]

#define sipType_QSql_TableType sipExportedTypes_QtSql[5]

#define sipType_QSql_ParamTypeFlag sipExportedTypes_QtSql[4]

#define sipType_QSql_Location sipExportedTypes_QtSql[2]

extern sipClassTypeDef sipTypeDef_QtSql_QSql;

#define sipType_QFlags_0100QSql_ParamTypeFlag sipExportedTypes_QtSql[0]

extern sipMappedTypeDef sipTypeDef_QtSql_QFlags_0100QSql_ParamTypeFlag;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtSql;
extern sipExportedModuleDef sipModuleAPI_QtSql;
extern sipTypeDef *sipExportedTypes_QtSql[];

#define sipType_Qt_DropAction sipImportedTypes_QtSql_QtCore[25].it_td

#define sipType_Qt_SortOrder sipImportedTypes_QtSql_QtCore[27].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtSql_QtCore[26].it_td

#define sipType_QObject sipImportedTypes_QtSql_QtCore[18].it_td

#define sipType_QModelIndex sipImportedTypes_QtSql_QtCore[16].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtSql_QtCore[0].it_td

#define sipType_QAbstractTableModel sipImportedTypes_QtSql_QtCore[1].it_td

#define sipType_QModelRoleDataSpan sipImportedTypes_QtSql_QtCore[17].it_td

#define sipType_QEvent sipImportedTypes_QtSql_QtCore[4].it_td

#define sipType_QTimerEvent sipImportedTypes_QtSql_QtCore[23].it_td

#define sipType_QChildEvent sipImportedTypes_QtSql_QtCore[3].it_td

#define sipType_QLocale sipImportedTypes_QtSql_QtCore[11].it_td

#define sipType_QMetaMethod sipImportedTypes_QtSql_QtCore[13].it_td

#define sipType_QMetaType sipImportedTypes_QtSql_QtCore[14].it_td

#define sipType_QMimeData sipImportedTypes_QtSql_QtCore[15].it_td

#define sipType_QSize sipImportedTypes_QtSql_QtCore[19].it_td

#define sipType_QThread sipImportedTypes_QtSql_QtCore[22].it_td

#define sipType_QVariant sipImportedTypes_QtSql_QtCore[24].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtSql_QtCore[8].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtSql_QtCore[12].it_td

#define sipType_QFlags_0100Qt_MatchFlag sipImportedTypes_QtSql_QtCore[7].it_td

#define sipType_QFlags_0100Qt_ItemFlag sipImportedTypes_QtSql_QtCore[6].it_td

#define sipType_QFlags_0100Qt_DropAction sipImportedTypes_QtSql_QtCore[5].it_td

#define sipType_QList_0100QVariant sipImportedTypes_QtSql_QtCore[10].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtSql_QtCore[9].it_td

#define sipType_QStringList sipImportedTypes_QtSql_QtCore[21].it_td

#define sipType_QString sipImportedTypes_QtSql_QtCore[20].it_td

#define sipType_QAnyStringView sipImportedTypes_QtSql_QtCore[2].it_td
extern sipImportedTypeDef sipImportedTypes_QtSql_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtSql_QtCore[];

#define sipType_QHelpEvent sipImportedTypes_QtSql_QtGui[0].it_td

#define sipType_QPainter sipImportedTypes_QtSql_QtGui[1].it_td
extern sipImportedTypeDef sipImportedTypes_QtSql_QtGui[];

#define sipType_QWidget sipImportedTypes_QtSql_QtWidgets[4].it_td

#define sipType_QAbstractItemDelegate sipImportedTypes_QtSql_QtWidgets[0].it_td

#define sipType_QAbstractItemView sipImportedTypes_QtSql_QtWidgets[1].it_td

#define sipType_QStyledItemDelegate sipImportedTypes_QtSql_QtWidgets[3].it_td

#define sipType_QStyleOptionViewItem sipImportedTypes_QtSql_QtWidgets[2].it_td
extern sipImportedTypeDef sipImportedTypes_QtSql_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtSql_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtSql_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtSql_qt_metacast;

#endif
