/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpdfwriter.sip"
#include <qpdfwriter.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpdfoutputintent.sip"
#include <qpdfoutputintent.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/quuid.sip"
#include <quuid.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpagedpaintdevice.sip"
#include <qpagedpaintdevice.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpageranges.sip"
#include <qpageranges.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 90 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpagelayout.sip"
#include <qpagelayout.h>
#line 112 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpagesize.sip"
#include <qpagesize.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQPdfWriter.cpp"


class sipQPdfWriter : public ::QPdfWriter
{
public:
    sipQPdfWriter(const ::QString&);
    sipQPdfWriter(::QIODevice*);
    virtual ~sipQPdfWriter();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    bool newPage() SIP_OVERRIDE;
    bool setPageSize(const ::QPageSize&) SIP_OVERRIDE;
    bool setPageLayout(const ::QPageLayout&) SIP_OVERRIDE;
    bool setPageOrientation(::QPageLayout::Orientation) SIP_OVERRIDE;
    bool setPageMargins(const ::QMarginsF&, ::QPageLayout::Unit) SIP_OVERRIDE;
    void setPageRanges(const ::QPageRanges&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPdfWriter(const sipQPdfWriter &);
    sipQPdfWriter &operator = (const sipQPdfWriter &);

    char sipPyMethods[15];
};

sipQPdfWriter::sipQPdfWriter(const ::QString& a0): ::QPdfWriter(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPdfWriter::sipQPdfWriter(::QIODevice*a0): ::QPdfWriter(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPdfWriter::~sipQPdfWriter()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQPdfWriter::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtGui_qt_metaobject(sipPySelf, sipType_QPdfWriter);

    return ::QPdfWriter::metaObject();
}

int sipQPdfWriter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QPdfWriter::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtGui_qt_metacall(sipPySelf, sipType_QPdfWriter, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQPdfWriter::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtGui_qt_metacast(sipPySelf, sipType_QPdfWriter, _clname, &sipCpp) ? sipCpp : ::QPdfWriter::qt_metacast(_clname));
}

int sipQPdfWriter::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QPdfWriter::metric(a0);

    extern int sipVH_QtGui_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtGui_23(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQPdfWriter::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QPdfWriter::paintEngine();

    extern ::QPaintEngine* sipVH_QtGui_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_22(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQPdfWriter::newPage()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_newPage);

    if (!sipMeth)
        return ::QPdfWriter::newPage();

    extern bool sipVH_QtGui_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_54(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQPdfWriter::setPageSize(const ::QPageSize& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_setPageSize);

    if (!sipMeth)
        return ::QPdfWriter::setPageSize(a0);

    extern bool sipVH_QtGui_108(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPageSize&);

    return sipVH_QtGui_108(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPdfWriter::setPageLayout(const ::QPageLayout& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_setPageLayout);

    if (!sipMeth)
        return ::QPdfWriter::setPageLayout(a0);

    extern bool sipVH_QtGui_109(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPageLayout&);

    return sipVH_QtGui_109(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPdfWriter::setPageOrientation(::QPageLayout::Orientation a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_setPageOrientation);

    if (!sipMeth)
        return ::QPdfWriter::setPageOrientation(a0);

    extern bool sipVH_QtGui_110(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPageLayout::Orientation);

    return sipVH_QtGui_110(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPdfWriter::setPageMargins(const ::QMarginsF& a0, ::QPageLayout::Unit a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_setPageMargins);

    if (!sipMeth)
        return ::QPdfWriter::setPageMargins(a0, a1);

    extern bool sipVH_QtGui_111(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMarginsF&, ::QPageLayout::Unit);

    return sipVH_QtGui_111(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQPdfWriter::setPageRanges(const ::QPageRanges& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_setPageRanges);

    if (!sipMeth)
    {
        ::QPdfWriter::setPageRanges(a0);
        return;
    }

    extern void sipVH_QtGui_112(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPageRanges&);

    sipVH_QtGui_112(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPdfWriter::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QPdfWriter::event(a0);

    extern bool sipVH_QtGui_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtGui_10(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPdfWriter::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QPdfWriter::eventFilter(a0, a1);

    extern bool sipVH_QtGui_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtGui_9(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQPdfWriter::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QPdfWriter::timerEvent(a0);
        return;
    }

    extern void sipVH_QtGui_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtGui_8(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfWriter::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QPdfWriter::childEvent(a0);
        return;
    }

    extern void sipVH_QtGui_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtGui_7(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfWriter::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QPdfWriter::customEvent(a0);
        return;
    }

    extern void sipVH_QtGui_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtGui_6(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfWriter::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QPdfWriter::connectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPdfWriter::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QPdfWriter::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QPdfWriter_title, "title(self) -> str");

extern "C" {static PyObject *meth_QPdfWriter_title(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_title(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfWriter, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_title, doc_QPdfWriter_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_setTitle, "setTitle(self, title: str|None)");

extern "C" {static PyObject *meth_QPdfWriter_setTitle(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_setTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPdfWriter, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTitle(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_setTitle, doc_QPdfWriter_setTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_creator, "creator(self) -> str");

extern "C" {static PyObject *meth_QPdfWriter_creator(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_creator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfWriter, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->creator());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_creator, doc_QPdfWriter_creator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_setCreator, "setCreator(self, creator: str|None)");

extern "C" {static PyObject *meth_QPdfWriter_setCreator(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_setCreator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPdfWriter, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCreator(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_setCreator, doc_QPdfWriter_setCreator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_newPage, "newPage(self) -> bool");

extern "C" {static PyObject *meth_QPdfWriter_newPage(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_newPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPdfWriter)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfWriter, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPdfWriter::newPage() : sipCpp->newPage());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_newPage, doc_QPdfWriter_newPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_paintEngine, "paintEngine(self) -> QPaintEngine|None");

extern "C" {static PyObject *meth_QPdfWriter_paintEngine(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_paintEngine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPdfWriter)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QPdfWriter, &sipCpp))
        {
            ::QPaintEngine*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPdfWriter::paintEngine() : sipCpp->paintEngine());

            return sipConvertFromType(sipRes, sipType_QPaintEngine, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_paintEngine, doc_QPdfWriter_paintEngine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_metric, "metric(self, id: QPaintDevice.PaintDeviceMetric) -> int");

extern "C" {static PyObject *meth_QPdfWriter_metric(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_metric(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPdfWriter)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintDevice::PaintDeviceMetric a0;
        const ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QPdfWriter, &sipCpp, sipType_QPaintDevice_PaintDeviceMetric, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPdfWriter::metric(a0) : sipCpp->metric(a0));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_metric, doc_QPdfWriter_metric);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_setResolution, "setResolution(self, resolution: int)");

extern "C" {static PyObject *meth_QPdfWriter_setResolution(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_setResolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QPdfWriter, &sipCpp, &a0))
        {
            sipCpp->setResolution(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_setResolution, doc_QPdfWriter_setResolution);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_resolution, "resolution(self) -> int");

extern "C" {static PyObject *meth_QPdfWriter_resolution(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_resolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfWriter, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->resolution();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_resolution, doc_QPdfWriter_resolution);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_setPdfVersion, "setPdfVersion(self, version: QPagedPaintDevice.PdfVersion)");

extern "C" {static PyObject *meth_QPdfWriter_setPdfVersion(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_setPdfVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPagedPaintDevice::PdfVersion a0;
        ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPdfWriter, &sipCpp, sipType_QPagedPaintDevice_PdfVersion, &a0))
        {
            sipCpp->setPdfVersion(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_setPdfVersion, doc_QPdfWriter_setPdfVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_pdfVersion, "pdfVersion(self) -> QPagedPaintDevice.PdfVersion");

extern "C" {static PyObject *meth_QPdfWriter_pdfVersion(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_pdfVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfWriter, &sipCpp))
        {
            ::QPagedPaintDevice::PdfVersion sipRes;

            sipRes = sipCpp->pdfVersion();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPagedPaintDevice_PdfVersion);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_pdfVersion, doc_QPdfWriter_pdfVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_setDocumentXmpMetadata, "setDocumentXmpMetadata(self, xmpMetadata: QByteArray|bytes|bytearray|memoryview)");

extern "C" {static PyObject *meth_QPdfWriter_setDocumentXmpMetadata(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_setDocumentXmpMetadata(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPdfWriter, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setDocumentXmpMetadata(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_setDocumentXmpMetadata, doc_QPdfWriter_setDocumentXmpMetadata);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_documentXmpMetadata, "documentXmpMetadata(self) -> QByteArray");

extern "C" {static PyObject *meth_QPdfWriter_documentXmpMetadata(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_documentXmpMetadata(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfWriter, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->documentXmpMetadata());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_documentXmpMetadata, doc_QPdfWriter_documentXmpMetadata);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_addFileAttachment, "addFileAttachment(self, fileName: str|None, data: QByteArray|bytes|bytearray|memoryview, mimeType: str|None = '')");

extern "C" {static PyObject *meth_QPdfWriter_addFileAttachment(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_addFileAttachment(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QByteArray* a1;
        int a1State = 0;
        const ::QString& a2def = QString();
        const ::QString* a2 = &a2def;
        int a2State = 0;
        ::QPdfWriter *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mimeType,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J1|J1", &sipSelf, sipType_QPdfWriter, &sipCpp, sipType_QString, &a0, &a0State, sipType_QByteArray, &a1, &a1State, sipType_QString, &a2, &a2State))
        {
            sipCpp->addFileAttachment(*a0, *a1, *a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_addFileAttachment, doc_QPdfWriter_addFileAttachment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_documentId, "documentId(self) -> QUuid");

extern "C" {static PyObject *meth_QPdfWriter_documentId(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_documentId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfWriter, &sipCpp))
        {
            ::QUuid*sipRes;

            sipRes = new ::QUuid(sipCpp->documentId());

            return sipConvertFromNewType(sipRes, sipType_QUuid, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_documentId, doc_QPdfWriter_documentId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_setDocumentId, "setDocumentId(self, documentId: QUuid)");

extern "C" {static PyObject *meth_QPdfWriter_setDocumentId(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_setDocumentId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QUuid* a0;
        ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPdfWriter, &sipCpp, sipType_QUuid, &a0))
        {
            sipCpp->setDocumentId(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_setDocumentId, doc_QPdfWriter_setDocumentId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_colorModel, "colorModel(self) -> QPdfWriter.ColorModel");

extern "C" {static PyObject *meth_QPdfWriter_colorModel(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_colorModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfWriter, &sipCpp))
        {
            ::QPdfWriter::ColorModel sipRes;

            sipRes = sipCpp->colorModel();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPdfWriter_ColorModel);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_colorModel, doc_QPdfWriter_colorModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_setColorModel, "setColorModel(self, model: QPdfWriter.ColorModel)");

extern "C" {static PyObject *meth_QPdfWriter_setColorModel(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_setColorModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfWriter::ColorModel a0;
        ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPdfWriter, &sipCpp, sipType_QPdfWriter_ColorModel, &a0))
        {
            sipCpp->setColorModel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_setColorModel, doc_QPdfWriter_setColorModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_outputIntent, "outputIntent(self) -> QPdfOutputIntent");

extern "C" {static PyObject *meth_QPdfWriter_outputIntent(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_outputIntent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfWriter, &sipCpp))
        {
            ::QPdfOutputIntent*sipRes;

            sipRes = new ::QPdfOutputIntent(sipCpp->outputIntent());

            return sipConvertFromNewType(sipRes, sipType_QPdfOutputIntent, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_outputIntent, doc_QPdfWriter_outputIntent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_setOutputIntent, "setOutputIntent(self, intent: QPdfOutputIntent)");

extern "C" {static PyObject *meth_QPdfWriter_setOutputIntent(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_setOutputIntent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfOutputIntent* a0;
        ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPdfWriter, &sipCpp, sipType_QPdfOutputIntent, &a0))
        {
            sipCpp->setOutputIntent(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_setOutputIntent, doc_QPdfWriter_setOutputIntent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_author, "author(self) -> str");

extern "C" {static PyObject *meth_QPdfWriter_author(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_author(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfWriter, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->author());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_author, doc_QPdfWriter_author);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfWriter_setAuthor, "setAuthor(self, author: str|None)");

extern "C" {static PyObject *meth_QPdfWriter_setAuthor(PyObject *, PyObject *);}
static PyObject *meth_QPdfWriter_setAuthor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPdfWriter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPdfWriter, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setAuthor(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfWriter, sipName_setAuthor, doc_QPdfWriter_setAuthor);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPdfWriter(void *, const sipTypeDef *);}
static void *cast_QPdfWriter(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPdfWriter *sipCpp = reinterpret_cast< ::QPdfWriter *>(sipCppV);

    if (targetType == sipType_QPdfWriter)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    sipCppV = ((const sipClassTypeDef *)sipType_QPagedPaintDevice)->ctd_cast(static_cast< ::QPagedPaintDevice *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPdfWriter(void *, int);}
static void release_QPdfWriter(void *sipCppV, int)
{
    ::QPdfWriter *sipCpp = reinterpret_cast< ::QPdfWriter *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QPdfWriter(sipSimpleWrapper *);}
static void dealloc_QPdfWriter(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPdfWriter *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPdfWriter(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPdfWriter(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPdfWriter(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQPdfWriter *sipCpp = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QString, &a0, &a0State))
        {
            sipCpp = new sipQPdfWriter(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QIODevice* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8", sipType_QIODevice, &a0))
        {
            sipCpp = new sipQPdfWriter(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPdfWriter[] = {{53, 0, 0}, {201, 255, 1}};


static PyMethodDef methods_QPdfWriter[] = {
    {sipName_addFileAttachment, SIP_MLMETH_CAST(meth_QPdfWriter_addFileAttachment), METH_VARARGS|METH_KEYWORDS, doc_QPdfWriter_addFileAttachment},
    {sipName_author, meth_QPdfWriter_author, METH_VARARGS, doc_QPdfWriter_author},
    {sipName_colorModel, meth_QPdfWriter_colorModel, METH_VARARGS, doc_QPdfWriter_colorModel},
    {sipName_creator, meth_QPdfWriter_creator, METH_VARARGS, doc_QPdfWriter_creator},
    {sipName_documentId, meth_QPdfWriter_documentId, METH_VARARGS, doc_QPdfWriter_documentId},
    {sipName_documentXmpMetadata, meth_QPdfWriter_documentXmpMetadata, METH_VARARGS, doc_QPdfWriter_documentXmpMetadata},
    {sipName_metric, meth_QPdfWriter_metric, METH_VARARGS, doc_QPdfWriter_metric},
    {sipName_newPage, meth_QPdfWriter_newPage, METH_VARARGS, doc_QPdfWriter_newPage},
    {sipName_outputIntent, meth_QPdfWriter_outputIntent, METH_VARARGS, doc_QPdfWriter_outputIntent},
    {sipName_paintEngine, meth_QPdfWriter_paintEngine, METH_VARARGS, doc_QPdfWriter_paintEngine},
    {sipName_pdfVersion, meth_QPdfWriter_pdfVersion, METH_VARARGS, doc_QPdfWriter_pdfVersion},
    {sipName_resolution, meth_QPdfWriter_resolution, METH_VARARGS, doc_QPdfWriter_resolution},
    {sipName_setAuthor, meth_QPdfWriter_setAuthor, METH_VARARGS, doc_QPdfWriter_setAuthor},
    {sipName_setColorModel, meth_QPdfWriter_setColorModel, METH_VARARGS, doc_QPdfWriter_setColorModel},
    {sipName_setCreator, meth_QPdfWriter_setCreator, METH_VARARGS, doc_QPdfWriter_setCreator},
    {sipName_setDocumentId, meth_QPdfWriter_setDocumentId, METH_VARARGS, doc_QPdfWriter_setDocumentId},
    {sipName_setDocumentXmpMetadata, meth_QPdfWriter_setDocumentXmpMetadata, METH_VARARGS, doc_QPdfWriter_setDocumentXmpMetadata},
    {sipName_setOutputIntent, meth_QPdfWriter_setOutputIntent, METH_VARARGS, doc_QPdfWriter_setOutputIntent},
    {sipName_setPdfVersion, meth_QPdfWriter_setPdfVersion, METH_VARARGS, doc_QPdfWriter_setPdfVersion},
    {sipName_setResolution, meth_QPdfWriter_setResolution, METH_VARARGS, doc_QPdfWriter_setResolution},
    {sipName_setTitle, meth_QPdfWriter_setTitle, METH_VARARGS, doc_QPdfWriter_setTitle},
    {sipName_title, meth_QPdfWriter_title, METH_VARARGS, doc_QPdfWriter_title}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QPdfWriter[] = {
    {sipName_RGB, static_cast<int>(::QPdfWriter::ColorModel::RGB)},
    {sipName_Grayscale, static_cast<int>(::QPdfWriter::ColorModel::Grayscale)},
    {sipName_CMYK, static_cast<int>(::QPdfWriter::ColorModel::CMYK)},
    {sipName_Auto, static_cast<int>(::QPdfWriter::ColorModel::Auto)},
    {0, 0}
};

PyDoc_STRVAR(doc_QPdfWriter, "\1QPdfWriter(filename: str|None)\n"
"QPdfWriter(device: QIODevice|None)");


static pyqt6ClassPluginDef plugin_QPdfWriter = {
    &::QPdfWriter::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QPdfWriter = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPdfWriter,
        SIP_NULLPTR,
        &plugin_QPdfWriter,
    },
    {
        sipNameNr_QPdfWriter,
        {0, 0, 1},
        22, methods_QPdfWriter,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QPdfWriter, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPdfWriter,
    -1,
    -1,
    supers_QPdfWriter,
    SIP_NULLPTR,
    init_type_QPdfWriter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPdfWriter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QPdfWriter,
    cast_QPdfWriter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QPdfWriter),
};
