/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPdf.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPdf/qpdflink.sip"
#include <qpdflink.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfLink.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qclipboard.sip"
#include <qclipboard.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfLink.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfLink.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfLink.cpp"
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfLink.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfLink.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPdf/sipQtPdfQPdfLink.cpp"


PyDoc_STRVAR(doc_QPdfLink_swap, "swap(self, other: QPdfLink)");

extern "C" {static PyObject *meth_QPdfLink_swap(PyObject *, PyObject *);}
static PyObject *meth_QPdfLink_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPdfLink* a0;
        ::QPdfLink *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPdfLink, &sipCpp, sipType_QPdfLink, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfLink, sipName_swap, doc_QPdfLink_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfLink_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QPdfLink_isValid(PyObject *, PyObject *);}
static PyObject *meth_QPdfLink_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfLink *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfLink, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfLink, sipName_isValid, doc_QPdfLink_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfLink_page, "page(self) -> int");

extern "C" {static PyObject *meth_QPdfLink_page(PyObject *, PyObject *);}
static PyObject *meth_QPdfLink_page(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfLink *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfLink, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->page();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfLink, sipName_page, doc_QPdfLink_page);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfLink_location, "location(self) -> QPointF");

extern "C" {static PyObject *meth_QPdfLink_location(PyObject *, PyObject *);}
static PyObject *meth_QPdfLink_location(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfLink *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfLink, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->location());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfLink, sipName_location, doc_QPdfLink_location);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfLink_zoom, "zoom(self) -> float");

extern "C" {static PyObject *meth_QPdfLink_zoom(PyObject *, PyObject *);}
static PyObject *meth_QPdfLink_zoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfLink *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfLink, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->zoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfLink, sipName_zoom, doc_QPdfLink_zoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfLink_url, "url(self) -> QUrl");

extern "C" {static PyObject *meth_QPdfLink_url(PyObject *, PyObject *);}
static PyObject *meth_QPdfLink_url(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfLink *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfLink, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->url());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfLink, sipName_url, doc_QPdfLink_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfLink_contextBefore, "contextBefore(self) -> str");

extern "C" {static PyObject *meth_QPdfLink_contextBefore(PyObject *, PyObject *);}
static PyObject *meth_QPdfLink_contextBefore(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfLink *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfLink, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->contextBefore());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfLink, sipName_contextBefore, doc_QPdfLink_contextBefore);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfLink_contextAfter, "contextAfter(self) -> str");

extern "C" {static PyObject *meth_QPdfLink_contextAfter(PyObject *, PyObject *);}
static PyObject *meth_QPdfLink_contextAfter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfLink *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfLink, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->contextAfter());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfLink, sipName_contextAfter, doc_QPdfLink_contextAfter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfLink_rectangles, "rectangles(self) -> list[QRectF]");

extern "C" {static PyObject *meth_QPdfLink_rectangles(PyObject *, PyObject *);}
static PyObject *meth_QPdfLink_rectangles(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfLink *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfLink, &sipCpp))
        {
            QList< ::QRectF>*sipRes;

            sipRes = new QList< ::QRectF>(sipCpp->rectangles());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfLink, sipName_rectangles, doc_QPdfLink_rectangles);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfLink_toString, "toString(self) -> str");

extern "C" {static PyObject *meth_QPdfLink_toString(PyObject *, PyObject *);}
static PyObject *meth_QPdfLink_toString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPdfLink *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPdfLink, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfLink, sipName_toString, doc_QPdfLink_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPdfLink_copyToClipboard, "copyToClipboard(self, mode: QClipboard.Mode = QClipboard.Clipboard)");

extern "C" {static PyObject *meth_QPdfLink_copyToClipboard(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPdfLink_copyToClipboard(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QClipboard::Mode a0 = QClipboard::Clipboard;
        const ::QPdfLink *sipCpp;

        static const char *sipKwdList[] = {
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QPdfLink, &sipCpp, sipType_QClipboard_Mode, &a0))
        {
            sipCpp->copyToClipboard(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPdfLink, sipName_copyToClipboard, doc_QPdfLink_copyToClipboard);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPdfLink(void *, int);}
static void release_QPdfLink(void *sipCppV, int)
{
    delete reinterpret_cast< ::QPdfLink *>(sipCppV);
}


extern "C" {static void *array_QPdfLink(Py_ssize_t);}
static void *array_QPdfLink(Py_ssize_t sipNrElem)
{
    return new ::QPdfLink[sipNrElem];
}


extern "C" {static void array_delete_QPdfLink(void *);}
static void array_delete_QPdfLink(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPdfLink *>(sipCpp);
}


extern "C" {static void assign_QPdfLink(void *, Py_ssize_t, void *);}
static void assign_QPdfLink(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPdfLink *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPdfLink *>(sipSrc);
}


extern "C" {static void *copy_QPdfLink(const void *, Py_ssize_t);}
static void *copy_QPdfLink(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPdfLink(reinterpret_cast<const ::QPdfLink *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPdfLink(sipSimpleWrapper *);}
static void dealloc_QPdfLink(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPdfLink(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QPdfLink(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPdfLink(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QPdfLink *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QPdfLink();

            return sipCpp;
        }
    }

    {
        const ::QPdfLink* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPdfLink, &a0))
        {
            sipCpp = new ::QPdfLink(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QPdfLink[] = {
    {sipName_contextAfter, meth_QPdfLink_contextAfter, METH_VARARGS, doc_QPdfLink_contextAfter},
    {sipName_contextBefore, meth_QPdfLink_contextBefore, METH_VARARGS, doc_QPdfLink_contextBefore},
    {sipName_copyToClipboard, SIP_MLMETH_CAST(meth_QPdfLink_copyToClipboard), METH_VARARGS|METH_KEYWORDS, doc_QPdfLink_copyToClipboard},
    {sipName_isValid, meth_QPdfLink_isValid, METH_VARARGS, doc_QPdfLink_isValid},
    {sipName_location, meth_QPdfLink_location, METH_VARARGS, doc_QPdfLink_location},
    {sipName_page, meth_QPdfLink_page, METH_VARARGS, doc_QPdfLink_page},
    {sipName_rectangles, meth_QPdfLink_rectangles, METH_VARARGS, doc_QPdfLink_rectangles},
    {sipName_swap, meth_QPdfLink_swap, METH_VARARGS, doc_QPdfLink_swap},
    {sipName_toString, meth_QPdfLink_toString, METH_VARARGS, doc_QPdfLink_toString},
    {sipName_url, meth_QPdfLink_url, METH_VARARGS, doc_QPdfLink_url},
    {sipName_zoom, meth_QPdfLink_zoom, METH_VARARGS, doc_QPdfLink_zoom}
};

PyDoc_STRVAR(doc_QPdfLink, "\1QPdfLink()\n"
"QPdfLink(other: QPdfLink)");


sipClassTypeDef sipTypeDef_QtPdf_QPdfLink = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPdfLink,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QPdfLink,
        {0, 0, 1},
        11, methods_QPdfLink,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPdfLink,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QPdfLink,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPdfLink,
    assign_QPdfLink,
    array_QPdfLink,
    copy_QPdfLink,
    release_QPdfLink,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPdfLink,
    sizeof (::QPdfLink),
};
