/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 165 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"

#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQQmlImageProviderBase.cpp"


PyDoc_STRVAR(doc_QQmlImageProviderBase_imageType, "imageType(self) -> QQmlImageProviderBase.ImageType");

extern "C" {static PyObject *meth_QQmlImageProviderBase_imageType(PyObject *, PyObject *);}
static PyObject *meth_QQmlImageProviderBase_imageType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QQmlImageProviderBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlImageProviderBase, &sipCpp))
        {
            ::QQmlImageProviderBase::ImageType sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QQmlImageProviderBase, sipName_imageType);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->imageType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QQmlImageProviderBase_ImageType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlImageProviderBase, sipName_imageType, doc_QQmlImageProviderBase_imageType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlImageProviderBase_flags, "flags(self) -> QQmlImageProviderBase.Flag");

extern "C" {static PyObject *meth_QQmlImageProviderBase_flags(PyObject *, PyObject *);}
static PyObject *meth_QQmlImageProviderBase_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QQmlImageProviderBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlImageProviderBase, &sipCpp))
        {
            ::QQmlImageProviderBase::Flags*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QQmlImageProviderBase, sipName_flags);
                return SIP_NULLPTR;
            }

            sipRes = new ::QQmlImageProviderBase::Flags(sipCpp->flags());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QQmlImageProviderBase_Flag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlImageProviderBase, sipName_flags, doc_QQmlImageProviderBase_flags);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQmlImageProviderBase(void *, const sipTypeDef *);}
static void *cast_QQmlImageProviderBase(void *sipCppV, const sipTypeDef *targetType)
{
    ::QQmlImageProviderBase *sipCpp = reinterpret_cast< ::QQmlImageProviderBase *>(sipCppV);

    if (targetType == sipType_QQmlImageProviderBase)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQmlImageProviderBase(void *, int);}
static void release_QQmlImageProviderBase(void *sipCppV, int)
{
    ::QQmlImageProviderBase *sipCpp = reinterpret_cast< ::QQmlImageProviderBase *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QQmlImageProviderBase(sipSimpleWrapper *);}
static void dealloc_QQmlImageProviderBase(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQmlImageProviderBase(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQmlImageProviderBase[] = {{14, 0, 1}};


static PyMethodDef methods_QQmlImageProviderBase[] = {
    {sipName_flags, meth_QQmlImageProviderBase_flags, METH_VARARGS, doc_QQmlImageProviderBase_flags},
    {sipName_imageType, meth_QQmlImageProviderBase_imageType, METH_VARARGS, doc_QQmlImageProviderBase_imageType}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QQmlImageProviderBase[] = {
    {sipName_ForceAsynchronousImageLoading, static_cast<int>(::QQmlImageProviderBase::ForceAsynchronousImageLoading)},
    {sipName_Image, static_cast<int>(::QQmlImageProviderBase::Image)},
    {sipName_Pixmap, static_cast<int>(::QQmlImageProviderBase::Pixmap)},
    {sipName_Texture, static_cast<int>(::QQmlImageProviderBase::Texture)},
    {sipName_ImageResponse, static_cast<int>(::QQmlImageProviderBase::ImageResponse)},
    {0, 0}
};


static pyqt6ClassPluginDef plugin_QQmlImageProviderBase = {
    &::QQmlImageProviderBase::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQml_QQmlImageProviderBase = {
    {
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQmlImageProviderBase,
        SIP_NULLPTR,
        &plugin_QQmlImageProviderBase,
    },
    {
        sipNameNr_QQmlImageProviderBase,
        {0, 0, 1},
        2, methods_QQmlImageProviderBase,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QQmlImageProviderBase, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QQmlImageProviderBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQmlImageProviderBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQmlImageProviderBase,
    cast_QQmlImageProviderBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
