/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/qextensionmanager.sip"
#include <qextensionmanager.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDesigner/extension.sip"
#include <extension.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDesigner/sipQtDesignerQExtensionManager.cpp"


class sipQExtensionManager : public ::QExtensionManager
{
public:
    sipQExtensionManager(::QObject*);
    virtual ~sipQExtensionManager();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void registerExtensions(::QAbstractExtensionFactory*, const ::QString&) SIP_OVERRIDE;
    void unregisterExtensions(::QAbstractExtensionFactory*, const ::QString&) SIP_OVERRIDE;
    ::QObject* extension(::QObject*, const ::QString&) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQExtensionManager(const sipQExtensionManager &);
    sipQExtensionManager &operator = (const sipQExtensionManager &);

    char sipPyMethods[10];
};

sipQExtensionManager::sipQExtensionManager(::QObject*a0): ::QExtensionManager(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQExtensionManager::~sipQExtensionManager()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQExtensionManager::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDesigner_qt_metaobject(sipPySelf, sipType_QExtensionManager);

    return ::QExtensionManager::metaObject();
}

int sipQExtensionManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QExtensionManager::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDesigner_qt_metacall(sipPySelf, sipType_QExtensionManager, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQExtensionManager::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDesigner_qt_metacast(sipPySelf, sipType_QExtensionManager, _clname, &sipCpp) ? sipCpp : ::QExtensionManager::qt_metacast(_clname));
}

void sipQExtensionManager::registerExtensions(::QAbstractExtensionFactory*a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_registerExtensions);

    if (!sipMeth)
    {
        ::QExtensionManager::registerExtensions(a0, a1);
        return;
    }

    extern void sipVH_QtDesigner_87(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractExtensionFactory*, const ::QString&);

    sipVH_QtDesigner_87(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQExtensionManager::unregisterExtensions(::QAbstractExtensionFactory*a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_unregisterExtensions);

    if (!sipMeth)
    {
        ::QExtensionManager::unregisterExtensions(a0, a1);
        return;
    }

    extern void sipVH_QtDesigner_87(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractExtensionFactory*, const ::QString&);

    sipVH_QtDesigner_87(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QObject* sipQExtensionManager::extension(::QObject*a0, const ::QString& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_extension);

    if (!sipMeth)
        return ::QExtensionManager::extension(a0, a1);

    extern ::QObject* sipVH_QtDesigner_85(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, const ::QString&);

    return sipVH_QtDesigner_85(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQExtensionManager::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QExtensionManager::event(a0);

    extern bool sipVH_QtDesigner_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDesigner_32(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQExtensionManager::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QExtensionManager::eventFilter(a0, a1);

    extern bool sipVH_QtDesigner_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDesigner_33(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQExtensionManager::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QExtensionManager::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDesigner_34(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQExtensionManager::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QExtensionManager::childEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDesigner_35(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQExtensionManager::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QExtensionManager::customEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDesigner_7(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQExtensionManager::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QExtensionManager::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDesigner_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDesigner_36(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQExtensionManager::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QExtensionManager::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDesigner_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDesigner_36(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QExtensionManager_registerExtensions, "registerExtensions(self, factory: QAbstractExtensionFactory|None, iid: str|None = '')");

extern "C" {static PyObject *meth_QExtensionManager_registerExtensions(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QExtensionManager_registerExtensions(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QExtensionManager)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QAbstractExtensionFactory* a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        ::QExtensionManager *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_iid,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|J1", &sipSelf, sipType_QExtensionManager, &sipCpp, sipType_QAbstractExtensionFactory, &a0, sipType_QString, &a1, &a1State))
        {
            (sipSelfWasArg ? sipCpp->::QExtensionManager::registerExtensions(a0, *a1) : sipCpp->registerExtensions(a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QExtensionManager, sipName_registerExtensions, doc_QExtensionManager_registerExtensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QExtensionManager_unregisterExtensions, "unregisterExtensions(self, factory: QAbstractExtensionFactory|None, iid: str|None = '')");

extern "C" {static PyObject *meth_QExtensionManager_unregisterExtensions(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QExtensionManager_unregisterExtensions(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QExtensionManager)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QAbstractExtensionFactory* a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        ::QExtensionManager *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_iid,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|J1", &sipSelf, sipType_QExtensionManager, &sipCpp, sipType_QAbstractExtensionFactory, &a0, sipType_QString, &a1, &a1State))
        {
            (sipSelfWasArg ? sipCpp->::QExtensionManager::unregisterExtensions(a0, *a1) : sipCpp->unregisterExtensions(a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QExtensionManager, sipName_unregisterExtensions, doc_QExtensionManager_unregisterExtensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QExtensionManager_extension, "extension(self, object: QObject|None, iid: str|None) -> QObject|None");

extern "C" {static PyObject *meth_QExtensionManager_extension(PyObject *, PyObject *);}
static PyObject *meth_QExtensionManager_extension(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QExtensionManager)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QObject* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QExtensionManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J1", &sipSelf, sipType_QExtensionManager, &sipCpp, sipType_QObject, &a0, sipType_QString, &a1, &a1State))
        {
            ::QObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QExtensionManager::extension(a0, *a1) : sipCpp->extension(a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QExtensionManager, sipName_extension, doc_QExtensionManager_extension);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QExtensionManager(void *, const sipTypeDef *);}
static void *cast_QExtensionManager(void *sipCppV, const sipTypeDef *targetType)
{
    ::QExtensionManager *sipCpp = reinterpret_cast< ::QExtensionManager *>(sipCppV);

    if (targetType == sipType_QExtensionManager)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    if (targetType == sipType_QAbstractExtensionManager)
        return static_cast< ::QAbstractExtensionManager *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QExtensionManager(void *, int);}
static void release_QExtensionManager(void *sipCppV, int)
{
    ::QExtensionManager *sipCpp = reinterpret_cast< ::QExtensionManager *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QExtensionManager(Py_ssize_t);}
static void *array_QExtensionManager(Py_ssize_t sipNrElem)
{
    return new ::QExtensionManager[sipNrElem];
}


extern "C" {static void array_delete_QExtensionManager(void *);}
static void array_delete_QExtensionManager(void *sipCpp)
{
    delete[] reinterpret_cast< ::QExtensionManager *>(sipCpp);
}


extern "C" {static void dealloc_QExtensionManager(sipSimpleWrapper *);}
static void dealloc_QExtensionManager(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQExtensionManager *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QExtensionManager(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QExtensionManager(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QExtensionManager(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQExtensionManager *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQExtensionManager(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QExtensionManager[] = {{8, 0, 0}, {1, 255, 1}};


static PyMethodDef methods_QExtensionManager[] = {
    {sipName_extension, meth_QExtensionManager_extension, METH_VARARGS, doc_QExtensionManager_extension},
    {sipName_registerExtensions, SIP_MLMETH_CAST(meth_QExtensionManager_registerExtensions), METH_VARARGS|METH_KEYWORDS, doc_QExtensionManager_registerExtensions},
    {sipName_unregisterExtensions, SIP_MLMETH_CAST(meth_QExtensionManager_unregisterExtensions), METH_VARARGS|METH_KEYWORDS, doc_QExtensionManager_unregisterExtensions}
};

PyDoc_STRVAR(doc_QExtensionManager, "\1QExtensionManager(parent: QObject|None = None)");


static pyqt6ClassPluginDef plugin_QExtensionManager = {
    &::QExtensionManager::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDesigner_QExtensionManager = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QExtensionManager,
        SIP_NULLPTR,
        &plugin_QExtensionManager,
    },
    {
        sipNameNr_QExtensionManager,
        {0, 0, 1},
        3, methods_QExtensionManager,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QExtensionManager,
    -1,
    -1,
    supers_QExtensionManager,
    SIP_NULLPTR,
    init_type_QExtensionManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QExtensionManager,
    SIP_NULLPTR,
    array_QExtensionManager,
    SIP_NULLPTR,
    release_QExtensionManager,
    cast_QExtensionManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QExtensionManager,
    sizeof (::QExtensionManager),
};
