/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothsocket.sip"
#include <qbluetoothsocket.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothserviceinfo.sip"
#include <qbluetoothserviceinfo.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetooth.sip"
#include <qbluetooth.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevicebase.sip"
#include <qiodevicebase.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothaddress.sip"
#include <qbluetoothaddress.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothuuid.sip"
#include <qbluetoothuuid.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"


class sipQBluetoothSocket : public ::QBluetoothSocket
{
public:
    sipQBluetoothSocket(::QBluetoothServiceInfo::Protocol, ::QObject*);
    sipQBluetoothSocket(::QObject*);
    virtual ~sipQBluetoothSocket();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::qint64 writeData(const char*, long long) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool isSequential() const SIP_OVERRIDE;
    bool open(::QIODeviceBase::OpenMode) SIP_OVERRIDE;
    void close() SIP_OVERRIDE;
    ::qint64 pos() const SIP_OVERRIDE;
    ::qint64 size() const SIP_OVERRIDE;
    bool seek(::qint64) SIP_OVERRIDE;
    bool atEnd() const SIP_OVERRIDE;
    bool reset() SIP_OVERRIDE;
    ::qint64 bytesAvailable() const SIP_OVERRIDE;
    ::qint64 bytesToWrite() const SIP_OVERRIDE;
    bool canReadLine() const SIP_OVERRIDE;
    bool waitForReadyRead(int) SIP_OVERRIDE;
    bool waitForBytesWritten(int) SIP_OVERRIDE;
    ::qint64 readData(char*, ::qint64) SIP_OVERRIDE;
    ::qint64 readLineData(char*, ::qint64) SIP_OVERRIDE;
    ::qint64 skipData(::qint64) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQBluetoothSocket(const sipQBluetoothSocket &);
    sipQBluetoothSocket &operator = (const sipQBluetoothSocket &);

    char sipPyMethods[24];
};

sipQBluetoothSocket::sipQBluetoothSocket(::QBluetoothServiceInfo::Protocol a0, ::QObject*a1): ::QBluetoothSocket(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBluetoothSocket::sipQBluetoothSocket(::QObject*a0): ::QBluetoothSocket(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQBluetoothSocket::~sipQBluetoothSocket()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQBluetoothSocket::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtBluetooth_qt_metaobject(sipPySelf, sipType_QBluetoothSocket);

    return ::QBluetoothSocket::metaObject();
}

int sipQBluetoothSocket::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QBluetoothSocket::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtBluetooth_qt_metacall(sipPySelf, sipType_QBluetoothSocket, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQBluetoothSocket::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtBluetooth_qt_metacast(sipPySelf, sipType_QBluetoothSocket, _clname, &sipCpp) ? sipCpp : ::QBluetoothSocket::qt_metacast(_clname));
}

::qint64 sipQBluetoothSocket::writeData(const char*a0, long long a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_writeData);

    if (!sipMeth)
        return ::QBluetoothSocket::writeData(a0, a1);

    extern ::qint64 sipVH_QtBluetooth_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const char*, long long);

    return sipVH_QtBluetooth_15(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQBluetoothSocket::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QBluetoothSocket::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtBluetooth_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtBluetooth_0(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothSocket::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QBluetoothSocket::connectNotify(a0);
        return;
    }

    extern void sipVH_QtBluetooth_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtBluetooth_0(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothSocket::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QBluetoothSocket::customEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtBluetooth_1(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothSocket::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QBluetoothSocket::childEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtBluetooth_2(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothSocket::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QBluetoothSocket::timerEvent(a0);
        return;
    }

    extern void sipVH_QtBluetooth_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtBluetooth_3(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQBluetoothSocket::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QBluetoothSocket::eventFilter(a0, a1);

    extern bool sipVH_QtBluetooth_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtBluetooth_4(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQBluetoothSocket::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QBluetoothSocket::event(a0);

    extern bool sipVH_QtBluetooth_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtBluetooth_5(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQBluetoothSocket::isSequential() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isSequential);

    if (!sipMeth)
        return ::QBluetoothSocket::isSequential();

    extern bool sipVH_QtBluetooth_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtBluetooth_10(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQBluetoothSocket::open(::QIODeviceBase::OpenMode a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_open);

    if (!sipMeth)
        return ::QBluetoothSocket::open(a0);

    extern bool sipVH_QtBluetooth_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QIODeviceBase::OpenMode);

    return sipVH_QtBluetooth_14(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQBluetoothSocket::close()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_close);

    if (!sipMeth)
    {
        ::QBluetoothSocket::close();
        return;
    }

    extern void sipVH_QtBluetooth_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtBluetooth_13(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qint64 sipQBluetoothSocket::pos() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_pos);

    if (!sipMeth)
        return ::QBluetoothSocket::pos();

    extern ::qint64 sipVH_QtBluetooth_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtBluetooth_11(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qint64 sipQBluetoothSocket::size() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_size);

    if (!sipMeth)
        return ::QBluetoothSocket::size();

    extern ::qint64 sipVH_QtBluetooth_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtBluetooth_11(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQBluetoothSocket::seek(::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_seek);

    if (!sipMeth)
        return ::QBluetoothSocket::seek(a0);

    extern bool sipVH_QtBluetooth_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qint64);

    return sipVH_QtBluetooth_12(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQBluetoothSocket::atEnd() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_atEnd);

    if (!sipMeth)
        return ::QBluetoothSocket::atEnd();

    extern bool sipVH_QtBluetooth_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtBluetooth_10(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQBluetoothSocket::reset()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_reset);

    if (!sipMeth)
        return ::QBluetoothSocket::reset();

    extern bool sipVH_QtBluetooth_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtBluetooth_10(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qint64 sipQBluetoothSocket::bytesAvailable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[16]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_bytesAvailable);

    if (!sipMeth)
        return ::QBluetoothSocket::bytesAvailable();

    extern ::qint64 sipVH_QtBluetooth_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtBluetooth_11(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qint64 sipQBluetoothSocket::bytesToWrite() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[17]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_bytesToWrite);

    if (!sipMeth)
        return ::QBluetoothSocket::bytesToWrite();

    extern ::qint64 sipVH_QtBluetooth_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtBluetooth_11(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQBluetoothSocket::canReadLine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[18]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_canReadLine);

    if (!sipMeth)
        return ::QBluetoothSocket::canReadLine();

    extern bool sipVH_QtBluetooth_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtBluetooth_10(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQBluetoothSocket::waitForReadyRead(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_waitForReadyRead);

    if (!sipMeth)
        return ::QBluetoothSocket::waitForReadyRead(a0);

    extern bool sipVH_QtBluetooth_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtBluetooth_9(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQBluetoothSocket::waitForBytesWritten(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_waitForBytesWritten);

    if (!sipMeth)
        return ::QBluetoothSocket::waitForBytesWritten(a0);

    extern bool sipVH_QtBluetooth_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtBluetooth_9(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::qint64 sipQBluetoothSocket::readData(char*a0, ::qint64 a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_readData);

    if (!sipMeth)
        return ::QBluetoothSocket::readData(a0, a1);

    extern ::qint64 sipVH_QtBluetooth_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, char*, ::qint64);

    return sipVH_QtBluetooth_8(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::qint64 sipQBluetoothSocket::readLineData(char*a0, ::qint64 a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_readLineData);

    if (!sipMeth)
        return ::QBluetoothSocket::readLineData(a0, a1);

    extern ::qint64 sipVH_QtBluetooth_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, char*, ::qint64);

    return sipVH_QtBluetooth_7(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::qint64 sipQBluetoothSocket::skipData(::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_skipData);

    if (!sipMeth)
        return ::QBluetoothSocket::skipData(a0);

    extern ::qint64 sipVH_QtBluetooth_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qint64);

    return sipVH_QtBluetooth_6(sipGILState, sipImportedVirtErrorHandlers_QtBluetooth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QBluetoothSocket_abort, "abort(self)");

extern "C" {static PyObject *meth_QBluetoothSocket_abort(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_abort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            sipCpp->abort();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_abort, doc_QBluetoothSocket_abort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_close, "close(self)");

extern "C" {static PyObject *meth_QBluetoothSocket_close(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_close(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QBluetoothSocket)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            (sipSelfWasArg ? sipCpp->::QBluetoothSocket::close() : sipCpp->close());
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_close, doc_QBluetoothSocket_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_isSequential, "isSequential(self) -> bool");

extern "C" {static PyObject *meth_QBluetoothSocket_isSequential(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_isSequential(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QBluetoothSocket)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QBluetoothSocket::isSequential() : sipCpp->isSequential());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_isSequential, doc_QBluetoothSocket_isSequential);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_bytesAvailable, "bytesAvailable(self) -> int");

extern "C" {static PyObject *meth_QBluetoothSocket_bytesAvailable(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_bytesAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QBluetoothSocket)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QBluetoothSocket::bytesAvailable() : sipCpp->bytesAvailable());

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_bytesAvailable, doc_QBluetoothSocket_bytesAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_bytesToWrite, "bytesToWrite(self) -> int");

extern "C" {static PyObject *meth_QBluetoothSocket_bytesToWrite(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_bytesToWrite(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QBluetoothSocket)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QBluetoothSocket::bytesToWrite() : sipCpp->bytesToWrite());

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_bytesToWrite, doc_QBluetoothSocket_bytesToWrite);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_canReadLine, "canReadLine(self) -> bool");

extern "C" {static PyObject *meth_QBluetoothSocket_canReadLine(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_canReadLine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QBluetoothSocket)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QBluetoothSocket::canReadLine() : sipCpp->canReadLine());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_canReadLine, doc_QBluetoothSocket_canReadLine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_connectToService, "connectToService(self, address: QBluetoothAddress, uuid: QBluetoothUuid.ServiceClassUuid, mode: QIODeviceBase.OpenModeFlag = QIODeviceBase.ReadWrite)\n"
"connectToService(self, address: QBluetoothAddress, port: int, mode: QIODeviceBase.OpenModeFlag = QIODeviceBase.ReadWrite)\n"
"connectToService(self, address: QBluetoothAddress, uuid: QBluetoothUuid, mode: QIODeviceBase.OpenModeFlag = QIODeviceBase.ReadWrite)\n"
"connectToService(self, service: QBluetoothServiceInfo, mode: QIODeviceBase.OpenModeFlag = QIODeviceBase.ReadWrite)");

extern "C" {static PyObject *meth_QBluetoothSocket_connectToService(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_connectToService(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothAddress* a0;
        ::QBluetoothUuid::ServiceClassUuid a1;
        ::QIODeviceBase::OpenMode a2def = QIODeviceBase::ReadWrite;
        ::QIODeviceBase::OpenMode* a2 = &a2def;
        int a2State = 0;
        ::QBluetoothSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9E|J1", &sipSelf, sipType_QBluetoothSocket, &sipCpp, sipType_QBluetoothAddress, &a0, sipType_QBluetoothUuid_ServiceClassUuid, &a1, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, &a2, &a2State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->connectToService(*a0, a1, *a2);
            Py_END_ALLOW_THREADS
            sipReleaseType(a2, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QBluetoothAddress* a0;
        ::quint16 a1;
        ::QIODeviceBase::OpenMode a2def = QIODeviceBase::ReadWrite;
        ::QIODeviceBase::OpenMode* a2 = &a2def;
        int a2State = 0;
        ::QBluetoothSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9t|J1", &sipSelf, sipType_QBluetoothSocket, &sipCpp, sipType_QBluetoothAddress, &a0, &a1, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, &a2, &a2State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->connectToService(*a0, a1, *a2);
            Py_END_ALLOW_THREADS
            sipReleaseType(a2, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QBluetoothAddress* a0;
        const ::QBluetoothUuid* a1;
        ::QIODeviceBase::OpenMode a2def = QIODeviceBase::ReadWrite;
        ::QIODeviceBase::OpenMode* a2 = &a2def;
        int a2State = 0;
        ::QBluetoothSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9J9|J1", &sipSelf, sipType_QBluetoothSocket, &sipCpp, sipType_QBluetoothAddress, &a0, sipType_QBluetoothUuid, &a1, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, &a2, &a2State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->connectToService(*a0, *a1, *a2);
            Py_END_ALLOW_THREADS
            sipReleaseType(a2, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QBluetoothServiceInfo* a0;
        ::QIODeviceBase::OpenMode a1def = QIODeviceBase::ReadWrite;
        ::QIODeviceBase::OpenMode* a1 = &a1def;
        int a1State = 0;
        ::QBluetoothSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J1", &sipSelf, sipType_QBluetoothSocket, &sipCpp, sipType_QBluetoothServiceInfo, &a0, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, &a1, &a1State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->connectToService(*a0, *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(a1, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_connectToService, doc_QBluetoothSocket_connectToService);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_disconnectFromService, "disconnectFromService(self)");

extern "C" {static PyObject *meth_QBluetoothSocket_disconnectFromService(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_disconnectFromService(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->disconnectFromService();
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_disconnectFromService, doc_QBluetoothSocket_disconnectFromService);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_localName, "localName(self) -> str");

extern "C" {static PyObject *meth_QBluetoothSocket_localName(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_localName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->localName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_localName, doc_QBluetoothSocket_localName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_localAddress, "localAddress(self) -> QBluetoothAddress");

extern "C" {static PyObject *meth_QBluetoothSocket_localAddress(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_localAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::QBluetoothAddress*sipRes;

            sipRes = new ::QBluetoothAddress(sipCpp->localAddress());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothAddress, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_localAddress, doc_QBluetoothSocket_localAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_localPort, "localPort(self) -> int");

extern "C" {static PyObject *meth_QBluetoothSocket_localPort(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_localPort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::quint16 sipRes;

            sipRes = sipCpp->localPort();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_localPort, doc_QBluetoothSocket_localPort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_peerName, "peerName(self) -> str");

extern "C" {static PyObject *meth_QBluetoothSocket_peerName(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_peerName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->peerName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_peerName, doc_QBluetoothSocket_peerName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_peerAddress, "peerAddress(self) -> QBluetoothAddress");

extern "C" {static PyObject *meth_QBluetoothSocket_peerAddress(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_peerAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::QBluetoothAddress*sipRes;

            sipRes = new ::QBluetoothAddress(sipCpp->peerAddress());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothAddress, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_peerAddress, doc_QBluetoothSocket_peerAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_peerPort, "peerPort(self) -> int");

extern "C" {static PyObject *meth_QBluetoothSocket_peerPort(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_peerPort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::quint16 sipRes;

            sipRes = sipCpp->peerPort();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_peerPort, doc_QBluetoothSocket_peerPort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_setSocketDescriptor, "setSocketDescriptor(self, socketDescriptor: int, socketType: QBluetoothServiceInfo.Protocol, state: QBluetoothSocket.SocketState = QBluetoothSocket.SocketState.ConnectedState, mode: QIODeviceBase.OpenModeFlag = QIODeviceBase.ReadWrite) -> bool");

extern "C" {static PyObject *meth_QBluetoothSocket_setSocketDescriptor(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_setSocketDescriptor(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QBluetoothServiceInfo::Protocol a1;
        ::QBluetoothSocket::SocketState a2 = QBluetoothSocket::SocketState::ConnectedState;
        ::QIODeviceBase::OpenMode a3def = QIODeviceBase::ReadWrite;
        ::QIODeviceBase::OpenMode* a3 = &a3def;
        int a3State = 0;
        ::QBluetoothSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_state,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiE|EJ1", &sipSelf, sipType_QBluetoothSocket, &sipCpp, &a0, sipType_QBluetoothServiceInfo_Protocol, &a1, sipType_QBluetoothSocket_SocketState, &a2, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, &a3, &a3State))
        {
            bool sipRes;

            sipRes = sipCpp->setSocketDescriptor(a0, a1, a2, *a3);
            sipReleaseType(a3, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, a3State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_setSocketDescriptor, doc_QBluetoothSocket_setSocketDescriptor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_socketDescriptor, "socketDescriptor(self) -> int");

extern "C" {static PyObject *meth_QBluetoothSocket_socketDescriptor(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_socketDescriptor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->socketDescriptor();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_socketDescriptor, doc_QBluetoothSocket_socketDescriptor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_socketType, "socketType(self) -> QBluetoothServiceInfo.Protocol");

extern "C" {static PyObject *meth_QBluetoothSocket_socketType(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_socketType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::QBluetoothServiceInfo::Protocol sipRes;

            sipRes = sipCpp->socketType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QBluetoothServiceInfo_Protocol);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_socketType, doc_QBluetoothSocket_socketType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_state, "state(self) -> QBluetoothSocket.SocketState");

extern "C" {static PyObject *meth_QBluetoothSocket_state(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::QBluetoothSocket::SocketState sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QBluetoothSocket_SocketState);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_state, doc_QBluetoothSocket_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_error, "error(self) -> QBluetoothSocket.SocketError");

extern "C" {static PyObject *meth_QBluetoothSocket_error(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::QBluetoothSocket::SocketError sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QBluetoothSocket_SocketError);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_error, doc_QBluetoothSocket_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QBluetoothSocket_errorString(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_errorString, doc_QBluetoothSocket_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_readData, "readData(self, maxlen: int) -> bytes");

extern "C" {static PyObject *meth_QBluetoothSocket_readData(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_readData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QBluetoothSocket)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::qint64 a0;
        ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pn", &sipSelf, sipType_QBluetoothSocket, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 94 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothsocket.sip"
        // Return the data read or None if there was an error.
        if (a0 < 0)
        {
            PyErr_SetString(PyExc_ValueError, "maximum length of data to be read cannot be negative");
            sipIsErr = 1;
        }
        else
        {
            char *s = new char[a0];
            qint64 len;
        
            Py_BEGIN_ALLOW_THREADS
        #if defined(SIP_PROTECTED_IS_PUBLIC)
            len = sipSelfWasArg ? sipCpp->QBluetoothSocket::readData(s, a0) : sipCpp->readData(s, a0);
        #else
            len = sipCpp->sipProtectVirt_readData(sipSelfWasArg, s, a0);
        #endif
            Py_END_ALLOW_THREADS
        
            if (len < 0)
            {
                Py_INCREF(Py_None);
                sipRes = Py_None;
            }
            else
            {
                sipRes = PyBytes_FromStringAndSize(s, len);
        
                if (!sipRes)
                    sipIsErr = 1;
            }
        
            delete[] s;
        }
#line 1267 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothSocket.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_readData, doc_QBluetoothSocket_readData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_writeData, "writeData(self, data: PyQt6.sip.array[bytes]) -> int");

extern "C" {static PyObject *meth_QBluetoothSocket_writeData(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_writeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QBluetoothSocket)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const char* a0;
        Py_ssize_t a1;
        ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pk", &sipSelf, sipType_QBluetoothSocket, &sipCpp, &a0, &a1))
        {
            ::qint64 sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp->::QBluetoothSocket::writeData(a0, (long long)a1) : sipCpp->writeData(a0, (long long)a1));
            Py_END_ALLOW_THREADS

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_writeData, doc_QBluetoothSocket_writeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_setSocketState, "setSocketState(self, state: QBluetoothSocket.SocketState)");

extern "C" {static PyObject *meth_QBluetoothSocket_setSocketState(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_setSocketState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothSocket::SocketState a0;
        ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QBluetoothSocket, &sipCpp, sipType_QBluetoothSocket_SocketState, &a0))
        {
            sipCpp->setSocketState(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_setSocketState, doc_QBluetoothSocket_setSocketState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_setSocketError, "setSocketError(self, error: QBluetoothSocket.SocketError)");

extern "C" {static PyObject *meth_QBluetoothSocket_setSocketError(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_setSocketError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetoothSocket::SocketError a0;
        ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QBluetoothSocket, &sipCpp, sipType_QBluetoothSocket_SocketError, &a0))
        {
            sipCpp->setSocketError(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_setSocketError, doc_QBluetoothSocket_setSocketError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_doDeviceDiscovery, "doDeviceDiscovery(self, service: QBluetoothServiceInfo, openMode: QIODeviceBase.OpenModeFlag)");

extern "C" {static PyObject *meth_QBluetoothSocket_doDeviceDiscovery(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_doDeviceDiscovery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothServiceInfo* a0;
        ::QIODeviceBase::OpenMode* a1;
        int a1State = 0;
        ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9J1", &sipSelf, sipType_QBluetoothSocket, &sipCpp, sipType_QBluetoothServiceInfo, &a0, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, &a1, &a1State))
        {
            sipCpp->doDeviceDiscovery(*a0, *a1);
            sipReleaseType(a1, sipType_QFlags_0100QIODeviceBase_OpenModeFlag, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_doDeviceDiscovery, doc_QBluetoothSocket_doDeviceDiscovery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_setPreferredSecurityFlags, "setPreferredSecurityFlags(self, flags: QBluetooth.Security)");

extern "C" {static PyObject *meth_QBluetoothSocket_setPreferredSecurityFlags(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_setPreferredSecurityFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBluetooth::SecurityFlags* a0;
        int a0State = 0;
        ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QBluetoothSocket, &sipCpp, sipType_QFlags_0100QBluetooth_Security, &a0, &a0State))
        {
            sipCpp->setPreferredSecurityFlags(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QBluetooth_Security, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_setPreferredSecurityFlags, doc_QBluetoothSocket_setPreferredSecurityFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothSocket_preferredSecurityFlags, "preferredSecurityFlags(self) -> QBluetooth.Security");

extern "C" {static PyObject *meth_QBluetoothSocket_preferredSecurityFlags(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothSocket_preferredSecurityFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothSocket, &sipCpp))
        {
            ::QBluetooth::SecurityFlags*sipRes;

            sipRes = new ::QBluetooth::SecurityFlags(sipCpp->preferredSecurityFlags());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QBluetooth_Security, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothSocket, sipName_preferredSecurityFlags, doc_QBluetoothSocket_preferredSecurityFlags);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QBluetoothSocket(void *, const sipTypeDef *);}
static void *cast_QBluetoothSocket(void *sipCppV, const sipTypeDef *targetType)
{
    ::QBluetoothSocket *sipCpp = reinterpret_cast< ::QBluetoothSocket *>(sipCppV);

    if (targetType == sipType_QBluetoothSocket)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QIODevice)->ctd_cast(static_cast< ::QIODevice *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QBluetoothSocket(void *, int);}
static void release_QBluetoothSocket(void *sipCppV, int)
{
    ::QBluetoothSocket *sipCpp = reinterpret_cast< ::QBluetoothSocket *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QBluetoothSocket(Py_ssize_t);}
static void *array_QBluetoothSocket(Py_ssize_t sipNrElem)
{
    return new ::QBluetoothSocket[sipNrElem];
}


extern "C" {static void array_delete_QBluetoothSocket(void *);}
static void array_delete_QBluetoothSocket(void *sipCpp)
{
    delete[] reinterpret_cast< ::QBluetoothSocket *>(sipCpp);
}


extern "C" {static void dealloc_QBluetoothSocket(sipSimpleWrapper *);}
static void dealloc_QBluetoothSocket(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQBluetoothSocket *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QBluetoothSocket(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QBluetoothSocket(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QBluetoothSocket(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQBluetoothSocket *sipCpp = SIP_NULLPTR;

    {
        ::QBluetoothServiceInfo::Protocol a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|JH", sipType_QBluetoothServiceInfo_Protocol, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQBluetoothSocket(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQBluetoothSocket(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QBluetoothSocket[] = {{5, 0, 1}};


static PyMethodDef methods_QBluetoothSocket[] = {
    {sipName_abort, meth_QBluetoothSocket_abort, METH_VARARGS, doc_QBluetoothSocket_abort},
    {sipName_bytesAvailable, meth_QBluetoothSocket_bytesAvailable, METH_VARARGS, doc_QBluetoothSocket_bytesAvailable},
    {sipName_bytesToWrite, meth_QBluetoothSocket_bytesToWrite, METH_VARARGS, doc_QBluetoothSocket_bytesToWrite},
    {sipName_canReadLine, meth_QBluetoothSocket_canReadLine, METH_VARARGS, doc_QBluetoothSocket_canReadLine},
    {sipName_close, meth_QBluetoothSocket_close, METH_VARARGS, doc_QBluetoothSocket_close},
    {sipName_connectToService, SIP_MLMETH_CAST(meth_QBluetoothSocket_connectToService), METH_VARARGS|METH_KEYWORDS, doc_QBluetoothSocket_connectToService},
    {sipName_disconnectFromService, meth_QBluetoothSocket_disconnectFromService, METH_VARARGS, doc_QBluetoothSocket_disconnectFromService},
    {sipName_doDeviceDiscovery, meth_QBluetoothSocket_doDeviceDiscovery, METH_VARARGS, doc_QBluetoothSocket_doDeviceDiscovery},
    {sipName_error, meth_QBluetoothSocket_error, METH_VARARGS, doc_QBluetoothSocket_error},
    {sipName_errorString, meth_QBluetoothSocket_errorString, METH_VARARGS, doc_QBluetoothSocket_errorString},
    {sipName_isSequential, meth_QBluetoothSocket_isSequential, METH_VARARGS, doc_QBluetoothSocket_isSequential},
    {sipName_localAddress, meth_QBluetoothSocket_localAddress, METH_VARARGS, doc_QBluetoothSocket_localAddress},
    {sipName_localName, meth_QBluetoothSocket_localName, METH_VARARGS, doc_QBluetoothSocket_localName},
    {sipName_localPort, meth_QBluetoothSocket_localPort, METH_VARARGS, doc_QBluetoothSocket_localPort},
    {sipName_peerAddress, meth_QBluetoothSocket_peerAddress, METH_VARARGS, doc_QBluetoothSocket_peerAddress},
    {sipName_peerName, meth_QBluetoothSocket_peerName, METH_VARARGS, doc_QBluetoothSocket_peerName},
    {sipName_peerPort, meth_QBluetoothSocket_peerPort, METH_VARARGS, doc_QBluetoothSocket_peerPort},
    {sipName_preferredSecurityFlags, meth_QBluetoothSocket_preferredSecurityFlags, METH_VARARGS, doc_QBluetoothSocket_preferredSecurityFlags},
    {sipName_readData, meth_QBluetoothSocket_readData, METH_VARARGS, doc_QBluetoothSocket_readData},
    {sipName_setPreferredSecurityFlags, meth_QBluetoothSocket_setPreferredSecurityFlags, METH_VARARGS, doc_QBluetoothSocket_setPreferredSecurityFlags},
    {sipName_setSocketDescriptor, SIP_MLMETH_CAST(meth_QBluetoothSocket_setSocketDescriptor), METH_VARARGS|METH_KEYWORDS, doc_QBluetoothSocket_setSocketDescriptor},
    {sipName_setSocketError, meth_QBluetoothSocket_setSocketError, METH_VARARGS, doc_QBluetoothSocket_setSocketError},
    {sipName_setSocketState, meth_QBluetoothSocket_setSocketState, METH_VARARGS, doc_QBluetoothSocket_setSocketState},
    {sipName_socketDescriptor, meth_QBluetoothSocket_socketDescriptor, METH_VARARGS, doc_QBluetoothSocket_socketDescriptor},
    {sipName_socketType, meth_QBluetoothSocket_socketType, METH_VARARGS, doc_QBluetoothSocket_socketType},
    {sipName_state, meth_QBluetoothSocket_state, METH_VARARGS, doc_QBluetoothSocket_state},
    {sipName_writeData, meth_QBluetoothSocket_writeData, METH_VARARGS, doc_QBluetoothSocket_writeData}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QBluetoothSocket[] = {
    {sipName_NoSocketError, static_cast<int>(::QBluetoothSocket::SocketError::NoSocketError)},
    {sipName_UnknownSocketError, static_cast<int>(::QBluetoothSocket::SocketError::UnknownSocketError)},
    {sipName_RemoteHostClosedError, static_cast<int>(::QBluetoothSocket::SocketError::RemoteHostClosedError)},
    {sipName_HostNotFoundError, static_cast<int>(::QBluetoothSocket::SocketError::HostNotFoundError)},
    {sipName_ServiceNotFoundError, static_cast<int>(::QBluetoothSocket::SocketError::ServiceNotFoundError)},
    {sipName_NetworkError, static_cast<int>(::QBluetoothSocket::SocketError::NetworkError)},
    {sipName_UnsupportedProtocolError, static_cast<int>(::QBluetoothSocket::SocketError::UnsupportedProtocolError)},
    {sipName_OperationError, static_cast<int>(::QBluetoothSocket::SocketError::OperationError)},
    {sipName_MissingPermissionsError, static_cast<int>(::QBluetoothSocket::SocketError::MissingPermissionsError)},
    {sipName_UnconnectedState, static_cast<int>(::QBluetoothSocket::SocketState::UnconnectedState)},
    {sipName_ServiceLookupState, static_cast<int>(::QBluetoothSocket::SocketState::ServiceLookupState)},
    {sipName_ConnectingState, static_cast<int>(::QBluetoothSocket::SocketState::ConnectingState)},
    {sipName_ConnectedState, static_cast<int>(::QBluetoothSocket::SocketState::ConnectedState)},
    {sipName_BoundState, static_cast<int>(::QBluetoothSocket::SocketState::BoundState)},
    {sipName_ClosingState, static_cast<int>(::QBluetoothSocket::SocketState::ClosingState)},
    {sipName_ListeningState, static_cast<int>(::QBluetoothSocket::SocketState::ListeningState)},
    {0, 0}
};

PyDoc_STRVAR(doc_QBluetoothSocket, "\1QBluetoothSocket(socketType: QBluetoothServiceInfo.Protocol, parent: QObject|None = None)\n"
"QBluetoothSocket(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QBluetoothSocket[] = {
    {"stateChanged(QBluetoothSocket::SocketState)", "\1stateChanged(self, state: QBluetoothSocket.SocketState)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorOccurred(QBluetoothSocket::SocketError)", "\1errorOccurred(self, error: QBluetoothSocket.SocketError)", SIP_NULLPTR, SIP_NULLPTR},
    {"disconnected()", "\1disconnected(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"connected()", "\1connected(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QBluetoothSocket = {
    &::QBluetoothSocket::staticMetaObject,
    signals_QBluetoothSocket,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothSocket = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QBluetoothSocket,
        SIP_NULLPTR,
        &plugin_QBluetoothSocket,
    },
    {
        sipNameNr_QBluetoothSocket,
        {0, 0, 1},
        27, methods_QBluetoothSocket,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QBluetoothSocket, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QBluetoothSocket,
    -1,
    -1,
    supers_QBluetoothSocket,
    SIP_NULLPTR,
    init_type_QBluetoothSocket,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QBluetoothSocket,
    SIP_NULLPTR,
    array_QBluetoothSocket,
    SIP_NULLPTR,
    release_QBluetoothSocket,
    cast_QBluetoothSocket,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QBluetoothSocket,
    sizeof (::QBluetoothSocket),
};
