/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qchar.sip"
#include <qchar.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQChar.cpp"



extern "C" {static PyObject *slot_QChar___eq__(PyObject *, PyObject *);}
static PyObject *slot_QChar___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QChar *sipCpp = reinterpret_cast< ::QChar *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QChar));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QChar* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QChar, &a0, &a0State))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);
            sipReleaseType(const_cast< ::QChar *>(a0), sipType_QChar, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QChar, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QChar___ne__(PyObject *, PyObject *);}
static PyObject *slot_QChar___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QChar *sipCpp = reinterpret_cast< ::QChar *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QChar));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QChar* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QChar, &a0, &a0State))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);
            sipReleaseType(const_cast< ::QChar *>(a0), sipType_QChar, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QChar, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QChar___ge__(PyObject *, PyObject *);}
static PyObject *slot_QChar___ge__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QChar *sipCpp = reinterpret_cast< ::QChar *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QChar));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QChar* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QChar, &a0, &a0State))
        {
            bool sipRes;

            sipRes = operator>=((*sipCpp), *a0);
            sipReleaseType(const_cast< ::QChar *>(a0), sipType_QChar, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ge_slot, sipType_QChar, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QChar___le__(PyObject *, PyObject *);}
static PyObject *slot_QChar___le__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QChar *sipCpp = reinterpret_cast< ::QChar *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QChar));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QChar* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QChar, &a0, &a0State))
        {
            bool sipRes;

            sipRes = operator<=((*sipCpp), *a0);
            sipReleaseType(const_cast< ::QChar *>(a0), sipType_QChar, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, le_slot, sipType_QChar, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QChar___gt__(PyObject *, PyObject *);}
static PyObject *slot_QChar___gt__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QChar *sipCpp = reinterpret_cast< ::QChar *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QChar));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QChar* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QChar, &a0, &a0State))
        {
            bool sipRes;

            sipRes = operator>((*sipCpp), *a0);
            sipReleaseType(const_cast< ::QChar *>(a0), sipType_QChar, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, gt_slot, sipType_QChar, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QChar___lt__(PyObject *, PyObject *);}
static PyObject *slot_QChar___lt__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QChar *sipCpp = reinterpret_cast< ::QChar *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QChar));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QChar* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QChar, &a0, &a0State))
        {
            bool sipRes;

            sipRes = operator<((*sipCpp), *a0);
            sipReleaseType(const_cast< ::QChar *>(a0), sipType_QChar, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, lt_slot, sipType_QChar, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QChar(void *, int);}
static void release_QChar(void *sipCppV, int)
{
    delete reinterpret_cast< ::QChar *>(sipCppV);
}


extern "C" {static void *array_QChar(Py_ssize_t);}
static void *array_QChar(Py_ssize_t sipNrElem)
{
    return new ::QChar[sipNrElem];
}


extern "C" {static void array_delete_QChar(void *);}
static void array_delete_QChar(void *sipCpp)
{
    delete[] reinterpret_cast< ::QChar *>(sipCpp);
}


extern "C" {static void assign_QChar(void *, Py_ssize_t, void *);}
static void assign_QChar(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QChar *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QChar *>(sipSrc);
}


extern "C" {static void *copy_QChar(const void *, Py_ssize_t);}
static void *copy_QChar(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QChar(reinterpret_cast<const ::QChar *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QChar(sipSimpleWrapper *);}
static void dealloc_QChar(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QChar(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QChar(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QChar(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QChar *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QChar();

            return sipCpp;
        }
    }

    {
        const ::QChar* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QChar, &a0, &a0State))
        {
            sipCpp = new ::QChar(*a0);
            sipReleaseType(const_cast< ::QChar *>(a0), sipType_QChar, a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static int convertTo_QChar(PyObject *, void **, int *, PyObject *, void **);}
static int convertTo_QChar(PyObject *sipPy, void **sipCppPtrV, int *sipIsErr, PyObject *sipTransferObj, void **)
{
    ::QChar **sipCppPtr = reinterpret_cast< ::QChar **>(sipCppPtrV);

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qchar.sip"
if (sipIsErr == NULL)
    return PyUnicode_Check(sipPy);

// TODO: review replacing with something more efficient.
QString qs = qpycore_PyObject_AsQString(sipPy);

if (qs.size() != 1)
{
    PyErr_SetString(PyExc_ValueError, "string of length 1 expected");
    *sipIsErr = 1;
    return 0;
}

*sipCppPtr = new QChar(qs.at(0));

return sipGetState(sipTransferObj);
#line 318 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQChar.cpp"
}


extern "C" {static PyObject *convertFrom_QChar(void *, PyObject *);}
static PyObject *convertFrom_QChar(void *sipCppV, PyObject *)
{
    ::QChar *sipCpp = reinterpret_cast< ::QChar *>(sipCppV);

#line 49 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qchar.sip"
// TODO: replace with...
// return PyUnicode_FromKindAndData(PyUnicode_2BYTE_KIND, sipCpp, 1);
return qpycore_PyObject_FromQString(QString(*sipCpp));
#line 331 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQChar.cpp"
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QChar[] = {
    {(void *)slot_QChar___eq__, eq_slot},
    {(void *)slot_QChar___ne__, ne_slot},
    {(void *)slot_QChar___ge__, ge_slot},
    {(void *)slot_QChar___le__, le_slot},
    {(void *)slot_QChar___gt__, gt_slot},
    {(void *)slot_QChar___lt__, lt_slot},
    {0, (sipPySlotType)0}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QChar[] = {
    {sipName_Script_Unknown, static_cast<int>(::QChar::Script_Unknown)},
    {sipName_Script_Inherited, static_cast<int>(::QChar::Script_Inherited)},
    {sipName_Script_Common, static_cast<int>(::QChar::Script_Common)},
    {sipName_Script_Latin, static_cast<int>(::QChar::Script_Latin)},
    {sipName_Script_Greek, static_cast<int>(::QChar::Script_Greek)},
    {sipName_Script_Cyrillic, static_cast<int>(::QChar::Script_Cyrillic)},
    {sipName_Script_Armenian, static_cast<int>(::QChar::Script_Armenian)},
    {sipName_Script_Hebrew, static_cast<int>(::QChar::Script_Hebrew)},
    {sipName_Script_Arabic, static_cast<int>(::QChar::Script_Arabic)},
    {sipName_Script_Syriac, static_cast<int>(::QChar::Script_Syriac)},
    {sipName_Script_Thaana, static_cast<int>(::QChar::Script_Thaana)},
    {sipName_Script_Devanagari, static_cast<int>(::QChar::Script_Devanagari)},
    {sipName_Script_Bengali, static_cast<int>(::QChar::Script_Bengali)},
    {sipName_Script_Gurmukhi, static_cast<int>(::QChar::Script_Gurmukhi)},
    {sipName_Script_Gujarati, static_cast<int>(::QChar::Script_Gujarati)},
    {sipName_Script_Oriya, static_cast<int>(::QChar::Script_Oriya)},
    {sipName_Script_Tamil, static_cast<int>(::QChar::Script_Tamil)},
    {sipName_Script_Telugu, static_cast<int>(::QChar::Script_Telugu)},
    {sipName_Script_Kannada, static_cast<int>(::QChar::Script_Kannada)},
    {sipName_Script_Malayalam, static_cast<int>(::QChar::Script_Malayalam)},
    {sipName_Script_Sinhala, static_cast<int>(::QChar::Script_Sinhala)},
    {sipName_Script_Thai, static_cast<int>(::QChar::Script_Thai)},
    {sipName_Script_Lao, static_cast<int>(::QChar::Script_Lao)},
    {sipName_Script_Tibetan, static_cast<int>(::QChar::Script_Tibetan)},
    {sipName_Script_Myanmar, static_cast<int>(::QChar::Script_Myanmar)},
    {sipName_Script_Georgian, static_cast<int>(::QChar::Script_Georgian)},
    {sipName_Script_Hangul, static_cast<int>(::QChar::Script_Hangul)},
    {sipName_Script_Ethiopic, static_cast<int>(::QChar::Script_Ethiopic)},
    {sipName_Script_Cherokee, static_cast<int>(::QChar::Script_Cherokee)},
    {sipName_Script_CanadianAboriginal, static_cast<int>(::QChar::Script_CanadianAboriginal)},
    {sipName_Script_Ogham, static_cast<int>(::QChar::Script_Ogham)},
    {sipName_Script_Runic, static_cast<int>(::QChar::Script_Runic)},
    {sipName_Script_Khmer, static_cast<int>(::QChar::Script_Khmer)},
    {sipName_Script_Mongolian, static_cast<int>(::QChar::Script_Mongolian)},
    {sipName_Script_Hiragana, static_cast<int>(::QChar::Script_Hiragana)},
    {sipName_Script_Katakana, static_cast<int>(::QChar::Script_Katakana)},
    {sipName_Script_Bopomofo, static_cast<int>(::QChar::Script_Bopomofo)},
    {sipName_Script_Han, static_cast<int>(::QChar::Script_Han)},
    {sipName_Script_Yi, static_cast<int>(::QChar::Script_Yi)},
    {sipName_Script_OldItalic, static_cast<int>(::QChar::Script_OldItalic)},
    {sipName_Script_Gothic, static_cast<int>(::QChar::Script_Gothic)},
    {sipName_Script_Deseret, static_cast<int>(::QChar::Script_Deseret)},
    {sipName_Script_Tagalog, static_cast<int>(::QChar::Script_Tagalog)},
    {sipName_Script_Hanunoo, static_cast<int>(::QChar::Script_Hanunoo)},
    {sipName_Script_Buhid, static_cast<int>(::QChar::Script_Buhid)},
    {sipName_Script_Tagbanwa, static_cast<int>(::QChar::Script_Tagbanwa)},
    {sipName_Script_Coptic, static_cast<int>(::QChar::Script_Coptic)},
    {sipName_Script_Limbu, static_cast<int>(::QChar::Script_Limbu)},
    {sipName_Script_TaiLe, static_cast<int>(::QChar::Script_TaiLe)},
    {sipName_Script_LinearB, static_cast<int>(::QChar::Script_LinearB)},
    {sipName_Script_Ugaritic, static_cast<int>(::QChar::Script_Ugaritic)},
    {sipName_Script_Shavian, static_cast<int>(::QChar::Script_Shavian)},
    {sipName_Script_Osmanya, static_cast<int>(::QChar::Script_Osmanya)},
    {sipName_Script_Cypriot, static_cast<int>(::QChar::Script_Cypriot)},
    {sipName_Script_Braille, static_cast<int>(::QChar::Script_Braille)},
    {sipName_Script_Buginese, static_cast<int>(::QChar::Script_Buginese)},
    {sipName_Script_NewTaiLue, static_cast<int>(::QChar::Script_NewTaiLue)},
    {sipName_Script_Glagolitic, static_cast<int>(::QChar::Script_Glagolitic)},
    {sipName_Script_Tifinagh, static_cast<int>(::QChar::Script_Tifinagh)},
    {sipName_Script_SylotiNagri, static_cast<int>(::QChar::Script_SylotiNagri)},
    {sipName_Script_OldPersian, static_cast<int>(::QChar::Script_OldPersian)},
    {sipName_Script_Kharoshthi, static_cast<int>(::QChar::Script_Kharoshthi)},
    {sipName_Script_Balinese, static_cast<int>(::QChar::Script_Balinese)},
    {sipName_Script_Cuneiform, static_cast<int>(::QChar::Script_Cuneiform)},
    {sipName_Script_Phoenician, static_cast<int>(::QChar::Script_Phoenician)},
    {sipName_Script_PhagsPa, static_cast<int>(::QChar::Script_PhagsPa)},
    {sipName_Script_Nko, static_cast<int>(::QChar::Script_Nko)},
    {sipName_Script_Sundanese, static_cast<int>(::QChar::Script_Sundanese)},
    {sipName_Script_Lepcha, static_cast<int>(::QChar::Script_Lepcha)},
    {sipName_Script_OlChiki, static_cast<int>(::QChar::Script_OlChiki)},
    {sipName_Script_Vai, static_cast<int>(::QChar::Script_Vai)},
    {sipName_Script_Saurashtra, static_cast<int>(::QChar::Script_Saurashtra)},
    {sipName_Script_KayahLi, static_cast<int>(::QChar::Script_KayahLi)},
    {sipName_Script_Rejang, static_cast<int>(::QChar::Script_Rejang)},
    {sipName_Script_Lycian, static_cast<int>(::QChar::Script_Lycian)},
    {sipName_Script_Carian, static_cast<int>(::QChar::Script_Carian)},
    {sipName_Script_Lydian, static_cast<int>(::QChar::Script_Lydian)},
    {sipName_Script_Cham, static_cast<int>(::QChar::Script_Cham)},
    {sipName_Script_TaiTham, static_cast<int>(::QChar::Script_TaiTham)},
    {sipName_Script_TaiViet, static_cast<int>(::QChar::Script_TaiViet)},
    {sipName_Script_Avestan, static_cast<int>(::QChar::Script_Avestan)},
    {sipName_Script_EgyptianHieroglyphs, static_cast<int>(::QChar::Script_EgyptianHieroglyphs)},
    {sipName_Script_Samaritan, static_cast<int>(::QChar::Script_Samaritan)},
    {sipName_Script_Lisu, static_cast<int>(::QChar::Script_Lisu)},
    {sipName_Script_Bamum, static_cast<int>(::QChar::Script_Bamum)},
    {sipName_Script_Javanese, static_cast<int>(::QChar::Script_Javanese)},
    {sipName_Script_MeeteiMayek, static_cast<int>(::QChar::Script_MeeteiMayek)},
    {sipName_Script_ImperialAramaic, static_cast<int>(::QChar::Script_ImperialAramaic)},
    {sipName_Script_OldSouthArabian, static_cast<int>(::QChar::Script_OldSouthArabian)},
    {sipName_Script_InscriptionalParthian, static_cast<int>(::QChar::Script_InscriptionalParthian)},
    {sipName_Script_InscriptionalPahlavi, static_cast<int>(::QChar::Script_InscriptionalPahlavi)},
    {sipName_Script_OldTurkic, static_cast<int>(::QChar::Script_OldTurkic)},
    {sipName_Script_Kaithi, static_cast<int>(::QChar::Script_Kaithi)},
    {sipName_Script_Batak, static_cast<int>(::QChar::Script_Batak)},
    {sipName_Script_Brahmi, static_cast<int>(::QChar::Script_Brahmi)},
    {sipName_Script_Mandaic, static_cast<int>(::QChar::Script_Mandaic)},
    {sipName_Script_Chakma, static_cast<int>(::QChar::Script_Chakma)},
    {sipName_Script_MeroiticCursive, static_cast<int>(::QChar::Script_MeroiticCursive)},
    {sipName_Script_MeroiticHieroglyphs, static_cast<int>(::QChar::Script_MeroiticHieroglyphs)},
    {sipName_Script_Miao, static_cast<int>(::QChar::Script_Miao)},
    {sipName_Script_Sharada, static_cast<int>(::QChar::Script_Sharada)},
    {sipName_Script_SoraSompeng, static_cast<int>(::QChar::Script_SoraSompeng)},
    {sipName_Script_Takri, static_cast<int>(::QChar::Script_Takri)},
    {sipName_Script_CaucasianAlbanian, static_cast<int>(::QChar::Script_CaucasianAlbanian)},
    {sipName_Script_BassaVah, static_cast<int>(::QChar::Script_BassaVah)},
    {sipName_Script_Duployan, static_cast<int>(::QChar::Script_Duployan)},
    {sipName_Script_Elbasan, static_cast<int>(::QChar::Script_Elbasan)},
    {sipName_Script_Grantha, static_cast<int>(::QChar::Script_Grantha)},
    {sipName_Script_PahawhHmong, static_cast<int>(::QChar::Script_PahawhHmong)},
    {sipName_Script_Khojki, static_cast<int>(::QChar::Script_Khojki)},
    {sipName_Script_LinearA, static_cast<int>(::QChar::Script_LinearA)},
    {sipName_Script_Mahajani, static_cast<int>(::QChar::Script_Mahajani)},
    {sipName_Script_Manichaean, static_cast<int>(::QChar::Script_Manichaean)},
    {sipName_Script_MendeKikakui, static_cast<int>(::QChar::Script_MendeKikakui)},
    {sipName_Script_Modi, static_cast<int>(::QChar::Script_Modi)},
    {sipName_Script_Mro, static_cast<int>(::QChar::Script_Mro)},
    {sipName_Script_OldNorthArabian, static_cast<int>(::QChar::Script_OldNorthArabian)},
    {sipName_Script_Nabataean, static_cast<int>(::QChar::Script_Nabataean)},
    {sipName_Script_Palmyrene, static_cast<int>(::QChar::Script_Palmyrene)},
    {sipName_Script_PauCinHau, static_cast<int>(::QChar::Script_PauCinHau)},
    {sipName_Script_OldPermic, static_cast<int>(::QChar::Script_OldPermic)},
    {sipName_Script_PsalterPahlavi, static_cast<int>(::QChar::Script_PsalterPahlavi)},
    {sipName_Script_Siddham, static_cast<int>(::QChar::Script_Siddham)},
    {sipName_Script_Khudawadi, static_cast<int>(::QChar::Script_Khudawadi)},
    {sipName_Script_Tirhuta, static_cast<int>(::QChar::Script_Tirhuta)},
    {sipName_Script_WarangCiti, static_cast<int>(::QChar::Script_WarangCiti)},
    {sipName_Script_Ahom, static_cast<int>(::QChar::Script_Ahom)},
    {sipName_Script_AnatolianHieroglyphs, static_cast<int>(::QChar::Script_AnatolianHieroglyphs)},
    {sipName_Script_Hatran, static_cast<int>(::QChar::Script_Hatran)},
    {sipName_Script_Multani, static_cast<int>(::QChar::Script_Multani)},
    {sipName_Script_OldHungarian, static_cast<int>(::QChar::Script_OldHungarian)},
    {sipName_Script_SignWriting, static_cast<int>(::QChar::Script_SignWriting)},
    {sipName_Script_Adlam, static_cast<int>(::QChar::Script_Adlam)},
    {sipName_Script_Bhaiksuki, static_cast<int>(::QChar::Script_Bhaiksuki)},
    {sipName_Script_Marchen, static_cast<int>(::QChar::Script_Marchen)},
    {sipName_Script_Newa, static_cast<int>(::QChar::Script_Newa)},
    {sipName_Script_Osage, static_cast<int>(::QChar::Script_Osage)},
    {sipName_Script_Tangut, static_cast<int>(::QChar::Script_Tangut)},
    {sipName_Script_MasaramGondi, static_cast<int>(::QChar::Script_MasaramGondi)},
    {sipName_Script_Nushu, static_cast<int>(::QChar::Script_Nushu)},
    {sipName_Script_Soyombo, static_cast<int>(::QChar::Script_Soyombo)},
    {sipName_Script_ZanabazarSquare, static_cast<int>(::QChar::Script_ZanabazarSquare)},
    {sipName_Script_Dogra, static_cast<int>(::QChar::Script_Dogra)},
    {sipName_Script_GunjalaGondi, static_cast<int>(::QChar::Script_GunjalaGondi)},
    {sipName_Script_HanifiRohingya, static_cast<int>(::QChar::Script_HanifiRohingya)},
    {sipName_Script_Makasar, static_cast<int>(::QChar::Script_Makasar)},
    {sipName_Script_Medefaidrin, static_cast<int>(::QChar::Script_Medefaidrin)},
    {sipName_Script_OldSogdian, static_cast<int>(::QChar::Script_OldSogdian)},
    {sipName_Script_Sogdian, static_cast<int>(::QChar::Script_Sogdian)},
    {sipName_Script_Elymaic, static_cast<int>(::QChar::Script_Elymaic)},
    {sipName_Script_Nandinagari, static_cast<int>(::QChar::Script_Nandinagari)},
    {sipName_Script_NyiakengPuachueHmong, static_cast<int>(::QChar::Script_NyiakengPuachueHmong)},
    {sipName_Script_Wancho, static_cast<int>(::QChar::Script_Wancho)},
    {sipName_Script_Chorasmian, static_cast<int>(::QChar::Script_Chorasmian)},
    {sipName_Script_DivesAkuru, static_cast<int>(::QChar::Script_DivesAkuru)},
    {sipName_Script_KhitanSmallScript, static_cast<int>(::QChar::Script_KhitanSmallScript)},
    {sipName_Script_Yezidi, static_cast<int>(::QChar::Script_Yezidi)},
    {sipName_Script_CyproMinoan, static_cast<int>(::QChar::Script_CyproMinoan)},
    {sipName_Script_NagMundari, static_cast<int>(::QChar::Script_NagMundari)},
    {sipName_Script_OldUyghur, static_cast<int>(::QChar::Script_OldUyghur)},
    {sipName_Script_Tangsa, static_cast<int>(::QChar::Script_Tangsa)},
    {sipName_Script_Toto, static_cast<int>(::QChar::Script_Toto)},
    {sipName_Script_Vithkuqi, static_cast<int>(::QChar::Script_Vithkuqi)},
    {sipName_Script_Kawi, static_cast<int>(::QChar::Script_Kawi)},
    {sipName_Script_Garay, static_cast<int>(::QChar::Script_Garay)},
    {sipName_Script_GurungKhema, static_cast<int>(::QChar::Script_GurungKhema)},
    {sipName_Script_KiratRai, static_cast<int>(::QChar::Script_KiratRai)},
    {sipName_Script_OlOnal, static_cast<int>(::QChar::Script_OlOnal)},
    {sipName_Script_Sunuwar, static_cast<int>(::QChar::Script_Sunuwar)},
    {sipName_Script_Todhri, static_cast<int>(::QChar::Script_Todhri)},
    {sipName_Script_TuluTigalari, static_cast<int>(::QChar::Script_TuluTigalari)},
    {sipName_Script_Sidetic, static_cast<int>(::QChar::Script_Sidetic)},
    {sipName_Script_TaiYo, static_cast<int>(::QChar::Script_TaiYo)},
    {sipName_Script_TolongSiki, static_cast<int>(::QChar::Script_TolongSiki)},
    {sipName_Script_BeriaErfe, static_cast<int>(::QChar::Script_BeriaErfe)},
    {0, 0}
};

PyDoc_STRVAR(doc_QChar, "\1QChar()\n"
"QChar(a0: QChar)");


sipClassTypeDef sipTypeDef_QtCore_QChar = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QChar,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QChar,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QChar, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QChar,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QChar,
    init_type_QChar,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QChar,
    assign_QChar,
    array_QChar,
    copy_QChar,
    release_QChar,
    SIP_NULLPTR,
    convertTo_QChar,
    convertFrom_QChar,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QChar,
    sizeof (::QChar),
};
