/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtRemoteObjects.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectreplica.sip"
#include <qremoteobjectreplica.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"

#line 44 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtRemoteObjects/qremoteobjectnode.sip"
#include <qremoteobjectnode.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtRemoteObjects/sipQtRemoteObjectsQRemoteObjectReplica.cpp"


PyDoc_STRVAR(doc_QRemoteObjectReplica_isReplicaValid, "isReplicaValid(self) -> bool");

extern "C" {static PyObject *meth_QRemoteObjectReplica_isReplicaValid(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectReplica_isReplicaValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectReplica *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRemoteObjectReplica, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isReplicaValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectReplica, sipName_isReplicaValid, doc_QRemoteObjectReplica_isReplicaValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectReplica_waitForSource, "waitForSource(self, timeout: int = 30000) -> bool");

extern "C" {static PyObject *meth_QRemoteObjectReplica_waitForSource(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectReplica_waitForSource(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = 30000;
        ::QRemoteObjectReplica *sipCpp;

        static const char *sipKwdList[] = {
            sipName_timeout,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QRemoteObjectReplica, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->waitForSource(a0);
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectReplica, sipName_waitForSource, doc_QRemoteObjectReplica_waitForSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectReplica_isInitialized, "isInitialized(self) -> bool");

extern "C" {static PyObject *meth_QRemoteObjectReplica_isInitialized(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectReplica_isInitialized(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectReplica *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRemoteObjectReplica, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isInitialized();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectReplica, sipName_isInitialized, doc_QRemoteObjectReplica_isInitialized);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectReplica_state, "state(self) -> QRemoteObjectReplica.State");

extern "C" {static PyObject *meth_QRemoteObjectReplica_state(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectReplica_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectReplica *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRemoteObjectReplica, &sipCpp))
        {
            ::QRemoteObjectReplica::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRemoteObjectReplica_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectReplica, sipName_state, doc_QRemoteObjectReplica_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectReplica_node, "node(self) -> QRemoteObjectNode|None");

extern "C" {static PyObject *meth_QRemoteObjectReplica_node(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectReplica_node(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRemoteObjectReplica *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRemoteObjectReplica, &sipCpp))
        {
            ::QRemoteObjectNode*sipRes;

            sipRes = sipCpp->node();

            return sipConvertFromType(sipRes, sipType_QRemoteObjectNode, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectReplica, sipName_node, doc_QRemoteObjectReplica_node);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRemoteObjectReplica_setNode, "setNode(self, node: QRemoteObjectNode|None)");

extern "C" {static PyObject *meth_QRemoteObjectReplica_setNode(PyObject *, PyObject *);}
static PyObject *meth_QRemoteObjectReplica_setNode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QRemoteObjectReplica)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QRemoteObjectNode* a0;
        ::QRemoteObjectReplica *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QRemoteObjectReplica, &sipCpp, sipType_QRemoteObjectNode, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QRemoteObjectReplica::setNode(a0) : sipCpp->setNode(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRemoteObjectReplica, sipName_setNode, doc_QRemoteObjectReplica_setNode);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRemoteObjectReplica(void *, const sipTypeDef *);}
static void *cast_QRemoteObjectReplica(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRemoteObjectReplica *sipCpp = reinterpret_cast< ::QRemoteObjectReplica *>(sipCppV);

    if (targetType == sipType_QRemoteObjectReplica)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRemoteObjectReplica(void *, int);}
static void release_QRemoteObjectReplica(void *sipCppV, int)
{
    ::QRemoteObjectReplica *sipCpp = reinterpret_cast< ::QRemoteObjectReplica *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QRemoteObjectReplica(sipSimpleWrapper *);}
static void dealloc_QRemoteObjectReplica(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRemoteObjectReplica(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRemoteObjectReplica[] = {{19, 0, 1}};


static PyMethodDef methods_QRemoteObjectReplica[] = {
    {sipName_isInitialized, meth_QRemoteObjectReplica_isInitialized, METH_VARARGS, doc_QRemoteObjectReplica_isInitialized},
    {sipName_isReplicaValid, meth_QRemoteObjectReplica_isReplicaValid, METH_VARARGS, doc_QRemoteObjectReplica_isReplicaValid},
    {sipName_node, meth_QRemoteObjectReplica_node, METH_VARARGS, doc_QRemoteObjectReplica_node},
    {sipName_setNode, meth_QRemoteObjectReplica_setNode, METH_VARARGS, doc_QRemoteObjectReplica_setNode},
    {sipName_state, meth_QRemoteObjectReplica_state, METH_VARARGS, doc_QRemoteObjectReplica_state},
    {sipName_waitForSource, SIP_MLMETH_CAST(meth_QRemoteObjectReplica_waitForSource), METH_VARARGS|METH_KEYWORDS, doc_QRemoteObjectReplica_waitForSource}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QRemoteObjectReplica[] = {
    {sipName_Uninitialized, static_cast<int>(::QRemoteObjectReplica::Uninitialized)},
    {sipName_Default, static_cast<int>(::QRemoteObjectReplica::Default)},
    {sipName_Valid, static_cast<int>(::QRemoteObjectReplica::Valid)},
    {sipName_Suspect, static_cast<int>(::QRemoteObjectReplica::Suspect)},
    {sipName_SignatureMismatch, static_cast<int>(::QRemoteObjectReplica::SignatureMismatch)},
    {0, 0}
};


/* Define this type's signals. */
static const pyqt6QtSignal signals_QRemoteObjectReplica[] = {
    {"notified()", "\1notified(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QRemoteObjectReplica::State,QRemoteObjectReplica::State)", "\1stateChanged(self, state: QRemoteObjectReplica.State, oldState: QRemoteObjectReplica.State)", SIP_NULLPTR, SIP_NULLPTR},
    {"initialized()", "\1initialized(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QRemoteObjectReplica = {
    &::QRemoteObjectReplica::staticMetaObject,
    signals_QRemoteObjectReplica,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtRemoteObjects_QRemoteObjectReplica = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRemoteObjectReplica,
        SIP_NULLPTR,
        &plugin_QRemoteObjectReplica,
    },
    {
        sipNameNr_QRemoteObjectReplica,
        {0, 0, 1},
        6, methods_QRemoteObjectReplica,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QRemoteObjectReplica, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QRemoteObjectReplica,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRemoteObjectReplica,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QRemoteObjectReplica,
    cast_QRemoteObjectReplica,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
