/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtDBusAPI_H
#define _QtDBusAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtDBus[0]
#define sipNameNr_QDBusConnectionInterface__ServiceReplacementOptions 59
#define sipName_QDBusConnectionInterface__ServiceReplacementOptions &sipStrings_QtDBus[59]
#define sipNameNr_QDBusConnectionInterface__RegisterServiceReply 111
#define sipName_QDBusConnectionInterface__RegisterServiceReply &sipStrings_QtDBus[111]
#define sipNameNr_QDBusConnectionInterface__ServiceQueueOptions 158
#define sipName_QDBusConnectionInterface__ServiceQueueOptions &sipStrings_QtDBus[158]
#define sipNameNr_204 204
#define sipName_204 &sipStrings_QtDBus[204]
#define sipNameNr_250 250
#define sipName_250 &sipStrings_QtDBus[250]
#define sipNameNr_293 293
#define sipName_293 &sipStrings_QtDBus[293]
#define sipNameNr_QDBusConnection__ConnectionCapability 333
#define sipName_QDBusConnection__ConnectionCapability &sipStrings_QtDBus[333]
#define sipNameNr_371 371
#define sipName_371 &sipStrings_QtDBus[371]
#define sipNameNr_QDBusServiceWatcher__WatchModeFlag 407
#define sipName_QDBusServiceWatcher__WatchModeFlag &sipStrings_QtDBus[407]
#define sipNameNr_setInteractiveAuthorizationAllowed 442
#define sipName_setInteractiveAuthorizationAllowed &sipStrings_QtDBus[442]
#define sipNameNr_isInteractiveAuthorizationAllowed 477
#define sipName_isInteractiveAuthorizationAllowed &sipStrings_QtDBus[477]
#define sipNameNr_QDBusConnection__RegisterOption 511
#define sipName_QDBusConnection__RegisterOption &sipStrings_QtDBus[511]
#define sipNameNr_QDBusConnection__UnregisterMode 543
#define sipName_QDBusConnection__UnregisterMode &sipStrings_QtDBus[543]
#define sipNameNr_ExportNonScriptableInvokables 575
#define sipName_ExportNonScriptableInvokables &sipStrings_QtDBus[575]
#define sipNameNr_ExportNonScriptableProperties 605
#define sipName_ExportNonScriptableProperties &sipStrings_QtDBus[605]
#define sipNameNr_ExportNonScriptableContents 635
#define sipName_ExportNonScriptableContents &sipStrings_QtDBus[635]
#define sipNameNr_ExportNonScriptableSignals 663
#define sipName_ExportNonScriptableSignals &sipStrings_QtDBus[663]
#define sipNameNr_ExportScriptableInvokables 690
#define sipName_ExportScriptableInvokables &sipStrings_QtDBus[690]
#define sipNameNr_ExportScriptableProperties 717
#define sipName_ExportScriptableProperties &sipStrings_QtDBus[717]
#define sipNameNr_QDBusMessage__MessageType 744
#define sipName_QDBusMessage__MessageType &sipStrings_QtDBus[744]
#define sipNameNr_ServiceReplacementOptions 85
#define sipName_ServiceReplacementOptions &sipStrings_QtDBus[85]
#define sipNameNr_UnixFileDescriptorPassing 770
#define sipName_UnixFileDescriptorPassing &sipStrings_QtDBus[770]
#define sipNameNr_asyncCallWithArgumentList 796
#define sipName_asyncCallWithArgumentList &sipStrings_QtDBus[796]
#define sipNameNr_ExportNonScriptableSlots 822
#define sipName_ExportNonScriptableSlots &sipStrings_QtDBus[822]
#define sipNameNr_ExportScriptableContents 847
#define sipName_ExportScriptableContents &sipStrings_QtDBus[847]
#define sipNameNr_QDBusConnection__BusType 872
#define sipName_QDBusConnection__BusType &sipStrings_QtDBus[872]
#define sipNameNr_QDBusConnectionInterface 897
#define sipName_QDBusConnectionInterface &sipStrings_QtDBus[897]
#define sipNameNr_ExportScriptableSignals 922
#define sipName_ExportScriptableSignals &sipStrings_QtDBus[922]
#define sipNameNr_PyQt6_sip_simplewrapper 946
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtDBus[946]
#define sipNameNr_QDBusPendingCallWatcher 970
#define sipName_QDBusPendingCallWatcher &sipStrings_QtDBus[970]
#define sipNameNr_994 994
#define sipName_994 &sipStrings_QtDBus[994]
#define sipNameNr_QDBusUnixFileDescriptor 1018
#define sipName_QDBusUnixFileDescriptor &sipStrings_QtDBus[1018]
#define sipNameNr_activatableServiceNames 1042
#define sipName_activatableServiceNames &sipStrings_QtDBus[1042]
#define sipNameNr_QDBusAbstractInterface 1066
#define sipName_QDBusAbstractInterface &sipStrings_QtDBus[1066]
#define sipNameNr_ReplaceExistingService 1089
#define sipName_ReplaceExistingService &sipStrings_QtDBus[1089]
#define sipNameNr_WatchForUnregistration 1112
#define sipName_WatchForUnregistration &sipStrings_QtDBus[1112]
#define sipNameNr_callWithCallbackFailed 1135
#define sipName_callWithCallbackFailed &sipStrings_QtDBus[1135]
#define sipNameNr_connectionCapabilities 1158
#define sipName_connectionCapabilities &sipStrings_QtDBus[1158]
#define sipNameNr_registeredServiceNames 1181
#define sipName_registeredServiceNames &sipStrings_QtDBus[1181]
#define sipNameNr_ExportScriptableSlots 1204
#define sipName_ExportScriptableSlots &sipStrings_QtDBus[1204]
#define sipNameNr_QDBusError__ErrorType 1226
#define sipName_QDBusError__ErrorType &sipStrings_QtDBus[1226]
#define sipNameNr_ConnectionCapability 350
#define sipName_ConnectionCapability &sipStrings_QtDBus[350]
#define sipNameNr_DontAllowReplacement 1248
#define sipName_DontAllowReplacement &sipStrings_QtDBus[1248]
#define sipNameNr_QDBusAbstractAdaptor 1269
#define sipName_QDBusAbstractAdaptor &sipStrings_QtDBus[1269]
#define sipNameNr_RegisterServiceReply 137
#define sipName_RegisterServiceReply &sipStrings_QtDBus[137]
#define sipNameNr_ServiceNotRegistered 1290
#define sipName_ServiceNotRegistered &sipStrings_QtDBus[1290]
#define sipNameNr_WatchForRegistration 1311
#define sipName_WatchForRegistration &sipStrings_QtDBus[1311]
#define sipNameNr_callWithArgumentList 1332
#define sipName_callWithArgumentList &sipStrings_QtDBus[1332]
#define sipNameNr_createTargetedSignal 1353
#define sipName_createTargetedSignal &sipStrings_QtDBus[1353]
#define sipNameNr_removeWatchedService 1374
#define sipName_removeWatchedService &sipStrings_QtDBus[1374]
#define sipNameNr_ExportAllInvokables 1395
#define sipName_ExportAllInvokables &sipStrings_QtDBus[1395]
#define sipNameNr_ExportAllProperties 1415
#define sipName_ExportAllProperties &sipStrings_QtDBus[1415]
#define sipNameNr_1435 1435
#define sipName_1435 &sipStrings_QtDBus[1435]
#define sipNameNr_QDBusServiceWatcher 1455
#define sipName_QDBusServiceWatcher &sipStrings_QtDBus[1455]
#define sipNameNr_QPyDBusPendingReply 1475
#define sipName_QPyDBusPendingReply &sipStrings_QtDBus[1475]
#define sipNameNr_ServiceQueueOptions 184
#define sipName_ServiceQueueOptions &sipStrings_QtDBus[184]
#define sipNameNr_WatchForOwnerChange 1495
#define sipName_WatchForOwnerChange &sipStrings_QtDBus[1495]
#define sipNameNr_isServiceRegistered 1515
#define sipName_isServiceRegistered &sipStrings_QtDBus[1515]
#define sipNameNr_serviceOwnerChanged 1535
#define sipName_serviceOwnerChanged &sipStrings_QtDBus[1535]
#define sipNameNr_serviceUnregistered 1555
#define sipName_serviceUnregistered &sipStrings_QtDBus[1555]
#define sipNameNr_setAutoRelaySignals 1575
#define sipName_setAutoRelaySignals &sipStrings_QtDBus[1575]
#define sipNameNr_setAutoStartService 1595
#define sipName_setAutoStartService &sipStrings_QtDBus[1595]
#define sipNameNr_ExportChildObjects 1615
#define sipName_ExportChildObjects &sipStrings_QtDBus[1615]
#define sipNameNr_disconnectFromPeer 1634
#define sipName_disconnectFromPeer &sipStrings_QtDBus[1634]
#define sipNameNr_objectRegisteredAt 1653
#define sipName_objectRegisteredAt &sipStrings_QtDBus[1653]
#define sipNameNr_serviceCredentials 1672
#define sipName_serviceCredentials &sipStrings_QtDBus[1672]
#define sipNameNr_setWatchedServices 1691
#define sipName_setWatchedServices &sipStrings_QtDBus[1691]
#define sipNameNr_ExportAllContents 1710
#define sipName_ExportAllContents &sipStrings_QtDBus[1710]
#define sipNameNr_InvalidObjectPath 1728
#define sipName_InvalidObjectPath &sipStrings_QtDBus[1728]
#define sipNameNr_MethodCallMessage 1746
#define sipName_MethodCallMessage &sipStrings_QtDBus[1746]
#define sipNameNr_QDBusPendingReply 1764
#define sipName_QDBusPendingReply &sipStrings_QtDBus[1764]
#define sipNameNr_ServiceRegistered 1517
#define sipName_ServiceRegistered &sipStrings_QtDBus[1517]
#define sipNameNr_addWatchedService 1782
#define sipName_addWatchedService &sipStrings_QtDBus[1782]
#define sipNameNr_disconnectFromBus 1800
#define sipName_disconnectFromBus &sipStrings_QtDBus[1800]
#define sipNameNr_fromCompletedCall 1818
#define sipName_fromCompletedCall &sipStrings_QtDBus[1818]
#define sipNameNr_serviceRegistered 1836
#define sipName_serviceRegistered &sipStrings_QtDBus[1836]
#define sipNameNr_setFileDescriptor 1854
#define sipName_setFileDescriptor &sipStrings_QtDBus[1854]
#define sipNameNr_unregisterService 1872
#define sipName_unregisterService &sipStrings_QtDBus[1872]
#define sipNameNr_AllowReplacement 1252
#define sipName_AllowReplacement &sipStrings_QtDBus[1252]
#define sipNameNr_DontQueueService 1890
#define sipName_DontQueueService &sipStrings_QtDBus[1890]
#define sipNameNr_ExportAllSignals 1907
#define sipName_ExportAllSignals &sipStrings_QtDBus[1907]
#define sipNameNr_InvalidInterface 1924
#define sipName_InvalidInterface &sipStrings_QtDBus[1924]
#define sipNameNr_InvalidSignature 1941
#define sipName_InvalidSignature &sipStrings_QtDBus[1941]
#define sipNameNr_PropertyReadOnly 1958
#define sipName_PropertyReadOnly &sipStrings_QtDBus[1958]
#define sipNameNr_QDBusPendingCall 1975
#define sipName_QDBusPendingCall &sipStrings_QtDBus[1975]
#define sipNameNr_1992 1992
#define sipName_1992 &sipStrings_QtDBus[1992]
#define sipNameNr_2009 2009
#define sipName_2009 &sipStrings_QtDBus[2009]
#define sipNameNr_2026 2026
#define sipName_2026 &sipStrings_QtDBus[2026]
#define sipNameNr_UnknownInterface 2043
#define sipName_UnknownInterface &sipStrings_QtDBus[2043]
#define sipNameNr_autoRelaySignals 2060
#define sipName_autoRelaySignals &sipStrings_QtDBus[2060]
#define sipNameNr_autoStartService 2077
#define sipName_autoStartService &sipStrings_QtDBus[2077]
#define sipNameNr_callWithCallback 2094
#define sipName_callWithCallback &sipStrings_QtDBus[2094]
#define sipNameNr_createErrorReply 2111
#define sipName_createErrorReply &sipStrings_QtDBus[2111]
#define sipNameNr_createMethodCall 2128
#define sipName_createMethodCall &sipStrings_QtDBus[2128]
#define sipNameNr_disconnectNotify 2145
#define sipName_disconnectNotify &sipStrings_QtDBus[2145]
#define sipNameNr_unregisterObject 2162
#define sipName_unregisterObject &sipStrings_QtDBus[2162]
#define sipNameNr_ExportAllSignal 2179
#define sipName_ExportAllSignal &sipStrings_QtDBus[2179]
#define sipNameNr_QDBus__CallMode 2195
#define sipName_QDBus__CallMode &sipStrings_QtDBus[2195]
#define sipNameNr_QDBusConnection 2211
#define sipName_QDBusConnection &sipStrings_QtDBus[2211]
#define sipNameNr_QDBusObjectPath 2227
#define sipName_QDBusObjectPath &sipStrings_QtDBus[2227]
#define sipNameNr_UnknownProperty 2243
#define sipName_UnknownProperty &sipStrings_QtDBus[2243]
#define sipNameNr_isReplyRequired 2259
#define sipName_isReplyRequired &sipStrings_QtDBus[2259]
#define sipNameNr_registerService 1874
#define sipName_registerService &sipStrings_QtDBus[1874]
#define sipNameNr_setDelayedReply 2275
#define sipName_setDelayedReply &sipStrings_QtDBus[2275]
#define sipNameNr_waitForFinished 2291
#define sipName_waitForFinished &sipStrings_QtDBus[2291]
#define sipNameNr_watchedServices 2307
#define sipName_watchedServices &sipStrings_QtDBus[2307]
#define sipNameNr_ExportAdaptors 2323
#define sipName_ExportAdaptors &sipStrings_QtDBus[2323]
#define sipNameNr_ExportAllSlots 2338
#define sipName_ExportAllSlots &sipStrings_QtDBus[2338]
#define sipNameNr_InvalidMessage 2353
#define sipName_InvalidMessage &sipStrings_QtDBus[2353]
#define sipNameNr_InvalidService 2368
#define sipName_InvalidService &sipStrings_QtDBus[2368]
#define sipNameNr_LimitsExceeded 2383
#define sipName_LimitsExceeded &sipStrings_QtDBus[2383]
#define sipNameNr_QDBusInterface 2398
#define sipName_QDBusInterface &sipStrings_QtDBus[2398]
#define sipNameNr_QDBusSignature 2413
#define sipName_QDBusSignature &sipStrings_QtDBus[2413]
#define sipNameNr_RegisterOption 528
#define sipName_RegisterOption &sipStrings_QtDBus[528]
#define sipNameNr_ServiceUnknown 2428
#define sipName_ServiceUnknown &sipStrings_QtDBus[2428]
#define sipNameNr_UnregisterMode 560
#define sipName_UnregisterMode &sipStrings_QtDBus[560]
#define sipNameNr_UnregisterNode 2443
#define sipName_UnregisterNode &sipStrings_QtDBus[2443]
#define sipNameNr_UnregisterTree 2458
#define sipName_UnregisterTree &sipStrings_QtDBus[2458]
#define sipNameNr_beginStructure 2473
#define sipName_beginStructure &sipStrings_QtDBus[2473]
#define sipNameNr_fileDescriptor 2488
#define sipName_fileDescriptor &sipStrings_QtDBus[2488]
#define sipNameNr_isDelayedReply 2503
#define sipName_isDelayedReply &sipStrings_QtDBus[2503]
#define sipNameNr_localMachineId 2518
#define sipName_localMachineId &sipStrings_QtDBus[2518]
#define sipNameNr_registerObject 2164
#define sipName_registerObject &sipStrings_QtDBus[2164]
#define sipNameNr_ActivationBus 2533
#define sipName_ActivationBus &sipStrings_QtDBus[2533]
#define sipNameNr_InternalError 2547
#define sipName_InternalError &sipStrings_QtDBus[2547]
#define sipNameNr_InvalidMember 2561
#define sipName_InvalidMember &sipStrings_QtDBus[2561]
#define sipNameNr_QDBusArgument 2575
#define sipName_QDBusArgument &sipStrings_QtDBus[2575]
#define sipNameNr_ServiceQueued 2589
#define sipName_ServiceQueued &sipStrings_QtDBus[2589]
#define sipNameNr_SignalMessage 2603
#define sipName_SignalMessage &sipStrings_QtDBus[2603]
#define sipNameNr_UnknownMethod 2617
#define sipName_UnknownMethod &sipStrings_QtDBus[2617]
#define sipNameNr_UnknownObject 2631
#define sipName_UnknownObject &sipStrings_QtDBus[2631]
#define sipNameNr_WatchModeFlag 428
#define sipName_WatchModeFlag &sipStrings_QtDBus[428]
#define sipNameNr_beginMapEntry 2645
#define sipName_beginMapEntry &sipStrings_QtDBus[2645]
#define sipNameNr_connectNotify 2148
#define sipName_connectNotify &sipStrings_QtDBus[2148]
#define sipNameNr_connectToPeer 2659
#define sipName_connectToPeer &sipStrings_QtDBus[2659]
#define sipNameNr_setConnection 2673
#define sipName_setConnection &sipStrings_QtDBus[2673]
#define sipNameNr_AccessDenied 2687
#define sipName_AccessDenied &sipStrings_QtDBus[2687]
#define sipNameNr_AddressInUse 2700
#define sipName_AddressInUse &sipStrings_QtDBus[2700]
#define sipNameNr_BlockWithGui 2713
#define sipName_BlockWithGui &sipStrings_QtDBus[2713]
#define sipNameNr_Disconnected 2726
#define sipName_Disconnected &sipStrings_QtDBus[2726]
#define sipNameNr_ErrorMessage 2739
#define sipName_ErrorMessage &sipStrings_QtDBus[2739]
#define sipNameNr_NotSupported 2752
#define sipName_NotSupported &sipStrings_QtDBus[2752]
#define sipNameNr_PyQt6_QtDBus 2765
#define sipName_PyQt6_QtDBus &sipStrings_QtDBus[2765]
#define sipNameNr_QDBusMessage 2778
#define sipName_QDBusMessage &sipStrings_QtDBus[2778]
#define sipNameNr_QDBusVariant 2791
#define sipName_QDBusVariant &sipStrings_QtDBus[2791]
#define sipNameNr_QPyDBusReply 2804
#define sipName_QPyDBusReply &sipStrings_QtDBus[2804]
#define sipNameNr_QueueService 1894
#define sipName_QueueService &sipStrings_QtDBus[1894]
#define sipNameNr_ReplyMessage 2817
#define sipName_ReplyMessage &sipStrings_QtDBus[2817]
#define sipNameNr_connectToBus 2830
#define sipName_connectToBus &sipStrings_QtDBus[2830]
#define sipNameNr_createSignal 2843
#define sipName_createSignal &sipStrings_QtDBus[2843]
#define sipNameNr_endStructure 2856
#define sipName_endStructure &sipStrings_QtDBus[2856]
#define sipNameNr_errorMessage 2869
#define sipName_errorMessage &sipStrings_QtDBus[2869]
#define sipNameNr_serviceOwner 2882
#define sipName_serviceOwner &sipStrings_QtDBus[2882]
#define sipNameNr_setArguments 2895
#define sipName_setArguments &sipStrings_QtDBus[2895]
#define sipNameNr_setSignature 2908
#define sipName_setSignature &sipStrings_QtDBus[2908]
#define sipNameNr_setWatchMode 2921
#define sipName_setWatchMode &sipStrings_QtDBus[2921]
#define sipNameNr_startService 2934
#define sipName_startService &sipStrings_QtDBus[2934]
#define sipNameNr_InvalidArgs 2947
#define sipName_InvalidArgs &sipStrings_QtDBus[2947]
#define sipNameNr_MessageType 758
#define sipName_MessageType &sipStrings_QtDBus[758]
#define sipNameNr_baseService 2959
#define sipName_baseService &sipStrings_QtDBus[2959]
#define sipNameNr_createError 2971
#define sipName_createError &sipStrings_QtDBus[2971]
#define sipNameNr_createReply 2983
#define sipName_createReply &sipStrings_QtDBus[2983]
#define sipNameNr_customEvent 2995
#define sipName_customEvent &sipStrings_QtDBus[2995]
#define sipNameNr_endMapEntry 3007
#define sipName_endMapEntry &sipStrings_QtDBus[3007]
#define sipNameNr_errorString 3019
#define sipName_errorString &sipStrings_QtDBus[3019]
#define sipNameNr_eventFilter 3031
#define sipName_eventFilter &sipStrings_QtDBus[3031]
#define sipNameNr_isConnected 3043
#define sipName_isConnected &sipStrings_QtDBus[3043]
#define sipNameNr_isSupported 3055
#define sipName_isSupported &sipStrings_QtDBus[3055]
#define sipNameNr_AutoDetect 3067
#define sipName_AutoDetect &sipStrings_QtDBus[3067]
#define sipNameNr_BadAddress 3078
#define sipName_BadAddress &sipStrings_QtDBus[3078]
#define sipNameNr_QDBusError 3089
#define sipName_QDBusError &sipStrings_QtDBus[3089]
#define sipNameNr_QDBusReply 3100
#define sipName_QDBusReply &sipStrings_QtDBus[3100]
#define sipNameNr_SessionBus 3111
#define sipName_SessionBus &sipStrings_QtDBus[3111]
#define sipNameNr___lshift__ 3122
#define sipName___lshift__ &sipStrings_QtDBus[3122]
#define sipNameNr_argumentAt 3133
#define sipName_argumentAt &sipStrings_QtDBus[3133]
#define sipNameNr_beginArray 3144
#define sipName_beginArray &sipStrings_QtDBus[3144]
#define sipNameNr_childEvent 3155
#define sipName_childEvent &sipStrings_QtDBus[3155]
#define sipNameNr_connection 3166
#define sipName_connection &sipStrings_QtDBus[3166]
#define sipNameNr_disconnect 3177
#define sipName_disconnect &sipStrings_QtDBus[3177]
#define sipNameNr_isFinished 3188
#define sipName_isFinished &sipStrings_QtDBus[3188]
#define sipNameNr_servicePid 3199
#define sipName_servicePid &sipStrings_QtDBus[3199]
#define sipNameNr_serviceUid 3210
#define sipName_serviceUid &sipStrings_QtDBus[3210]
#define sipNameNr_sessionBus 3221
#define sipName_sessionBus &sipStrings_QtDBus[3221]
#define sipNameNr_setTimeout 3232
#define sipName_setTimeout &sipStrings_QtDBus[3232]
#define sipNameNr_setVariant 3243
#define sipName_setVariant &sipStrings_QtDBus[3243]
#define sipNameNr_timerEvent 3254
#define sipName_timerEvent &sipStrings_QtDBus[3254]
#define sipNameNr_ErrorType 1238
#define sipName_ErrorType &sipStrings_QtDBus[1238]
#define sipNameNr_NoNetwork 3265
#define sipName_NoNetwork &sipStrings_QtDBus[3265]
#define sipNameNr_SystemBus 3275
#define sipName_SystemBus &sipStrings_QtDBus[3275]
#define sipNameNr_arguments 3285
#define sipName_arguments &sipStrings_QtDBus[3285]
#define sipNameNr_asyncCall 3295
#define sipName_asyncCall &sipStrings_QtDBus[3295]
#define sipNameNr_errorName 3305
#define sipName_errorName &sipStrings_QtDBus[3305]
#define sipNameNr_fromError 3315
#define sipName_fromError &sipStrings_QtDBus[3315]
#define sipNameNr_interface 3325
#define sipName_interface &sipStrings_QtDBus[3325]
#define sipNameNr_lastError 3335
#define sipName_lastError &sipStrings_QtDBus[3335]
#define sipNameNr_signature 3345
#define sipName_signature &sipStrings_QtDBus[3345]
#define sipNameNr_systemBus 3355
#define sipName_systemBus &sipStrings_QtDBus[3355]
#define sipNameNr_watchMode 3365
#define sipName_watchMode &sipStrings_QtDBus[3365]
#define sipNameNr_CallMode 2202
#define sipName_CallMode &sipStrings_QtDBus[2202]
#define sipNameNr_NoMemory 3375
#define sipName_NoMemory &sipStrings_QtDBus[3375]
#define sipNameNr_NoServer 3384
#define sipName_NoServer &sipStrings_QtDBus[3384]
#define sipNameNr_TimedOut 3393
#define sipName_TimedOut &sipStrings_QtDBus[3393]
#define sipNameNr___hash__ 3402
#define sipName___hash__ &sipStrings_QtDBus[3402]
#define sipNameNr_beginMap 3411
#define sipName_beginMap &sipStrings_QtDBus[3411]
#define sipNameNr_endArray 3420
#define sipName_endArray &sipStrings_QtDBus[3420]
#define sipNameNr_finished 3429
#define sipName_finished &sipStrings_QtDBus[3429]
#define sipNameNr_BusType 889
#define sipName_BusType &sipStrings_QtDBus[889]
#define sipNameNr_NoBlock 3438
#define sipName_NoBlock &sipStrings_QtDBus[3438]
#define sipNameNr_NoError 3446
#define sipName_NoError &sipStrings_QtDBus[3446]
#define sipNameNr_NoReply 3454
#define sipName_NoReply &sipStrings_QtDBus[3454]
#define sipNameNr_Timeout 3235
#define sipName_Timeout &sipStrings_QtDBus[3235]
#define sipNameNr_connect 3180
#define sipName_connect &sipStrings_QtDBus[3180]
#define sipNameNr_isError 3462
#define sipName_isError &sipStrings_QtDBus[3462]
#define sipNameNr_isValid 3470
#define sipName_isValid &sipStrings_QtDBus[3470]
#define sipNameNr_message 3478
#define sipName_message &sipStrings_QtDBus[3478]
#define sipNameNr_options 3486
#define sipName_options &sipStrings_QtDBus[3486]
#define sipNameNr_qoption 3494
#define sipName_qoption &sipStrings_QtDBus[3494]
#define sipNameNr_roption 3502
#define sipName_roption &sipStrings_QtDBus[3502]
#define sipNameNr_service 3510
#define sipName_service &sipStrings_QtDBus[3510]
#define sipNameNr_setPath 3518
#define sipName_setPath &sipStrings_QtDBus[3518]
#define sipNameNr_timeout 3526
#define sipName_timeout &sipStrings_QtDBus[3526]
#define sipNameNr_variant 3534
#define sipName_variant &sipStrings_QtDBus[3534]
#define sipNameNr_watcher 3542
#define sipName_watcher &sipStrings_QtDBus[3542]
#define sipNameNr_Failed 1151
#define sipName_Failed &sipStrings_QtDBus[1151]
#define sipNameNr___eq__ 3550
#define sipName___eq__ &sipStrings_QtDBus[3550]
#define sipNameNr___ge__ 3557
#define sipName___ge__ &sipStrings_QtDBus[3557]
#define sipNameNr___lt__ 3564
#define sipName___lt__ &sipStrings_QtDBus[3564]
#define sipNameNr___ne__ 3571
#define sipName___ne__ &sipStrings_QtDBus[3571]
#define sipNameNr_endMap 3578
#define sipName_endMap &sipStrings_QtDBus[3578]
#define sipNameNr_member 3585
#define sipName_member &sipStrings_QtDBus[3585]
#define sipNameNr_parent 3592
#define sipName_parent &sipStrings_QtDBus[3592]
#define sipNameNr_Block 3440
#define sipName_Block &sipStrings_QtDBus[3440]
#define sipNameNr_Other 3599
#define sipName_Other &sipStrings_QtDBus[3599]
#define sipNameNr_QDBus 3605
#define sipName_QDBus &sipStrings_QtDBus[3605]
#define sipNameNr_error 3611
#define sipName_error &sipStrings_QtDBus[3611]
#define sipNameNr_event 3617
#define sipName_event &sipStrings_QtDBus[3617]
#define sipNameNr_reply 3623
#define sipName_reply &sipStrings_QtDBus[3623]
#define sipNameNr_value 3629
#define sipName_value &sipStrings_QtDBus[3629]
#define sipNameNr_call 3635
#define sipName_call &sipStrings_QtDBus[3635]
#define sipNameNr_mode 3640
#define sipName_mode &sipStrings_QtDBus[3640]
#define sipNameNr_name 3645
#define sipName_name &sipStrings_QtDBus[3645]
#define sipNameNr_path 3650
#define sipName_path &sipStrings_QtDBus[3650]
#define sipNameNr_send 3655
#define sipName_send &sipStrings_QtDBus[3655]
#define sipNameNr_swap 3660
#define sipName_swap &sipStrings_QtDBus[3660]
#define sipNameNr_type 3665
#define sipName_type &sipStrings_QtDBus[3665]
#define sipNameNr_add 3670
#define sipName_add &sipStrings_QtDBus[3670]
#define sipNameNr_id 3207
#define sipName_id &sipStrings_QtDBus[3207]

#define sipMalloc                   sipAPI_QtDBus->api_malloc
#define sipFree                     sipAPI_QtDBus->api_free
#define sipBuildResult              sipAPI_QtDBus->api_build_result
#define sipCallMethod               sipAPI_QtDBus->api_call_method
#define sipCallProcedureMethod      sipAPI_QtDBus->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtDBus->api_call_error_handler
#define sipParseResultEx            sipAPI_QtDBus->api_parse_result_ex
#define sipParseResult              sipAPI_QtDBus->api_parse_result
#define sipParseArgs                sipAPI_QtDBus->api_parse_args
#define sipParseKwdArgs             sipAPI_QtDBus->api_parse_kwd_args
#define sipParsePair                sipAPI_QtDBus->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtDBus->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtDBus->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtDBus->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtDBus->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtDBus->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtDBus->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtDBus->api_add_exception
#define sipNoFunction               sipAPI_QtDBus->api_no_function
#define sipNoMethod                 sipAPI_QtDBus->api_no_method
#define sipAbstractMethod           sipAPI_QtDBus->api_abstract_method
#define sipBadClass                 sipAPI_QtDBus->api_bad_class
#define sipBadCatcherResult         sipAPI_QtDBus->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtDBus->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtDBus->api_bad_operator_arg
#define sipTrace                    sipAPI_QtDBus->api_trace
#define sipTransferBack             sipAPI_QtDBus->api_transfer_back
#define sipTransferTo               sipAPI_QtDBus->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtDBus->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtDBus->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtDBus->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtDBus->api_voidptr_type
#define sipGetPyObject              sipAPI_QtDBus->api_get_pyobject
#define sipGetAddress               sipAPI_QtDBus->api_get_address
#define sipGetMixinAddress          sipAPI_QtDBus->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtDBus->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtDBus->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtDBus->api_call_hook
#define sipEndThread                sipAPI_QtDBus->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtDBus->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtDBus->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtDBus->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtDBus->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtDBus->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtDBus->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtDBus->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtDBus->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtDBus->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtDBus->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtDBus->api_convert_to_bool
#define sipReleaseType              sipAPI_QtDBus->api_release_type
#define sipConvertFromType          sipAPI_QtDBus->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtDBus->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtDBus->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtDBus->api_convert_from_enum
#define sipGetState                 sipAPI_QtDBus->api_get_state
#define sipExportSymbol             sipAPI_QtDBus->api_export_symbol
#define sipImportSymbol             sipAPI_QtDBus->api_import_symbol
#define sipFindType                 sipAPI_QtDBus->api_find_type
#define sipBytes_AsChar             sipAPI_QtDBus->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtDBus->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtDBus->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtDBus->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtDBus->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtDBus->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtDBus->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtDBus->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtDBus->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtDBus->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtDBus->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtDBus->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtDBus->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtDBus->api_get_reference
#define sipKeepReference            sipAPI_QtDBus->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtDBus->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtDBus->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtDBus->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtDBus->api_type_scope
#define sipResolveTypedef           sipAPI_QtDBus->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtDBus->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtDBus->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtDBus->api_init_mixin
#define sipExportModule             sipAPI_QtDBus->api_export_module
#define sipInitModule               sipAPI_QtDBus->api_init_module
#define sipGetInterpreter           sipAPI_QtDBus->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtDBus->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtDBus->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtDBus->api_py_type_dict
#define sipPyTypeName               sipAPI_QtDBus->api_py_type_name
#define sipGetCFunction             sipAPI_QtDBus->api_get_c_function
#define sipGetMethod                sipAPI_QtDBus->api_get_method
#define sipFromMethod               sipAPI_QtDBus->api_from_method
#define sipGetDate                  sipAPI_QtDBus->api_get_date
#define sipFromDate                 sipAPI_QtDBus->api_from_date
#define sipGetDateTime              sipAPI_QtDBus->api_get_datetime
#define sipFromDateTime             sipAPI_QtDBus->api_from_datetime
#define sipGetTime                  sipAPI_QtDBus->api_get_time
#define sipFromTime                 sipAPI_QtDBus->api_from_time
#define sipIsUserType               sipAPI_QtDBus->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtDBus->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtDBus->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtDBus->api_unicode_write
#define sipUnicodeData              sipAPI_QtDBus->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtDBus->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtDBus->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtDBus->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtDBus->api_is_derived_class
#define sipGetUserObject            sipAPI_QtDBus->api_get_user_object
#define sipSetUserObject            sipAPI_QtDBus->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtDBus->api_register_event_handler
#define sipConvertToArray           sipAPI_QtDBus->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtDBus->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtDBus->api_enable_gc
#define sipPrintObject              sipAPI_QtDBus->api_print_object
#define sipLong_AsChar              sipAPI_QtDBus->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtDBus->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtDBus->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtDBus->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtDBus->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtDBus->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtDBus->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtDBus->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtDBus->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtDBus->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtDBus->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtDBus->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtDBus->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtDBus->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtDBus->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtDBus->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtDBus->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtDBus->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtDBus->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtDBus->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtDBus->api_release_type_us
#define sipIsPyMethod               sipAPI_QtDBus->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtDBus[];

#define sipType_QDBusAbstractAdaptor sipExportedTypes_QtDBus[2]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusAbstractAdaptor;

#define sipType_QDBusAbstractInterface sipExportedTypes_QtDBus[3]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusAbstractInterface;

#define sipType_QDBusArgument sipExportedTypes_QtDBus[4]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusArgument;

#define sipType_QDBus sipExportedTypes_QtDBus[0]

#define sipType_QDBus_CallMode sipExportedTypes_QtDBus[1]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBus;

#define sipType_QDBusConnection sipExportedTypes_QtDBus[5]

#define sipType_QDBusConnection_ConnectionCapability sipExportedTypes_QtDBus[7]

#define sipType_QDBusConnection_UnregisterMode sipExportedTypes_QtDBus[9]

#define sipType_QDBusConnection_RegisterOption sipExportedTypes_QtDBus[8]

#define sipType_QDBusConnection_BusType sipExportedTypes_QtDBus[6]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusConnection;

#define sipType_QDBusConnectionInterface sipExportedTypes_QtDBus[10]

#define sipType_QDBusConnectionInterface_RegisterServiceReply sipExportedTypes_QtDBus[11]

#define sipType_QDBusConnectionInterface_ServiceReplacementOptions sipExportedTypes_QtDBus[13]

#define sipType_QDBusConnectionInterface_ServiceQueueOptions sipExportedTypes_QtDBus[12]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusConnectionInterface;

#define sipType_QDBusError sipExportedTypes_QtDBus[14]

#define sipType_QDBusError_ErrorType sipExportedTypes_QtDBus[15]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusError;

#define sipType_QDBusObjectPath sipExportedTypes_QtDBus[19]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusObjectPath;

#define sipType_QDBusSignature sipExportedTypes_QtDBus[31]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusSignature;

#define sipType_QDBusVariant sipExportedTypes_QtDBus[33]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusVariant;

#define sipType_QDBusInterface sipExportedTypes_QtDBus[16]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusInterface;

#define sipType_QDBusMessage sipExportedTypes_QtDBus[17]

#define sipType_QDBusMessage_MessageType sipExportedTypes_QtDBus[18]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusMessage;

#define sipType_QDBusPendingCall sipExportedTypes_QtDBus[20]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusPendingCall;

#define sipType_QDBusPendingCallWatcher sipExportedTypes_QtDBus[21]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusPendingCallWatcher;

#define sipType_QDBusServiceWatcher sipExportedTypes_QtDBus[29]

#define sipType_QDBusServiceWatcher_WatchModeFlag sipExportedTypes_QtDBus[30]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusServiceWatcher;

#define sipType_QDBusUnixFileDescriptor sipExportedTypes_QtDBus[32]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusUnixFileDescriptor;

#define sipType_QPyDBusReply sipExportedTypes_QtDBus[38]

extern sipClassTypeDef sipTypeDef_QtDBus_QPyDBusReply;

#define sipType_QPyDBusPendingReply sipExportedTypes_QtDBus[37]

extern sipClassTypeDef sipTypeDef_QtDBus_QPyDBusPendingReply;

#define sipType_QDBusReply_0100QString sipExportedTypes_QtDBus[24]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_0100QString;

#define sipType_QDBusReply_0100QStringList sipExportedTypes_QtDBus[25]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_0100QStringList;

#define sipType_QFlags_0100QDBusServiceWatcher_WatchModeFlag sipExportedTypes_QtDBus[36]

extern sipMappedTypeDef sipTypeDef_QtDBus_QFlags_0100QDBusServiceWatcher_WatchModeFlag;

#define sipType_QFlags_0100QDBusConnection_RegisterOption sipExportedTypes_QtDBus[35]

extern sipMappedTypeDef sipTypeDef_QtDBus_QFlags_0100QDBusConnection_RegisterOption;

#define sipType_QFlags_0100QDBusConnection_ConnectionCapability sipExportedTypes_QtDBus[34]

extern sipMappedTypeDef sipTypeDef_QtDBus_QFlags_0100QDBusConnection_ConnectionCapability;

#define sipType_QDBusReply_0600QMap_0100QString_0100QVariant sipExportedTypes_QtDBus[23]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_0600QMap_0100QString_0100QVariant;

#define sipType_QDBusReply_0100QDBusConnectionInterface_RegisterServiceReply sipExportedTypes_QtDBus[22]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_0100QDBusConnectionInterface_RegisterServiceReply;

#define sipType_QDBusReply_1900 sipExportedTypes_QtDBus[27]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_1900;

#define sipType_QDBusReply_2600 sipExportedTypes_QtDBus[26]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_2600;

#define sipType_QDBusReply_0400 sipExportedTypes_QtDBus[28]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_0400;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtDBus;
extern sipExportedModuleDef sipModuleAPI_QtDBus;
extern sipTypeDef *sipExportedTypes_QtDBus[];

#define sipType_QObject sipImportedTypes_QtDBus_QtCore[6].it_td

#define sipType_QByteArray sipImportedTypes_QtDBus_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtDBus_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtDBus_QtCore[9].it_td

#define sipType_QChildEvent sipImportedTypes_QtDBus_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtDBus_QtCore[4].it_td

#define sipType_QMetaType sipImportedTypes_QtDBus_QtCore[5].it_td

#define sipType_QVariant sipImportedTypes_QtDBus_QtCore[10].it_td

#define sipType_QList_0100QVariant sipImportedTypes_QtDBus_QtCore[3].it_td

#define sipType_QStringList sipImportedTypes_QtDBus_QtCore[8].it_td

#define sipType_QString sipImportedTypes_QtDBus_QtCore[7].it_td
extern sipImportedTypeDef sipImportedTypes_QtDBus_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtDBus_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtDBus_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtDBus_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtDBus_qt_metacast;
#line 207 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtDBus/qdbusabstractinterface.sip"
#include "qpydbus_api.h"

// Imports from QtCore.
typedef PyObject *(*pyqt6_qtdbus_from_qvariant_by_type_t)(QVariant &, PyObject *);
extern pyqt6_qtdbus_from_qvariant_by_type_t pyqt6_qtdbus_from_qvariant_by_type;

typedef sipErrorState (*pyqt6_qtdbus_get_pyqtslot_parts_t)(PyObject *, QObject **, QByteArray &);
extern pyqt6_qtdbus_get_pyqtslot_parts_t pyqt6_qtdbus_get_pyqtslot_parts;
#line 882 "/build/pyqt6/src/pyqt6-6.11.0/build/QtDBus/sipAPIQtDBus.h"

#endif
