/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtBluetooth.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothhostinfo.sip"
#include <qbluetoothhostinfo.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothHostInfo.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothHostInfo.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtBluetooth/qbluetoothaddress.sip"
#include <qbluetoothaddress.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtBluetooth/sipQtBluetoothQBluetoothHostInfo.cpp"


PyDoc_STRVAR(doc_QBluetoothHostInfo_address, "address(self) -> QBluetoothAddress");

extern "C" {static PyObject *meth_QBluetoothHostInfo_address(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothHostInfo_address(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothHostInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothHostInfo, &sipCpp))
        {
            ::QBluetoothAddress*sipRes;

            sipRes = new ::QBluetoothAddress(sipCpp->address());

            return sipConvertFromNewType(sipRes, sipType_QBluetoothAddress, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothHostInfo, sipName_address, doc_QBluetoothHostInfo_address);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothHostInfo_setAddress, "setAddress(self, address: QBluetoothAddress)");

extern "C" {static PyObject *meth_QBluetoothHostInfo_setAddress(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothHostInfo_setAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothAddress* a0;
        ::QBluetoothHostInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QBluetoothHostInfo, &sipCpp, sipType_QBluetoothAddress, &a0))
        {
            sipCpp->setAddress(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothHostInfo, sipName_setAddress, doc_QBluetoothHostInfo_setAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothHostInfo_name, "name(self) -> str");

extern "C" {static PyObject *meth_QBluetoothHostInfo_name(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothHostInfo_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothHostInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QBluetoothHostInfo, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothHostInfo, sipName_name, doc_QBluetoothHostInfo_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QBluetoothHostInfo_setName, "setName(self, name: str|None)");

extern "C" {static PyObject *meth_QBluetoothHostInfo_setName(PyObject *, PyObject *);}
static PyObject *meth_QBluetoothHostInfo_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QBluetoothHostInfo *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QBluetoothHostInfo, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBluetoothHostInfo, sipName_setName, doc_QBluetoothHostInfo_setName);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QBluetoothHostInfo___eq__(PyObject *, PyObject *);}
static PyObject *slot_QBluetoothHostInfo___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QBluetoothHostInfo *sipCpp = reinterpret_cast< ::QBluetoothHostInfo *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QBluetoothHostInfo));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothHostInfo* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QBluetoothHostInfo, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, eq_slot, sipType_QBluetoothHostInfo, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QBluetoothHostInfo___ne__(PyObject *, PyObject *);}
static PyObject *slot_QBluetoothHostInfo___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QBluetoothHostInfo *sipCpp = reinterpret_cast< ::QBluetoothHostInfo *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QBluetoothHostInfo));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBluetoothHostInfo* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QBluetoothHostInfo, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtBluetooth, ne_slot, sipType_QBluetoothHostInfo, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QBluetoothHostInfo(void *, int);}
static void release_QBluetoothHostInfo(void *sipCppV, int)
{
    delete reinterpret_cast< ::QBluetoothHostInfo *>(sipCppV);
}


extern "C" {static void *array_QBluetoothHostInfo(Py_ssize_t);}
static void *array_QBluetoothHostInfo(Py_ssize_t sipNrElem)
{
    return new ::QBluetoothHostInfo[sipNrElem];
}


extern "C" {static void array_delete_QBluetoothHostInfo(void *);}
static void array_delete_QBluetoothHostInfo(void *sipCpp)
{
    delete[] reinterpret_cast< ::QBluetoothHostInfo *>(sipCpp);
}


extern "C" {static void assign_QBluetoothHostInfo(void *, Py_ssize_t, void *);}
static void assign_QBluetoothHostInfo(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QBluetoothHostInfo *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QBluetoothHostInfo *>(sipSrc);
}


extern "C" {static void *copy_QBluetoothHostInfo(const void *, Py_ssize_t);}
static void *copy_QBluetoothHostInfo(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QBluetoothHostInfo(reinterpret_cast<const ::QBluetoothHostInfo *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QBluetoothHostInfo(sipSimpleWrapper *);}
static void dealloc_QBluetoothHostInfo(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QBluetoothHostInfo(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QBluetoothHostInfo(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QBluetoothHostInfo(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QBluetoothHostInfo *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QBluetoothHostInfo();

            return sipCpp;
        }
    }

    {
        const ::QBluetoothHostInfo* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QBluetoothHostInfo, &a0))
        {
            sipCpp = new ::QBluetoothHostInfo(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QBluetoothHostInfo[] = {
    {(void *)slot_QBluetoothHostInfo___eq__, eq_slot},
    {(void *)slot_QBluetoothHostInfo___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QBluetoothHostInfo[] = {
    {sipName_address, meth_QBluetoothHostInfo_address, METH_VARARGS, doc_QBluetoothHostInfo_address},
    {sipName_name, meth_QBluetoothHostInfo_name, METH_VARARGS, doc_QBluetoothHostInfo_name},
    {sipName_setAddress, meth_QBluetoothHostInfo_setAddress, METH_VARARGS, doc_QBluetoothHostInfo_setAddress},
    {sipName_setName, meth_QBluetoothHostInfo_setName, METH_VARARGS, doc_QBluetoothHostInfo_setName}
};

PyDoc_STRVAR(doc_QBluetoothHostInfo, "\1QBluetoothHostInfo()\n"
"QBluetoothHostInfo(other: QBluetoothHostInfo)");


sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothHostInfo = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QBluetoothHostInfo,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QBluetoothHostInfo,
        {0, 0, 1},
        4, methods_QBluetoothHostInfo,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QBluetoothHostInfo,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QBluetoothHostInfo,
    init_type_QBluetoothHostInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QBluetoothHostInfo,
    assign_QBluetoothHostInfo,
    array_QBluetoothHostInfo,
    copy_QBluetoothHostInfo,
    release_QBluetoothHostInfo,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QBluetoothHostInfo,
    sizeof (::QBluetoothHostInfo),
};
