/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 48 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsprimitivevalue.sip"
#include <qjsprimitivevalue.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSPrimitiveValue.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsprimitivevalue.sip"
#include <qjsprimitivevalue.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSPrimitiveValue.cpp"
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtQml/qjsprimitivevalue.sip"
#include <qjsprimitivevalue.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSPrimitiveValue.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSPrimitiveValue.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetatype.sip"
#include <qmetatype.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtQml/sipQtQmlQJSPrimitiveValue.cpp"


PyDoc_STRVAR(doc_QJSPrimitiveValue_type, "type(self) -> QJSPrimitiveValue.Type");

extern "C" {static PyObject *meth_QJSPrimitiveValue_type(PyObject *, PyObject *);}
static PyObject *meth_QJSPrimitiveValue_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSPrimitiveValue, &sipCpp))
        {
            ::QJSPrimitiveValue::Type sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QJSPrimitiveValue_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSPrimitiveValue, sipName_type, doc_QJSPrimitiveValue_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSPrimitiveValue_toBoolean, "toBoolean(self) -> bool");

extern "C" {static PyObject *meth_QJSPrimitiveValue_toBoolean(PyObject *, PyObject *);}
static PyObject *meth_QJSPrimitiveValue_toBoolean(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSPrimitiveValue, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->toBoolean();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSPrimitiveValue, sipName_toBoolean, doc_QJSPrimitiveValue_toBoolean);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSPrimitiveValue_toInteger, "toInteger(self) -> int");

extern "C" {static PyObject *meth_QJSPrimitiveValue_toInteger(PyObject *, PyObject *);}
static PyObject *meth_QJSPrimitiveValue_toInteger(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSPrimitiveValue, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->toInteger();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSPrimitiveValue, sipName_toInteger, doc_QJSPrimitiveValue_toInteger);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSPrimitiveValue_toDouble, "toDouble(self) -> float");

extern "C" {static PyObject *meth_QJSPrimitiveValue_toDouble(PyObject *, PyObject *);}
static PyObject *meth_QJSPrimitiveValue_toDouble(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSPrimitiveValue, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->toDouble();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSPrimitiveValue, sipName_toDouble, doc_QJSPrimitiveValue_toDouble);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSPrimitiveValue_toString, "toString(self) -> str");

extern "C" {static PyObject *meth_QJSPrimitiveValue_toString(PyObject *, PyObject *);}
static PyObject *meth_QJSPrimitiveValue_toString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSPrimitiveValue, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSPrimitiveValue, sipName_toString, doc_QJSPrimitiveValue_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSPrimitiveValue_strictlyEquals, "strictlyEquals(self, other: QJSPrimitiveValue) -> bool");

extern "C" {static PyObject *meth_QJSPrimitiveValue_strictlyEquals(PyObject *, PyObject *);}
static PyObject *meth_QJSPrimitiveValue_strictlyEquals(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;
        const ::QJSPrimitiveValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QJSPrimitiveValue, &sipCpp, sipType_QJSPrimitiveValue, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->strictlyEquals(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSPrimitiveValue, sipName_strictlyEquals, doc_QJSPrimitiveValue_strictlyEquals);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSPrimitiveValue_equals, "equals(self, other: QJSPrimitiveValue) -> bool");

extern "C" {static PyObject *meth_QJSPrimitiveValue_equals(PyObject *, PyObject *);}
static PyObject *meth_QJSPrimitiveValue_equals(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;
        const ::QJSPrimitiveValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QJSPrimitiveValue, &sipCpp, sipType_QJSPrimitiveValue, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->equals(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSPrimitiveValue, sipName_equals, doc_QJSPrimitiveValue_equals);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSPrimitiveValue_metaType, "metaType(self) -> QMetaType");

extern "C" {static PyObject *meth_QJSPrimitiveValue_metaType(PyObject *, PyObject *);}
static PyObject *meth_QJSPrimitiveValue_metaType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSPrimitiveValue, &sipCpp))
        {
            ::QMetaType*sipRes;

            sipRes = reinterpret_cast< ::QMetaType *>(::operator new(sizeof (::QMetaType)));
            *sipRes = sipCpp->metaType();

            return sipConvertFromNewType(sipRes, sipType_QMetaType, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSPrimitiveValue, sipName_metaType, doc_QJSPrimitiveValue_metaType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSPrimitiveValue_data, "data(self) -> PyQt6.sip.voidptr");

extern "C" {static PyObject *meth_QJSPrimitiveValue_data(PyObject *, PyObject *);}
static PyObject *meth_QJSPrimitiveValue_data(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QJSPrimitiveValue *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSPrimitiveValue, &sipCpp))
        {
            void*sipRes;

            sipRes = sipCpp->data();

            return sipConvertFromVoidPtr(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSPrimitiveValue, sipName_data, doc_QJSPrimitiveValue_data);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___add__(PyObject *, PyObject *);}
static PyObject *slot_QJSPrimitiveValue___add__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;
        const ::QJSPrimitiveValue* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QJSPrimitiveValue, &a0, sipType_QJSPrimitiveValue, &a1))
        {
            ::QJSPrimitiveValue*sipRes;

            sipRes = new ::QJSPrimitiveValue((*a0 + *a1));

            return sipConvertFromNewType(sipRes, sipType_QJSPrimitiveValue, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtQml, add_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___sub__(PyObject *, PyObject *);}
static PyObject *slot_QJSPrimitiveValue___sub__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;
        const ::QJSPrimitiveValue* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QJSPrimitiveValue, &a0, sipType_QJSPrimitiveValue, &a1))
        {
            ::QJSPrimitiveValue*sipRes;

            sipRes = new ::QJSPrimitiveValue((*a0 - *a1));

            return sipConvertFromNewType(sipRes, sipType_QJSPrimitiveValue, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtQml, sub_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___mul__(PyObject *, PyObject *);}
static PyObject *slot_QJSPrimitiveValue___mul__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;
        const ::QJSPrimitiveValue* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QJSPrimitiveValue, &a0, sipType_QJSPrimitiveValue, &a1))
        {
            ::QJSPrimitiveValue*sipRes;

            sipRes = new ::QJSPrimitiveValue((*a0 * *a1));

            return sipConvertFromNewType(sipRes, sipType_QJSPrimitiveValue, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtQml, mul_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___truediv__(PyObject *, PyObject *);}
static PyObject *slot_QJSPrimitiveValue___truediv__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;
        const ::QJSPrimitiveValue* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QJSPrimitiveValue, &a0, sipType_QJSPrimitiveValue, &a1))
        {
            ::QJSPrimitiveValue*sipRes;

            sipRes = new ::QJSPrimitiveValue((*a0 / *a1));

            return sipConvertFromNewType(sipRes, sipType_QJSPrimitiveValue, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtQml, truediv_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___mod__(PyObject *, PyObject *);}
static PyObject *slot_QJSPrimitiveValue___mod__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;
        const ::QJSPrimitiveValue* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QJSPrimitiveValue, &a0, sipType_QJSPrimitiveValue, &a1))
        {
            ::QJSPrimitiveValue*sipRes;

            sipRes = new ::QJSPrimitiveValue((*a0 % *a1));

            return sipConvertFromNewType(sipRes, sipType_QJSPrimitiveValue, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtQml, mod_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___eq__(PyObject *, PyObject *);}
static PyObject *slot_QJSPrimitiveValue___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QJSPrimitiveValue *sipCpp = reinterpret_cast< ::QJSPrimitiveValue *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QJSPrimitiveValue));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QJSPrimitiveValue, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtQml, eq_slot, sipType_QJSPrimitiveValue, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___ne__(PyObject *, PyObject *);}
static PyObject *slot_QJSPrimitiveValue___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QJSPrimitiveValue *sipCpp = reinterpret_cast< ::QJSPrimitiveValue *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QJSPrimitiveValue));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QJSPrimitiveValue, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtQml, ne_slot, sipType_QJSPrimitiveValue, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___lt__(PyObject *, PyObject *);}
static PyObject *slot_QJSPrimitiveValue___lt__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QJSPrimitiveValue *sipCpp = reinterpret_cast< ::QJSPrimitiveValue *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QJSPrimitiveValue));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QJSPrimitiveValue, &a0))
        {
            bool sipRes;

            sipRes = operator<((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtQml, lt_slot, sipType_QJSPrimitiveValue, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___gt__(PyObject *, PyObject *);}
static PyObject *slot_QJSPrimitiveValue___gt__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QJSPrimitiveValue *sipCpp = reinterpret_cast< ::QJSPrimitiveValue *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QJSPrimitiveValue));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QJSPrimitiveValue, &a0))
        {
            bool sipRes;

            sipRes = operator>((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtQml, gt_slot, sipType_QJSPrimitiveValue, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___le__(PyObject *, PyObject *);}
static PyObject *slot_QJSPrimitiveValue___le__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QJSPrimitiveValue *sipCpp = reinterpret_cast< ::QJSPrimitiveValue *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QJSPrimitiveValue));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QJSPrimitiveValue, &a0))
        {
            bool sipRes;

            sipRes = operator<=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtQml, le_slot, sipType_QJSPrimitiveValue, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___ge__(PyObject *, PyObject *);}
static PyObject *slot_QJSPrimitiveValue___ge__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QJSPrimitiveValue *sipCpp = reinterpret_cast< ::QJSPrimitiveValue *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QJSPrimitiveValue));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QJSPrimitiveValue* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QJSPrimitiveValue, &a0))
        {
            bool sipRes;

            sipRes = operator>=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtQml, ge_slot, sipType_QJSPrimitiveValue, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___neg__(PyObject *);}
static PyObject *slot_QJSPrimitiveValue___neg__(PyObject *sipSelf)
{
    ::QJSPrimitiveValue *sipCpp = reinterpret_cast< ::QJSPrimitiveValue *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QJSPrimitiveValue));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            ::QJSPrimitiveValue*sipRes;

            sipRes = new ::QJSPrimitiveValue(-(*sipCpp));

            return sipConvertFromNewType(sipRes, sipType_QJSPrimitiveValue, SIP_NULLPTR);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QJSPrimitiveValue___pos__(PyObject *);}
static PyObject *slot_QJSPrimitiveValue___pos__(PyObject *sipSelf)
{
    ::QJSPrimitiveValue *sipCpp = reinterpret_cast< ::QJSPrimitiveValue *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QJSPrimitiveValue));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            ::QJSPrimitiveValue*sipRes;

            sipRes = new ::QJSPrimitiveValue(+(*sipCpp));

            return sipConvertFromNewType(sipRes, sipType_QJSPrimitiveValue, SIP_NULLPTR);
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QJSPrimitiveValue(void *, int);}
static void release_QJSPrimitiveValue(void *sipCppV, int)
{
    delete reinterpret_cast< ::QJSPrimitiveValue *>(sipCppV);
}


extern "C" {static void *array_QJSPrimitiveValue(Py_ssize_t);}
static void *array_QJSPrimitiveValue(Py_ssize_t sipNrElem)
{
    return new ::QJSPrimitiveValue[sipNrElem];
}


extern "C" {static void array_delete_QJSPrimitiveValue(void *);}
static void array_delete_QJSPrimitiveValue(void *sipCpp)
{
    delete[] reinterpret_cast< ::QJSPrimitiveValue *>(sipCpp);
}


extern "C" {static void assign_QJSPrimitiveValue(void *, Py_ssize_t, void *);}
static void assign_QJSPrimitiveValue(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QJSPrimitiveValue *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QJSPrimitiveValue *>(sipSrc);
}


extern "C" {static void *copy_QJSPrimitiveValue(const void *, Py_ssize_t);}
static void *copy_QJSPrimitiveValue(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QJSPrimitiveValue(reinterpret_cast<const ::QJSPrimitiveValue *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QJSPrimitiveValue(sipSimpleWrapper *);}
static void dealloc_QJSPrimitiveValue(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QJSPrimitiveValue(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QJSPrimitiveValue(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QJSPrimitiveValue(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QJSPrimitiveValue *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QJSPrimitiveValue();

            return sipCpp;
        }
    }

    {
        ::QJSPrimitiveUndefined* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QJSPrimitiveUndefined, &a0))
        {
            sipCpp = new ::QJSPrimitiveValue(*a0);

            return sipCpp;
        }
    }

    {
        ::QJSPrimitiveNull* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QJSPrimitiveNull, &a0))
        {
            sipCpp = new ::QJSPrimitiveValue(*a0);

            return sipCpp;
        }
    }

    {
        bool a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "Xb", &a0))
        {
            sipCpp = new ::QJSPrimitiveValue(a0);

            return sipCpp;
        }
    }

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "Xi", &a0))
        {
            sipCpp = new ::QJSPrimitiveValue(a0);

            return sipCpp;
        }
    }

    {
        double a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "Xd", &a0))
        {
            sipCpp = new ::QJSPrimitiveValue(a0);

            return sipCpp;
        }
    }

    {
        ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QString, &a0, &a0State))
        {
            sipCpp = new ::QJSPrimitiveValue(*a0);
            sipReleaseType(a0, sipType_QString, a0State);

            return sipCpp;
        }
    }

    {
        const ::QJSPrimitiveValue* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QJSPrimitiveValue, &a0))
        {
            sipCpp = new ::QJSPrimitiveValue(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QJSPrimitiveValue[] = {
    {(void *)slot_QJSPrimitiveValue___add__, add_slot},
    {(void *)slot_QJSPrimitiveValue___sub__, sub_slot},
    {(void *)slot_QJSPrimitiveValue___mul__, mul_slot},
    {(void *)slot_QJSPrimitiveValue___truediv__, truediv_slot},
    {(void *)slot_QJSPrimitiveValue___mod__, mod_slot},
    {(void *)slot_QJSPrimitiveValue___eq__, eq_slot},
    {(void *)slot_QJSPrimitiveValue___ne__, ne_slot},
    {(void *)slot_QJSPrimitiveValue___lt__, lt_slot},
    {(void *)slot_QJSPrimitiveValue___gt__, gt_slot},
    {(void *)slot_QJSPrimitiveValue___le__, le_slot},
    {(void *)slot_QJSPrimitiveValue___ge__, ge_slot},
    {(void *)slot_QJSPrimitiveValue___neg__, neg_slot},
    {(void *)slot_QJSPrimitiveValue___pos__, pos_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QJSPrimitiveValue[] = {
    {sipName_data, meth_QJSPrimitiveValue_data, METH_VARARGS, doc_QJSPrimitiveValue_data},
    {sipName_equals, meth_QJSPrimitiveValue_equals, METH_VARARGS, doc_QJSPrimitiveValue_equals},
    {sipName_metaType, meth_QJSPrimitiveValue_metaType, METH_VARARGS, doc_QJSPrimitiveValue_metaType},
    {sipName_strictlyEquals, meth_QJSPrimitiveValue_strictlyEquals, METH_VARARGS, doc_QJSPrimitiveValue_strictlyEquals},
    {sipName_toBoolean, meth_QJSPrimitiveValue_toBoolean, METH_VARARGS, doc_QJSPrimitiveValue_toBoolean},
    {sipName_toDouble, meth_QJSPrimitiveValue_toDouble, METH_VARARGS, doc_QJSPrimitiveValue_toDouble},
    {sipName_toInteger, meth_QJSPrimitiveValue_toInteger, METH_VARARGS, doc_QJSPrimitiveValue_toInteger},
    {sipName_toString, meth_QJSPrimitiveValue_toString, METH_VARARGS, doc_QJSPrimitiveValue_toString},
    {sipName_type, meth_QJSPrimitiveValue_type, METH_VARARGS, doc_QJSPrimitiveValue_type}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QJSPrimitiveValue[] = {
    {sipName_Undefined, static_cast<int>(::QJSPrimitiveValue::Undefined)},
    {sipName_Null, static_cast<int>(::QJSPrimitiveValue::Null)},
    {sipName_Boolean, static_cast<int>(::QJSPrimitiveValue::Boolean)},
    {sipName_Integer, static_cast<int>(::QJSPrimitiveValue::Integer)},
    {sipName_Double, static_cast<int>(::QJSPrimitiveValue::Double)},
    {sipName_String, static_cast<int>(::QJSPrimitiveValue::String)},
    {0, 0}
};

PyDoc_STRVAR(doc_QJSPrimitiveValue, "\1QJSPrimitiveValue()\n"
"QJSPrimitiveValue(undefined: QJSPrimitiveUndefined)\n"
"QJSPrimitiveValue(null: QJSPrimitiveNull)\n"
"QJSPrimitiveValue(value: bool)\n"
"QJSPrimitiveValue(value: int)\n"
"QJSPrimitiveValue(value: float)\n"
"QJSPrimitiveValue(string: str|None)\n"
"QJSPrimitiveValue(a0: QJSPrimitiveValue)");


sipClassTypeDef sipTypeDef_QtQml_QJSPrimitiveValue = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QJSPrimitiveValue,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QJSPrimitiveValue,
        {0, 0, 1},
        9, methods_QJSPrimitiveValue,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QJSPrimitiveValue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QJSPrimitiveValue,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QJSPrimitiveValue,
    init_type_QJSPrimitiveValue,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QJSPrimitiveValue,
    assign_QJSPrimitiveValue,
    array_QJSPrimitiveValue,
    copy_QJSPrimitiveValue,
    release_QJSPrimitiveValue,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QJSPrimitiveValue,
    sizeof (::QJSPrimitiveValue),
};
