/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 123 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 32 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 35 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 40 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 43 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qabstractfileiconprovider.sip"
#include <qabstractfileiconprovider.h>
#line 49 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qfileinfo.sip"
#include <qfileinfo.h>
#line 52 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 55 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 58 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 61 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 64 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 67 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qabstracttextdocumentlayout.sip"
#include <qabstracttextdocumentlayout.h>
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qabstracttextdocumentlayout.sip"
#include <qabstracttextdocumentlayout.h>
#line 75 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 78 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 114 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 117 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextlayout.sip"
#include <qtextlayout.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextdocument.sip"
#include <qtextdocument.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 311 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 429 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 511 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 529 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 542 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 569 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 586 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 604 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 619 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 631 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 650 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 672 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 691 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 716 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 770 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 215 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 825 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 848 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 221 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 867 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 224 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 227 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
// The capsule destructor for a QModelRoleData array.
static void qpycore_gc_modelroledata(PyObject *mrd_obj);
#line 231 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 234 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 271 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 237 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 240 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 243 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 246 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 249 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 252 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 255 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 258 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 261 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 264 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 267 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 270 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 273 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 276 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 279 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qimage.sip"
#include <qimage.h>
#line 282 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qimageiohandler.sip"
#include <qimageiohandler.h>
#line 285 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 288 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qsurface.sip"
#include <qsurface.h>
#line 291 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpagesize.sip"
#include <qpagesize.h>
#line 294 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpagelayout.sip"
#include <qpagelayout.h>
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 90 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 300 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpageranges.sip"
#include <qpageranges.h>
#line 303 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 306 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 309 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qline.sip"
#include <qline.h>
#line 312 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qline.sip"
#include <qline.h>
#line 315 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 318 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 321 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 324 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 327 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 99 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qstandarditemmodel.sip"
#include <qstandarditemmodel.h>
#line 330 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 333 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 336 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qundostack.sip"
#include <qundostack.h>
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvalidator.sip"
#include <qvalidator.h>
#line 342 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 345 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 348 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolorspace.sip"
#include <qcolorspace.h>
#line 351 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 354 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 357 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 267 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 362 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 27 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 365 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 368 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 263 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 371 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 381 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 374 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 496 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 377 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 611 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 723 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 383 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 835 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 386 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qmatrix4x4.sip"
#include <qmatrix4x4.h>
#line 389 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 392 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpen.sip"
#include <qpen.h>
#line 395 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpicture.sip"
#include <qpicture.h>
#line 398 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixelformat.sip"
#include <qpixelformat.h>
#line 401 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 404 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 274 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 407 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 410 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 413 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qrgba64.sip"
#include <qrgba64.h>
#line 416 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 648 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 419 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 559 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 422 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 496 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 425 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 439 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 428 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 319 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 431 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 434 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 437 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 440 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 443 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 446 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qabstracttextdocumentlayout.sip"
#include <qabstracttextdocumentlayout.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qabstracttextdocumentlayout.sip"
#include <qabstracttextdocumentlayout.h>
#line 451 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaccessibilityhints.sip"
#include <qaccessibilityhints.h>
#line 454 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 457 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 460 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 361 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 463 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 409 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 469 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolorspace.sip"
#include <qcolorspace.h>
#line 174 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolorspace.sip"
#include <qcolorspace.h>
#line 474 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcolortransform.sip"
#include <qcolortransform.h>
#line 477 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qdesktopservices.sip"
#include <qdesktopservices.h>
#line 480 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 399 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 485 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qeventpoint.sip"
#include <qeventpoint.h>
#line 488 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfilesystemmodel.sip"
#include <qfilesystemmodel.h>
#line 491 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontdatabase.sip"
#include <qfontdatabase.h>
#line 494 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 500 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 503 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontvariableaxis.sip"
#include <qfontvariableaxis.h>
#line 506 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qglyphrun.sip"
#include <qglyphrun.h>
#line 509 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 61 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 514 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qimagereader.sip"
#include <qimagereader.h>
#line 517 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qimagewriter.sip"
#include <qimagewriter.h>
#line 520 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qinputdevice.sip"
#include <qinputdevice.h>
#line 523 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qmovie.sip"
#include <qmovie.h>
#line 526 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qoffscreensurface.sip"
#include <qoffscreensurface.h>
#line 529 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qopenglcontext.sip"
#include <qopenglcontext.h>
#line 532 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpageranges.sip"
#include <qpageranges.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpageranges.sip"
#include <qpageranges.h>
#line 537 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 540 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 517 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 545 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 148 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 548 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpdfoutputintent.sip"
#include <qpdfoutputintent.h>
#line 551 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmapcache.sip"
#include <qpixmapcache.h>
#line 554 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmapcache.sip"
#include <qpixmapcache.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmapcache.sip"
#include <qpixmapcache.h>
#line 559 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpointingdevice.sip"
#include <qpointingdevice.h>
#line 562 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 46 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpointingdevice.sip"
#include <qpointingdevice.h>
#line 565 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 111 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 570 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 127 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 575 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qrawfont.sip"
#include <qrawfont.h>
#line 578 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qstandarditemmodel.sip"
#include <qstandarditemmodel.h>
#line 581 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qstatictext.sip"
#include <qstatictext.h>
#line 584 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextcursor.sip"
#include <qtextcursor.h>
#line 587 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextdocumentfragment.sip"
#include <qtextdocumentfragment.h>
#line 590 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextdocumentwriter.sip"
#include <qtextdocumentwriter.h>
#line 593 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 534 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 596 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 622 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 599 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextlayout.sip"
#include <qtextlayout.h>
#line 602 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextlayout.sip"
#include <qtextlayout.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextlayout.sip"
#include <qtextlayout.h>
#line 607 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 142 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextlayout.sip"
#include <qtextlayout.h>
#line 610 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 615 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 117 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 142 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 620 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 220 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 623 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 244 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 626 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextoption.sip"
#include <qtextoption.h>
#line 629 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextoption.sip"
#include <qtextoption.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextoption.sip"
#include <qtextoption.h>
#line 634 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtexttable.sip"
#include <qtexttable.h>
#line 637 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qundogroup.sip"
#include <qundogroup.h>
#line 640 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 52 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qundostack.sip"
#include <qundostack.h>
#line 643 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 52 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvalidator.sip"
#include <qvalidator.h>
#line 646 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvalidator.sip"
#include <qvalidator.h>
#line 649 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvalidator.sip"
#include <qvalidator.h>
#line 652 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qsessionmanager.sip"
#include <qsessionmanager.h>
#line 655 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpdfwriter.sip"
#include <qpdfwriter.h>
#line 658 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainterstateguard.sip"
#include <qpainterstateguard.h>
#line 661 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpagedpaintdevice.sip"
#include <qpagedpaintdevice.h>
#line 664 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qinputmethod.sip"
#include <qinputmethod.h>
#line 667 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qclipboard.sip"
#include <qclipboard.h>
#line 670 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qactiongroup.sip"
#include <qactiongroup.h>
#line 673 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtGui[] = {
    'Q', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'F', 'o', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 'I', 'n', 'h', 'e', 'r', 'i', 't', 'a', 'n', 'c', 'e', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'T', 'e', 'x', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 'R', 'e', 't', 'r', 'i', 'e', 'v', 'a', 'l', 'F', 'l', 'a', 'g', '>', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'P', 'a', 'i', 'n', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'F', 'i', 'l', 'e', 'I', 'c', 'o', 'n', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'O', 'p', 't', 'i', 'o', 'n', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 'F', 'e', 'a', 't', 'u', 'r', 'e', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'I', 'm', 'a', 'g', 'e', 'I', 'O', 'H', 'a', 'n', 'd', 'l', 'e', 'r', ':', ':', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', '>', 0,
    'Q', 'P', 'l', 'a', 't', 'f', 'o', 'r', 'm', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'E', 'v', 'e', 'n', 't', ':', ':', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'E', 'v', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'F', 'e', 'a', 't', 'u', 'r', 'e', '>', 0,
    'A', 'd', 'd', 'S', 'p', 'a', 'c', 'e', 'F', 'o', 'r', 'L', 'i', 'n', 'e', 'A', 'n', 'd', 'P', 'a', 'r', 'a', 'g', 'r', 'a', 'p', 'h', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 's', 0,
    'Q', 'N', 'a', 't', 'i', 'v', 'e', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'Q', 'W', 'a', 'y', 'l', 'a', 'n', 'd', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'P', 'i', 'x', 'm', 'a', 'p', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'H', 'i', 'n', 't', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'P', 'o', 'i', 'n', 't', 'i', 'n', 'g', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'P', 'o', 'i', 'n', 't', 'e', 'r', 'T', 'y', 'p', 'e', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 'O', 'p', 't', 'i', 'o', 'n', '>', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'F', 'i', 'l', 'e', 'I', 'c', 'o', 'n', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'I', 'c', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'F', 'o', 'n', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', ':', ':', 'W', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', '>', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'n', 'd', 'N', 'o', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'm', 'o', 'u', 's', 'e', 'Q', 'u', 'i', 'c', 'k', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    's', 'e', 't', 'H', 'i', 'g', 'h', 'D', 'p', 'i', 'S', 'c', 'a', 'l', 'e', 'F', 'a', 'c', 't', 'o', 'r', 'R', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', 'F', 'l', 'a', 'g', '>', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 'R', 'e', 't', 'r', 'i', 'e', 'v', 'a', 'l', 'F', 'l', 'a', 'g', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'r', 'N', 'o', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    's', 'h', 'o', 'w', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 's', 'I', 'n', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'B', 'l', 'o', 'c', 'k', 'T', 'r', 'a', 'i', 'l', 'i', 'n', 'g', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'R', 'u', 'l', 'e', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'F', 'i', 'l', 'e', 'I', 'c', 'o', 'n', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'I', 'c', 'o', 'n', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'S', 'c', 'a', 'l', 'e', 'd', 'P', 'i', 'x', 'm', 'a', 'p', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 0,
    'Q', 'N', 'a', 't', 'i', 'v', 'e', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'Q', 'X', '1', '1', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'L', 'i', 'n', 'e', 'H', 'e', 'i', 'g', 'h', 't', 'T', 'y', 'p', 'e', 's', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'F', 'i', 'l', 'e', 'S', 'y', 's', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', ':', ':', 'O', 'p', 't', 'i', 'o', 'n', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'I', 'n', 'p', 'u', 't', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'I', 'n', 'p', 'u', 't', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'D', 'e', 'v', 'i', 'c', 'e', 'T', 'y', 'p', 'e', '>', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', ':', ':', 'O', 'p', 'e', 'n', 'G', 'L', 'M', 'o', 'd', 'u', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 'S', 't', 'a', 't', 'e', 'G', 'u', 'a', 'r', 'd', ':', ':', 'I', 'n', 'i', 't', 'i', 'a', 'l', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'A', 'l', 'p', 'h', 'a', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'T', 'y', 'p', 'e', 'I', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'n', 'd', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'X', 'o', 'r', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'n', 'd', 'N', 'o', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'a', 'd', 'd', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'h', 'i', 'g', 'h', 'D', 'p', 'i', 'S', 'c', 'a', 'l', 'e', 'F', 'a', 'c', 't', 'o', 'r', 'R', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'A', 'n', 'd', 'H', 'o', 'l', 'd', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'E', 'm', 'o', 'j', 'i', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 't', 'o', 'p', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'O', 'v', 'e', 'r', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '1', '6', 'F', 'P', 'x', '4', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '3', '2', 'F', 'P', 'x', '4', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', ':', ':', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 'F', 'l', 'a', 'g', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'D', 'i', 'r', 't', 'y', 'F', 'l', 'a', 'g', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'F', 'i', 'n', 'd', 'F', 'l', 'a', 'g', '>', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'I', 'O', 'H', 'a', 'n', 'd', 'l', 'e', 'r', ':', ':', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'e', 'x', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 'R', 'a', 'n', 'g', 'e', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 's', 't', 'd', ':', ':', 'p', 'a', 'i', 'r', '<', 'q', 'r', 'e', 'a', 'l', ',', 'Q', 'C', 'o', 'l', 'o', 'r', '>', ' ', '>', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 'M', 'e', 't', 'r', 'i', 'c', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'r', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'r', 'N', 'o', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'M', 'i', 'r', 'r', 'o', 'r', 'A', 'n', 'd', 'R', 'o', 't', 'a', 't', 'e', '9', '0', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'V', 'i', 'r', 't', 'u', 'a', 'l', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'E', 'm', 'o', 'j', 'i', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    's', 'e', 't', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'I', 'n', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'O', 'u', 't', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'a', 'd', 'e', 'r', ':', ':', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'a', 'd', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'W', 'r', 'i', 't', 'e', 'r', ':', ':', 'I', 'm', 'a', 'g', 'e', 'W', 'r', 'i', 't', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'O', 'u', 't', 'O', 'f', 'B', 'o', 'u', 'n', 'd', 's', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'a', 'b', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'M', 'e', 't', 'a', 'I', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', ':', ':', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'S', 'h', 'o', 'w', 'L', 'i', 'n', 'e', 'A', 'n', 'd', 'P', 'a', 'r', 'a', 'g', 'r', 'a', 'p', 'h', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 's', 0,
    'i', 's', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'I', 'n', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 0,
    'r', 'e', 'p', 'o', 'r', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'S', 'h', 'o', 'w', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 's', 'I', 'n', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 's', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'I', 'n', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '4', '4', '4', '4', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '6', '6', '6', '6', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '8', '5', '5', '5', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '8', '5', '6', '5', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '8', '8', '8', '8', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'P', 'd', 'm', 'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 'F', '_', 'E', 'n', 'c', 'o', 'd', 'e', 'd', 'A', 0,
    'P', 'd', 'm', 'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 'F', '_', 'E', 'n', 'c', 'o', 'd', 'e', 'd', 'B', 0,
    'Q', 'A', 'c', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', ':', ':', 'E', 'x', 'c', 'l', 'u', 's', 'i', 'o', 'n', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', ':', ':', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'T', 'e', 'x', 't', 'I', 't', 'e', 'm', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'F', 'l', 'a', 'g', '>', 0,
    'Q', 'P', 'a', 'g', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 'D', 'r', 'a', 'w', 'M', 'o', 'd', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'n', 'd', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'X', 'o', 'r', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'F', 'l', 'i', 'p', 'A', 'n', 'd', 'R', 'o', 't', 'a', 't', 'e', '9', '0', 0,
    'a', 'd', 'd', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'E', 'm', 'o', 'j', 'i', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'q', 't', '_', 's', 'e', 't', '_', 's', 'e', 'q', 'u', 'e', 'n', 'c', 'e', '_', 'a', 'u', 't', 'o', '_', 'm', 'n', 'e', 'm', 'o', 'n', 'i', 'c', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', '2', 'B', 'G', 'R', '3', '0', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', '2', 'R', 'G', 'B', '3', '0', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', ':', ':', 'N', 'a', 'm', 'e', 'd', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', '>', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'R', 'a', 'w', 'F', 'o', 'n', 't', ':', ':', 'L', 'a', 'y', 'o', 'u', 't', 'F', 'l', 'a', 'g', '>', 0,
    'Q', 'F', 'o', 'n', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', ':', ':', 'W', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'I', 'O', 'H', 'a', 'n', 'd', 'l', 'e', 'r', ':', ':', 'I', 'm', 'a', 'g', 'e', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'Q', 'K', 'e', 'y', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', ':', ':', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'P', 'i', 'x', 'm', 'a', 'p', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'H', 'i', 'n', 't', 0,
    'Q', 'P', 'o', 'i', 'n', 't', 'i', 'n', 'g', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'P', 'o', 'i', 'n', 't', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'e', 's', 's', 'i', 'o', 'n', 'M', 'a', 'n', 'a', 'g', 'e', 'r', ':', ':', 'R', 'e', 's', 't', 'a', 'r', 't', 'H', 'i', 'n', 't', 0,
    'Q', 'S', 't', 'a', 't', 'i', 'c', 'T', 'e', 'x', 't', ':', ':', 'P', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'S', 'w', 'a', 'p', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'M', 'a', 'r', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'r', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'W', 'r', 'a', 'p', 'A', 't', 'W', 'o', 'r', 'd', 'B', 'o', 'u', 'n', 'd', 'a', 'r', 'y', 'O', 'r', 'A', 'n', 'y', 'w', 'h', 'e', 'r', 'e', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'E', 'm', 'o', 'j', 'i', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'I', 'n', 'p', 'u', 't', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'Q', 'u', 'i', 'c', 'k', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 0,
    's', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', 'C', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'D', 'o', 'n', 't', 'U', 's', 'e', 'C', 'u', 's', 't', 'o', 'm', 'D', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'y', 'I', 'c', 'o', 'n', 's', 0,
    'F', 'o', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 'S', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', 'O', 'n', 'l', 'y', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '3', '2', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '6', '4', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'O', 'b', 'j', 'e', 'c', 't', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 's', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', ':', ':', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'M', 'o', 'd', 'e', 'l', 0,
    'Q', 'I', 'c', 'o', 'n', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'I', 'c', 'o', 'n', 'E', 'n', 'g', 'i', 'n', 'e', 'H', 'o', 'o', 'k', 0,
    'Q', 'K', 'e', 'y', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', ':', ':', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 'M', 'a', 't', 'c', 'h', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'A', 'l', 'p', 'h', 'a', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'Q', 'R', 'e', 'g', 'u', 'l', 'a', 'r', 'E', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 'C', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 't', 's', 0,
    'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'S', 'u', 'b', 'p', 'i', 'x', 'e', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', 0,
    'c', 'l', 'e', 'a', 'r', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 'C', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 't', 's', 0,
    's', 'h', 'o', 'w', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 's', 'I', 'n', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 's', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'C', 'o', 'l', 'o', 'r', 'D', 'o', 'd', 'g', 'e', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 't', 'o', 'p', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'v', 'e', 'r', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', ':', ':', 'P', 'r', 'i', 'm', 'a', 'r', 'y', 'P', 'o', 'i', 'n', 't', 's', 0,
    'Q', 'D', 'o', 'u', 'b', 'l', 'e', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', ':', ':', 'N', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'E', 'v', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', ':', ':', 'S', 't', 'a', 't', 'e', '>', 0,
    'Q', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', ':', ':', 'S', 'i', 'z', 'e', 'M', 'a', 't', 'c', 'h', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'R', 'a', 'w', 'F', 'o', 'n', 't', ':', ':', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'u', 'r', 's', 'o', 'r', ':', ':', 'M', 'o', 'v', 'e', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'u', 'r', 's', 'o', 'r', ':', ':', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', 'F', 'l', 'a', 'g', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'a', 'd', 'd', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'n', 't', 'F', 'r', 'o', 'm', 'D', 'a', 't', 'a', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'D', 'e', 'c', 'i', 'd', 'e', 'F', 'o', 'r', 'm', 'a', 't', 'F', 'r', 'o', 'm', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'T', 'o', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'C', 'o', 'l', 'o', 'r', 'B', 'u', 'r', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'E', 'x', 'c', 'l', 'u', 's', 'i', 'o', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'H', 'a', 'r', 'd', 'L', 'i', 'g', 'h', 't', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'f', 't', 'L', 'i', 'g', 'h', 't', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'u', 't', 0,
    'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'D', 'i', 'a', 'l', 'e', 'c', 't', 'C', 'o', 'm', 'm', 'o', 'n', 'M', 'a', 'r', 'k', 0,
    'P', 'd', 'm', 'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 'S', 'c', 'a', 'l', 'e', 'd', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'F', 'i', 'l', 'e', 'I', 'c', 'o', 'n', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    'Q', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'E', 'v', 'e', 'n', 't', ':', ':', 'R', 'e', 'a', 's', 'o', 'n', 0,
    'Q', 'F', 'l', 'a', 'g', 's', '<', 'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'F', 'l', 'a', 'g', '>', 0,
    'Q', 'F', 'o', 'n', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', ':', ':', 'S', 'y', 's', 't', 'e', 'm', 'F', 'o', 'n', 't', 0,
    'Q', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', ':', ':', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 'K', 'e', 'y', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', ':', ':', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'K', 'e', 'y', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'a', 'g', 'e', 'R', 'a', 'n', 'g', 'e', 's', ':', ':', 'R', 'a', 'n', 'g', 'e', '>', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 'P', 'a', 't', 'h', ':', ':', 'E', 'l', 'e', 'm', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'c', 'r', 'o', 'l', 'l', 'E', 'v', 'e', 'n', 't', ':', ':', 'S', 'c', 'r', 'o', 'l', 'l', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 'n', 'e', ':', ':', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'C', 'l', 'e', 'a', 'r', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'u', 'r', 'f', 'a', 'c', 'e', 'A', 'b', 'o', 'u', 't', 'T', 'o', 'B', 'e', 'D', 'e', 's', 't', 'r', 'o', 'y', 'e', 'd', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'T', 'r', 'i', 'g', 'g', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'r', 'a', 's', 't', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'A', 'n', 'd', 'H', 'o', 'l', 'd', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    'o', 'u', 't', 'p', 'u', 't', 'C', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'l', 'l', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'n', 't', 's', 0,
    's', 'e', 't', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 'C', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 't', 's', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'u', 'r', 's', 'o', 'r', 'M', 'o', 'v', 'e', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'L', 'a', 'b', 'e', 'l', 's', 0,
    's', 'e', 't', 'Q', 'u', 'i', 't', 'O', 'n', 'L', 'a', 's', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'l', 'o', 's', 'e', 'd', 0,
    's', 't', 'd', ':', ':', 'o', 'p', 't', 'i', 'o', 'n', 'a', 'l', '<', 'Q', 'F', 'o', 'n', 't', ':', ':', 'T', 'a', 'g', '>', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'y', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'I', 'n', 0,
    'I', 'n', 's', 'e', 'r', 't', 'P', 'a', 'r', 'a', 'g', 'r', 'a', 'p', 'h', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 0,
    'N', 'o', 'n', 'C', 'o', 's', 'm', 'e', 't', 'i', 'c', 'B', 'r', 'u', 's', 'h', 'P', 'a', 't', 't', 'e', 'r', 'n', 's', 0,
    'O', 'l', 'd', 'F', 'o', 'n', 't', 'L', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    'Q', 'F', 'i', 'l', 'e', 'S', 'y', 's', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', ':', ':', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'H', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'D', 'e', 'v', 'i', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'F', 'o', 'n', 't', 'V', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'A', 'x', 'i', 's', '>', 0,
    'Q', 'M', 'a', 'p', '<', 'Q', 'F', 'o', 'n', 't', ':', ':', 'T', 'a', 'g', ',', 'q', 'u', 'i', 'n', 't', '3', '2', '>', 0,
    'Q', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'P', 'i', 'x', 'm', 'a', 'p', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'A', 'l', 'p', 'h', 'a', 'U', 's', 'a', 'g', 'e', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'C', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 'l', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'O', 'b', 'j', 'e', 'c', 't', 'T', 'y', 'p', 'e', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 'R', 'a', 'n', 'g', 'e', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'V', 'i', 'r', 't', 'u', 'a', 'l', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'D', 'e', 't', 'e', 'c', 't', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'E', 'x', 'c', 'l', 'u', 's', 'i', 'v', 'e', 'P', 'o', 'i', 'n', 't', 'G', 'r', 'a', 'b', 'b', 'e', 'r', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'H', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'L', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    's', 't', 'a', 'r', 't', 'D', 'r', 'a', 'g', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    't', 'a', 'k', 'e', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'S', 'p', 'e', 'c', 'i', 'f', 'i', 'c', 'R', 'o', 'l', 'e', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'L', 'i', 'g', 'h', 't', 'e', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'O', 'v', 'e', 'r', 'l', 'a', 'y', 0,
    'C', 'u', 'r', 's', 'o', 'r', 'B', 'e', 't', 'w', 'e', 'e', 'n', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 's', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'T', 'e', 'x', 't', 'S', 't', 'r', 'i', 'k', 'e', 't', 'h', 'r', 'o', 'u', 'g', 'h', 0,
    'P', 'y', 'Q', 't', '6', '.', 's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', ':', ':', 'C', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 'l', 0,
    'Q', 'F', 'i', 'l', 'e', 'S', 'y', 's', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', ':', ':', 'R', 'o', 'l', 'e', 's', 0,
    'Q', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', ':', ':', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 'F', 'l', 'a', 'g', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'T', 'a', 'b', '>', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'D', 'i', 'r', 't', 'y', 'F', 'l', 'a', 'g', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'B', 'y', 't', 'e', 'O', 'r', 'd', 'e', 'r', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'Y', 'U', 'V', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'Q', 'P', 'o', 'i', 'n', 't', 'i', 'n', 'g', 'D', 'e', 'v', 'i', 'c', 'e', 'U', 'n', 'i', 'q', 'u', 'e', 'I', 'd', 0,
    'Q', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'I', 't', 'e', 'm', ':', ':', 'I', 't', 'e', 'm', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'F', 'i', 'n', 'd', 'F', 'l', 'a', 'g', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'C', 'u', 'r', 's', 'o', 'r', 'M', 'o', 'd', 'e', 0,
    'Q', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'e', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'o', 'f', 't', 'w', 'a', 'r', 'e', 'U', 'p', 'd', 'a', 't', 'e', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'T', 'e', 'x', 't', 'S', 'u', 'p', 'e', 'r', 'S', 'c', 'r', 'i', 'p', 't', 'B', 'a', 's', 'e', 'l', 'i', 'n', 'e', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'R', 'o', 't', 'a', 't', 'e', '1', '8', '0', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'R', 'o', 't', 'a', 't', 'e', '2', '7', '0', 0,
    'a', 'd', 'v', 'a', 'n', 'c', 'e', 's', 'F', 'o', 'r', 'G', 'l', 'y', 'p', 'h', 'I', 'n', 'd', 'e', 'x', 'e', 's', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'c', 'i', 'd', 'e', 'F', 'o', 'r', 'm', 'a', 't', 'F', 'r', 'o', 'm', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    'i', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 's', 'F', 'o', 'r', 'M', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'A', 'u', 't', 'o', 'R', 'e', 'p', 'e', 'a', 't', 'R', 'a', 't', 'e', 'F', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'B', 'l', 'o', 'c', 'k', 'U', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'D', 'e', 's', 'k', 't', 'o', 'p', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'A', 'w', 'a', 'r', 'e', 0,
    's', 'e', 't', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    's', 'e', 't', 'K', 'e', 'e', 'p', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'O', 'n', 'I', 'n', 's', 'e', 'r', 't', 0,
    's', 'e', 't', 'P', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 'S', 'c', 'a', 'n', 'W', 'r', 'i', 't', 'e', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'L', 'a', 'b', 'e', 'l', 's', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'W', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 's', 0,
    't', 'a', 'b', 'F', 'o', 'c', 'u', 's', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'h', 'e', 'e', 'l', 'S', 'c', 'r', 'o', 'l', 'l', 'L', 'i', 'n', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'B', 'l', 'o', 'c', 'k', 'N', 'o', 'n', 'B', 'r', 'e', 'a', 'k', 'a', 'b', 'l', 'e', 'L', 'i', 'n', 'e', 's', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'D', 'o', 't', 'D', 'o', 't', 'D', 'a', 's', 'h', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'a', 'r', 'k', 'e', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'T', 'e', 'x', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'L', 't', 'r', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'T', 'e', 'x', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'R', 't', 'l', 0,
    'L', 'o', 's', 's', 'l', 'e', 's', 's', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', '_', 'A', 'l', 'w', 'a', 'y', 's', 'B', 'e', 'f', 'o', 'r', 'e', 0,
    'P', 'a', 'i', 'n', 't', 'O', 'u', 't', 's', 'i', 'd', 'e', 'P', 'a', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', ':', ':', 'P', 'r', 'i', 'm', 'a', 'r', 'i', 'e', 's', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'Q', 'u', 'e', 'r', 'y', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', '*', '>', 0,
    'Q', 'M', 'a', 'p', '<', 'Q', 'F', 'o', 'n', 't', ':', ':', 'T', 'a', 'g', ',', 'f', 'l', 'o', 'a', 't', '>', 0,
    'Q', 'P', 'd', 'f', 'W', 'r', 'i', 't', 'e', 'r', ':', ':', 'C', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 'l', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', ':', ':', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'C', 'l', 'a', 's', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 's', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'S', 't', 'y', 'l', 'e', 0,
    'Q', 'W', 'h', 'a', 't', 's', 'T', 'h', 'i', 's', 'C', 'l', 'i', 'c', 'k', 'e', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'R', 'e', 't', 'r', 'i', 'e', 'v', 'e', 'G', 'l', 'y', 'p', 'h', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'S', 'h', 'o', 'w', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'T', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'o', 'r', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'B', 'o', 't', 't', 'o', 'm', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'R', 'o', 't', 'a', 't', 'e', '9', '0', 0,
    'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'o', 'r', 'm', 'a', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'a', 'l', 'l', 'o', 'w', 's', 'E', 'r', 'r', 'o', 'r', 'I', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 'C', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 't', 's', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'F', 'l', 'a', 's', 'h', 'T', 'i', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'u', 'r', 's', 'o', 'r', 'M', 'o', 'v', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 'F', 'S', 'c', 'a', 'l', 'e', 0,
    'i', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'A', 'u', 't', 'o', 'R', 'e', 'p', 'e', 'a', 't', 'R', 'a', 't', 'e', 0,
    'l', 'a', 'y', 'o', 'u', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'q', 'u', 'e', 'r', 'y', 'K', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'q', 'u', 'i', 't', 'O', 'n', 'L', 'a', 's', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'l', 'o', 's', 'e', 'd', 0,
    's', 'a', 'f', 'e', 'A', 'r', 'e', 'a', 'M', 'a', 'r', 'g', 'i', 'n', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'X', 'm', 'p', 'M', 'e', 't', 'a', 'd', 'a', 't', 'a', 0,
    's', 'e', 't', 'F', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'S', 'e', 'a', 'r', 'c', 'h', 'P', 'a', 't', 'h', 's', 0,
    's', 'e', 't', 'F', 'o', 'c', 'u', 's', 'O', 'n', 'T', 'o', 'u', 'c', 'h', 'R', 'e', 'l', 'e', 'a', 's', 'e', 0,
    's', 'e', 't', 'K', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'G', 'r', 'a', 'b', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'S', 'u', 'p', 'e', 'r', 'S', 'c', 'r', 'i', 'p', 't', 'B', 'a', 's', 'e', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'C', 'o', 'l', 'u', 'm', 'n', 'S', 'p', 'a', 'n', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'T', 'h', 'r', 'e', 'a', 'd', 'e', 'd', 'O', 'p', 'e', 'n', 'G', 'L', 0,
    't', 'a', 'k', 'e', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    't', 'o', 'u', 'c', 'h', 'D', 'o', 'u', 'b', 'l', 'e', 'T', 'a', 'p', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'u', 's', 'e', 'H', 'o', 'v', 'e', 'r', 'E', 'f', 'f', 'e', 'c', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'i', 'r', 't', 'u', 'a', 'l', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'C', 'l', 'e', 'a', 'r', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'a', 'b', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'R', 'e', 't', 'r', 'i', 'e', 'v', 'a', 'l', 'F', 'l', 'a', 'g', 's', 0,
    'E', 'l', 'e', 'm', 'e', 'n', 't', 'L', 'i', 's', 't', 'P', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', 0,
    'F', 'u', 'z', 'z', 'y', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'M', 'a', 't', 'c', 'h', 0,
    'I', 'n', 'c', 'l', 'u', 'd', 'e', 'T', 'r', 'a', 'i', 'l', 'i', 'n', 'g', 'S', 'p', 'a', 'c', 'e', 's', 0,
    'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'D', 'i', 'a', 'l', 'e', 'c', 't', 'G', 'i', 't', 'H', 'u', 'b', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'S', 't', 'a', 'r', 't', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'O', 'l', 'd', 'T', 'e', 'x', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', '_', 'A', 'l', 'w', 'a', 'y', 's', 'A', 'f', 't', 'e', 'r', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'T', 'y', 'p', 'o', 'L', 'i', 'n', 'e', 'M', 'e', 't', 'r', 'i', 'c', 's', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'H', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'C', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'I', 't', 'e', 'm', '*', '>', 0,
    'Q', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', ':', ':', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 'I', 'd', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 'P', 'a', 't', 'h', ':', ':', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'Q', 'P', 'l', 'a', 't', 'f', 'o', 'r', 'm', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', ':', ':', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'u', 'r', 's', 'o', 'r', ':', ':', 'M', 'o', 'v', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'S', 't', 'a', 'c', 'k', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'Q', 'T', 'e', 'x', 't', 'I', 't', 'e', 'm', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'F', 'l', 'a', 'g', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'Q', 'W', 'i', 'n', 'd', 'o', 'w', ':', ':', 'A', 'n', 'c', 'e', 's', 't', 'o', 'r', 'M', 'o', 'd', 'e', 0,
    'R', 'e', 't', 'r', 'i', 'e', 'v', 'e', 'S', 't', 'r', 'i', 'n', 'g', 'I', 'n', 'd', 'e', 'x', 'e', 's', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'S', 't', 'a', 'r', 't', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'S', 'h', 'o', 'w', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'I', 'g', 'n', 'o', 'r', 'a', 'b', 'l', 'e', 's', 0,
    'S', 'm', 'o', 'o', 't', 'h', 'P', 'i', 'x', 'm', 'a', 'p', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'i', 'g', 'h', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'T', 'e', 'x', 't', 'S', 'u', 'b', 'S', 'c', 'r', 'i', 'p', 't', 'B', 'a', 's', 'e', 'l', 'i', 'n', 'e', 0,
    'T', 'e', 'x', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'W', 'e', 'a', 't', 'h', 'e', 'r', 'F', 'e', 'w', 'C', 'l', 'o', 'u', 'd', 's', 'N', 'i', 'g', 'h', 't', 0,
    'a', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'a', 'u', 't', 'o', 'D', 'e', 't', 'e', 'c', 't', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'e', 'd', 'T', 'o', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'I', 'n', 'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'x', 'c', 'l', 'u', 's', 'i', 'v', 'e', 'P', 'o', 'i', 'n', 't', 'G', 'r', 'a', 'b', 'b', 'e', 'r', 0,
    'f', 'i', 'n', 'd', 'B', 'l', 'o', 'c', 'k', 'B', 'y', 'L', 'i', 'n', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'f', 'o', 'n', 't', 'H', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'f', 'o', 'n', 't', 'L', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    'g', 'l', 'y', 'p', 'h', 'I', 'n', 'd', 'e', 'x', 'e', 's', 'F', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'i', 'n', 'p', 'u', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'j', 'o', 'i', 'n', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'E', 'd', 'i', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'I', 'n', 'p', 'u', 't', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'a', 's', 's', 'w', 'o', 'r', 'd', 'M', 'a', 's', 'k', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'P', 'o', 'i', 'n', 't', 'i', 'n', 'g', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'G', 'r', 'a', 'y', 's', 'c', 'a', 'l', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'n', 't', 0,
    'r', 'e', 's', 't', 'o', 'r', 'e', 'O', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 'C', 'u', 'r', 's', 'o', 'r', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'T', 'r', 'i', 'g', 'g', 'e', 'r', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'C', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'I', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    's', 'e', 't', 'I', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 'F', 'i', 'l', 't', 'e', 'r', 'D', 'i', 's', 'a', 'b', 'l', 'e', 's', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    's', 'e', 't', 'W', 'o', 'r', 'l', 'd', 'M', 'a', 't', 'r', 'i', 'x', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'i', 'n', 'g', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'A', 'c', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'w', 'i', 't', 'h', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', 0,
    'A', 'u', 'd', 'i', 'o', 'I', 'n', 'p', 'u', 't', 'M', 'i', 'c', 'r', 'o', 'p', 'h', 'o', 'n', 'e', 0,
    'C', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'P', 'l', 'u', 's', 0,
    'D', 'i', 'r', 't', 'y', 'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'P', 'r', 'i', 'n', 't', 'P', 'r', 'e', 'v', 'i', 'e', 'w', 0,
    'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'l', 'i', 's', 't', 'S', 'h', 'u', 'f', 'f', 'l', 'e', 0,
    'P', 'e', 'r', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'H', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'Q', 'A', 'c', 't', 'i', 'o', 'n', ':', ':', 'A', 'c', 't', 'i', 'o', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'C', 'o', 'n', 's', 't', 'a', 'n', 't', 's', ':', ':', 'S', 'v', 'g', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'S', 't', 'y', 'l', 'e', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', ':', ':', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'I', 'n', 'p', 'u', 't', 'D', 'e', 'v', 'i', 'c', 'e', '*', '>', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 0,
    'Q', 'P', 'a', 'l', 'e', 't', 't', 'e', ':', ':', 'C', 'o', 'l', 'o', 'r', 'G', 'r', 'o', 'u', 'p', 0,
    'Q', 'R', 'a', 'w', 'F', 'o', 'n', 't', ':', ':', 'L', 'a', 'y', 'o', 'u', 't', 'F', 'l', 'a', 'g', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', ':', ':', 'i', 't', 'e', 'r', 'a', 't', 'o', 'r', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', ':', ':', 'i', 't', 'e', 'r', 'a', 't', 'o', 'r', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'b', 'j', 'e', 'c', 't', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'T', 'a', 'b', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'R', 'e', 't', 'r', 'i', 'e', 'v', 'e', 'G', 'l', 'y', 'p', 'h', 'I', 'n', 'd', 'e', 'x', 'e', 's', 0,
    'S', 'm', 'a', 'l', 'l', 'e', 's', 't', 'R', 'e', 'a', 'd', 'a', 'b', 'l', 'e', 'F', 'o', 'n', 't', 0,
    'S', 'o', 'f', 't', 'w', 'a', 'r', 'e', 'U', 'p', 'd', 'a', 't', 'e', 'U', 'r', 'g', 'e', 'n', 't', 0,
    'S', 'u', 'b', 'P', 'i', 'x', 'e', 'l', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'L', 'e', 'f', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'T', 'h', 'r', 'e', 'e', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'M', 'i', 'r', 'r', 'o', 'r', 0,
    'a', 'c', 'c', 'e', 'p', 't', 'P', 'r', 'o', 'p', 'o', 's', 'e', 'd', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', 'A', 'm', 'b', 'i', 'g', 'u', 'o', 'u', 's', 'l', 'y', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'V', 'i', 'r', 't', 'u', 'a', 'l', 'S', 'i', 'z', 'e', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'O', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'F', 'r', 'o', 'm', 'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'B', 'l', 'o', 'c', 'k', 'U', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'd', 'e', 's', 'k', 't', 'o', 'p', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'A', 'w', 'a', 'r', 'e', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    'k', 'e', 'e', 'p', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'O', 'n', 'I', 'n', 's', 'e', 'r', 't', 0,
    'l', 'e', 'n', 'g', 't', 'h', 'V', 'e', 'c', 't', 'o', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'l', 'i', 'g', 'h', 't', 'g', 'o', 'l', 'd', 'e', 'n', 'r', 'o', 'd', 'y', 'e', 'l', 'l', 'o', 'w', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'e', 'r', 'g', 'e', 'B', 'l', 'o', 'c', 'k', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'X', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'Y', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'I', 'n', 'l', 'i', 'n', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'S', 'c', 'r', 'e', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 'S', 'c', 'a', 'n', 'W', 'r', 'i', 't', 'e', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'B', 'l', 'o', 'c', 'k', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'C', 'o', 'l', 'o', 'r', 'G', 'r', 'o', 'u', 'p', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'S', 't', 'y', 'l', 'e', 'S', 'h', 'e', 'e', 't', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'E', 'l', 'e', 'm', 'e', 'n', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 't', 0,
    's', 'e', 't', 'F', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'T', 'h', 'e', 'm', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'L', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    's', 'e', 't', 'H', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    's', 'e', 't', 'I', 'c', 'o', 'n', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'I', 'n', 'M', 'e', 'n', 'u', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'B', 'l', 'o', 'c', 'k', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'N', 'o', 'n', 'B', 'r', 'e', 'a', 'k', 'a', 'b', 'l', 'e', 'L', 'i', 'n', 'e', 's', 0,
    's', 'e', 't', 'R', 'e', 'g', 'u', 'l', 'a', 'r', 'E', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'S', 'u', 'b', 'S', 'c', 'r', 'i', 'p', 't', 'B', 'a', 's', 'e', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'M', 'o', 'v', 'e', 'm', 'e', 'n', 't', 'X', 0,
    's', 't', 'a', 'r', 't', 'D', 'r', 'a', 'g', 'T', 'i', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'r', 'a', 'g', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'r', 'o', 'p', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    't', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'v', 'i', 'e', 'w', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'w', 'i', 't', 'h', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'A', 'u', 't', 'o', 'm', 'a', 't', 'i', 'c', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'D', 'o', 't', 'D', 'a', 's', 'h', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'X', 'o', 'r', 0,
    'C', 'o', 'n', 'i', 'c', 'a', 'l', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 'F', 'i', 'l', 'l', 0,
    'C', 'u', 'r', 'r', 'e', 'n', 't', 'S', 'y', 's', 't', 'e', 'm', 'E', 'n', 'd', 'i', 'a', 'n', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'S', 'w', 'a', 'p', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'D', 'e', 'p', 'r', 'e', 'c', 'a', 't', 'e', 'd', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', 0,
    'D', 'i', 'r', 't', 'y', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'M', 'o', 'd', 'e', 0,
    'D', 'i', 's', 'a', 'b', 'l', 'e', 'E', 'm', 'o', 'j', 'i', 'P', 'a', 'r', 's', 'i', 'n', 'g', 0,
    'D', 'o', 'n', 't', 'R', 'e', 's', 'o', 'l', 'v', 'e', 'S', 'y', 'm', 'l', 'i', 'n', 'k', 's', 0,
    'D', 'o', 'n', 't', 'W', 'a', 't', 'c', 'h', 'F', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 's', 0,
    'F', 'i', 'n', 'd', 'C', 'a', 's', 'e', 'S', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', 'l', 'y', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'J', 'u', 's', 't', 'i', 'f', 'y', 'C', 'e', 'n', 't', 'e', 'r', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'T', 'e', 'x', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'I', 'm', 'a', 'g', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'I', 'n', 's', 'e', 'r', 't', 'L', 'i', 'n', 'e', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 0,
    'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'l', 'i', 's', 't', 'R', 'e', 'p', 'e', 'a', 't', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'E', 'n', 'd', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'N', 'o', 'S', 'u', 'b', 'p', 'i', 'x', 'e', 'l', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 0,
    'P', 'd', 'm', 'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    'Q', 'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'H', 'i', 'n', 't', 's', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'K', 'e', 'y', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', '>', 0,
    'Q', 'N', 'a', 't', 'i', 'v', 'e', 'G', 'e', 's', 't', 'u', 'r', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', 'G', 'r', 'o', 'u', 'p', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 'P', 'a', 't', 'h', 'S', 't', 'r', 'o', 'k', 'e', 'r', 0,
    'Q', 'P', 'a', 'l', 'e', 't', 't', 'e', ':', ':', 'C', 'o', 'l', 'o', 'r', 'R', 'o', 'l', 'e', 0,
    'Q', 'R', 'e', 'g', 'i', 'o', 'n', ':', ':', 'R', 'e', 'g', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'c', 'r', 'o', 'l', 'l', 'P', 'r', 'e', 'p', 'a', 'r', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'W', 'r', 'i', 't', 'e', 'r', 0,
    'Q', 'W', 'i', 'n', 'd', 'o', 'w', ':', ':', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'E', 'n', 'd', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'S', 'p', 'e', 'l', 'l', 'C', 'h', 'e', 'c', 'k', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'S', 't', 'r', 'e', 't', 'c', 'h', 'T', 'o', 'D', 'e', 'v', 'i', 'c', 'e', 'M', 'o', 'd', 'e', 0,
    'T', 'a', 'b', 'l', 'e', 'B', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'l', 'a', 'p', 's', 'e', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'T', 'o', 'p', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'T', 'a', 'b', 'l', 'e', 'H', 'e', 'a', 'd', 'e', 'r', 'R', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    'a', 'p', 'p', 'l', 'y', 'C', 'o', 'l', 'o', 'r', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'b', 'e', 'g', 'i', 'n', 'N', 'a', 't', 'i', 'v', 'e', 'P', 'a', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'b', 'r', 'u', 's', 'h', 'N', 'e', 'e', 'd', 's', 'R', 'e', 's', 'o', 'l', 'v', 'i', 'n', 'g', 0,
    'c', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'e', 'a', 'r', 'U', 'n', 'd', 'o', 'R', 'e', 'd', 'o', 'S', 't', 'a', 'c', 'k', 's', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'T', 'o', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'H', 'e', 'u', 'r', 'i', 's', 't', 'i', 'c', 'M', 'a', 's', 'k', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'M', 'a', 's', 'k', 'F', 'r', 'o', 'm', 'C', 'o', 'l', 'o', 'r', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 'G', 'r', 'o', 'u', 'p', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'X', 'm', 'p', 'M', 'e', 't', 'a', 'd', 'a', 't', 'a', 0,
    'd', 'r', 'a', 'w', 'P', 'i', 'x', 'm', 'a', 'p', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 's', 0,
    'f', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'S', 'e', 'a', 'r', 'c', 'h', 'P', 'a', 't', 'h', 's', 0,
    'f', 'i', 'r', 's', 't', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'f', 'o', 'n', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'P', 'r', 'e', 's', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'h', 'a', 's', 'C', 'o', 'm', 'p', 'l', 'e', 'x', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'i', 'n', 's', 'e', 'r', 't', 'S', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 's', 0,
    'i', 's', 'I', 'c', 'o', 'n', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'I', 'n', 'M', 'e', 'n', 'u', 0,
    'l', 'i', 'n', 'e', 'F', 'o', 'r', 'T', 'e', 'x', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'X', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'Y', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'e', 'e', 'd', 'i', 't', 'A', 'r', 'e', 'a', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'r', 'e', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'A', 's', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'S', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 's', 0,
    'r', 'i', 'g', 'h', 't', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'V', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'A', 'x', 'e', 's', 0,
    's', 'e', 't', 'M', 'o', 'u', 's', 'e', 'G', 'r', 'a', 'b', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'o', 'w', 'S', 'p', 'a', 'n', 0,
    's', 'e', 't', 'T', 'h', 'e', 'm', 'e', 'S', 'e', 'a', 'r', 'c', 'h', 'P', 'a', 't', 'h', 's', 0,
    's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'U', 's', 'e', 'D', 'e', 's', 'i', 'g', 'n', 'M', 'e', 't', 'r', 'i', 'c', 's', 0,
    's', 'e', 't', 'V', 'i', 's', 'u', 'a', 'l', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 0,
    's', 'u', 'p', 'e', 'r', 'S', 'c', 'r', 'i', 'p', 't', 'B', 'a', 's', 'e', 'l', 'i', 'n', 'e', 0,
    't', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'C', 'o', 'l', 'u', 'm', 'n', 'S', 'p', 'a', 'n', 0,
    'w', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'S', 'a', 'm', 'p', 'l', 'e', 0,
    'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'I', 'm', 'a', 'g', 'e', 'U', 'r', 'l', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'D', 'a', 's', 'h', 'e', 'd', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'D', 'o', 't', 't', 'e', 'd', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'D', 'o', 'u', 'b', 'l', 'e', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'G', 'r', 'o', 'o', 'v', 'e', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'O', 'u', 't', 's', 'e', 't', 0,
    'C', 'o', 'n', 't', 'e', 'x', 't', 'F', 'o', 'n', 't', 'M', 'e', 'r', 'g', 'i', 'n', 'g', 0,
    'C', 'u', 'r', 'v', 'e', 'T', 'o', 'D', 'a', 't', 'a', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'L', 'i', 'n', 'e', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'O', 'p', 'e', 'n', 'R', 'e', 'c', 'e', 'n', 't', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 0,
    'F', 'a', 'n', 'F', 'o', 'l', 'd', 'G', 'e', 'r', 'm', 'a', 'n', 'L', 'e', 'g', 'a', 'l', 0,
    'F', 'o', 'n', 't', 'S', 'i', 'z', 'e', 'A', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'J', 'u', 's', 't', 'i', 'f', 'y', 'R', 'i', 'g', 'h', 't', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'G', 'r', 'a', 'y', 's', 'c', 'a', 'l', 'e', '1', '6', 0,
    'F', 'u', 'l', 'l', 'W', 'i', 'd', 't', 'h', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'I', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'a', 'l', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'L', 'i', 'n', 'e', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'L', 'i', 'n', 'e', 'a', 'r', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 'F', 'i', 'l', 'l', 0,
    'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'P', 'a', 'u', 's', 'e', 0,
    'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'S', 't', 'a', 'r', 't', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'a', 'r', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'L', 'i', 'n', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'P', 'a', 'g', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'W', 'o', 'r', 'd', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'S', 't', 'a', 'r', 't', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'N', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'O', 'b', 'j', 'e', 'c', 't', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'P', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'a', 'l', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', ':', ':', 'N', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'E', 'v', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', ':', ':', 'I', 'n', 'v', 'e', 'r', 't', 'M', 'o', 'd', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'E', 'v', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', '*', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'e', 'x', 't', 'L', 'e', 'n', 'g', 't', 'h', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'U', 'n', 'd', 'o', 'S', 't', 'a', 'c', 'k', '*', '>', 0,
    'Q', 'M', 'o', 'v', 'i', 'e', ':', ':', 'M', 'o', 'v', 'i', 'e', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'P', 'a', 'g', 'e', 'R', 'a', 'n', 'g', 'e', 's', ':', ':', 'R', 'a', 'n', 'g', 'e', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'T', 'y', 'p', 'e', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 'S', 't', 'a', 't', 'e', 'G', 'u', 'a', 'r', 'd', 0,
    'Q', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'I', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', 0,
    'Q', 'S', 'y', 'n', 't', 'a', 'x', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'e', 'r', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 'U', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'R', 'a', 'd', 'i', 'a', 'l', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 'F', 'i', 'l', 'l', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'R', 'e', 's', 't', 'a', 'r', 't', 'I', 'm', 'm', 'e', 'd', 'i', 'a', 't', 'e', 'l', 'y', 0,
    'S', 'c', 'i', 'e', 'n', 't', 'i', 'f', 'i', 'c', 'N', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'a', 'r', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'L', 'i', 'n', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'P', 'a', 'g', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'W', 'o', 'r', 'd', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'S', 't', 'a', 'r', 't', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'S', 't', 'y', 'l', 'e', 'S', 'h', 'e', 'e', 't', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'T', 'a', 'n', 'g', 'e', 'n', 't', 'i', 'a', 'l', 'P', 'r', 'e', 's', 's', 'u', 'r', 'e', 0,
    'T', 'e', 'x', 't', 'B', 'a', 's', 'e', 'l', 'i', 'n', 'e', 'O', 'f', 'f', 's', 'e', 't', 0,
    'T', 'e', 'x', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'T', 'o', 'o', 'l', 's', 'C', 'h', 'e', 'c', 'k', 'S', 'p', 'e', 'l', 'l', 'i', 'n', 'g', 0,
    'T', 'r', 'a', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'C', 'h', 'i', 'n', 'e', 's', 'e', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'F', 'l', 'i', 'p', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'N', 'o', 'n', 'e', 0,
    'a', 'b', 'o', 'u', 't', 'T', 'o', 'B', 'e', 'D', 'e', 's', 't', 'r', 'o', 'y', 'e', 'd', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'S', 't', 'a', 'c', 'k', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'd', 'd', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'n', 't', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'R', 'e', 'd', 'o', 'S', 't', 'e', 'p', 's', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'U', 'n', 'd', 'o', 'S', 't', 'e', 'p', 's', 0,
    'b', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'o', 'r', 'S', 'c', 'h', 'e', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'T', 'r', 'i', 'g', 'g', 'e', 'r', 0,
    'c', 'o', 'n', 't', 'r', 'a', 's', 't', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'F', 'r', 'a', 'm', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'm', 'a', 'g', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'a', 'r', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'b', 'j', 'e', 'c', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'o', 'c', 'u', 's', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'o', 'n', 't', 'C', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'f', 'o', 'n', 't', 'S', 'm', 'o', 'o', 't', 'h', 'i', 'n', 'g', 'G', 'a', 'm', 'm', 'a', 0,
    'f', 'r', 'o', 'm', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'G', 'r', 'a', 'b', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'L', 'a', 's', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'S', 'h', 'a', 'r', 'e', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'i', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'i', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'i', 'n', 's', 'e', 'r', 't', 'S', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 0,
    'i', 's', 'S', 'm', 'o', 'o', 't', 'h', 'l', 'y', 'S', 'c', 'a', 'l', 'a', 'b', 'l', 'e', 0,
    'l', 'a', 's', 't', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'l', 'e', 'f', 't', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 0,
    'm', 'e', 'n', 'u', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'W', 'r', 'a', 'p', 's', 0,
    'n', 'a', 'm', 'e', 'F', 'i', 'l', 't', 'e', 'r', 'D', 'i', 's', 'a', 'b', 'l', 'e', 's', 0,
    'n', 'e', 'x', 't', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'B', 'l', 'o', 'c', 'k', 'S', 't', 'a', 't', 'e', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'r', 'e', 'f', 'r', 'e', 's', 'h', 'R', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'S', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'T', 'e', 'x', 't', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'I', 'n', 'l', 'i', 'n', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'c', 'e', 'n', 'e', 'P', 'r', 'e', 's', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 's', 0,
    's', 'e', 't', 'A', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'L', 'i', 'm', 'i', 't', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'B', 'l', 'o', 'c', 'k', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 'P', 'o', 's', 'R', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'C', 'u', 'r', 's', 'o', 'r', 'M', 'o', 'v', 'e', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'D', 'e', 'p', 't', 'h', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'D', 'e', 's', 'k', 't', 'o', 'p', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'E', 'x', 'c', 'l', 'u', 's', 'i', 'o', 'n', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'W', 'o', 'r', 'd', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    's', 'e', 't', 'G', 'r', 'e', 'e', 'n', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'L', 'a', 'y', 'o', 'u', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'e', 'a', 'd', 'i', 'n', 'g', 'I', 'n', 'c', 'l', 'u', 'd', 'e', 'd', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'M', 'e', 't', 'a', 'I', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', 'C', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'R', 'e', 's', 'o', 'l', 'v', 'e', 'S', 'y', 'm', 'l', 'i', 'n', 'k', 's', 0,
    's', 'e', 't', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    's', 'e', 't', 'T', 'a', 'b', 'S', 't', 'o', 'p', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'i', 'e', 'n', 't', 'P', 'a', 'r', 'e', 'n', 't', 0,
    's', 'e', 't', 'U', 'n', 'd', 'o', 'R', 'e', 'd', 'o', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'U', 's', 'e', 'H', 'o', 'v', 'e', 'r', 'E', 'f', 'f', 'e', 'c', 't', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'M', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'F', 'i', 'n', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    't', 'a', 'n', 'g', 'e', 'n', 't', 'i', 'a', 'l', 'P', 'r', 'e', 's', 's', 'u', 'r', 'e', 0,
    't', 'y', 'p', 'e', 'I', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 't', 'i', 'o', 'n', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'T', 'i', 't', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'o', 'r', 'l', 'd', 'M', 'a', 't', 'r', 'i', 'x', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'A', 'g', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 'C', 'a', 'c', 'h', 'i', 'n', 'g', 0,
    'A', 'p', 'p', 'o', 'i', 'n', 't', 'm', 'e', 'n', 't', 'M', 'i', 's', 's', 'e', 'd', 0,
    'A', 'u', 'd', 'i', 'o', 'V', 'o', 'l', 'u', 'm', 'e', 'M', 'e', 'd', 'i', 'u', 'm', 0,
    'B', 'l', 'o', 'c', 'k', 'B', 'o', 't', 't', 'o', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'B', 'l', 'o', 'c', 'k', 'C', 'o', 'd', 'e', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'I', 'n', 's', 'e', 't', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'R', 'i', 'd', 'g', 'e', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'S', 'o', 'l', 'i', 'd', 0,
    'C', 'u', 'r', 's', 'o', 'r', 'O', 'n', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'S', 't', 'a', 'r', 't', 'O', 'f', 'W', 'o', 'r', 'd', 0,
    'D', 'i', 'a', 'l', 'o', 'g', 'I', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'P', 'a', 'g', 'e', 'S', 'e', 't', 'u', 'p', 0,
    'E', 'x', 'c', 'l', 'u', 'd', 'e', 'T', 'r', 'a', 'n', 's', 'i', 'e', 'n', 't', 's', 0,
    'E', 'x', 'c', 'l', 'u', 's', 'i', 'v', 'e', 'O', 'p', 't', 'i', 'o', 'n', 'a', 'l', 0,
    'E', 'x', 'e', 'c', 'u', 't', 'i', 'v', 'e', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 0,
    'F', 'i', 'l', 'e', 'N', 'o', 't', 'F', 'o', 'u', 'n', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'F', 'i', 'r', 's', 't', 'F', 'o', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'F', 'o', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 'A', 'l', 'l', 0,
    'F', 'o', 'n', 't', 'S', 'i', 'z', 'e', 'I', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'J', 'u', 's', 't', 'i', 'f', 'y', 'F', 'i', 'l', 'l', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'J', 'u', 's', 't', 'i', 'f', 'y', 'L', 'e', 'f', 't', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'G', 'r', 'a', 'y', 's', 'c', 'a', 'l', 'e', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '1', '6', 'F', 'P', 'x', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '3', '2', 'F', 'P', 'x', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'X', '1', '6', 'F', 'P', 'x', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'X', '3', '2', 'F', 'P', 'x', '4', 0,
    'F', 'r', 'a', 'm', 'e', 'B', 'o', 't', 't', 'o', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'I', 'n', 'c', 'l', 'u', 'd', 'e', 'T', 'r', 'a', 'n', 's', 'i', 'e', 'n', 't', 's', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'I', 'm', 'a', 'g', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'M', 'a', 'i', 'l', 'M', 'a', 'r', 'k', 'I', 'm', 'p', 'o', 'r', 't', 'a', 'n', 't', 0,
    'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'S', 't', 'o', 'p', 0,
    'M', 'e', 'd', 'i', 'a', 'S', 'e', 'e', 'k', 'B', 'a', 'c', 'k', 'w', 'a', 'r', 'd', 0,
    'M', 'e', 'd', 'i', 'a', 'S', 'k', 'i', 'p', 'B', 'a', 'c', 'k', 'w', 'a', 'r', 'd', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'S', 't', 'a', 'r', 't', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'O', 'b', 'j', 'e', 'c', 't', 'R', 'o', 't', 'a', 't', 'e', 'R', 'i', 'g', 'h', 't', 0,
    'P', 'e', 'r', 'c', 'e', 'n', 't', 'a', 'g', 'e', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'F', 'u', 'l', 'l', 'H', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 0,
    'Q', 'A', 'c', 't', 'i', 'o', 'n', ':', ':', 'M', 'e', 'n', 'u', 'R', 'o', 'l', 'e', 0,
    'Q', 'A', 'c', 't', 'i', 'o', 'n', ':', ':', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    'Q', 'C', 'h', 'i', 'l', 'd', 'W', 'i', 'n', 'd', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'F', 'o', 'n', 't', 'V', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'A', 'x', 'i', 's', 0,
    'Q', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', ':', ':', 'P', 'r', 'e', 's', 'e', 't', 0,
    'Q', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', ':', ':', 'S', 'p', 'r', 'e', 'a', 'd', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'F', 'o', 'n', 't', ':', ':', 'T', 'a', 'g', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', '>', 0,
    'Q', 'M', 'o', 'v', 'i', 'e', ':', ':', 'C', 'a', 'c', 'h', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 'O', 'f', 'f', 's', 'c', 'r', 'e', 'e', 'n', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'M', 'o', 'd', 'e', 0,
    'Q', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'U', 'n', 'i', 't', 0,
    'Q', 'P', 'a', 'g', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'P', 'i', 'x', 'm', 'a', 'p', 'C', 'a', 'c', 'h', 'e', ':', ':', 'K', 'e', 'y', 0,
    'Q', 'Q', 'u', 'a', 't', 'e', 'r', 'n', 'i', 'o', 'n', ':', ':', 'A', 'x', 'e', 's', 0,
    'Q', 'Q', 'u', 'a', 't', 'e', 'r', 'n', 'i', 'o', 'n', ':', ':', 'A', 'x', 'i', 's', 0,
    'Q', 'S', 'i', 'n', 'g', 'l', 'e', 'P', 'o', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'I', 'n', 'l', 'i', 'n', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'e', 'n', 'g', 't', 'h', ':', ':', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'F', 'l', 'a', 'g', 0,
    'Q', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'R', 'e', 's', 'e', 't', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'S', 't', 'a', 'r', 't', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'S', 'h', 'o', 'w', 'T', 'a', 'b', 's', 'A', 'n', 'd', 'S', 'p', 'a', 'c', 'e', 's', 0,
    'S', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'd', 'C', 'h', 'i', 'n', 'e', 's', 'e', 0,
    'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'u', 'b', 'T', 'y', 'p', 'e', 's', 0,
    'S', 'y', 'n', 'c', 'S', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 'z', 'i', 'n', 'g', 0,
    'T', 'e', 'x', 't', 'H', 'e', 'u', 'r', 'i', 's', 't', 'i', 'c', 'R', 'o', 'l', 'e', 0,
    'U', 'n', 'd', 'o', 'A', 'n', 'd', 'R', 'e', 'd', 'o', 'S', 't', 'a', 'c', 'k', 's', 0,
    'W', 'e', 'a', 't', 'h', 'e', 'r', 'C', 'l', 'e', 'a', 'r', 'N', 'i', 'g', 'h', 't', 0,
    'a', 'd', 'd', 'F', 'i', 'l', 'e', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 0,
    'a', 'l', 'l', 'P', 'o', 'i', 'n', 't', 's', 'A', 'c', 'c', 'e', 'p', 't', 'e', 'd', 0,
    'a', 'l', 'l', 'o', 'w', 's', 'I', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'o', 'n', 0,
    'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'e', 'd', 'O', 'b', 'j', 'e', 'c', 't', 's', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'b', 'l', 'o', 'c', 'k', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'b', 'l', 'o', 'c', 'k', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'l', 'o', 'c', 'k', 'W', 'i', 't', 'h', 'M', 'a', 'r', 'k', 'e', 'r', 'A', 't', 0,
    'b', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'b', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'c', 'l', 'e', 'a', 'r', 'V', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'A', 'x', 'e', 's', 0,
    'c', 'o', 'm', 'b', 'i', 'n', 'e', 'd', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'c', 'o', 'm', 'm', 'i', 't', 'D', 'a', 't', 'a', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'B', 'l', 'o', 'c', 'k', 'S', 't', 'a', 't', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'C', 'o', 'l', 'o', 'r', 'G', 'r', 'o', 'u', 'p', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'S', 't', 'y', 'l', 'e', 'S', 'h', 'e', 'e', 't', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 'F', 0,
    'd', 'r', 'a', 'w', 'C', 'o', 'n', 'v', 'e', 'x', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    'e', 'n', 'd', 'N', 'a', 't', 'i', 'v', 'e', 'P', 'a', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'f', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'T', 'h', 'e', 'm', 'e', 'N', 'a', 'm', 'e', 0,
    'f', 'i', 'n', 'd', 'B', 'l', 'o', 'c', 'k', 'B', 'y', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'f', 'i', 'n', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'o', 'n', 't', 'L', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'f', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    'f', 'r', 'a', 'm', 'e', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'h', 'a', 's', 'S', 't', 'a', 't', 'i', 'c', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'h', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'A', 'd', 'v', 'a', 'n', 'c', 'e', 0,
    'i', 'n', 'v', 'i', 's', 'i', 'b', 'l', 'e', 'R', 'o', 'o', 't', 'I', 't', 'e', 'm', 0,
    'i', 's', 'S', 'e', 's', 's', 'i', 'o', 'n', 'R', 'e', 's', 't', 'o', 'r', 'e', 'd', 0,
    'i', 's', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'U', 'n', 'd', 'o', 'R', 'e', 'd', 'o', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'V', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'A', 'x', 'i', 's', 'S', 'e', 't', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'l', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    'm', 'a', 'r', 'k', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'D', 'i', 'r', 't', 'y', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'B', 'l', 'o', 'c', 'k', 'C', 'o', 'u', 'n', 't', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 's', 'p', 'r', 'i', 'n', 'g', 'g', 'r', 'e', 'e', 'n', 0,
    'm', 'o', 'u', 's', 'e', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'n', 'o', 'n', 'B', 'r', 'e', 'a', 'k', 'a', 'b', 'l', 'e', 'L', 'i', 'n', 'e', 's', 0,
    'o', 'u', 't', 'O', 'f', 'B', 'o', 'u', 'n', 'd', 's', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'o', 'v', 'e', 'r', 's', 'h', 'o', 'o', 't', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'p', 'a', 's', 's', 'w', 'o', 'r', 'd', 'M', 'a', 's', 'k', 'D', 'e', 'l', 'a', 'y', 0,
    'p', 'e', 'n', 'N', 'e', 'e', 'd', 's', 'R', 'e', 's', 'o', 'l', 'v', 'i', 'n', 'g', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'A', 'l', 'p', 'h', 'a', 0,
    'r', 'e', 'g', 'u', 'l', 'a', 'r', 'E', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'r', 'e', 's', 'e', 't', 'I', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'D', 'a', 't', 'a', 0,
    's', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'b', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'c', 'e', 'n', 'e', 'L', 'a', 's', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'l', 'i', 'n', 'e', 'O', 'f', 'f', 's', 'e', 't', 0,
    's', 'e', 't', 'B', 'l', 'u', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'l', 'a', 'p', 's', 'e', 0,
    's', 'e', 't', 'C', 'a', 'c', 'h', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'C', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'C', 'u', 'r', 'v', 'e', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 0,
    's', 'e', 't', 'D', 'i', 's', 'c', 'a', 'r', 'd', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    's', 'e', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', 0,
    's', 'e', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'F', 'i', 'x', 'e', 'd', 'P', 'i', 't', 'c', 'h', 0,
    's', 'e', 't', 'H', 'e', 'a', 'd', 'e', 'r', 'R', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    's', 'e', 't', 'O', 'p', 't', 'i', 'm', 'i', 'z', 'e', 'd', 'W', 'r', 'i', 't', 'e', 0,
    's', 'e', 't', 'O', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 'C', 'u', 'r', 's', 'o', 'r', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'a', 'b', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'R', 'e', 's', 't', 'a', 'r', 't', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'e', 'd', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    's', 'e', 't', 'S', 't', 'a', 't', 'i', 'c', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    's', 'e', 't', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'W', 'o', 'r', 'l', 'd', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    's', 't', 'a', 'r', 't', 'D', 'r', 'a', 'g', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    's', 't', 'a', 'r', 't', 'D', 'r', 'a', 'g', 'V', 'e', 'l', 'o', 'c', 'i', 't', 'y', 0,
    's', 't', 'a', 'r', 't', 'S', 'y', 's', 't', 'e', 'm', 'R', 'e', 's', 'i', 'z', 'e', 0,
    's', 't', 'e', 'n', 'c', 'i', 'l', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'u', 'b', 'S', 'c', 'r', 'i', 'p', 't', 'B', 'a', 's', 'e', 'l', 'i', 'n', 'e', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'u', 'b', 'T', 'y', 'p', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    't', 'i', 'g', 'h', 't', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    't', 'o', 'S', 'u', 'b', 'p', 'a', 't', 'h', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 's', 0,
    't', 'o', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'u', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'u', 'n', 's', 'e', 't', 'V', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'A', 'x', 'i', 's', 0,
    'v', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'A', 'x', 'i', 's', 'V', 'a', 'l', 'u', 'e', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'M', 'o', 'v', 'e', 'm', 'e', 'n', 't', 'X', 0,
    'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'N', 'a', 'm', 'e', 0,
    'A', 'l', 'i', 'g', 'n', 'S', 'u', 'p', 'e', 'r', 'S', 'c', 'r', 'i', 'p', 't', 0,
    'A', 'u', 'd', 'i', 'o', 'V', 'o', 'l', 'u', 'm', 'e', 'M', 'u', 't', 'e', 'd', 0,
    'B', 'l', 'o', 'c', 'k', 'R', 'i', 'g', 'h', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'B', 'l', 'o', 'c', 'k', 'U', 'n', 'd', 'e', 'r', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'N', 'o', 'n', 'e', 0,
    'C', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'R', 'a', 't', 'i', 'o', 0,
    'D', 'i', 'r', 't', 'y', 'B', 'r', 'u', 's', 'h', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    'D', 'i', 'r', 't', 'y', 'C', 'l', 'i', 'p', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'e', 'r', 's', 'o', 'n', 'a', 'l', 0,
    'E', 't', 'e', 'r', 'n', 'a', 'l', 'C', 'o', 'n', 's', 't', 'a', 'n', 'c', 'e', 0,
    'F', 'o', 'l', 'd', 'e', 'r', 'D', 'r', 'a', 'g', 'A', 'c', 'c', 'e', 'p', 't', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'I', 'n', 'd', 'e', 'n', 't', 'L', 'e', 's', 's', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'I', 'n', 'd', 'e', 'n', 't', 'M', 'o', 'r', 'e', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'T', 'e', 'x', 't', 'I', 't', 'a', 'l', 'i', 'c', 0,
    'F', 'r', 'a', 'm', 'e', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'F', 'r', 'a', 'm', 'e', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'F', 'r', 'a', 'm', 'e', 'R', 'i', 'g', 'h', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'D', 'a', 't', 'a', 'E', 'r', 'r', 'o', 'r', 0,
    'L', 'a', 's', 't', 'F', 'o', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'L', 'i', 's', 't', 'N', 'u', 'm', 'b', 'e', 'r', 'P', 'r', 'e', 'f', 'i', 'x', 0,
    'L', 'i', 's', 't', 'N', 'u', 'm', 'b', 'e', 'r', 'S', 'u', 'f', 'f', 'i', 'x', 0,
    'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'M', 'e', 'd', 'i', 'a', 'S', 'e', 'e', 'k', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'M', 'e', 'd', 'i', 'a', 'S', 'k', 'i', 'p', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'E', 'n', 'd', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'M', 'u', 'l', 't', 'i', 'm', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'e', 'r', 0,
    'N', 'o', 't', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'O', 'b', 'j', 'e', 'c', 't', 'R', 'o', 't', 'a', 't', 'e', 'L', 'e', 'f', 't', 0,
    'P', 'a', 't', 't', 'e', 'r', 'n', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'P', 'e', 'r', 'c', 'e', 'n', 't', 'a', 'g', 'e', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'P', 'r', 'o', 't', 'e', 'c', 't', 'e', 'd', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'Q', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', ':', ':', 'M', 'o', 'd', 'e', 0,
    'Q', 'C', 'o', 'n', 'i', 'c', 'a', 'l', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'Q', 'D', 'e', 's', 'k', 't', 'o', 'p', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 's', 0,
    'Q', 'D', 'o', 'u', 'b', 'l', 'e', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', 0,
    'Q', 'F', 'i', 'l', 'e', 'S', 'y', 's', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'S', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 0,
    'Q', 'I', 'c', 'o', 'n', ':', ':', 'T', 'h', 'e', 'm', 'e', 'I', 'c', 'o', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 'F', '>', 0,
    'Q', 'N', 'a', 't', 'i', 'v', 'e', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'P', 'd', 'f', 'O', 'u', 't', 'p', 'u', 't', 'I', 'n', 't', 'e', 'n', 't', 0,
    'Q', 'S', 'e', 't', '<', 'Q', 'B', 'y', 't', 'e', 'A', 'r', 'r', 'a', 'y', '>', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'T', 'a', 'b', 0,
    'Q', 'T', 'e', 'x', 't', 'T', 'a', 'b', 'l', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'R', 'e', 's', 't', 'a', 'r', 't', 'I', 'f', 'R', 'u', 'n', 'n', 'i', 'n', 'g', 0,
    'S', 'c', 'a', 'l', 'e', 'd', 'P', 'i', 'x', 'm', 'a', 'p', 'H', 'o', 'o', 'k', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'E', 'n', 'd', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'S', 'e', 'p', 'a', 'r', 'a', 't', 'e', 'A', 'd', 'v', 'a', 'n', 'c', 'e', 's', 0,
    'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'N', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'y', 's', 't', 'e', 'm', 'L', 'o', 'c', 'k', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'T', 'e', 'x', 't', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 0,
    'W', 'e', 'a', 't', 'h', 'e', 'r', 'F', 'e', 'w', 'C', 'l', 'o', 'u', 'd', 's', 0,
    'a', 'l', 'p', 'h', 'a', 'M', 'a', 'p', 'F', 'o', 'r', 'G', 'l', 'y', 'p', 'h', 0,
    'a', 'n', 'i', 'm', 'a', 't', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 't', 'e', 0,
    'a', 'v', 'e', 'r', 'a', 'g', 'e', 'C', 'h', 'a', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'b', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 'C', 'h', 'a', 'r', 0,
    'c', 'h', 'e', 'c', 'k', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'i', 'p', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'c', 'o', 'l', 'o', 'r', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'r', 'o', 'l', 'P', 'o', 'i', 'n', 't', 'R', 'e', 'c', 't', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'F', 'r', 'o', 'm', 'I', 'm', 'a', 'g', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'R', 'e', 'd', 'o', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'U', 'n', 'd', 'o', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'c', 't', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'd', 'r', 'a', 'w', 'I', 'n', 'l', 'i', 'n', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'e', 'l', 'l', 'i', 'p', 's', 'e', 'D', 'i', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    'f', 'o', 'n', 't', 'V', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'A', 'x', 'e', 's', 0,
    'f', 'r', 'o', 'm', 'A', 'x', 'i', 's', 'A', 'n', 'd', 'A', 'n', 'g', 'l', 'e', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 'r', 'F', 'o', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'i', 's', 'B', 'i', 't', 'm', 'a', 'p', 'S', 'c', 'a', 'l', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'C', 'a', 'c', 'h', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 'C', 'o', 'l', 'o', 'r', 'N', 'a', 'm', 'e', 0,
    'l', 'a', 's', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'l', 'o', 's', 'e', 'd', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 'a', 'q', 'u', 'a', 'm', 'a', 'r', 'i', 'n', 'e', 0,
    'm', 'e', 'r', 'g', 'e', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'V', 'i', 'r', 't', 'u', 'a', 'l', 'K', 'e', 'y', 0,
    'n', 'a', 't', 'u', 'r', 'a', 'l', 'T', 'e', 'x', 't', 'W', 'i', 'd', 't', 'h', 0,
    'o', 'p', 'e', 'n', 'G', 'L', 'M', 'o', 'd', 'u', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'p', 'a', 'g', 'e', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'm', 'y', 'k', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'R', 'g', 'b', 'a', 0,
    'q', 'u', 'e', 'r', 'y', 'F', 'o', 'c', 'u', 's', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'r', 'e', 'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', 'S', 't', 'a', 'r', 't', 0,
    'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    'r', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'r', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'a', 'v', 'e', 'S', 't', 'a', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'D', 'o', 't', 's', 'P', 'e', 'r', 'M', 'e', 't', 'e', 'r', 'X', 0,
    's', 'e', 't', 'D', 'o', 't', 's', 'P', 'e', 'r', 'M', 'e', 't', 'e', 'r', 'Y', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'P', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'S', 't', 'r', 'i', 'k', 'e', 'O', 'u', 't', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'F', 'r', 'a', 'm', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'P', 'r', 'o', 't', 'o', 't', 'y', 'p', 'e', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'R', 'o', 'l', 'e', 'N', 'a', 'm', 'e', 's', 0,
    's', 'e', 't', 'L', 'a', 'y', 'o', 'u', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'L', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    's', 'e', 't', 'P', 'r', 'i', 'm', 'a', 'r', 'y', 'P', 'o', 'i', 'n', 't', 's', 0,
    's', 'e', 't', 'R', 'e', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'S', 'i', 'z', 'e', 'I', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'S', 't', 'r', 'i', 'n', 'g', 'I', 'n', 'd', 'e', 'x', 'e', 's', 0,
    's', 'e', 't', 'S', 't', 'y', 'l', 'e', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'h', 'o', 'w', 'I', 's', 'F', 'u', 'l', 'l', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'E', 'v', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    't', 'a', 'b', 'F', 'o', 'c', 'u', 's', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    't', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'o', 'w', 'S', 'p', 'a', 'n', 0,
    't', 'h', 'e', 'm', 'e', 'S', 'e', 'a', 'r', 'c', 'h', 'P', 'a', 't', 'h', 's', 0,
    't', 'o', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'M', 'a', 't', 'r', 'i', 'x', 0,
    't', 'o', 'V', 'e', 'c', 't', 'o', 'r', '2', 'D', 'A', 'f', 'f', 'i', 'n', 'e', 0,
    't', 'o', 'V', 'e', 'c', 't', 'o', 'r', '3', 'D', 'A', 'f', 'f', 'i', 'n', 'e', 0,
    't', 'o', 'u', 'c', 'h', 'P', 'o', 'i', 'n', 't', 'S', 't', 'a', 't', 'e', 's', 0,
    't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'B', 'e', 't', 'w', 'e', 'e', 'n', 0,
    'u', 'n', 'd', 'o', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 'A', 'd', 'd', 'e', 'd', 0,
    'u', 'n', 's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'S', 'c', 'h', 'e', 'm', 'e', 0,
    'u', 's', 'e', 'D', 'e', 's', 'i', 'g', 'n', 'M', 'e', 't', 'r', 'i', 'c', 's', 0,
    'u', 's', 'e', 'R', 't', 'l', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    'v', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'A', 'x', 'i', 's', 'T', 'a', 'g', 's', 0,
    'v', 'i', 'r', 't', 'u', 'a', 'l', 'S', 'i', 'b', 'l', 'i', 'n', 'g', 'A', 't', 0,
    'v', 'i', 's', 'u', 'a', 'l', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 0,
    'w', 'h', 'e', 'e', 'l', 'S', 'c', 'r', 'o', 'l', 'l', 'L', 'i', 'n', 'e', 's', 0,
    'A', 'b', 's', 'o', 'l', 'u', 't', 'e', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'A', 'l', 'l', 'P', 'o', 'i', 'n', 't', 'e', 'r', 'T', 'y', 'p', 'e', 's', 0,
    'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'E', 'x', 'i', 't', 0,
    'A', 'p', 'p', 'o', 'i', 'n', 't', 'm', 'e', 'n', 't', 'S', 'o', 'o', 'n', 0,
    'A', 'u', 'd', 'i', 'o', 'V', 'o', 'l', 'u', 'm', 'e', 'H', 'i', 'g', 'h', 0,
    'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'B', 'r', 'u', 's', 'h', 0,
    'B', 'l', 'o', 'c', 'k', 'L', 'e', 'f', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'B', 'l', 'o', 'c', 'k', 'Q', 'u', 'o', 't', 'e', 'L', 'e', 'v', 'e', 'l', 0,
    'C', 'h', 'e', 'e', 'r', 'f', 'u', 'l', 'C', 'a', 'r', 'a', 'm', 'e', 'l', 0,
    'C', 'l', 'o', 'u', 'd', 'y', 'K', 'n', 'o', 'x', 'v', 'i', 'l', 'l', 'e', 0,
    'C', 'o', 'n', 's', 't', 'a', 'n', 't', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'E', 'n', 'd', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'E', 'n', 'd', 'O', 'f', 'W', 'o', 'r', 'd', 0,
    'D', 'i', 'r', 'e', 'c', 't', '3', 'D', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'D', 'i', 'r', 't', 'y', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'D', 'i', 'r', 't', 'y', 'C', 'l', 'i', 'p', 'R', 'e', 'g', 'i', 'o', 'n', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'I', 't', 'a', 'l', 'i', 'a', 'n', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'M', 'o', 'n', 'a', 'r', 'c', 'h', 0,
    'F', 'i', 'l', 'e', 'P', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', 0,
    'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 'B', 'r', 'u', 's', 'h', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'C', 'M', 'Y', 'K', '8', '8', '8', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'I', 'n', 'd', 'e', 'x', 'e', 'd', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '8', '8', '8', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'X', '8', '8', '8', '8', 0,
    'F', 'r', 'a', 'm', 'e', 'L', 'e', 'f', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'e', 'd', 'T', 'e', 'x', 't', 0,
    'L', 'a', 'n', 'd', 'i', 'n', 'g', 'A', 'i', 'r', 'c', 'r', 'a', 'f', 't', 0,
    'L', 'i', 'n', 'e', 'U', 'n', 'd', 'e', 'r', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'M', 'a', 'i', 'l', 'R', 'e', 'p', 'l', 'y', 'S', 'e', 'n', 'd', 'e', 'r', 0,
    'M', 'o', 'd', 'e', 'r', 'a', 't', 'e', 'C', 'a', 'c', 'h', 'i', 'n', 'g', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'E', 'n', 'd', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'N', 'e', 't', 'w', 'o', 'r', 'k', 'W', 'i', 'r', 'e', 'l', 'e', 's', 's', 0,
    'P', 'd', 'm', 'P', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'X', 0,
    'P', 'd', 'm', 'P', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'Y', 0,
    'P', 'l', 'a', 'c', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 'T', 'e', 'x', 't', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'N', 'o', 'H', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'N', 'o', 'S', 'h', 'a', 'p', 'i', 'n', 'g', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', 'R', 'o', 'l', 'e', 0,
    'P', 'r', 'i', 'n', 't', 'e', 'r', 'P', 'r', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'C', 'o', 'n', 's', 't', 'a', 'n', 't', 's', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'Q', 'D', 'r', 'a', 'g', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'D', 'r', 'a', 'g', 'L', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', ':', ':', 'T', 'y', 'p', 'e', 0,
    'Q', 'G', 'u', 'i', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'I', 'O', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'Q', 'L', 'i', 'n', 'e', 'a', 'r', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'A', 'c', 't', 'i', 'o', 'n', '*', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 'c', 'r', 'e', 'e', 'n', '*', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'W', 'i', 'n', 'd', 'o', 'w', '*', '>', 0,
    'Q', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', ':', ':', 'U', 'n', 'i', 't', 0,
    'Q', 'P', 'o', 'i', 'n', 't', 'i', 'n', 'g', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'Q', 'R', 'a', 'd', 'i', 'a', 'l', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'Q', 'S', 'e', 's', 's', 'i', 'o', 'n', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'Q', 'S', 't', 'a', 't', 'u', 's', 'T', 'i', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 'G', 'r', 'o', 'u', 'p', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 'n', 'e', ':', ':', 'E', 'd', 'g', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 's', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'R', 'a', 's', 't', 'e', 'r', 'G', 'L', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'S', 'a', 'i', 'n', 't', 'P', 'e', 't', 'e', 'r', 's', 'b', 'u', 'r', 'g', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'E', 'n', 'd', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'S', 'i', 'n', 'g', 'l', 'e', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'I', 'n', 't', 'e', 'g', 'e', 'r', 0,
    'W', 'o', 'r', 'd', 'U', 'n', 'd', 'e', 'r', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'a', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'L', 'i', 'm', 'i', 't', 0,
    'a', 'l', 'p', 'h', 'a', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'a', 'm', 'b', 'i', 'g', 'u', 'o', 'u', 's', 'M', 'e', 'm', 'b', 'e', 'r', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'a', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 'M', 'o', 'd', 'e', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'B', 'r', 'u', 's', 'h', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    'b', 'l', 'o', 'c', 'k', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'c', 'a', 'c', 'h', 'e', 'S', 't', 'a', 't', 'i', 's', 't', 'i', 'c', 's', 0,
    'c', 'a', 'n', 'D', 'r', 'o', 'p', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'c', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'c', 'l', 'e', 'a', 'n', 'u', 'p', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'c', 'l', 'e', 'a', 'r', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'c', 'l', 'e', 'a', 'r', 'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'c', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'P', 'o', 's', 'R', 'a', 'n', 'g', 'e', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'T', 'o', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'A', 'l', 'p', 'h', 'a', 'M', 'a', 's', 'k', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'F', 'l', 'a', 's', 'h', 'T', 'i', 'm', 'e', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'M', 'o', 'v', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'o', 'n', 'U', 'n', 'i', 't', 's', 0,
    'd', 'e', 'p', 't', 'h', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'd', 'e', 's', 'k', 't', 'o', 'p', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'y', 'L', 'o', 'a', 'd', 'e', 'd', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'o', 'P', 'l', 'a', 'n', 'e', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'o', 'P', 'o', 'i', 'n', 't', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'r', 'a', 'w', 'R', 'o', 'u', 'n', 'd', 'e', 'd', 'R', 'e', 'c', 't', 0,
    'd', 'r', 'a', 'w', 'T', 'i', 'l', 'e', 'd', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'e', 'm', 'i', 't', 'D', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'x', 'c', 'l', 'u', 's', 'i', 'o', 'n', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'f', 'i', 'r', 's', 't', 'L', 'i', 'n', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'f', 'o', 'n', 't', 'W', 'o', 'r', 'd', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'f', 'r', 'o', 'm', 'E', 'u', 'l', 'e', 'r', 'A', 'n', 'g', 'l', 'e', 's', 0,
    'f', 'r', 'o', 'm', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'a', 'd', 'e', 'r', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'e', 't', 'A', 'x', 'i', 's', 'A', 'n', 'd', 'A', 'n', 'g', 'l', 'e', 0,
    'g', 'r', 'e', 'e', 'n', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'h', 'a', 's', 'A', 'l', 'p', 'h', 'a', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 0,
    'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'e', 'd', 'T', 'e', 'x', 't', 0,
    'i', 's', 'L', 'a', 'y', 'o', 'u', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'P', 'r', 'i', 'v', 'a', 't', 'e', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'i', 's', 'R', 'e', 'd', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'S', 'a', 'v', 'i', 'n', 'g', 'S', 'e', 's', 's', 'i', 'o', 'n', 0,
    'i', 's', 'U', 'n', 'd', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'j', 'u', 'm', 'p', 'T', 'o', 'N', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'j', 'u', 'm', 'p', 'T', 'o', 'N', 'e', 'x', 't', 'I', 'm', 'a', 'g', 'e', 0,
    'k', 'e', 'y', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'a', 's', 't', 'E', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'l', 'a', 'y', 'o', 'u', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'l', 'e', 'a', 'd', 'i', 'n', 'g', 'I', 'n', 'c', 'l', 'u', 'd', 'e', 'd', 0,
    'l', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'l', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 's', 'l', 'a', 't', 'e', 'b', 'l', 'u', 'e', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 't', 'u', 'r', 'q', 'u', 'o', 'i', 's', 'e', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 'v', 'i', 'o', 'l', 'e', 't', 'r', 'e', 'd', 0,
    'm', 'e', 'r', 'g', 'e', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'm', 'e', 't', 'a', 'I', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'm', 'i', 'g', 'h', 't', 'B', 'e', 'R', 'i', 'c', 'h', 'T', 'e', 'x', 't', 0,
    'm', 'i', 'n', 'R', 'i', 'g', 'h', 't', 'B', 'e', 'a', 'r', 'i', 'n', 'g', 0,
    'm', 'o', 'd', 'a', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'n', 'a', 't', 'u', 'r', 'a', 'l', 'T', 'e', 'x', 't', 'R', 'e', 'c', 't', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'F', 'o', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'o', 'u', 't', 'p', 'u', 't', 'C', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 0,
    'p', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'p', 'a', 'i', 'n', 't', 'R', 'e', 'c', 't', 'P', 'i', 'x', 'e', 'l', 's', 0,
    'p', 'a', 'i', 'n', 't', 'R', 'e', 'c', 't', 'P', 'o', 'i', 'n', 't', 's', 0,
    'p', 'e', 'r', 'c', 'e', 'n', 't', 'A', 't', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'p', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    'p', 'l', 'a', 'c', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 'T', 'e', 'x', 't', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'I', 'n', 'B', 'l', 'o', 'c', 'k', 0,
    'p', 'o', 's', 's', 'i', 'b', 'l', 'e', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    'p', 'r', 'e', 'e', 'd', 'i', 't', 'A', 'r', 'e', 'a', 'T', 'e', 'x', 't', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'K', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'H', 's', 'l', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'H', 's', 'v', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'Y', 'u', 'v', 0,
    'r', 'e', 'd', 'o', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'A', 'c', 't', 'i', 'v', 'a', 't', 'e', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'r', 'e', 's', 'o', 'l', 'v', 'e', 'S', 'y', 'm', 'l', 'i', 'n', 'k', 's', 0,
    'r', 'o', 'o', 't', 'P', 'a', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'a', 'f', 'e', 'A', 'r', 'e', 'a', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'T', 'r', 'i', 's', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    's', 'e', 't', 'C', 'a', 'c', 'h', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'C', 'e', 'n', 't', 'e', 'r', 'R', 'a', 'd', 'i', 'u', 's', 0,
    's', 'e', 't', 'C', 'o', 'm', 'm', 'i', 't', 'S', 't', 'r', 'i', 'n', 'g', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'O', 'v', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'G', 'l', 'y', 'p', 'h', 'I', 'n', 'd', 'e', 'x', 'e', 's', 0,
    's', 'e', 't', 'H', 'e', 'a', 'd', 'i', 'n', 'g', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'e', 't', 'I', 'c', 'o', 'n', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    's', 'e', 't', 'M', 'a', 'j', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'M', 'i', 'n', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'N', 'u', 'm', 'b', 'e', 'r', 'P', 'r', 'e', 'f', 'i', 'x', 0,
    's', 'e', 't', 'N', 'u', 'm', 'b', 'e', 'r', 'S', 'u', 'f', 'f', 'i', 'x', 0,
    's', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', 'I', 'n', 't', 'e', 'n', 't', 0,
    's', 'e', 't', 'R', 'e', 'g', 'i', 's', 't', 'r', 'y', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'S', 'h', 'a', 'r', 'e', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'S', 't', 'r', 'i', 'n', 'g', 0,
    's', 'e', 't', 'S', 'w', 'a', 'p', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    's', 'e', 't', 'S', 'w', 'a', 'p', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    's', 'e', 't', 'T', 'a', 'b', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'T', 'r', 'i', 's', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 's', 0,
    's', 'h', 'o', 'r', 't', 'c', 'u', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    's', 'h', 'o', 'w', 'I', 's', 'M', 'a', 'x', 'i', 'm', 'i', 'z', 'e', 'd', 0,
    's', 't', 'a', 'r', 't', 'S', 'y', 's', 't', 'e', 'm', 'M', 'o', 'v', 'e', 0,
    't', 'a', 'b', 'S', 't', 'o', 'p', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    't', 'o', 'p', 'L', 'e', 'v', 'e', 'l', 'W', 'i', 'n', 'd', 'o', 'w', 's', 0,
    't', 'r', 'a', 'n', 's', 'i', 'e', 'n', 't', 'P', 'a', 'r', 'e', 'n', 't', 0,
    'u', 'n', 'd', 'o', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'u', 'n', 'p', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'u', 'n', 's', 'e', 't', 'U', 'r', 'l', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'u', 's', 'e', 'H', 'o', 'v', 'e', 'r', 'E', 'f', 'f', 'e', 'c', 't', 's', 0,
    'v', 'i', 'r', 't', 'u', 'a', 'l', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'v', 'i', 'r', 't', 'u', 'a', 'l', 'S', 'i', 'b', 'l', 'i', 'n', 'g', 's', 0,
    'A', 'd', 'd', 'r', 'e', 's', 's', 'B', 'o', 'o', 'k', 'N', 'e', 'w', 0,
    'A', 'l', 'i', 'g', 'n', 'S', 'u', 'b', 'S', 'c', 'r', 'i', 'p', 't', 0,
    'A', 'p', 'p', 'o', 'i', 'n', 't', 'm', 'e', 'n', 't', 'N', 'e', 'w', 0,
    'A', 'u', 'd', 'i', 'o', 'V', 'o', 'l', 'u', 'm', 'e', 'L', 'o', 'w', 0,
    'B', 'a', 't', 't', 'e', 'r', 'y', 'C', 'a', 'u', 't', 'i', 'o', 'n', 0,
    'B', 'l', 'o', 'c', 'k', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'B', 'l', 'o', 'c', 'k', 'C', 'o', 'd', 'e', 'F', 'e', 'n', 'c', 'e', 0,
    'B', 'l', 'o', 'c', 'k', 'T', 'o', 'p', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'C', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 't', 'C', 'l', 'o', 'u', 'd', 0,
    'C', 'u', 'r', 'v', 'e', 'T', 'o', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'D', 'a', 's', 'h', 'D', 'o', 't', 'D', 'o', 't', 'L', 'i', 'n', 'e', 0,
    'D', 'i', 'a', 'l', 'o', 'g', 'P', 'a', 's', 's', 'w', 'o', 'r', 'd', 0,
    'D', 'i', 'a', 'l', 'o', 'g', 'Q', 'u', 'e', 's', 't', 'i', 'o', 'n', 0,
    'D', 'i', 'r', 't', 'y', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'R', 'e', 'v', 'e', 'r', 't', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'S', 'a', 'v', 'e', 'A', 's', 0,
    'D', 'o', 'u', 'b', 'l', 'e', 'P', 'o', 's', 't', 'c', 'a', 'r', 'd', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'I', 'n', 'v', 'i', 't', 'e', 0,
    'E', 'v', 'e', 'r', 'l', 'a', 's', 't', 'i', 'n', 'g', 'S', 'k', 'y', 0,
    'E', 'x', 't', 'r', 'a', 'C', 'o', 'n', 'd', 'e', 'n', 's', 'e', 'd', 0,
    'F', 'i', 'n', 'd', 'W', 'h', 'o', 'l', 'e', 'W', 'o', 'r', 'd', 's', 0,
    'F', 'o', 'l', 'd', 'e', 'r', 'V', 'i', 's', 'i', 't', 'i', 'n', 'g', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'T', 'e', 'x', 't', 'B', 'o', 'l', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'I', 'n', 'v', 'a', 'l', 'i', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'M', 'o', 'n', 'o', 'L', 'S', 'B', 0,
    'F', 'r', 'a', 'm', 'e', 'T', 'o', 'p', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'K', 'e', 'r', 'n', 'e', 'd', 'A', 'd', 'v', 'a', 'n', 'c', 'e', 's', 0,
    'L', 'i', 'n', 'e', 'H', 'e', 'i', 'g', 'h', 't', 'T', 'y', 'p', 'e', 0,
    'L', 'i', 's', 't', 'L', 'o', 'w', 'e', 'r', 'A', 'l', 'p', 'h', 'a', 0,
    'L', 'i', 's', 't', 'L', 'o', 'w', 'e', 'r', 'R', 'o', 'm', 'a', 'n', 0,
    'L', 'i', 's', 't', 'U', 'p', 'p', 'e', 'r', 'A', 'l', 'p', 'h', 'a', 0,
    'L', 'i', 's', 't', 'U', 'p', 'p', 'e', 'r', 'R', 'o', 'm', 'a', 'n', 0,
    'M', 'a', 'i', 'l', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 0,
    'M', 'a', 'i', 'l', 'M', 'a', 'r', 'k', 'U', 'n', 'r', 'e', 'a', 'd', 0,
    'M', 'a', 'i', 'l', 'M', 'e', 's', 's', 'a', 'g', 'e', 'N', 'e', 'w', 0,
    'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'N', 'o', 'H', 'T', 'M', 'L', 0,
    'M', 'i', 'l', 'l', 'e', 'n', 'n', 'i', 'u', 'm', 'P', 'i', 'n', 'e', 0,
    'M', 'o', 'u', 's', 'e', 'E', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'C', 'h', 'a', 'r', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'L', 'i', 'n', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'P', 'a', 'g', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'W', 'o', 'r', 'd', 0,
    'N', 'e', 't', 'w', 'o', 'r', 'k', 'O', 'f', 'f', 'l', 'i', 'n', 'e', 0,
    'N', 'o', 'r', 'm', 'a', 'l', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    'O', 'c', 't', 'o', 'b', 'e', 'r', 'S', 'i', 'l', 'e', 'n', 'c', 'e', 0,
    'O', 'l', 'd', 'F', 'o', 'n', 't', 'S', 't', 'r', 'e', 't', 'c', 'h', 0,
    'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', '_', 'A', 'u', 't', 'o', 0,
    'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', '_', '1', '_', '4', 0,
    'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', '_', '1', '_', '6', 0,
    'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', '_', 'A', '1', 'b', 0,
    'P', 'u', 'r', 'p', 'l', 'e', 'D', 'i', 'v', 'i', 's', 'i', 'o', 'n', 0,
    'Q', 'D', 'r', 'a', 'g', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'F', 'i', 'l', 'e', 'O', 'p', 'e', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'S', 't', 'r', 'e', 't', 'c', 'h', 0,
    'Q', 'I', 'c', 'o', 'n', 'D', 'r', 'a', 'g', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'Q', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 0,
    'R', 'e', 't', 'r', 'i', 'e', 'v', 'e', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'S', 'c', 'r', 'o', 'l', 'l', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'N', 'e', 'x', 't', 'C', 'h', 'a', 'r', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'N', 'e', 'x', 't', 'L', 'i', 'n', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'N', 'e', 'x', 't', 'P', 'a', 'g', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'N', 'e', 'x', 't', 'W', 'o', 'r', 'd', 0,
    'S', 'k', 'i', 'p', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 's', 0,
    'S', 'l', 'e', 'e', 'p', 'l', 'e', 's', 's', 'N', 'i', 'g', 'h', 't', 0,
    'S', 't', 'r', 'i', 'c', 't', 'N', 'o', 'v', 'e', 'm', 'b', 'e', 'r', 0,
    'S', 'u', 'p', 'p', 'r', 'e', 's', 's', 'C', 'o', 'l', 'o', 'r', 's', 0,
    'S', 'u', 'r', 'f', 'a', 'c', 'e', 'C', 'r', 'e', 'a', 't', 'e', 'd', 0,
    'S', 'y', 's', 't', 'e', 'm', 'S', 'h', 'u', 't', 'd', 'o', 'w', 'n', 0,
    'U', 'l', 't', 'r', 'a', 'C', 'o', 'n', 'd', 'e', 'n', 's', 'e', 'd', 0,
    'V', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'V', 'i', 'e', 'w', 'F', 'u', 'l', 'l', 's', 'c', 'r', 'e', 'e', 'n', 0,
    'W', 'e', 'a', 't', 'h', 'e', 'r', 'S', 'h', 'o', 'w', 'e', 'r', 's', 0,
    'a', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 'T', 'e', 'x', 't', 0,
    'a', 'd', 'd', 'R', 'o', 'u', 'n', 'd', 'e', 'd', 'R', 'e', 'c', 't', 0,
    'a', 'n', 'g', 'l', 'e', 'A', 't', 'P', 'e', 'r', 'c', 'e', 'n', 't', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'S', 'i', 'z', 'e', 's', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'M', 'o', 'd', 'e', 0,
    'b', 'a', 's', 'e', 'U', 'r', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 's', 'e', 'l', 'i', 'n', 'e', 'O', 'f', 'f', 's', 'e', 't', 0,
    'b', 'e', 'g', 'i', 'n', 'E', 'd', 'i', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'b', 'l', 'a', 'n', 'c', 'h', 'e', 'd', 'a', 'l', 'm', 'o', 'n', 'd', 0,
    'b', 'l', 'u', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'l', 'a', 'p', 's', 'e', 0,
    'b', 'r', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 'S', 'i', 'z', 'e', 0,
    'c', 'a', 'n', 'R', 'e', 'd', 'o', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'a', 'n', 'U', 'n', 'd', 'o', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'l', 'e', 'a', 'r', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'c', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'M', 'o', 'd', 'e', 0,
    'c', 'o', 'r', 'n', 'f', 'l', 'o', 'w', 'e', 'r', 'b', 'l', 'u', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'c', 'u', 'r', 'v', 'e', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 0,
    'd', 'a', 'r', 'k', 'o', 'l', 'i', 'v', 'e', 'g', 'r', 'e', 'e', 'n', 0,
    'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'o', 'n', 'S', 'i', 'z', 'e', 0,
    'd', 'i', 's', 'c', 'a', 'r', 'd', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'o', 'L', 'i', 'n', 'e', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'd', 'o', 'u', 'b', 'l', 'e', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'd', 'r', 'a', 'w', 'S', 't', 'a', 't', 'i', 'c', 'T', 'e', 'x', 't', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'o', 'n', 't', 'F', 'i', 'x', 'e', 'd', 'P', 'i', 't', 'c', 'h', 0,
    'f', 'r', 'o', 'm', 'I', 'c', 'c', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'f', 'u', 'l', 'l', 'R', 'e', 'c', 't', 'P', 'i', 'x', 'e', 'l', 's', 0,
    'f', 'u', 'l', 'l', 'R', 'e', 'c', 't', 'P', 'o', 'i', 'n', 't', 's', 0,
    'g', 'e', 't', 'E', 'u', 'l', 'e', 'r', 'A', 'n', 'g', 'l', 'e', 's', 0,
    'g', 'e', 't', 'P', 'r', 'o', 'c', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'h', 'e', 'a', 'd', 'e', 'r', 'R', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    'h', 's', 'l', 'S', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'F', 0,
    'h', 's', 'v', 'S', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'F', 0,
    'i', 'n', 'p', 'u', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'i', 'n', 's', 'e', 'r', 't', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 0,
    'i', 'n', 's', 'e', 'r', 't', 'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 0,
    'i', 's', 'A', 'u', 't', 'o', 'T', 'r', 'i', 's', 't', 'a', 't', 'e', 0,
    'i', 's', 'E', 'q', 'u', 'i', 'v', 'a', 'l', 'e', 'n', 't', 'T', 'o', 0,
    'i', 's', 'U', 's', 'e', 'r', 'T', 'r', 'i', 's', 't', 'a', 't', 'e', 0,
    'k', 'e', 'y', 'C', 'o', 'm', 'b', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'l', 'e', 'n', 'g', 't', 'h', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'l', 'i', 'g', 'h', 't', 's', 'l', 'a', 't', 'e', 'g', 'r', 'a', 'y', 0,
    'l', 'i', 'g', 'h', 't', 's', 'l', 'a', 't', 'e', 'g', 'r', 'e', 'y', 0,
    'l', 'i', 'g', 'h', 't', 's', 't', 'e', 'e', 'l', 'b', 'l', 'u', 'e', 0,
    'l', 'i', 'n', 'e', 'H', 'e', 'i', 'g', 'h', 't', 'T', 'y', 'p', 'e', 0,
    'l', 'i', 's', 't', 'F', 'r', 'o', 'm', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 's', 'e', 'a', 'g', 'r', 'e', 'e', 'n', 0,
    'm', 'i', 'n', 'L', 'e', 'f', 't', 'B', 'e', 'a', 'r', 'i', 'n', 'g', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'm', 'o', 'u', 's', 'e', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'S', 'c', 'a', 'n', 'C', 'o', 'd', 'e', 0,
    'n', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 'D', 'e', 'l', 'a', 'y', 0,
    'n', 'e', 'x', 't', 'I', 'm', 'a', 'g', 'e', 'D', 'e', 'l', 'a', 'y', 0,
    'o', 'p', 'a', 'c', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'p', 't', 'i', 'm', 'i', 'z', 'e', 'd', 'W', 'r', 'i', 't', 'e', 0,
    'o', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'o', 'w', 'n', 's', 'F', 'i', 'n', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'p', 'a', 'i', 'n', 't', 'i', 'n', 'g', 'A', 'c', 't', 'i', 'v', 'e', 0,
    'p', 'o', 'i', 'n', 't', 'A', 't', 'P', 'e', 'r', 'c', 'e', 'n', 't', 0,
    'p', 'o', 'i', 'n', 't', 'i', 'n', 'g', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'p', 'r', 'e', 's', 's', 'T', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 0,
    'p', 'r', 'o', 'p', 'o', 's', 'e', 'd', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'q', 'U', 'n', 'p', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'y', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'a', 'b', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'r', 'e', 's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'r', 'e', 's', 't', 'a', 'r', 't', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    's', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'S', 'i', 'z', 'e', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'T', 'o', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'S', 't', 'a', 'r', 't', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'S', 't', 'a', 'c', 'k', 0,
    's', 'e', 't', 'A', 'n', 'c', 'h', 'o', 'r', 'N', 'a', 'm', 'e', 's', 0,
    's', 'e', 't', 'B', 'a', 'd', 'g', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    's', 'e', 't', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'B', 'r', 'u', 's', 'h', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    's', 'e', 't', 'C', 'e', 'l', 'l', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'C', 'e', 'l', 'l', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'D', 'a', 's', 'h', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'o', 'n', 't', 0,
    's', 'e', 't', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'D', 'r', 'a', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'D', 'r', 'o', 'p', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'F', 'o', 'c', 'a', 'l', 'R', 'a', 'd', 'i', 'u', 's', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'K', 'e', 'r', 'n', 'i', 'n', 'g', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'S', 't', 'r', 'e', 't', 'c', 'h', 0,
    's', 'e', 't', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'I', 'n', 'd', 'e', 'n', 't', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 'F', 'i', 'l', 't', 'e', 'r', 's', 0,
    's', 'e', 't', 'O', 'b', 'j', 'e', 'c', 't', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    's', 'e', 't', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 'e', 't', 'P', 'r', 'e', 'e', 'd', 'i', 't', 'A', 'r', 'e', 'a', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 's', 0,
    's', 'e', 't', 'R', 'e', 's', 't', 'a', 'r', 't', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'T', 'o', 'L', 'e', 'f', 't', 0,
    's', 'e', 't', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'O', 'u', 't', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'W', 'o', 'r', 'd', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    's', 'h', 'o', 'w', 'F', 'u', 'l', 'l', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    's', 'h', 'o', 'w', 'S', 't', 'a', 't', 'u', 's', 'T', 'e', 'x', 't', 0,
    's', 'l', 'o', 'p', 'e', 'A', 't', 'P', 'e', 'r', 'c', 'e', 'n', 't', 0,
    's', 't', 'a', 't', 'i', 'c', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    's', 't', 'r', 'i', 'n', 'g', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'O', 'p', 'e', 'n', 'G', 'L', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'O', 'p', 't', 'i', 'o', 'n', 0,
    't', 'e', 's', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 0,
    't', 'o', 'F', 'i', 'l', 'l', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 's', 0,
    't', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    't', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'M', 'o', 'd', 'e', 'l', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'v', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'o', 'r', 'l', 'd', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'w', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 's', 0,
    'A', 'l', 'i', 'g', 'n', 'B', 'a', 's', 'e', 'l', 'i', 'n', 'e', 0,
    'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'e', 'B', 'a', 's', 'e', 0,
    'B', 'u', 'r', 'n', 'i', 'n', 'g', 'S', 'p', 'r', 'i', 'n', 'g', 0,
    'C', 'o', 'l', 'o', 'r', 'f', 'u', 'l', 'P', 'e', 'a', 'c', 'h', 0,
    'D', 'a', 's', 'h', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'D', 'i', 'a', 'l', 'o', 'g', 'W', 'a', 'r', 'n', 'i', 'n', 'g', 0,
    'D', 'i', 'r', 't', 'y', 'C', 'l', 'i', 'p', 'P', 'a', 't', 'h', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'P', 'r', 'i', 'n', 't', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'T', 'i', 't', 'l', 'e', 0,
    'D', 'r', 'i', 'v', 'e', 'H', 'a', 'r', 'd', 'd', 'i', 's', 'k', 0,
    'E', 'd', 'i', 't', 'S', 'e', 'l', 'e', 'c', 't', 'A', 'l', 'l', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', 'h', 'o', 'u', '3', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', 'h', 'o', 'u', '4', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'K', 'a', 'k', 'u', '2', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'K', 'a', 'k', 'u', '3', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '1', '0', 0,
    'E', 'x', 't', 'r', 'a', 'E', 'x', 'p', 'a', 'n', 'd', 'e', 'd', 0,
    'F', 'a', 'n', 'F', 'o', 'l', 'd', 'G', 'e', 'r', 'm', 'a', 'n', 0,
    'F', 'l', 'o', 'a', 't', 'i', 'n', 'g', 'P', 'o', 'i', 'n', 't', 0,
    'F', 'o', 'n', 't', 'P', 'i', 'x', 'e', 'l', 'S', 'i', 'z', 'e', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '3', '2', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'l', 'p', 'h', 'a', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'B', 'G', 'R', '8', '8', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '4', '4', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '5', '5', '5', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '6', '6', '6', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '8', '8', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '6', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'X', '6', '4', 0,
    'H', 'a', 'p', 'p', 'y', 'M', 'e', 'm', 'o', 'r', 'i', 'e', 's', 0,
    'I', 'm', 'a', 'g', 'e', 'M', 'a', 'x', 'W', 'i', 'd', 't', 'h', 0,
    'I', 'm', 'a', 'g', 'e', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '1', '0', 'x', '1', '1', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '1', '0', 'x', '1', '3', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '1', '0', 'x', '1', '4', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '1', '2', 'x', '1', '1', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '1', '5', 'x', '1', '1', 0,
    'I', 'n', 'p', 'u', 't', 'K', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'I', 't', 'm', 'e', 'o', 'B', 'r', 'a', 'n', 'd', 'i', 'n', 'g', 0,
    'L', 'i', 'n', 'e', 'T', 'o', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'M', 'i', 'd', 'n', 'i', 'g', 'h', 't', 'B', 'l', 'o', 'o', 'm', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'N', 'e', 'x', 't', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 0,
    'N', 'o', 'F', 'o', 'n', 't', 'M', 'e', 'r', 'g', 'i', 'n', 'g', 0,
    'O', 'l', 'd', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'O', 'p', 'e', 'n', 'G', 'L', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'O', 'p', 'e', 'n', 'V', 'G', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'P', 'a', 's', 's', 'i', 'o', 'n', 'a', 't', 'e', 'B', 'e', 'd', 0,
    'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', '_', 'X', '4', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'O', 'u', 't', 'l', 'i', 'n', 'e', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'B', 'l', 'o', 'c', 'k', 0,
    'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'i', 'l', 'd', 0,
    'Q', 'B', 'a', 'c', 'k', 'i', 'n', 'g', 'S', 't', 'o', 'r', 'e', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'Q', 'F', 'o', 'n', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 0,
    'Q', 'F', 'o', 'n', 't', 'M', 'e', 't', 'r', 'i', 'c', 's', 'F', 0,
    'Q', 'I', 'n', 't', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'o', 'i', 'n', 't', '>', 0,
    'Q', 'P', 'o', 'i', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'R', 'a', 's', 't', 'e', 'r', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'Q', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'I', 't', 'e', 'm', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 0,
    'Q', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'y', 's', 't', 'e', 'm', 0,
    'R', 'a', 'i', 'n', 'y', 'A', 's', 'h', 'v', 'i', 'l', 'l', 'e', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', 'M', 'o', 'd', 'e', 's', 0,
    'R', 'a', 's', 't', 'e', 'r', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'R', 'e', 'f', 'l', 'e', 'c', 't', 'S', 'p', 'r', 'e', 'a', 'd', 0,
    'R', 'e', 's', 't', 'a', 'r', 't', 'A', 'n', 'y', 'w', 'a', 'y', 0,
    'R', 'i', 's', 'k', 'y', 'C', 'o', 'n', 'c', 'r', 'e', 't', 'e', 0,
    'S', 'c', 'r', 'o', 'l', 'l', 'S', 't', 'a', 'r', 't', 'e', 'd', 0,
    'S', 'c', 'r', 'o', 'l', 'l', 'U', 'p', 'd', 'a', 't', 'e', 'd', 0,
    'S', 'e', 'm', 'i', 'C', 'o', 'n', 'd', 'e', 'n', 's', 'e', 'd', 0,
    'S', 'h', 'a', 'r', 'p', 'e', 'y', 'e', 'E', 'a', 'g', 'l', 'e', 0,
    'S', 'p', 'l', 'i', 't', 'L', 'i', 'g', 'a', 't', 'u', 'r', 'e', 0,
    'S', 't', 'e', 'r', 'e', 'o', 'B', 'u', 'f', 'f', 'e', 'r', 's', 0,
    'S', 'u', 'g', 'a', 'r', 'L', 'o', 'l', 'l', 'i', 'p', 'o', 'p', 0,
    'T', 'e', 'm', 'p', 't', 'i', 'n', 'g', 'A', 'z', 'u', 'r', 'e', 0,
    'U', 'l', 't', 'r', 'a', 'E', 'x', 'p', 'a', 'n', 'd', 'e', 'd', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'S', 'h', 'o', 'r', 't', 0,
    'U', 's', 'e', 'r', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'V', 'i', 'c', 'i', 'o', 'u', 's', 'S', 't', 'a', 'n', 'c', 'e', 0,
    'V', 'u', 'l', 'k', 'a', 'n', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'W', 'a', 'v', 'e', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'a', 'c', 'c', 'e', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'l', 'p', 'h', 'a', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'e', 'B', 'a', 's', 'e', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'a', 'u', 't', 'o', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'S', 'i', 'z', 'e', 0,
    'b', 'i', 't', 'P', 'l', 'a', 'n', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'b', 'l', 'o', 'c', 'k', 'I', 'n', 's', 'e', 'r', 't', 'e', 'd', 0,
    'b', 'o', 't', 't', 'o', 'm', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'b', 'r', 'u', 's', 'h', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'c', 'h', 'e', 'c', 'k', 'e', 'd', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'c', 'l', 'e', 'a', 'r', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'c', 'l', 'e', 'a', 'r', 'I', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    'c', 'l', 'e', 'a', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'c', 'l', 'i', 'p', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'o', 'l', 'o', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'c', 'o', 'n', 's', 't', 'S', 'c', 'a', 'n', 'L', 'i', 'n', 'e', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 'P', 'o', 'i', 'n', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'd', 'a', 'r', 'k', 'g', 'o', 'l', 'd', 'e', 'n', 'r', 'o', 'd', 0,
    'd', 'a', 'r', 'k', 's', 'l', 'a', 't', 'e', 'b', 'l', 'u', 'e', 0,
    'd', 'a', 'r', 'k', 's', 'l', 'a', 't', 'e', 'g', 'r', 'a', 'y', 0,
    'd', 'a', 'r', 'k', 's', 'l', 'a', 't', 'e', 'g', 'r', 'e', 'y', 0,
    'd', 'a', 'r', 'k', 't', 'u', 'r', 'q', 'u', 'o', 'i', 's', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'd', 'o', 't', 's', 'P', 'e', 'r', 'M', 'e', 't', 'e', 'r', 'X', 0,
    'd', 'o', 't', 's', 'P', 'e', 'r', 'M', 'e', 't', 'e', 'r', 'Y', 0,
    'f', 'i', 'r', 's', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'n', 't', 'P', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'f', 'o', 'n', 't', 'S', 't', 'r', 'i', 'k', 'e', 'O', 'u', 't', 0,
    'f', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 0,
    'f', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'f', 'o', 'n', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'f', 'o', 'r', 'm', 'a', 't', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'f', 'r', 'a', 'm', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'f', 'r', 'a', 'm', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'f', 'r', 'o', 'm', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'f', 'r', 'o', 'm', 'N', 'u', 'm', 'e', 'r', 'i', 'c', 'I', 'd', 0,
    'f', 'r', 'o', 'm', 'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    'f', 'r', 'o', 'm', 'P', 'r', 'i', 'm', 'a', 'r', 'i', 'e', 's', 0,
    'f', 'r', 'o', 'm', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 0,
    'h', 'a', 's', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 's', 'l', 'S', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'h', 's', 'v', 'S', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'i', 'n', 'd', 'e', 'x', 'F', 'r', 'o', 'm', 'I', 't', 'e', 'm', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'i', 'n', 't', 'r', 'i', 'n', 's', 'i', 'c', 'S', 'i', 'z', 'e', 0,
    'i', 's', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'C', 'l', 'i', 'p', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'D', 'r', 'a', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'D', 'r', 'o', 'p', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'L', 'e', 'f', 't', 'T', 'o', 'R', 'i', 'g', 'h', 't', 0,
    'i', 's', 'R', 'i', 'g', 'h', 't', 'T', 'o', 'L', 'e', 'f', 't', 0,
    'i', 's', 'T', 'a', 'b', 'l', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'n', 'g', 0,
    'i', 's', 'T', 'r', 'a', 'n', 's', 'p', 'a', 'r', 'e', 'n', 't', 0,
    'i', 's', 'U', 'p', 'd', 'a', 't', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'i', 't', 'e', 'm', 'F', 'r', 'o', 'm', 'I', 'n', 'd', 'e', 'x', 0,
    'i', 't', 'e', 'm', 'P', 'r', 'o', 't', 'o', 't', 'y', 'p', 'e', 0,
    'k', 'e', 'y', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'a', 's', 't', 'T', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 0,
    'l', 'a', 'v', 'e', 'n', 'd', 'e', 'r', 'b', 'l', 'u', 's', 'h', 0,
    'l', 'e', 'n', 'g', 't', 'h', 'S', 'q', 'u', 'a', 'r', 'e', 'd', 0,
    'l', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'l', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 'S', 'i', 'z', 'e', 0,
    'l', 'i', 'g', 'h', 't', 's', 'e', 'a', 'g', 'r', 'e', 'e', 'n', 0,
    'l', 'i', 'n', 'e', 'T', 'h', 'i', 'c', 'k', 'n', 'e', 's', 's', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'p', 'F', 'r', 'o', 'm', 'G', 'l', 'o', 'b', 'a', 'l', 0,
    'm', 'a', 'r', 'g', 'i', 'n', 's', 'P', 'i', 'x', 'e', 'l', 's', 0,
    'm', 'a', 'r', 'g', 'i', 'n', 's', 'P', 'o', 'i', 'n', 't', 's', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'P', 'o', 'i', 'n', 't', 's', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'o', 'u', 't', 'p', 'u', 't', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'o', 'w', 'n', 's', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    'o', 'w', 'n', 's', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'p', 'a', 'l', 'e', 'g', 'o', 'l', 'd', 'e', 'n', 'r', 'o', 'd', 0,
    'p', 'a', 'l', 'e', 't', 'u', 'r', 'q', 'u', 'o', 'i', 's', 'e', 0,
    'p', 'a', 'l', 'e', 'v', 'i', 'o', 'l', 'e', 't', 'r', 'e', 'd', 0,
    'p', 'r', 'e', 'e', 'd', 'i', 't', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'p', 'r', 'e', 's', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'P', 'o', 'i', 'n', 't', 's', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'C', 'o', 'u', 'n', 't', 0,
    'q', 'F', 'u', 'z', 'z', 'y', 'C', 'o', 'm', 'p', 'a', 'r', 'e', 0,
    'r', 'e', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'r', 'e', 'd', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'P', 'h', 'a', 's', 'e', '2', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'U', 'p', 'd', 'a', 't', 'e', 0,
    'r', 'o', 'o', 't', 'D', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'y', 0,
    'r', 'o', 't', 'a', 't', 'e', 'R', 'a', 'd', 'i', 'a', 'n', 's', 0,
    'r', 'o', 't', 'a', 't', 'e', 'd', 'V', 'e', 'c', 't', 'o', 'r', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'T', 'o', 'W', 'i', 'd', 't', 'h', 0,
    's', 'c', 'e', 'n', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'c', 'r', 'e', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'c', 'r', 'e', 'e', 'n', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    's', 'e', 't', 'A', 'n', 'c', 'h', 'o', 'r', 'H', 'r', 'e', 'f', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'R', 'e', 'p', 'e', 'a', 't', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    's', 'e', 't', 'C', 'a', 'c', 'h', 'e', 'L', 'i', 'm', 'i', 't', 0,
    's', 'e', 't', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'C', 'h', 'e', 'c', 'k', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 'R', 'e', 'g', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'G', 'r', 'o', 'u', 'p', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 'l', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'T', 'a', 'b', 'l', 'e', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 'P', 'o', 's', 0,
    's', 'e', 't', 'D', 'a', 's', 'h', 'O', 'f', 'f', 's', 'e', 't', 0,
    's', 'e', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'I', 'd', 0,
    's', 'e', 't', 'D', 'r', 'a', 'g', 'C', 'u', 'r', 's', 'o', 'r', 0,
    's', 'e', 't', 'D', 'r', 'o', 'p', 'A', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'F', 'i', 'x', 'e', 'd', 'P', 'i', 't', 'c', 'h', 0,
    's', 'e', 't', 'F', 'o', 'c', 'a', 'l', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'I', 't', 'a', 'l', 'i', 'c', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'W', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    's', 'e', 't', 'H', 'e', 'a', 'd', 'e', 'r', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'M', 'i', 't', 'e', 'r', 'L', 'i', 'm', 'i', 't', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'N', 'u', 'm', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    's', 'e', 't', 'O', 'b', 'j', 'e', 'c', 't', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'R', 'a', 'n', 'g', 'e', 's', 0,
    's', 'e', 't', 'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'i', 'x', 'e', 'l', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 'F', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'e', 'd', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'a', 'b', 'l', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'I', 'n', 'd', 'e', 'n', 't', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'T', 'o', 'I', 'd', 'e', 'n', 't', 'i', 't', 'y', 0,
    's', 'e', 't', 'T', 'o', 'p', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    's', 'e', 't', 'W', 'h', 'i', 't', 'e', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'I', 'c', 'o', 'n', 0,
    's', 'h', 'o', 'w', 'M', 'a', 'x', 'i', 'm', 'i', 'z', 'e', 'd', 0,
    's', 'h', 'o', 'w', 'M', 'i', 'n', 'i', 'm', 'i', 'z', 'e', 'd', 0,
    's', 'i', 'z', 'e', 'I', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 0,
    's', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'S', 'i', 'z', 'e', 's', 0,
    's', 't', 'a', 'r', 't', 'D', 'r', 'a', 'g', 'T', 'i', 'm', 'e', 0,
    's', 't', 'r', 'i', 'n', 'g', 'I', 'n', 'd', 'e', 'x', 'e', 's', 0,
    's', 't', 'y', 'l', 'e', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 's', 0,
    't', 'a', 'r', 'g', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    't', 'e', 'x', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    't', 'o', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'o', 'E', 'u', 'l', 'e', 'r', 'A', 'n', 'g', 'l', 'e', 's', 0,
    't', 'o', 'E', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'R', 'g', 'b', 0,
    't', 'o', 'F', 'i', 'l', 'l', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    't', 'o', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'o', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'o', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'o', 'T', 'a', 'b', 'l', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'M', 'o', 'd', 'e', 0,
    'u', 'n', 'd', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'w', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 0,
    'A', 'f', 'r', 'i', 'c', 'a', 'n', 'F', 'i', 'e', 'l', 'd', 0,
    'A', 'l', 'c', 'h', 'e', 'm', 'i', 's', 't', 'L', 'a', 'b', 0,
    'A', 'l', 'l', 'L', 'o', 'w', 'e', 'r', 'c', 'a', 's', 'e', 0,
    'A', 'l', 'l', 'U', 'p', 'p', 'e', 'r', 'c', 'a', 's', 'e', 0,
    'A', 'q', 'u', 'a', 'G', 'u', 'i', 'd', 'a', 'n', 'c', 'e', 0,
    'C', 'o', 'r', 'e', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 0,
    'C', 'r', 'y', 's', 't', 'a', 'l', 'R', 'i', 'v', 'e', 'r', 0,
    'D', 'e', 'b', 'u', 'g', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'D', 'e', 'l', 'i', 'm', 'i', 't', 'e', 'r', 'T', 'a', 'b', 0,
    'D', 'i', 'r', 't', 'y', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'O', 'p', 'e', 'n', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'S', 'a', 'v', 'e', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'S', 'e', 'n', 'd', 0,
    'D', 'o', 'u', 'b', 'l', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'D', 'r', 'i', 'v', 'e', 'O', 'p', 't', 'i', 'c', 'a', 'l', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '1', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '2', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '3', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '4', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '5', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '6', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '7', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '8', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '9', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'Y', 'o', 'u', '4', 0,
    'F', 'a', 'b', 'l', 'e', 'd', 'S', 'u', 'n', 's', 'e', 't', 0,
    'F', 'a', 'r', 'a', 'w', 'a', 'y', 'R', 'i', 'v', 'e', 'r', 0,
    'F', 'i', 'l', 'e', 'I', 'c', 'o', 'n', 'R', 'o', 'l', 'e', 0,
    'F', 'i', 'l', 'e', 'I', 'n', 'f', 'o', 'R', 'o', 'l', 'e', 0,
    'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 'R', 'o', 'l', 'e', 0,
    'F', 'i', 'l', 'e', 'P', 'a', 't', 'h', 'R', 'o', 'l', 'e', 0,
    'F', 'i', 'n', 'd', 'B', 'a', 'c', 'k', 'w', 'a', 'r', 'd', 0,
    'F', 'i', 'n', 'd', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 0,
    'F', 'o', 'r', 'c', 'e', 'O', 'u', 't', 'l', 'i', 'n', 'e', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'B', 'G', 'R', '3', '0', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '1', '6', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '3', '0', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '3', '2', 0,
    'F', 'r', 'a', 'm', 'e', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'F', 'r', 'o', 'z', 'e', 'n', 'D', 'r', 'e', 'a', 'm', 's', 0,
    'F', 'u', 'l', 'l', 'P', 'a', 'g', 'e', 'M', 'o', 'd', 'e', 0,
    'G', 'r', 'a', 's', 's', 'S', 'h', 'a', 'm', 'p', 'o', 'o', 0,
    'H', 'a', 'p', 'p', 'y', 'U', 'n', 'i', 'c', 'o', 'r', 'n', 0,
    'H', 'e', 'a', 'l', 't', 'h', 'y', 'W', 'a', 't', 'e', 'r', 0,
    'H', 'e', 'l', 'p', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'H', 'i', 'd', 'd', 'e', 'n', 'J', 'a', 'g', 'u', 'a', 'r', 0,
    'H', 'i', 'g', 'h', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    'H', 't', 'm', 'l', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'I', 'g', 'n', 'o', 'r', 'e', 's', 'A', 'l', 'p', 'h', 'a', 0,
    'I', 'm', 'a', 'g', 'e', 'A', 'l', 't', 'T', 'e', 'x', 't', 0,
    'I', 'm', 'a', 'g', 'e', 'L', 'o', 'a', 'd', 'i', 'n', 'g', 0,
    'I', 'm', 'a', 'g', 'e', 'M', 'i', 's', 's', 'i', 'n', 'g', 0,
    'I', 'm', 'a', 'g', 'e', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '8', 'x', '1', '0', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '9', 'x', '1', '1', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '9', 'x', '1', '2', 0,
    'I', 'n', 't', 'e', 'r', 'm', 'e', 'd', 'i', 'a', 't', 'e', 0,
    'L', 'a', 'd', 'o', 'g', 'a', 'B', 'o', 't', 't', 'o', 'm', 0,
    'L', 'a', 's', 't', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'L', 'i', 't', 't', 'l', 'e', 'E', 'n', 'd', 'i', 'a', 'n', 0,
    'M', 'a', 'i', 'l', 'M', 'a', 'r', 'k', 'R', 'e', 'a', 'd', 0,
    'M', 'a', 'i', 'l', 'R', 'e', 'p', 'l', 'y', 'A', 'l', 'l', 0,
    'M', 'e', 'd', 'i', 'a', 'O', 'p', 't', 'i', 'c', 'a', 'l', 0,
    'M', 'e', 't', 'a', 'l', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'M', 'o', 'r', 'n', 'i', 'n', 'g', 'S', 'a', 'l', 'a', 'd', 0,
    'M', 'o', 'u', 'n', 't', 'a', 'i', 'n', 'R', 'o', 'c', 'k', 0,
    'N', 'C', 'o', 'l', 'o', 'r', 'G', 'r', 'o', 'u', 'p', 's', 0,
    'N', 'e', 't', 'w', 'o', 'r', 'k', 'W', 'i', 'r', 'e', 'd', 0,
    'N', 'e', 'w', 'R', 'e', 't', 'r', 'o', 'w', 'a', 'v', 'e', 0,
    'N', 'o', 'r', 't', 'h', 'M', 'i', 'r', 'a', 'c', 'l', 'e', 0,
    'P', 'a', 'i', 'n', 't', 'e', 'r', 'P', 'a', 't', 'h', 's', 0,
    'P', 'a', 'r', 't', 'i', 'a', 'l', 'M', 'a', 't', 'c', 'h', 0,
    'P', 'a', 't', 't', 'e', 'r', 'n', 'B', 'r', 'u', 's', 'h', 0,
    'P', 'd', 'm', 'N', 'u', 'm', 'C', 'o', 'l', 'o', 'r', 's', 0,
    'P', 'e', 'r', 'f', 'e', 'c', 't', 'W', 'h', 'i', 't', 'e', 0,
    'P', 'h', 'o', 'e', 'n', 'i', 'x', 'S', 't', 'a', 'r', 't', 0,
    'P', 'o', 'l', 'i', 't', 'e', 'R', 'u', 'm', 'o', 'r', 's', 0,
    'P', 'o', 'l', 'y', 'l', 'i', 'n', 'e', 'M', 'o', 'd', 'e', 0,
    'P', 'o', 'r', 't', 'a', 'b', 'l', 'e', 'T', 'e', 'x', 't', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'B', 'i', 't', 'm', 'a', 'p', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'P', 'r', 'e', 'm', 'i', 'u', 'm', 'W', 'h', 'i', 't', 'e', 0,
    'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'e', 'l', 'l', 0,
    'Q', 'A', 'c', 't', 'i', 'o', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'A', 'c', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', ':', ':', 'S', 'p', 'e', 'c', 0,
    'Q', 'E', 'x', 'p', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'S', 't', 'y', 'l', 'e', 0,
    'Q', 'F', 'o', 'n', 't', 'M', 'e', 't', 'r', 'i', 'c', 's', 0,
    'Q', 'I', 'c', 'o', 'n', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'a', 'd', 'e', 'r', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'W', 'r', 'i', 't', 'e', 'r', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'Q', 'K', 'e', 'y', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'R', 'e', 'c', 't', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 'i', 'z', 'e', '>', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 'P', 'a', 't', 'h', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'P', 'i', 'x', 'm', 'a', 'p', 'C', 'a', 'c', 'h', 'e', 0,
    'Q', 'R', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'S', 'c', 'r', 'o', 'l', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'T', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'U', 'n', 'd', 'o', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    'R', 'e', 'd', 'S', 'a', 'l', 'v', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'e', 'p', 'e', 'a', 't', 'S', 'p', 'r', 'e', 'a', 'd', 0,
    'R', 'e', 's', 't', 'a', 'r', 't', 'N', 'e', 'v', 'e', 'r', 0,
    'S', 'a', 'l', 't', 'M', 'o', 'u', 'n', 't', 'a', 'i', 'n', 0,
    'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'H', 'i', 'g', 'h', 0,
    'S', 'e', 'm', 'i', 'E', 'x', 'p', 'a', 'n', 'd', 'e', 'd', 0,
    'S', 'i', 'n', 'g', 'l', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'S', 'i', 'n', 'g', 'l', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'S', 'o', 'f', 't', 'L', 'i', 'p', 's', 't', 'i', 'c', 'k', 0,
    'S', 'p', 'r', 'i', 'n', 'g', 'W', 'a', 'r', 'm', 't', 'h', 0,
    'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'M', 'o', 'd', 'e', 0,
    'S', 't', 'y', 'l', 'e', 'O', 'b', 'l', 'i', 'q', 'u', 'e', 0,
    'S', 'u', 'n', 'n', 'y', 'M', 'o', 'r', 'n', 'i', 'n', 'g', 0,
    'S', 'w', 'e', 'e', 't', 'D', 'e', 's', 's', 'e', 'r', 't', 0,
    'S', 'y', 's', 't', 'e', 'm', 'L', 'o', 'g', 'O', 'u', 't', 0,
    'S', 'y', 's', 't', 'e', 'm', 'R', 'e', 'b', 'o', 'o', 't', 0,
    'S', 'y', 's', 't', 'e', 'm', 'S', 'e', 'a', 'r', 'c', 'h', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'T', 'a', 'b', 'l', 'o', 'i', 'd', 'E', 'x', 't', 'r', 'a', 0,
    'T', 'e', 'e', 'n', 'N', 'o', 't', 'e', 'b', 'o', 'o', 'k', 0,
    'T', 'r', 'i', 'p', 'l', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'B', 'y', 't', 'e', 0,
    'U', 's', 'e', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'U', 's', 'e', 'r', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'V', 'i', 'd', 'e', 'o', 'D', 'i', 's', 'p', 'l', 'a', 'y', 0,
    'W', 'e', 'a', 't', 'h', 'e', 'r', 'C', 'l', 'e', 'a', 'r', 0,
    'W', 'e', 'a', 't', 'h', 'e', 'r', 'S', 't', 'o', 'r', 'm', 0,
    'W', 'r', 'a', 'p', 'A', 'n', 'y', 'w', 'h', 'e', 'r', 'e', 0,
    'Y', 'o', 'u', 'n', 'g', 'P', 'a', 's', 's', 'i', 'o', 'n', 0,
    '_', '_', 'c', 'o', 'n', 't', 'a', 'i', 'n', 's', '_', '_', 0,
    '_', '_', 'i', 't', 'r', 'u', 'e', 'd', 'i', 'v', '_', '_', 0,
    'a', 'n', 'g', 'l', 'e', 'B', 'e', 't', 'w', 'e', 'e', 'n', 0,
    'a', 'n', 't', 'i', 'q', 'u', 'e', 'w', 'h', 'i', 't', 'e', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'a', 't', 'B', 'l', 'o', 'c', 'k', 'S', 't', 'a', 'r', 't', 0,
    'b', 'i', 't', 's', 'P', 'e', 'r', 'P', 'i', 'x', 'e', 'l', 0,
    'b', 'l', 'o', 'c', 'k', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'b', 'o', 'o', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'b', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'b', 'o', 't', 't', 'o', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'b', 'r', 'u', 's', 'h', 'O', 'r', 'i', 'g', 'i', 'n', 'F', 0,
    'b', 'y', 't', 'e', 's', 'P', 'e', 'r', 'L', 'i', 'n', 'e', 0,
    'c', 'a', 'c', 'h', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'c', 'a', 'n', 'F', 'e', 't', 'c', 'h', 'M', 'o', 'r', 'e', 0,
    'c', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 0,
    'c', 'e', 'n', 't', 'e', 'r', 'R', 'a', 'd', 'i', 'u', 's', 0,
    'c', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'l', 'e', 'a', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'e', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'c', 'l', 'o', 's', 'e', 'S', 'u', 'b', 'p', 'a', 't', 'h', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'c', 'o', 'm', 'm', 'i', 't', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'S', 't', 'r', 'o', 'k', 'e', 0,
    'c', 'r', 'o', 's', 's', 'P', 'r', 'o', 'd', 'u', 'c', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'm', 'a', 'g', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'T', 'a', 'b', 'l', 'e', 0,
    'd', 'a', 'r', 'k', 's', 'e', 'a', 'g', 'r', 'e', 'e', 'n', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'D', 'e', 'p', 't', 'h', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'V', 'a', 'l', 'u', 'e', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'd', 'r', 'a', 'w', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'd', 'r', 'a', 'w', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 0,
    'd', 'r', 'a', 'w', 'P', 'o', 'l', 'y', 'l', 'i', 'n', 'e', 0,
    'd', 'r', 'a', 'w', 'T', 'e', 'x', 't', 'I', 't', 'e', 'm', 0,
    'd', 'r', 'o', 'p', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'e', 'l', 'e', 'm', 'e', 'n', 't', 'C', 'o', 'u', 'n', 't', 0,
    'e', 'n', 'd', 'E', 'd', 'i', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'f', 'e', 'a', 't', 'u', 'r', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    'f', 'l', 'a', 'g', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'o', 'c', 'u', 's', 'I', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    'f', 'o', 'n', 't', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'f', 'o', 'n', 't', 'O', 'v', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'f', 'r', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'a', 'm', 'e', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'f', 'r', 'o', 'm', 'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 0,
    'f', 'r', 'o', 'm', 'V', 'e', 'c', 't', 'o', 'r', '3', 'D', 0,
    'g', 'l', 'y', 'p', 'h', 'I', 'n', 'd', 'e', 'x', 'e', 's', 0,
    'g', 'r', 'a', 'b', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'h', 'a', 's', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'h', 'a', 's', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'h', 'a', 's', 'T', 'h', 'e', 'm', 'e', 'I', 'c', 'o', 'n', 0,
    'h', 'e', 'a', 'd', 'i', 'n', 'g', 'L', 'e', 'v', 'e', 'l', 0,
    'i', 'c', 'o', 'n', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    'i', 'n', 'd', 'e', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'i', 'n', 'v', 'e', 'r', 't', 'P', 'i', 'x', 'e', 'l', 's', 0,
    'i', 'n', 'v', 'o', 'k', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'i', 's', 'A', 'n', 'c', 'e', 's', 't', 'o', 'r', 'O', 'f', 0,
    'i', 's', 'A', 'u', 't', 'o', 'R', 'e', 'p', 'e', 'a', 't', 0,
    'i', 's', 'B', 'e', 'g', 'i', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'S', 'e', 't', 0,
    'i', 's', 'F', 'i', 'x', 'e', 'd', 'P', 'i', 't', 'c', 'h', 0,
    'i', 's', 'I', 'n', 'v', 'e', 'r', 't', 'i', 'b', 'l', 'e', 0,
    'i', 's', 'L', 'i', 's', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'S', 'e', 'l', 'e', 'c', 't', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    'l', 'a', 's', 't', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', 0,
    'l', 'a', 's', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'l', 'e', 'm', 'o', 'n', 'c', 'h', 'i', 'f', 'f', 'o', 'n', 0,
    'l', 'i', 'g', 'h', 't', 's', 'k', 'y', 'b', 'l', 'u', 'e', 0,
    'l', 'i', 's', 't', 'T', 'o', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'l', 'o', 'a', 'd', 'F', 'r', 'o', 'm', 'D', 'a', 't', 'a', 0,
    'l', 'o', 'a', 'd', 'F', 'r', 'o', 'm', 'F', 'i', 'l', 'e', 0,
    'l', 'o', 'a', 'd', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'm', 'a', 'j', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'm', 'a', 'n', 'u', 'f', 'a', 'c', 't', 'u', 'r', 'e', 'r', 0,
    'm', 'a', 'p', 'T', 'o', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    'm', 'a', 'x', 'C', 'h', 'a', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'V', 'a', 'l', 'u', 'e', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 'o', 'r', 'c', 'h', 'i', 'd', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 'p', 'u', 'r', 'p', 'l', 'e', 0,
    'm', 'i', 'd', 'n', 'i', 'g', 'h', 't', 'b', 'l', 'u', 'e', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'V', 'a', 'l', 'u', 'e', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 0,
    'm', 'i', 'n', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'm', 'o', 'u', 's', 'e', 'B', 'u', 't', 't', 'o', 'n', 's', 0,
    'm', 'o', 'v', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'n', 'u', 'm', 'b', 'e', 'r', 'P', 'r', 'e', 'f', 'i', 'x', 0,
    'n', 'u', 'm', 'b', 'e', 'r', 'S', 'u', 'f', 'f', 'i', 'x', 0,
    'o', 'u', 't', 'p', 'u', 't', 'I', 'n', 't', 'e', 'n', 't', 0,
    'p', 'a', 't', 'h', 'F', 'o', 'r', 'G', 'l', 'y', 'p', 'h', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'X', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'Y', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'S', 'i', 'z', 'e', 0,
    'p', 'l', 'a', 't', 'f', 'o', 'r', 'm', 'N', 'a', 'm', 'e', 0,
    'q', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'y', 0,
    'q', 'u', 'a', 'd', 'T', 'o', 'S', 'q', 'u', 'a', 'r', 'e', 0,
    'r', 'e', 'g', 'i', 's', 't', 'r', 'y', 'N', 'a', 'm', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'r', 'e', 's', 'e', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'r', 'i', 'g', 'h', 't', 'B', 'e', 'a', 'r', 'i', 'n', 'g', 0,
    'r', 'i', 'g', 'h', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'T', 'e', 'x', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'E', 'n', 'd', 0,
    's', 'e', 'r', 'i', 'a', 'l', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    's', 'e', 't', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'C', 'a', 'c', 'h', 'e', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'C', 'h', 'e', 'c', 'k', 'a', 'b', 'l', 'e', 0,
    's', 'e', 't', 'E', 'x', 'c', 'l', 'u', 's', 'i', 'v', 'e', 0,
    's', 'e', 't', 'F', 'i', 'n', 'a', 'l', 'S', 't', 'o', 'p', 0,
    's', 'e', 't', 'J', 'o', 'i', 'n', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'P', 'i', 'x', 'e', 'l', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'P', 'r', 'i', 'm', 'a', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 0,
    's', 'e', 't', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 's', 0,
    's', 'e', 't', 'S', 't', 'a', 't', 'u', 's', 'T', 'i', 'p', 0,
    's', 'e', 't', 'S', 't', 'r', 'i', 'k', 'e', 'O', 'u', 't', 0,
    's', 'e', 't', 'S', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'S', 't', 'y', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'T', 'h', 'e', 'm', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'T', 'o', 'p', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'U', 'n', 'd', 'o', 'L', 'i', 'm', 'i', 't', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'W', 'h', 'a', 't', 's', 'T', 'h', 'i', 's', 0,
    's', 'h', 'a', 'r', 'e', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    's', 'o', 'r', 't', 'C', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'S', 't', 'r', 'i', 'n', 'g', 0,
    's', 'q', 'u', 'a', 'r', 'e', 'T', 'o', 'Q', 'u', 'a', 'd', 0,
    's', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 't', 'r', 'i', 'k', 'e', 'O', 'u', 't', 'P', 'o', 's', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'C', 'l', 'a', 's', 's', 0,
    's', 'w', 'a', 'p', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    's', 'w', 'a', 'p', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    't', 'a', 'b', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    't', 'e', 'x', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    't', 'o', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'o', 'L', 'i', 's', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'P', 'o', 's', 0,
    'u', 'n', 's', 'e', 't', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'v', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'A', 'x', 'e', 's', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'S', 'i', 'z', 'e', 0,
    'w', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 's', 0,
    'A', 'b', 'o', 'u', 't', 'Q', 't', 'R', 'o', 'l', 'e', 0,
    'A', 'b', 'o', 'v', 'e', 'T', 'h', 'e', 'S', 'k', 'y', 0,
    'A', 'l', 'i', 'g', 'n', 'B', 'o', 't', 't', 'o', 'm', 0,
    'A', 'l', 'i', 'g', 'n', 'M', 'i', 'd', 'd', 'l', 'e', 0,
    'A', 'l', 'i', 'g', 'n', 'N', 'o', 'r', 'm', 'a', 'l', 0,
    'A', 'l', 'l', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'A', 't', 'B', 'e', 'g', 'i', 'n', 'n', 'i', 'n', 'g', 0,
    'A', 'w', 'e', 's', 'o', 'm', 'e', 'P', 'i', 'n', 'e', 0,
    'B', 'l', 'o', 'c', 'k', 'I', 'n', 'd', 'e', 'n', 't', 0,
    'B', 'l', 'o', 'c', 'k', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    'B', 'r', 'u', 's', 'h', 'S', 't', 'r', 'o', 'k', 'e', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'h', 'o', 't', 'o', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'V', 'i', 'd', 'e', 'o', 0,
    'C', 'l', 'e', 'a', 'n', 'M', 'i', 'r', 'r', 'o', 'r', 0,
    'C', 'l', 'o', 'u', 'd', 'y', 'A', 'p', 'p', 'l', 'e', 0,
    'C', 'o', 'c', 'h', 'i', 't', 'i', 'L', 'a', 'k', 'e', 0,
    'C', 'o', 'l', 'd', 'E', 'v', 'e', 'n', 'i', 'n', 'g', 0,
    'C', 'o', 'r', 'e', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'C', 'r', 'y', 's', 't', 'a', 'l', 'l', 'i', 'n', 'e', 0,
    'D', 'a', 'r', 'k', 'M', 'a', 'g', 'e', 'n', 't', 'a', 0,
    'D', 'a', 's', 'h', 'D', 'o', 't', 'L', 'i', 'n', 'e', 0,
    'D', 'e', 'v', 'i', 'c', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'D', 'i', 'a', 'l', 'o', 'g', 'E', 'r', 'r', 'o', 'r', 0,
    'D', 'i', 'r', 't', 'y', 'B', 'e', 'a', 'u', 't', 'y', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'N', 'e', 'w', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'U', 'r', 'l', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '6', '5', 0,
    'F', 'e', 'b', 'r', 'u', 'a', 'r', 'y', 'I', 'n', 'k', 0,
    'F', 'i', 'x', 'e', 'd', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'F', 'i', 'x', 'e', 'd', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'F', 'l', 'y', 'i', 'n', 'g', 'L', 'e', 'm', 'o', 'n', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'M', 'o', 'n', 'o', 0,
    'F', 'r', 'a', 'm', 'e', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'F', 'r', 'a', 'm', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'F', 'r', 'a', 'm', 'e', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'F', 'r', 'o', 'n', 't', 'M', 'a', 't', 't', 'e', 'r', 0,
    'F', 'r', 'o', 'z', 'e', 'n', 'B', 'e', 'r', 'r', 'y', 0,
    'G', 'a', 'g', 'a', 'r', 'i', 'n', 'V', 'i', 'e', 'w', 0,
    'G', 'e', 'n', 'e', 'r', 'a', 'l', 'F', 'o', 'n', 't', 0,
    'H', 'a', 'p', 'p', 'y', 'F', 'i', 's', 'h', 'e', 'r', 0,
    'H', 'e', 'a', 'v', 'e', 'n', 'P', 'e', 'a', 'c', 'h', 0,
    'I', 'm', 'a', 'g', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'I', 'm', 'a', 'g', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '7', 'x', '9', 0,
    'I', 'n', 'p', 'u', 't', 'G', 'a', 'm', 'i', 'n', 'g', 0,
    'I', 'n', 'p', 'u', 't', 'T', 'a', 'b', 'l', 'e', 't', 0,
    'I', 'n', 's', 'e', 'r', 't', 'I', 'm', 'a', 'g', 'e', 0,
    'L', 'e', 't', 't', 'e', 'r', 'E', 'x', 't', 'r', 'a', 0,
    'L', 'e', 't', 't', 'e', 'r', 'S', 'm', 'a', 'l', 'l', 0,
    'L', 'i', 'n', 'k', 'V', 'i', 's', 'i', 't', 'e', 'd', 0,
    'L', 'i', 's', 't', 'D', 'e', 'c', 'i', 'm', 'a', 'l', 0,
    'L', 'o', 'g', 'i', 'c', 'a', 'l', 'M', 'o', 'd', 'e', 0,
    'L', 'o', 'w', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    'M', 'a', 'i', 'l', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'M', 'a', 'i', 'l', 'R', 'e', 'p', 'l', 'i', 'e', 'd', 0,
    'M', 'a', 'l', 'i', 'b', 'u', 'B', 'e', 'a', 'c', 'h', 0,
    'M', 'a', 's', 'k', 'e', 'd', 'B', 'r', 'u', 's', 'h', 0,
    'M', 'e', 'd', 'i', 'a', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'M', 'o', 'r', 'p', 'h', 'e', 'u', 's', 'D', 'e', 'n', 0,
    'N', 'C', 'o', 'l', 'o', 'r', 'R', 'o', 'l', 'e', 's', 0,
    'N', 'o', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 0,
    'N', 'o', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'N', 'o', 'r', 's', 'e', 'B', 'e', 'a', 'u', 't', 'y', 0,
    'O', 'd', 'd', 'E', 'v', 'e', 'n', 'M', 'o', 'd', 'e', 0,
    'O', 'r', 'a', 'n', 'g', 'e', 'J', 'u', 'i', 'c', 'e', 0,
    'P', 'a', 'i', 'n', 't', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'P', 'd', 'm', 'H', 'e', 'i', 'g', 'h', 't', 'M', 'M', 0,
    'P', 'e', 'r', 'f', 'e', 'c', 't', 'B', 'l', 'u', 'e', 0,
    'P', 'i', 'x', 'e', 'l', 'S', 'c', 'r', 'o', 'l', 'l', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'M', 'a', 't', 'c', 'h', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', 0,
    'P', 'r', 'e', 'm', 'i', 'u', 'm', 'D', 'a', 'r', 'k', 0,
    'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'R', 'o', 'w', 0,
    'P', 'r', 'o', 'P', 'h', 'o', 't', 'o', 'R', 'g', 'b', 0,
    'P', 'r', 'o', 'c', 'e', 's', 's', 'S', 't', 'o', 'p', 0,
    'P', 'y', 'Q', 't', '6', '.', 'Q', 't', 'G', 'u', 'i', 0,
    'Q', 'C', 'l', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'Q', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'E', 'v', 'e', 'n', 't', 'P', 'o', 'i', 'n', 't', 0,
    'Q', 'F', 'o', 'c', 'u', 's', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'H', 'o', 'v', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'I', 'c', 'o', 'n', ':', ':', 'M', 'o', 'd', 'e', 0,
    'Q', 'I', 'c', 'o', 'n', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'M', 'o', 'u', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'Q', 'P', 'a', 'g', 'e', 'R', 'a', 'n', 'g', 'e', 's', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'Q', 'u', 'a', 't', 'e', 'r', 'n', 'i', 'o', 'n', 0,
    'Q', 'S', 't', 'a', 't', 'i', 'c', 'T', 'e', 'x', 't', 0,
    'Q', 'S', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'T', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'W', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'R', 'e', 't', 'r', 'i', 'e', 'v', 'e', 'A', 'l', 'l', 0,
    'R', 'i', 'p', 'e', 'M', 'a', 'l', 'i', 'n', 'k', 'a', 0,
    'R', 'o', 'y', 'a', 'l', 'G', 'a', 'r', 'd', 'e', 'n', 0,
    'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'L', 'o', 'w', 0,
    'S', 'm', 'a', 'r', 't', 'I', 'n', 'd', 'i', 'g', 'o', 0,
    'S', 'm', 'i', 'l', 'i', 'n', 'g', 'R', 'a', 'i', 'n', 0,
    'S', 'o', 'f', 't', 'C', 'h', 'e', 'r', 'i', 's', 'h', 0,
    'S', 't', 'r', 'o', 'n', 'g', 'B', 'l', 'i', 's', 's', 0,
    'S', 't', 'r', 'o', 'n', 'g', 'S', 't', 'i', 'c', 'k', 0,
    'S', 't', 'y', 'l', 'e', 'I', 't', 'a', 'l', 'i', 'c', 0,
    'S', 't', 'y', 'l', 'e', 'N', 'o', 'r', 'm', 'a', 'l', 0,
    'S', 'u', 'm', 'm', 'e', 'r', 'G', 'a', 'm', 'e', 's', 0,
    'S', 'w', 'e', 'e', 't', 'P', 'e', 'r', 'i', 'o', 'd', 0,
    'T', 'a', 'b', 'l', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'T', 'e', 'x', 't', 'T', 'o', 'o', 'l', 'T', 'i', 'p', 0,
    'T', 'o', 'o', 'l', 'T', 'i', 'p', 'B', 'a', 's', 'e', 0,
    'T', 'o', 'o', 'l', 'T', 'i', 'p', 'T', 'e', 'x', 't', 0,
    'T', 'o', 'u', 'c', 'h', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'T', 'x', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 0,
    'U', 'n', 's', 't', 'r', 'e', 't', 'c', 'h', 'e', 'd', 0,
    'U', 's', 'e', 'r', 'O', 'f', 'f', 'l', 'i', 'n', 'e', 0,
    'V', 'i', 'e', 'w', 'R', 'e', 'f', 'r', 'e', 's', 'h', 0,
    'V', 'i', 'e', 'w', 'R', 'e', 's', 't', 'o', 'r', 'e', 0,
    'W', 'e', 'a', 't', 'h', 'e', 'r', 'S', 'n', 'o', 'w', 0,
    'W', 'i', 'n', 'd', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'W', 'i', 'n', 'd', 'o', 'w', 'C', 'l', 'o', 's', 'e', 0,
    'Z', 'e', 'u', 's', 'M', 'i', 'r', 'a', 'c', 'l', 'e', 0,
    'Z', 'o', 'o', 'm', 'F', 'i', 't', 'B', 'e', 's', 't', 0,
    '_', '_', 'd', 'e', 'l', 'i', 't', 'e', 'm', '_', '_', 0,
    '_', '_', 'g', 'e', 't', 'i', 't', 'e', 'm', '_', '_', 0,
    '_', '_', 'i', 'm', 'a', 't', 'm', 'u', 'l', '_', '_', 0,
    '_', '_', 's', 'e', 't', 'i', 't', 'e', 'm', '_', '_', 0,
    '_', '_', 't', 'r', 'u', 'e', 'd', 'i', 'v', '_', '_', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'S', 't', 'a', 'c', 'k', 0,
    'a', 'd', 'd', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 'N', 'a', 'm', 'e', 's', 0,
    'b', 'e', 'g', 'i', 'n', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'b', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'b', 'l', 'o', 'c', 'k', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'b', 'r', 'u', 's', 'h', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    'b', 'u', 't', 't', 'o', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'e', 'l', 'l', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'c', 'e', 'l', 'l', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'A', 't', 0,
    'c', 'h', 'i', 'l', 'd', 'F', 'r', 'a', 'm', 'e', 's', 0,
    'c', 'l', 'e', 'a', 'n', 'u', 'p', 'I', 'n', 'f', 'o', 0,
    'c', 'l', 'e', 'a', 'r', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'c', 'o', 'l', 'o', 'r', 'S', 'c', 'h', 'e', 'm', 'e', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'P', 'a', 't', 'h', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'e', 'd', 'T', 'o', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'L', 'i', 's', 't', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'a', 'r', 'k', 'm', 'a', 'g', 'e', 'n', 't', 'a', 0,
    'd', 'a', 's', 'h', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'd', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'e', 'p', 's', 'k', 'y', 'b', 'l', 'u', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'o', 'n', 't', 0,
    'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'n', 't', 0,
    'd', 'o', 'n', 'e', 'C', 'u', 'r', 'r', 'e', 'n', 't', 0,
    'd', 'r', 'a', 'w', 'E', 'l', 'l', 'i', 'p', 's', 'e', 0,
    'd', 'r', 'a', 'w', 'P', 'i', 'c', 't', 'u', 'r', 'e', 0,
    'd', 'r', 'a', 'w', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    'e', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'e', 'x', 'p', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'e', 'a', 't', 'u', 'r', 'e', 'T', 'a', 'g', 's', 0,
    'f', 'i', 'l', 'e', 'R', 'e', 'n', 'a', 'm', 'e', 'd', 0,
    'f', 'i', 'n', 'g', 'e', 'r', 'C', 'o', 'u', 'n', 't', 0,
    'f', 'l', 'o', 'r', 'a', 'l', 'w', 'h', 'i', 't', 'e', 0,
    'f', 'o', 'c', 'a', 'l', 'R', 'a', 'd', 'i', 'u', 's', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'f', 'o', 'c', 'u', 's', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'f', 'o', 'n', 't', 'K', 'e', 'r', 'n', 'i', 'n', 'g', 0,
    'f', 'o', 'n', 't', 'M', 'e', 't', 'r', 'i', 'c', 's', 0,
    'f', 'o', 'n', 't', 'S', 't', 'r', 'e', 't', 'c', 'h', 0,
    'f', 'o', 'r', 'e', 's', 't', 'g', 'r', 'e', 'e', 'n', 0,
    'f', 'o', 'r', 'm', 'a', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'f', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'g', 'e', 's', 't', 'u', 'r', 'e', 'T', 'y', 'p', 'e', 0,
    'g', 'r', 'e', 'e', 'n', 'y', 'e', 'l', 'l', 'o', 'w', 0,
    'h', 'a', 's', 'C', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 0,
    'h', 'a', 's', 'C', 'l', 'i', 'p', 'p', 'i', 'n', 'g', 0,
    'h', 'a', 's', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'i', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 'n', 'd', 'e', 'n', 't', 'W', 'i', 'd', 't', 'h', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'i', 'n', 's', 'e', 'r', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'i', 'n', 's', 'e', 'r', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 'I', 'm', 'a', 'g', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 'T', 'a', 'b', 'l', 'e', 0,
    'i', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'i', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', 'e', 'd', 0,
    'i', 's', 'A', 'm', 'b', 'i', 'g', 'u', 'o', 'u', 's', 0,
    'i', 's', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'n', 'g', 0,
    'i', 's', 'C', 'h', 'e', 'c', 'k', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'E', 'x', 'c', 'l', 'u', 's', 'i', 'v', 'e', 0,
    'i', 's', 'G', 'r', 'a', 'y', 's', 'c', 'a', 'l', 'e', 0,
    'i', 's', 'L', 'a', 'n', 'd', 's', 'c', 'a', 'p', 'e', 0,
    'i', 's', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 0,
    'i', 't', 'e', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'j', 'u', 'm', 'p', 'T', 'o', 'F', 'r', 'a', 'm', 'e', 0,
    'j', 'u', 'm', 'p', 'T', 'o', 'I', 'm', 'a', 'g', 'e', 0,
    'k', 'e', 'y', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 's', 0,
    'l', 'a', 's', 't', 'I', 'n', 'd', 'e', 'x', 'O', 'f', 0,
    'l', 'e', 'f', 't', 'B', 'e', 'a', 'r', 'i', 'n', 'g', 0,
    'l', 'e', 'f', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'l', 'i', 'g', 'h', 't', 's', 'a', 'l', 'm', 'o', 'n', 0,
    'l', 'i', 'g', 'h', 't', 'y', 'e', 'l', 'l', 'o', 'w', 0,
    'l', 'i', 'n', 'e', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'l', 'i', 'n', 'k', 'V', 'i', 's', 'i', 't', 'e', 'd', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'X', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'Y', 0,
    'm', 'a', 'g', 'e', 'n', 't', 'a', 'S', 'i', 'z', 'e', 0,
    'm', 'a', 'k', 'e', 'C', 'u', 'r', 'r', 'e', 'n', 't', 0,
    'm', 'a', 'p', 'T', 'o', 'G', 'l', 'o', 'b', 'a', 'l', 0,
    'm', 'a', 't', 'c', 'h', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 0,
    'm', 'o', 'd', 'a', 'l', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'n', 'a', 'm', 'e', 'F', 'i', 'l', 't', 'e', 'r', 's', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'n', 'a', 'v', 'a', 'j', 'o', 'w', 'h', 'i', 't', 'e', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'o', 'v', 'e', 'r', 'l', 'i', 'n', 'e', 'P', 'o', 's', 0,
    'p', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'p', 'a', 'i', 'n', 't', 'd', 'e', 'v', 'i', 'c', 'e', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'p', 'e', 'n', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'p', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', 0,
    'p', 'e', 'r', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 0,
    'p', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'p', 'o', 'i', 'n', 't', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'r', 'e', 'f', 'r', 'e', 's', 'h', 'R', 'a', 't', 'e', 0,
    'r', 'e', 'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'S', 't', 'a', 'c', 'k', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'F', 'l', 'a', 'g', 's', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 's', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'e', 's', 't', 'a', 'r', 't', 'H', 'i', 'n', 't', 0,
    'r', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'r', 'i', 'g', 'h', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'a', 'd', 'd', 'l', 'e', 'b', 'r', 'o', 'w', 'n', 0,
    's', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'F', 0,
    's', 'c', 'r', 'e', 'e', 'n', 'A', 'd', 'd', 'e', 'd', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 'p', 't', 'e', 'd', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'C', 'a', 'p', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 'p', 'i', 'n', 'g', 0,
    's', 'e', 't', 'C', 'o', 's', 'm', 'e', 't', 'i', 'c', 0,
    's', 'e', 't', 'D', 'e', 'c', 'i', 'm', 'a', 'l', 's', 0,
    's', 'e', 't', 'D', 'i', 's', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'E', 'd', 'i', 't', 'a', 'b', 'l', 'e', 0,
    's', 'e', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    's', 'e', 't', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'F', 'i', 'l', 'e', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'F', 'i', 'l', 'l', 'R', 'u', 'l', 'e', 0,
    's', 'e', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    's', 'e', 't', 'I', 'c', 'o', 'n', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 0,
    's', 'e', 't', 'M', 'e', 'n', 'u', 'R', 'o', 'l', 'e', 0,
    's', 'e', 't', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'M', 'o', 'd', 'a', 'l', 'i', 't', 'y', 0,
    's', 'e', 't', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', 0,
    's', 'e', 't', 'N', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'O', 'b', 's', 'o', 'l', 'e', 't', 'e', 0,
    's', 'e', 't', 'O', 'v', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    's', 'e', 't', 'R', 'e', 'v', 'i', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'R', 'o', 'o', 't', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'R', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 0,
    's', 'e', 't', 'S', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'S', 'o', 'r', 't', 'R', 'o', 'l', 'e', 0,
    's', 'e', 't', 'T', 'a', 'b', 'A', 'r', 'r', 'a', 'y', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    's', 'e', 't', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    's', 'i', 'z', 'e', 'I', 'n', 'B', 'y', 't', 'e', 's', 0,
    's', 'm', 'o', 'o', 't', 'h', 'S', 'i', 'z', 'e', 's', 0,
    's', 't', 'y', 'l', 'e', 'S', 't', 'r', 'i', 'n', 'g', 0,
    's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'e', 's', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'w', 'a', 'p', 'B', 'u', 'f', 'f', 'e', 'r', 's', 0,
    't', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    't', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    't', 'e', 'x', 't', 'O', 'u', 't', 'l', 'i', 'n', 'e', 0,
    't', 'o', 'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    't', 'o', 'R', 'a', 'n', 'g', 'e', 'L', 'i', 's', 't', 0,
    't', 'o', 'o', 'l', 'T', 'i', 'p', 'B', 'a', 's', 'e', 0,
    't', 'o', 'o', 'l', 'T', 'i', 'p', 'T', 'e', 'x', 't', 0,
    't', 'o', 'u', 'c', 'h', 'P', 'o', 'i', 'n', 't', 's', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'e', 'd', 0,
    'u', 'n', 's', 'e', 't', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'B', 'l', 'o', 'c', 'k', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'S', 't', 'a', 't', 'e', 0,
    'v', 'i', 'r', 't', 'u', 'a', 'l', 'S', 'i', 'z', 'e', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 0,
    'w', 'o', 'r', 'd', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'y', 'e', 'l', 'l', 'o', 'w', 'g', 'r', 'e', 'e', 'n', 0,
    'A', 'c', 'c', 'e', 'p', 't', 'a', 'b', 'l', 'e', 0,
    'A', 'l', 'l', 'D', 'e', 'v', 'i', 'c', 'e', 's', 0,
    'A', 'l', 'p', 'h', 'a', 'B', 'l', 'e', 'n', 'd', 0,
    'A', 'm', 'o', 'u', 'r', 'A', 'm', 'o', 'u', 'r', 0,
    'A', 'n', 'c', 'h', 'o', 'r', 'N', 'a', 'm', 'e', 0,
    'A', 'n', 'y', 'S', 't', 'r', 'e', 't', 'c', 'h', 0,
    'A', 'q', 'u', 'a', 'S', 'p', 'l', 'a', 's', 'h', 0,
    'B', 'a', 't', 't', 'e', 'r', 'y', 'L', 'o', 'w', 0,
    'B', 'l', 'e', 'n', 'd', 'M', 'o', 'd', 'e', 's', 0,
    'B', 'r', 'i', 'g', 'h', 't', 'T', 'e', 'x', 't', 0,
    'B', 'u', 't', 't', 'o', 'n', 'T', 'e', 'x', 't', 0,
    'C', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'e', 0,
    'C', 'o', 'n', 't', 'a', 'c', 't', 'N', 'e', 'w', 0,
    'C', 'o', 'n', 'v', 'e', 'x', 'M', 'o', 'd', 'e', 0,
    'D', 'a', 'r', 'k', 'Y', 'e', 'l', 'l', 'o', 'w', 0,
    'D', 'e', 'c', 'o', 'r', 'a', 't', 'i', 'v', 'e', 0,
    'D', 'e', 'e', 'p', 'R', 'e', 'l', 'i', 'e', 'f', 0,
    'D', 'e', 'n', 's', 'e', 'W', 'a', 't', 'e', 'r', 0,
    'D', 'e', 's', 'e', 'r', 't', 'H', 'u', 'm', 'p', 0,
    'D', 'e', 'v', 'a', 'n', 'a', 'g', 'a', 'r', 'i', 0,
    'D', 'i', 'r', 't', 'y', 'B', 'r', 'u', 's', 'h', 0,
    'D', 'i', 'r', 't', 'y', 'H', 'i', 'n', 't', 's', 0,
    'D', 'u', 's', 't', 'y', 'G', 'r', 'a', 's', 's', 0,
    'E', 'd', 'i', 't', 'D', 'e', 'l', 'e', 't', 'e', 0,
    'E', 'n', 'd', 'i', 'a', 'n', 'n', 'e', 's', 's', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', '1', '0', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', '1', '1', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', '1', '2', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', '1', '4', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'B', '4', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'B', '5', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'B', '6', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '0', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '1', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '2', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '3', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '4', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '5', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '6', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '7', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'D', 'L', 0,
    'E', 'x', 'a', 'c', 't', 'M', 'a', 't', 'c', 'h', 0,
    'E', 'x', 't', 'r', 'a', 'L', 'i', 'g', 'h', 't', 0,
    'F', 'l', 'o', 'a', 't', 'R', 'i', 'g', 'h', 't', 0,
    'F', 'o', 'l', 'd', 'e', 'r', 'O', 'p', 'e', 'n', 0,
    'F', 'o', 'r', 'e', 's', 't', 'I', 'n', 'e', 'i', 0,
    'F', 'r', 'a', 'm', 'e', 'W', 'i', 'd', 't', 'h', 0,
    'F', 'r', 'e', 's', 'h', 'O', 'a', 's', 'i', 's', 0,
    'F', 'r', 'o', 'z', 'e', 'n', 'H', 'e', 'a', 't', 0,
    'F', 'r', 'u', 'i', 't', 'B', 'l', 'e', 'n', 'd', 0,
    'F', 'u', 'z', 'z', 'y', 'M', 'a', 't', 'c', 'h', 0,
    'G', 'e', 'n', 't', 'l', 'e', 'C', 'a', 'r', 'e', 0,
    'G', 'l', 'a', 's', 's', 'W', 'a', 't', 'e', 'r', 0,
    'G', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 0,
    'G', 'r', 'e', 'a', 't', 'W', 'h', 'a', 'l', 'e', 0,
    'G', 'r', 'o', 'w', 'n', 'E', 'a', 'r', 'l', 'y', 0,
    'H', 'i', 'g', 'h', 'F', 'l', 'i', 'g', 'h', 't', 0,
    'I', 'm', 'a', 'g', 'e', 'T', 'i', 't', 'l', 'e', 0,
    'I', 'm', 'a', 'g', 'e', 'W', 'i', 'd', 't', 'h', 0,
    'I', 'n', 'p', 'u', 't', 'M', 'o', 'u', 's', 'e', 0,
    'I', 'n', 's', 'e', 'r', 't', 'L', 'i', 'n', 'k', 0,
    'I', 'n', 's', 'e', 'r', 't', 'T', 'e', 'x', 't', 0,
    'I', 'n', 'v', 'e', 'r', 't', 'R', 'g', 'b', 'a', 0,
    'I', 's', 'N', 'u', 'l', 'l', 'H', 'o', 'o', 'k', 0,
    'J', 'a', 'p', 'a', 'n', 'B', 'l', 'u', 's', 'h', 0,
    'J', 'u', 'i', 'c', 'y', 'P', 'e', 'a', 'c', 'h', 0,
    'K', 'e', 'e', 'p', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    'L', 'e', 'C', 'o', 'c', 'k', 't', 'a', 'i', 'l', 0,
    'L', 'e', 'g', 'a', 'l', 'E', 'x', 't', 'r', 'a', 0,
    'L', 'e', 't', 't', 'e', 'r', 'P', 'l', 'u', 's', 0,
    'L', 'i', 'l', 'y', 'M', 'e', 'a', 'd', 'o', 'w', 0,
    'L', 'i', 's', 't', 'C', 'i', 'r', 'c', 'l', 'e', 0,
    'L', 'i', 's', 't', 'I', 'n', 'd', 'e', 'n', 't', 0,
    'L', 'i', 's', 't', 'R', 'e', 'm', 'o', 'v', 'e', 0,
    'L', 'i', 's', 't', 'S', 'q', 'u', 'a', 'r', 'e', 0,
    'M', 'a', 'c', 'P', 'r', 'i', 'n', 't', 'e', 'r', 0,
    'M', 'a', 'i', 'l', 'U', 'n', 'r', 'e', 'a', 'd', 0,
    'M', 'a', 'n', 'u', 'a', 'l', 'W', 'r', 'a', 'p', 0,
    'M', 'a', 'r', 'b', 'l', 'e', 'W', 'a', 'l', 'l', 0,
    'M', 'e', 'd', 'i', 'a', 'E', 'j', 'e', 'c', 't', 0,
    'M', 'e', 'd', 'i', 'a', 'F', 'l', 'a', 's', 'h', 0,
    'M', 'i', 'l', 'l', 'i', 'm', 'e', 't', 'e', 'r', 0,
    'M', 'i', 'x', 'e', 'd', 'H', 'o', 'p', 'e', 's', 0,
    'M', 'o', 'v', 'e', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    'N', 'a', 't', 'i', 'v', 'e', 'T', 'e', 'x', 't', 0,
    'N', 'i', 'g', 'h', 't', 'P', 'a', 'r', 't', 'y', 0,
    'N', 'o', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'N', 'o', 't', 'R', 'u', 'n', 'n', 'i', 'n', 'g', 0,
    'N', 'u', 'm', 'P', 'r', 'e', 's', 'e', 't', 's', 0,
    'O', 'b', 'j', 'e', 'c', 't', 'M', 'o', 'd', 'e', 0,
    'O', 'l', 'd', 'E', 'n', 'g', 'l', 'i', 's', 'h', 0,
    'O', 'p', 'a', 'q', 'u', 'e', 'H', 'i', 'n', 't', 0,
    'O', 'u', 't', 'l', 'i', 'n', 'e', 'P', 'e', 'n', 0,
    'P', 'a', 'r', 't', 'y', 'B', 'l', 'i', 's', 's', 0,
    'P', 'd', 'm', 'W', 'i', 'd', 't', 'h', 'M', 'M', 0,
    'P', 'o', 'r', 't', 'e', 'r', 'D', 'u', 'f', 'f', 0,
    'Q', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    'Q', 'D', 'r', 'o', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'T', 'a', 'g', 0,
    'Q', 'H', 'e', 'l', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'H', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '2', 'x', '2', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '2', 'x', '3', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '2', 'x', '4', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '3', 'x', '2', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '3', 'x', '3', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '3', 'x', '4', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '4', 'x', '2', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '4', 'x', '3', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '4', 'x', '4', 0,
    'Q', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'P', 'd', 'f', 'W', 'r', 'i', 't', 'e', 'r', 0,
    'Q', 'S', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'T', 'a', 'b', 'l', 'e', 0,
    'Q', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'Q', 'U', 'n', 'd', 'o', 'G', 'r', 'o', 'u', 'p', 0,
    'Q', 'U', 'n', 'd', 'o', 'S', 't', 'a', 'c', 'k', 0,
    'Q', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', 0,
    'S', 'R', 'g', 'b', 'L', 'i', 'n', 'e', 'a', 'r', 0,
    'S', 'a', 'n', 'd', 'S', 't', 'r', 'i', 'k', 'e', 0,
    'S', 'h', 'a', 'd', 'y', 'W', 'a', 't', 'e', 'r', 0,
    'S', 'h', 'a', 'r', 'p', 'B', 'l', 'u', 'e', 's', 0,
    'S', 'h', 'y', 'R', 'a', 'i', 'n', 'b', 'o', 'w', 0,
    'S', 'o', 'l', 'i', 'd', 'S', 't', 'o', 'n', 'e', 0,
    'S', 'p', 'a', 'c', 'e', 'S', 'h', 'i', 'f', 't', 0,
    'S', 't', 'a', 't', 'i', 'o', 'n', 'a', 'r', 'y', 0,
    'S', 'u', 'p', 'r', 'e', 'm', 'e', 'S', 'k', 'y', 0,
    'T', 'r', 'u', 'e', 'S', 'u', 'n', 's', 'e', 't', 0,
    'T', 'y', 'p', 'e', 'W', 'r', 'i', 't', 'e', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'K', 'e', 'y', 0,
    'U', 's', 'e', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'U', 's', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'V', 'i', 'e', 't', 'n', 'a', 'm', 'e', 's', 'e', 0,
    'W', 'e', 'a', 't', 'h', 'e', 'r', 'F', 'o', 'g', 0,
    'W', 'i', 'd', 'e', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'W', 'i', 'n', 'd', 'o', 'w', 'T', 'e', 'x', 't', 0,
    'W', 'i', 'n', 't', 'e', 'r', 'N', 'e', 'v', 'a', 0,
    'W', 'i', 't', 'c', 'h', 'D', 'a', 'n', 'c', 'e', 0,
    'Y', 'o', 'u', 'n', 'g', 'G', 'r', 'a', 's', 's', 0,
    '_', '_', 'l', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    '_', '_', 'm', 'a', 't', 'm', 'u', 'l', '_', '_', 0,
    '_', '_', 'r', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'T', 'e', 'x', 't', 0,
    'a', 'c', 't', 'u', 'a', 'l', 'S', 'i', 'z', 'e', 0,
    'a', 'd', 'd', 'E', 'l', 'l', 'i', 'p', 's', 'e', 0,
    'a', 'd', 'd', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    'a', 'd', 'j', 'u', 's', 't', 'S', 'i', 'z', 'e', 0,
    'a', 'l', 'l', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'a', 'l', 'l', 'W', 'i', 'n', 'd', 'o', 'w', 's', 0,
    'a', 'l', 'p', 'h', 'a', 'U', 's', 'a', 'g', 'e', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 'H', 'r', 'e', 'f', 0,
    'a', 'n', 'g', 'l', 'e', 'D', 'e', 'l', 't', 'a', 0,
    'a', 'n', 's', 'w', 'e', 'r', 'R', 'e', 'c', 't', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'R', 'o', 'w', 's', 0,
    'a', 'r', 'e', 'S', 'h', 'a', 'r', 'i', 'n', 'g', 0,
    'a', 't', 'B', 'l', 'o', 'c', 'k', 'E', 'n', 'd', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    'a', 'u', 't', 'o', 'R', 'e', 'p', 'e', 'a', 't', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'b', 'e', 'g', 'i', 'n', 'M', 'a', 'c', 'r', 'o', 0,
    'b', 'e', 'g', 'i', 'n', 'P', 'a', 'i', 'n', 't', 0,
    'b', 'l', 'o', 'c', 'k', 'C', 'o', 'u', 'n', 't', 0,
    'b', 'l', 'u', 'e', 'v', 'i', 'o', 'l', 'e', 't', 0,
    'b', 'r', 'i', 'g', 'h', 't', 'T', 'e', 'x', 't', 0,
    'b', 'u', 't', 't', 'o', 'n', 'T', 'e', 'x', 't', 0,
    'c', 'a', 'c', 'h', 'e', 'L', 'i', 'm', 'i', 't', 0,
    'c', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'c', 'h', 'a', 'r', 't', 'r', 'e', 'u', 's', 'e', 0,
    'c', 'h', 'e', 'c', 'k', 'S', 't', 'a', 't', 'e', 0,
    'c', 'h', 'i', 'l', 'd', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'l', 'e', 'a', 'n', 'I', 'n', 'd', 'e', 'x', 0,
    'c', 'l', 'i', 'p', 'R', 'e', 'g', 'i', 'o', 'n', 0,
    'c', 'l', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'o', 'l', 'o', 'r', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 'l', 0,
    'c', 'o', 'l', 'o', 'r', 'N', 'a', 'm', 'e', 's', 0,
    'c', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'c', 'o', 'l', 'o', 'r', 'T', 'a', 'b', 'l', 'e', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'S', 'p', 'a', 'n', 0,
    'c', 'o', 'n', 'j', 'u', 'g', 'a', 't', 'e', 'd', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'P', 'o', 's', 0,
    'c', 'o', 'p', 'y', 'D', 'a', 't', 'a', 'T', 'o', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'L', 'i', 'n', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'L', 'i', 's', 't', 0,
    'd', 'a', 'r', 'k', 'o', 'r', 'a', 'n', 'g', 'e', 0,
    'd', 'a', 'r', 'k', 'o', 'r', 'c', 'h', 'i', 'd', 0,
    'd', 'a', 'r', 'k', 's', 'a', 'l', 'm', 'o', 'n', 0,
    'd', 'a', 'r', 'k', 'v', 'i', 'o', 'l', 'e', 't', 0,
    'd', 'a', 's', 'h', 'O', 'f', 'f', 's', 'e', 't', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'C', 'h', 'a', 'r', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'I', 'd', 0,
    'd', 'o', 'd', 'g', 'e', 'r', 'b', 'l', 'u', 'e', 0,
    'd', 'o', 't', 'P', 'r', 'o', 'd', 'u', 'c', 't', 0,
    'd', 'r', 'a', 'g', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'd', 'r', 'a', 'w', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'd', 'r', 'a', 'w', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'd', 'r', 'a', 'w', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'd', 'r', 'a', 'w', 'P', 'o', 'i', 'n', 't', 's', 0,
    'd', 'r', 'o', 'p', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'e', 'l', 'i', 'd', 'e', 'd', 'T', 'e', 'x', 't', 0,
    'e', 'x', 'a', 'c', 't', 'M', 'a', 't', 'c', 'h', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    'f', 'a', 'm', 'i', 'l', 'y', 'N', 'a', 'm', 'e', 0,
    'f', 'i', 'r', 's', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'f', 'i', 'x', 'e', 'd', 'P', 'i', 't', 'c', 'h', 0,
    'f', 'o', 'c', 'a', 'l', 'P', 'o', 'i', 'n', 't', 0,
    'f', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'f', 'o', 'n', 't', 'I', 't', 'a', 'l', 'i', 'c', 0,
    'f', 'o', 'n', 't', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'f', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'f', 'r', 'a', 'm', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'f', 'r', 'o', 'm', 'A', 'r', 'g', 'b', '3', '2', 0,
    'f', 'r', 'o', 'm', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'f', 'r', 'o', 'm', 'R', 'g', 'b', 'a', '6', '4', 0,
    'f', 'r', 'o', 'm', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'g', 'h', 'o', 's', 't', 'w', 'h', 'i', 't', 'e', 0,
    'g', 'l', 'y', 'p', 'h', 'C', 'o', 'u', 'n', 't', 0,
    'g', 'r', 'a', 'b', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'h', 'a', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'h', 'e', 'a', 'd', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 0,
    'i', 'c', 'c', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'i', 'd', 'e', 'a', 'l', 'W', 'i', 'd', 't', 'h', 0,
    'i', 'm', 'a', 'g', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'i', 'n', 'F', 'o', 'n', 't', 'U', 'c', 's', '4', 0,
    'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 'H', 't', 'm', 'l', 0,
    'i', 'n', 's', 'e', 'r', 't', 'L', 'i', 's', 't', 0,
    'i', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 's', 0,
    'i', 'n', 's', 'e', 'r', 't', 'T', 'e', 'x', 't', 0,
    'i', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', 's', 0,
    'i', 'n', 'v', 'e', 'r', 't', 'i', 'b', 'l', 'e', 0,
    'i', 's', 'A', 'c', 'c', 'e', 'p', 't', 'e', 'd', 0,
    'i', 's', 'B', 'r', 'u', 's', 'h', 'S', 'e', 't', 0,
    'i', 's', 'C', 'o', 's', 'm', 'e', 't', 'i', 'c', 0,
    'i', 's', 'D', 'e', 't', 'a', 'c', 'h', 'e', 'd', 0,
    'i', 's', 'E', 'd', 'i', 't', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'E', 'n', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'I', 'd', 'e', 'n', 't', 'i', 't', 'y', 0,
    'i', 's', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', 0,
    'i', 's', 'O', 'b', 's', 'o', 'l', 'e', 't', 'e', 0,
    'i', 's', 'O', 'p', 'e', 'n', 'G', 'L', 'E', 'S', 0,
    'i', 's', 'P', 'o', 'r', 't', 'r', 'a', 'i', 't', 0,
    'i', 's', 'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    'i', 's', 'R', 'o', 't', 'a', 't', 'i', 'n', 'g', 0,
    'i', 's', 'S', 'c', 'a', 'l', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'T', 'o', 'p', 'L', 'e', 'v', 'e', 'l', 0,
    'i', 't', 'e', 'm', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'l', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'l', 'e', 'f', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'l', 'i', 'g', 'h', 't', 'c', 'o', 'r', 'a', 'l', 0,
    'l', 'i', 'g', 'h', 't', 'g', 'r', 'e', 'e', 'n', 0,
    'l', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 'F', 0,
    'l', 'i', 'n', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'l', 'i', 'n', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'm', 'a', 'p', 'B', 'e', 't', 'w', 'e', 'e', 'n', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 'b', 'l', 'u', 'e', 0,
    'm', 'e', 'r', 'g', 'e', 'C', 'e', 'l', 'l', 's', 0,
    'm', 'i', 'n', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'm', 'i', 't', 'e', 'r', 'L', 'i', 'm', 'i', 't', 0,
    'm', 'y', 'C', 'o', 'm', 'p', 'u', 't', 'e', 'r', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'T', 'y', 'p', 'e', 0,
    'p', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'p', 'a', 'g', 'e', 'R', 'a', 'n', 'g', 'e', 's', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'a', 'p', 'a', 'y', 'a', 'w', 'h', 'i', 'p', 0,
    'p', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'p', 'i', 'x', 'e', 'l', 'C', 'o', 'l', 'o', 'r', 0,
    'p', 'i', 'x', 'e', 'l', 'D', 'e', 'l', 't', 'a', 0,
    'p', 'i', 'x', 'e', 'l', 'I', 'n', 'd', 'e', 'x', 0,
    'p', 'o', 'i', 'n', 't', 'C', 'o', 'u', 'n', 't', 0,
    'p', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 'F', 0,
    'p', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 's', 0,
    'p', 'o', 'w', 'd', 'e', 'r', 'b', 'l', 'u', 'e', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 0,
    'q', 'u', 'a', 'd', 'T', 'o', 'Q', 'u', 'a', 'd', 0,
    'r', 'e', 'c', 't', 'P', 'i', 'x', 'e', 'l', 's', 0,
    'r', 'e', 'c', 't', 'P', 'o', 'i', 'n', 't', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'I', 't', 'e', 'm', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'R', 'o', 'w', 's', 0,
    'r', 'e', 's', 'e', 't', 'C', 'l', 'e', 'a', 'n', 0,
    'r', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'r', 'g', 'b', 'S', 'w', 'a', 'p', 'p', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'T', 'o', 0,
    's', 'a', 'n', 'd', 'y', 'b', 'r', 'o', 'w', 'n', 0,
    's', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'S', 'i', 'z', 'e', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 'I', 'd', 0,
    's', 'e', 's', 's', 'i', 'o', 'n', 'K', 'e', 'y', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'U', 'r', 'l', 0,
    's', 'e', 't', 'C', 'h', 'e', 'c', 'k', 'e', 'd', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'A', 't', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    's', 'e', 't', 'C', 'r', 'e', 'a', 't', 'o', 'r', 0,
    's', 'e', 't', 'D', 'e', 's', 'c', 'e', 'n', 't', 0,
    's', 'e', 't', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    's', 'e', 't', 'H', 'o', 't', 'S', 'p', 'o', 't', 0,
    's', 'e', 't', 'K', 'e', 'r', 'n', 'i', 'n', 'g', 0,
    's', 'e', 't', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    's', 'e', 't', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    's', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'P', 'a', 'l', 'e', 't', 't', 'e', 0,
    's', 'e', 't', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    's', 'e', 't', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    's', 'e', 't', 'R', 'a', 'w', 'F', 'o', 'n', 't', 0,
    's', 'e', 't', 'S', 'a', 'm', 'p', 'l', 'e', 's', 0,
    's', 'e', 't', 'S', 't', 'r', 'e', 't', 'c', 'h', 0,
    's', 'e', 't', 'S', 'u', 'b', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'T', 'o', 'o', 'l', 'T', 'i', 'p', 0,
    's', 'e', 't', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'h', 'a', 'r', 'e', 'G', 'r', 'o', 'u', 'p', 0,
    's', 'h', 'o', 'r', 't', 'c', 'u', 't', 'I', 'd', 0,
    's', 'h', 'o', 'w', 'N', 'o', 'r', 'm', 'a', 'l', 0,
    's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'd', 0,
    's', 'i', 'z', 'e', 'P', 'i', 'x', 'e', 'l', 's', 0,
    's', 'i', 'z', 'e', 'P', 'o', 'i', 'n', 't', 's', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'L', 'e', 'f', 't', 0,
    's', 't', 'r', 'o', 'k', 'e', 'P', 'a', 't', 'h', 0,
    's', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 's', 0,
    's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'e', 0,
    's', 'u', 'b', 't', 'r', 'a', 'c', 't', 'e', 'd', 0,
    's', 'y', 's', 't', 'e', 'm', 'F', 'o', 'n', 't', 0,
    't', 'a', 'k', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    't', 'e', 's', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    't', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'e', 'x', 't', 'I', 'n', 'd', 'e', 'n', 't', 0,
    't', 'e', 'x', 't', 'L', 'e', 'n', 'g', 't', 'h', 0,
    't', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    't', 'o', 'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 0,
    't', 'o', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 'F', 0,
    't', 'o', 'R', 'e', 'v', 'e', 'r', 's', 'e', 'd', 0,
    't', 'o', 'V', 'e', 'c', 't', 'o', 'r', '2', 'D', 0,
    't', 'o', 'V', 'e', 'c', 't', 'o', 'r', '3', 'D', 0,
    't', 'o', 'V', 'e', 'c', 't', 'o', 'r', '4', 'D', 0,
    't', 'o', 'p', 'L', 'e', 'v', 'e', 'l', 'A', 't', 0,
    't', 'o', 'p', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    't', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', 0,
    't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'd', 0,
    't', 'r', 'a', 'n', 's', 'p', 'o', 's', 'e', 'd', 0,
    't', 'r', 'u', 'e', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'u', 'n', 'i', 't', 's', 'P', 'e', 'r', 'E', 'm', 0,
    'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'w', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'w', 'h', 'i', 't', 'e', 'P', 'o', 'i', 'n', 't', 0,
    'w', 'h', 'i', 't', 'e', 's', 'm', 'o', 'k', 'e', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'I', 'c', 'o', 'n', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'T', 'e', 'x', 't', 0,
    'y', 'e', 'l', 'l', 'o', 'w', 'S', 'i', 'z', 'e', 0,
    'A', 'b', 'o', 'u', 't', 'R', 'o', 'l', 'e', 0,
    'A', 'n', 'g', 'e', 'l', 'C', 'a', 'r', 'e', 0,
    'A', 'u', 'd', 'i', 'o', 'C', 'a', 'r', 'd', 0,
    'B', 'a', 'c', 'k', 's', 'p', 'a', 'c', 'e', 0,
    'B', 'i', 'g', 'E', 'n', 'd', 'i', 'a', 'n', 0,
    'B', 't', '2', '1', '0', '0', 'H', 'l', 'g', 0,
    'C', 'a', 'c', 'h', 'e', 'N', 'o', 'n', 'e', 0,
    'C', 'a', 'l', 'l', 'S', 't', 'a', 'r', 't', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'W', 'e', 'b', 0,
    'C', 'e', 'n', 't', 'e', 'r', 'T', 'a', 'b', 0,
    'C', 'h', 'i', 'l', 'd', 'C', 'a', 'r', 'e', 0,
    'D', 'a', 'r', 'k', 'G', 'r', 'e', 'e', 'n', 0,
    'D', 'i', 'r', 't', 'y', 'F', 'o', 'n', 't', 0,
    'D', 'i', 's', 'p', 'l', 'a', 'y', 'P', '3', 0,
    'E', 'd', 'i', 't', 'C', 'l', 'e', 'a', 'r', 0,
    'E', 'd', 'i', 't', 'P', 'a', 's', 't', 'e', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', '9', 0,
    'E', 'x', 'e', 'c', 'u', 't', 'i', 'v', 'e', 0,
    'E', 'x', 't', 'r', 'a', 'B', 'o', 'l', 'd', 0,
    'F', 'a', 'n', 'F', 'o', 'l', 'd', 'U', 'S', 0,
    'F', 'i', 'x', 'e', 'd', 'F', 'o', 'n', 't', 0,
    'F', 'l', 'o', 'a', 't', 'L', 'e', 'f', 't', 0,
    'F', 'o', 'l', 'd', 'e', 'r', 'N', 'e', 'w', 0,
    'F', 'r', 'e', 's', 'h', 'M', 'i', 'l', 'k', 0,
    'H', 'a', 'p', 'p', 'y', 'A', 'c', 'i', 'd', 0,
    'H', 'e', 'a', 'v', 'y', 'R', 'a', 'i', 'n', 0,
    'H', 'e', 'l', 'p', 'A', 'b', 'o', 'u', 't', 0,
    'H', 'e', 'l', 'v', 'e', 't', 'i', 'c', 'a', 0,
    'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 0,
    'I', 'm', 'a', 'g', 'e', 'N', 'a', 'm', 'e', 0,
    'I', 'n', 'v', 'e', 'r', 't', 'R', 'g', 'b', 0,
    'J', 'u', 'i', 'c', 'y', 'C', 'a', 'k', 'e', 0,
    'J', 'u', 'n', 'g', 'l', 'e', 'D', 'a', 'y', 0,
    'K', 'i', 'n', 'd', 'S', 't', 'e', 'e', 'l', 0,
    'L', 'e', 'm', 'o', 'n', 'G', 'a', 't', 'e', 0,
    'L', 'i', 'g', 'h', 't', 'B', 'l', 'u', 'e', 0,
    'L', 'i', 'g', 'h', 't', 'G', 'r', 'a', 'y', 0,
    'L', 'i', 's', 't', 'S', 't', 'a', 'r', 't', 0,
    'L', 'i', 's', 't', 'S', 't', 'y', 'l', 'e', 0,
    'M', 'a', 'g', 'i', 'c', 'L', 'a', 'k', 'e', 0,
    'M', 'a', 'l', 'a', 'y', 'a', 'l', 'a', 'm', 0,
    'M', 'a', 'r', 's', 'P', 'a', 'r', 't', 'y', 0,
    'M', 'e', 'a', 'n', 'F', 'r', 'u', 'i', 't', 0,
    'M', 'e', 'd', 'i', 'a', 'T', 'a', 'p', 'e', 0,
    'M', 'i', 'n', 'd', 'C', 'r', 'a', 'w', 'l', 0,
    'M', 'i', 'x', 'e', 'd', 'C', 'a', 's', 'e', 0,
    'M', 'o', 'n', 'o', 's', 'p', 'a', 'c', 'e', 0,
    'N', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'N', 'e', 'x', 't', 'C', 'h', 'i', 'l', 'd', 0,
    'N', 'i', 'g', 'h', 't', 'C', 'a', 'l', 'l', 0,
    'N', 'i', 'g', 'h', 't', 'F', 'a', 'd', 'e', 0,
    'N', 'o', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'O', 'f', 'f', 's', 'c', 'r', 'e', 'e', 'n', 0,
    'P', 'a', 'd', 'S', 'p', 'r', 'e', 'a', 'd', 0,
    'P', 'd', 'm', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'P', 'l', 'u', 'm', 'P', 'l', 'a', 't', 'e', 0,
    'P', 'r', 'c', '3', '2', 'K', 'B', 'i', 'g', 0,
    'Q', 'F', 'o', 'n', 't', 'I', 'n', 'f', 'o', 0,
    'Q', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 0,
    'Q', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'Q', 'K', 'e', 'y', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'Q', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 'F', 0,
    'Q', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'I', 't', 'e', 'm', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 'n', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 's', 't', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '2', 'D', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '3', 'D', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '4', 'D', 0,
    'Q', 'u', 'i', 'c', 'k', 'D', 'r', 'a', 'w', 0,
    'R', 'e', 'd', 'o', 'S', 't', 'a', 'c', 'k', 0,
    'R', 'i', 'c', 'h', 'M', 'e', 't', 'a', 'l', 0,
    'R', 'i', 'v', 'e', 'r', 'C', 'i', 't', 'y', 0,
    'S', 'a', 'n', 's', 'S', 'e', 'r', 'i', 'f', 0,
    'S', 'e', 'a', 'S', 't', 'r', 'i', 'k', 'e', 0,
    'S', 'k', 'i', 'p', 'W', 'o', 'r', 'd', 's', 0,
    'S', 'k', 'y', 'G', 'l', 'i', 'd', 'e', 'r', 0,
    'S', 'm', 'a', 'l', 'l', 'C', 'a', 'p', 's', 0,
    'S', 'n', 'o', 'w', 'A', 'g', 'a', 'i', 'n', 0,
    'S', 'o', 'f', 't', 'G', 'r', 'a', 's', 's', 0,
    'S', 'p', 'i', 'k', 'y', 'N', 'a', 'g', 'a', 0,
    'S', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 0,
    'S', 'u', 'n', 'V', 'e', 'g', 'g', 'i', 'e', 0,
    'S', 'y', 'n', 'c', 'E', 'r', 'r', 'o', 'r', 0,
    'T', 'e', 'e', 'n', 'P', 'a', 'r', 't', 'y', 0,
    'T', 'i', 't', 'l', 'e', 'F', 'o', 'n', 't', 0,
    'T', 'x', 'P', 'r', 'o', 'j', 'e', 'c', 't', 0,
    'U', 'n', 'c', 'h', 'e', 'c', 'k', 'e', 'd', 0,
    'U', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', 0,
    'U', 's', 'e', 's', 'A', 'l', 'p', 'h', 'a', 0,
    'W', 'a', 'r', 'm', 'F', 'l', 'a', 'm', 'e', 0,
    'W', 'i', 'l', 'd', 'A', 'p', 'p', 'l', 'e', 0,
    'W', 'i', 'n', 'd', 'o', 'w', 'N', 'e', 'w', 0,
    'W', 'o', 'r', 'd', 'R', 'i', 'g', 'h', 't', 0,
    'Z', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    '_', '_', 'e', 'n', 't', 'e', 'r', '_', '_', 0,
    'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', 0,
    'a', 'd', 'd', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'd', 'd', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'a', 'd', 'd', 'R', 'e', 'g', 'i', 'o', 'n', 0,
    'a', 'l', 'i', 'c', 'e', 'b', 'l', 'u', 'e', 0,
    'a', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'a', 'l', 'p', 'h', 'a', 'S', 'i', 'z', 'e', 0,
    'a', 'm', 'b', 'i', 'g', 'u', 'o', 'u', 's', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'R', 'o', 'w', 0,
    'a', 'r', 'c', 'M', 'o', 'v', 'e', 'T', 'o', 0,
    'b', 'l', 'a', 'c', 'k', 'S', 'i', 'z', 'e', 0,
    'b', 'l', 'o', 'c', 'k', 'L', 'i', 's', 't', 0,
    'b', 'u', 'r', 'l', 'y', 'w', 'o', 'o', 'd', 0,
    'b', 'y', 't', 'e', 'O', 'r', 'd', 'e', 'r', 0,
    'c', 'a', 'c', 'h', 'e', 'M', 'o', 'd', 'e', 0,
    'c', 'a', 'd', 'e', 't', 'b', 'l', 'u', 'e', 0,
    'c', 'a', 'p', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'c', 'h', 'o', 'c', 'o', 'l', 'a', 't', 'e', 0,
    'c', 'l', 'e', 'a', 'r', 'D', 'a', 't', 'a', 0,
    'c', 'l', 'i', 'p', 'T', 'i', 'g', 'h', 't', 0,
    'c', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'c', 'o', 'n', 's', 't', 'B', 'i', 't', 's', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'T', 'o', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'T', 'o', 'X', 0,
    'd', 'a', 'r', 'k', 'g', 'r', 'e', 'e', 'n', 0,
    'd', 'a', 'r', 'k', 'k', 'h', 'a', 'k', 'i', 0,
    'd', 'e', 'l', 'i', 'm', 'i', 't', 'e', 'r', 0,
    'd', 'r', 'a', 'w', 'C', 'h', 'o', 'r', 'd', 0,
    'd', 'r', 'a', 'w', 'I', 'm', 'a', 'g', 'e', 0,
    'd', 'r', 'a', 'w', 'L', 'i', 'n', 'e', 's', 0,
    'd', 'r', 'a', 'w', 'P', 'o', 'i', 'n', 't', 0,
    'd', 'r', 'a', 'w', 'R', 'e', 'c', 't', 's', 0,
    'e', 'l', 'e', 'm', 'e', 'n', 't', 'A', 't', 0,
    'e', 'n', 'd', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'e', 'r', 'a', 's', 'e', 'R', 'e', 'c', 't', 0,
    'f', 'e', 't', 'c', 'h', 'M', 'o', 'r', 'e', 0,
    'f', 'i', 'n', 'a', 'l', 'S', 't', 'o', 'p', 0,
    'f', 'i', 'n', 'd', 'B', 'l', 'o', 'c', 'k', 0,
    'f', 'i', 'n', 'd', 'I', 't', 'e', 'm', 's', 0,
    'f', 'i', 'r', 'e', 'b', 'r', 'i', 'c', 'k', 0,
    'f', 'i', 'r', 's', 't', 'P', 'a', 'g', 'e', 0,
    'f', 'o', 'n', 't', 'T', 'a', 'b', 'l', 'e', 0,
    'f', 'r', 'a', 'm', 'e', 'R', 'e', 'c', 't', 0,
    'f', 'r', 'o', 'm', 'C', 'm', 'y', 'k', 'F', 0,
    'f', 'r', 'o', 'm', 'I', 'm', 'a', 'g', 'e', 0,
    'f', 'r', 'o', 'm', 'S', 'c', 'a', 'l', 'e', 0,
    'f', 'r', 'o', 'm', 'T', 'h', 'e', 'm', 'e', 0,
    'f', 'r', 'o', 'm', 'V', 'a', 'l', 'u', 'e', 0,
    'f', 'r', 'o', 'm', 'W', 'i', 'n', 'I', 'd', 0,
    'g', 'a', 'i', 'n', 's', 'b', 'o', 'r', 'o', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'P', 'o', 's', 0,
    'g', 'l', 'y', 'p', 'h', 'N', 'a', 'm', 'e', 0,
    'g', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 's', 0,
    'g', 'r', 'e', 'e', 'n', 'S', 'i', 'z', 'e', 0,
    'h', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 'd', 'i', 'a', 'n', 'r', 'e', 'd', 0,
    'i', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 0,
    'i', 's', 'C', 'h', 'e', 'c', 'k', 'e', 'd', 0,
    'i', 's', 'C', 'u', 'r', 'v', 'e', 'T', 'o', 0,
    'i', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'E', 'x', 'p', 'o', 's', 'e', 'd', 0,
    'i', 's', 'Q', 'B', 'i', 't', 'm', 'a', 'p', 0,
    'i', 's', 'S', 'c', 'a', 'l', 'i', 'n', 'g', 0,
    'i', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'j', 'o', 'i', 'n', 'S', 't', 'y', 'l', 'e', 0,
    'l', 'a', 's', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'l', 'a', 's', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'l', 'a', 'w', 'n', 'g', 'r', 'e', 'e', 'n', 0,
    'l', 'i', 'g', 'h', 't', 'b', 'l', 'u', 'e', 0,
    'l', 'i', 'g', 'h', 't', 'c', 'y', 'a', 'n', 0,
    'l', 'i', 'g', 'h', 't', 'g', 'r', 'a', 'y', 0,
    'l', 'i', 'g', 'h', 't', 'g', 'r', 'e', 'y', 0,
    'l', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 0,
    'l', 'i', 'g', 'h', 't', 'p', 'i', 'n', 'k', 0,
    'l', 'i', 'm', 'e', 'g', 'r', 'e', 'e', 'n', 0,
    'l', 'i', 'n', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'l', 'i', 'n', 'e', 'W', 'i', 'd', 't', 'h', 0,
    'l', 'o', 'o', 'p', 'C', 'o', 'u', 'n', 't', 0,
    'l', 'o', 's', 't', 'F', 'o', 'c', 'u', 's', 0,
    'm', 'a', 'p', 'V', 'e', 'c', 't', 'o', 'r', 0,
    'm', 'e', 'r', 'g', 'e', 'W', 'i', 't', 'h', 0,
    'm', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 's', 0,
    'm', 'i', 'n', 't', 'c', 'r', 'e', 'a', 'm', 0,
    'm', 'i', 's', 't', 'y', 'r', 'o', 's', 'e', 0,
    'm', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'm', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'u', 'l', 't', 'i', 'D', 'a', 't', 'a', 0,
    'n', 'e', 'a', 'r', 'P', 'l', 'a', 'n', 'e', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 0,
    'n', 'u', 'm', 'e', 'r', 'i', 'c', 'I', 'd', 0,
    'o', 'l', 'i', 'v', 'e', 'd', 'r', 'a', 'b', 0,
    'o', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'o', 'r', 'a', 'n', 'g', 'e', 'r', 'e', 'd', 0,
    'p', 'a', 'g', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'p', 'a', 'i', 'n', 't', 'R', 'e', 'c', 't', 0,
    'p', 'a', 'l', 'e', 'g', 'r', 'e', 'e', 'n', 0,
    'p', 'e', 'a', 'c', 'h', 'p', 'u', 'f', 'f', 0,
    'p', 'i', 'x', 'e', 'l', 'S', 'i', 'z', 'e', 0,
    'p', 'o', 'i', 'n', 't', 'B', 'y', 'I', 'd', 0,
    'p', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'i', 'e', 's', 0,
    'p', 'u', 't', 'P', 'o', 'i', 'n', 't', 's', 0,
    'r', 'e', 'c', 't', 'C', 'o', 'u', 'n', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'R', 'o', 'w', 0,
    'r', 'o', 'l', 'e', 'N', 'a', 'm', 'e', 's', 0,
    'r', 'o', 'o', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'r', 'o', 's', 'y', 'b', 'r', 'o', 'w', 'n', 0,
    'r', 'o', 'y', 'a', 'l', 'b', 'l', 'u', 'e', 0,
    's', 'e', 'a', 't', 'N', 'a', 'm', 'e', 's', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 's', 's', 'i', 'o', 'n', 'I', 'd', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 'F', 0,
    's', 'e', 't', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    's', 'e', 't', 'A', 's', 'c', 'e', 'n', 't', 0,
    's', 'e', 't', 'A', 'u', 't', 'h', 'o', 'r', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 0,
    's', 'e', 't', 'C', 'e', 'n', 't', 'e', 'r', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 'e', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    's', 'e', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    's', 'e', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'G', 'r', 'e', 'e', 'n', 'F', 0,
    's', 'e', 't', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'I', 'n', 'd', 'e', 'n', 't', 0,
    's', 'e', 't', 'I', 's', 'M', 'a', 's', 'k', 0,
    's', 'e', 't', 'I', 't', 'a', 'l', 'i', 'c', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'e', 0,
    's', 'e', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    's', 'e', 't', 'M', 'a', 't', 'r', 'i', 'x', 0,
    's', 'e', 't', 'O', 'f', 'f', 's', 'e', 't', 0,
    's', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'a', 'r', 'e', 'n', 't', 0,
    's', 'e', 't', 'P', 'a', 'u', 's', 'e', 'd', 0,
    's', 'e', 't', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 's', 0,
    's', 'e', 't', 'R', 'a', 'd', 'i', 'u', 's', 0,
    's', 'e', 't', 'R', 'g', 'b', 'a', '6', '4', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'a', 'r', 0,
    's', 'e', 't', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    's', 'e', 't', 'S', 'p', 'r', 'e', 'a', 'd', 0,
    's', 'e', 't', 'S', 't', 'e', 'r', 'e', 'o', 0,
    's', 'e', 't', 'V', 'e', 'c', 't', 'o', 'r', 0,
    's', 'e', 't', 'W', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'W', 'i', 'd', 't', 'h', 'F', 0,
    's', 'e', 't', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    's', 'h', 'o', 'r', 't', 'c', 'u', 't', 's', 0,
    's', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'T', 'o', 'p', 0,
    's', 'p', 'l', 'i', 't', 'C', 'e', 'l', 'l', 0,
    's', 't', 'a', 't', 'u', 's', 'T', 'i', 'p', 0,
    's', 't', 'r', 'i', 'k', 'e', 'O', 'u', 't', 0,
    's', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 0,
    's', 't', 'y', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    't', 'a', 'k', 'e', 'C', 'h', 'i', 'l', 'd', 0,
    't', 'e', 'x', 't', 'S', 't', 'a', 'r', 't', 0,
    't', 'e', 'x', 't', 'W', 'i', 'd', 't', 'h', 0,
    't', 'h', 'e', 'm', 'e', 'N', 'a', 'm', 'e', 0,
    't', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 0,
    't', 'o', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    't', 'o', 'R', 'a', 'w', 'T', 'e', 'x', 't', 0,
    't', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    't', 'o', 'p', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 0,
    't', 'r', 'i', 'g', 'g', 'e', 'r', 'e', 'd', 0,
    'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'u', 'n', 'd', 'o', 'L', 'i', 'm', 'i', 't', 0,
    'u', 'n', 'p', 'r', 'o', 'j', 'e', 'c', 't', 0,
    'u', 's', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    'w', 'h', 'a', 't', 's', 'T', 'h', 'i', 's', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 's', 'I', 'd', 0,
    'x', 'T', 'o', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'y', 'u', 'v', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'A', 'd', 'o', 'b', 'e', 'R', 'g', 'b', 0,
    'A', 'i', 'r', 'b', 'r', 'u', 's', 'h', 0,
    'A', 'l', 'i', 'g', 'n', 'T', 'o', 'p', 0,
    'A', 'l', 'l', 'D', 'i', 'r', 't', 'y', 0,
    'A', 'm', 'y', 'C', 'r', 'i', 's', 'p', 0,
    'A', 'n', 'y', 'S', 't', 'y', 'l', 'e', 0,
    'A', 'r', 'm', 'e', 'n', 'i', 'a', 'n', 0,
    'B', 'i', 'g', 'M', 'a', 'n', 'g', 'o', 0,
    'B', 'l', 'a', 'c', 'k', 'S', 'e', 'a', 0,
    'B', 'l', 'e', 's', 's', 'i', 'n', 'g', 0,
    'B', 't', '2', '1', '0', '0', 'P', 'q', 0,
    'C', 'a', 'c', 'h', 'e', 'A', 'l', 'l', 0,
    'C', 'a', 'l', 'l', 'S', 't', 'o', 'p', 0,
    'C', 's', 's', 'F', 'l', 'o', 'a', 't', 0,
    'C', 's', 's', 'M', 'e', 'd', 'i', 'a', 0,
    'C', 'y', 'r', 'i', 'l', 'l', 'i', 'c', 0,
    'D', 'a', 'r', 'k', 'B', 'l', 'u', 'e', 0,
    'D', 'a', 'r', 'k', 'C', 'y', 'a', 'n', 0,
    'D', 'a', 'r', 'k', 'G', 'r', 'a', 'y', 0,
    'D', 'c', 'i', 'P', '3', 'D', '6', '5', 0,
    'D', 'e', 'e', 'p', 'B', 'l', 'u', 'e', 0,
    'D', 'e', 'm', 'i', 'B', 'o', 'l', 'd', 0,
    'D', 'e', 's', 'e', 'l', 'e', 'c', 't', 0,
    'D', 'i', 'r', 'e', 'c', 't', '2', 'D', 0,
    'D', 'i', 'r', 'e', 'c', 't', '3', 'D', 0,
    'D', 'i', 'r', 't', 'y', 'P', 'e', 'n', 0,
    'E', 'd', 'i', 't', 'C', 'o', 'p', 'y', 0,
    'E', 'd', 'i', 't', 'F', 'i', 'n', 'd', 0,
    'E', 'd', 'i', 't', 'R', 'e', 'd', 'o', 0,
    'E', 'd', 'i', 't', 'U', 'n', 'd', 'o', 0,
    'F', 'i', 'n', 'd', 'N', 'e', 'x', 't', 0,
    'G', 'e', 'o', 'r', 'g', 'i', 'a', 'n', 0,
    'G', 'u', 'j', 'a', 'r', 'a', 't', 'i', 0,
    'G', 'u', 'r', 'm', 'u', 'k', 'h', 'i', 0,
    'I', 'n', 'a', 'c', 't', 'i', 'v', 'e', 0,
    'I', 's', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    'J', 'a', 'p', 'a', 'n', 'e', 's', 'e', 0,
    'L', 'a', 'd', 'y', 'L', 'i', 'p', 's', 0,
    'L', 'i', 's', 't', 'D', 'i', 's', 'c', 0,
    'L', 'o', 'v', 'e', 'K', 'i', 's', 's', 0,
    'M', 'a', 'g', 'i', 'c', 'R', 'a', 'y', 0,
    'M', 'a', 'i', 'l', 'R', 'e', 'a', 'd', 0,
    'M', 'a', 'i', 'l', 'S', 'e', 'n', 'd', 0,
    'M', 'i', 'd', 'l', 'i', 'g', 'h', 't', 0,
    'M', 'o', 'l', 'e', 'H', 'a', 'l', 'l', 0,
    'N', 'e', 'a', 'r', 'M', 'o', 'o', 'n', 0,
    'N', 'e', 'x', 't', 'C', 'e', 'l', 'l', 0,
    'N', 'i', 'g', 'h', 't', 'S', 'k', 'y', 0,
    'N', 'o', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    'N', 'o', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'P', 'a', 'l', 'o', 'A', 'l', 't', 'o', 0,
    'P', 'd', 'm', 'D', 'e', 'p', 't', 'h', 0,
    'P', 'd', 'm', 'W', 'i', 'd', 't', 'h', 0,
    'P', 'l', 'u', 'm', 'B', 'a', 't', 'h', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'Q', 'P', 'a', 'l', 'e', 't', 't', 'e', 0,
    'Q', 'P', 'i', 'c', 't', 'u', 'r', 'e', 0,
    'Q', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    'Q', 'R', 'a', 'w', 'F', 'o', 'n', 't', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'u', 'i', 't', 'R', 'o', 'l', 'e', 0,
    'R', 'a', 'r', 'e', 'W', 'i', 'n', 'd', 0,
    'R', 'e', 'l', 'e', 'a', 's', 'e', 'd', 0,
    'R', 'i', 'g', 'h', 't', 'T', 'a', 'b', 0,
    'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'e', 'a', 's', 'h', 'o', 'r', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'e', 'd', 0,
    'S', 't', 'a', 'r', 'W', 'i', 'n', 'e', 0,
    'T', 'o', 'u', 'c', 'h', 'P', 'a', 'd', 0,
    'T', 'r', 'a', 'i', 'l', 'i', 'n', 'g', 0,
    'T', 'r', 'a', 's', 'h', 'c', 'a', 'n', 0,
    'T', 'x', 'R', 'o', 't', 'a', 't', 'e', 0,
    'U', 's', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'W', 'i', 'n', 'd', 'o', 'w', 'e', 'd', 0,
    'W', 'o', 'r', 'd', 'L', 'e', 'f', 't', 0,
    'W', 'o', 'r', 'd', 'W', 'r', 'a', 'p', 0,
    'Y', 'U', 'V', '4', '2', '0', 'S', 'P', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'e', 'x', 'i', 't', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'd', 'd', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'm', 'u', 'l', '_', '_', 0,
    '_', '_', 'i', 's', 'u', 'b', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    '_', '_', 'r', 'e', 'p', 'r', '_', '_', 0,
    'a', 'c', 'c', 'e', 'p', 't', 'e', 'd', 0,
    'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 0,
    'a', 'd', 'd', 'R', 'a', 'n', 'g', 'e', 0,
    'a', 'd', 'd', 'S', 't', 'a', 'c', 'k', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 'A', 't', 0,
    'b', 'a', 's', 'e', 'S', 'i', 'z', 'e', 0,
    'b', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'b', 'l', 'u', 'e', 'S', 'i', 'z', 'e', 0,
    'c', 'a', 'c', 'h', 'e', 'K', 'e', 'y', 0,
    'c', 'a', 'p', 'S', 't', 'y', 'l', 'e', 0,
    'c', 'a', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'c', 'l', 'i', 'p', 'P', 'a', 't', 'h', 0,
    'c', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 0,
    'c', 'o', 'r', 'n', 's', 'i', 'l', 'k', 0,
    'c', 'y', 'a', 'n', 'S', 'i', 'z', 'e', 0,
    'd', 'a', 'r', 'k', 'b', 'l', 'u', 'e', 0,
    'd', 'a', 'r', 'k', 'c', 'y', 'a', 'n', 0,
    'd', 'a', 'r', 'k', 'g', 'r', 'a', 'y', 0,
    'd', 'a', 'r', 'k', 'g', 'r', 'e', 'y', 0,
    'd', 'e', 'c', 'i', 'm', 'a', 'l', 's', 0,
    'd', 'e', 'e', 'p', 'p', 'i', 'n', 'k', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'd', 'r', 'a', 'w', 'L', 'i', 'n', 'e', 0,
    'd', 'r', 'a', 'w', 'P', 'a', 't', 'h', 0,
    'd', 'r', 'a', 'w', 'R', 'e', 'c', 't', 0,
    'd', 'r', 'a', 'w', 'T', 'e', 'x', 't', 0,
    'e', 'n', 'd', 'M', 'a', 'c', 'r', 'o', 0,
    'e', 'n', 'd', 'P', 'a', 'i', 'n', 't', 0,
    'f', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    'f', 'a', 'r', 'P', 'l', 'a', 'n', 'e', 0,
    'f', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'f', 'i', 'l', 'e', 'I', 'c', 'o', 'n', 0,
    'f', 'i', 'l', 'e', 'I', 'n', 'f', 'o', 0,
    'f', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'f', 'i', 'l', 'e', 'P', 'a', 't', 'h', 0,
    'f', 'i', 'l', 'l', 'P', 'a', 't', 'h', 0,
    'f', 'i', 'l', 'l', 'R', 'e', 'c', 't', 0,
    'f', 'i', 'l', 'l', 'R', 'u', 'l', 'e', 0,
    'f', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'f', 'o', 'n', 't', 'I', 'n', 'f', 'o', 0,
    'f', 'o', 'r', 'm', 'a', 't', 'A', 't', 0,
    'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 0,
    'f', 'r', 'o', 'm', 'A', 'x', 'e', 's', 0,
    'f', 'r', 'o', 'm', 'C', 'm', 'y', 'k', 0,
    'f', 'r', 'o', 'm', 'D', 'a', 't', 'a', 0,
    'f', 'r', 'o', 'm', 'F', 'o', 'n', 't', 0,
    'f', 'r', 'o', 'm', 'H', 's', 'l', 'F', 0,
    'f', 'r', 'o', 'm', 'H', 's', 'v', 'F', 0,
    'f', 'r', 'o', 'm', 'H', 't', 'm', 'l', 0,
    'f', 'r', 'o', 'm', 'R', 'g', 'b', 'F', 0,
    'f', 'r', 'o', 'm', 'R', 'g', 'b', 'a', 0,
    'f', 'u', 'l', 'l', 'R', 'e', 'c', 't', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'g', 'e', 't', 'C', 'm', 'y', 'k', 'F', 0,
    'g', 'o', 't', 'F', 'o', 'c', 'u', 's', 0,
    'g', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'h', 'a', 's', 'A', 'l', 'p', 'h', 'a', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'M', 'M', 0,
    'h', 'o', 'n', 'e', 'y', 'd', 'e', 'w', 0,
    'i', 'c', 'o', 'n', 'N', 'a', 'm', 'e', 0,
    'i', 'c', 'o', 'n', 'T', 'e', 'x', 't', 0,
    'i', 'n', 'v', 'e', 'r', 't', 'e', 'd', 0,
    'i', 's', 'A', 'c', 't', 'i', 'v', 'e', 0,
    'i', 's', 'A', 'f', 'f', 'i', 'n', 'e', 0,
    'i', 's', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    'i', 's', 'C', 'l', 'o', 's', 'e', 'd', 0,
    'i', 's', 'C', 'o', 'p', 'y', 'O', 'f', 0,
    'i', 's', 'L', 'i', 'n', 'e', 'T', 'o', 0,
    'i', 's', 'M', 'o', 'v', 'e', 'T', 'o', 0,
    'i', 's', 'O', 'p', 'a', 'q', 'u', 'e', 0,
    'i', 's', 'P', 'h', 'a', 's', 'e', '2', 0,
    'i', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    'i', 't', 'e', 'm', 'T', 'e', 'x', 't', 0,
    'l', 'a', 's', 't', 'P', 'a', 'g', 'e', 0,
    'l', 'a', 'v', 'e', 'n', 'd', 'e', 'r', 0,
    'm', 'a', 'g', 'e', 'n', 't', 'a', 'F', 0,
    'm', 'a', 'x', 'W', 'i', 'd', 't', 'h', 0,
    'm', 'e', 'n', 'u', 'R', 'o', 'l', 'e', 0,
    'm', 'i', 'd', 'l', 'i', 'g', 'h', 't', 0,
    'm', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'm', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 0,
    'm', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 0,
    'm', 'o', 'c', 'c', 'a', 's', 'i', 'n', 0,
    'm', 'o', 'd', 'a', 'l', 'i', 't', 'y', 0,
    'n', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'o', 'l', 'd', 'S', 't', 'a', 't', 'e', 0,
    'o', 'p', 'e', 'n', 'F', 'i', 'l', 'e', 0,
    'o', 'p', 't', 'i', 'm', 'i', 'z', 'e', 0,
    'o', 'v', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'p', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'e', 's', 's', 'u', 'r', 'e', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 0,
    'p', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'r', 'a', 'w', 'V', 'a', 'l', 'u', 'e', 0,
    'r', 'e', 'd', 'o', 'T', 'e', 'x', 't', 0,
    'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'r', 'e', 'v', 'i', 's', 'i', 'o', 'n', 0,
    'r', 'o', 'o', 't', 'P', 'a', 't', 'h', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'r', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    'r', 'o', 'w', 'S', 't', 'a', 'r', 't', 0,
    's', 'c', 'a', 'n', 'L', 'i', 'n', 'e', 0,
    's', 'c', 'r', 'e', 'e', 'n', 'A', 't', 0,
    's', 'e', 'a', 's', 'h', 'e', 'l', 'l', 0,
    's', 'e', 'a', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 0,
    's', 'e', 't', 'A', 'n', 'g', 'l', 'e', 0,
    's', 'e', 't', 'B', 'l', 'u', 'e', 'F', 0,
    's', 'e', 't', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'C', 'h', 'i', 'l', 'd', 0,
    's', 'e', 't', 'C', 'm', 'y', 'k', 'F', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'F', 'l', 'a', 'g', 's', 0,
    's', 'e', 't', 'G', 'r', 'e', 'e', 'n', 0,
    's', 'e', 't', 'I', 'm', 'a', 'g', 'e', 0,
    's', 'e', 't', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'P', 'i', 'x', 'e', 'l', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'R', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'R', 'e', 'c', 't', 's', 0,
    's', 'e', 't', 'S', 'h', 'a', 'p', 'e', 0,
    's', 'e', 't', 'S', 'p', 'e', 'e', 'd', 0,
    's', 'e', 't', 'S', 't', 'a', 'r', 't', 0,
    's', 'e', 't', 'S', 't', 'o', 'p', 's', 0,
    's', 'e', 't', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 0,
    's', 'e', 't', 'U', 'n', 'i', 't', 's', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'W', 'i', 'd', 't', 'h', 0,
    's', 'h', 'o', 'r', 't', 'c', 'u', 't', 0,
    's', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    's', 'o', 'r', 't', 'R', 'o', 'l', 'e', 0,
    's', 't', 'a', 'r', 't', 'P', 'o', 's', 0,
    's', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    's', 'y', 's', 't', 'e', 'm', 'I', 'd', 0,
    't', 'a', 'b', 'A', 'r', 'r', 'a', 'y', 0,
    't', 'a', 'b', 'S', 't', 'o', 'p', 's', 0,
    't', 'a', 'k', 'e', 'I', 't', 'e', 'm', 0,
    't', 'e', 'x', 't', 'K', 'e', 'y', 's', 0,
    't', 'e', 'x', 't', 'L', 'i', 's', 't', 0,
    't', 'i', 'm', 'e', 'H', 'e', 'l', 'd', 0,
    't', 'o', 'A', 'r', 'g', 'b', '3', '2', 0,
    't', 'o', 'P', 'o', 'i', 'n', 't', 'F', 0,
    't', 'o', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'u', 'n', 'd', 'o', 'T', 'e', 'x', 't', 0,
    'u', 'n', 'i', 'q', 'u', 'e', 'I', 'd', 0,
    'u', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 0,
    'v', 'e', 'l', 'o', 'c', 'i', 't', 'y', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    'w', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'A', '3', 'E', 'x', 't', 'r', 'a', 0,
    'A', '4', 'E', 'x', 't', 'r', 'a', 0,
    'A', '4', 'S', 'm', 'a', 'l', 'l', 0,
    'A', '5', 'E', 'x', 't', 'r', 'a', 0,
    'B', '5', 'E', 'x', 't', 'r', 'a', 0,
    'B', 'a', 't', 't', 'e', 'r', 'y', 0,
    'B', 'e', 'n', 'g', 'a', 'l', 'i', 0,
    'B', 'l', 'i', 't', 't', 'e', 'r', 0,
    'C', 'o', 'm', 'm', '1', '0', 'E', 0,
    'C', 'o', 'u', 'r', 'i', 'e', 'r', 0,
    'C', 'u', 'r', 's', 'i', 'v', 'e', 0,
    'D', 'a', 'r', 'k', 'R', 'e', 'd', 0,
    'D', 'e', 's', 'k', 't', 'o', 'p', 0,
    'E', 'd', 'i', 't', 'C', 'u', 't', 0,
    'F', 'a', 'n', 't', 'a', 's', 'y', 0,
    'F', 'l', 'y', 'H', 'i', 'g', 'h', 0,
    'G', 'e', 'n', 'e', 'r', 'i', 'c', 0,
    'H', 'e', 'l', 'p', 'F', 'a', 'q', 0,
    'H', 'e', 'x', 'A', 'r', 'g', 'b', 0,
    'I', 'n', 'd', 'e', 'x', 'e', 'd', 0,
    'K', 'a', 'n', 'n', 'a', 'd', 'a', 0,
    'L', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'L', 'e', 'f', 't', 'T', 'a', 'b', 0,
    'L', 'i', 'b', 'G', 'L', 'E', 'S', 0,
    'L', 'i', 's', 't', 'A', 'd', 'd', 0,
    'M', 'a', 'x', 'U', 's', 'e', 'r', 0,
    'M', 'y', 'a', 'n', 'm', 'a', 'r', 0,
    'N', 'e', 't', 'w', 'o', 'r', 'k', 0,
    'N', 'e', 'w', 'L', 'i', 'f', 'e', 0,
    'N', 'e', 'w', 'Y', 'o', 'r', 'k', 0,
    'N', 'e', 'x', 't', 'R', 'o', 'w', 0,
    'N', 'o', 'M', 'a', 't', 'c', 'h', 0,
    'O', 'p', 'e', 'n', 'G', 'L', '2', 0,
    'O', 'v', 'e', 'r', 'S', 'u', 'n', 0,
    'P', 'd', 'm', 'D', 'p', 'i', 'X', 0,
    'P', 'd', 'm', 'D', 'p', 'i', 'Y', 0,
    'P', 'r', 'e', 's', 's', 'e', 'd', 0,
    'Q', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'Q', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'Q', 'R', 'e', 'g', 'i', 'o', 'n', 0,
    'Q', 'R', 'g', 'b', 'a', '6', '4', 0,
    'Q', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'Q', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'S', 'c', 'a', 'n', 'n', 'e', 'r', 0,
    'S', 'e', 'a', 'L', 'o', 'r', 'd', 0,
    'S', 'i', 'n', 'h', 'a', 'l', 'a', 0,
    'T', 'a', 'b', 'l', 'o', 'i', 'd', 0,
    'T', 'i', 'b', 'e', 't', 'a', 'n', 0,
    'T', 'x', 'S', 'c', 'a', 'l', 'e', 0,
    'T', 'x', 'S', 'h', 'e', 'a', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    'Y', 'U', 'V', '4', '2', '0', 'P', 0,
    'Z', 'o', 'o', 'm', 'O', 'u', 't', 0,
    '_', '_', 'a', 'd', 'd', '_', '_', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'l', 'e', 'n', '_', '_', 0,
    '_', '_', 'm', 'u', 'l', '_', '_', 0,
    '_', '_', 'n', 'e', 'g', '_', '_', 0,
    '_', '_', 's', 'u', 'b', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'a', 'c', 't', 'i', 'o', 'n', 's', 0,
    'a', 'd', 'd', 'F', 'i', 'l', 'e', 0,
    'a', 'd', 'd', 'P', 'a', 'g', 'e', 0,
    'a', 'd', 'd', 'P', 'a', 't', 'h', 0,
    'a', 'd', 'd', 'R', 'e', 'c', 't', 0,
    'a', 'd', 'd', 'T', 'e', 'x', 't', 0,
    'a', 'd', 'j', 'o', 'i', 'n', 't', 0,
    'a', 'l', 'l', 'G', 'r', 'a', 'y', 0,
    'a', 't', 'S', 't', 'a', 'r', 't', 0,
    'a', 'u', 't', 'o', 'r', 'e', 'p', 0,
    'b', 'a', 's', 'e', 'U', 'r', 'l', 0,
    'b', 'u', 't', 't', 'o', 'n', 's', 0,
    'c', 'a', 'n', 'R', 'e', 'a', 'd', 0,
    'c', 'a', 'n', 'R', 'e', 'd', 'o', 0,
    'c', 'a', 'n', 'U', 'n', 'd', 'o', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'e', 'a', 'n', 'u', 'p', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'c', 'o', 'm', 'b', 'i', 'n', 'e', 0,
    'c', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 0,
    'c', 'r', 'e', 'a', 't', 'o', 'r', 0,
    'c', 'r', 'i', 'm', 's', 'o', 'n', 0,
    'c', 'u', 'b', 'i', 'c', 'T', 'o', 0,
    'd', 'a', 'r', 'k', 'r', 'e', 'd', 0,
    'd', 'e', 's', 'c', 'e', 'n', 't', 0,
    'd', 'e', 's', 't', 'r', 'o', 'y', 0,
    'd', 'e', 'v', 'T', 'y', 'p', 'e', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 's', 0,
    'd', 'i', 'm', 'g', 'r', 'a', 'y', 0,
    'd', 'i', 'm', 'g', 'r', 'e', 'y', 0,
    'd', 'i', 's', 'p', 'l', 'a', 'y', 0,
    'd', 'r', 'a', 'w', 'A', 'r', 'c', 0,
    'd', 'r', 'a', 'w', 'P', 'i', 'e', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'e', 'x', 'p', 'o', 's', 'e', 'd', 0,
    'f', 'l', 'i', 'p', 'p', 'e', 'd', 0,
    'f', 'o', 'n', 't', 'D', 'p', 'i', 0,
    'f', 'o', 'r', 'm', 'a', 't', 's', 0,
    'f', 'r', 'o', 'm', 'H', 's', 'l', 0,
    'f', 'r', 'o', 'm', 'H', 's', 'v', 0,
    'f', 'r', 'o', 'm', 'R', 'g', 'b', 0,
    'f', 'r', 'u', 's', 't', 'u', 'm', 0,
    'f', 'u', 'c', 'h', 's', 'i', 'a', 0,
    'g', 'e', 't', 'A', 'x', 'e', 's', 0,
    'g', 'e', 't', 'C', 'm', 'y', 'k', 0,
    'g', 'e', 't', 'H', 's', 'l', 'F', 0,
    'g', 'e', 't', 'H', 's', 'v', 'F', 0,
    'g', 'e', 't', 'R', 'g', 'b', 'F', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'X', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'Y', 0,
    'h', 'i', 't', 'T', 'e', 's', 't', 0,
    'h', 'o', 't', 'S', 'p', 'o', 't', 0,
    'h', 'o', 't', 'p', 'i', 'n', 'k', 0,
    'h', 'o', 'v', 'e', 'r', 'e', 'd', 0,
    'h', 's', 'l', 'H', 'u', 'e', 'F', 0,
    'h', 's', 'v', 'H', 'u', 'e', 'F', 0,
    'h', 'u', 'e', 'S', 'i', 'z', 'e', 0,
    'i', 'm', 'a', 'g', 'e', 'A', 't', 0,
    'i', 'n', 'd', 'e', 'x', 'O', 'f', 0,
    'i', 's', 'C', 'l', 'e', 'a', 'n', 0,
    'i', 's', 'E', 'm', 'p', 't', 'y', 0,
    'i', 's', 'E', 'q', 'u', 'a', 'l', 0,
    'i', 's', 'M', 'o', 'd', 'a', 'l', 0,
    'i', 's', 'S', 'o', 'l', 'i', 'd', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'k', 'e', 'r', 'n', 'i', 'n', 'g', 0,
    'l', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'm', 'a', 'p', 'R', 'e', 'c', 't', 0,
    'm', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'm', 'a', 't', 'c', 'h', 'e', 's', 0,
    'n', 'e', 'w', 'P', 'a', 'g', 'e', 0,
    'o', 'l', 'd', 'P', 'o', 's', 'F', 0,
    'o', 'l', 'd', 'S', 'i', 'z', 'e', 0,
    'o', 'l', 'd', 'l', 'a', 'c', 'e', 0,
    'o', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'o', 'p', 'e', 'n', 'U', 'r', 'l', 0,
    'o', 'p', 't', 'i', 'o', 'n', 's', 0,
    'p', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'p', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'p', 'a', 'l', 'e', 't', 't', 'e', 0,
    'p', 'r', 'e', 'p', 'a', 'r', 'e', 0,
    'p', 'r', 'e', 'p', 'e', 'n', 'd', 0,
    'p', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'q', 'R', 'g', 'b', 'a', '6', '4', 0,
    'q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'q', 'u', 'e', 'r', 'i', 'e', 's', 0,
    'r', 'a', 'w', 'F', 'o', 'n', 't', 0,
    'r', 'e', 'd', 'S', 'i', 'z', 'e', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'r', 'e', 's', 'e', 'r', 'v', 'e', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'd', 0,
    'r', 'e', 's', 'o', 'l', 'v', 'e', 0,
    'r', 'e', 's', 't', 'o', 'r', 'e', 0,
    'r', 'g', 'b', 'S', 'w', 'a', 'p', 0,
    'r', 'o', 'w', 'S', 'p', 'a', 'n', 0,
    's', 'a', 'm', 'p', 'l', 'e', 's', 0,
    's', 'c', 'a', 'l', 'i', 'n', 'g', 0,
    's', 'c', 'r', 'e', 'e', 'n', 's', 0,
    's', 'e', 't', 'B', 'l', 'u', 'e', 0,
    's', 'e', 't', 'B', 'o', 'l', 'd', 0,
    's', 'e', 't', 'C', 'm', 'y', 'k', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'F', 'l', 'a', 'g', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 0,
    's', 'e', 't', 'H', 's', 'l', 'F', 0,
    's', 'e', 't', 'H', 's', 'v', 'F', 0,
    's', 'e', 't', 'H', 't', 'm', 'l', 0,
    's', 'e', 't', 'I', 'c', 'o', 'n', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 0,
    's', 'e', 't', 'K', 'e', 'y', 's', 0,
    's', 'e', 't', 'M', 'a', 's', 'k', 0,
    's', 'e', 't', 'M', 'e', 'n', 'u', 0,
    's', 'e', 't', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'R', 'e', 'd', 'F', 0,
    's', 'e', 't', 'R', 'g', 'b', 'F', 0,
    's', 'e', 't', 'R', 'g', 'b', 'a', 0,
    's', 'e', 't', 'T', 'a', 'b', 's', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 0,
    's', 'i', 'b', 'l', 'i', 'n', 'g', 0,
    's', 't', 'a', 'r', 't', 'e', 'd', 0,
    's', 't', 'r', 'e', 't', 'c', 'h', 0,
    's', 'u', 'b', 'E', 'n', 'u', 'm', 0,
    's', 'u', 'b', 'T', 'y', 'p', 'e', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    't', 'a', 'k', 'e', 'R', 'o', 'w', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 0,
    't', 'h', 'i', 's', 't', 'l', 'e', 0,
    't', 'o', 'I', 'm', 'a', 'g', 'e', 0,
    't', 'o', 'P', 'o', 'i', 'n', 't', 0,
    't', 'o', 'R', 'g', 'b', '1', '6', 0,
    't', 'o', 'g', 'g', 'l', 'e', 'd', 0,
    't', 'o', 'o', 'l', 'T', 'i', 'p', 0,
    't', 'r', 'i', 'g', 'g', 'e', 'r', 0,
    't', 'r', 'i', 'm', 'm', 'e', 'd', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'd', 0,
    'v', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'w', 'i', 'd', 't', 'h', 'M', 'M', 0,
    'x', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'y', 'e', 'l', 'l', 'o', 'w', 'F', 0,
    'A', '4', 'P', 'l', 'u', 's', 0,
    'A', 'c', 'c', 'e', 'n', 't', 0,
    'A', 'd', 'd', 'T', 'a', 'b', 0,
    'A', 'r', 'a', 'b', 'i', 'c', 0,
    'B', 't', '2', '0', '2', '0', 0,
    'B', 'u', 't', 't', 'o', 'n', 0,
    'C', 'a', 'n', 'c', 'e', 'l', 0,
    'C', 'i', 'c', 'e', 'r', 'o', 0,
    'C', 'o', 'l', 'o', 'r', '0', 0,
    'C', 'o', 'l', 'o', 'r', '1', 0,
    'C', 'u', 's', 't', 'o', 'm', 0,
    'E', 'r', 'a', 's', 'e', 'r', 0,
    'F', 'i', 'n', 'g', 'e', 'r', 0,
    'F', 'o', 'l', 'd', 'e', 'r', 0,
    'G', 'o', 'D', 'o', 'w', 'n', 0,
    'G', 'o', 'H', 'o', 'm', 'e', 0,
    'G', 'o', 'N', 'e', 'x', 't', 0,
    'H', 'e', 'b', 'r', 'e', 'w', 0,
    'H', 'e', 'x', 'R', 'g', 'b', 0,
    'H', 'i', 'd', 'd', 'e', 'n', 0,
    'I', 'n', 'F', 'l', 'o', 'w', 0,
    'J', 'i', 's', 'B', '1', '0', 0,
    'K', 'o', 'r', 'e', 'a', 'n', 0,
    'L', 'e', 'd', 'g', 'e', 'r', 0,
    'L', 'e', 't', 't', 'e', 'r', 0,
    'N', 'o', 'M', 'o', 'v', 'e', 0,
    'N', 'o', 'R', 'o', 'l', 'e', 0,
    'N', 'o', 'S', 'a', 'v', 'e', 0,
    'N', 'o', 'W', 'r', 'a', 'p', 0,
    'O', 'l', 'd', 'H', 'a', 't', 0,
    'O', 'p', 'e', 'n', 'V', 'G', 0,
    'P', 'r', 'c', '1', '6', 'K', 0,
    'P', 'r', 'c', '3', '2', 'K', 0,
    'Q', 'B', 'r', 'u', 's', 'h', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 0,
    'Q', 'M', 'o', 'v', 'i', 'e', 0,
    'Q', 'u', 'a', 'r', 't', 'o', 0,
    'R', 'a', 's', 't', 'e', 'r', 0,
    'R', 'e', 'j', 'e', 'c', 't', 0,
    'S', 'h', 'a', 'd', 'o', 'w', 0,
    'S', 't', '2', '0', '8', '4', 0,
    'S', 't', 'y', 'l', 'u', 's', 0,
    'S', 'u', 'p', 'e', 'r', 'A', 0,
    'S', 'u', 'p', 'e', 'r', 'B', 0,
    'S', 'y', 'm', 'b', 'o', 'l', 0,
    'S', 'y', 'r', 'i', 'a', 'c', 0,
    'T', 'e', 'l', 'u', 'g', 'u', 0,
    'T', 'h', 'a', 'a', 'n', 'a', 0,
    'T', 'x', 'N', 'o', 'n', 'e', 0,
    'Y', 'U', 'V', '4', '1', '1', 0,
    'Y', 'U', 'V', '4', '2', '2', 0,
    'Y', 'U', 'V', '4', '4', '4', 0,
    'Z', 'o', 'o', 'm', 'I', 'n', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'g', 'e', '_', '_', 0,
    '_', '_', 'g', 't', '_', '_', 0,
    '_', '_', 'l', 'e', '_', '_', 0,
    '_', '_', 'l', 't', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'a', 'c', 'c', 'e', 'n', 't', 0,
    'a', 'c', 'c', 'e', 'p', 't', 0,
    'a', 'l', 'p', 'h', 'a', '8', 0,
    'a', 'l', 'p', 'h', 'a', 'F', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 0,
    'a', 's', 'c', 'e', 'n', 't', 0,
    'a', 'u', 't', 'h', 'o', 'r', 0,
    'b', 'e', 'f', 'o', 'r', 'e', 0,
    'b', 'i', 's', 'q', 'u', 'e', 0,
    'b', 'i', 't', 'm', 'a', 'p', 0,
    'b', 'l', 'a', 'c', 'k', 'F', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 0,
    'b', 'o', 't', 't', 'o', 'm', 0,
    'b', 'u', 't', 't', 'o', 'n', 0,
    'c', 'a', 'n', 'c', 'e', 'l', 0,
    'c', 'e', 'l', 'l', 'A', 't', 0,
    'c', 'e', 'n', 't', 'e', 'r', 0,
    'c', 'l', 'o', 's', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 0,
    'c', 'o', 'm', 'm', 'i', 't', 0,
    'c', 'r', 'e', 'a', 't', 'e', 0,
    'c', 'u', 'r', 's', 'o', 'r', 0,
    'd', 'a', 'r', 'k', 'e', 'r', 0,
    'd', 'e', 't', 'a', 'c', 'h', 0,
    'f', 'a', 'c', 't', 'o', 'r', 0,
    'f', 'a', 'm', 'i', 'l', 'y', 0,
    'f', 'i', 'l', 't', 'e', 'r', 0,
    'f', 'o', 'r', 'm', 'a', 't', 0,
    'g', 'e', 't', 'H', 's', 'l', 0,
    'g', 'e', 't', 'H', 's', 'v', 0,
    'g', 'e', 't', 'R', 'g', 'b', 0,
    'g', 'r', 'e', 'e', 'n', '8', 0,
    'g', 'r', 'e', 'e', 'n', 'F', 0,
    'h', 'e', 'i', 'g', 'h', 't', 0,
    'h', 's', 'l', 'H', 'u', 'e', 0,
    'h', 's', 'v', 'H', 'u', 'e', 0,
    'i', 'g', 'n', 'o', 'r', 'e', 0,
    'i', 'n', 'F', 'o', 'n', 't', 0,
    'i', 'n', 'd', 'e', 'n', 't', 0,
    'i', 'n', 'd', 'i', 'g', 'o', 0,
    'i', 'n', 's', 'e', 'r', 't', 0,
    'i', 's', 'M', 'a', 's', 'k', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    'i', 't', 'a', 'l', 'i', 'c', 0,
    'l', 'a', 'y', 'o', 'u', 't', 0,
    'l', 'e', 'n', 'g', 't', 'h', 0,
    'l', 'i', 'n', 'e', 'A', 't', 0,
    'l', 'i', 'n', 'e', 'T', 'o', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 0,
    'l', 'o', 'o', 'k', 'A', 't', 0,
    'm', 'a', 'r', 'g', 'i', 'n', 0,
    'm', 'a', 'r', 'k', 'e', 'r', 0,
    'm', 'a', 'r', 'o', 'o', 'n', 0,
    'm', 'a', 't', 'r', 'i', 'x', 0,
    'm', 'e', 'm', 'b', 'e', 'r', 0,
    'm', 'e', 't', 'r', 'i', 'c', 0,
    'm', 'i', 'r', 'r', 'o', 'r', 0,
    'm', 'o', 'v', 'e', 'T', 'o', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 0,
    'n', 'o', 't', 'i', 'f', 'y', 0,
    'o', 'b', 'j', 'e', 'c', 't', 0,
    'o', 'f', 'f', 's', 'e', 't', 0,
    'o', 'l', 'd', 'P', 'o', 's', 0,
    'o', 'p', 't', 'i', 'o', 'n', 0,
    'o', 'r', 'i', 'e', 'n', 't', 0,
    'p', 'i', 'x', 'm', 'a', 'p', 0,
    'p', 'o', 'i', 'n', 't', 's', 0,
    'p', 'r', 'e', 'f', 'i', 'x', 0,
    'q', 'A', 'l', 'p', 'h', 'a', 0,
    'q', 'G', 'r', 'e', 'e', 'n', 0,
    'q', 'u', 'a', 'd', 'T', 'o', 0,
    'r', 'a', 'd', 'i', 'u', 's', 0,
    'r', 'a', 'i', 's', 'e', '_', 0,
    'r', 'e', 'a', 's', 'o', 'n', 0,
    'r', 'e', 'g', 'i', 'o', 'n', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 0,
    'r', 'e', 's', 'i', 'z', 'e', 0,
    'r', 'e', 'v', 'e', 'r', 't', 0,
    'r', 'g', 'b', 'a', '6', '4', 0,
    'r', 'o', 't', 'a', 't', 'e', 0,
    'r', 'o', 'w', 'E', 'n', 'd', 0,
    's', 'c', 'a', 'l', 'a', 'r', 0,
    's', 'c', 'a', 'l', 'e', 'X', 0,
    's', 'c', 'a', 'l', 'e', 'Y', 0,
    's', 'c', 'a', 'l', 'e', 'd', 0,
    's', 'c', 'r', 'o', 'l', 'l', 0,
    's', 'e', 't', 'H', 's', 'l', 0,
    's', 'e', 't', 'H', 's', 'v', 0,
    's', 'e', 't', 'K', 'e', 'y', 0,
    's', 'e', 't', 'P', 'e', 'n', 0,
    's', 'e', 't', 'P', 'o', 's', 0,
    's', 'e', 't', 'R', 'e', 'd', 0,
    's', 'e', 't', 'R', 'g', 'b', 0,
    's', 'e', 't', 'R', 'o', 'w', 0,
    's', 'e', 't', 'T', 'a', 'g', 0,
    's', 'e', 't', 'T', 'o', 'p', 0,
    's', 'h', 'a', 'd', 'o', 'w', 0,
    's', 'h', 'a', 'r', 'e', 's', 0,
    's', 'i', 'e', 'n', 'n', 'a', 0,
    's', 'i', 'l', 'v', 'e', 'r', 0,
    's', 'p', 'r', 'e', 'a', 'd', 0,
    's', 't', 'a', 'c', 'k', 's', 0,
    's', 't', 'e', 'r', 'e', 'o', 0,
    's', 't', 'y', 'l', 'e', 's', 0,
    's', 'u', 'b', 'm', 'i', 't', 0,
    't', 'a', 'r', 'g', 'e', 't', 0,
    't', 'o', 'A', 'x', 'e', 's', 0,
    't', 'o', 'C', 'm', 'y', 'k', 0,
    't', 'o', 'H', 't', 'm', 'l', 0,
    't', 'o', 'g', 'g', 'l', 'e', 0,
    't', 'o', 'm', 'a', 't', 'o', 0,
    'u', 'n', 'i', 't', 'e', 'd', 0,
    'u', 'p', 'd', 'a', 't', 'e', 0,
    'v', 'a', 'l', 'u', 'e', 'F', 0,
    'v', 'e', 'c', 't', 'o', 'r', 0,
    'w', 'e', 'i', 'g', 'h', 't', 0,
    'w', 'i', 'd', 't', 'h', 'F', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 0,
    'A', 'n', 's', 'i', 'A', 0,
    'A', 'n', 's', 'i', 'B', 0,
    'A', 'n', 's', 'i', 'C', 0,
    'A', 'n', 's', 'i', 'D', 0,
    'A', 'n', 's', 'i', 'E', 0,
    'A', 'r', 'c', 'h', 'A', 0,
    'A', 'r', 'c', 'h', 'B', 0,
    'A', 'r', 'c', 'h', 'C', 0,
    'A', 'r', 'c', 'h', 'D', 0,
    'A', 'r', 'c', 'h', 'E', 0,
    'A', 't', 'E', 'n', 'd', 0,
    'B', 'l', 'a', 'c', 'k', 0,
    'C', 'l', 'a', 'm', 'p', 0,
    'C', 'l', 'i', 'c', 'k', 0,
    'D', 'i', 'd', 'o', 't', 0,
    'D', 'r', 'i', 'v', 'e', 0,
    'F', 'o', 'l', 'i', 'o', 0,
    'G', 'r', 'e', 'e', 'k', 0,
    'H', 'o', 'v', 'e', 'r', 0,
    'J', 'i', 's', 'B', '0', 0,
    'J', 'i', 's', 'B', '1', 0,
    'J', 'i', 's', 'B', '2', 0,
    'J', 'i', 's', 'B', '3', 0,
    'J', 'i', 's', 'B', '4', 0,
    'J', 'i', 's', 'B', '5', 0,
    'J', 'i', 's', 'B', '6', 0,
    'J', 'i', 's', 'B', '7', 0,
    'J', 'i', 's', 'B', '8', 0,
    'J', 'i', 's', 'B', '9', 0,
    'K', 'h', 'm', 'e', 'r', 0,
    'L', 'a', 't', 'i', 'n', 0,
    'L', 'i', 'b', 'G', 'L', 0,
    'N', 'o', 'n', 'e', '_', 0,
    'O', 'g', 'h', 'a', 'm', 0,
    'O', 'r', 'i', 'y', 'a', 0,
    'O', 't', 'h', 'e', 'r', 0,
    'P', 'h', 'o', 'n', 'e', 0,
    'Q', 'D', 'r', 'a', 'g', 0,
    'Q', 'F', 'o', 'n', 't', 0,
    'Q', 'I', 'c', 'o', 'n', 0,
    'Q', 'M', 'e', 'n', 'u', 0,
    'R', 'u', 'n', 'i', 'c', 0,
    'T', 'a', 'm', 'i', 'l', 0,
    'T', 'i', 'm', 'e', 's', 0,
    'X', 'T', 'i', 'l', 't', 0,
    'Y', 'T', 'i', 'l', 't', 0,
    'a', 'l', 'e', 'r', 't', 0,
    'a', 'l', 'p', 'h', 'a', 0,
    'a', 'r', 'c', 'T', 'o', 0,
    'a', 't', 'E', 'n', 'd', 0,
    'a', 'z', 'u', 'r', 'e', 0,
    'b', 'e', 'g', 'i', 'n', 0,
    'b', 'e', 'i', 'g', 'e', 0,
    'b', 'l', 'a', 'c', 'k', 0,
    'b', 'l', 'o', 'c', 'k', 0,
    'b', 'l', 'u', 'e', '8', 0,
    'b', 'l', 'u', 'e', 'F', 0,
    'b', 'u', 'd', 'd', 'y', 0,
    'c', 'h', 'i', 'l', 'd', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'c', 'l', 'o', 'n', 'e', 0,
    'c', 'l', 'o', 's', 'e', 0,
    'c', 'o', 'l', 'o', 'r', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'c', 'y', 'a', 'n', 'F', 0,
    'd', 'e', 'l', 'i', 'm', 0,
    'd', 'e', 'l', 't', 'a', 0,
    'd', 'e', 'p', 't', 'h', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'i', 'r', 's', 't', 0,
    'f', 'i', 'x', 'u', 'p', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'f', 'l', 'u', 's', 'h', 0,
    'f', 'r', 'o', 'm', '_', 0,
    'g', 'a', 'm', 'm', 'a', 0,
    'h', 'i', 'n', 't', 's', 0,
    'h', 'o', 'v', 'e', 'r', 0,
    'i', 'm', 'a', 'g', 'e', 0,
    'i', 'n', 'd', 'e', 'x', 0,
    'i', 's', 'D', 'i', 'r', 0,
    'i', 'v', 'o', 'r', 'y', 0,
    'l', 'i', 'n', 'e', 'n', 0,
    'l', 'o', 'w', 'e', 'r', 0,
    'm', 'a', 't', 'c', 'h', 0,
    'm', 'e', 'r', 'g', 'e', 0,
    'm', 'k', 'd', 'i', 'r', 0,
    'm', 'o', 'd', 'e', 'l', 0,
    'n', 'l', 'e', 'r', 'p', 0,
    'o', 'l', 'i', 'v', 'e', 0,
    'o', 'r', 't', 'h', 'o', 0,
    'p', 'a', 'i', 'n', 't', 0,
    'p', 'h', 'a', 's', 'e', 0,
    'p', 'i', 'x', 'e', 'l', 0,
    'p', 'o', 'i', 'n', 't', 0,
    'p', 'r', 'i', 'n', 't', 0,
    'q', 'B', 'l', 'u', 'e', 0,
    'q', 'G', 'r', 'a', 'y', 0,
    'q', 'R', 'g', 'b', 'a', 0,
    'r', 'm', 'd', 'i', 'r', 0,
    's', 'h', 'a', 'p', 'e', 0,
    's', 'h', 'e', 'a', 'r', 0,
    's', 'l', 'e', 'r', 'p', 0,
    's', 'p', 'e', 'e', 'd', 0,
    's', 't', 'a', 'r', 't', 0,
    's', 't', 'o', 'p', 's', 0,
    's', 't', 'y', 'l', 'e', 0,
    't', 'i', 't', 'l', 'e', 0,
    't', 'o', 'H', 's', 'l', 0,
    't', 'o', 'H', 's', 'v', 0,
    'u', 'n', 'i', 't', 's', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'w', 'h', 'e', 'a', 't', 0,
    'w', 'i', 'd', 't', 'h', 0,
    'w', 'i', 'n', 'I', 'd', 0,
    'w', 'r', 'i', 't', 'e', 0,
    'x', 'T', 'i', 'l', 't', 0,
    'x', 'o', 'r', 'e', 'd', 0,
    'y', 'T', 'i', 'l', 't', 0,
    'B', 'a', 'c', 'k', 0,
    'C', 'M', 'Y', 'K', 0,
    'G', 'o', 'U', 'p', 0,
    'I', 'M', 'C', '1', 0,
    'I', 'M', 'C', '2', 0,
    'I', 'M', 'C', '3', 0,
    'I', 'M', 'C', '4', 0,
    'N', 'V', '1', '2', 0,
    'N', 'V', '2', '1', 0,
    'N', 'e', 'g', 'a', 0,
    'N', 'o', 't', 'e', 0,
    'P', 'i', 'c', 'a', 0,
    'P', 'u', 'c', 'k', 0,
    'Q', 'P', 'e', 'n', 0,
    'Q', 'u', 'i', 't', 0,
    'R', 'u', 'b', 'y', 0,
    'S', 'R', 'g', 'b', 0,
    'T', 'h', 'a', 'i', 0,
    'T', 'h', 'i', 'n', 0,
    'U', 'Y', 'V', 'Y', 0,
    'Y', 'U', 'Y', 'V', 0,
    'Y', 'V', '1', '2', 0,
    'a', 'q', 'u', 'a', 0,
    'a', 'x', 'i', 's', 0,
    'b', 'i', 't', 's', 0,
    'b', 'o', 'l', 'd', 0,
    'c', 'l', 'i', 'p', 0,
    'c', 'o', 'p', 'y', 0,
    'd', 'a', 'r', 'k', 0,
    'd', 'r', 'a', 'w', 0,
    'e', 'd', 'g', 'e', 0,
    'e', 'x', 'e', 'c', 0,
    'f', 'i', 'l', 'l', 0,
    'f', 'i', 'n', 'd', 0,
    'f', 'l', 'i', 'p', 0,
    'f', 'o', 'n', 't', 0,
    'f', 'r', 'o', 'm', 0,
    'g', 'o', 'l', 'd', 0,
    'h', 'i', 'd', 'e', 0,
    'h', 'o', 't', 'X', 0,
    'h', 'o', 't', 'Y', 0,
    'h', 'r', 'e', 'f', 0,
    'h', 'u', 'e', 'F', 0,
    'i', 'c', 'o', 'n', 0,
    'i', 't', 'e', 'm', 0,
    'j', 'o', 'i', 'n', 0,
    'k', 'e', 'y', '2', 0,
    'k', 'e', 'y', '3', 0,
    'k', 'e', 'y', '4', 0,
    'k', 'e', 'y', 's', 0,
    'l', 'a', 's', 't', 0,
    'l', 'i', 'm', 'e', 0,
    'l', 'i', 'n', 'k', 0,
    'l', 'o', 'a', 'd', 0,
    'm', 'a', 's', 'k', 0,
    'm', 'e', 'n', 'u', 0,
    'm', 'o', 'd', 'e', 0,
    'n', 'a', 'm', 'e', 0,
    'n', 'a', 'v', 'y', 0,
    'n', 'e', 'x', 't', 0,
    'p', 'e', 'r', 'u', 0,
    'p', 'l', 'u', 'm', 0,
    'p', 'u', 's', 'h', 0,
    'q', 'R', 'e', 'd', 0,
    'q', 'R', 'g', 'b', 0,
    'r', 'e', 'c', 't', 0,
    'r', 'e', 'd', '8', 0,
    'r', 'e', 'd', 'F', 0,
    'r', 'e', 'd', 'o', 0,
    'r', 'g', 'b', 'a', 0,
    'r', 'o', 'l', 'e', 0,
    'r', 'o', 'w', 's', 0,
    's', 'a', 'v', 'e', 0,
    's', 'e', 't', 'W', 0,
    's', 'e', 't', 'X', 0,
    's', 'e', 't', 'Y', 0,
    's', 'e', 't', 'Z', 0,
    's', 'h', 'o', 'w', 0,
    's', 'n', 'o', 'w', 0,
    's', 'o', 'r', 't', 0,
    's', 'p', 'a', 'n', 0,
    's', 'p', 'e', 'c', 0,
    's', 't', 'o', 'p', 0,
    's', 'w', 'a', 'p', 0,
    's', 'y', 'n', 'c', 0,
    't', 'a', 'b', 's', 0,
    't', 'e', 'a', 'l', 0,
    'u', 'n', 'd', 'o', 0,
    'A', '1', '0', 0,
    'A', 'n', 'y', 0,
    'B', 'G', 'R', 0,
    'C', '5', 'E', 0,
    'D', 'L', 'E', 0,
    'H', 'S', 'L', 0,
    'H', 'S', 'V', 0,
    'L', 'a', 'o', 0,
    'M', 'i', 'd', 0,
    'N', 'k', 'o', 0,
    'O', 'f', 'f', 0,
    'P', 'd', 'f', 0,
    'R', 'G', 'B', 0,
    'S', 'V', 'G', 0,
    'X', '1', '1', 0,
    'Y', '1', '6', 0,
    'Y', 'U', 'V', 0,
    'a', 'd', 'd', 0,
    'c', 'a', 'p', 0,
    'h', 'u', 'e', 0,
    'k', 'e', 'y', 0,
    'm', '1', '1', 0,
    'm', '1', '2', 0,
    'm', '1', '3', 0,
    'm', '2', '1', 0,
    'm', '2', '2', 0,
    'm', '2', '3', 0,
    'm', '3', '1', 0,
    'm', '3', '2', 0,
    'm', '3', '3', 0,
    'm', 'i', 'd', 0,
    'p', 'o', 's', 0,
    'r', 'o', 'w', 0,
    't', 'a', 'g', 0,
    't', 'i', 'p', 0,
    'u', 'r', 'l', 0,
    'A', '0', 0,
    'A', '1', 0,
    'A', '2', 0,
    'A', '3', 0,
    'A', '4', 0,
    'A', '5', 0,
    'A', '6', 0,
    'A', '7', 0,
    'A', '8', 0,
    'A', '9', 0,
    'O', 'n', 0,
    'Q', 't', 0,
    'Y', '8', 0,
    'd', 'x', 0,
    's', 'w', 0,
    's', 'x', 0,
    'z', 0,
};
#line 180 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
// Convert an optional Python list to a 0 terminated array of integers on the
// heap.
int *qtgui_tabarray(PyObject *l)
{
    if (!l || l == Py_None)
        return 0;

    int *arr = new int[PyList_Size(l) + 1];
    Py_ssize_t i;

    for (i = 0; i < PyList_Size(l); ++i)
        arr[i] = PyLong_AsLong(PyList_GetItem(l, i));

    arr[i] = 0;

    return arr;
}
#line 278 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qguiapplication.sip"
// Imports from QtCore.
pyqt6_qtgui_cleanup_qobjects_t pyqt6_qtgui_cleanup_qobjects;
pyqt6_qtgui_from_argv_list_t pyqt6_qtgui_from_argv_list;
pyqt6_qtgui_update_argv_list_t pyqt6_qtgui_update_argv_list;

// Forward declarations not in any header files but are part of the API.
void qt_set_sequence_auto_mnemonic(bool enable);
#line 367 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qimage.sip"
// Convert a list of strings to an array of ASCII strings on the heap.  Used by
// QImage and QPixmap.
const char **QtGui_ListToArray(PyObject *lst)
{
    Py_ssize_t nstr = PyList_Size(lst);
    const char **arr = new const char *[nstr + 1];

    for (Py_ssize_t i = 0; i < nstr; ++i)
    {
        PyObject *ascii_obj = PyList_GetItem(lst, i);
        const char *ascii = sipString_AsASCIIString(&ascii_obj);

        if (!ascii)
        {
            while (i-- > 0)
                delete[] arr[i];

            delete[] arr;

            return 0;
        }

        // Copy the string.
        arr[i] = qstrdup(ascii);

        Py_DECREF(ascii_obj);
    }

    // The sentinal.
    arr[nstr] = 0;

    return arr;
}


// Return a string array created by QtGui_ListToArray() to the heap.
void QtGui_DeleteArray(const char **arr)
{
    for (Py_ssize_t i = 0; arr[i]; ++i)
        delete[] arr[i];

    delete[] arr;
}

// Imports from QtCore.
pyqt6_qtgui_err_print_t pyqt6_qtgui_err_print;
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qmatrix4x4.sip"
#include <qmatrix4x4.h>
#line 204 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qmatrix4x4.sip"
// Convert a Python object to a row and column.
sipErrorState qtgui_matrixParseIndex(PyObject *tup, int nr_rows,
        int nr_columns, int *row, int *column)
{
    sipErrorState es = sipErrorContinue;

    if (PyTuple_Check(tup) && PyArg_ParseTuple(tup, "ii", row, column))
        if (*row >= 0 && *row < nr_rows && *column >= 0 && *column < nr_columns)
            es = sipErrorNone;

    if (es == sipErrorContinue)
        PyErr_Format(PyExc_IndexError, "an index must be a row in the range 0 to %d and a column in the range 0 to %d", nr_rows - 1, nr_columns - 1);

    return es;
}


// Convert a Python object to an array of qreals.
sipErrorState qtgui_matrixDataFromSequence(PyObject *seq, int nr_values,
        PYQT_FLOAT *values)
{
    sipErrorState es;

    if (PySequence_Size(seq) == nr_values)
    {
        es = sipErrorNone;

        for (int i = 0; i < nr_values; ++i)
        {
            PyObject *value = PySequence_GetItem(seq, i);

            if (!value)
            {
                es = sipErrorFail;
                break;
            }

            PyErr_Clear();

            double d = PyFloat_AsDouble(value);

            if (PyErr_Occurred())
            {
                Py_DECREF(value);
                es = sipErrorContinue;
                break;
            }

            Py_DECREF(value);

            *values++ = d;
        }
    }
    else
    {
        es = sipErrorContinue;
    }

    if (es == sipErrorContinue)
        PyErr_Format(PyExc_TypeError, "a sequence of %d floats is expected",
                nr_values);

    return es;
}


// Convert an array of qreals to a Python list.
sipErrorState qtgui_matrixDataAsList(int nr_values, const PYQT_FLOAT *values,
        PyObject **list)
{
    PyObject *l = PyList_New(nr_values);

    if (!l)
        return sipErrorFail;

    for (int i = 0; i < nr_values; ++i)
    {
        PyObject *value = PyFloat_FromDouble(*values++);

        if (!value)
        {
            Py_DECREF(l);
            return sipErrorFail;
        }

        PyList_SetItem(l, i, value);
    }

    *list = l;

    return sipErrorNone;
}
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixelformat.sip"
#include <qpixelformat.h>
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qrgba64.sip"
#include <qrgba64.h>
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qrgb.sip"
#include <qrgb.h>
#line 163 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qshortcut.sip"
// Imports from QtCore.
pyqt6_qtgui_get_connection_parts_t pyqt6_qtgui_get_connection_parts;
#line 256 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
// Wrap a QObject and ensure that it's ancestors are all wrapped with the
// correct ownerships.
static PyObject *qtgui_wrap_ancestors_worker(QObject *obj)
{
    if (!obj)
    {
        Py_INCREF(Py_None);
        return Py_None;
    }

    PyObject *py_parent = qtgui_wrap_ancestors_worker(obj->parent());

    if (!py_parent)
        return 0;

    PyObject *py_obj = sipConvertFromType(obj, sipType_QObject,
            (py_parent != Py_None ? py_parent : 0));

    Py_DECREF(py_parent);
    return py_obj;
}

PyObject *qtgui_wrap_ancestors(QObject *obj, const sipTypeDef *td)
{
    PyObject *py_parent = qtgui_wrap_ancestors_worker(obj->parent());

    if (!py_parent)
        return 0;

    PyObject *py_obj = sipConvertFromType(obj, td,
            (py_parent != Py_None ? py_parent : 0));

    Py_DECREF(py_parent);

    return py_obj;
}
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 4722 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"

void* sipVH_QtGui_161(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    void* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "V", &sipRes);

    return sipRes;
}

void sipVH_QtGui_160(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QString& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", &a0, sipType_QString, SIP_NULLPTR);
}

void sipVH_QtGui_159(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QString& a0)
{
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", &a0, sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &a0);
}

::QValidator::State sipVH_QtGui_158(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QString& a0, int& a1)
{
    ::QValidator::State sipRes = ::QValidator::Invalid;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "Di", &a0, sipType_QString, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(FH5i)", sipType_QValidator_State, &sipRes, sipType_QString, &a0, &a1);

    return sipRes;
}

bool sipVH_QtGui_157(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QUndoCommand*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", const_cast< ::QUndoCommand *>(a0), sipType_QUndoCommand, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_156(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QTextBlock& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QTextBlock(a0), sipType_QTextBlock, SIP_NULLPTR);
}

::QVariant sipVH_QtGui_155(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, const ::QUrl& a1)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iN", a0, new ::QUrl(a1), sipType_QUrl, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

::QTextObject* sipVH_QtGui_154(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QTextFormat& a0)
{
    ::QTextObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QTextFormat(a0), sipType_QTextFormat, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QTextObject, &sipRes);

    return sipRes;
}

void sipVH_QtGui_153(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);
}

bool sipVH_QtGui_152(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QStandardItem& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", const_cast< ::QStandardItem *>(&a0), sipType_QStandardItem, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_151(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDataStream& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", &a0, sipType_QDataStream, SIP_NULLPTR);
}

::QStandardItem* sipVH_QtGui_150(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QStandardItem* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QStandardItem, &sipRes);

    return sipRes;
}

void sipVH_QtGui_149(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QVariant& a0, int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "Ni", new ::QVariant(a0), sipType_QVariant, SIP_NULLPTR, a1);
}

::QVariant sipVH_QtGui_148(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

::QMimeData* sipVH_QtGui_147(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndexList& a0)
{
    ::QMimeData* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndexList(a0), sipType_QList_0100QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QMimeData, &sipRes);

    return sipRes;
}

void sipVH_QtGui_146(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const char*a0, uint a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "g", a0, (Py_ssize_t)a1);
}

::QPaintEngine::Type sipVH_QtGui_145(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPaintEngine::Type sipRes = ::QPaintEngine::X11;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QPaintEngine_Type, &sipRes);

    return sipRes;
}

void sipVH_QtGui_144(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QRectF& a0, const ::QImage& a1, const ::QRectF& a2, ::Qt::ImageConversionFlags a3)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NNNN", new ::QRectF(a0), sipType_QRectF, SIP_NULLPTR, new ::QImage(a1), sipType_QImage, SIP_NULLPTR, new ::QRectF(a2), sipType_QRectF, SIP_NULLPTR, new ::Qt::ImageConversionFlags(a3), sipType_QFlags_0100Qt_ImageConversionFlag, SIP_NULLPTR);
}

void sipVH_QtGui_143(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QRectF& a0, const ::QPixmap& a1, const ::QPointF& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NNN", new ::QRectF(a0), sipType_QRectF, SIP_NULLPTR, new ::QPixmap(a1), sipType_QPixmap, SIP_NULLPTR, new ::QPointF(a2), sipType_QPointF, SIP_NULLPTR);
}

void sipVH_QtGui_142(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPointF& a0, const ::QTextItem& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "ND", new ::QPointF(a0), sipType_QPointF, SIP_NULLPTR, const_cast< ::QTextItem *>(&a1), sipType_QTextItem, SIP_NULLPTR);
}

void sipVH_QtGui_141(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QRectF& a0, const ::QPixmap& a1, const ::QRectF& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NNN", new ::QRectF(a0), sipType_QRectF, SIP_NULLPTR, new ::QPixmap(a1), sipType_QPixmap, SIP_NULLPTR, new ::QRectF(a2), sipType_QRectF, SIP_NULLPTR);
}

void sipVH_QtGui_140(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPoint*a0, int a1, ::QPaintEngine::PolygonDrawMode a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "rF", const_cast< ::QPoint *>(a0), (Py_ssize_t)a1, sipType_QPoint, a2, sipType_QPaintEngine_PolygonDrawMode);
}

void sipVH_QtGui_139(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPointF*a0, int a1, ::QPaintEngine::PolygonDrawMode a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "rF", const_cast< ::QPointF *>(a0), (Py_ssize_t)a1, sipType_QPointF, a2, sipType_QPaintEngine_PolygonDrawMode);
}

void sipVH_QtGui_138(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPoint*a0, int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QPoint *>(a0), (Py_ssize_t)a1, sipType_QPoint);
}

void sipVH_QtGui_137(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPointF*a0, int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QPointF *>(a0), (Py_ssize_t)a1, sipType_QPointF);
}

void sipVH_QtGui_136(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPainterPath& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QPainterPath(a0), sipType_QPainterPath, SIP_NULLPTR);
}

void sipVH_QtGui_135(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QRect& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QRect(a0), sipType_QRect, SIP_NULLPTR);
}

void sipVH_QtGui_134(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QRectF& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QRectF(a0), sipType_QRectF, SIP_NULLPTR);
}

void sipVH_QtGui_133(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QLineF*a0, int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QLineF *>(a0), (Py_ssize_t)a1, sipType_QLineF);
}

void sipVH_QtGui_132(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QLine*a0, int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QLine *>(a0), (Py_ssize_t)a1, sipType_QLine);
}

void sipVH_QtGui_131(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QRectF*a0, int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QRectF *>(a0), (Py_ssize_t)a1, sipType_QRectF);
}

void sipVH_QtGui_130(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QRect*a0, int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QRect *>(a0), (Py_ssize_t)a1, sipType_QRect);
}

void sipVH_QtGui_129(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPaintEngineState& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", const_cast< ::QPaintEngineState *>(&a0), sipType_QPaintEngineState, SIP_NULLPTR);
}

bool sipVH_QtGui_128(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintDevice*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QPaintDevice, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_127(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NV", new ::QByteArray(a0), sipType_QByteArray, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(bH4)", &sipRes, sipType_qintptr, a2);

    return sipRes;
}

void sipVH_QtGui_126(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCloseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QCloseEvent, SIP_NULLPTR);
}

void sipVH_QtGui_125(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPaintEvent, SIP_NULLPTR);
}

void sipVH_QtGui_124(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTabletEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTabletEvent, SIP_NULLPTR);
}

void sipVH_QtGui_123(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTouchEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTouchEvent, SIP_NULLPTR);
}

void sipVH_QtGui_122(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWheelEvent, SIP_NULLPTR);
}

void sipVH_QtGui_121(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMouseEvent, SIP_NULLPTR);
}

void sipVH_QtGui_120(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QKeyEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QKeyEvent, SIP_NULLPTR);
}

void sipVH_QtGui_119(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QHideEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QHideEvent, SIP_NULLPTR);
}

void sipVH_QtGui_118(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QShowEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QShowEvent, SIP_NULLPTR);
}

void sipVH_QtGui_117(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QFocusEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QFocusEvent, SIP_NULLPTR);
}

void sipVH_QtGui_116(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMoveEvent, SIP_NULLPTR);
}

void sipVH_QtGui_115(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QResizeEvent, SIP_NULLPTR);
}

void sipVH_QtGui_114(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QExposeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QExposeEvent, SIP_NULLPTR);
}

::QObject* sipVH_QtGui_113(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QObject, &sipRes);

    return sipRes;
}

void sipVH_QtGui_112(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPageRanges& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QPageRanges(a0), sipType_QPageRanges, SIP_NULLPTR);
}

bool sipVH_QtGui_111(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMarginsF& a0, ::QPageLayout::Unit a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NF", new ::QMarginsF(a0), sipType_QMarginsF, SIP_NULLPTR, a1, sipType_QPageLayout_Unit);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_110(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPageLayout::Orientation a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QPageLayout_Orientation);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_109(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPageLayout& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPageLayout(a0), sipType_QPageLayout, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_108(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPageSize& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPageSize(a0), sipType_QPageSize, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QSize sipVH_QtGui_107(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

::QSurface::SurfaceType sipVH_QtGui_106(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSurface::SurfaceType sipRes = ::QSurface::RasterSurface;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QSurface_SurfaceType, &sipRes);

    return sipRes;
}

::QSurfaceFormat sipVH_QtGui_105(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSurfaceFormat sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSurfaceFormat, &sipRes);

    return sipRes;
}

::QRect sipVH_QtGui_104(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QRect sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRect, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_103(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_102(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QImageIOHandler::ImageOption a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QImageIOHandler_ImageOption);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_101(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QImageIOHandler::ImageOption a0, const ::QVariant& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "FN", a0, sipType_QImageIOHandler_ImageOption, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);
}

::QVariant sipVH_QtGui_100(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QImageIOHandler::ImageOption a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QImageIOHandler_ImageOption);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_99(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QImage& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QImage(a0), sipType_QImage, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_98(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QImage*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QImage, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QPixmap sipVH_QtGui_97(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QSize& a0, ::QIcon::Mode a1, ::QIcon::State a2, ::qreal a3)
{
    ::QPixmap sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NFFd", new ::QSize(a0), sipType_QSize, SIP_NULLPTR, a1, sipType_QIcon_Mode, a2, sipType_QIcon_State, a3);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QPixmap, &sipRes);

    return sipRes;
}

QList< ::QSize> sipVH_QtGui_96(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QIcon::Mode a0, ::QIcon::State a1)
{
    QList< ::QSize> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FF", a0, sipType_QIcon_Mode, a1, sipType_QIcon_State);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QSize, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_95(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDataStream& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", &a0, sipType_QDataStream, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QIconEngine* sipVH_QtGui_94(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QIconEngine* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QIconEngine, &sipRes);

    return sipRes;
}

::QString sipVH_QtGui_93(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

void sipVH_QtGui_92(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, const ::QSize& a1, ::QIcon::Mode a2, ::QIcon::State a3)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NNFF", new ::QString(a0), sipType_QString, SIP_NULLPTR, new ::QSize(a1), sipType_QSize, SIP_NULLPTR, a2, sipType_QIcon_Mode, a3, sipType_QIcon_State);
}

void sipVH_QtGui_91(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPixmap& a0, ::QIcon::Mode a1, ::QIcon::State a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NFF", new ::QPixmap(a0), sipType_QPixmap, SIP_NULLPTR, a1, sipType_QIcon_Mode, a2, sipType_QIcon_State);
}

::QPixmap sipVH_QtGui_90(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QSize& a0, ::QIcon::Mode a1, ::QIcon::State a2)
{
    ::QPixmap sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NFF", new ::QSize(a0), sipType_QSize, SIP_NULLPTR, a1, sipType_QIcon_Mode, a2, sipType_QIcon_State);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QPixmap, &sipRes);

    return sipRes;
}

::QSize sipVH_QtGui_89(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QSize& a0, ::QIcon::Mode a1, ::QIcon::State a2)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NFF", new ::QSize(a0), sipType_QSize, SIP_NULLPTR, a1, sipType_QIcon_Mode, a2, sipType_QIcon_State);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

void sipVH_QtGui_88(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QRect& a1, ::QIcon::Mode a2, ::QIcon::State a3)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DNFF", a0, sipType_QPainter, SIP_NULLPTR, new ::QRect(a1), sipType_QRect, SIP_NULLPTR, a2, sipType_QIcon_Mode, a3, sipType_QIcon_State);
}

::QModelIndex sipVH_QtGui_87(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1, const ::QModelIndex& a2)
{
    ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iiN", a0, a1, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

int sipVH_QtGui_86(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtGui_85(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "Ni", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_84(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, const ::QVariant& a1, int a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NNi", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR, a2);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtGui_83(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::Orientation a1, int a2)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iFi", a0, a1, sipType_Qt_Orientation, a2);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_82(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::Orientation a1, const ::QVariant& a2, int a3)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iFNi", a0, a1, sipType_Qt_Orientation, new ::QVariant(a2), sipType_QVariant, SIP_NULLPTR, a3);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

QMap<int, ::QVariant> sipVH_QtGui_81(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    QMap<int, ::QVariant> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QMap_1800_0100QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_80(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, const QMap<int, ::QVariant>& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new QMap<int, ::QVariant>(a1), sipType_QMap_1800_0100QVariant, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QStringList sipVH_QtGui_79(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QStringList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QStringList, &sipRes);

    return sipRes;
}

::QMimeData* sipVH_QtGui_78(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndexList& a0)
{
    ::QMimeData* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndexList(a0), sipType_QList_0100QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QMimeData, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_77(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1, const ::QModelIndex& a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iiN", a0, a1, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_76(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);
}

::Qt::ItemFlags sipVH_QtGui_75(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::Qt::ItemFlags sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QFlags_0100Qt_ItemFlag, &sipRes);

    return sipRes;
}

void sipVH_QtGui_74(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::SortOrder a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iF", a0, a1, sipType_Qt_SortOrder);
}

::QModelIndex sipVH_QtGui_73(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

::QModelIndexList sipVH_QtGui_72(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1, const ::QVariant& a2, int a3, ::Qt::MatchFlags a4)
{
    ::QModelIndexList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NiNiN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, new ::QVariant(a2), sipType_QVariant, SIP_NULLPTR, a3, new ::Qt::MatchFlags(a4), sipType_QFlags_0100Qt_MatchFlag, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QModelIndex, &sipRes);

    return sipRes;
}

::QSize sipVH_QtGui_71(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

::Qt::DropActions sipVH_QtGui_70(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::Qt::DropActions sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QFlags_0100Qt_DropAction, &sipRes);

    return sipRes;
}

QHash<int, ::QByteArray> sipVH_QtGui_69(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    QHash<int, ::QByteArray> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QHash_1800_0100QByteArray, &sipRes);

    return sipRes;
}

void sipVH_QtGui_68(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

bool sipVH_QtGui_67(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DFiiN", const_cast< ::QMimeData *>(a0), sipType_QMimeData, SIP_NULLPTR, a1, sipType_Qt_DropAction, a2, a3, new ::QModelIndex(a4), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_66(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1, int a2, const ::QModelIndex& a3, int a4)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NiiNi", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, a2, new ::QModelIndex(a3), sipType_QModelIndex, SIP_NULLPTR, a4);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_65(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_64(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, ::QModelRoleDataSpan a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new ::QModelRoleDataSpan(a1), sipType_QModelRoleDataSpan, SIP_NULLPTR);
}

::QChildWindowEvent* sipVH_QtGui_63(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QChildWindowEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QChildWindowEvent, &sipRes);

    return sipRes;
}

::QTouchEvent* sipVH_QtGui_62(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QTouchEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QTouchEvent, &sipRes);

    return sipRes;
}

::QNativeGestureEvent* sipVH_QtGui_61(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QNativeGestureEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QNativeGestureEvent, &sipRes);

    return sipRes;
}

::QTabletEvent* sipVH_QtGui_60(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QTabletEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QTabletEvent, &sipRes);

    return sipRes;
}

::QWheelEvent* sipVH_QtGui_59(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QWheelEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QWheelEvent, &sipRes);

    return sipRes;
}

::QHoverEvent* sipVH_QtGui_58(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QHoverEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QHoverEvent, &sipRes);

    return sipRes;
}

::QMouseEvent* sipVH_QtGui_57(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QMouseEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QMouseEvent, &sipRes);

    return sipRes;
}

::QEnterEvent* sipVH_QtGui_56(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QEnterEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QEnterEvent, &sipRes);

    return sipRes;
}

::QSinglePointEvent* sipVH_QtGui_55(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSinglePointEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QSinglePointEvent, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_54(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QPointerEvent* sipVH_QtGui_53(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPointerEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QPointerEvent, &sipRes);

    return sipRes;
}

::QPlatformSurfaceEvent* sipVH_QtGui_52(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPlatformSurfaceEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QPlatformSurfaceEvent, &sipRes);

    return sipRes;
}

::QScrollEvent* sipVH_QtGui_51(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QScrollEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QScrollEvent, &sipRes);

    return sipRes;
}

::QScrollPrepareEvent* sipVH_QtGui_50(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QScrollPrepareEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QScrollPrepareEvent, &sipRes);

    return sipRes;
}

::QExposeEvent* sipVH_QtGui_49(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QExposeEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QExposeEvent, &sipRes);

    return sipRes;
}

::QWindowStateChangeEvent* sipVH_QtGui_48(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QWindowStateChangeEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QWindowStateChangeEvent, &sipRes);

    return sipRes;
}

::QShortcutEvent* sipVH_QtGui_47(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QShortcutEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QShortcutEvent, &sipRes);

    return sipRes;
}

::QFileOpenEvent* sipVH_QtGui_46(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QFileOpenEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QFileOpenEvent, &sipRes);

    return sipRes;
}

::QActionEvent* sipVH_QtGui_45(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QActionEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QActionEvent, &sipRes);

    return sipRes;
}

::QWhatsThisClickedEvent* sipVH_QtGui_44(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QWhatsThisClickedEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QWhatsThisClickedEvent, &sipRes);

    return sipRes;
}

::QStatusTipEvent* sipVH_QtGui_43(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QStatusTipEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QStatusTipEvent, &sipRes);

    return sipRes;
}

::QHelpEvent* sipVH_QtGui_42(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QHelpEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QHelpEvent, &sipRes);

    return sipRes;
}

::QDragLeaveEvent* sipVH_QtGui_41(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QDragLeaveEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QDragLeaveEvent, &sipRes);

    return sipRes;
}

::QDragEnterEvent* sipVH_QtGui_40(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QDragEnterEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QDragEnterEvent, &sipRes);

    return sipRes;
}

::QDragMoveEvent* sipVH_QtGui_39(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QDragMoveEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QDragMoveEvent, &sipRes);

    return sipRes;
}

::QDropEvent* sipVH_QtGui_38(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QDropEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QDropEvent, &sipRes);

    return sipRes;
}

::QInputMethodQueryEvent* sipVH_QtGui_37(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QInputMethodQueryEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QInputMethodQueryEvent, &sipRes);

    return sipRes;
}

::QInputMethodEvent* sipVH_QtGui_36(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QInputMethodEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QInputMethodEvent, &sipRes);

    return sipRes;
}

::QContextMenuEvent* sipVH_QtGui_35(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QContextMenuEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QContextMenuEvent, &sipRes);

    return sipRes;
}

::QHideEvent* sipVH_QtGui_34(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QHideEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QHideEvent, &sipRes);

    return sipRes;
}

::QShowEvent* sipVH_QtGui_33(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QShowEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QShowEvent, &sipRes);

    return sipRes;
}

::QIconDragEvent* sipVH_QtGui_32(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QIconDragEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QIconDragEvent, &sipRes);

    return sipRes;
}

::QCloseEvent* sipVH_QtGui_31(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCloseEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QCloseEvent, &sipRes);

    return sipRes;
}

::QResizeEvent* sipVH_QtGui_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QResizeEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QResizeEvent, &sipRes);

    return sipRes;
}

::QMoveEvent* sipVH_QtGui_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QMoveEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QMoveEvent, &sipRes);

    return sipRes;
}

::QPaintEvent* sipVH_QtGui_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPaintEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QPaintEvent, &sipRes);

    return sipRes;
}

::QFocusEvent* sipVH_QtGui_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QFocusEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QFocusEvent, &sipRes);

    return sipRes;
}

::QKeyEvent* sipVH_QtGui_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QKeyEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QKeyEvent, &sipRes);

    return sipRes;
}

void sipVH_QtGui_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "b", a0);
}

::QInputEvent* sipVH_QtGui_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QInputEvent* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QInputEvent, &sipRes);

    return sipRes;
}

int sipVH_QtGui_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintDevice::PaintDeviceMetric a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QPaintDevice_PaintDeviceMetric);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QPaintEngine* sipVH_QtGui_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPaintEngine* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPaintEngine, &sipRes);

    return sipRes;
}

void sipVH_QtGui_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QRectF& a1, ::QTextDocument*a2, int a3, const ::QTextFormat& a4)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DNDiN", a0, sipType_QPainter, SIP_NULLPTR, new ::QRectF(a1), sipType_QRectF, SIP_NULLPTR, a2, sipType_QTextDocument, SIP_NULLPTR, a3, new ::QTextFormat(a4), sipType_QTextFormat, SIP_NULLPTR);
}

::QSizeF sipVH_QtGui_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTextDocument*a0, int a1, const ::QTextFormat& a2)
{
    ::QSizeF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DiN", a0, sipType_QTextDocument, SIP_NULLPTR, a1, new ::QTextFormat(a2), sipType_QTextFormat, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSizeF, &sipRes);

    return sipRes;
}

void sipVH_QtGui_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QRectF& a1, ::QTextInlineObject a2, int a3, const ::QTextFormat& a4)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DNNiN", a0, sipType_QPainter, SIP_NULLPTR, new ::QRectF(a1), sipType_QRectF, SIP_NULLPTR, new ::QTextInlineObject(a2), sipType_QTextInlineObject, SIP_NULLPTR, a3, new ::QTextFormat(a4), sipType_QTextFormat, SIP_NULLPTR);
}

void sipVH_QtGui_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTextInlineObject a0, int a1, const ::QTextFormat& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NiN", new ::QTextInlineObject(a0), sipType_QTextInlineObject, SIP_NULLPTR, a1, new ::QTextFormat(a2), sipType_QTextFormat, SIP_NULLPTR);
}

void sipVH_QtGui_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1, int a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iii", a0, a1, a2);
}

::QRectF sipVH_QtGui_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QTextBlock& a0)
{
    ::QRectF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QTextBlock(a0), sipType_QTextBlock, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRectF, &sipRes);

    return sipRes;
}

::QRectF sipVH_QtGui_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTextFrame*a0)
{
    ::QRectF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QTextFrame, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRectF, &sipRes);

    return sipRes;
}

::QSizeF sipVH_QtGui_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSizeF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSizeF, &sipRes);

    return sipRes;
}

int sipVH_QtGui_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

int sipVH_QtGui_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPointF& a0, ::Qt::HitTestAccuracy a1)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NF", new ::QPointF(a0), sipType_QPointF, SIP_NULLPTR, a1, sipType_Qt_HitTestAccuracy);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtGui_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QAbstractTextDocumentLayout::PaintContext& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DN", a0, sipType_QPainter, SIP_NULLPTR, new ::QAbstractTextDocumentLayout::PaintContext(a1), sipType_QAbstractTextDocumentLayout_PaintContext, SIP_NULLPTR);
}

bool sipVH_QtGui_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtGui_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtGui_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtGui_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

::QAbstractFileIconProvider::Options sipVH_QtGui_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QAbstractFileIconProvider::Options sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QFlags_0100QAbstractFileIconProvider_Option, &sipRes);

    return sipRes;
}

void sipVH_QtGui_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAbstractFileIconProvider::Options a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QAbstractFileIconProvider::Options(a0), sipType_QFlags_0100QAbstractFileIconProvider_Option, SIP_NULLPTR);
}

::QString sipVH_QtGui_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QFileInfo& a0)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QFileInfo(a0), sipType_QFileInfo, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

::QIcon sipVH_QtGui_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QFileInfo& a0)
{
    ::QIcon sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QFileInfo(a0), sipType_QFileInfo, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QIcon, &sipRes);

    return sipRes;
}

::QIcon sipVH_QtGui_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAbstractFileIconProvider::IconType a0)
{
    ::QIcon sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QAbstractFileIconProvider_IconType);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QIcon, &sipRes);

    return sipRes;
}


PyDoc_STRVAR(doc_qGray, "qGray(r: int, g: int, b: int) -> int\n"
"qGray(rgb: int) -> int");

extern "C" {static PyObject *func_qGray(PyObject *, PyObject *);}
static PyObject *func_qGray(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;

        if (sipParseArgs(&sipParseErr, sipArgs, "iii", &a0, &a1, &a2))
        {
            int sipRes;

            sipRes = qGray(a0, a1, a2);

            return PyLong_FromLong(sipRes);
        }
    }

    {
        ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            int sipRes;

            sipRes = qGray(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qGray, doc_qGray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qRgba, "qRgba(r: int, g: int, b: int, a: int) -> int");

extern "C" {static PyObject *func_qRgba(PyObject *, PyObject *);}
static PyObject *func_qRgba(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        int a3;

        if (sipParseArgs(&sipParseErr, sipArgs, "iiii", &a0, &a1, &a2, &a3))
        {
            ::QRgb sipRes;

            sipRes = qRgba(a0, a1, a2, a3);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qRgba, doc_qRgba);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qRgb, "qRgb(r: int, g: int, b: int) -> int");

extern "C" {static PyObject *func_qRgb(PyObject *, PyObject *);}
static PyObject *func_qRgb(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;

        if (sipParseArgs(&sipParseErr, sipArgs, "iii", &a0, &a1, &a2))
        {
            ::QRgb sipRes;

            sipRes = qRgb(a0, a1, a2);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qRgb, doc_qRgb);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qAlpha, "qAlpha(rgb: QRgba64) -> int\n"
"qAlpha(rgb: int) -> int");

extern "C" {static PyObject *func_qAlpha(PyObject *, PyObject *);}
static PyObject *func_qAlpha(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
            ::uint sipRes;

            sipRes = qAlpha(*a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    {
        ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            int sipRes;

            sipRes = qAlpha(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qAlpha, doc_qAlpha);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qBlue, "qBlue(rgb: QRgba64) -> int\n"
"qBlue(rgb: int) -> int");

extern "C" {static PyObject *func_qBlue(PyObject *, PyObject *);}
static PyObject *func_qBlue(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
            ::uint sipRes;

            sipRes = qBlue(*a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    {
        ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            int sipRes;

            sipRes = qBlue(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qBlue, doc_qBlue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qGreen, "qGreen(rgb: QRgba64) -> int\n"
"qGreen(rgb: int) -> int");

extern "C" {static PyObject *func_qGreen(PyObject *, PyObject *);}
static PyObject *func_qGreen(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
            ::uint sipRes;

            sipRes = qGreen(*a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    {
        ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            int sipRes;

            sipRes = qGreen(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qGreen, doc_qGreen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qRed, "qRed(rgb: QRgba64) -> int\n"
"qRed(rgb: int) -> int");

extern "C" {static PyObject *func_qRed(PyObject *, PyObject *);}
static PyObject *func_qRed(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
            ::uint sipRes;

            sipRes = qRed(*a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    {
        ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            int sipRes;

            sipRes = qRed(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qRed, doc_qRed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qUnpremultiply, "qUnpremultiply(c: QRgba64) -> QRgba64\n"
"qUnpremultiply(p: int) -> int");

extern "C" {static PyObject *func_qUnpremultiply(PyObject *, PyObject *);}
static PyObject *func_qUnpremultiply(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
            ::QRgba64*sipRes;

            sipRes = new ::QRgba64(qUnpremultiply(*a0));

            return sipConvertFromNewType(sipRes, sipType_QRgba64, SIP_NULLPTR);
        }
    }

    {
        ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            ::QRgb sipRes;

            sipRes = qUnpremultiply(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qUnpremultiply, doc_qUnpremultiply);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPremultiply, "qPremultiply(c: QRgba64) -> QRgba64\n"
"qPremultiply(x: int) -> int");

extern "C" {static PyObject *func_qPremultiply(PyObject *, PyObject *);}
static PyObject *func_qPremultiply(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
            ::QRgba64*sipRes;

            sipRes = new ::QRgba64(qPremultiply(*a0));

            return sipConvertFromNewType(sipRes, sipType_QRgba64, SIP_NULLPTR);
        }
    }

    {
        ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            ::QRgb sipRes;

            sipRes = qPremultiply(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPremultiply, doc_qPremultiply);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qRgba64, "qRgba64(r: int, g: int, b: int, a: int) -> QRgba64\n"
"qRgba64(c: int) -> QRgba64");

extern "C" {static PyObject *func_qRgba64(PyObject *, PyObject *);}
static PyObject *func_qRgba64(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint16 a0;
        ::quint16 a1;
        ::quint16 a2;
        ::quint16 a3;

        if (sipParseArgs(&sipParseErr, sipArgs, "tttt", &a0, &a1, &a2, &a3))
        {
            ::QRgba64*sipRes;

            sipRes = new ::QRgba64(qRgba64(a0, a1, a2, a3));

            return sipConvertFromNewType(sipRes, sipType_QRgba64, SIP_NULLPTR);
        }
    }

    {
        ::quint64 a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "o", &a0))
        {
            ::QRgba64*sipRes;

            sipRes = new ::QRgba64(qRgba64(a0));

            return sipConvertFromNewType(sipRes, sipType_QRgba64, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qRgba64, doc_qRgba64);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatAlpha, "qPixelFormatAlpha(channelSize: int, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.UnsignedInteger) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatAlpha(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qPixelFormatAlpha(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uchar a0;
        ::QPixelFormat::TypeInterpretation a1 = QPixelFormat::UnsignedInteger;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "M|E", &a0, sipType_QPixelFormat_TypeInterpretation, &a1))
        {
            ::QPixelFormat*sipRes;

            sipRes = new ::QPixelFormat(qPixelFormatAlpha(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QPixelFormat, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatAlpha, doc_qPixelFormatAlpha);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatYuv, "qPixelFormatYuv(layout: QPixelFormat.YUVLayout, alphaSize: int = 0, alphaUsage: QPixelFormat.AlphaUsage = QPixelFormat.IgnoresAlpha, alphaPosition: QPixelFormat.AlphaPosition = QPixelFormat.AtBeginning, premultiplied: QPixelFormat.AlphaPremultiplied = QPixelFormat.NotPremultiplied, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.UnsignedByte, byteOrder: QPixelFormat.ByteOrder = QPixelFormat.LittleEndian) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatYuv(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qPixelFormatYuv(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPixelFormat::YUVLayout a0;
        ::uchar a1 = 0;
        ::QPixelFormat::AlphaUsage a2 = QPixelFormat::IgnoresAlpha;
        ::QPixelFormat::AlphaPosition a3 = QPixelFormat::AtBeginning;
        ::QPixelFormat::AlphaPremultiplied a4 = QPixelFormat::NotPremultiplied;
        ::QPixelFormat::TypeInterpretation a5 = QPixelFormat::UnsignedByte;
        ::QPixelFormat::ByteOrder a6 = QPixelFormat::LittleEndian;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_alphaSize,
            sipName_alphaUsage,
            sipName_alphaPosition,
            sipName_premultiplied,
            sipName_typeInterpretation,
            sipName_byteOrder,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "E|MEEEEE", sipType_QPixelFormat_YUVLayout, &a0, &a1, sipType_QPixelFormat_AlphaUsage, &a2, sipType_QPixelFormat_AlphaPosition, &a3, sipType_QPixelFormat_AlphaPremultiplied, &a4, sipType_QPixelFormat_TypeInterpretation, &a5, sipType_QPixelFormat_ByteOrder, &a6))
        {
            ::QPixelFormat*sipRes;

            sipRes = new ::QPixelFormat(qPixelFormatYuv(a0, a1, a2, a3, a4, a5, a6));

            return sipConvertFromNewType(sipRes, sipType_QPixelFormat, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatYuv, doc_qPixelFormatYuv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatHsv, "qPixelFormatHsv(channelSize: int, alphaSize: int = 0, alphaUsage: QPixelFormat.AlphaUsage = QPixelFormat.IgnoresAlpha, alphaPosition: QPixelFormat.AlphaPosition = QPixelFormat.AtBeginning, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.FloatingPoint) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatHsv(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qPixelFormatHsv(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uchar a0;
        ::uchar a1 = 0;
        ::QPixelFormat::AlphaUsage a2 = QPixelFormat::IgnoresAlpha;
        ::QPixelFormat::AlphaPosition a3 = QPixelFormat::AtBeginning;
        ::QPixelFormat::TypeInterpretation a4 = QPixelFormat::FloatingPoint;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_alphaSize,
            sipName_alphaUsage,
            sipName_alphaPosition,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "M|MEEE", &a0, &a1, sipType_QPixelFormat_AlphaUsage, &a2, sipType_QPixelFormat_AlphaPosition, &a3, sipType_QPixelFormat_TypeInterpretation, &a4))
        {
            ::QPixelFormat*sipRes;

            sipRes = new ::QPixelFormat(qPixelFormatHsv(a0, a1, a2, a3, a4));

            return sipConvertFromNewType(sipRes, sipType_QPixelFormat, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatHsv, doc_qPixelFormatHsv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatHsl, "qPixelFormatHsl(channelSize: int, alphaSize: int = 0, alphaUsage: QPixelFormat.AlphaUsage = QPixelFormat.IgnoresAlpha, alphaPosition: QPixelFormat.AlphaPosition = QPixelFormat.AtBeginning, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.FloatingPoint) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatHsl(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qPixelFormatHsl(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uchar a0;
        ::uchar a1 = 0;
        ::QPixelFormat::AlphaUsage a2 = QPixelFormat::IgnoresAlpha;
        ::QPixelFormat::AlphaPosition a3 = QPixelFormat::AtBeginning;
        ::QPixelFormat::TypeInterpretation a4 = QPixelFormat::FloatingPoint;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_alphaSize,
            sipName_alphaUsage,
            sipName_alphaPosition,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "M|MEEE", &a0, &a1, sipType_QPixelFormat_AlphaUsage, &a2, sipType_QPixelFormat_AlphaPosition, &a3, sipType_QPixelFormat_TypeInterpretation, &a4))
        {
            ::QPixelFormat*sipRes;

            sipRes = new ::QPixelFormat(qPixelFormatHsl(a0, a1, a2, a3, a4));

            return sipConvertFromNewType(sipRes, sipType_QPixelFormat, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatHsl, doc_qPixelFormatHsl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatCmyk, "qPixelFormatCmyk(channelSize: int, alphaSize: int = 0, alphaUsage: QPixelFormat.AlphaUsage = QPixelFormat.IgnoresAlpha, alphaPosition: QPixelFormat.AlphaPosition = QPixelFormat.AtBeginning, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.UnsignedInteger) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatCmyk(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qPixelFormatCmyk(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uchar a0;
        ::uchar a1 = 0;
        ::QPixelFormat::AlphaUsage a2 = QPixelFormat::IgnoresAlpha;
        ::QPixelFormat::AlphaPosition a3 = QPixelFormat::AtBeginning;
        ::QPixelFormat::TypeInterpretation a4 = QPixelFormat::UnsignedInteger;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_alphaSize,
            sipName_alphaUsage,
            sipName_alphaPosition,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "M|MEEE", &a0, &a1, sipType_QPixelFormat_AlphaUsage, &a2, sipType_QPixelFormat_AlphaPosition, &a3, sipType_QPixelFormat_TypeInterpretation, &a4))
        {
            ::QPixelFormat*sipRes;

            sipRes = new ::QPixelFormat(qPixelFormatCmyk(a0, a1, a2, a3, a4));

            return sipConvertFromNewType(sipRes, sipType_QPixelFormat, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatCmyk, doc_qPixelFormatCmyk);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatGrayscale, "qPixelFormatGrayscale(channelSize: int, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.UnsignedInteger) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatGrayscale(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qPixelFormatGrayscale(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uchar a0;
        ::QPixelFormat::TypeInterpretation a1 = QPixelFormat::UnsignedInteger;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "M|E", &a0, sipType_QPixelFormat_TypeInterpretation, &a1))
        {
            ::QPixelFormat*sipRes;

            sipRes = new ::QPixelFormat(qPixelFormatGrayscale(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QPixelFormat, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatGrayscale, doc_qPixelFormatGrayscale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatRgba, "qPixelFormatRgba(red: int, green: int, blue: int, alfa: int, usage: QPixelFormat.AlphaUsage, position: QPixelFormat.AlphaPosition, premultiplied: QPixelFormat.AlphaPremultiplied = QPixelFormat.NotPremultiplied, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.UnsignedInteger) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatRgba(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qPixelFormatRgba(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uchar a0;
        ::uchar a1;
        ::uchar a2;
        ::uchar a3;
        ::QPixelFormat::AlphaUsage a4;
        ::QPixelFormat::AlphaPosition a5;
        ::QPixelFormat::AlphaPremultiplied a6 = QPixelFormat::NotPremultiplied;
        ::QPixelFormat::TypeInterpretation a7 = QPixelFormat::UnsignedInteger;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_premultiplied,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "MMMMEE|EE", &a0, &a1, &a2, &a3, sipType_QPixelFormat_AlphaUsage, &a4, sipType_QPixelFormat_AlphaPosition, &a5, sipType_QPixelFormat_AlphaPremultiplied, &a6, sipType_QPixelFormat_TypeInterpretation, &a7))
        {
            ::QPixelFormat*sipRes;

            sipRes = new ::QPixelFormat(qPixelFormatRgba(a0, a1, a2, a3, a4, a5, a6, a7));

            return sipConvertFromNewType(sipRes, sipType_QPixelFormat, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatRgba, doc_qPixelFormatRgba);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qFuzzyCompare, "qFuzzyCompare(m1: QMatrix4x4, m2: QMatrix4x4) -> bool\n"
"qFuzzyCompare(q1: QQuaternion, q2: QQuaternion) -> bool\n"
"qFuzzyCompare(t1: QTransform, t2: QTransform) -> bool\n"
"qFuzzyCompare(v1: QVector4D, v2: QVector4D) -> bool\n"
"qFuzzyCompare(v1: QVector3D, v2: QVector3D) -> bool\n"
"qFuzzyCompare(v1: QVector2D, v2: QVector2D) -> bool");

extern "C" {static PyObject *func_qFuzzyCompare(PyObject *, PyObject *);}
static PyObject *func_qFuzzyCompare(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMatrix4x4* a0;
        const ::QMatrix4x4* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QMatrix4x4, &a0, sipType_QMatrix4x4, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QQuaternion* a0;
        const ::QQuaternion* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QQuaternion, &a0, sipType_QQuaternion, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QTransform* a0;
        const ::QTransform* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QTransform, &a0, sipType_QTransform, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QVector4D* a0;
        ::QVector4D* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QVector4D, &a0, sipType_QVector4D, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QVector3D* a0;
        ::QVector3D* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QVector3D, &a0, sipType_QVector3D, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QVector2D* a0;
        ::QVector2D* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QVector2D, &a0, sipType_QVector2D, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qFuzzyCompare, doc_qFuzzyCompare);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot___mul__(PyObject *, PyObject *);}
static PyObject *slot___mul__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        const ::QMatrix4x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QPoint, &a0, sipType_QMatrix4x4, &a1))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint((*a0 * *a1));

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    {
        const ::QPointF* a0;
        const ::QMatrix4x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QPointF, &a0, sipType_QMatrix4x4, &a1))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF((*a0 * *a1));

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    {
        const ::QPoint* a0;
        const ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QPoint, &a0, sipType_QTransform, &a1))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint((*a0 * *a1));

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    {
        const ::QPointF* a0;
        const ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QPointF, &a0, sipType_QTransform, &a1))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF((*a0 * *a1));

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    {
        const ::QLineF* a0;
        const ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QLineF, &a0, sipType_QTransform, &a1))
        {
            ::QLineF*sipRes;

            sipRes = new ::QLineF((*a0 * *a1));

            return sipConvertFromNewType(sipRes, sipType_QLineF, SIP_NULLPTR);
        }
    }

    {
        const ::QLine* a0;
        const ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QLine, &a0, sipType_QTransform, &a1))
        {
            ::QLine*sipRes;

            sipRes = new ::QLine((*a0 * *a1));

            return sipConvertFromNewType(sipRes, sipType_QLine, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


PyDoc_STRVAR(doc_qt_set_sequence_auto_mnemonic, "qt_set_sequence_auto_mnemonic(b: bool)");

extern "C" {static PyObject *func_qt_set_sequence_auto_mnemonic(PyObject *, PyObject *);}
static PyObject *func_qt_set_sequence_auto_mnemonic(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "b", &a0))
        {
            qt_set_sequence_auto_mnemonic(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qt_set_sequence_auto_mnemonic, doc_qt_set_sequence_auto_mnemonic);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot___rshift__(PyObject *, PyObject *);}
static PyObject *slot___rshift__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDataStream* a0;
        ::QColor* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QColor, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QBrush* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QBrush, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QColorSpace* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QColorSpace, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QCursor* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QCursor, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QFont* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QFont, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QFont::Tag* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QFont_Tag, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QMatrix4x3* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix4x3, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QMatrix4x2* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix4x2, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QMatrix3x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix3x4, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QMatrix3x3* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix3x3, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QMatrix3x2* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix3x2, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QMatrix2x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix2x4, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QMatrix2x3* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix2x3, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QMatrix2x2* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix2x2, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QIcon* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QIcon, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QImage* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QImage, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QKeySequence* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QKeySequence, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QMatrix4x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix4x4, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QPageRanges* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPageRanges, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QPainterPath* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPainterPath, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QPalette* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPalette, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QPen* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPen, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QPicture* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPicture, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QPixmap* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPixmap, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QPolygon* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPolygon, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QPolygonF* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPolygonF, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QQuaternion* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QQuaternion, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QRegion* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QRegion, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QStandardItem* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QStandardItem, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QTextTableCellFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextTableCellFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QTextFrameFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextFrameFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QTextListFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextListFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QTextBlockFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextBlockFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QTextCharFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextCharFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QTextLength* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextLength, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QTextFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTransform, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QVector4D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector4D, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QVector3D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector3D, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QVector2D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector2D, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot___lshift__(PyObject *, PyObject *);}
static PyObject *slot___lshift__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDataStream* a0;
        const ::QColor* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J1", sipType_QDataStream, &a0, sipType_QColor, &a1, &a1State))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QColor *>(a1), sipType_QColor, a1State);

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QBrush* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QBrush, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QColorSpace* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QColorSpace, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QCursor* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J1", sipType_QDataStream, &a0, sipType_QCursor, &a1, &a1State))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QCursor *>(a1), sipType_QCursor, a1State);

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QFont* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QFont, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QFont::Tag* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QFont_Tag, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QMatrix4x3* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix4x3, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QMatrix4x2* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix4x2, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QMatrix3x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix3x4, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QMatrix3x3* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix3x3, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QMatrix3x2* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix3x2, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QMatrix2x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix2x4, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QMatrix2x3* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix2x3, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QMatrix2x2* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix2x2, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QIcon* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QIcon, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QImage* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QImage, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QKeySequence* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J1", sipType_QDataStream, &a0, sipType_QKeySequence, &a1, &a1State))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QKeySequence *>(a1), sipType_QKeySequence, a1State);

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QMatrix4x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix4x4, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QPageRanges* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPageRanges, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QPainterPath* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPainterPath, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QPalette* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPalette, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QPen* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J1", sipType_QDataStream, &a0, sipType_QPen, &a1, &a1State))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QPen *>(a1), sipType_QPen, a1State);

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QPicture* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPicture, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QPixmap* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPixmap, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QPolygon* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPolygon, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QPolygonF* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPolygonF, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QQuaternion* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QQuaternion, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QRegion* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QRegion, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QStandardItem* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QStandardItem, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QTextTableCellFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextTableCellFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QTextFrameFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextFrameFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QTextListFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextListFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QTextBlockFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextBlockFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QTextCharFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextCharFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QTextLength* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextLength, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QTextFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextFormat, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        const ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTransform, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QVector4D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector4D, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QVector3D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector3D, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    {
        ::QDataStream* a0;
        ::QVector2D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector2D, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static void *init_type_QPointF(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPointF(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QPointF *sipCpp = SIP_NULLPTR;

    {
        ::QPainterPath::Element* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPainterPath_Element, &a0))
        {
            sipCpp = new ::QPointF(a0->operator ::QPointF());

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}

static sipInitExtenderDef initExtenders[] = {
    {init_type_QPointF, {55, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};

static sipPySlotExtenderDef slotExtenders[] = {
    {(void *)slot___mul__, mul_slot, {0, 0, 0}},
    {(void *)slot___rshift__, rshift_slot, {0, 0, 0}},
    {(void *)slot___lshift__, lshift_slot, {0, 0, 0}},
    {SIP_NULLPTR, (sipPySlotType)0, {0, 0, 0}}
};


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QGradient(void **);}
static const sipTypeDef *sipSubClass_QGradient(void **sipCppRet)
{
    ::QGradient *sipCpp = reinterpret_cast< ::QGradient *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 127 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbrush.sip"
    switch (sipCpp->type())
    {
    case QGradient::ConicalGradient:
        sipType = sipType_QConicalGradient;
        break;
    
    case QGradient::LinearGradient:
        sipType = sipType_QLinearGradient;
        break;
    
    case QGradient::RadialGradient:
        sipType = sipType_QRadialGradient;
        break;
    
    default:
        sipType = 0;
    }
#line 8339 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"

    return sipType;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QInputEvent(void **);}
static const sipTypeDef *sipSubClass_QInputEvent(void **sipCppRet)
{
    ::QEvent *sipCpp = reinterpret_cast< ::QEvent *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
    switch (sipCpp->type())
    {
    case QEvent::ActionAdded:
    case QEvent::ActionChanged:
    case QEvent::ActionRemoved:
        sipType = sipType_QActionEvent;
        break;
    
    case QEvent::Close:
        sipType = sipType_QCloseEvent;
        break;
    
    case QEvent::ContextMenu:
        sipType = sipType_QContextMenuEvent;
        break;
    
    case QEvent::DragEnter:
        sipType = sipType_QDragEnterEvent;
        break;
    
    case QEvent::DragLeave:
        sipType = sipType_QDragLeaveEvent;
        break;
    
    case QEvent::DragMove:
        sipType = sipType_QDragMoveEvent;
        break;
    
    case QEvent::Drop:
        sipType = sipType_QDropEvent;
        break;
    
    case QEvent::Enter:
        sipType = sipType_QEnterEvent;
        break;
    
    case QEvent::FileOpen:
        sipType = sipType_QFileOpenEvent;
        break;
    
    case QEvent::FocusIn:
    case QEvent::FocusOut:
        sipType = sipType_QFocusEvent;
        break;
    
    case QEvent::Hide:
        sipType = sipType_QHideEvent;
        break;
    
    case QEvent::HoverEnter:
    case QEvent::HoverLeave:
    case QEvent::HoverMove:
        sipType = sipType_QHoverEvent;
        break;
    
    case QEvent::IconDrag:
        sipType = sipType_QIconDragEvent;
        break;
    
    case QEvent::InputMethod:
        sipType = sipType_QInputMethodEvent;
        break;
    
    case QEvent::KeyPress:
    case QEvent::KeyRelease:
    case QEvent::ShortcutOverride:
        sipType = sipType_QKeyEvent;
        break;
    
    case QEvent::MouseButtonDblClick:
    case QEvent::MouseButtonPress:
    case QEvent::MouseButtonRelease:
    case QEvent::MouseMove:
        sipType = sipType_QMouseEvent;
        break;
    
    case QEvent::Move:
        sipType = sipType_QMoveEvent;
        break;
    
    case QEvent::Paint:
        sipType = sipType_QPaintEvent;
        break;
    
    case QEvent::Resize:
        sipType = sipType_QResizeEvent;
        break;
    
    case QEvent::Shortcut:
        sipType = sipType_QShortcutEvent;
        break;
    
    case QEvent::Show:
        sipType = sipType_QShowEvent;
        break;
    
    case QEvent::StatusTip:
        sipType = sipType_QStatusTipEvent;
        break;
    
    case QEvent::TabletMove:
    case QEvent::TabletPress:
    case QEvent::TabletRelease:
    case QEvent::TabletEnterProximity:
    case QEvent::TabletLeaveProximity:
        sipType = sipType_QTabletEvent;
        break;
    
    case QEvent::ToolTip:
    case QEvent::WhatsThis:
        sipType = sipType_QHelpEvent;
        break;
    
    case QEvent::WhatsThisClicked:
        sipType = sipType_QWhatsThisClickedEvent;
        break;
    
    case QEvent::Wheel:
        sipType = sipType_QWheelEvent;
        break;
    
    case QEvent::WindowStateChange:
        sipType = sipType_QWindowStateChangeEvent;
        break;
    
    case QEvent::TouchBegin:
    case QEvent::TouchUpdate:
    case QEvent::TouchEnd:
    case QEvent::TouchCancel:
        sipType = sipType_QTouchEvent;
        break;
    
    case QEvent::InputMethodQuery:
        sipType = sipType_QInputMethodQueryEvent;
        break;
    
    case QEvent::Expose:
        sipType = sipType_QExposeEvent;
        break;
    
    case QEvent::ScrollPrepare:
        sipType = sipType_QScrollPrepareEvent;
        break;
    
    case QEvent::Scroll:
        sipType = sipType_QScrollEvent;
        break;
    
    case QEvent::NativeGesture:
        sipType = sipType_QNativeGestureEvent;
        break;
    
    case QEvent::PlatformSurface:
        sipType = sipType_QPlatformSurfaceEvent;
        break;
    
    #if QT_VERSION >= 0x060700
    case QEvent::ChildWindowAdded:
    case QEvent::ChildWindowRemoved:
        sipType = sipType_QChildWindowEvent;
        break;
    #endif
    
    default:
        sipType = 0;
    }
#line 8519 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"

    return sipType;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QGuiApplication(void **);}
static const sipTypeDef *sipSubClass_QGuiApplication(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qguiapplication.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QAbstractTextDocumentLayout, &sipType_QAbstractTextDocumentLayout, -1, 1},
    #if QT_VERSION >= 0x060a00
        {sipName_QAccessibilityHints, &sipType_QAccessibilityHints, -1, 2},
    #else
        {0, 0, -1, 2},
    #endif
        {sipName_QAction, &sipType_QAction, -1, 3},
        {sipName_QActionGroup, &sipType_QActionGroup, -1, 4},
        {sipName_QClipboard, &sipType_QClipboard, -1, 5},
        {sipName_QValidator, &sipType_QValidator, 27, 6},
        {sipName_QDrag, &sipType_QDrag, -1, 7},
        {sipName_QFileSystemModel, &sipType_QFileSystemModel, -1, 8},
        {sipName_QGuiApplication, &sipType_QGuiApplication, -1, 9},
        {sipName_QInputDevice, &sipType_QInputDevice, 30, 10},
        {sipName_QInputMethod, &sipType_QInputMethod, -1, 11},
        {sipName_QMovie, &sipType_QMovie, -1, 12},
        {sipName_QOffscreenSurface, &sipType_QOffscreenSurface, -1, 13},
    #if defined(SIP_FEATURE_PyQt_OpenGL)
        {sipName_QOpenGLContext, &sipType_QOpenGLContext, -1, 14},
    #else
        {0, 0, -1, 14},
    #endif
    #if defined(SIP_FEATURE_PyQt_OpenGL)
        {sipName_QOpenGLContextGroup, &sipType_QOpenGLContextGroup, -1, 15},
    #else
        {0, 0, -1, 15},
    #endif
        {sipName_QWindow, &sipType_QWindow, 31, 16},
        {sipName_QPdfWriter, &sipType_QPdfWriter, -1, 17},
        {sipName_QScreen, &sipType_QScreen, -1, 18},
    #if defined(SIP_FEATURE_PyQt_SessionManager)
        {sipName_QSessionManager, &sipType_QSessionManager, -1, 19},
    #else
        {0, 0, -1, 19},
    #endif
        {sipName_QShortcut, &sipType_QShortcut, -1, 20},
        {sipName_QStandardItemModel, &sipType_QStandardItemModel, -1, 21},
        {sipName_QStyleHints, &sipType_QStyleHints, -1, 22},
        {sipName_QSyntaxHighlighter, &sipType_QSyntaxHighlighter, -1, 23},
        {sipName_QTextObject, &sipType_QTextObject, 33, 24},
        {sipName_QTextDocument, &sipType_QTextDocument, -1, 25},
        {sipName_QUndoGroup, &sipType_QUndoGroup, -1, 26},
        {sipName_QUndoStack, &sipType_QUndoStack, -1, -1},
        {sipName_QDoubleValidator, &sipType_QDoubleValidator, -1, 28},
        {sipName_QIntValidator, &sipType_QIntValidator, -1, 29},
        {sipName_QRegularExpressionValidator, &sipType_QRegularExpressionValidator, -1, -1},
        {sipName_QPointingDevice, &sipType_QPointingDevice, -1, -1},
        {sipName_QPaintDeviceWindow, &sipType_QPaintDeviceWindow, 32, -1},
        {sipName_QRasterWindow, &sipType_QRasterWindow, -1, -1},
        {sipName_QTextBlockGroup, &sipType_QTextBlockGroup, 35, 34},
        {sipName_QTextFrame, &sipType_QTextFrame, 36, -1},
        {sipName_QTextList, &sipType_QTextList, -1, -1},
        {sipName_QTextTable, &sipType_QTextTable, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 8610 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"

    return sipType;
}


/* This defines each external type declared in this module, */
static sipExternalTypeDef externalTypesTable[] = {
    {176, "QMenu"},
    {-1, SIP_NULLPTR}
};


extern "C" {static PyObject *slot_QKeySequence_StandardKey___eq__(PyObject *, PyObject *);}
static PyObject *slot_QKeySequence_StandardKey___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QKeySequence::StandardKey sipCpp = static_cast< ::QKeySequence::StandardKey>(sipConvertToEnum(sipSelf, sipType_QKeySequence_StandardKey));

    if (PyErr_Occurred())
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QKeyEvent* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J8", sipType_QKeyEvent, &a0))
        {
            bool sipRes;

            sipRes = operator==(sipCpp, a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QKeySequence_StandardKey[] = {
    {(void *)slot_QKeySequence_StandardKey___eq__, eq_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAbstractFileIconProvider__IconType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_IconType, 0, 7, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAbstractFileIconProvider__Option, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_Option, 0, 1, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAction__ActionEvent, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ActionEvent, 7, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAction__MenuRole, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_MenuRole, 7, 7, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAction__Priority, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Priority, 7, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QActionGroup__ExclusionPolicy, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ExclusionPolicy, 12, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QClipboard__Mode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Mode, 18, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QColor__NameFormat, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_NameFormat, 21, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QColor__Spec, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Spec, 21, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QColorSpace__ColorModel, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ColorModel, 26, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QColorSpace__NamedColorSpace, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_NamedColorSpace, 26, 8, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QColorSpace__Primaries, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Primaries, 26, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QColorSpace__TransferFunction, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_TransferFunction, 26, 8, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QColorSpace__TransformModel, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_TransformModel, 26, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QContextMenuEvent__Reason, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Reason, 35, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDoubleValidator__Notation, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Notation, 39, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QEventPoint__State, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_State, 47, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFileSystemModel__Option, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_Option, 51, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFileSystemModel__Roles, SIP_NULLPTR, 0}, SIP_ENUM_INT_ENUM, sipNameNr_Roles, 51, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFont__Capitalization, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Capitalization, 75, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFont__HintingPreference, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_HintingPreference, 75, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFont__SpacingType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_SpacingType, 75, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFont__Stretch, SIP_NULLPTR, 0}, SIP_ENUM_INT_ENUM, sipNameNr_Stretch, 75, 10, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFont__Style, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Style, 75, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFont__StyleHint, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_StyleHint, 75, 13, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFont__StyleStrategy, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_StyleStrategy, 75, 14, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFont__Weight, SIP_NULLPTR, 0}, SIP_ENUM_INT_ENUM, sipNameNr_Weight, 75, 9, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFontDatabase__SystemFont, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_SystemFont, 85, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QFontDatabase__WritingSystem, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_WritingSystem, 85, 35, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGlyphRun__GlyphRunFlag, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_GlyphRunFlag, 92, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGradient__CoordinateMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_CoordinateMode, 94, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGradient__Preset, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Preset, 94, 169, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGradient__Spread, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Spread, 94, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGradient__Type, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Type, 94, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QIcon__Mode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Mode, 103, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QIcon__State, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_State, 103, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QIcon__ThemeIcon, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ThemeIcon, 103, 150, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QIconEngine__IconEngineHook, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_IconEngineHook, 108, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QImage__Format, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Format, 111, 37, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QImage__InvertMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_InvertMode, 111, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QImageIOHandler__ImageOption, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ImageOption, 114, 18, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QImageIOHandler__Transformation, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_Transformation, 114, 8, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QImageReader__ImageReaderError, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ImageReaderError, 117, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QImageWriter__ImageWriterError, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ImageWriterError, 119, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QInputDevice__Capability, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_Capability, 121, 16, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QInputDevice__DeviceType, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_DeviceType, 121, 9, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QInputMethod__Action, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Action, 125, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QInputMethodEvent__AttributeType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_AttributeType, 127, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QKeySequence__SequenceFormat, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_SequenceFormat, 133, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QKeySequence__SequenceMatch, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_SequenceMatch, 133, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QKeySequence__StandardKey, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_StandardKey, 133, 71, slots_QKeySequence_StandardKey},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMovie__CacheMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_CacheMode, 179, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMovie__MovieState, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_MovieState, 179, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QOpenGLContext__OpenGLModuleType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_OpenGLModuleType, 187, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPageLayout__Mode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Mode, 190, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPageLayout__Orientation, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Orientation, 190, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPageLayout__OutOfBoundsPolicy, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_OutOfBoundsPolicy, 190, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPageLayout__Unit, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Unit, 190, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPageSize__PageSizeId, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_PageSizeId, 197, 125, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPageSize__SizeMatchPolicy, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_SizeMatchPolicy, 197, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPageSize__Unit, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Unit, 197, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPagedPaintDevice__PdfVersion, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_PdfVersion, 201, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPaintDevice__PaintDeviceMetric, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_PaintDeviceMetric, 203, 14, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPaintEngine__DirtyFlag, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_DirtyFlag, 206, 14, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPaintEngine__PaintEngineFeature, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_PaintEngineFeature, 206, 20, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPaintEngine__PolygonDrawMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_PolygonDrawMode, 206, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPaintEngine__Type, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Type, 206, 19, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPainter__CompositionMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_CompositionMode, 213, 38, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPainter__PixmapFragmentHint, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_PixmapFragmentHint, 213, 1, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPainter__RenderHint, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_RenderHint, 213, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPainterPath__ElementType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ElementType, 218, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPainterStateGuard__InitialState, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_InitialState, 222, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPalette__ColorGroup, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ColorGroup, 224, 7, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPalette__ColorRole, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ColorRole, 224, 23, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPdfWriter__ColorModel, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ColorModel, 228, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__AlphaPosition, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_AlphaPosition, 232, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__AlphaPremultiplied, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_AlphaPremultiplied, 232, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__AlphaUsage, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_AlphaUsage, 232, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__ByteOrder, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ByteOrder, 232, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__ColorModel, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ColorModel, 232, 9, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__TypeInterpretation, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_TypeInterpretation, 232, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__YUVLayout, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_YUVLayout, 232, 16, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPlatformSurfaceEvent__SurfaceEventType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_SurfaceEventType, 243, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPointingDevice__PointerType, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_PointerType, 246, 7, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QRawFont__AntialiasingType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_AntialiasingType, 256, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QRawFont__LayoutFlag, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_LayoutFlag, 256, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QRegion__RegionType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_RegionType, 259, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QScrollEvent__ScrollState, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ScrollState, 265, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSessionManager__RestartHint, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_RestartHint, 268, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QStandardItem__ItemType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_ItemType, 275, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QStaticText__PerformanceHint, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_PerformanceHint, 278, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSurface__SurfaceClass, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_SurfaceClass, 282, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSurface__SurfaceType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_SurfaceType, 282, 7, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSurfaceFormat__FormatOption, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_FormatOption, 285, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSurfaceFormat__OpenGLContextProfile, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_OpenGLContextProfile, 285, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSurfaceFormat__RenderableType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_RenderableType, 285, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSurfaceFormat__SwapBehavior, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_SwapBehavior, 285, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextBlockFormat__LineHeightTypes, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_LineHeightTypes, 294, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextBlockFormat__MarkerType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_MarkerType, 294, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextCharFormat__FontPropertiesInheritanceBehavior, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_FontPropertiesInheritanceBehavior, 299, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextCharFormat__UnderlineStyle, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_UnderlineStyle, 299, 8, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextCharFormat__VerticalAlignment, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_VerticalAlignment, 299, 7, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextCursor__MoveMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_MoveMode, 303, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextCursor__MoveOperation, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_MoveOperation, 303, 25, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextCursor__SelectionType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_SelectionType, 303, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextDocument__FindFlag, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_FindFlag, 307, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextDocument__MarkdownFeature, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_MarkdownFeature, 307, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextDocument__MetaInformation, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_MetaInformation, 307, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextDocument__ResourceType, SIP_NULLPTR, 0}, SIP_ENUM_INT_ENUM, sipNameNr_ResourceType, 307, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextDocument__Stacks, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Stacks, 307, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextFormat__FormatType, SIP_NULLPTR, 0}, SIP_ENUM_INT_ENUM, sipNameNr_FormatType, 315, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextFormat__ObjectTypes, SIP_NULLPTR, 0}, SIP_ENUM_INT_ENUM, sipNameNr_ObjectTypes, 315, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextFormat__PageBreakFlag, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_PageBreakFlag, 315, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextFormat__Property, SIP_NULLPTR, 0}, SIP_ENUM_INT_ENUM, sipNameNr_Property, 315, 115, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextFrameFormat__BorderStyle, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_BorderStyle, 323, 11, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextFrameFormat__Position, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Position, 323, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextItem__RenderFlag, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_RenderFlag, 328, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextLayout__CursorMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_CursorMode, 330, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextLayout__GlyphRunRetrievalFlag, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_GlyphRunRetrievalFlag, 330, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextLength__Type, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Type, 334, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextLine__CursorPosition, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_CursorPosition, 336, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextLine__Edge, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Edge, 336, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextListFormat__Style, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Style, 340, 8, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextOption__Flag, SIP_NULLPTR, 0}, SIP_ENUM_FLAG, sipNameNr_Flag, 344, 8, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextOption__TabType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_TabType, 344, 4, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTextOption__WrapMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_WrapMode, 344, 5, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTransform__TransformationType, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_TransformationType, 354, 6, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QValidator__State, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_State, 359, 3, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWindow__AncestorMode, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_AncestorMode, 366, 2, SIP_NULLPTR},
    {{SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWindow__Visibility, SIP_NULLPTR, 0}, SIP_ENUM_ENUM, sipNameNr_Visibility, 366, 6, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtGui[] = {
    &sipTypeDef_QtGui_QAbstractFileIconProvider.ctd_base,
    &enumTypes[0].etd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtGui_QAbstractTextDocumentLayout.ctd_base,
    &sipTypeDef_QtGui_QAbstractTextDocumentLayout_PaintContext.ctd_base,
    &sipTypeDef_QtGui_QAbstractTextDocumentLayout_Selection.ctd_base,
    &sipTypeDef_QtGui_QAccessibilityHints.ctd_base,
    &sipTypeDef_QtGui_QAction.ctd_base,
    &enumTypes[2].etd_base,
    &enumTypes[3].etd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtGui_QActionEvent.ctd_base,
    &sipTypeDef_QtGui_QActionGroup.ctd_base,
    &enumTypes[5].etd_base,
    &sipTypeDef_QtGui_QBackingStore.ctd_base,
    &sipTypeDef_QtGui_QBitmap.ctd_base,
    &sipTypeDef_QtGui_QBrush.ctd_base,
    &sipTypeDef_QtGui_QChildWindowEvent.ctd_base,
    &sipTypeDef_QtGui_QClipboard.ctd_base,
    &enumTypes[6].etd_base,
    &sipTypeDef_QtGui_QCloseEvent.ctd_base,
    &sipTypeDef_QtGui_QColor.ctd_base,
    &enumTypes[7].etd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtGui_QColorConstants.ctd_base,
    &sipTypeDef_QtGui_QColorConstants_Svg.ctd_base,
    &sipTypeDef_QtGui_QColorSpace.ctd_base,
    &enumTypes[9].etd_base,
    &enumTypes[10].etd_base,
    &enumTypes[11].etd_base,
    &sipTypeDef_QtGui_QColorSpace_PrimaryPoints.ctd_base,
    &enumTypes[12].etd_base,
    &enumTypes[13].etd_base,
    &sipTypeDef_QtGui_QColorTransform.ctd_base,
    &sipTypeDef_QtGui_QConicalGradient.ctd_base,
    &sipTypeDef_QtGui_QContextMenuEvent.ctd_base,
    &enumTypes[14].etd_base,
    &sipTypeDef_QtGui_QCursor.ctd_base,
    &sipTypeDef_QtGui_QDesktopServices.ctd_base,
    &sipTypeDef_QtGui_QDoubleValidator.ctd_base,
    &enumTypes[15].etd_base,
    &sipTypeDef_QtGui_QDrag.ctd_base,
    &sipTypeDef_QtGui_QDragEnterEvent.ctd_base,
    &sipTypeDef_QtGui_QDragLeaveEvent.ctd_base,
    &sipTypeDef_QtGui_QDragMoveEvent.ctd_base,
    &sipTypeDef_QtGui_QDropEvent.ctd_base,
    &sipTypeDef_QtGui_QEnterEvent.ctd_base,
    &sipTypeDef_QtGui_QEventPoint.ctd_base,
    &enumTypes[16].etd_base,
    &sipTypeDef_QtGui_QExposeEvent.ctd_base,
    &sipTypeDef_QtGui_QFileOpenEvent.ctd_base,
    &sipTypeDef_QtGui_QFileSystemModel.ctd_base,
    &enumTypes[17].etd_base,
    &enumTypes[18].etd_base,
    &sipTypeDef_QtGui_QFlags_0100QAbstractFileIconProvider_Option.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QEventPoint_State.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QFileSystemModel_Option.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QGlyphRun_GlyphRunFlag.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QImageIOHandler_Transformation.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QInputDevice_Capability.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QInputDevice_DeviceType.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QPaintEngine_DirtyFlag.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QPaintEngine_PaintEngineFeature.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QPainter_PixmapFragmentHint.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QPainter_RenderHint.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QPointingDevice_PointerType.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QRawFont_LayoutFlag.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QSurfaceFormat_FormatOption.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QTextDocument_FindFlag.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QTextDocument_MarkdownFeature.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QTextFormat_PageBreakFlag.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QTextItem_RenderFlag.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QTextLayout_GlyphRunRetrievalFlag.mtd_base,
    &sipTypeDef_QtGui_QFlags_0100QTextOption_Flag.mtd_base,
    &sipTypeDef_QtGui_QFocusEvent.ctd_base,
    &sipTypeDef_QtGui_QFont.ctd_base,
    &enumTypes[19].etd_base,
    &enumTypes[20].etd_base,
    &enumTypes[21].etd_base,
    &enumTypes[22].etd_base,
    &enumTypes[23].etd_base,
    &enumTypes[24].etd_base,
    &enumTypes[25].etd_base,
    &sipTypeDef_QtGui_QFont_Tag.ctd_base,
    &enumTypes[26].etd_base,
    &sipTypeDef_QtGui_QFontDatabase.ctd_base,
    &enumTypes[27].etd_base,
    &enumTypes[28].etd_base,
    &sipTypeDef_QtGui_QFontInfo.ctd_base,
    &sipTypeDef_QtGui_QFontMetrics.ctd_base,
    &sipTypeDef_QtGui_QFontMetricsF.ctd_base,
    &sipTypeDef_QtGui_QFontVariableAxis.ctd_base,
    &sipTypeDef_QtGui_QGlyphRun.ctd_base,
    &enumTypes[29].etd_base,
    &sipTypeDef_QtGui_QGradient.ctd_base,
    &enumTypes[30].etd_base,
    &enumTypes[31].etd_base,
    &enumTypes[32].etd_base,
    &enumTypes[33].etd_base,
    &sipTypeDef_QtGui_QGuiApplication.ctd_base,
    &sipTypeDef_QtGui_QHelpEvent.ctd_base,
    &sipTypeDef_QtGui_QHideEvent.ctd_base,
    &sipTypeDef_QtGui_QHoverEvent.ctd_base,
    &sipTypeDef_QtGui_QIcon.ctd_base,
    &enumTypes[34].etd_base,
    &enumTypes[35].etd_base,
    &enumTypes[36].etd_base,
    &sipTypeDef_QtGui_QIconDragEvent.ctd_base,
    &sipTypeDef_QtGui_QIconEngine.ctd_base,
    &enumTypes[37].etd_base,
    &sipTypeDef_QtGui_QIconEngine_ScaledPixmapArgument.ctd_base,
    &sipTypeDef_QtGui_QImage.ctd_base,
    &enumTypes[38].etd_base,
    &enumTypes[39].etd_base,
    &sipTypeDef_QtGui_QImageIOHandler.ctd_base,
    &enumTypes[40].etd_base,
    &enumTypes[41].etd_base,
    &sipTypeDef_QtGui_QImageReader.ctd_base,
    &enumTypes[42].etd_base,
    &sipTypeDef_QtGui_QImageWriter.ctd_base,
    &enumTypes[43].etd_base,
    &sipTypeDef_QtGui_QInputDevice.ctd_base,
    &enumTypes[44].etd_base,
    &enumTypes[45].etd_base,
    &sipTypeDef_QtGui_QInputEvent.ctd_base,
    &sipTypeDef_QtGui_QInputMethod.ctd_base,
    &enumTypes[46].etd_base,
    &sipTypeDef_QtGui_QInputMethodEvent.ctd_base,
    &sipTypeDef_QtGui_QInputMethodEvent_Attribute.ctd_base,
    &enumTypes[47].etd_base,
    &sipTypeDef_QtGui_QInputMethodQueryEvent.ctd_base,
    &sipTypeDef_QtGui_QIntValidator.ctd_base,
    &sipTypeDef_QtGui_QKeyEvent.ctd_base,
    &sipTypeDef_QtGui_QKeySequence.ctd_base,
    &enumTypes[48].etd_base,
    &enumTypes[49].etd_base,
    &enumTypes[50].etd_base,
    &sipTypeDef_QtGui_QLinearGradient.ctd_base,
    &sipTypeDef_QtGui_QList_0100QAbstractTextDocumentLayout_Selection.mtd_base,
    &sipTypeDef_QtGui_QList_0101QAction.mtd_base,
    &sipTypeDef_QtGui_QList_0100QEventPoint.mtd_base,
    &sipTypeDef_QtGui_QList_0100QFont_Tag.mtd_base,
    &sipTypeDef_QtGui_QList_0100QFontDatabase_WritingSystem.mtd_base,
    &sipTypeDef_QtGui_QList_0100QFontVariableAxis.mtd_base,
    &sipTypeDef_QtGui_QList_0100QGlyphRun.mtd_base,
    &sipTypeDef_QtGui_QList_0111QInputDevice.mtd_base,
    &sipTypeDef_QtGui_QList_0100QInputMethodEvent_Attribute.mtd_base,
    &sipTypeDef_QtGui_QList_0100QKeySequence.mtd_base,
    &sipTypeDef_QtGui_QList_0101QOpenGLContext.mtd_base,
    &sipTypeDef_QtGui_QList_0100QPageRanges_Range.mtd_base,
    &sipTypeDef_QtGui_QList_0100QPoint.mtd_base,
    &sipTypeDef_QtGui_QList_0100QPolygonF.mtd_base,
    &sipTypeDef_QtGui_QList_0100QRect.mtd_base,
    &sipTypeDef_QtGui_QList_0101QScreen.mtd_base,
    &sipTypeDef_QtGui_QList_0100QSize.mtd_base,
    &sipTypeDef_QtGui_QList_0101QStandardItem.mtd_base,
    &sipTypeDef_QtGui_QList_0100QTextBlock.mtd_base,
    &sipTypeDef_QtGui_QList_0100QTextFormat.mtd_base,
    &sipTypeDef_QtGui_QList_0101QTextFrame.mtd_base,
    &sipTypeDef_QtGui_QList_0100QTextLayout_FormatRange.mtd_base,
    &sipTypeDef_QtGui_QList_0100QTextLength.mtd_base,
    &sipTypeDef_QtGui_QList_0100QTextOption_Tab.mtd_base,
    &sipTypeDef_QtGui_QList_0101QUndoStack.mtd_base,
    &sipTypeDef_QtGui_QList_0101QWindow.mtd_base,
    &sipTypeDef_QtGui_QList_0600std_pair_2400_0100QColor.mtd_base,
    &sipTypeDef_QtGui_QMap_0100QFont_Tag_2200.mtd_base,
    &sipTypeDef_QtGui_QMap_0100QFont_Tag_1900.mtd_base,
    &sipTypeDef_QtGui_QMatrix2x2.ctd_base,
    &sipTypeDef_QtGui_QMatrix2x3.ctd_base,
    &sipTypeDef_QtGui_QMatrix2x4.ctd_base,
    &sipTypeDef_QtGui_QMatrix3x2.ctd_base,
    &sipTypeDef_QtGui_QMatrix3x3.ctd_base,
    &sipTypeDef_QtGui_QMatrix3x4.ctd_base,
    &sipTypeDef_QtGui_QMatrix4x2.ctd_base,
    &sipTypeDef_QtGui_QMatrix4x3.ctd_base,
    &sipTypeDef_QtGui_QMatrix4x4.ctd_base,
    0,
    &sipTypeDef_QtGui_QMouseEvent.ctd_base,
    &sipTypeDef_QtGui_QMoveEvent.ctd_base,
    &sipTypeDef_QtGui_QMovie.ctd_base,
    &enumTypes[51].etd_base,
    &enumTypes[52].etd_base,
    &sipTypeDef_QtGui_QNativeGestureEvent.ctd_base,
    &sipTypeDef_QtGui_QNativeInterface.ctd_base,
    &sipTypeDef_QtGui_QNativeInterface_QWaylandApplication.ctd_base,
    &sipTypeDef_QtGui_QNativeInterface_QX11Application.ctd_base,
    &sipTypeDef_QtGui_QOffscreenSurface.ctd_base,
    &sipTypeDef_QtGui_QOpenGLContext.ctd_base,
    &enumTypes[53].etd_base,
    &sipTypeDef_QtGui_QOpenGLContextGroup.ctd_base,
    &sipTypeDef_QtGui_QPageLayout.ctd_base,
    &enumTypes[54].etd_base,
    &enumTypes[55].etd_base,
    &enumTypes[56].etd_base,
    &enumTypes[57].etd_base,
    &sipTypeDef_QtGui_QPageRanges.ctd_base,
    &sipTypeDef_QtGui_QPageRanges_Range.ctd_base,
    &sipTypeDef_QtGui_QPageSize.ctd_base,
    &enumTypes[58].etd_base,
    &enumTypes[59].etd_base,
    &enumTypes[60].etd_base,
    &sipTypeDef_QtGui_QPagedPaintDevice.ctd_base,
    &enumTypes[61].etd_base,
    &sipTypeDef_QtGui_QPaintDevice.ctd_base,
    &enumTypes[62].etd_base,
    &sipTypeDef_QtGui_QPaintDeviceWindow.ctd_base,
    &sipTypeDef_QtGui_QPaintEngine.ctd_base,
    &enumTypes[63].etd_base,
    &enumTypes[64].etd_base,
    &enumTypes[65].etd_base,
    &enumTypes[66].etd_base,
    &sipTypeDef_QtGui_QPaintEngineState.ctd_base,
    &sipTypeDef_QtGui_QPaintEvent.ctd_base,
    &sipTypeDef_QtGui_QPainter.ctd_base,
    &enumTypes[67].etd_base,
    &sipTypeDef_QtGui_QPainter_PixmapFragment.ctd_base,
    &enumTypes[68].etd_base,
    &enumTypes[69].etd_base,
    &sipTypeDef_QtGui_QPainterPath.ctd_base,
    &sipTypeDef_QtGui_QPainterPath_Element.ctd_base,
    &enumTypes[70].etd_base,
    &sipTypeDef_QtGui_QPainterPathStroker.ctd_base,
    &sipTypeDef_QtGui_QPainterStateGuard.ctd_base,
    &enumTypes[71].etd_base,
    &sipTypeDef_QtGui_QPalette.ctd_base,
    &enumTypes[72].etd_base,
    &enumTypes[73].etd_base,
    &sipTypeDef_QtGui_QPdfOutputIntent.ctd_base,
    &sipTypeDef_QtGui_QPdfWriter.ctd_base,
    &enumTypes[74].etd_base,
    &sipTypeDef_QtGui_QPen.ctd_base,
    &sipTypeDef_QtGui_QPicture.ctd_base,
    &sipTypeDef_QtGui_QPixelFormat.ctd_base,
    &enumTypes[75].etd_base,
    &enumTypes[76].etd_base,
    &enumTypes[77].etd_base,
    &enumTypes[78].etd_base,
    &enumTypes[79].etd_base,
    &enumTypes[80].etd_base,
    &enumTypes[81].etd_base,
    &sipTypeDef_QtGui_QPixmap.ctd_base,
    &sipTypeDef_QtGui_QPixmapCache.ctd_base,
    &sipTypeDef_QtGui_QPixmapCache_Key.ctd_base,
    &sipTypeDef_QtGui_QPlatformSurfaceEvent.ctd_base,
    &enumTypes[82].etd_base,
    &sipTypeDef_QtGui_QPointerEvent.ctd_base,
    &sipTypeDef_QtGui_QPointingDevice.ctd_base,
    &enumTypes[83].etd_base,
    &sipTypeDef_QtGui_QPointingDeviceUniqueId.ctd_base,
    &sipTypeDef_QtGui_QPolygon.ctd_base,
    &sipTypeDef_QtGui_QPolygonF.ctd_base,
    &sipTypeDef_QtGui_QQuaternion.ctd_base,
    &sipTypeDef_QtGui_QQuaternion_Axes.ctd_base,
    &sipTypeDef_QtGui_QQuaternion_Axis.ctd_base,
    &sipTypeDef_QtGui_QRadialGradient.ctd_base,
    &sipTypeDef_QtGui_QRasterWindow.ctd_base,
    &sipTypeDef_QtGui_QRawFont.ctd_base,
    &enumTypes[84].etd_base,
    &enumTypes[85].etd_base,
    &sipTypeDef_QtGui_QRegion.ctd_base,
    &enumTypes[86].etd_base,
    &sipTypeDef_QtGui_QRegularExpressionValidator.ctd_base,
    &sipTypeDef_QtGui_QResizeEvent.ctd_base,
    &sipTypeDef_QtGui_QRgba64.ctd_base,
    &sipTypeDef_QtGui_QScreen.ctd_base,
    &sipTypeDef_QtGui_QScrollEvent.ctd_base,
    &enumTypes[87].etd_base,
    &sipTypeDef_QtGui_QScrollPrepareEvent.ctd_base,
    &sipTypeDef_QtGui_QSessionManager.ctd_base,
    &enumTypes[88].etd_base,
    &sipTypeDef_QtGui_QSet_0100QByteArray.mtd_base,
    &sipTypeDef_QtGui_QShortcut.ctd_base,
    &sipTypeDef_QtGui_QShortcutEvent.ctd_base,
    &sipTypeDef_QtGui_QShowEvent.ctd_base,
    &sipTypeDef_QtGui_QSinglePointEvent.ctd_base,
    &sipTypeDef_QtGui_QStandardItem.ctd_base,
    &enumTypes[89].etd_base,
    &sipTypeDef_QtGui_QStandardItemModel.ctd_base,
    &sipTypeDef_QtGui_QStaticText.ctd_base,
    &enumTypes[90].etd_base,
    &sipTypeDef_QtGui_QStatusTipEvent.ctd_base,
    &sipTypeDef_QtGui_QStyleHints.ctd_base,
    &sipTypeDef_QtGui_QSurface.ctd_base,
    &enumTypes[91].etd_base,
    &enumTypes[92].etd_base,
    &sipTypeDef_QtGui_QSurfaceFormat.ctd_base,
    &enumTypes[93].etd_base,
    &enumTypes[94].etd_base,
    &enumTypes[95].etd_base,
    &enumTypes[96].etd_base,
    &sipTypeDef_QtGui_QSyntaxHighlighter.ctd_base,
    &sipTypeDef_QtGui_QTabletEvent.ctd_base,
    &sipTypeDef_QtGui_QTextBlock.ctd_base,
    &sipTypeDef_QtGui_QTextBlock_iterator.ctd_base,
    &sipTypeDef_QtGui_QTextBlockFormat.ctd_base,
    &enumTypes[97].etd_base,
    &enumTypes[98].etd_base,
    &sipTypeDef_QtGui_QTextBlockGroup.ctd_base,
    &sipTypeDef_QtGui_QTextBlockUserData.ctd_base,
    &sipTypeDef_QtGui_QTextCharFormat.ctd_base,
    &enumTypes[99].etd_base,
    &enumTypes[100].etd_base,
    &enumTypes[101].etd_base,
    &sipTypeDef_QtGui_QTextCursor.ctd_base,
    &enumTypes[102].etd_base,
    &enumTypes[103].etd_base,
    &enumTypes[104].etd_base,
    &sipTypeDef_QtGui_QTextDocument.ctd_base,
    &enumTypes[105].etd_base,
    &enumTypes[106].etd_base,
    &enumTypes[107].etd_base,
    &enumTypes[108].etd_base,
    &enumTypes[109].etd_base,
    &sipTypeDef_QtGui_QTextDocumentFragment.ctd_base,
    &sipTypeDef_QtGui_QTextDocumentWriter.ctd_base,
    &sipTypeDef_QtGui_QTextFormat.ctd_base,
    &enumTypes[110].etd_base,
    &enumTypes[111].etd_base,
    &enumTypes[112].etd_base,
    &enumTypes[113].etd_base,
    &sipTypeDef_QtGui_QTextFragment.ctd_base,
    &sipTypeDef_QtGui_QTextFrame.ctd_base,
    &sipTypeDef_QtGui_QTextFrame_iterator.ctd_base,
    &sipTypeDef_QtGui_QTextFrameFormat.ctd_base,
    &enumTypes[114].etd_base,
    &enumTypes[115].etd_base,
    &sipTypeDef_QtGui_QTextImageFormat.ctd_base,
    &sipTypeDef_QtGui_QTextInlineObject.ctd_base,
    &sipTypeDef_QtGui_QTextItem.ctd_base,
    &enumTypes[116].etd_base,
    &sipTypeDef_QtGui_QTextLayout.ctd_base,
    &enumTypes[117].etd_base,
    &sipTypeDef_QtGui_QTextLayout_FormatRange.ctd_base,
    &enumTypes[118].etd_base,
    &sipTypeDef_QtGui_QTextLength.ctd_base,
    &enumTypes[119].etd_base,
    &sipTypeDef_QtGui_QTextLine.ctd_base,
    &enumTypes[120].etd_base,
    &enumTypes[121].etd_base,
    &sipTypeDef_QtGui_QTextList.ctd_base,
    &sipTypeDef_QtGui_QTextListFormat.ctd_base,
    &enumTypes[122].etd_base,
    &sipTypeDef_QtGui_QTextObject.ctd_base,
    &sipTypeDef_QtGui_QTextObjectInterface.ctd_base,
    &sipTypeDef_QtGui_QTextOption.ctd_base,
    &enumTypes[123].etd_base,
    &sipTypeDef_QtGui_QTextOption_Tab.ctd_base,
    &enumTypes[124].etd_base,
    &enumTypes[125].etd_base,
    &sipTypeDef_QtGui_QTextTable.ctd_base,
    &sipTypeDef_QtGui_QTextTableCell.ctd_base,
    &sipTypeDef_QtGui_QTextTableCellFormat.ctd_base,
    &sipTypeDef_QtGui_QTextTableFormat.ctd_base,
    &sipTypeDef_QtGui_QTouchEvent.ctd_base,
    &sipTypeDef_QtGui_QTransform.ctd_base,
    &enumTypes[126].etd_base,
    &sipTypeDef_QtGui_QUndoCommand.ctd_base,
    &sipTypeDef_QtGui_QUndoGroup.ctd_base,
    &sipTypeDef_QtGui_QUndoStack.ctd_base,
    &sipTypeDef_QtGui_QValidator.ctd_base,
    &enumTypes[127].etd_base,
    &sipTypeDef_QtGui_QVector2D.ctd_base,
    &sipTypeDef_QtGui_QVector3D.ctd_base,
    &sipTypeDef_QtGui_QVector4D.ctd_base,
    &sipTypeDef_QtGui_QWhatsThisClickedEvent.ctd_base,
    &sipTypeDef_QtGui_QWheelEvent.ctd_base,
    &sipTypeDef_QtGui_QWindow.ctd_base,
    &enumTypes[128].etd_base,
    &enumTypes[129].etd_base,
    &sipTypeDef_QtGui_QWindowStateChangeEvent.ctd_base,
    &sipTypeDef_QtGui_Qt.ctd_base,
    &sipTypeDef_QtGui_std_optional_0100QFont_Tag.mtd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"GLbitfield", "uint"},
    {"GLboolean", "unsigned char"},
    {"GLbyte", "signed char"},
    {"GLchar", "char"},
    {"GLclampf", "float"},
    {"GLdouble", "double"},
    {"GLenum", "uint"},
    {"GLfloat", "float"},
    {"GLint", "int"},
    {"GLintptr", "long"},
    {"GLshort", "short"},
    {"GLsizei", "int"},
    {"GLsizeiptr", "long"},
    {"GLubyte", "unsigned char"},
    {"GLuint", "uint"},
    {"GLuint64", "unsigned long long"},
    {"GLushort", "unsigned short"},
    {"QAbstractFileIconProvider::Options", "QFlags<QAbstractFileIconProvider::Option>"},
    {"QEventPoint::States", "QFlags<QEventPoint::State>"},
    {"QFileSystemModel::Options", "QFlags<QFileSystemModel::Option>"},
    {"QGlyphRun::GlyphRunFlags", "QFlags<QGlyphRun::GlyphRunFlag>"},
    {"QGradientStops", "QList<std::pair<qreal, QColor>>"},
    {"QImageIOHandler::Transformations", "QFlags<QImageIOHandler::Transformation>"},
    {"QInputDevice::Capabilities", "QFlags<QInputDevice::Capability>"},
    {"QInputDevice::DeviceTypes", "QFlags<QInputDevice::DeviceType>"},
    {"QPaintEngine::DirtyFlags", "QFlags<QPaintEngine::DirtyFlag>"},
    {"QPaintEngine::PaintEngineFeatures", "QFlags<QPaintEngine::PaintEngineFeature>"},
    {"QPainter::PixmapFragmentHints", "QFlags<QPainter::PixmapFragmentHint>"},
    {"QPainter::RenderHints", "QFlags<QPainter::RenderHint>"},
    {"QPointingDevice::PointerTypes", "QFlags<QPointingDevice::PointerType>"},
    {"QRawFont::LayoutFlags", "QFlags<QRawFont::LayoutFlag>"},
    {"QRgb", "uint"},
    {"QSurfaceFormat::FormatOptions", "QFlags<QSurfaceFormat::FormatOption>"},
    {"QTextBlock::Iterator", "QTextBlock::iterator"},
    {"QTextDocument::FindFlags", "QFlags<QTextDocument::FindFlag>"},
    {"QTextDocument::MarkdownFeatures", "QFlags<QTextDocument::MarkdownFeature>"},
    {"QTextFormat::PageBreakFlags", "QFlags<QTextFormat::PageBreakFlag>"},
    {"QTextFrame::Iterator", "QTextFrame::iterator"},
    {"QTextItem::RenderFlags", "QFlags<QTextItem::RenderFlag>"},
    {"QTextLayout::GlyphRunRetrievalFlags", "QFlags<QTextLayout::GlyphRunRetrievalFlag>"},
    {"QTextOption::Flags", "QFlags<QTextOption::Flag>"},
    {"QWindowList", "QList<QWindow*>"},
    {"WId", "quintptr"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtGui_QtCore[] = {
    {"QAbstractItemModel"},
    {"QAnyStringView"},
    {"QByteArray"},
    {"QChar"},
    {"QChar::Script"},
    {"QChildEvent"},
    {"QCoreApplication"},
    {"QDataStream"},
    {"QDateTime"},
    {"QDir"},
    {"QEvent"},
    {"QEvent::Type"},
    {"QFile"},
    {"QFileInfo"},
    {"QFlags<QDir::Filter>"},
    {"QFlags<QFileDevice::Permission>"},
    {"QFlags<QIODeviceBase::OpenModeFlag>"},
    {"QFlags<Qt::AlignmentFlag>"},
    {"QFlags<Qt::DropAction>"},
    {"QFlags<Qt::Edge>"},
    {"QFlags<Qt::ImageConversionFlag>"},
    {"QFlags<Qt::InputMethodQuery>"},
    {"QFlags<Qt::ItemFlag>"},
    {"QFlags<Qt::KeyboardModifier>"},
    {"QFlags<Qt::MatchFlag>"},
    {"QFlags<Qt::MouseButton>"},
    {"QFlags<Qt::MouseEventFlag>"},
    {"QFlags<Qt::Orientation>"},
    {"QFlags<Qt::WindowState>"},
    {"QFlags<Qt::WindowType>"},
    {"QHash<int,QByteArray>"},
    {"QIODevice"},
    {"QKeyCombination"},
    {"QLine"},
    {"QLineF"},
    {"QList<QByteArray>"},
    {"QList<QModelIndex>"},
    {"QList<QObject*>"},
    {"QList<QPointF>"},
    {"QList<int>"},
    {"QList<qreal>"},
    {"QList<qsizetype>"},
    {"QList<uint>"},
    {"QList<unsigned short>"},
    {"QLocale"},
    {"QMap<int,QVariant>"},
    {"QMargins"},
    {"QMarginsF"},
    {"QMetaMethod"},
    {"QMimeData"},
    {"QModelIndex"},
    {"QModelRoleDataSpan"},
    {"QNativeInterface"},
    {"QObject"},
    {"QPoint"},
    {"QPointF"},
    {"QRect"},
    {"QRectF"},
    {"QRegularExpression"},
    {"QSize"},
    {"QSizeF"},
    {"QString"},
    {"QStringList"},
    {"QStringView"},
    {"QTimeZone"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QUuid"},
    {"QVariant"},
    {"Qt"},
    {"Qt::ApplicationState"},
    {"Qt::AspectRatioMode"},
    {"Qt::Axis"},
    {"Qt::BGMode"},
    {"Qt::BrushStyle"},
    {"Qt::CheckState"},
    {"Qt::ClipOperation"},
    {"Qt::ColorScheme"},
    {"Qt::ContextMenuTrigger"},
    {"Qt::ContrastPreference"},
    {"Qt::CursorMoveStyle"},
    {"Qt::CursorShape"},
    {"Qt::DropAction"},
    {"Qt::FillRule"},
    {"Qt::FocusReason"},
    {"Qt::GlobalColor"},
    {"Qt::HighDpiScaleFactorRoundingPolicy"},
    {"Qt::HitTestAccuracy"},
    {"Qt::InputMethodQuery"},
    {"Qt::LayoutDirection"},
    {"Qt::MaskMode"},
    {"Qt::MouseButton"},
    {"Qt::MouseEventSource"},
    {"Qt::NativeGestureType"},
    {"Qt::Orientation"},
    {"Qt::PenCapStyle"},
    {"Qt::PenJoinStyle"},
    {"Qt::PenStyle"},
    {"Qt::ScreenOrientation"},
    {"Qt::ScrollPhase"},
    {"Qt::ShortcutContext"},
    {"Qt::SizeMode"},
    {"Qt::SortOrder"},
    {"Qt::TabFocusBehavior"},
    {"Qt::TextElideMode"},
    {"Qt::TextFormat"},
    {"Qt::TransformationMode"},
    {"Qt::WhiteSpaceMode"},
    {"Qt::WindowModality"},
    {"Qt::WindowState"},
    {"Qt::WindowType"},
    {"qintptr"},
    {"quintptr"},
    {"std::pair<int,int>"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtGui_QtCore[] = {
    {"PyQt6"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt6.QtCore", sipImportedTypes_QtGui_QtCore, sipImportedVirtErrorHandlers_QtGui_QtCore, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QGradient, {94, 255, 0}, SIP_NULLPTR},
    {sipSubClass_QInputEvent, {10, 0, 0}, SIP_NULLPTR},
    {sipSubClass_QGuiApplication, {53, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtGui = {
    SIP_NULLPTR,
    8,
    sipNameNr_PyQt6_QtGui,
    0,
    sipStrings_QtGui,
    importsTable,
    372,
    sipExportedTypes_QtGui,
    externalTypesTable,
    43,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    slotExtenders,
    initExtenders,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtGui;

sip_qt_metaobject_func sip_QtGui_qt_metaobject;
sip_qt_metacall_func sip_QtGui_qt_metacall;
sip_qt_metacast_func sip_QtGui_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtGui()
#else
PyMODINIT_FUNC PyInit_QtGui()
#endif
{
    static PyMethodDef sip_methods[] = {
        {sipName_qGray, func_qGray, METH_VARARGS, doc_qGray},
        {sipName_qRgba, func_qRgba, METH_VARARGS, doc_qRgba},
        {sipName_qRgb, func_qRgb, METH_VARARGS, doc_qRgb},
        {sipName_qAlpha, func_qAlpha, METH_VARARGS, doc_qAlpha},
        {sipName_qBlue, func_qBlue, METH_VARARGS, doc_qBlue},
        {sipName_qGreen, func_qGreen, METH_VARARGS, doc_qGreen},
        {sipName_qRed, func_qRed, METH_VARARGS, doc_qRed},
        {sipName_qUnpremultiply, func_qUnpremultiply, METH_VARARGS, doc_qUnpremultiply},
        {sipName_qPremultiply, func_qPremultiply, METH_VARARGS, doc_qPremultiply},
        {sipName_qRgba64, func_qRgba64, METH_VARARGS, doc_qRgba64},
        {sipName_qPixelFormatAlpha, SIP_MLMETH_CAST(func_qPixelFormatAlpha), METH_VARARGS|METH_KEYWORDS, doc_qPixelFormatAlpha},
        {sipName_qPixelFormatYuv, SIP_MLMETH_CAST(func_qPixelFormatYuv), METH_VARARGS|METH_KEYWORDS, doc_qPixelFormatYuv},
        {sipName_qPixelFormatHsv, SIP_MLMETH_CAST(func_qPixelFormatHsv), METH_VARARGS|METH_KEYWORDS, doc_qPixelFormatHsv},
        {sipName_qPixelFormatHsl, SIP_MLMETH_CAST(func_qPixelFormatHsl), METH_VARARGS|METH_KEYWORDS, doc_qPixelFormatHsl},
        {sipName_qPixelFormatCmyk, SIP_MLMETH_CAST(func_qPixelFormatCmyk), METH_VARARGS|METH_KEYWORDS, doc_qPixelFormatCmyk},
        {sipName_qPixelFormatGrayscale, SIP_MLMETH_CAST(func_qPixelFormatGrayscale), METH_VARARGS|METH_KEYWORDS, doc_qPixelFormatGrayscale},
        {sipName_qPixelFormatRgba, SIP_MLMETH_CAST(func_qPixelFormatRgba), METH_VARARGS|METH_KEYWORDS, doc_qPixelFormatRgba},
        {sipName_qFuzzyCompare, func_qFuzzyCompare, METH_VARARGS, doc_qFuzzyCompare},
        {sipName_qt_set_sequence_auto_mnemonic, func_qt_set_sequence_auto_mnemonic, METH_VARARGS, doc_qt_set_sequence_auto_mnemonic},
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt6.QtGui",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt6.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt6.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtGui = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt6.sip._C_API"));

    if (sipAPI_QtGui == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

#line 288 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qguiapplication.sip"
// Export our own helpers.
sipExportSymbol("qtgui_wrap_ancestors", (void *)qtgui_wrap_ancestors);
#line 9480 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"
    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtGui, 13, 8, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtGui_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtGui_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtGui_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtGui_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtGui, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }
    qMetaTypeId<::QWindow::Visibility>();
    qMetaTypeId<::QWindow::AncestorMode>();
    qMetaTypeId<::QDoubleValidator::Notation>();
    qMetaTypeId<::QValidator::State>();
    qMetaTypeId<::QTransform::TransformationType>();
    qMetaTypeId<::QTextOption::TabType>();
    qMetaTypeId<::QTextOption::Flag>();
    qMetaTypeId<::QTextOption::WrapMode>();
    qMetaTypeId<::QTextLine::CursorPosition>();
    qMetaTypeId<::QTextLine::Edge>();
    qMetaTypeId<::QTextLayout::GlyphRunRetrievalFlag>();
    qMetaTypeId<::QTextLayout::CursorMode>();
    qMetaTypeId<::QTextFrameFormat::BorderStyle>();
    qMetaTypeId<::QTextFrameFormat::Position>();
    qMetaTypeId<::QTextListFormat::Style>();
    qMetaTypeId<::QTextBlockFormat::MarkerType>();
    qMetaTypeId<::QTextBlockFormat::LineHeightTypes>();
    qMetaTypeId<::QTextCharFormat::FontPropertiesInheritanceBehavior>();
    qMetaTypeId<::QTextCharFormat::UnderlineStyle>();
    qMetaTypeId<::QTextCharFormat::VerticalAlignment>();
    qMetaTypeId<::QTextFormat::Property>();
    qMetaTypeId<::QTextFormat::PageBreakFlag>();
    qMetaTypeId<::QTextFormat::ObjectTypes>();
    qMetaTypeId<::QTextFormat::FormatType>();
    qMetaTypeId<::QTextLength::Type>();
    qMetaTypeId<::QTextDocument::MarkdownFeature>();
    qMetaTypeId<::QTextDocument::Stacks>();
    qMetaTypeId<::QTextDocument::ResourceType>();
    qMetaTypeId<::QTextDocument::FindFlag>();
    qMetaTypeId<::QTextDocument::MetaInformation>();
    qMetaTypeId<::QTextCursor::SelectionType>();
    qMetaTypeId<::QTextCursor::MoveOperation>();
    qMetaTypeId<::QTextCursor::MoveMode>();
    qMetaTypeId<::QSurfaceFormat::OpenGLContextProfile>();
    qMetaTypeId<::QSurfaceFormat::RenderableType>();
    qMetaTypeId<::QSurfaceFormat::SwapBehavior>();
    qMetaTypeId<::QSurfaceFormat::FormatOption>();
    qMetaTypeId<::QSurface::SurfaceType>();
    qMetaTypeId<::QSurface::SurfaceClass>();
    qMetaTypeId<::QStaticText::PerformanceHint>();
    qMetaTypeId<::QStandardItem::ItemType>();
    qMetaTypeId<::QSessionManager::RestartHint>();
    qMetaTypeId<::QRegion::RegionType>();
    qMetaTypeId<::QRawFont::LayoutFlag>();
    qMetaTypeId<::QRawFont::AntialiasingType>();
    qMetaTypeId<::QPointingDevice::PointerType>();
    qMetaTypeId<::QPixelFormat::ByteOrder>();
    qMetaTypeId<::QPixelFormat::YUVLayout>();
    qMetaTypeId<::QPixelFormat::TypeInterpretation>();
    qMetaTypeId<::QPixelFormat::AlphaPremultiplied>();
    qMetaTypeId<::QPixelFormat::AlphaPosition>();
    qMetaTypeId<::QPixelFormat::AlphaUsage>();
    qMetaTypeId<::QPixelFormat::ColorModel>();
    qMetaTypeId<::QPdfWriter::ColorModel>();
    qMetaTypeId<::QPalette::ColorRole>();
    qMetaTypeId<::QPalette::ColorGroup>();
    qMetaTypeId<::QPainterStateGuard::InitialState>();
    qMetaTypeId<::QPainterPath::ElementType>();
    qMetaTypeId<::QPainter::PixmapFragmentHint>();
    qMetaTypeId<::QPainter::CompositionMode>();
    qMetaTypeId<::QPainter::RenderHint>();
    qMetaTypeId<::QPaintEngine::Type>();
    qMetaTypeId<::QPaintEngine::PolygonDrawMode>();
    qMetaTypeId<::QPaintEngine::DirtyFlag>();
    qMetaTypeId<::QPaintEngine::PaintEngineFeature>();
    qMetaTypeId<::QTextItem::RenderFlag>();
    qMetaTypeId<::QPaintDevice::PaintDeviceMetric>();
    qMetaTypeId<::QPageSize::SizeMatchPolicy>();
    qMetaTypeId<::QPageSize::Unit>();
    qMetaTypeId<::QPageSize::PageSizeId>();
    qMetaTypeId<::QPageLayout::OutOfBoundsPolicy>();
    qMetaTypeId<::QPageLayout::Mode>();
    qMetaTypeId<::QPageLayout::Orientation>();
    qMetaTypeId<::QPageLayout::Unit>();
    qMetaTypeId<::QPagedPaintDevice::PdfVersion>();
    qMetaTypeId<::QOpenGLContext::OpenGLModuleType>();
    qMetaTypeId<::QMovie::CacheMode>();
    qMetaTypeId<::QMovie::MovieState>();
    qMetaTypeId<::QKeySequence::StandardKey>();
    qMetaTypeId<::QKeySequence::SequenceMatch>();
    qMetaTypeId<::QKeySequence::SequenceFormat>();
    qMetaTypeId<::QInputMethod::Action>();
    qMetaTypeId<::QInputDevice::Capability>();
    qMetaTypeId<::QInputDevice::DeviceType>();
    qMetaTypeId<::QImageWriter::ImageWriterError>();
    qMetaTypeId<::QImageReader::ImageReaderError>();
    qMetaTypeId<::QImageIOHandler::Transformation>();
    qMetaTypeId<::QImageIOHandler::ImageOption>();
    qMetaTypeId<::QImage::Format>();
    qMetaTypeId<::QImage::InvertMode>();
    qMetaTypeId<::QIconEngine::IconEngineHook>();
    qMetaTypeId<::QIcon::ThemeIcon>();
    qMetaTypeId<::QIcon::State>();
    qMetaTypeId<::QIcon::Mode>();
    qMetaTypeId<::QGlyphRun::GlyphRunFlag>();
    qMetaTypeId<::QFontDatabase::SystemFont>();
    qMetaTypeId<::QFontDatabase::WritingSystem>();
    qMetaTypeId<::QFont::HintingPreference>();
    qMetaTypeId<::QFont::SpacingType>();
    qMetaTypeId<::QFont::Capitalization>();
    qMetaTypeId<::QFont::Stretch>();
    qMetaTypeId<::QFont::Style>();
    qMetaTypeId<::QFont::Weight>();
    qMetaTypeId<::QFont::StyleStrategy>();
    qMetaTypeId<::QFont::StyleHint>();
    qMetaTypeId<::QFileSystemModel::Option>();
    qMetaTypeId<::QFileSystemModel::Roles>();
    qMetaTypeId<::QEventPoint::State>();
    qMetaTypeId<::QPlatformSurfaceEvent::SurfaceEventType>();
    qMetaTypeId<::QScrollEvent::ScrollState>();
    qMetaTypeId<::QInputMethodEvent::AttributeType>();
    qMetaTypeId<::QContextMenuEvent::Reason>();
    qMetaTypeId<::QColorSpace::TransformModel>();
    qMetaTypeId<::QColorSpace::TransferFunction>();
    qMetaTypeId<::QColorSpace::Primaries>();
    qMetaTypeId<::QColorSpace::NamedColorSpace>();
    qMetaTypeId<::QColorSpace::ColorModel>();
    qMetaTypeId<::QClipboard::Mode>();
    qMetaTypeId<::QGradient::Preset>();
    qMetaTypeId<::QGradient::Spread>();
    qMetaTypeId<::QGradient::Type>();
    qMetaTypeId<::QGradient::CoordinateMode>();
    qMetaTypeId<::QColor::NameFormat>();
    qMetaTypeId<::QColor::Spec>();
    qMetaTypeId<::QActionGroup::ExclusionPolicy>();
    qMetaTypeId<::QAction::Priority>();
    qMetaTypeId<::QAction::MenuRole>();
    qMetaTypeId<::QAction::ActionEvent>();
    qMetaTypeId<::QAbstractFileIconProvider::Option>();
    qMetaTypeId<::QAbstractFileIconProvider::IconType>();
    qMetaTypeId<QFlags< ::QTextOption::Flag>>();
    qMetaTypeId<QFlags< ::QTextLayout::GlyphRunRetrievalFlag>>();
    qMetaTypeId<QFlags< ::QTextItem::RenderFlag>>();
    qMetaTypeId<QFlags< ::QTextFormat::PageBreakFlag>>();
    qMetaTypeId<QFlags< ::QTextDocument::MarkdownFeature>>();
    qMetaTypeId<QFlags< ::QTextDocument::FindFlag>>();
    qMetaTypeId<QFlags< ::QSurfaceFormat::FormatOption>>();
    qMetaTypeId<QFlags< ::QRawFont::LayoutFlag>>();
    qMetaTypeId<QFlags< ::QPointingDevice::PointerType>>();
    qMetaTypeId<QFlags< ::QPainter::RenderHint>>();
    qMetaTypeId<QFlags< ::QPainter::PixmapFragmentHint>>();
    qMetaTypeId<QFlags< ::QPaintEngine::PaintEngineFeature>>();
    qMetaTypeId<QFlags< ::QPaintEngine::DirtyFlag>>();
    qMetaTypeId<QFlags< ::QInputDevice::DeviceType>>();
    qMetaTypeId<QFlags< ::QInputDevice::Capability>>();
    qMetaTypeId<QFlags< ::QImageIOHandler::Transformation>>();
    qMetaTypeId<QFlags< ::QGlyphRun::GlyphRunFlag>>();
    qMetaTypeId<QFlags< ::QFileSystemModel::Option>>();
    qMetaTypeId<QFlags< ::QEventPoint::State>>();
    qMetaTypeId<QFlags< ::QAbstractFileIconProvider::Option>>();
#line 293 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qguiapplication.sip"
// Imports from QtCore.
pyqt6_qtgui_cleanup_qobjects = (pyqt6_qtgui_cleanup_qobjects_t)sipImportSymbol("pyqt6_cleanup_qobjects");
Q_ASSERT(pyqt6_qtgui_cleanup_qobjects);

pyqt6_qtgui_from_argv_list = (pyqt6_qtgui_from_argv_list_t)sipImportSymbol("pyqt6_from_argv_list");
Q_ASSERT(pyqt6_qtgui_from_argv_list);

pyqt6_qtgui_update_argv_list = (pyqt6_qtgui_update_argv_list_t)sipImportSymbol("pyqt6_update_argv_list");
Q_ASSERT(pyqt6_qtgui_update_argv_list);
#line 416 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qimage.sip"
// Imports from QtCore.
pyqt6_qtgui_err_print = (pyqt6_qtgui_err_print_t)sipImportSymbol("pyqt6_err_print");
Q_ASSERT(pyqt6_qtgui_err_print);
#line 168 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qshortcut.sip"
// Imports from QtCore.
pyqt6_qtgui_get_connection_parts = (pyqt6_qtgui_get_connection_parts_t)sipImportSymbol("pyqt6_get_connection_parts");
Q_ASSERT(pyqt6_qtgui_get_connection_parts);
#line 9670 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuicmodule.cpp"

    return sipModule;
}
