/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtWidgetsAPI_H
#define _QtWidgetsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtWidgets[0]
#define sipNameNr_SH_ItemView_PaintAlternatingRowColorsForEmptyArea 50
#define sipName_SH_ItemView_PaintAlternatingRowColorsForEmptyArea &sipStrings_QtWidgets[50]
#define sipNameNr_QStyleOptionTabWidgetFrame__StyleOptionVersion 100
#define sipName_QStyleOptionTabWidgetFrame__StyleOptionVersion &sipStrings_QtWidgets[100]
#define sipNameNr_147 147
#define sipName_147 &sipStrings_QtWidgets[147]
#define sipNameNr_193 193
#define sipName_193 &sipStrings_QtWidgets[193]
#define sipNameNr_QStyleOptionGraphicsItem__StyleOptionVersion 239
#define sipName_QStyleOptionGraphicsItem__StyleOptionVersion &sipStrings_QtWidgets[239]
#define sipNameNr_SH_ItemView_MovementWithoutUpdatingSelection 284
#define sipName_SH_ItemView_MovementWithoutUpdatingSelection &sipStrings_QtWidgets[284]
#define sipNameNr_329 329
#define sipName_329 &sipStrings_QtWidgets[329]
#define sipNameNr_QStyleHintReturnVariant__StyleOptionVersion 373
#define sipName_QStyleHintReturnVariant__StyleOptionVersion &sipStrings_QtWidgets[373]
#define sipNameNr_QStyleOptionProgressBar__StyleOptionVersion 417
#define sipName_QStyleOptionProgressBar__StyleOptionVersion &sipStrings_QtWidgets[417]
#define sipNameNr_QStyleOptionTabWidgetFrame__StyleOptionType 461
#define sipName_QStyleOptionTabWidgetFrame__StyleOptionType &sipStrings_QtWidgets[461]
#define sipNameNr_SH_ScrollBar_ScrollWhenPointerLeavesControl 505
#define sipName_SH_ScrollBar_ScrollWhenPointerLeavesControl &sipStrings_QtWidgets[505]
#define sipNameNr_SH_TextControl_FocusIndicatorTextCharFormat 549
#define sipName_SH_TextControl_FocusIndicatorTextCharFormat &sipStrings_QtWidgets[549]
#define sipNameNr_QStyleOptionDockWidget__StyleOptionVersion 593
#define sipName_QStyleOptionDockWidget__StyleOptionVersion &sipStrings_QtWidgets[593]
#define sipNameNr_QStyleOptionMenuItemV2__StyleOptionVersion 636
#define sipName_QStyleOptionMenuItemV2__StyleOptionVersion &sipStrings_QtWidgets[636]
#define sipNameNr_QStyleOptionRubberBand__StyleOptionVersion 679
#define sipName_QStyleOptionRubberBand__StyleOptionVersion &sipStrings_QtWidgets[679]
#define sipNameNr_QStyleOptionTabBarBase__StyleOptionVersion 722
#define sipName_QStyleOptionTabBarBase__StyleOptionVersion &sipStrings_QtWidgets[722]
#define sipNameNr_QStyleOptionToolButton__StyleOptionVersion 765
#define sipName_QStyleOptionToolButton__StyleOptionVersion &sipStrings_QtWidgets[765]
#define sipNameNr_808 808
#define sipName_808 &sipStrings_QtWidgets[808]
#define sipNameNr_850 850
#define sipName_850 &sipStrings_QtWidgets[850]
#define sipNameNr_QStyleOptionFocusRect__StyleOptionVersion 892
#define sipName_QStyleOptionFocusRect__StyleOptionVersion &sipStrings_QtWidgets[892]
#define sipNameNr_QStyleOptionGraphicsItem__StyleOptionType 934
#define sipName_QStyleOptionGraphicsItem__StyleOptionType &sipStrings_QtWidgets[934]
#define sipNameNr_QStyleOptionToolButton__ToolButtonFeature 976
#define sipName_QStyleOptionToolButton__ToolButtonFeature &sipStrings_QtWidgets[976]
#define sipNameNr_SH_ItemView_ArrowKeysNavigateIntoChildren 1018
#define sipName_SH_ItemView_ArrowKeysNavigateIntoChildren &sipStrings_QtWidgets[1018]
#define sipNameNr_QAbstractItemView__DropIndicatorPosition 1060
#define sipName_QAbstractItemView__DropIndicatorPosition &sipStrings_QtWidgets[1060]
#define sipNameNr_1101 1101
#define sipName_1101 &sipStrings_QtWidgets[1101]
#define sipNameNr_QStyleHintReturnMask__StyleOptionVersion 1142
#define sipName_QStyleHintReturnMask__StyleOptionVersion &sipStrings_QtWidgets[1142]
#define sipNameNr_QStyleHintReturnVariant__StyleOptionType 1183
#define sipName_QStyleHintReturnVariant__StyleOptionType &sipStrings_QtWidgets[1183]
#define sipNameNr_QStyleOptionComboBox__StyleOptionVersion 1224
#define sipName_QStyleOptionComboBox__StyleOptionVersion &sipStrings_QtWidgets[1224]
#define sipNameNr_QStyleOptionGroupBox__StyleOptionVersion 1265
#define sipName_QStyleOptionGroupBox__StyleOptionVersion &sipStrings_QtWidgets[1265]
#define sipNameNr_QStyleOptionHeaderV2__StyleOptionVersion 1306
#define sipName_QStyleOptionHeaderV2__StyleOptionVersion &sipStrings_QtWidgets[1306]
#define sipNameNr_QStyleOptionMenuItem__StyleOptionVersion 1347
#define sipName_QStyleOptionMenuItem__StyleOptionVersion &sipStrings_QtWidgets[1347]
#define sipNameNr_QStyleOptionProgressBar__StyleOptionType 1388
#define sipName_QStyleOptionProgressBar__StyleOptionType &sipStrings_QtWidgets[1388]
#define sipNameNr_QStyleOptionSizeGrip__StyleOptionVersion 1429
#define sipName_QStyleOptionSizeGrip__StyleOptionVersion &sipStrings_QtWidgets[1429]
#define sipNameNr_QStyleOptionTitleBar__StyleOptionVersion 1470
#define sipName_QStyleOptionTitleBar__StyleOptionVersion &sipStrings_QtWidgets[1470]
#define sipNameNr_QStyleOptionViewItem__StyleOptionVersion 1511
#define sipName_QStyleOptionViewItem__StyleOptionVersion &sipStrings_QtWidgets[1511]
#define sipNameNr_SH_Menu_SubMenuResetWhenReenteringParent 1552
#define sipName_SH_Menu_SubMenuResetWhenReenteringParent &sipStrings_QtWidgets[1552]
#define sipNameNr_SH_ScrollBar_MiddleClickAbsolutePosition 1593
#define sipName_SH_ScrollBar_MiddleClickAbsolutePosition &sipStrings_QtWidgets[1593]
#define sipNameNr_QCalendarWidget__HorizontalHeaderFormat 1634
#define sipName_QCalendarWidget__HorizontalHeaderFormat &sipStrings_QtWidgets[1634]
#define sipNameNr_1674 1674
#define sipName_1674 &sipStrings_QtWidgets[1674]
#define sipNameNr_1714 1714
#define sipName_1714 &sipStrings_QtWidgets[1714]
#define sipNameNr_1754 1754
#define sipName_1754 &sipStrings_QtWidgets[1754]
#define sipNameNr_1794 1794
#define sipName_1794 &sipStrings_QtWidgets[1794]
#define sipNameNr_1834 1834
#define sipName_1834 &sipStrings_QtWidgets[1834]
#define sipNameNr_QStyleOptionComplex__StyleOptionVersion 1874
#define sipName_QStyleOptionComplex__StyleOptionVersion &sipStrings_QtWidgets[1874]
#define sipNameNr_QStyleOptionDockWidget__StyleOptionType 1914
#define sipName_QStyleOptionDockWidget__StyleOptionType &sipStrings_QtWidgets[1914]
#define sipNameNr_QStyleOptionRubberBand__StyleOptionType 1954
#define sipName_QStyleOptionRubberBand__StyleOptionType &sipStrings_QtWidgets[1954]
#define sipNameNr_QStyleOptionSpinBox__StyleOptionVersion 1994
#define sipName_QStyleOptionSpinBox__StyleOptionVersion &sipStrings_QtWidgets[1994]
#define sipNameNr_QStyleOptionTabBarBase__StyleOptionType 2034
#define sipName_QStyleOptionTabBarBase__StyleOptionType &sipStrings_QtWidgets[2034]
#define sipNameNr_QStyleOptionToolBar__StyleOptionVersion 2074
#define sipName_QStyleOptionToolBar__StyleOptionVersion &sipStrings_QtWidgets[2074]
#define sipNameNr_QStyleOptionToolBox__StyleOptionVersion 2114
#define sipName_QStyleOptionToolBox__StyleOptionVersion &sipStrings_QtWidgets[2114]
#define sipNameNr_QStyleOptionToolButton__StyleOptionType 2154
#define sipName_QStyleOptionToolButton__StyleOptionType &sipStrings_QtWidgets[2154]
#define sipNameNr_SH_Menu_SubMenuSloppySelectOtherActions 2194
#define sipName_SH_Menu_SubMenuSloppySelectOtherActions &sipStrings_QtWidgets[2194]
#define sipNameNr_SH_MessageBox_UseBorderForButtonSpacing 2234
#define sipName_SH_MessageBox_UseBorderForButtonSpacing &sipStrings_QtWidgets[2234]
#define sipNameNr_2274 2274
#define sipName_2274 &sipStrings_QtWidgets[2274]
#define sipNameNr_2313 2313
#define sipName_2313 &sipStrings_QtWidgets[2313]
#define sipNameNr_2352 2352
#define sipName_2352 &sipStrings_QtWidgets[2352]
#define sipNameNr_2391 2391
#define sipName_2391 &sipStrings_QtWidgets[2391]
#define sipNameNr_QGraphicsSceneContextMenuEvent__Reason 2430
#define sipName_QGraphicsSceneContextMenuEvent__Reason &sipStrings_QtWidgets[2430]
#define sipNameNr_QStyleOptionButton__StyleOptionVersion 2469
#define sipName_QStyleOptionButton__StyleOptionVersion &sipStrings_QtWidgets[2469]
#define sipNameNr_QStyleOptionFocusRect__StyleOptionType 2508
#define sipName_QStyleOptionFocusRect__StyleOptionType &sipStrings_QtWidgets[2508]
#define sipNameNr_QStyleOptionHeader__StyleOptionVersion 2547
#define sipName_QStyleOptionHeader__StyleOptionVersion &sipStrings_QtWidgets[2547]
#define sipNameNr_QStyleOptionSlider__StyleOptionVersion 2586
#define sipName_QStyleOptionSlider__StyleOptionVersion &sipStrings_QtWidgets[2586]
#define sipNameNr_QStyleOptionViewItem__ViewItemPosition 2625
#define sipName_QStyleOptionViewItem__ViewItemPosition &sipStrings_QtWidgets[2625]
#define sipNameNr_SH_GroupBox_TextLabelVerticalAlignment 2664
#define sipName_SH_GroupBox_TextLabelVerticalAlignment &sipStrings_QtWidgets[2664]
#define sipNameNr_SH_ScrollBar_LeftClickAbsolutePosition 2703
#define sipName_SH_ScrollBar_LeftClickAbsolutePosition &sipStrings_QtWidgets[2703]
#define sipNameNr_AdjustToMinimumContentsLengthWithIcon 2742
#define sipName_AdjustToMinimumContentsLengthWithIcon &sipStrings_QtWidgets[2742]
#define sipNameNr_PM_HeaderDefaultSectionSizeHorizontal 2780
#define sipName_PM_HeaderDefaultSectionSizeHorizontal &sipStrings_QtWidgets[2780]
#define sipNameNr_QAbstractScrollArea__SizeAdjustPolicy 2818
#define sipName_QAbstractScrollArea__SizeAdjustPolicy &sipStrings_QtWidgets[2818]
#define sipNameNr_QCalendarWidget__VerticalHeaderFormat 2856
#define sipName_QCalendarWidget__VerticalHeaderFormat &sipStrings_QtWidgets[2856]
#define sipNameNr_2894 2894
#define sipName_2894 &sipStrings_QtWidgets[2894]
#define sipNameNr_2932 2932
#define sipName_2932 &sipStrings_QtWidgets[2932]
#define sipNameNr_2970 2970
#define sipName_2970 &sipStrings_QtWidgets[2970]
#define sipNameNr_3008 3008
#define sipName_3008 &sipStrings_QtWidgets[3008]
#define sipNameNr_QStyleHintReturnMask__StyleOptionType 3046
#define sipName_QStyleHintReturnMask__StyleOptionType &sipStrings_QtWidgets[3046]
#define sipNameNr_QStyleOptionComboBox__StyleOptionType 3084
#define sipName_QStyleOptionComboBox__StyleOptionType &sipStrings_QtWidgets[3084]
#define sipNameNr_QStyleOptionFrame__StyleOptionVersion 3122
#define sipName_QStyleOptionFrame__StyleOptionVersion &sipStrings_QtWidgets[3122]
#define sipNameNr_QStyleOptionGroupBox__StyleOptionType 3160
#define sipName_QStyleOptionGroupBox__StyleOptionType &sipStrings_QtWidgets[3160]
#define sipNameNr_QStyleOptionHeaderV2__StyleOptionType 3198
#define sipName_QStyleOptionHeaderV2__StyleOptionType &sipStrings_QtWidgets[3198]
#define sipNameNr_QStyleOptionMenuItem__StyleOptionType 3236
#define sipName_QStyleOptionMenuItem__StyleOptionType &sipStrings_QtWidgets[3236]
#define sipNameNr_QStyleOptionSizeGrip__StyleOptionType 3274
#define sipName_QStyleOptionSizeGrip__StyleOptionType &sipStrings_QtWidgets[3274]
#define sipNameNr_QStyleOptionTitleBar__StyleOptionType 3312
#define sipName_QStyleOptionTitleBar__StyleOptionType &sipStrings_QtWidgets[3312]
#define sipNameNr_QStyleOptionToolBox__SelectedPosition 3350
#define sipName_QStyleOptionToolBox__SelectedPosition &sipStrings_QtWidgets[3350]
#define sipNameNr_QStyleOptionViewItem__StyleOptionType 3388
#define sipName_QStyleOptionViewItem__StyleOptionType &sipStrings_QtWidgets[3388]
#define sipNameNr_QStyleOptionViewItem__ViewItemFeature 3426
#define sipName_QStyleOptionViewItem__ViewItemFeature &sipStrings_QtWidgets[3426]
#define sipNameNr_QTreeWidgetItem__ChildIndicatorPolicy 3464
#define sipName_QTreeWidgetItem__ChildIndicatorPolicy &sipStrings_QtWidgets[3464]
#define sipNameNr_QTreeWidgetItemIterator__IteratorFlag 3502
#define sipName_QTreeWidgetItemIterator__IteratorFlag &sipStrings_QtWidgets[3502]
#define sipNameNr_SH_ComboBox_ListMouseTracking_Current 3540
#define sipName_SH_ComboBox_ListMouseTracking_Current &sipStrings_QtWidgets[3540]
#define sipNameNr_SH_ItemView_ActivateItemOnSingleClick 3578
#define sipName_SH_ItemView_ActivateItemOnSingleClick &sipStrings_QtWidgets[3578]
#define sipNameNr_SH_Menu_SubMenuDontStartSloppyOnLeave 3616
#define sipName_SH_Menu_SubMenuDontStartSloppyOnLeave &sipStrings_QtWidgets[3616]
#define sipNameNr_SH_ScrollView_FrameOnlyAroundContents 3654
#define sipName_SH_ScrollView_FrameOnlyAroundContents &sipStrings_QtWidgets[3654]
#define sipNameNr_ItemDoesntPropagateOpacityToChildren 3692
#define sipName_ItemDoesntPropagateOpacityToChildren &sipStrings_QtWidgets[3692]
#define sipNameNr_QAbstractItemView__SelectionBehavior 3729
#define sipName_QAbstractItemView__SelectionBehavior &sipStrings_QtWidgets[3729]
#define sipNameNr_3766 3766
#define sipName_3766 &sipStrings_QtWidgets[3766]
#define sipNameNr_QScrollerProperties__OvershootPolicy 3803
#define sipName_QScrollerProperties__OvershootPolicy &sipStrings_QtWidgets[3803]
#define sipNameNr_QStyleHintReturn__StyleOptionVersion 3840
#define sipName_QStyleHintReturn__StyleOptionVersion &sipStrings_QtWidgets[3840]
#define sipNameNr_QStyleOptionComplex__StyleOptionType 3877
#define sipName_QStyleOptionComplex__StyleOptionType &sipStrings_QtWidgets[3877]
#define sipNameNr_QStyleOptionHeader__SelectedPosition 3914
#define sipName_QStyleOptionHeader__SelectedPosition &sipStrings_QtWidgets[3914]
#define sipNameNr_QStyleOptionSpinBox__StyleOptionType 3951
#define sipName_QStyleOptionSpinBox__StyleOptionType &sipStrings_QtWidgets[3951]
#define sipNameNr_QStyleOptionToolBar__StyleOptionType 3988
#define sipName_QStyleOptionToolBar__StyleOptionType &sipStrings_QtWidgets[3988]
#define sipNameNr_QStyleOptionToolBar__ToolBarPosition 4025
#define sipName_QStyleOptionToolBar__ToolBarPosition &sipStrings_QtWidgets[4025]
#define sipNameNr_QStyleOptionToolBox__StyleOptionType 4062
#define sipName_QStyleOptionToolBox__StyleOptionType &sipStrings_QtWidgets[4062]
#define sipNameNr_SH_ComboBox_ListMouseTracking_Active 4099
#define sipName_SH_ComboBox_ListMouseTracking_Active &sipStrings_QtWidgets[4099]
#define sipNameNr_SH_Menu_SubMenuUniDirectionFailCount 4136
#define sipName_SH_Menu_SubMenuUniDirectionFailCount &sipStrings_QtWidgets[4136]
#define sipNameNr_SH_ProgressDialog_CenterCancelButton 4173
#define sipName_SH_ProgressDialog_CenterCancelButton &sipStrings_QtWidgets[4173]
#define sipNameNr_SH_ProgressDialog_TextLabelAlignment 4210
#define sipName_SH_ProgressDialog_TextLabelAlignment &sipStrings_QtWidgets[4210]
#define sipNameNr_PM_HeaderDefaultSectionSizeVertical 4247
#define sipName_PM_HeaderDefaultSectionSizeVertical &sipStrings_QtWidgets[4247]
#define sipNameNr_4283 4283
#define sipName_4283 &sipStrings_QtWidgets[4283]
#define sipNameNr_4319 4319
#define sipName_4319 &sipStrings_QtWidgets[4319]
#define sipNameNr_4355 4355
#define sipName_4355 &sipStrings_QtWidgets[4355]
#define sipNameNr_QStyleOptionButton__StyleOptionType 4391
#define sipName_QStyleOptionButton__StyleOptionType &sipStrings_QtWidgets[4391]
#define sipNameNr_QStyleOptionHeader__SectionPosition 4427
#define sipName_QStyleOptionHeader__SectionPosition &sipStrings_QtWidgets[4427]
#define sipNameNr_QStyleOptionHeader__StyleOptionType 4463
#define sipName_QStyleOptionHeader__StyleOptionType &sipStrings_QtWidgets[4463]
#define sipNameNr_QStyleOptionSlider__StyleOptionType 4499
#define sipName_QStyleOptionSlider__StyleOptionType &sipStrings_QtWidgets[4499]
#define sipNameNr_QStyleOptionTab__StyleOptionVersion 4535
#define sipName_QStyleOptionTab__StyleOptionVersion &sipStrings_QtWidgets[4535]
#define sipNameNr_QStyleOptionToolBar__ToolBarFeature 4571
#define sipName_QStyleOptionToolBar__ToolBarFeature &sipStrings_QtWidgets[4571]
#define sipNameNr_SH_DialogButtonBox_ButtonsHaveIcons 4607
#define sipName_SH_DialogButtonBox_ButtonsHaveIcons &sipStrings_QtWidgets[4607]
#define sipNameNr_SH_SpinBox_ClickAutoRepeatThreshold 4643
#define sipName_SH_SpinBox_ClickAutoRepeatThreshold &sipStrings_QtWidgets[4643]
#define sipNameNr_SH_Table_AlwaysDrawLeftTopGridLines 4679
#define sipName_SH_Table_AlwaysDrawLeftTopGridLines &sipStrings_QtWidgets[4679]
#define sipNameNr_SP_ToolBarHorizontalExtensionButton 4715
#define sipName_SP_ToolBarHorizontalExtensionButton &sipStrings_QtWidgets[4715]
#define sipNameNr_ItemTransformOriginPointHasChanged 4751
#define sipName_ItemTransformOriginPointHasChanged &sipStrings_QtWidgets[4751]
#define sipNameNr_PE_IndicatorDockWidgetResizeHandle 4786
#define sipName_PE_IndicatorDockWidgetResizeHandle &sipStrings_QtWidgets[4786]
#define sipNameNr_QAbstractItemDelegate__EndEditHint 4821
#define sipName_QAbstractItemDelegate__EndEditHint &sipStrings_QtWidgets[4821]
#define sipNameNr_4856 4856
#define sipName_4856 &sipStrings_QtWidgets[4856]
#define sipNameNr_QStyleOptionFrame__StyleOptionType 4891
#define sipName_QStyleOptionFrame__StyleOptionType &sipStrings_QtWidgets[4891]
#define sipNameNr_QStyleOptionMenuItem__MenuItemType 4926
#define sipName_QStyleOptionMenuItem__MenuItemType &sipStrings_QtWidgets[4926]
#define sipNameNr_RSIP_OnMouseClickAndAlreadyFocused 4961
#define sipName_RSIP_OnMouseClickAndAlreadyFocused &sipStrings_QtWidgets[4961]
#define sipNameNr_SH_FontDialog_SelectAssociatedText 4996
#define sipName_SH_FontDialog_SelectAssociatedText &sipStrings_QtWidgets[4996]
#define sipNameNr_SH_ItemView_ChangeHighlightOnFocus 5031
#define sipName_SH_ItemView_ChangeHighlightOnFocus &sipStrings_QtWidgets[5031]
#define sipNameNr_SH_ItemView_ShowDecorationSelected 5066
#define sipName_SH_ItemView_ShowDecorationSelected &sipStrings_QtWidgets[5066]
#define sipNameNr_SH_MessageBox_TextInteractionFlags 5101
#define sipName_SH_MessageBox_TextInteractionFlags &sipStrings_QtWidgets[5101]
#define sipNameNr_DontMaximizeSubWindowOnActivation 5136
#define sipName_DontMaximizeSubWindowOnActivation &sipStrings_QtWidgets[5136]
#define sipNameNr_PM_DockWidgetTitleBarButtonMargin 5170
#define sipName_PM_DockWidgetTitleBarButtonMargin &sipStrings_QtWidgets[5170]
#define sipNameNr_QAbstractSpinBox__StepEnabledFlag 5204
#define sipName_QAbstractSpinBox__StepEnabledFlag &sipStrings_QtWidgets[5204]
#define sipNameNr_5238 5238
#define sipName_5238 &sipStrings_QtWidgets[5238]
#define sipNameNr_5272 5272
#define sipName_5272 &sipStrings_QtWidgets[5272]
#define sipNameNr_QGraphicsItem__GraphicsItemChange 5306
#define sipName_QGraphicsItem__GraphicsItemChange &sipStrings_QtWidgets[5306]
#define sipNameNr_QGraphicsView__ViewportUpdateMode 5340
#define sipName_QGraphicsView__ViewportUpdateMode &sipStrings_QtWidgets[5340]
#define sipNameNr_5374 5374
#define sipName_5374 &sipStrings_QtWidgets[5374]
#define sipNameNr_QScrollerProperties__ScrollMetric 5408
#define sipName_QScrollerProperties__ScrollMetric &sipStrings_QtWidgets[5408]
#define sipNameNr_QStyle__RequestSoftwareInputPanel 5442
#define sipName_QStyle__RequestSoftwareInputPanel &sipStrings_QtWidgets[5442]
#define sipNameNr_QStyleHintReturn__StyleOptionType 5476
#define sipName_QStyleHintReturn__StyleOptionType &sipStrings_QtWidgets[5476]
#define sipNameNr_QStyleOptionButton__ButtonFeature 5510
#define sipName_QStyleOptionButton__ButtonFeature &sipStrings_QtWidgets[5510]
#define sipNameNr_QStyleOptionHeader__SortIndicator 5544
#define sipName_QStyleOptionHeader__SortIndicator &sipStrings_QtWidgets[5544]
#define sipNameNr_QStyleOptionTab__SelectedPosition 5578
#define sipName_QStyleOptionTab__SelectedPosition &sipStrings_QtWidgets[5578]
#define sipNameNr_QSystemTrayIcon__ActivationReason 5612
#define sipName_QSystemTrayIcon__ActivationReason &sipStrings_QtWidgets[5612]
#define sipNameNr_SH_ListViewExpand_SelectMouseType 5646
#define sipName_SH_ListViewExpand_SelectMouseType &sipStrings_QtWidgets[5646]
#define sipNameNr_SH_Menu_SubMenuSloppyCloseTimeout 5680
#define sipName_SH_Menu_SubMenuSloppyCloseTimeout &sipStrings_QtWidgets[5680]
#define sipNameNr_SH_SpinBox_KeyPressAutoRepeatRate 5714
#define sipName_SH_SpinBox_KeyPressAutoRepeatRate &sipStrings_QtWidgets[5714]
#define sipNameNr_SH_TitleBar_ShowToolTipsOnButtons 5748
#define sipName_SH_TitleBar_ShowToolTipsOnButtons &sipStrings_QtWidgets[5748]
#define sipNameNr_SP_ToolBarVerticalExtensionButton 5782
#define sipName_SP_ToolBarVerticalExtensionButton &sipStrings_QtWidgets[5782]
#define sipNameNr_QAbstractItemView__SelectionMode 5816
#define sipName_QAbstractItemView__SelectionMode &sipStrings_QtWidgets[5816]
#define sipNameNr_QAbstractSpinBox__CorrectionMode 5849
#define sipName_QAbstractSpinBox__CorrectionMode &sipStrings_QtWidgets[5849]
#define sipNameNr_QDialogButtonBox__StandardButton 5882
#define sipName_QDialogButtonBox__StandardButton &sipStrings_QtWidgets[5882]
#define sipNameNr_5915 5915
#define sipName_5915 &sipStrings_QtWidgets[5915]
#define sipNameNr_5948 5948
#define sipName_5948 &sipStrings_QtWidgets[5948]
#define sipNameNr_QStyleHintReturn__HintReturnType 5981
#define sipName_QStyleHintReturn__HintReturnType &sipStrings_QtWidgets[5981]
#define sipNameNr_QStyleOption__StyleOptionVersion 6014
#define sipName_QStyleOption__StyleOptionVersion &sipStrings_QtWidgets[6014]
#define sipNameNr_QStyleOptionTab__StyleOptionType 6047
#define sipName_QStyleOptionTab__StyleOptionType &sipStrings_QtWidgets[6047]
#define sipNameNr_QStyleOptionToolBox__TabPosition 6080
#define sipName_QStyleOptionToolBox__TabPosition &sipStrings_QtWidgets[6080]
#define sipNameNr_QToolButton__ToolButtonPopupMode 6113
#define sipName_QToolButton__ToolButtonPopupMode &sipStrings_QtWidgets[6113]
#define sipNameNr_SH_PrintDialog_RightAlignButtons 6146
#define sipName_SH_PrintDialog_RightAlignButtons &sipStrings_QtWidgets[6146]
#define sipNameNr_SH_ToolBox_SelectedPageTitleBold 6179
#define sipName_SH_ToolBox_SelectedPageTitleBold &sipStrings_QtWidgets[6179]
#define sipNameNr_SH_Workspace_FillSpaceOnMaximize 6212
#define sipName_SH_Workspace_FillSpaceOnMaximize &sipStrings_QtWidgets[6212]
#define sipNameNr_ItemNegativeZStacksBehindParent 6245
#define sipName_ItemNegativeZStacksBehindParent &sipStrings_QtWidgets[6245]
#define sipNameNr_QAbstractItemView__CursorAction 6277
#define sipName_QAbstractItemView__CursorAction &sipStrings_QtWidgets[6277]
#define sipNameNr_QAbstractItemView__DragDropMode 6309
#define sipName_QAbstractItemView__DragDropMode &sipStrings_QtWidgets[6309]
#define sipNameNr_QAbstractSpinBox__ButtonSymbols 6341
#define sipName_QAbstractSpinBox__ButtonSymbols &sipStrings_QtWidgets[6341]
#define sipNameNr_QColorDialog__ColorDialogOption 6373
#define sipName_QColorDialog__ColorDialogOption &sipStrings_QtWidgets[6373]
#define sipNameNr_QDataWidgetMapper__SubmitPolicy 6405
#define sipName_QDataWidgetMapper__SubmitPolicy &sipStrings_QtWidgets[6405]
#define sipNameNr_6437 6437
#define sipName_6437 &sipStrings_QtWidgets[6437]
#define sipNameNr_QGraphicsItem__GraphicsItemFlag 6469
#define sipName_QGraphicsItem__GraphicsItemFlag &sipStrings_QtWidgets[6469]
#define sipNameNr_QGraphicsScene__ItemIndexMethod 6501
#define sipName_QGraphicsScene__ItemIndexMethod &sipStrings_QtWidgets[6501]
#define sipNameNr_QGraphicsView__OptimizationFlag 6533
#define sipName_QGraphicsView__OptimizationFlag &sipStrings_QtWidgets[6533]
#define sipNameNr_QInputDialog__InputDialogOption 6565
#define sipName_QInputDialog__InputDialogOption &sipStrings_QtWidgets[6565]
#define sipNameNr_QScrollerProperties__FrameRates 6597
#define sipName_QScrollerProperties__FrameRates &sipStrings_QtWidgets[6597]
#define sipNameNr_QStyleOptionFrame__FrameFeature 6629
#define sipName_QStyleOptionFrame__FrameFeature &sipStrings_QtWidgets[6629]
#define sipNameNr_QStyleOptionMenuItem__CheckType 6661
#define sipName_QStyleOptionMenuItem__CheckType &sipStrings_QtWidgets[6661]
#define sipNameNr_SH_ComboBox_AllowWheelScrolling 6693
#define sipName_SH_ComboBox_AllowWheelScrolling &sipStrings_QtWidgets[6693]
#define sipNameNr_SH_MainWindow_SpaceBelowMenuBar 6725
#define sipName_SH_MainWindow_SpaceBelowMenuBar &sipStrings_QtWidgets[6725]
#define sipNameNr_SH_ScrollBar_RollBetweenButtons 6757
#define sipName_SH_ScrollBar_RollBetweenButtons &sipStrings_QtWidgets[6757]
#define sipNameNr_SH_SpinControls_DisableOnBounds 6789
#define sipName_SH_SpinControls_DisableOnBounds &sipStrings_QtWidgets[6789]
#define sipNameNr_SH_TabWidget_DefaultTabPosition 6821
#define sipName_SH_TabWidget_DefaultTabPosition &sipStrings_QtWidgets[6821]
#define sipNameNr_horizontalScrollbarValueChanged 6853
#define sipName_horizontalScrollbarValueChanged &sipStrings_QtWidgets[6853]
#define sipNameNr_AcceleratingFlickSpeedupFactor 6885
#define sipName_AcceleratingFlickSpeedupFactor &sipStrings_QtWidgets[6885]
#define sipNameNr_DontShowIndicatorWhenChildless 6916
#define sipName_DontShowIndicatorWhenChildless &sipStrings_QtWidgets[6916]
#define sipNameNr_ItemTransformOriginPointChange 6947
#define sipName_ItemTransformOriginPointChange &sipStrings_QtWidgets[6947]
#define sipNameNr_PM_ScrollView_ScrollBarOverlap 6978
#define sipName_PM_ScrollView_ScrollBarOverlap &sipStrings_QtWidgets[6978]
#define sipNameNr_PM_ScrollView_ScrollBarSpacing 7009
#define sipName_PM_ScrollView_ScrollBarSpacing &sipStrings_QtWidgets[7009]
#define sipNameNr_QAbstractItemView__EditTrigger 7040
#define sipName_QAbstractItemView__EditTrigger &sipStrings_QtWidgets[7040]
#define sipNameNr_QCalendarWidget__SelectionMode 7071
#define sipName_QCalendarWidget__SelectionMode &sipStrings_QtWidgets[7071]
#define sipNameNr_QDialogButtonBox__ButtonLayout 7102
#define sipName_QDialogButtonBox__ButtonLayout &sipStrings_QtWidgets[7102]
#define sipNameNr_QDockWidget__DockWidgetFeature 7133
#define sipName_QDockWidget__DockWidgetFeature &sipStrings_QtWidgets[7133]
#define sipNameNr_7164 7164
#define sipName_7164 &sipStrings_QtWidgets[7164]
#define sipNameNr_QFormLayout__FieldGrowthPolicy 7195
#define sipName_QFormLayout__FieldGrowthPolicy &sipStrings_QtWidgets[7195]
#define sipNameNr_QGestureRecognizer__ResultFlag 7226
#define sipName_QGestureRecognizer__ResultFlag &sipStrings_QtWidgets[7226]
#define sipNameNr_QGraphicsEffect__PixmapPadMode 7257
#define sipName_QGraphicsEffect__PixmapPadMode &sipStrings_QtWidgets[7257]
#define sipNameNr_QGraphicsPixmapItem__ShapeMode 7288
#define sipName_QGraphicsPixmapItem__ShapeMode &sipStrings_QtWidgets[7288]
#define sipNameNr_QGraphicsSceneContextMenuEvent 7319
#define sipName_QGraphicsSceneContextMenuEvent &sipStrings_QtWidgets[7319]
#define sipNameNr_QMdiSubWindow__SubWindowOption 7350
#define sipName_QMdiSubWindow__SubWindowOption &sipStrings_QtWidgets[7350]
#define sipNameNr_QScroller__ScrollerGestureType 7381
#define sipName_QScroller__ScrollerGestureType &sipStrings_QtWidgets[7381]
#define sipNameNr_QStyleOptionViewItem__Position 7412
#define sipName_QStyleOptionViewItem__Position &sipStrings_QtWidgets[7412]
#define sipNameNr_SH_BlinkCursorWhenTextSelected 7443
#define sipName_SH_BlinkCursorWhenTextSelected &sipStrings_QtWidgets[7443]
#define sipNameNr_SH_DialogButtons_DefaultButton 7474
#define sipName_SH_DialogButtons_DefaultButton &sipStrings_QtWidgets[7474]
#define sipNameNr_SH_DockWidget_ButtonsHaveFrame 7505
#define sipName_SH_DockWidget_ButtonsHaveFrame &sipStrings_QtWidgets[7505]
#define sipNameNr_SH_FormLayoutFieldGrowthPolicy 7536
#define sipName_SH_FormLayoutFieldGrowthPolicy &sipStrings_QtWidgets[7536]
#define sipNameNr_SH_Menu_AllowActiveAndDisabled 7567
#define sipName_SH_Menu_AllowActiveAndDisabled &sipStrings_QtWidgets[7567]
#define sipNameNr_SH_RichText_FullWidthSelection 7598
#define sipName_SH_RichText_FullWidthSelection &sipStrings_QtWidgets[7598]
#define sipNameNr_SH_SpinBox_ClickAutoRepeatRate 7629
#define sipName_SH_SpinBox_ClickAutoRepeatRate &sipStrings_QtWidgets[7629]
#define sipNameNr_SH_TitleBar_ModifyNotification 7660
#define sipName_SH_TitleBar_ModifyNotification &sipStrings_QtWidgets[7660]
#define sipNameNr_setUnifiedTitleAndToolBarOnMac 7691
#define sipName_setUnifiedTitleAndToolBarOnMac &sipStrings_QtWidgets[7691]
#define sipNameNr_unsetDefaultScrollerProperties 7722
#define sipName_unsetDefaultScrollerProperties &sipStrings_QtWidgets[7722]
#define sipNameNr_ItemSendsScenePositionChanges 7753
#define sipName_ItemSendsScenePositionChanges &sipStrings_QtWidgets[7753]
#define sipNameNr_OvershootDragResistanceFactor 7783
#define sipName_OvershootDragResistanceFactor &sipStrings_QtWidgets[7783]
#define sipNameNr_OvershootScrollDistanceFactor 7813
#define sipName_OvershootScrollDistanceFactor &sipStrings_QtWidgets[7813]
#define sipNameNr_PE_IndicatorItemViewItemCheck 7843
#define sipName_PE_IndicatorItemViewItemCheck &sipStrings_QtWidgets[7843]
#define sipNameNr_PM_MdiSubWindowMinimizedWidth 7873
#define sipName_PM_MdiSubWindowMinimizedWidth &sipStrings_QtWidgets[7873]
#define sipNameNr_PM_TabBar_ScrollButtonOverlap 7903
#define sipName_PM_TabBar_ScrollButtonOverlap &sipStrings_QtWidgets[7903]
#define sipNameNr_QAbstractItemView__ScrollHint 7933
#define sipName_QAbstractItemView__ScrollHint &sipStrings_QtWidgets[7933]
#define sipNameNr_QAbstractItemView__ScrollMode 7963
#define sipName_QAbstractItemView__ScrollMode &sipStrings_QtWidgets[7963]
#define sipNameNr_QAbstractSlider__SliderAction 7993
#define sipName_QAbstractSlider__SliderAction &sipStrings_QtWidgets[7993]
#define sipNameNr_QAbstractSlider__SliderChange 8023
#define sipName_QAbstractSlider__SliderChange &sipStrings_QtWidgets[8023]
#define sipNameNr_8053 8053
#define sipName_8053 &sipStrings_QtWidgets[8053]
#define sipNameNr_QFontDialog__FontDialogOption 8083
#define sipName_QFontDialog__FontDialogOption &sipStrings_QtWidgets[8083]
#define sipNameNr_QGesture__GestureCancelPolicy 8113
#define sipName_QGesture__GestureCancelPolicy &sipStrings_QtWidgets[8113]
#define sipNameNr_QGraphicsBlurEffect__BlurHint 8143
#define sipName_QGraphicsBlurEffect__BlurHint &sipStrings_QtWidgets[8143]
#define sipNameNr_QGraphicsView__ViewportAnchor 8173
#define sipName_QGraphicsView__ViewportAnchor &sipStrings_QtWidgets[8173]
#define sipNameNr_QStyleOption__StyleOptionType 8203
#define sipName_QStyleOption__StyleOptionType &sipStrings_QtWidgets[8203]
#define sipNameNr_QStyleOptionTab__CornerWidget 8233
#define sipName_QStyleOptionTab__CornerWidget &sipStrings_QtWidgets[8233]
#define sipNameNr_QSwipeGesture__SwipeDirection 8263
#define sipName_QSwipeGesture__SwipeDirection &sipStrings_QtWidgets[8263]
#define sipNameNr_QTextEdit__AutoFormattingFlag 8293
#define sipName_QTextEdit__AutoFormattingFlag &sipStrings_QtWidgets[8293]
#define sipNameNr_SE_ItemViewItemCheckIndicator 8323
#define sipName_SE_ItemViewItemCheckIndicator &sipStrings_QtWidgets[8323]
#define sipNameNr_SH_ComboBox_ListMouseTracking 8353
#define sipName_SH_ComboBox_ListMouseTracking &sipStrings_QtWidgets[8353]
#define sipNameNr_SH_ItemView_DrawDelegateFrame 8383
#define sipName_SH_ItemView_DrawDelegateFrame &sipStrings_QtWidgets[8383]
#define sipNameNr_SH_LineEdit_PasswordCharacter 8413
#define sipName_SH_LineEdit_PasswordCharacter &sipStrings_QtWidgets[8413]
#define sipNameNr_SH_LineEdit_PasswordMaskDelay 8443
#define sipName_SH_LineEdit_PasswordMaskDelay &sipStrings_QtWidgets[8443]
#define sipNameNr_SH_Slider_StopMouseOverSlider 8473
#define sipName_SH_Slider_StopMouseOverSlider &sipStrings_QtWidgets[8473]
#define sipNameNr_SH_SpinBox_ButtonsInsideFrame 8503
#define sipName_SH_SpinBox_ButtonsInsideFrame &sipStrings_QtWidgets[8503]
#define sipNameNr_SH_TabBar_AllowWheelScrolling 8533
#define sipName_SH_TabBar_AllowWheelScrolling &sipStrings_QtWidgets[8533]
#define sipNameNr_SH_TabBar_CloseButtonPosition 8563
#define sipName_SH_TabBar_CloseButtonPosition &sipStrings_QtWidgets[8563]
#define sipNameNr_sortIndicatorClearableChanged 8593
#define sipName_sortIndicatorClearableChanged &sipStrings_QtWidgets[8593]
#define sipNameNr_verticalScrollbarValueChanged 8623
#define sipName_verticalScrollbarValueChanged &sipStrings_QtWidgets[8623]
#define sipNameNr_AcceleratingFlickMaximumTime 8653
#define sipName_AcceleratingFlickMaximumTime &sipStrings_QtWidgets[8653]
#define sipNameNr_CaseInsensitivelySortedModel 8682
#define sipName_CaseInsensitivelySortedModel &sipStrings_QtWidgets[8682]
#define sipNameNr_DisabledBackButtonOnLastPage 8711
#define sipName_DisabledBackButtonOnLastPage &sipStrings_QtWidgets[8711]
#define sipNameNr_HaveFinishButtonOnEarlyPages 8740
#define sipName_HaveFinishButtonOnEarlyPages &sipStrings_QtWidgets[8740]
#define sipNameNr_PE_IndicatorItemViewItemDrop 8769
#define sipName_PE_IndicatorItemViewItemDrop &sipStrings_QtWidgets[8769]
#define sipNameNr_PE_IndicatorToolBarSeparator 8798
#define sipName_PE_IndicatorToolBarSeparator &sipStrings_QtWidgets[8798]
#define sipNameNr_PM_DialogButtonsButtonHeight 8827
#define sipName_PM_DialogButtonsButtonHeight &sipStrings_QtWidgets[8827]
#define sipNameNr_PM_DockWidgetSeparatorExtent 8856
#define sipName_PM_DockWidgetSeparatorExtent &sipStrings_QtWidgets[8856]
#define sipNameNr_QDialogButtonBox__ButtonRole 8885
#define sipName_QDialogButtonBox__ButtonRole &sipStrings_QtWidgets[8885]
#define sipNameNr_8914 8914
#define sipName_8914 &sipStrings_QtWidgets[8914]
#define sipNameNr_QGraphicsItem__PanelModality 8943
#define sipName_QGraphicsItem__PanelModality &sipStrings_QtWidgets[8943]
#define sipNameNr_QGraphicsView__CacheModeFlag 8972
#define sipName_QGraphicsView__CacheModeFlag &sipStrings_QtWidgets[8972]
#define sipNameNr_9001 9001
#define sipName_9001 &sipStrings_QtWidgets[9001]
#define sipNameNr_QPlainTextEdit__LineWrapMode 9030
#define sipName_QPlainTextEdit__LineWrapMode &sipStrings_QtWidgets[9030]
#define sipNameNr_QStackedLayout__StackingMode 9059
#define sipName_QStackedLayout__StackingMode &sipStrings_QtWidgets[9059]
#define sipNameNr_QStyleOptionTab__TabPosition 9088
#define sipName_QStyleOptionTab__TabPosition &sipStrings_QtWidgets[9088]
#define sipNameNr_QSystemTrayIcon__MessageIcon 9117
#define sipName_QSystemTrayIcon__MessageIcon &sipStrings_QtWidgets[9117]
#define sipNameNr_SC_TitleBarContextHelpButton 9146
#define sipName_SC_TitleBarContextHelpButton &sipStrings_QtWidgets[9146]
#define sipNameNr_SH_ItemView_EllipsisLocation 9175
#define sipName_SH_ItemView_EllipsisLocation &sipStrings_QtWidgets[9175]
#define sipNameNr_SH_Menu_FillScreenWithScroll 9204
#define sipName_SH_Menu_FillScreenWithScroll &sipStrings_QtWidgets[9204]
#define sipNameNr_SH_RequestSoftwareInputPanel 9233
#define sipName_SH_RequestSoftwareInputPanel &sipStrings_QtWidgets[9233]
#define sipNameNr_SH_Slider_AbsoluteSetButtons 9262
#define sipName_SH_Slider_AbsoluteSetButtons &sipStrings_QtWidgets[9262]
#define sipNameNr_SH_TabBar_ChangeCurrentDelay 9291
#define sipName_SH_TabBar_ChangeCurrentDelay &sipStrings_QtWidgets[9291]
#define sipNameNr_SH_Widget_Animation_Duration 9320
#define sipName_SH_Widget_Animation_Duration &sipStrings_QtWidgets[9320]
#define sipNameNr_SP_TitleBarContextHelpButton 9349
#define sipName_SP_TitleBarContextHelpButton &sipStrings_QtWidgets[9349]
#define sipNameNr_UsePlainTextEditForTextInput 9378
#define sipName_UsePlainTextEditForTextInput &sipStrings_QtWidgets[9378]
#define sipNameNr_setBoundingRegionGranularity 9407
#define sipName_setBoundingRegionGranularity &sipStrings_QtWidgets[9407]
#define sipNameNr_setDefaultScrollerProperties 7724
#define sipName_setDefaultScrollerProperties &sipStrings_QtWidgets[7724]
#define sipNameNr_setHorizontalScrollBarPolicy 9436
#define sipName_setHorizontalScrollBarPolicy &sipStrings_QtWidgets[9436]
#define sipNameNr_setSelectionBehaviorOnRemove 9465
#define sipName_setSelectionBehaviorOnRemove &sipStrings_QtWidgets[9465]
#define sipNameNr_AdjustToContentsOnFirstShow 9494
#define sipName_AdjustToContentsOnFirstShow &sipStrings_QtWidgets[9494]
#define sipNameNr_DontUseCustomDirectoryIcons 9522
#define sipName_DontUseCustomDirectoryIcons &sipStrings_QtWidgets[9522]
#define sipNameNr_DragVelocitySmoothingFactor 9550
#define sipName_DragVelocitySmoothingFactor &sipStrings_QtWidgets[9550]
#define sipNameNr_ItemContainsChildrenInShape 9578
#define sipName_ItemContainsChildrenInShape &sipStrings_QtWidgets[9578]
#define sipNameNr_ItemScenePositionHasChanged 9606
#define sipName_ItemScenePositionHasChanged &sipStrings_QtWidgets[9606]
#define sipNameNr_ItemUsesExtendedStyleOption 9634
#define sipName_ItemUsesExtendedStyleOption &sipStrings_QtWidgets[9634]
#define sipNameNr_MaximumClickThroughVelocity 9662
#define sipName_MaximumClickThroughVelocity &sipStrings_QtWidgets[9662]
#define sipNameNr_OvershootDragDistanceFactor 9690
#define sipName_OvershootDragDistanceFactor &sipStrings_QtWidgets[9690]
#define sipNameNr_PE_IndicatorColumnViewArrow 9718
#define sipName_PE_IndicatorColumnViewArrow &sipStrings_QtWidgets[9718]
#define sipNameNr_PM_DialogButtonsButtonWidth 9746
#define sipName_PM_DialogButtonsButtonWidth &sipStrings_QtWidgets[9746]
#define sipNameNr_PM_ExclusiveIndicatorHeight 9774
#define sipName_PM_ExclusiveIndicatorHeight &sipStrings_QtWidgets[9774]
#define sipNameNr_PM_TabBarTabShiftHorizontal 9802
#define sipName_PM_TabBarTabShiftHorizontal &sipStrings_QtWidgets[9802]
#define sipNameNr_QComboBox__LabelDrawingMode 9830
#define sipName_QComboBox__LabelDrawingMode &sipStrings_QtWidgets[9830]
#define sipNameNr_QComboBox__SizeAdjustPolicy 9858
#define sipName_QComboBox__SizeAdjustPolicy &sipStrings_QtWidgets[9858]
#define sipNameNr_9886 9886
#define sipName_9886 &sipStrings_QtWidgets[9886]
#define sipNameNr_9914 9914
#define sipName_9914 &sipStrings_QtWidgets[9914]
#define sipNameNr_9942 9942
#define sipName_9942 &sipStrings_QtWidgets[9942]
#define sipNameNr_QGraphicsEffect__ChangeFlag 9970
#define sipName_QGraphicsEffect__ChangeFlag &sipStrings_QtWidgets[9970]
#define sipNameNr_QGraphicsSceneDragDropEvent 9998
#define sipName_QGraphicsSceneDragDropEvent &sipStrings_QtWidgets[9998]
#define sipNameNr_10026 10026
#define sipName_10026 &sipStrings_QtWidgets[10026]
#define sipNameNr_QMessageBox__StandardButton 10054
#define sipName_QMessageBox__StandardButton &sipStrings_QtWidgets[10054]
#define sipNameNr_QStyleOptionTab__TabFeature 10082
#define sipName_QStyleOptionTab__TabFeature &sipStrings_QtWidgets[10082]
#define sipNameNr_SE_TabBarTearIndicatorRight 10110
#define sipName_SE_TabBarTearIndicatorRight &sipStrings_QtWidgets[10110]
#define sipNameNr_SH_ComboBox_LayoutDirection 10138
#define sipName_SH_ComboBox_LayoutDirection &sipStrings_QtWidgets[10138]
#define sipNameNr_SH_ComboBox_PopupFrameStyle 10166
#define sipName_SH_ComboBox_PopupFrameStyle &sipStrings_QtWidgets[10166]
#define sipNameNr_SH_FormLayoutLabelAlignment 10194
#define sipName_SH_FormLayoutLabelAlignment &sipStrings_QtWidgets[10194]
#define sipNameNr_SH_MenuBar_AltKeyNavigation 10222
#define sipName_SH_MenuBar_AltKeyNavigation &sipStrings_QtWidgets[10222]
#define sipNameNr_SH_Menu_SubMenuUniDirection 10250
#define sipName_SH_Menu_SubMenuUniDirection &sipStrings_QtWidgets[10250]
#define sipNameNr_SH_MessageBox_CenterButtons 10278
#define sipName_SH_MessageBox_CenterButtons &sipStrings_QtWidgets[10278]
#define sipNameNr_UseListViewForComboBoxItems 10306
#define sipName_UseListViewForComboBoxItems &sipStrings_QtWidgets[10306]
#define sipNameNr_createMimeDataFromSelection 10334
#define sipName_createMimeDataFromSelection &sipStrings_QtWidgets[10334]
#define sipNameNr_setFinishingKeyCombinations 10362
#define sipName_setFinishingKeyCombinations &sipStrings_QtWidgets[10362]
#define sipNameNr_setHorizontalSizeConstraint 10390
#define sipName_setHorizontalSizeConstraint &sipStrings_QtWidgets[10390]
#define sipNameNr_tabifiedDockWidgetActivated 10418
#define sipName_tabifiedDockWidgetActivated &sipStrings_QtWidgets[10418]
#define sipNameNr_unifiedTitleAndToolBarOnMac 10446
#define sipName_unifiedTitleAndToolBarOnMac &sipStrings_QtWidgets[10446]
#define sipNameNr_BoundingRectViewportUpdate 10474
#define sipName_BoundingRectViewportUpdate &sipStrings_QtWidgets[10474]
#define sipNameNr_CaseSensitivelySortedModel 10501
#define sipName_CaseSensitivelySortedModel &sipStrings_QtWidgets[10501]
#define sipNameNr_DockWidgetVerticalTitleBar 10528
#define sipName_DockWidgetVerticalTitleBar &sipStrings_QtWidgets[10528]
#define sipNameNr_ItemIgnoresTransformations 10555
#define sipName_ItemIgnoresTransformations &sipStrings_QtWidgets[10555]
#define sipNameNr_NextAndPreviousAreSelected 10582
#define sipName_NextAndPreviousAreSelected &sipStrings_QtWidgets[10582]
#define sipNameNr_PE_IndicatorButtonDropDown 10609
#define sipName_PE_IndicatorButtonDropDown &sipStrings_QtWidgets[10609]
#define sipNameNr_PM_ExclusiveIndicatorWidth 10636
#define sipName_PM_ExclusiveIndicatorWidth &sipStrings_QtWidgets[10636]
#define sipNameNr_PM_LayoutHorizontalSpacing 10663
#define sipName_PM_LayoutHorizontalSpacing &sipStrings_QtWidgets[10663]
#define sipNameNr_PM_RadioButtonLabelSpacing 10690
#define sipName_PM_RadioButtonLabelSpacing &sipStrings_QtWidgets[10690]
#define sipNameNr_PM_TabBarScrollButtonWidth 10717
#define sipName_PM_TabBarScrollButtonWidth &sipStrings_QtWidgets[10717]
#define sipNameNr_PM_TabCloseIndicatorHeight 10744
#define sipName_PM_TabCloseIndicatorHeight &sipStrings_QtWidgets[10744]
#define sipNameNr_PadToEffectiveBoundingRect 10771
#define sipName_PadToEffectiveBoundingRect &sipStrings_QtWidgets[10771]
#define sipNameNr_QAbstractGraphicsShapeItem 10798
#define sipName_QAbstractGraphicsShapeItem &sipStrings_QtWidgets[10798]
#define sipNameNr_QAbstractSpinBox__StepType 10825
#define sipName_QAbstractSpinBox__StepType &sipStrings_QtWidgets[10825]
#define sipNameNr_QCompleter__CompletionMode 10852
#define sipName_QCompleter__CompletionMode &sipStrings_QtWidgets[10852]
#define sipNameNr_10879 10879
#define sipName_10879 &sipStrings_QtWidgets[10879]
#define sipNameNr_QFormLayout__RowWrapPolicy 10906
#define sipName_QFormLayout__RowWrapPolicy &sipStrings_QtWidgets[10906]
#define sipNameNr_QFormLayout__TakeRowResult 10933
#define sipName_QFormLayout__TakeRowResult &sipStrings_QtWidgets[10933]
#define sipNameNr_QGraphicsScene__SceneLayer 10960
#define sipName_QGraphicsScene__SceneLayer &sipStrings_QtWidgets[10960]
#define sipNameNr_10987 10987
#define sipName_10987 &sipStrings_QtWidgets[10987]
#define sipNameNr_QStyleOptionTabWidgetFrame 11014
#define sipName_QStyleOptionTabWidgetFrame &sipStrings_QtWidgets[11014]
#define sipNameNr_QTabBar__SelectionBehavior 11041
#define sipName_QTabBar__SelectionBehavior &sipStrings_QtWidgets[11041]
#define sipNameNr_QTableWidgetItem__ItemType 11068
#define sipName_QTableWidgetItem__ItemType &sipStrings_QtWidgets[11068]
#define sipNameNr_QTableWidgetSelectionRange 11095
#define sipName_QTableWidgetSelectionRange &sipStrings_QtWidgets[11095]
#define sipNameNr_SE_TabBarScrollRightButton 11122
#define sipName_SE_TabBarScrollRightButton &sipStrings_QtWidgets[11122]
#define sipNameNr_SE_TabBarTearIndicatorLeft 11149
#define sipName_SE_TabBarTearIndicatorLeft &sipStrings_QtWidgets[11149]
#define sipNameNr_SH_FormLayoutFormAlignment 11176
#define sipName_SH_FormLayoutFormAlignment &sipStrings_QtWidgets[11176]
#define sipNameNr_SH_GroupBox_TextLabelColor 11203
#define sipName_SH_GroupBox_TextLabelColor &sipStrings_QtWidgets[11203]
#define sipNameNr_SH_Menu_FlashTriggeredItem 11230
#define sipName_SH_Menu_FlashTriggeredItem &sipStrings_QtWidgets[11230]
#define sipNameNr_SH_Menu_SpaceActivatesItem 11257
#define sipName_SH_Menu_SpaceActivatesItem &sipStrings_QtWidgets[11257]
#define sipNameNr_SH_ToolTip_FallAsleepDelay 11284
#define sipName_SH_ToolTip_FallAsleepDelay &sipStrings_QtWidgets[11284]
#define sipNameNr_customContextMenuRequested 11311
#define sipName_customContextMenuRequested &sipStrings_QtWidgets[11311]
#define sipNameNr_levelOfDetailFromTransform 11338
#define sipName_levelOfDetailFromTransform &sipStrings_QtWidgets[11338]
#define sipNameNr_scheduleDelayedItemsLayout 11365
#define sipName_scheduleDelayedItemsLayout &sipStrings_QtWidgets[11365]
#define sipNameNr_sectionHandleDoubleClicked 11392
#define sipName_sectionHandleDoubleClicked &sipStrings_QtWidgets[11392]
#define sipNameNr_setCascadingSectionResizes 11419
#define sipName_setCascadingSectionResizes &sipStrings_QtWidgets[11419]
#define sipNameNr_setOffsetToSectionPosition 11446
#define sipName_setOffsetToSectionPosition &sipStrings_QtWidgets[11446]
#define sipNameNr_setResizeContentsPrecision 11473
#define sipName_setResizeContentsPrecision &sipStrings_QtWidgets[11473]
#define sipNameNr_setRubberBandSelectionMode 11500
#define sipName_setRubberBandSelectionMode &sipStrings_QtWidgets[11500]
#define sipNameNr_setVerticalScrollBarPolicy 11527
#define sipName_setVerticalScrollBarPolicy &sipStrings_QtWidgets[11527]
#define sipNameNr_DontAdjustForAntialiasing 11554
#define sipName_DontAdjustForAntialiasing &sipStrings_QtWidgets[11554]
#define sipNameNr_HorizontalOvershootPolicy 11580
#define sipName_HorizontalOvershootPolicy &sipStrings_QtWidgets[11580]
#define sipNameNr_IsDecorationForRootColumn 11606
#define sipName_IsDecorationForRootColumn &sipStrings_QtWidgets[11606]
#define sipNameNr_PE_IndicatorMenuCheckMark 11632
#define sipName_PE_IndicatorMenuCheckMark &sipStrings_QtWidgets[11632]
#define sipNameNr_PE_IndicatorProgressChunk 11658
#define sipName_PE_IndicatorProgressChunk &sipStrings_QtWidgets[11658]
#define sipNameNr_PE_IndicatorToolBarHandle 11684
#define sipName_PE_IndicatorToolBarHandle &sipStrings_QtWidgets[11684]
#define sipNameNr_PM_ButtonDefaultIndicator 11710
#define sipName_PM_ButtonDefaultIndicator &sipStrings_QtWidgets[11710]
#define sipNameNr_PM_DialogButtonsSeparator 11736
#define sipName_PM_DialogButtonsSeparator &sipStrings_QtWidgets[11736]
#define sipNameNr_PM_DockWidgetHandleExtent 11762
#define sipName_PM_DockWidgetHandleExtent &sipStrings_QtWidgets[11762]
#define sipNameNr_PM_MdiSubWindowFrameWidth 11788
#define sipName_PM_MdiSubWindowFrameWidth &sipStrings_QtWidgets[11788]
#define sipNameNr_PM_SliderControlThickness 11814
#define sipName_PM_SliderControlThickness &sipStrings_QtWidgets[11814]
#define sipNameNr_PM_TabBarTabShiftVertical 11840
#define sipName_PM_TabBarTabShiftVertical &sipStrings_QtWidgets[11840]
#define sipNameNr_PM_TabCloseIndicatorWidth 11866
#define sipName_PM_TabCloseIndicatorWidth &sipStrings_QtWidgets[11866]
#define sipNameNr_PM_TitleBarButtonIconSize 11892
#define sipName_PM_TitleBarButtonIconSize &sipStrings_QtWidgets[11892]
#define sipNameNr_PM_ToolBarExtensionExtent 11918
#define sipName_PM_ToolBarExtensionExtent &sipStrings_QtWidgets[11918]
#define sipNameNr_PM_ToolBarSeparatorExtent 11944
#define sipName_PM_ToolBarSeparatorExtent &sipStrings_QtWidgets[11944]
#define sipNameNr_PM_ToolTipLabelFrameWidth 11970
#define sipName_PM_ToolTipLabelFrameWidth &sipStrings_QtWidgets[11970]
#define sipNameNr_11996 11996
#define sipName_11996 &sipStrings_QtWidgets[11996]
#define sipNameNr_QFontComboBox__FontFilter 12022
#define sipName_QFontComboBox__FontFilter &sipStrings_QtWidgets[12022]
#define sipNameNr_QGraphicsDropShadowEffect 12048
#define sipName_QGraphicsDropShadowEffect &sipStrings_QtWidgets[12048]
#define sipNameNr_QGraphicsSceneResizeEvent 12074
#define sipName_QGraphicsSceneResizeEvent &sipStrings_QtWidgets[12074]
#define sipNameNr_QLineEdit__ActionPosition 12100
#define sipName_QLineEdit__ActionPosition &sipStrings_QtWidgets[12100]
#define sipNameNr_QListWidgetItem__ItemType 12126
#define sipName_QListWidgetItem__ItemType &sipStrings_QtWidgets[12126]
#define sipNameNr_QPinchGesture__ChangeFlag 12152
#define sipName_QPinchGesture__ChangeFlag &sipStrings_QtWidgets[12152]
#define sipNameNr_QTextEdit__ExtraSelection 12178
#define sipName_QTextEdit__ExtraSelection &sipStrings_QtWidgets[12178]
#define sipNameNr_QTreeWidgetItem__ItemType 12204
#define sipName_QTreeWidgetItem__ItemType &sipStrings_QtWidgets[12204]
#define sipNameNr_RequestSoftwareInputPanel 5450
#define sipName_RequestSoftwareInputPanel &sipStrings_QtWidgets[5450]
#define sipNameNr_SE_DateTimeEditLayoutItem 12230
#define sipName_SE_DateTimeEditLayoutItem &sipStrings_QtWidgets[12230]
#define sipNameNr_SE_DockWidgetTitleBarText 12256
#define sipName_SE_DockWidgetTitleBarText &sipStrings_QtWidgets[12256]
#define sipNameNr_SE_ItemViewItemDecoration 12282
#define sipName_SE_ItemViewItemDecoration &sipStrings_QtWidgets[12282]
#define sipNameNr_SE_TabBarScrollLeftButton 12308
#define sipName_SE_TabBarScrollLeftButton &sipStrings_QtWidgets[12308]
#define sipNameNr_SE_TreeViewDisclosureItem 12334
#define sipName_SE_TreeViewDisclosureItem &sipStrings_QtWidgets[12334]
#define sipNameNr_SH_FocusFrame_AboveWidget 12360
#define sipName_SH_FocusFrame_AboveWidget &sipStrings_QtWidgets[12360]
#define sipNameNr_SH_Menu_SubMenuPopupDelay 12386
#define sipName_SH_Menu_SubMenuPopupDelay &sipStrings_QtWidgets[12386]
#define sipNameNr_SH_Slider_SloppyKeyEvents 12412
#define sipName_SH_Slider_SloppyKeyEvents &sipStrings_QtWidgets[12412]
#define sipNameNr_SH_TabBar_SelectMouseType 12438
#define sipName_SH_TabBar_SelectMouseType &sipStrings_QtWidgets[12438]
#define sipNameNr_SH_Widget_ShareActivation 12464
#define sipName_SH_Widget_ShareActivation &sipStrings_QtWidgets[12464]
#define sipNameNr_SP_FileDialogContentsView 12490
#define sipName_SP_FileDialogContentsView &sipStrings_QtWidgets[12490]
#define sipNameNr_SP_FileDialogDetailedView 12516
#define sipName_SP_FileDialogDetailedView &sipStrings_QtWidgets[12516]
#define sipNameNr_SourceBoundingRectChanged 12542
#define sipName_SourceBoundingRectChanged &sipStrings_QtWidgets[12542]
#define sipNameNr_State_KeyboardFocusChange 12568
#define sipName_State_KeyboardFocusChange &sipStrings_QtWidgets[12568]
#define sipNameNr_UnfilteredPopupCompletion 12594
#define sipName_UnfilteredPopupCompletion &sipStrings_QtWidgets[12594]
#define sipNameNr_activatePreviousSubWindow 12620
#define sipName_activatePreviousSubWindow &sipStrings_QtWidgets[12620]
#define sipNameNr_boundingRegionGranularity 12646
#define sipName_boundingRegionGranularity &sipStrings_QtWidgets[12646]
#define sipNameNr_createProxyForChildWidget 12672
#define sipName_createProxyForChildWidget &sipStrings_QtWidgets[12672]
#define sipNameNr_createStandardContextMenu 12698
#define sipName_createStandardContextMenu &sipStrings_QtWidgets[12698]
#define sipNameNr_executeDelayedItemsLayout 12724
#define sipName_executeDelayedItemsLayout &sipStrings_QtWidgets[12724]
#define sipNameNr_horizontalScrollBarPolicy 12750
#define sipName_horizontalScrollBarPolicy &sipStrings_QtWidgets[12750]
#define sipNameNr_horizontalScrollbarAction 12776
#define sipName_horizontalScrollbarAction &sipStrings_QtWidgets[12776]
#define sipNameNr_resetHorizontalScrollMode 12802
#define sipName_resetHorizontalScrollMode &sipStrings_QtWidgets[12802]
#define sipNameNr_scrollerPropertiesChanged 12828
#define sipName_scrollerPropertiesChanged &sipStrings_QtWidgets[12828]
#define sipNameNr_selectionBehaviorOnRemove 12854
#define sipName_selectionBehaviorOnRemove &sipStrings_QtWidgets[12854]
#define sipNameNr_setHorizontalHeaderFormat 12880
#define sipName_setHorizontalHeaderFormat &sipStrings_QtWidgets[12880]
#define sipNameNr_setHorizontalHeaderLabels 12906
#define sipName_setHorizontalHeaderLabels &sipStrings_QtWidgets[12906]
#define sipNameNr_setSortIndicatorClearable 12932
#define sipName_setSortIndicatorClearable &sipStrings_QtWidgets[12932]
#define sipNameNr_setVerticalSizeConstraint 12958
#define sipName_setVerticalSizeConstraint &sipStrings_QtWidgets[12958]
#define sipNameNr_HaveNextButtonOnLastPage 12984
#define sipName_HaveNextButtonOnLastPage &sipStrings_QtWidgets[12984]
#define sipNameNr_ItemClipsChildrenToShape 13009
#define sipName_ItemClipsChildrenToShape &sipStrings_QtWidgets[13009]
#define sipNameNr_ItemIgnoresParentOpacity 13034
#define sipName_ItemIgnoresParentOpacity &sipStrings_QtWidgets[13034]
#define sipNameNr_ItemSendsGeometryChanges 13059
#define sipName_ItemSendsGeometryChanges &sipStrings_QtWidgets[13059]
#define sipNameNr_MiddleMouseButtonGesture 13084
#define sipName_MiddleMouseButtonGesture &sipStrings_QtWidgets[13084]
#define sipNameNr_NoCancelButtonOnLastPage 13109
#define sipName_NoCancelButtonOnLastPage &sipStrings_QtWidgets[13109]
#define sipNameNr_PE_IndicatorTabTearRight 13134
#define sipName_PE_IndicatorTabTearRight &sipStrings_QtWidgets[13134]
#define sipNameNr_PE_PanelScrollAreaCorner 13159
#define sipName_PE_PanelScrollAreaCorner &sipStrings_QtWidgets[13159]
#define sipNameNr_PM_ButtonShiftHorizontal 13184
#define sipName_PM_ButtonShiftHorizontal &sipStrings_QtWidgets[13184]
#define sipNameNr_PM_DockWidgetTitleMargin 13209
#define sipName_PM_DockWidgetTitleMargin &sipStrings_QtWidgets[13209]
#define sipNameNr_PM_LayoutVerticalSpacing 13234
#define sipName_PM_LayoutVerticalSpacing &sipStrings_QtWidgets[13234]
#define sipNameNr_PM_MenuDesktopFrameWidth 13259
#define sipName_PM_MenuDesktopFrameWidth &sipStrings_QtWidgets[13259]
#define sipNameNr_PM_ProgressBarChunkWidth 13284
#define sipName_PM_ProgressBarChunkWidth &sipStrings_QtWidgets[13284]
#define sipNameNr_QAbstractItemView__State 13309
#define sipName_QAbstractItemView__State &sipStrings_QtWidgets[13309]
#define sipNameNr_QCompleter__ModelSorting 13334
#define sipName_QCompleter__ModelSorting &sipStrings_QtWidgets[13334]
#define sipNameNr_QFileDialog__DialogLabel 13359
#define sipName_QFileDialog__DialogLabel &sipStrings_QtWidgets[13359]
#define sipNameNr_QGraphicsItem__CacheMode 13384
#define sipName_QGraphicsItem__CacheMode &sipStrings_QtWidgets[13384]
#define sipNameNr_QGraphicsSceneHoverEvent 13409
#define sipName_QGraphicsSceneHoverEvent &sipStrings_QtWidgets[13409]
#define sipNameNr_QGraphicsSceneMouseEvent 13434
#define sipName_QGraphicsSceneMouseEvent &sipStrings_QtWidgets[13434]
#define sipNameNr_QGraphicsSceneWheelEvent 13459
#define sipName_QGraphicsSceneWheelEvent &sipStrings_QtWidgets[13459]
#define sipNameNr_QLCDNumber__SegmentStyle 13484
#define sipName_QLCDNumber__SegmentStyle &sipStrings_QtWidgets[13484]
#define sipNameNr_13509 13509
#define sipName_13509 &sipStrings_QtWidgets[13509]
#define sipNameNr_QPlainTextDocumentLayout 13534
#define sipName_QPlainTextDocumentLayout &sipStrings_QtWidgets[13534]
#define sipNameNr_QSizePolicy__ControlType 13559
#define sipName_QSizePolicy__ControlType &sipStrings_QtWidgets[13559]
#define sipNameNr_QStyle__PrimitiveElement 13584
#define sipName_QStyle__PrimitiveElement &sipStrings_QtWidgets[13584]
#define sipNameNr_QStyleOption__OptionType 13609
#define sipName_QStyleOption__OptionType &sipStrings_QtWidgets[13609]
#define sipNameNr_QStyleOptionGraphicsItem 13634
#define sipName_QStyleOptionGraphicsItem &sipStrings_QtWidgets[13634]
#define sipNameNr_SC_TitleBarUnshadeButton 13659
#define sipName_SC_TitleBarUnshadeButton &sipStrings_QtWidgets[13659]
#define sipNameNr_SE_DockWidgetCloseButton 13684
#define sipName_SE_DockWidgetCloseButton &sipStrings_QtWidgets[13684]
#define sipNameNr_SE_DockWidgetFloatButton 13709
#define sipName_SE_DockWidgetFloatButton &sipStrings_QtWidgets[13709]
#define sipNameNr_SE_ItemViewItemFocusRect 13734
#define sipName_SE_ItemViewItemFocusRect &sipStrings_QtWidgets[13734]
#define sipNameNr_SE_ProgressBarLayoutItem 13759
#define sipName_SE_ProgressBarLayoutItem &sipStrings_QtWidgets[13759]
#define sipNameNr_SE_RadioButtonLayoutItem 13784
#define sipName_SE_RadioButtonLayoutItem &sipStrings_QtWidgets[13784]
#define sipNameNr_SH_Header_ArrowAlignment 13809
#define sipName_SH_Header_ArrowAlignment &sipStrings_QtWidgets[13809]
#define sipNameNr_SH_MenuBar_MouseTracking 13834
#define sipName_SH_MenuBar_MouseTracking &sipStrings_QtWidgets[13834]
#define sipNameNr_SH_Menu_SupportsSections 13859
#define sipName_SH_Menu_SupportsSections &sipStrings_QtWidgets[13859]
#define sipNameNr_SH_ScrollBar_ContextMenu 13884
#define sipName_SH_ScrollBar_ContextMenu &sipStrings_QtWidgets[13884]
#define sipNameNr_SH_Slider_PageSetButtons 13909
#define sipName_SH_Slider_PageSetButtons &sipStrings_QtWidgets[13909]
#define sipNameNr_SH_SpinBox_AnimateButton 13934
#define sipName_SH_SpinBox_AnimateButton &sipStrings_QtWidgets[13934]
#define sipNameNr_SH_Splitter_OpaqueResize 13959
#define sipName_SH_Splitter_OpaqueResize &sipStrings_QtWidgets[13959]
#define sipNameNr_SH_TabBar_PreferNoArrows 13984
#define sipName_SH_TabBar_PreferNoArrows &sipStrings_QtWidgets[13984]
#define sipNameNr_SH_ToolButton_PopupDelay 14009
#define sipName_SH_ToolButton_PopupDelay &sipStrings_QtWidgets[14009]
#define sipNameNr_SP_DockWidgetCloseButton 14034
#define sipName_SP_DockWidgetCloseButton &sipStrings_QtWidgets[14034]
#define sipNameNr_SP_MessageBoxInformation 14059
#define sipName_SP_MessageBoxInformation &sipStrings_QtWidgets[14059]
#define sipNameNr_SP_RestoreDefaultsButton 14084
#define sipName_SP_RestoreDefaultsButton &sipStrings_QtWidgets[14084]
#define sipNameNr_SP_TitleBarUnshadeButton 14109
#define sipName_SP_TitleBarUnshadeButton &sipStrings_QtWidgets[14109]
#define sipNameNr_currentCharFormatChanged 14134
#define sipName_currentCharFormatChanged &sipStrings_QtWidgets[14134]
#define sipNameNr_finishingKeyCombinations 14159
#define sipName_finishingKeyCombinations &sipStrings_QtWidgets[14159]
#define sipNameNr_horizontalSizeConstraint 14184
#define sipName_horizontalSizeConstraint &sipStrings_QtWidgets[14184]
#define sipNameNr_isSortIndicatorClearable 14209
#define sipName_isSortIndicatorClearable &sipStrings_QtWidgets[14209]
#define sipNameNr_sectionsAboutToBeRemoved 14234
#define sipName_sectionsAboutToBeRemoved &sipStrings_QtWidgets[14234]
#define sipNameNr_setAccessibleDescription 14259
#define sipName_setAccessibleDescription &sipStrings_QtWidgets[14259]
#define sipNameNr_setDragDropOverwriteMode 14284
#define sipName_setDragDropOverwriteMode &sipStrings_QtWidgets[14284]
#define sipNameNr_setItemDelegateForColumn 14309
#define sipName_setItemDelegateForColumn &sipStrings_QtWidgets[14309]
#define sipNameNr_setKeyboardInputInterval 14334
#define sipName_setKeyboardInputInterval &sipStrings_QtWidgets[14334]
#define sipNameNr_setLineWrapColumnOrWidth 14359
#define sipName_setLineWrapColumnOrWidth &sipStrings_QtWidgets[14359]
#define sipNameNr_setMaximumSequenceLength 14384
#define sipName_setMaximumSequenceLength &sipStrings_QtWidgets[14384]
#define sipNameNr_setMinimumContentsLength 14409
#define sipName_setMinimumContentsLength &sipStrings_QtWidgets[14409]
#define sipNameNr_setSeparatorsCollapsible 14434
#define sipName_setSeparatorsCollapsible &sipStrings_QtWidgets[14434]
#define sipNameNr_takeHorizontalHeaderItem 14459
#define sipName_takeHorizontalHeaderItem &sipStrings_QtWidgets[14459]
#define sipNameNr_visualRegionForSelection 14484
#define sipName_visualRegionForSelection &sipStrings_QtWidgets[14484]
#define sipNameNr_AdaptiveDecimalStepType 14509
#define sipName_AdaptiveDecimalStepType &sipStrings_QtWidgets[14509]
#define sipNameNr_ExtendedWatermarkPixmap 14533
#define sipName_ExtendedWatermarkPixmap &sipStrings_QtWidgets[14533]
#define sipNameNr_ItemTransformHasChanged 14557
#define sipName_ItemTransformHasChanged &sipStrings_QtWidgets[14557]
#define sipNameNr_NoBackButtonOnStartPage 14581
#define sipName_NoBackButtonOnStartPage &sipStrings_QtWidgets[14581]
#define sipNameNr_OvershootWhenScrollable 14605
#define sipName_OvershootWhenScrollable &sipStrings_QtWidgets[14605]
#define sipNameNr_PE_IndicatorHeaderArrow 14629
#define sipName_PE_IndicatorHeaderArrow &sipStrings_QtWidgets[14629]
#define sipNameNr_PE_IndicatorRadioButton 14653
#define sipName_PE_IndicatorRadioButton &sipStrings_QtWidgets[14653]
#define sipNameNr_PE_IndicatorTabTearLeft 14677
#define sipName_PE_IndicatorTabTearLeft &sipStrings_QtWidgets[14677]
#define sipNameNr_PM_CheckBoxLabelSpacing 14701
#define sipName_PM_CheckBoxLabelSpacing &sipStrings_QtWidgets[14701]
#define sipNameNr_PM_DockWidgetFrameWidth 14725
#define sipName_PM_DockWidgetFrameWidth &sipStrings_QtWidgets[14725]
#define sipNameNr_PM_SliderSpaceAvailable 14749
#define sipName_PM_SliderSpaceAvailable &sipStrings_QtWidgets[14749]
#define sipNameNr_PM_SliderTickmarkOffset 14773
#define sipName_PM_SliderTickmarkOffset &sipStrings_QtWidgets[14773]
#define sipNameNr_PyQt6_sip_simplewrapper 14797
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtWidgets[14797]
#define sipNameNr_QComboBox__InsertPolicy 14821
#define sipName_QComboBox__InsertPolicy &sipStrings_QtWidgets[14821]
#define sipNameNr_QFileDialog__AcceptMode 14845
#define sipName_QFileDialog__AcceptMode &sipStrings_QtWidgets[14845]
#define sipNameNr_QGraphicsColorizeEffect 14869
#define sipName_QGraphicsColorizeEffect &sipStrings_QtWidgets[14869]
#define sipNameNr_QGraphicsSceneHelpEvent 14893
#define sipName_QGraphicsSceneHelpEvent &sipStrings_QtWidgets[14893]
#define sipNameNr_QGraphicsSceneMoveEvent 14917
#define sipName_QGraphicsSceneMoveEvent &sipStrings_QtWidgets[14917]
#define sipNameNr_QGraphicsSimpleTextItem 14941
#define sipName_QGraphicsSimpleTextItem &sipStrings_QtWidgets[14941]
#define sipNameNr_QGraphicsView__DragMode 14965
#define sipName_QGraphicsView__DragMode &sipStrings_QtWidgets[14965]
#define sipNameNr_QHeaderView__ResizeMode 14989
#define sipName_QHeaderView__ResizeMode &sipStrings_QtWidgets[14989]
#define sipNameNr_QInputDialog__InputMode 15013
#define sipName_QInputDialog__InputMode &sipStrings_QtWidgets[15013]
#define sipNameNr_QLayout__SizeConstraint 15037
#define sipName_QLayout__SizeConstraint &sipStrings_QtWidgets[15037]
#define sipNameNr_15061 15061
#define sipName_15061 &sipStrings_QtWidgets[15061]
#define sipNameNr_15085 15085
#define sipName_15085 &sipStrings_QtWidgets[15085]
#define sipNameNr_15109 15109
#define sipName_15109 &sipStrings_QtWidgets[15109]
#define sipNameNr_QMainWindow__DockOption 15133
#define sipName_QMainWindow__DockOption &sipStrings_QtWidgets[15133]
#define sipNameNr_QMessageBox__ButtonRole 15157
#define sipName_QMessageBox__ButtonRole &sipStrings_QtWidgets[15157]
#define sipNameNr_QProgressBar__Direction 15181
#define sipName_QProgressBar__Direction &sipStrings_QtWidgets[15181]
#define sipNameNr_QSizePolicy__PolicyFlag 15205
#define sipName_QSizePolicy__PolicyFlag &sipStrings_QtWidgets[15205]
#define sipNameNr_QStyleHintReturnVariant 15229
#define sipName_QStyleHintReturnVariant &sipStrings_QtWidgets[15229]
#define sipNameNr_QStyleOptionProgressBar 15253
#define sipName_QStyleOptionProgressBar &sipStrings_QtWidgets[15253]
#define sipNameNr_QTabBar__ButtonPosition 15277
#define sipName_QTabBar__ButtonPosition &sipStrings_QtWidgets[15277]
#define sipNameNr_QTabWidget__TabPosition 15301
#define sipName_QTabWidget__TabPosition &sipStrings_QtWidgets[15301]
#define sipNameNr_QTextEdit__LineWrapMode 15325
#define sipName_QTextEdit__LineWrapMode &sipStrings_QtWidgets[15325]
#define sipNameNr_QTreeWidgetItemIterator 15349
#define sipName_QTreeWidgetItemIterator &sipStrings_QtWidgets[15349]
#define sipNameNr_RightMouseButtonGesture 15373
#define sipName_RightMouseButtonGesture &sipStrings_QtWidgets[15373]
#define sipNameNr_SC_ComboBoxListBoxPopup 15397
#define sipName_SC_ComboBoxListBoxPopup &sipStrings_QtWidgets[15397]
#define sipNameNr_SC_TitleBarNormalButton 15421
#define sipName_SC_TitleBarNormalButton &sipStrings_QtWidgets[15421]
#define sipNameNr_SE_PushButtonLayoutItem 15445
#define sipName_SE_PushButtonLayoutItem &sipStrings_QtWidgets[15445]
#define sipNameNr_SE_RadioButtonClickRect 15469
#define sipName_SE_RadioButtonClickRect &sipStrings_QtWidgets[15469]
#define sipNameNr_SE_RadioButtonFocusRect 15493
#define sipName_SE_RadioButtonFocusRect &sipStrings_QtWidgets[15493]
#define sipNameNr_SE_RadioButtonIndicator 15517
#define sipName_SE_RadioButtonIndicator &sipStrings_QtWidgets[15517]
#define sipNameNr_SE_TabBarTabRightButton 15541
#define sipName_SE_TabBarTabRightButton &sipStrings_QtWidgets[15541]
#define sipNameNr_SE_TabWidgetRightCorner 15565
#define sipName_SE_TabWidgetRightCorner &sipStrings_QtWidgets[15565]
#define sipNameNr_SE_TabWidgetTabContents 15589
#define sipName_SE_TabWidgetTabContents &sipStrings_QtWidgets[15589]
#define sipNameNr_SE_ToolButtonLayoutItem 15613
#define sipName_SE_ToolButtonLayoutItem &sipStrings_QtWidgets[15613]
#define sipNameNr_SH_DrawMenuBarSeparator 15637
#define sipName_SH_DrawMenuBarSeparator &sipStrings_QtWidgets[15637]
#define sipNameNr_SH_FormLayoutWrapPolicy 15661
#define sipName_SH_FormLayoutWrapPolicy &sipStrings_QtWidgets[15661]
#define sipNameNr_SH_SpinBox_SelectOnStep 15685
#define sipName_SH_SpinBox_SelectOnStep &sipStrings_QtWidgets[15685]
#define sipNameNr_SH_SpinBox_StepModifier 15709
#define sipName_SH_SpinBox_StepModifier &sipStrings_QtWidgets[15709]
#define sipNameNr_SH_ToolTipLabel_Opacity 15733
#define sipName_SH_ToolTipLabel_Opacity &sipStrings_QtWidgets[15733]
#define sipNameNr_SP_DialogYesToAllButton 15757
#define sipName_SP_DialogYesToAllButton &sipStrings_QtWidgets[15757]
#define sipNameNr_SP_TitleBarNormalButton 15781
#define sipName_SP_TitleBarNormalButton &sipStrings_QtWidgets[15781]
#define sipNameNr_SliderOrientationChange 15805
#define sipName_SliderOrientationChange &sipStrings_QtWidgets[15805]
#define sipNameNr_VerticalOvershootPolicy 15829
#define sipName_VerticalOvershootPolicy &sipStrings_QtWidgets[15829]
#define sipNameNr_cascadingSectionResizes 15853
#define sipName_cascadingSectionResizes &sipStrings_QtWidgets[15853]
#define sipNameNr_getExistingDirectoryUrl 15877
#define sipName_getExistingDirectoryUrl &sipStrings_QtWidgets[15877]
#define sipNameNr_initStyleOptionForIndex 15901
#define sipName_initStyleOptionForIndex &sipStrings_QtWidgets[15901]
#define sipNameNr_installSceneEventFilter 15925
#define sipName_installSceneEventFilter &sipStrings_QtWidgets[15925]
#define sipNameNr_resetDefaultSectionSize 15949
#define sipName_resetDefaultSectionSize &sipStrings_QtWidgets[15949]
#define sipNameNr_resetVerticalScrollMode 15973
#define sipName_resetVerticalScrollMode &sipStrings_QtWidgets[15973]
#define sipNameNr_resizeColumnsToContents 15997
#define sipName_resizeColumnsToContents &sipStrings_QtWidgets[15997]
#define sipNameNr_resizeContentsPrecision 16021
#define sipName_resizeContentsPrecision &sipStrings_QtWidgets[16021]
#define sipNameNr_rubberBandSelectionMode 16045
#define sipName_rubberBandSelectionMode &sipStrings_QtWidgets[16045]
#define sipNameNr_sectionSizeFromContents 16069
#define sipName_sectionSizeFromContents &sipStrings_QtWidgets[16069]
#define sipNameNr_sectionViewportPosition 16093
#define sipName_sectionViewportPosition &sipStrings_QtWidgets[16093]
#define sipNameNr_setAcceptedMouseButtons 16117
#define sipName_setAcceptedMouseButtons &sipStrings_QtWidgets[16117]
#define sipNameNr_setAccessibleIdentifier 16141
#define sipName_setAccessibleIdentifier &sipStrings_QtWidgets[16141]
#define sipNameNr_setAlternatingRowColors 16165
#define sipName_setAlternatingRowColors &sipStrings_QtWidgets[16165]
#define sipNameNr_setChildIndicatorPolicy 16189
#define sipName_setChildIndicatorPolicy &sipStrings_QtWidgets[16189]
#define sipNameNr_setColumnPreferredWidth 16213
#define sipName_setColumnPreferredWidth &sipStrings_QtWidgets[16213]
#define sipNameNr_setExpandsOnDoubleClick 16237
#define sipName_setExpandsOnDoubleClick &sipStrings_QtWidgets[16237]
#define sipNameNr_setHorizontalHeaderItem 16261
#define sipName_setHorizontalHeaderItem &sipStrings_QtWidgets[16261]
#define sipNameNr_setHorizontalScrollMode 12804
#define sipName_setHorizontalScrollMode &sipStrings_QtWidgets[12804]
#define sipNameNr_setNavigationBarVisible 16285
#define sipName_setNavigationBarVisible &sipStrings_QtWidgets[16285]
#define sipNameNr_setPreviewColumnVisible 16309
#define sipName_setPreviewColumnVisible &sipStrings_QtWidgets[16309]
#define sipNameNr_setRetainSizeWhenHidden 16333
#define sipName_setRetainSizeWhenHidden &sipStrings_QtWidgets[16333]
#define sipNameNr_setSelectionRectVisible 16357
#define sipName_setSelectionRectVisible &sipStrings_QtWidgets[16357]
#define sipNameNr_setSupportedDragActions 16381
#define sipName_setSupportedDragActions &sipStrings_QtWidgets[16381]
#define sipNameNr_setTextInteractionFlags 16405
#define sipName_setTextInteractionFlags &sipStrings_QtWidgets[16405]
#define sipNameNr_setTransformOriginPoint 16429
#define sipName_setTransformOriginPoint &sipStrings_QtWidgets[16429]
#define sipNameNr_setTransformationAnchor 16453
#define sipName_setTransformationAnchor &sipStrings_QtWidgets[16453]
#define sipNameNr_setVerticalHeaderFormat 16477
#define sipName_setVerticalHeaderFormat &sipStrings_QtWidgets[16477]
#define sipNameNr_setVerticalHeaderLabels 16501
#define sipName_setVerticalHeaderLabels &sipStrings_QtWidgets[16501]
#define sipNameNr_sliderPositionFromValue 16525
#define sipName_sliderPositionFromValue &sipStrings_QtWidgets[16525]
#define sipNameNr_sliderValueFromPosition 16549
#define sipName_sliderValueFromPosition &sipStrings_QtWidgets[16549]
#define sipNameNr_unsetWindowFrameMargins 16573
#define sipName_unsetWindowFrameMargins &sipStrings_QtWidgets[16573]
#define sipNameNr_verticalScrollBarPolicy 16597
#define sipName_verticalScrollBarPolicy &sipStrings_QtWidgets[16597]
#define sipNameNr_verticalScrollbarAction 16621
#define sipName_verticalScrollbarAction &sipStrings_QtWidgets[16621]
#define sipNameNr_ActivationHistoryOrder 16645
#define sipName_ActivationHistoryOrder &sipStrings_QtWidgets[16645]
#define sipNameNr_CE_ProgressBarContents 16668
#define sipName_CE_ProgressBarContents &sipStrings_QtWidgets[16668]
#define sipNameNr_CorrectToPreviousValue 16691
#define sipName_CorrectToPreviousValue &sipStrings_QtWidgets[16691]
#define sipNameNr_HorizontalHeaderFormat 1651
#define sipName_HorizontalHeaderFormat &sipStrings_QtWidgets[1651]
#define sipNameNr_ItemAcceptsInputMethod 16714
#define sipName_ItemAcceptsInputMethod &sipStrings_QtWidgets[16714]
#define sipNameNr_ItemChildRemovedChange 16737
#define sipName_ItemChildRemovedChange &sipStrings_QtWidgets[16737]
#define sipNameNr_ItemPositionHasChanged 16760
#define sipName_ItemPositionHasChanged &sipStrings_QtWidgets[16760]
#define sipNameNr_ItemRotationHasChanged 16783
#define sipName_ItemRotationHasChanged &sipStrings_QtWidgets[16783]
#define sipNameNr_ItemSelectedHasChanged 16806
#define sipName_ItemSelectedHasChanged &sipStrings_QtWidgets[16806]
#define sipNameNr_ItemStacksBehindParent 16829
#define sipName_ItemStacksBehindParent &sipStrings_QtWidgets[16829]
#define sipNameNr_LeftMouseButtonGesture 16852
#define sipName_LeftMouseButtonGesture &sipStrings_QtWidgets[16852]
#define sipNameNr_NoBackButtonOnLastPage 16875
#define sipName_NoBackButtonOnLastPage &sipStrings_QtWidgets[16875]
#define sipNameNr_PE_IndicatorArrowRight 16898
#define sipName_PE_IndicatorArrowRight &sipStrings_QtWidgets[16898]
#define sipNameNr_PM_ButtonShiftVertical 16921
#define sipName_PM_ButtonShiftVertical &sipStrings_QtWidgets[16921]
#define sipNameNr_PM_MaximumDragDistance 16944
#define sipName_PM_MaximumDragDistance &sipStrings_QtWidgets[16944]
#define sipNameNr_PM_MenuButtonIndicator 16967
#define sipName_PM_MenuButtonIndicator &sipStrings_QtWidgets[16967]
#define sipNameNr_PM_SpinBoxSliderHeight 16990
#define sipName_PM_SpinBoxSliderHeight &sipStrings_QtWidgets[16990]
#define sipNameNr_PM_ToolBarHandleExtent 17013
#define sipName_PM_ToolBarHandleExtent &sipStrings_QtWidgets[17013]
#define sipNameNr_PM_TreeViewIndentation 17036
#define sipName_PM_TreeViewIndentation &sipStrings_QtWidgets[17036]
#define sipNameNr_PadToTransparentBorder 17059
#define sipName_PadToTransparentBorder &sipStrings_QtWidgets[17059]
#define sipNameNr_QDateTimeEdit__Section 17082
#define sipName_QDateTimeEdit__Section &sipStrings_QtWidgets[17082]
#define sipNameNr_QGraphicsOpacityEffect 17105
#define sipName_QGraphicsOpacityEffect &sipStrings_QtWidgets[17105]
#define sipNameNr_QItemEditorCreatorBase 17128
#define sipName_QItemEditorCreatorBase &sipStrings_QtWidgets[17128]
#define sipNameNr_17151 17151
#define sipName_17151 &sipStrings_QtWidgets[17151]
#define sipNameNr_QStyle__ComplexControl 17174
#define sipName_QStyle__ComplexControl &sipStrings_QtWidgets[17174]
#define sipNameNr_QStyle__ControlElement 17197
#define sipName_QStyle__ControlElement &sipStrings_QtWidgets[17197]
#define sipNameNr_QStyle__StandardPixmap 17220
#define sipName_QStyle__StandardPixmap &sipStrings_QtWidgets[17220]
#define sipNameNr_QStyleOptionDockWidget 17243
#define sipName_QStyleOptionDockWidget &sipStrings_QtWidgets[17243]
#define sipNameNr_QStyleOptionMenuItemV2 17266
#define sipName_QStyleOptionMenuItemV2 &sipStrings_QtWidgets[17266]
#define sipNameNr_QStyleOptionRubberBand 17289
#define sipName_QStyleOptionRubberBand &sipStrings_QtWidgets[17289]
#define sipNameNr_QStyleOptionTabBarBase 17312
#define sipName_QStyleOptionTabBarBase &sipStrings_QtWidgets[17312]
#define sipNameNr_QStyleOptionToolButton 17335
#define sipName_QStyleOptionToolButton &sipStrings_QtWidgets[17335]
#define sipNameNr_SC_TitleBarCloseButton 17358
#define sipName_SC_TitleBarCloseButton &sipStrings_QtWidgets[17358]
#define sipNameNr_SC_TitleBarShadeButton 17381
#define sipName_SC_TitleBarShadeButton &sipStrings_QtWidgets[17381]
#define sipNameNr_SE_ProgressBarContents 17404
#define sipName_SE_ProgressBarContents &sipStrings_QtWidgets[17404]
#define sipNameNr_SE_PushButtonFocusRect 17427
#define sipName_SE_PushButtonFocusRect &sipStrings_QtWidgets[17427]
#define sipNameNr_SE_RadioButtonContents 17450
#define sipName_SE_RadioButtonContents &sipStrings_QtWidgets[17450]
#define sipNameNr_SE_ShapedFrameContents 17473
#define sipName_SE_ShapedFrameContents &sipStrings_QtWidgets[17473]
#define sipNameNr_SE_TabBarTabLeftButton 17496
#define sipName_SE_TabBarTabLeftButton &sipStrings_QtWidgets[17496]
#define sipNameNr_SE_TabBarTearIndicator 17519
#define sipName_SE_TabBarTearIndicator &sipStrings_QtWidgets[17519]
#define sipNameNr_SE_TabWidgetLayoutItem 17542
#define sipName_SE_TabWidgetLayoutItem &sipStrings_QtWidgets[17542]
#define sipNameNr_SE_TabWidgetLeftCorner 17565
#define sipName_SE_TabWidgetLeftCorner &sipStrings_QtWidgets[17565]
#define sipNameNr_SH_Dial_BackgroundRole 17588
#define sipName_SH_Dial_BackgroundRole &sipStrings_QtWidgets[17588]
#define sipNameNr_SH_ItemView_ScrollMode 17611
#define sipName_SH_ItemView_ScrollMode &sipStrings_QtWidgets[17611]
#define sipNameNr_SH_Menu_KeyboardSearch 17634
#define sipName_SH_Menu_KeyboardSearch &sipStrings_QtWidgets[17634]
#define sipNameNr_SH_Menu_SloppySubMenus 17657
#define sipName_SH_Menu_SloppySubMenus &sipStrings_QtWidgets[17657]
#define sipNameNr_SH_ScrollBar_Transient 17680
#define sipName_SH_ScrollBar_Transient &sipStrings_QtWidgets[17680]
#define sipNameNr_SH_Table_GridLineColor 17703
#define sipName_SH_Table_GridLineColor &sipStrings_QtWidgets[17703]
#define sipNameNr_SH_ToolTip_WakeUpDelay 17726
#define sipName_SH_ToolTip_WakeUpDelay &sipStrings_QtWidgets[17726]
#define sipNameNr_SP_DialogDiscardButton 17749
#define sipName_SP_DialogDiscardButton &sipStrings_QtWidgets[17749]
#define sipNameNr_SP_DialogNoToAllButton 17772
#define sipName_SP_DialogNoToAllButton &sipStrings_QtWidgets[17772]
#define sipNameNr_SP_DialogSaveAllButton 17795
#define sipName_SP_DialogSaveAllButton &sipStrings_QtWidgets[17795]
#define sipNameNr_SP_FileDialogNewFolder 17818
#define sipName_SP_FileDialogNewFolder &sipStrings_QtWidgets[17818]
#define sipNameNr_SP_LineEditClearButton 17841
#define sipName_SP_LineEditClearButton &sipStrings_QtWidgets[17841]
#define sipNameNr_SP_TitleBarCloseButton 17864
#define sipName_SP_TitleBarCloseButton &sipStrings_QtWidgets[17864]
#define sipNameNr_SP_TitleBarShadeButton 17887
#define sipName_SP_TitleBarShadeButton &sipStrings_QtWidgets[17887]
#define sipNameNr_columnViewportPosition 17910
#define sipName_columnViewportPosition &sipStrings_QtWidgets[17910]
#define sipNameNr_horizontalHeaderFormat 17933
#define sipName_horizontalHeaderFormat &sipStrings_QtWidgets[17933]
#define sipNameNr_isNavigationBarVisible 17956
#define sipName_isNavigationBarVisible &sipStrings_QtWidgets[17956]
#define sipNameNr_isPersistentEditorOpen 17979
#define sipName_isPersistentEditorOpen &sipStrings_QtWidgets[17979]
#define sipNameNr_isPreviewColumnVisible 18002
#define sipName_isPreviewColumnVisible &sipStrings_QtWidgets[18002]
#define sipNameNr_isSelectionRectVisible 18025
#define sipName_isSelectionRectVisible &sipStrings_QtWidgets[18025]
#define sipNameNr_mergeCurrentCharFormat 18048
#define sipName_mergeCurrentCharFormat &sipStrings_QtWidgets[18048]
#define sipNameNr_removeSceneEventFilter 18071
#define sipName_removeSceneEventFilter &sipStrings_QtWidgets[18071]
#define sipNameNr_resizeColumnToContents 18094
#define sipName_resizeColumnToContents &sipStrings_QtWidgets[18094]
#define sipNameNr_selectedMimeTypeFilter 18117
#define sipName_selectedMimeTypeFilter &sipStrings_QtWidgets[18117]
#define sipNameNr_setAllColumnsShowFocus 18140
#define sipName_setAllColumnsShowFocus &sipStrings_QtWidgets[18140]
#define sipNameNr_setChangeCurrentOnDrag 18163
#define sipName_setChangeCurrentOnDrag &sipStrings_QtWidgets[18163]
#define sipNameNr_setChildrenCollapsible 18186
#define sipName_setChildrenCollapsible &sipStrings_QtWidgets[18186]
#define sipNameNr_setColumnStretchFactor 18209
#define sipName_setColumnStretchFactor &sipStrings_QtWidgets[18209]
#define sipNameNr_setCornerButtonEnabled 18232
#define sipName_setCornerButtonEnabled &sipStrings_QtWidgets[18232]
#define sipNameNr_setCurrentSectionIndex 18255
#define sipName_setCurrentSectionIndex &sipStrings_QtWidgets[18255]
#define sipNameNr_setDateEditAcceptDelay 18278
#define sipName_setDateEditAcceptDelay &sipStrings_QtWidgets[18278]
#define sipNameNr_setDoubleClickInterval 18301
#define sipName_setDoubleClickInterval &sipStrings_QtWidgets[18301]
#define sipNameNr_setFirstSectionMovable 18324
#define sipName_setFirstSectionMovable &sipStrings_QtWidgets[18324]
#define sipNameNr_setGestureCancelPolicy 18347
#define sipName_setGestureCancelPolicy &sipStrings_QtWidgets[18347]
#define sipNameNr_setGroupSeparatorShown 18370
#define sipName_setGroupSeparatorShown &sipStrings_QtWidgets[18370]
#define sipNameNr_setHorizontalScrollBar 18393
#define sipName_setHorizontalScrollBar &sipStrings_QtWidgets[18393]
#define sipNameNr_setKeyboardSearchFlags 18416
#define sipName_setKeyboardSearchFlags &sipStrings_QtWidgets[18416]
#define sipNameNr_setOffsetToLastSection 18439
#define sipName_setOffsetToLastSection &sipStrings_QtWidgets[18439]
#define sipNameNr_setSampleTextForSystem 18462
#define sipName_setSampleTextForSystem &sipStrings_QtWidgets[18462]
#define sipNameNr_setTextBackgroundColor 18485
#define sipName_setTextBackgroundColor &sipStrings_QtWidgets[18485]
#define sipNameNr_showDecorationSelected 18508
#define sipName_showDecorationSelected &sipStrings_QtWidgets[18508]
#define sipNameNr_takeVerticalHeaderItem 18531
#define sipName_takeVerticalHeaderItem &sipStrings_QtWidgets[18531]
#define sipNameNr_toolButtonStyleChanged 18554
#define sipName_toolButtonStyleChanged &sipStrings_QtWidgets[18554]
#define sipNameNr_updateEditorGeometries 18577
#define sipName_updateEditorGeometries &sipStrings_QtWidgets[18577]
#define sipNameNr_verticalSizeConstraint 18600
#define sipName_verticalSizeConstraint &sipStrings_QtWidgets[18600]
#define sipNameNr_AllNonFixedFieldsGrow 18623
#define sipName_AllNonFixedFieldsGrow &sipStrings_QtWidgets[18623]
#define sipNameNr_CorrectToNearestValue 18645
#define sipName_CorrectToNearestValue &sipStrings_QtWidgets[18645]
#define sipNameNr_DeviceCoordinateCache 18667
#define sipName_DeviceCoordinateCache &sipStrings_QtWidgets[18667]
#define sipNameNr_DropIndicatorPosition 1079
#define sipName_DropIndicatorPosition &sipStrings_QtWidgets[1079]
#define sipNameNr_HideNameFilterDetails 18689
#define sipName_HideNameFilterDetails &sipStrings_QtWidgets[18689]
#define sipNameNr_IsDecoratedRootColumn 18711
#define sipName_IsDecoratedRootColumn &sipStrings_QtWidgets[18711]
#define sipNameNr_ItemEnabledHasChanged 18733
#define sipName_ItemEnabledHasChanged &sipStrings_QtWidgets[18733]
#define sipNameNr_ItemOpacityHasChanged 18755
#define sipName_ItemOpacityHasChanged &sipStrings_QtWidgets[18755]
#define sipNameNr_ItemToolTipHasChanged 18777
#define sipName_ItemToolTipHasChanged &sipStrings_QtWidgets[18777]
#define sipNameNr_ItemVisibleHasChanged 18799
#define sipName_ItemVisibleHasChanged &sipStrings_QtWidgets[18799]
#define sipNameNr_MinimalViewportUpdate 18821
#define sipName_MinimalViewportUpdate &sipStrings_QtWidgets[18821]
#define sipNameNr_PE_FrameDefaultButton 18843
#define sipName_PE_FrameDefaultButton &sipStrings_QtWidgets[18843]
#define sipNameNr_PE_FrameStatusBarItem 18865
#define sipName_PE_FrameStatusBarItem &sipStrings_QtWidgets[18865]
#define sipNameNr_PE_IndicatorArrowDown 18887
#define sipName_PE_IndicatorArrowDown &sipStrings_QtWidgets[18887]
#define sipNameNr_PE_IndicatorArrowLeft 18909
#define sipName_PE_IndicatorArrowLeft &sipStrings_QtWidgets[18909]
#define sipNameNr_PE_IndicatorSpinMinus 18931
#define sipName_PE_IndicatorSpinMinus &sipStrings_QtWidgets[18931]
#define sipNameNr_PE_PanelButtonCommand 18953
#define sipName_PE_PanelButtonCommand &sipStrings_QtWidgets[18953]
#define sipNameNr_PM_ComboBoxFrameWidth 18975
#define sipName_PM_ComboBoxFrameWidth &sipStrings_QtWidgets[18975]
#define sipNameNr_PM_LayoutBottomMargin 18997
#define sipName_PM_LayoutBottomMargin &sipStrings_QtWidgets[18997]
#define sipNameNr_PM_LineEditIconMargin 19019
#define sipName_PM_LineEditIconMargin &sipStrings_QtWidgets[19019]
#define sipNameNr_PM_MenuBarItemSpacing 19041
#define sipName_PM_MenuBarItemSpacing &sipStrings_QtWidgets[19041]
#define sipNameNr_PM_MenuScrollerHeight 19063
#define sipName_PM_MenuScrollerHeight &sipStrings_QtWidgets[19063]
#define sipNameNr_PM_MessageBoxIconSize 19085
#define sipName_PM_MessageBoxIconSize &sipStrings_QtWidgets[19085]
#define sipNameNr_PM_ScrollBarSliderMin 19107
#define sipName_PM_ScrollBarSliderMin &sipStrings_QtWidgets[19107]
#define sipNameNr_PM_TitleBarButtonSize 19129
#define sipName_PM_TitleBarButtonSize &sipStrings_QtWidgets[19129]
#define sipNameNr_PM_ToolBarItemSpacing 19151
#define sipName_PM_ToolBarItemSpacing &sipStrings_QtWidgets[19151]
#define sipNameNr_QAbstractItemDelegate 19173
#define sipName_QAbstractItemDelegate &sipStrings_QtWidgets[19173]
#define sipNameNr_QBoxLayout__Direction 19195
#define sipName_QBoxLayout__Direction &sipStrings_QtWidgets[19195]
#define sipNameNr_QFileDialog__FileMode 19217
#define sipName_QFileDialog__FileMode &sipStrings_QtWidgets[19217]
#define sipNameNr_QFileDialog__ViewMode 19239
#define sipName_QFileDialog__ViewMode &sipStrings_QtWidgets[19239]
#define sipNameNr_QFormLayout__ItemRole 19261
#define sipName_QFormLayout__ItemRole &sipStrings_QtWidgets[19261]
#define sipNameNr_QGraphicsAnchorLayout 19283
#define sipName_QGraphicsAnchorLayout &sipStrings_QtWidgets[19283]
#define sipNameNr_QGraphicsLinearLayout 19305
#define sipName_QGraphicsLinearLayout &sipStrings_QtWidgets[19305]
#define sipNameNr_19327 19327
#define sipName_19327 &sipStrings_QtWidgets[19327]
#define sipNameNr_19349 19349
#define sipName_19349 &sipStrings_QtWidgets[19349]
#define sipNameNr_19371 19371
#define sipName_19371 &sipStrings_QtWidgets[19371]
#define sipNameNr_QListView__LayoutMode 19393
#define sipName_QListView__LayoutMode &sipStrings_QtWidgets[19393]
#define sipNameNr_QListView__ResizeMode 19415
#define sipName_QListView__ResizeMode &sipStrings_QtWidgets[19415]
#define sipNameNr_QMdiArea__WindowOrder 19437
#define sipName_QMdiArea__WindowOrder &sipStrings_QtWidgets[19437]
#define sipNameNr_QSlider__TickPosition 19459
#define sipName_QSlider__TickPosition &sipStrings_QtWidgets[19459]
#define sipNameNr_QStyleOptionFocusRect 19481
#define sipName_QStyleOptionFocusRect &sipStrings_QtWidgets[19481]
#define sipNameNr_QWizard__WizardButton 19503
#define sipName_QWizard__WizardButton &sipStrings_QtWidgets[19503]
#define sipNameNr_QWizard__WizardOption 19525
#define sipName_QWizard__WizardOption &sipStrings_QtWidgets[19525]
#define sipNameNr_QWizard__WizardPixmap 19547
#define sipName_QWizard__WizardPixmap &sipStrings_QtWidgets[19547]
#define sipNameNr_SE_CheckBoxLayoutItem 19569
#define sipName_SE_CheckBoxLayoutItem &sipStrings_QtWidgets[19569]
#define sipNameNr_SE_ComboBoxLayoutItem 19591
#define sipName_SE_ComboBoxLayoutItem &sipStrings_QtWidgets[19591]
#define sipNameNr_SE_GroupBoxLayoutItem 19613
#define sipName_SE_GroupBoxLayoutItem &sipStrings_QtWidgets[19613]
#define sipNameNr_SE_PushButtonContents 19635
#define sipName_SE_PushButtonContents &sipStrings_QtWidgets[19635]
#define sipNameNr_SE_ToolBoxTabContents 19657
#define sipName_SE_ToolBoxTabContents &sipStrings_QtWidgets[19657]
#define sipNameNr_SH_Button_FocusPolicy 19679
#define sipName_SH_Button_FocusPolicy &sipStrings_QtWidgets[19679]
#define sipNameNr_SH_DialogButtonLayout 19701
#define sipName_SH_DialogButtonLayout &sipStrings_QtWidgets[19701]
#define sipNameNr_SH_DitherDisabledText 19723
#define sipName_SH_DitherDisabledText &sipStrings_QtWidgets[19723]
#define sipNameNr_SH_Menu_FadeOutOnHide 19745
#define sipName_SH_Menu_FadeOutOnHide &sipStrings_QtWidgets[19745]
#define sipNameNr_SH_Menu_MouseTracking 19767
#define sipName_SH_Menu_MouseTracking &sipStrings_QtWidgets[19767]
#define sipNameNr_SH_Menu_SelectionWrap 19789
#define sipName_SH_Menu_SelectionWrap &sipStrings_QtWidgets[19789]
#define sipNameNr_SH_Slider_SnapToValue 19811
#define sipName_SH_Slider_SnapToValue &sipStrings_QtWidgets[19811]
#define sipNameNr_SH_TitleBar_AutoRaise 19833
#define sipName_SH_TitleBar_AutoRaise &sipStrings_QtWidgets[19833]
#define sipNameNr_SP_DialogCancelButton 19855
#define sipName_SP_DialogCancelButton &sipStrings_QtWidgets[19855]
#define sipNameNr_SP_DialogIgnoreButton 19877
#define sipName_SP_DialogIgnoreButton &sipStrings_QtWidgets[19877]
#define sipNameNr_SP_FileDialogInfoView 19899
#define sipName_SP_FileDialogInfoView &sipStrings_QtWidgets[19899]
#define sipNameNr_SP_FileDialogListView 19921
#define sipName_SP_FileDialogListView &sipStrings_QtWidgets[19921]
#define sipNameNr_SP_FileDialogToParent 19943
#define sipName_SP_FileDialogToParent &sipStrings_QtWidgets[19943]
#define sipNameNr_SP_MessageBoxCritical 19965
#define sipName_SP_MessageBoxCritical &sipStrings_QtWidgets[19965]
#define sipNameNr_SP_MessageBoxQuestion 19987
#define sipName_SP_MessageBoxQuestion &sipStrings_QtWidgets[19987]
#define sipNameNr_SP_TitleBarMenuButton 20009
#define sipName_SP_TitleBarMenuButton &sipStrings_QtWidgets[20009]
#define sipNameNr_accessibleDescription 20031
#define sipName_accessibleDescription &sipStrings_QtWidgets[20031]
#define sipNameNr_activateNextSubWindow 20053
#define sipName_activateNextSubWindow &sipStrings_QtWidgets[20053]
#define sipNameNr_blockBoundingGeometry 20075
#define sipName_blockBoundingGeometry &sipStrings_QtWidgets[20075]
#define sipNameNr_canInsertFromMimeData 20097
#define sipName_canInsertFromMimeData &sipStrings_QtWidgets[20097]
#define sipNameNr_closePersistentEditor 20119
#define sipName_closePersistentEditor &sipStrings_QtWidgets[20119]
#define sipNameNr_closestAcceptableSize 20141
#define sipName_closestAcceptableSize &sipStrings_QtWidgets[20141]
#define sipNameNr_combinedLayoutSpacing 20163
#define sipName_combinedLayoutSpacing &sipStrings_QtWidgets[20163]
#define sipNameNr_createWindowContainer 20185
#define sipName_createWindowContainer &sipStrings_QtWidgets[20185]
#define sipNameNr_cursorPositionChanged 20207
#define sipName_cursorPositionChanged &sipStrings_QtWidgets[20207]
#define sipNameNr_dragDropOverwriteMode 20229
#define sipName_dragDropOverwriteMode &sipStrings_QtWidgets[20229]
#define sipNameNr_dropIndicatorPosition 20251
#define sipName_dropIndicatorPosition &sipStrings_QtWidgets[20251]
#define sipNameNr_getWindowFrameMargins 20273
#define sipName_getWindowFrameMargins &sipStrings_QtWidgets[20273]
#define sipNameNr_hitTestComplexControl 20295
#define sipName_hitTestComplexControl &sipStrings_QtWidgets[20295]
#define sipNameNr_insertPermanentWidget 20317
#define sipName_insertPermanentWidget &sipStrings_QtWidgets[20317]
#define sipNameNr_isBlockedByModalPanel 20339
#define sipName_isBlockedByModalPanel &sipStrings_QtWidgets[20339]
#define sipNameNr_isCornerButtonEnabled 20361
#define sipName_isCornerButtonEnabled &sipStrings_QtWidgets[20361]
#define sipNameNr_isFirstSectionMovable 20383
#define sipName_isFirstSectionMovable &sipStrings_QtWidgets[20383]
#define sipNameNr_isGroupSeparatorShown 20405
#define sipName_isGroupSeparatorShown &sipStrings_QtWidgets[20405]
#define sipNameNr_isSystemTrayAvailable 20427
#define sipName_isSystemTrayAvailable &sipStrings_QtWidgets[20427]
#define sipNameNr_itemDelegateForColumn 20449
#define sipName_itemDelegateForColumn &sipStrings_QtWidgets[20449]
#define sipNameNr_keyboardInputInterval 20471
#define sipName_keyboardInputInterval &sipStrings_QtWidgets[20471]
#define sipNameNr_lineWrapColumnOrWidth 20493
#define sipName_lineWrapColumnOrWidth &sipStrings_QtWidgets[20493]
#define sipNameNr_maximumSequenceLength 20515
#define sipName_maximumSequenceLength &sipStrings_QtWidgets[20515]
#define sipNameNr_menuHasCheckableItems 20537
#define sipName_menuHasCheckableItems &sipStrings_QtWidgets[20537]
#define sipNameNr_minimumContentsLength 20559
#define sipName_minimumContentsLength &sipStrings_QtWidgets[20559]
#define sipNameNr_minimumHeightForWidth 20581
#define sipName_minimumHeightForWidth &sipStrings_QtWidgets[20581]
#define sipNameNr_mouseDoubleClickEvent 20603
#define sipName_mouseDoubleClickEvent &sipStrings_QtWidgets[20603]
#define sipNameNr_prepareGeometryChange 20625
#define sipName_prepareGeometryChange &sipStrings_QtWidgets[20625]
#define sipNameNr_qDrawPlainRoundedRect 20647
#define sipName_qDrawPlainRoundedRect &sipStrings_QtWidgets[20647]
#define sipNameNr_reservedShortcutWidth 20669
#define sipName_reservedShortcutWidth &sipStrings_QtWidgets[20669]
#define sipNameNr_rightCornerWidgetSize 20691
#define sipName_rightCornerWidgetSize &sipStrings_QtWidgets[20691]
#define sipNameNr_separatorsCollapsible 20713
#define sipName_separatorsCollapsible &sipStrings_QtWidgets[20713]
#define sipNameNr_setAutoFillBackground 20735
#define sipName_setAutoFillBackground &sipStrings_QtWidgets[20735]
#define sipNameNr_setAutoRepeatInterval 20757
#define sipName_setAutoRepeatInterval &sipStrings_QtWidgets[20757]
#define sipNameNr_setClearButtonEnabled 20779
#define sipName_setClearButtonEnabled &sipStrings_QtWidgets[20779]
#define sipNameNr_setColumnMaximumWidth 20801
#define sipName_setColumnMaximumWidth &sipStrings_QtWidgets[20801]
#define sipNameNr_setColumnMinimumWidth 20823
#define sipName_setColumnMinimumWidth &sipStrings_QtWidgets[20823]
#define sipNameNr_setDefaultPositioning 20845
#define sipName_setDefaultPositioning &sipStrings_QtWidgets[20845]
#define sipNameNr_setDefaultSectionSize 15951
#define sipName_setDefaultSectionSize &sipStrings_QtWidgets[15951]
#define sipNameNr_setDisplayIntegerBase 20867
#define sipName_setDisplayIntegerBase &sipStrings_QtWidgets[20867]
#define sipNameNr_setDockNestingEnabled 20889
#define sipName_setDockNestingEnabled &sipStrings_QtWidgets[20889]
#define sipNameNr_setDropIndicatorShown 20911
#define sipName_setDropIndicatorShown &sipStrings_QtWidgets[20911]
#define sipNameNr_setFiltersChildEvents 20933
#define sipName_setFiltersChildEvents &sipStrings_QtWidgets[20933]
#define sipNameNr_setFirstColumnSpanned 20955
#define sipName_setFirstColumnSpanned &sipStrings_QtWidgets[20955]
#define sipNameNr_setInvertedAppearance 20977
#define sipName_setInvertedAppearance &sipStrings_QtWidgets[20977]
#define sipNameNr_setItemDelegateForRow 20999
#define sipName_setItemDelegateForRow &sipStrings_QtWidgets[20999]
#define sipNameNr_setKeyboardSingleStep 21021
#define sipName_setKeyboardSingleStep &sipStrings_QtWidgets[21021]
#define sipNameNr_setMaximumSectionSize 21043
#define sipName_setMaximumSectionSize &sipStrings_QtWidgets[21043]
#define sipNameNr_setMinimumSectionSize 21065
#define sipName_setMinimumSectionSize &sipStrings_QtWidgets[21065]
#define sipNameNr_setResizeGripsVisible 21087
#define sipName_setResizeGripsVisible &sipStrings_QtWidgets[21087]
#define sipNameNr_setRowPreferredHeight 21109
#define sipName_setRowPreferredHeight &sipStrings_QtWidgets[21109]
#define sipNameNr_setScrollerProperties 21131
#define sipName_setScrollerProperties &sipStrings_QtWidgets[21131]
#define sipNameNr_setShortcutAutoRepeat 21153
#define sipName_setShortcutAutoRepeat &sipStrings_QtWidgets[21153]
#define sipNameNr_setSortIndicatorShown 21175
#define sipName_setSortIndicatorShown &sipStrings_QtWidgets[21175]
#define sipNameNr_setStretchLastSection 21197
#define sipName_setStretchLastSection &sipStrings_QtWidgets[21197]
#define sipNameNr_setTotalRotationAngle 21219
#define sipName_setTotalRotationAngle &sipStrings_QtWidgets[21219]
#define sipNameNr_setTransformationMode 21241
#define sipName_setTransformationMode &sipStrings_QtWidgets[21241]
#define sipNameNr_setVerticalHeaderItem 21263
#define sipName_setVerticalHeaderItem &sipStrings_QtWidgets[21263]
#define sipNameNr_setVerticalScrollMode 15975
#define sipName_setVerticalScrollMode &sipStrings_QtWidgets[15975]
#define sipNameNr_setViewportUpdateMode 21285
#define sipName_setViewportUpdateMode &sipStrings_QtWidgets[21285]
#define sipNameNr_setWindowFrameMargins 16575
#define sipName_setWindowFrameMargins &sipStrings_QtWidgets[16575]
#define sipNameNr_windowIconTextChanged 21307
#define sipName_windowIconTextChanged &sipStrings_QtWidgets[21307]
#define sipNameNr_CE_ProgressBarGroove 21329
#define sipName_CE_ProgressBarGroove &sipStrings_QtWidgets[21329]
#define sipNameNr_ChildIndicatorPolicy 3481
#define sipName_ChildIndicatorPolicy &sipStrings_QtWidgets[3481]
#define sipNameNr_DontConfirmOverwrite 21350
#define sipName_DontConfirmOverwrite &sipStrings_QtWidgets[21350]
#define sipNameNr_DontSavePainterState 21371
#define sipName_DontSavePainterState &sipStrings_QtWidgets[21371]
#define sipNameNr_DrawWindowBackground 21392
#define sipName_DrawWindowBackground &sipStrings_QtWidgets[21392]
#define sipNameNr_FieldsStayAtSizeHint 21413
#define sipName_FieldsStayAtSizeHint &sipStrings_QtWidgets[21413]
#define sipNameNr_InsertAlphabetically 21434
#define sipName_InsertAlphabetically &sipStrings_QtWidgets[21434]
#define sipNameNr_ItemChildAddedChange 21455
#define sipName_ItemChildAddedChange &sipStrings_QtWidgets[21455]
#define sipNameNr_ItemCursorHasChanged 21476
#define sipName_ItemCursorHasChanged &sipStrings_QtWidgets[21476]
#define sipNameNr_ItemFlagsHaveChanged 21497
#define sipName_ItemFlagsHaveChanged &sipStrings_QtWidgets[21497]
#define sipNameNr_ItemParentHasChanged 21518
#define sipName_ItemParentHasChanged &sipStrings_QtWidgets[21518]
#define sipNameNr_ItemZValueHasChanged 21539
#define sipName_ItemZValueHasChanged &sipStrings_QtWidgets[21539]
#define sipNameNr_MousePressEventDelay 21560
#define sipName_MousePressEventDelay &sipStrings_QtWidgets[21560]
#define sipNameNr_NoDockWidgetFeatures 21581
#define sipName_NoDockWidgetFeatures &sipStrings_QtWidgets[21581]
#define sipNameNr_PE_IndicatorCheckBox 21602
#define sipName_PE_IndicatorCheckBox &sipStrings_QtWidgets[21602]
#define sipNameNr_PE_IndicatorSpinDown 21623
#define sipName_PE_IndicatorSpinDown &sipStrings_QtWidgets[21623]
#define sipNameNr_PE_IndicatorSpinPlus 21644
#define sipName_PE_IndicatorSpinPlus &sipStrings_QtWidgets[21644]
#define sipNameNr_PE_IndicatorTabClose 21665
#define sipName_PE_IndicatorTabClose &sipStrings_QtWidgets[21665]
#define sipNameNr_PE_PanelItemViewItem 21686
#define sipName_PE_PanelItemViewItem &sipStrings_QtWidgets[21686]
#define sipNameNr_PM_DefaultFrameWidth 21707
#define sipName_PM_DefaultFrameWidth &sipStrings_QtWidgets[21707]
#define sipNameNr_PM_FocusFrameHMargin 21728
#define sipName_PM_FocusFrameHMargin &sipStrings_QtWidgets[21728]
#define sipNameNr_PM_FocusFrameVMargin 21749
#define sipName_PM_FocusFrameVMargin &sipStrings_QtWidgets[21749]
#define sipNameNr_PM_LayoutRightMargin 21770
#define sipName_PM_LayoutRightMargin &sipStrings_QtWidgets[21770]
#define sipNameNr_PM_MenuBarPanelWidth 21791
#define sipName_PM_MenuBarPanelWidth &sipStrings_QtWidgets[21791]
#define sipNameNr_PM_MenuTearoffHeight 21812
#define sipName_PM_MenuTearoffHeight &sipStrings_QtWidgets[21812]
#define sipNameNr_PM_SpinBoxFrameWidth 21833
#define sipName_PM_SpinBoxFrameWidth &sipStrings_QtWidgets[21833]
#define sipNameNr_PM_TabBarBaseOverlap 21854
#define sipName_PM_TabBarBaseOverlap &sipStrings_QtWidgets[21854]
#define sipNameNr_PM_ToolBarFrameWidth 21875
#define sipName_PM_ToolBarFrameWidth &sipStrings_QtWidgets[21875]
#define sipNameNr_PM_ToolBarItemMargin 21896
#define sipName_PM_ToolBarItemMargin &sipStrings_QtWidgets[21896]
#define sipNameNr_QGraphicsEllipseItem 21917
#define sipName_QGraphicsEllipseItem &sipStrings_QtWidgets[21917]
#define sipNameNr_QGraphicsPolygonItem 21938
#define sipName_QGraphicsPolygonItem &sipStrings_QtWidgets[21938]
#define sipNameNr_QGraphicsProxyWidget 21959
#define sipName_QGraphicsProxyWidget &sipStrings_QtWidgets[21959]
#define sipNameNr_QMdiArea__AreaOption 21980
#define sipName_QMdiArea__AreaOption &sipStrings_QtWidgets[21980]
#define sipNameNr_QStyle__ContentsType 22001
#define sipName_QStyle__ContentsType &sipStrings_QtWidgets[22001]
#define sipNameNr_QStyleHintReturnMask 22022
#define sipName_QStyleHintReturnMask &sipStrings_QtWidgets[22022]
#define sipNameNr_QStyleOptionComboBox 22043
#define sipName_QStyleOptionComboBox &sipStrings_QtWidgets[22043]
#define sipNameNr_QStyleOptionGroupBox 22064
#define sipName_QStyleOptionGroupBox &sipStrings_QtWidgets[22064]
#define sipNameNr_QStyleOptionHeaderV2 22085
#define sipName_QStyleOptionHeaderV2 &sipStrings_QtWidgets[22085]
#define sipNameNr_QStyleOptionMenuItem 22106
#define sipName_QStyleOptionMenuItem &sipStrings_QtWidgets[22106]
#define sipNameNr_QStyleOptionSizeGrip 22127
#define sipName_QStyleOptionSizeGrip &sipStrings_QtWidgets[22127]
#define sipNameNr_QStyleOptionTitleBar 22148
#define sipName_QStyleOptionTitleBar &sipStrings_QtWidgets[22148]
#define sipNameNr_QStyleOptionViewItem 22169
#define sipName_QStyleOptionViewItem &sipStrings_QtWidgets[22169]
#define sipNameNr_QTabWidget__TabShape 22190
#define sipName_QTabWidget__TabShape &sipStrings_QtWidgets[22190]
#define sipNameNr_QWizard__WizardStyle 22211
#define sipName_QWizard__WizardStyle &sipStrings_QtWidgets[22211]
#define sipNameNr_RotationAngleChanged 22232
#define sipName_RotationAngleChanged &sipStrings_QtWidgets[22232]
#define sipNameNr_SC_ComboBoxEditField 22253
#define sipName_SC_ComboBoxEditField &sipStrings_QtWidgets[22253]
#define sipNameNr_SC_TitleBarMaxButton 22274
#define sipName_SC_TitleBarMaxButton &sipStrings_QtWidgets[22274]
#define sipNameNr_SC_TitleBarMinButton 22295
#define sipName_SC_TitleBarMinButton &sipStrings_QtWidgets[22295]
#define sipNameNr_SE_CheckBoxClickRect 22316
#define sipName_SE_CheckBoxClickRect &sipStrings_QtWidgets[22316]
#define sipNameNr_SE_CheckBoxFocusRect 22337
#define sipName_SE_CheckBoxFocusRect &sipStrings_QtWidgets[22337]
#define sipNameNr_SE_CheckBoxIndicator 22358
#define sipName_SE_CheckBoxIndicator &sipStrings_QtWidgets[22358]
#define sipNameNr_SE_ComboBoxFocusRect 22379
#define sipName_SE_ComboBoxFocusRect &sipStrings_QtWidgets[22379]
#define sipNameNr_SE_ProgressBarGroove 22400
#define sipName_SE_ProgressBarGroove &sipStrings_QtWidgets[22400]
#define sipNameNr_SE_SpinBoxLayoutItem 22421
#define sipName_SE_SpinBoxLayoutItem &sipStrings_QtWidgets[22421]
#define sipNameNr_SH_TitleBar_NoBorder 22442
#define sipName_SH_TitleBar_NoBorder &sipStrings_QtWidgets[22442]
#define sipNameNr_SH_UnderlineShortcut 22463
#define sipName_SH_UnderlineShortcut &sipStrings_QtWidgets[22463]
#define sipNameNr_SO_ComplexCustomBase 22484
#define sipName_SO_ComplexCustomBase &sipStrings_QtWidgets[22484]
#define sipNameNr_SP_DialogAbortButton 22505
#define sipName_SP_DialogAbortButton &sipStrings_QtWidgets[22505]
#define sipNameNr_SP_DialogApplyButton 22526
#define sipName_SP_DialogApplyButton &sipStrings_QtWidgets[22526]
#define sipNameNr_SP_DialogCloseButton 22547
#define sipName_SP_DialogCloseButton &sipStrings_QtWidgets[22547]
#define sipNameNr_SP_DialogResetButton 22568
#define sipName_SP_DialogResetButton &sipStrings_QtWidgets[22568]
#define sipNameNr_SP_DialogRetryButton 22589
#define sipName_SP_DialogRetryButton &sipStrings_QtWidgets[22589]
#define sipNameNr_SP_MediaSeekBackward 22610
#define sipName_SP_MediaSeekBackward &sipStrings_QtWidgets[22610]
#define sipNameNr_SP_MediaSkipBackward 22631
#define sipName_SP_MediaSkipBackward &sipStrings_QtWidgets[22631]
#define sipNameNr_SP_MessageBoxWarning 22652
#define sipName_SP_MessageBoxWarning &sipStrings_QtWidgets[22652]
#define sipNameNr_SP_TitleBarMaxButton 22673
#define sipName_SP_TitleBarMaxButton &sipStrings_QtWidgets[22673]
#define sipNameNr_SP_TitleBarMinButton 22694
#define sipName_SP_TitleBarMinButton &sipStrings_QtWidgets[22694]
#define sipNameNr_SetDefaultConstraint 22715
#define sipName_SetDefaultConstraint &sipStrings_QtWidgets[22715]
#define sipNameNr_SingleLetterDayNames 22736
#define sipName_SingleLetterDayNames &sipStrings_QtWidgets[22736]
#define sipNameNr_VerticalHeaderFormat 2873
#define sipName_VerticalHeaderFormat &sipStrings_QtWidgets[2873]
#define sipNameNr_acceptProposedAction 22757
#define sipName_acceptProposedAction &sipStrings_QtWidgets[22757]
#define sipNameNr_acceptedMouseButtons 22778
#define sipName_acceptedMouseButtons &sipStrings_QtWidgets[22778]
#define sipNameNr_accessibleIdentifier 22799
#define sipName_accessibleIdentifier &sipStrings_QtWidgets[22799]
#define sipNameNr_alternatingRowColors 22820
#define sipName_alternatingRowColors &sipStrings_QtWidgets[22820]
#define sipNameNr_backwardHistoryCount 22841
#define sipName_backwardHistoryCount &sipStrings_QtWidgets[22841]
#define sipNameNr_childIndicatorPolicy 22862
#define sipName_childIndicatorPolicy &sipStrings_QtWidgets[22862]
#define sipNameNr_childrenBoundingRect 22883
#define sipName_childrenBoundingRect &sipStrings_QtWidgets[22883]
#define sipNameNr_clearMaximumDateTime 22904
#define sipName_clearMaximumDateTime &sipStrings_QtWidgets[22904]
#define sipNameNr_clearMinimumDateTime 22925
#define sipName_clearMinimumDateTime &sipStrings_QtWidgets[22925]
#define sipNameNr_closeActiveSubWindow 22946
#define sipName_closeActiveSubWindow &sipStrings_QtWidgets[22946]
#define sipNameNr_closestLegalPosition 22967
#define sipName_closestLegalPosition &sipStrings_QtWidgets[22967]
#define sipNameNr_columnPreferredWidth 22988
#define sipName_columnPreferredWidth &sipStrings_QtWidgets[22988]
#define sipNameNr_expandsOnDoubleClick 23009
#define sipName_expandsOnDoubleClick &sipStrings_QtWidgets[23009]
#define sipNameNr_getExistingDirectory 23030
#define sipName_getExistingDirectory &sipStrings_QtWidgets[23030]
#define sipNameNr_horizontalHeaderItem 23051
#define sipName_horizontalHeaderItem &sipStrings_QtWidgets[23051]
#define sipNameNr_horizontalScrollMode 23072
#define sipName_horizontalScrollMode &sipStrings_QtWidgets[23072]
#define sipNameNr_isClearButtonEnabled 23093
#define sipName_isClearButtonEnabled &sipStrings_QtWidgets[23093]
#define sipNameNr_isDockNestingEnabled 23114
#define sipName_isDockNestingEnabled &sipStrings_QtWidgets[23114]
#define sipNameNr_isFirstColumnSpanned 23135
#define sipName_isFirstColumnSpanned &sipStrings_QtWidgets[23135]
#define sipNameNr_isSortIndicatorShown 23156
#define sipName_isSortIndicatorShown &sipStrings_QtWidgets[23156]
#define sipNameNr_isTearOffMenuVisible 23177
#define sipName_isTearOffMenuVisible &sipStrings_QtWidgets[23177]
#define sipNameNr_itemDelegateForIndex 23198
#define sipName_itemDelegateForIndex &sipStrings_QtWidgets[23198]
#define sipNameNr_itemSelectionChanged 23219
#define sipName_itemSelectionChanged &sipStrings_QtWidgets[23219]
#define sipNameNr_leftCornerWidgetSize 23240
#define sipName_leftCornerWidgetSize &sipStrings_QtWidgets[23240]
#define sipNameNr_openPersistentEditor 23261
#define sipName_openPersistentEditor &sipStrings_QtWidgets[23261]
#define sipNameNr_positionInlineObject 23282
#define sipName_positionInlineObject &sipStrings_QtWidgets[23282]
#define sipNameNr_previousInFocusChain 23303
#define sipName_previousInFocusChain &sipStrings_QtWidgets[23303]
#define sipNameNr_resizeRowsToContents 23324
#define sipName_resizeRowsToContents &sipStrings_QtWidgets[23324]
#define sipNameNr_retainSizeWhenHidden 23345
#define sipName_retainSizeWhenHidden &sipStrings_QtWidgets[23345]
#define sipNameNr_rowsAboutToBeRemoved 23366
#define sipName_rowsAboutToBeRemoved &sipStrings_QtWidgets[23366]
#define sipNameNr_sectionDoubleClicked 23387
#define sipName_sectionDoubleClicked &sipStrings_QtWidgets[23387]
#define sipNameNr_selectMimeTypeFilter 23408
#define sipName_selectMimeTypeFilter &sipStrings_QtWidgets[23408]
#define sipNameNr_setAcceptHoverEvents 23429
#define sipName_setAcceptHoverEvents &sipStrings_QtWidgets[23429]
#define sipNameNr_setAcceptTouchEvents 23450
#define sipName_setAcceptTouchEvents &sipStrings_QtWidgets[23450]
#define sipNameNr_setAccessibleTabName 23471
#define sipName_setAccessibleTabName &sipStrings_QtWidgets[23471]
#define sipNameNr_setBackgroundVisible 23492
#define sipName_setBackgroundVisible &sipStrings_QtWidgets[23492]
#define sipNameNr_setContextMenuPolicy 23513
#define sipName_setContextMenuPolicy &sipStrings_QtWidgets[23513]
#define sipNameNr_setCurrentCharFormat 23534
#define sipName_setCurrentCharFormat &sipStrings_QtWidgets[23534]
#define sipNameNr_setCurrentModelIndex 23555
#define sipName_setCurrentModelIndex &sipStrings_QtWidgets[23555]
#define sipNameNr_setDefaultDropAction 23576
#define sipName_setDefaultDropAction &sipStrings_QtWidgets[23576]
#define sipNameNr_setDuplicatesEnabled 23597
#define sipName_setDuplicatesEnabled &sipStrings_QtWidgets[23597]
#define sipNameNr_setFieldGrowthPolicy 23618
#define sipName_setFieldGrowthPolicy &sipStrings_QtWidgets[23618]
#define sipNameNr_setHighlightSections 23639
#define sipName_setHighlightSections &sipStrings_QtWidgets[23639]
#define sipNameNr_setHorizontalSpacing 23660
#define sipName_setHorizontalSpacing &sipStrings_QtWidgets[23660]
#define sipNameNr_setHorizontalStretch 23681
#define sipName_setHorizontalStretch &sipStrings_QtWidgets[23681]
#define sipNameNr_setItemEditorFactory 23702
#define sipName_setItemEditorFactory &sipStrings_QtWidgets[23702]
#define sipNameNr_setLastRotationAngle 23723
#define sipName_setLastRotationAngle &sipStrings_QtWidgets[23723]
#define sipNameNr_setMaximumBlockCount 23744
#define sipName_setMaximumBlockCount &sipStrings_QtWidgets[23744]
#define sipNameNr_setMinimumRenderSize 23765
#define sipName_setMinimumRenderSize &sipStrings_QtWidgets[23765]
#define sipNameNr_setOpenExternalLinks 23786
#define sipName_setOpenExternalLinks &sipStrings_QtWidgets[23786]
#define sipNameNr_setOptimizationFlags 23807
#define sipName_setOptimizationFlags &sipStrings_QtWidgets[23807]
#define sipNameNr_setSampleTextForFont 23828
#define sipName_setSampleTextForFont &sipStrings_QtWidgets[23828]
#define sipNameNr_setSectionResizeMode 23849
#define sipName_setSectionResizeMode &sipStrings_QtWidgets[23849]
#define sipNameNr_setSectionsClickable 23870
#define sipName_setSectionsClickable &sipStrings_QtWidgets[23870]
#define sipNameNr_setSelectionBehavior 23891
#define sipName_setSelectionBehavior &sipStrings_QtWidgets[23891]
#define sipNameNr_setSmallDecimalPoint 23912
#define sipName_setSmallDecimalPoint &sipStrings_QtWidgets[23912]
#define sipNameNr_setStartDragDistance 23933
#define sipName_setStartDragDistance &sipStrings_QtWidgets[23933]
#define sipNameNr_setUniformRowHeights 23954
#define sipName_setUniformRowHeights &sipStrings_QtWidgets[23954]
#define sipNameNr_setUsesScrollButtons 23975
#define sipName_setUsesScrollButtons &sipStrings_QtWidgets[23975]
#define sipNameNr_setVerticalScrollBar 23996
#define sipName_setVerticalScrollBar &sipStrings_QtWidgets[23996]
#define sipNameNr_setWeekdayTextFormat 24017
#define sipName_setWeekdayTextFormat &sipStrings_QtWidgets[24017]
#define sipNameNr_sortIndicatorChanged 24038
#define sipName_sortIndicatorChanged &sipStrings_QtWidgets[24038]
#define sipNameNr_sortIndicatorSection 24059
#define sipName_sortIndicatorSection &sipStrings_QtWidgets[24059]
#define sipNameNr_supportedDragActions 24080
#define sipName_supportedDragActions &sipStrings_QtWidgets[24080]
#define sipNameNr_supportedDropActions 24101
#define sipName_supportedDropActions &sipStrings_QtWidgets[24101]
#define sipNameNr_textInteractionFlags 24122
#define sipName_textInteractionFlags &sipStrings_QtWidgets[24122]
#define sipNameNr_transformOriginPoint 24143
#define sipName_transformOriginPoint &sipStrings_QtWidgets[24143]
#define sipNameNr_transformationAnchor 24164
#define sipName_transformationAnchor &sipStrings_QtWidgets[24164]
#define sipNameNr_unregisterRecognizer 24185
#define sipName_unregisterRecognizer &sipStrings_QtWidgets[24185]
#define sipNameNr_unsetContentsMargins 24206
#define sipName_unsetContentsMargins &sipStrings_QtWidgets[24206]
#define sipNameNr_unsetLayoutDirection 24227
#define sipName_unsetLayoutDirection &sipStrings_QtWidgets[24227]
#define sipNameNr_updateEditorGeometry 24248
#define sipName_updateEditorGeometry &sipStrings_QtWidgets[24248]
#define sipNameNr_verticalHeaderFormat 24269
#define sipName_verticalHeaderFormat &sipStrings_QtWidgets[24269]
#define sipNameNr_windowFrameSectionAt 24290
#define sipName_windowFrameSectionAt &sipStrings_QtWidgets[24290]
#define sipNameNr_CE_MenuBarEmptyArea 24311
#define sipName_CE_MenuBarEmptyArea &sipStrings_QtWidgets[24311]
#define sipNameNr_CE_ProgressBarLabel 24331
#define sipName_CE_ProgressBarLabel &sipStrings_QtWidgets[24331]
#define sipNameNr_CE_RadioButtonLabel 24351
#define sipName_CE_RadioButtonLabel &sipStrings_QtWidgets[24351]
#define sipNameNr_CE_ScrollBarAddLine 24371
#define sipName_CE_ScrollBarAddLine &sipStrings_QtWidgets[24371]
#define sipNameNr_CE_ScrollBarAddPage 24391
#define sipName_CE_ScrollBarAddPage &sipStrings_QtWidgets[24391]
#define sipNameNr_CE_ScrollBarSubLine 24411
#define sipName_CE_ScrollBarSubLine &sipStrings_QtWidgets[24411]
#define sipNameNr_CE_ScrollBarSubPage 24431
#define sipName_CE_ScrollBarSubPage &sipStrings_QtWidgets[24431]
#define sipNameNr_ContiguousSelection 24451
#define sipName_ContiguousSelection &sipStrings_QtWidgets[24451]
#define sipNameNr_DockWidgetFloatable 24471
#define sipName_DockWidgetFloatable &sipStrings_QtWidgets[24471]
#define sipNameNr_DontResolveSymlinks 24491
#define sipName_DontResolveSymlinks &sipStrings_QtWidgets[24491]
#define sipNameNr_DontUseNativeDialog 24511
#define sipName_DontUseNativeDialog &sipStrings_QtWidgets[24511]
#define sipNameNr_ExpandingFieldsGrow 24531
#define sipName_ExpandingFieldsGrow &sipStrings_QtWidgets[24531]
#define sipNameNr_GestureCancelPolicy 8123
#define sipName_GestureCancelPolicy &sipStrings_QtWidgets[8123]
#define sipNameNr_InsertBeforeCurrent 24551
#define sipName_InsertBeforeCurrent &sipStrings_QtWidgets[24551]
#define sipNameNr_ItemCoordinateCache 24571
#define sipName_ItemCoordinateCache &sipStrings_QtWidgets[24571]
#define sipNameNr_ItemScaleHasChanged 24591
#define sipName_ItemScaleHasChanged &sipStrings_QtWidgets[24591]
#define sipNameNr_ItemSceneHasChanged 24611
#define sipName_ItemSceneHasChanged &sipStrings_QtWidgets[24611]
#define sipNameNr_ItemTransformChange 24631
#define sipName_ItemTransformChange &sipStrings_QtWidgets[24631]
#define sipNameNr_OvershootScrollTime 24651
#define sipName_OvershootScrollTime &sipStrings_QtWidgets[24651]
#define sipNameNr_PE_FrameButtonBevel 24671
#define sipName_PE_FrameButtonBevel &sipStrings_QtWidgets[24671]
#define sipNameNr_PE_IndicatorArrowUp 24691
#define sipName_PE_IndicatorArrowUp &sipStrings_QtWidgets[24691]
#define sipNameNr_PE_IndicatorTabTear 24711
#define sipName_PE_IndicatorTabTear &sipStrings_QtWidgets[24711]
#define sipNameNr_PE_PanelButtonBevel 24731
#define sipName_PE_PanelButtonBevel &sipStrings_QtWidgets[24731]
#define sipNameNr_PE_PanelItemViewRow 24751
#define sipName_PE_PanelItemViewRow &sipStrings_QtWidgets[24751]
#define sipNameNr_PM_HeaderGripMargin 24771
#define sipName_PM_HeaderGripMargin &sipStrings_QtWidgets[24771]
#define sipNameNr_PM_IconViewIconSize 24791
#define sipName_PM_IconViewIconSize &sipStrings_QtWidgets[24791]
#define sipNameNr_PM_LayoutLeftMargin 24811
#define sipName_PM_LayoutLeftMargin &sipStrings_QtWidgets[24811]
#define sipNameNr_PM_LineEditIconSize 24831
#define sipName_PM_LineEditIconSize &sipStrings_QtWidgets[24831]
#define sipNameNr_PM_ListViewIconSize 24851
#define sipName_PM_ListViewIconSize &sipStrings_QtWidgets[24851]
#define sipNameNr_PM_TabBarBaseHeight 24871
#define sipName_PM_TabBarBaseHeight &sipStrings_QtWidgets[24871]
#define sipNameNr_PM_TabBarTabOverlap 24891
#define sipName_PM_TabBarTabOverlap &sipStrings_QtWidgets[24891]
#define sipNameNr_QAbstractScrollArea 24911
#define sipName_QAbstractScrollArea &sipStrings_QtWidgets[24911]
#define sipNameNr_QDialog__DialogCode 24931
#define sipName_QDialog__DialogCode &sipStrings_QtWidgets[24931]
#define sipNameNr_QFileDialog__Option 24951
#define sipName_QFileDialog__Option &sipStrings_QtWidgets[24951]
#define sipNameNr_QGraphicsBlurEffect 24971
#define sipName_QGraphicsBlurEffect &sipStrings_QtWidgets[24971]
#define sipNameNr_QGraphicsGridLayout 24991
#define sipName_QGraphicsGridLayout &sipStrings_QtWidgets[24991]
#define sipNameNr_QGraphicsLayoutItem 25011
#define sipName_QGraphicsLayoutItem &sipStrings_QtWidgets[25011]
#define sipNameNr_QGraphicsPixmapItem 25031
#define sipName_QGraphicsPixmapItem &sipStrings_QtWidgets[25031]
#define sipNameNr_QGraphicsSceneEvent 25051
#define sipName_QGraphicsSceneEvent &sipStrings_QtWidgets[25051]
#define sipNameNr_QLineEdit__EchoMode 25071
#define sipName_QLineEdit__EchoMode &sipStrings_QtWidgets[25071]
#define sipNameNr_25091 25091
#define sipName_25091 &sipStrings_QtWidgets[25091]
#define sipNameNr_QListView__Movement 25111
#define sipName_QListView__Movement &sipStrings_QtWidgets[25111]
#define sipNameNr_QListView__ViewMode 25131
#define sipName_QListView__ViewMode &sipStrings_QtWidgets[25131]
#define sipNameNr_QMessageBox__Option 25151
#define sipName_QMessageBox__Option &sipStrings_QtWidgets[25151]
#define sipNameNr_QScrollerProperties 25171
#define sipName_QScrollerProperties &sipStrings_QtWidgets[25171]
#define sipNameNr_QSizePolicy__Policy 25191
#define sipName_QSizePolicy__Policy &sipStrings_QtWidgets[25191]
#define sipNameNr_QStyle__PixelMetric 25211
#define sipName_QStyle__PixelMetric &sipStrings_QtWidgets[25211]
#define sipNameNr_QStyleOptionComplex 25231
#define sipName_QStyleOptionComplex &sipStrings_QtWidgets[25231]
#define sipNameNr_QStyleOptionSpinBox 25251
#define sipName_QStyleOptionSpinBox &sipStrings_QtWidgets[25251]
#define sipNameNr_QStyleOptionToolBar 25271
#define sipName_QStyleOptionToolBar &sipStrings_QtWidgets[25271]
#define sipNameNr_QStyleOptionToolBox 25291
#define sipName_QStyleOptionToolBox &sipStrings_QtWidgets[25291]
#define sipNameNr_QStyledItemDelegate 25311
#define sipName_QStyledItemDelegate &sipStrings_QtWidgets[25311]
#define sipNameNr_QWidget__RenderFlag 25331
#define sipName_QWidget__RenderFlag &sipStrings_QtWidgets[25331]
#define sipNameNr_SC_GroupBoxCheckBox 25351
#define sipName_SC_GroupBoxCheckBox &sipStrings_QtWidgets[25351]
#define sipNameNr_SC_GroupBoxContents 25371
#define sipName_SC_GroupBoxContents &sipStrings_QtWidgets[25371]
#define sipNameNr_SC_ScrollBarAddLine 25391
#define sipName_SC_ScrollBarAddLine &sipStrings_QtWidgets[25391]
#define sipNameNr_SC_ScrollBarAddPage 25411
#define sipName_SC_ScrollBarAddPage &sipStrings_QtWidgets[25411]
#define sipNameNr_SC_ScrollBarSubLine 25431
#define sipName_SC_ScrollBarSubLine &sipStrings_QtWidgets[25431]
#define sipNameNr_SC_ScrollBarSubPage 25451
#define sipName_SC_ScrollBarSubPage &sipStrings_QtWidgets[25451]
#define sipNameNr_SC_SpinBoxEditField 25471
#define sipName_SC_SpinBoxEditField &sipStrings_QtWidgets[25471]
#define sipNameNr_SE_CheckBoxContents 25491
#define sipName_SE_CheckBoxContents &sipStrings_QtWidgets[25491]
#define sipNameNr_SE_ItemViewItemText 25511
#define sipName_SE_ItemViewItemText &sipStrings_QtWidgets[25511]
#define sipNameNr_SE_LineEditContents 25531
#define sipName_SE_LineEditContents &sipStrings_QtWidgets[25531]
#define sipNameNr_SE_ProgressBarLabel 25551
#define sipName_SE_ProgressBarLabel &sipStrings_QtWidgets[25551]
#define sipNameNr_SE_SliderLayoutItem 25571
#define sipName_SE_SliderLayoutItem &sipStrings_QtWidgets[25571]
#define sipNameNr_SE_TabWidgetTabPane 25591
#define sipName_SE_TabWidgetTabPane &sipStrings_QtWidgets[25591]
#define sipNameNr_SH_EtchDisabledText 25611
#define sipName_SH_EtchDisabledText &sipStrings_QtWidgets[25611]
#define sipNameNr_SH_TabBar_Alignment 25631
#define sipName_SH_TabBar_Alignment &sipStrings_QtWidgets[25631]
#define sipNameNr_SH_TabBar_ElideMode 25651
#define sipName_SH_TabBar_ElideMode &sipStrings_QtWidgets[25651]
#define sipNameNr_SH_WindowFrame_Mask 25671
#define sipName_SH_WindowFrame_Mask &sipStrings_QtWidgets[25671]
#define sipNameNr_SP_DialogHelpButton 25691
#define sipName_SP_DialogHelpButton &sipStrings_QtWidgets[25691]
#define sipNameNr_SP_DialogOpenButton 25711
#define sipName_SP_DialogOpenButton &sipStrings_QtWidgets[25711]
#define sipNameNr_SP_DialogSaveButton 25731
#define sipName_SP_DialogSaveButton &sipStrings_QtWidgets[25731]
#define sipNameNr_SP_MediaSeekForward 25751
#define sipName_SP_MediaSeekForward &sipStrings_QtWidgets[25751]
#define sipNameNr_SP_MediaSkipForward 25771
#define sipName_SP_MediaSkipForward &sipStrings_QtWidgets[25771]
#define sipNameNr_SP_MediaVolumeMuted 25791
#define sipName_SP_MediaVolumeMuted &sipStrings_QtWidgets[25791]
#define sipNameNr_ScrollerGestureType 7392
#define sipName_ScrollerGestureType &sipStrings_QtWidgets[7392]
#define sipNameNr_SliderSingleStepAdd 25811
#define sipName_SliderSingleStepAdd &sipStrings_QtWidgets[25811]
#define sipNameNr_SliderSingleStepSub 25831
#define sipName_SliderSingleStepSub &sipStrings_QtWidgets[25831]
#define sipNameNr_SmartViewportUpdate 25851
#define sipName_SmartViewportUpdate &sipStrings_QtWidgets[25851]
#define sipNameNr_State_FocusAtBorder 25871
#define sipName_State_FocusAtBorder &sipStrings_QtWidgets[25871]
#define sipNameNr_ToolButtonPopupMode 6126
#define sipName_ToolButtonPopupMode &sipStrings_QtWidgets[6126]
#define sipNameNr_allColumnsShowFocus 25891
#define sipName_allColumnsShowFocus &sipStrings_QtWidgets[25891]
#define sipNameNr_allowedAreasChanged 25911
#define sipName_allowedAreasChanged &sipStrings_QtWidgets[25911]
#define sipNameNr_buttonDownScreenPos 25931
#define sipName_buttonDownScreenPos &sipStrings_QtWidgets[25931]
#define sipNameNr_changeCurrentOnDrag 25951
#define sipName_changeCurrentOnDrag &sipStrings_QtWidgets[25951]
#define sipNameNr_childrenCollapsible 25971
#define sipName_childrenCollapsible &sipStrings_QtWidgets[25971]
#define sipNameNr_columnStretchFactor 25991
#define sipName_columnStretchFactor &sipStrings_QtWidgets[25991]
#define sipNameNr_currentColorChanged 26011
#define sipName_currentColorChanged &sipStrings_QtWidgets[26011]
#define sipNameNr_currentIndexChanged 26031
#define sipName_currentIndexChanged &sipStrings_QtWidgets[26031]
#define sipNameNr_currentSectionIndex 26051
#define sipName_currentSectionIndex &sipStrings_QtWidgets[26051]
#define sipNameNr_customButtonClicked 26071
#define sipName_customButtonClicked &sipStrings_QtWidgets[26071]
#define sipNameNr_dateEditAcceptDelay 26091
#define sipName_dateEditAcceptDelay &sipStrings_QtWidgets[26091]
#define sipNameNr_decorationAlignment 26111
#define sipName_decorationAlignment &sipStrings_QtWidgets[26111]
#define sipNameNr_directoryUrlEntered 26131
#define sipName_directoryUrlEntered &sipStrings_QtWidgets[26131]
#define sipNameNr_dockLocationChanged 26151
#define sipName_dockLocationChanged &sipStrings_QtWidgets[26151]
#define sipNameNr_doubleClickInterval 26171
#define sipName_doubleClickInterval &sipStrings_QtWidgets[26171]
#define sipNameNr_doubleValueSelected 26191
#define sipName_doubleValueSelected &sipStrings_QtWidgets[26191]
#define sipNameNr_ensureCursorVisible 26211
#define sipName_ensureCursorVisible &sipStrings_QtWidgets[26211]
#define sipNameNr_ensureWidgetVisible 26231
#define sipName_ensureWidgetVisible &sipStrings_QtWidgets[26231]
#define sipNameNr_expandingDirections 26251
#define sipName_expandingDirections &sipStrings_QtWidgets[26251]
#define sipNameNr_forwardHistoryCount 26271
#define sipName_forwardHistoryCount &sipStrings_QtWidgets[26271]
#define sipNameNr_generatedIconPixmap 26291
#define sipName_generatedIconPixmap &sipStrings_QtWidgets[26291]
#define sipNameNr_gestureCancelPolicy 26311
#define sipName_gestureCancelPolicy &sipStrings_QtWidgets[26311]
#define sipNameNr_graphicsProxyWidget 26331
#define sipName_graphicsProxyWidget &sipStrings_QtWidgets[26331]
#define sipNameNr_horizontalDirection 26351
#define sipName_horizontalDirection &sipStrings_QtWidgets[26351]
#define sipNameNr_horizontalScrollBar 26371
#define sipName_horizontalScrollBar &sipStrings_QtWidgets[26371]
#define sipNameNr_indexOfTopLevelItem 26391
#define sipName_indexOfTopLevelItem &sipStrings_QtWidgets[26391]
#define sipNameNr_insertTopLevelItems 26411
#define sipName_insertTopLevelItems &sipStrings_QtWidgets[26411]
#define sipNameNr_isBackwardAvailable 26431
#define sipName_isBackwardAvailable &sipStrings_QtWidgets[26431]
#define sipNameNr_isSectionDragTarget 26451
#define sipName_isSectionDragTarget &sipStrings_QtWidgets[26451]
#define sipNameNr_keyboardSearchFlags 26471
#define sipName_keyboardSearchFlags &sipStrings_QtWidgets[26471]
#define sipNameNr_maximumViewportSize 26491
#define sipName_maximumViewportSize &sipStrings_QtWidgets[26491]
#define sipNameNr_modificationChanged 26511
#define sipName_modificationChanged &sipStrings_QtWidgets[26511]
#define sipNameNr_overrideWindowFlags 26531
#define sipName_overrideWindowFlags &sipStrings_QtWidgets[26531]
#define sipNameNr_overrideWindowState 26551
#define sipName_overrideWindowState &sipStrings_QtWidgets[26551]
#define sipNameNr_resizeRowToContents 26571
#define sipName_resizeRowToContents &sipStrings_QtWidgets[26571]
#define sipNameNr_rowViewportPosition 26591
#define sipName_rowViewportPosition &sipStrings_QtWidgets[26591]
#define sipNameNr_sampleTextForSystem 26611
#define sipName_sampleTextForSystem &sipStrings_QtWidgets[26611]
#define sipNameNr_sectionCountChanged 26631
#define sipName_sectionCountChanged &sipStrings_QtWidgets[26631]
#define sipNameNr_setAutoScrollMargin 26651
#define sipName_setAutoScrollMargin &sipStrings_QtWidgets[26651]
#define sipNameNr_setCancelButtonText 26671
#define sipName_setCancelButtonText &sipStrings_QtWidgets[26671]
#define sipNameNr_setColumnFixedWidth 26691
#define sipName_setColumnFixedWidth &sipStrings_QtWidgets[26691]
#define sipNameNr_setComboBoxEditable 26711
#define sipName_setComboBoxEditable &sipStrings_QtWidgets[26711]
#define sipNameNr_setCompletionColumn 26731
#define sipName_setCompletionColumn &sipStrings_QtWidgets[26731]
#define sipNameNr_setCompletionPrefix 26751
#define sipName_setCompletionPrefix &sipStrings_QtWidgets[26751]
#define sipNameNr_setDefaultAlignment 26771
#define sipName_setDefaultAlignment &sipStrings_QtWidgets[26771]
#define sipNameNr_setDefaultTextColor 26791
#define sipName_setDefaultTextColor &sipStrings_QtWidgets[26791]
#define sipNameNr_setHeaderTextFormat 26811
#define sipName_setHeaderTextFormat &sipStrings_QtWidgets[26811]
#define sipNameNr_setHorizontalHeader 26831
#define sipName_setHorizontalHeader &sipStrings_QtWidgets[26831]
#define sipNameNr_setHorizontalPolicy 26851
#define sipName_setHorizontalPolicy &sipStrings_QtWidgets[26851]
#define sipNameNr_setInputMethodHints 26871
#define sipName_setInputMethodHints &sipStrings_QtWidgets[26871]
#define sipNameNr_setInvertedControls 26891
#define sipName_setInvertedControls &sipStrings_QtWidgets[26891]
#define sipNameNr_setKeyboardPageStep 26911
#define sipName_setKeyboardPageStep &sipStrings_QtWidgets[26911]
#define sipNameNr_setKeyboardTracking 26931
#define sipName_setKeyboardTracking &sipStrings_QtWidgets[26931]
#define sipNameNr_setLabelDrawingMode 26951
#define sipName_setLabelDrawingMode &sipStrings_QtWidgets[26951]
#define sipNameNr_setOptimizationFlag 26971
#define sipName_setOptimizationFlag &sipStrings_QtWidgets[26971]
#define sipNameNr_setParentLayoutItem 26991
#define sipName_setParentLayoutItem &sipStrings_QtWidgets[26991]
#define sipNameNr_setPositionForIndex 27011
#define sipName_setPositionForIndex &sipStrings_QtWidgets[27011]
#define sipNameNr_setResourceProvider 27031
#define sipName_setResourceProvider &sipStrings_QtWidgets[27031]
#define sipNameNr_setRowMaximumHeight 27051
#define sipName_setRowMaximumHeight &sipStrings_QtWidgets[27051]
#define sipNameNr_setRowMinimumHeight 27071
#define sipName_setRowMinimumHeight &sipStrings_QtWidgets[27071]
#define sipNameNr_setRowStretchFactor 27091
#define sipName_setRowStretchFactor &sipStrings_QtWidgets[27091]
#define sipNameNr_setSizeAdjustPolicy 27111
#define sipName_setSizeAdjustPolicy &sipStrings_QtWidgets[27111]
#define sipNameNr_setSpecialValueText 27131
#define sipName_setSpecialValueText &sipStrings_QtWidgets[27131]
#define sipNameNr_setStartCenterPoint 27151
#define sipName_setStartCenterPoint &sipStrings_QtWidgets[27151]
#define sipNameNr_setSupportedSchemes 27171
#define sipName_setSupportedSchemes &sipStrings_QtWidgets[27171]
#define sipNameNr_setTabKeyNavigation 27191
#define sipName_setTabKeyNavigation &sipStrings_QtWidgets[27191]
#define sipNameNr_setTotalChangeFlags 27211
#define sipName_setTotalChangeFlags &sipStrings_QtWidgets[27211]
#define sipNameNr_setTotalScaleFactor 27231
#define sipName_setTotalScaleFactor &sipStrings_QtWidgets[27231]
#define sipNameNr_setUniformItemSizes 27251
#define sipName_setUniformItemSizes &sipStrings_QtWidgets[27251]
#define sipNameNr_setWheelScrollLines 27271
#define sipName_setWheelScrollLines &sipStrings_QtWidgets[27271]
#define sipNameNr_stretchSectionCount 27291
#define sipName_stretchSectionCount &sipStrings_QtWidgets[27291]
#define sipNameNr_tabBarDoubleClicked 27311
#define sipName_tabBarDoubleClicked &sipStrings_QtWidgets[27311]
#define sipNameNr_tabifiedDockWidgets 27331
#define sipName_tabifiedDockWidgets &sipStrings_QtWidgets[27331]
#define sipNameNr_textBackgroundColor 27351
#define sipName_textBackgroundColor &sipStrings_QtWidgets[27351]
#define sipNameNr_totalHeightForWidth 27371
#define sipName_totalHeightForWidth &sipStrings_QtWidgets[27371]
#define sipNameNr_ungrabKeyboardEvent 27391
#define sipName_ungrabKeyboardEvent &sipStrings_QtWidgets[27391]
#define sipNameNr_updatePreviewWidget 27411
#define sipName_updatePreviewWidget &sipStrings_QtWidgets[27411]
#define sipNameNr_validateCurrentPage 27431
#define sipName_validateCurrentPage &sipStrings_QtWidgets[27431]
#define sipNameNr_windowFrameGeometry 27451
#define sipName_windowFrameGeometry &sipStrings_QtWidgets[27451]
#define sipNameNr_AutoFormattingFlag 8304
#define sipName_AutoFormattingFlag &sipStrings_QtWidgets[8304]
#define sipNameNr_CE_DockWidgetTitle 27471
#define sipName_CE_DockWidgetTitle &sipStrings_QtWidgets[27471]
#define sipNameNr_CE_HeaderEmptyArea 27490
#define sipName_CE_HeaderEmptyArea &sipStrings_QtWidgets[27490]
#define sipNameNr_CE_PushButtonBevel 27509
#define sipName_CE_PushButtonBevel &sipStrings_QtWidgets[27509]
#define sipNameNr_CE_PushButtonLabel 27528
#define sipName_CE_PushButtonLabel &sipStrings_QtWidgets[27528]
#define sipNameNr_CE_ScrollBarSlider 27547
#define sipName_CE_ScrollBarSlider &sipStrings_QtWidgets[27547]
#define sipNameNr_CE_ToolBoxTabLabel 27566
#define sipName_CE_ToolBoxTabLabel &sipStrings_QtWidgets[27566]
#define sipNameNr_CE_ToolBoxTabShape 27585
#define sipName_CE_ToolBoxTabShape &sipStrings_QtWidgets[27585]
#define sipNameNr_CE_ToolButtonLabel 27604
#define sipName_CE_ToolButtonLabel &sipStrings_QtWidgets[27604]
#define sipNameNr_CancelAllInContext 27623
#define sipName_CancelAllInContext &sipStrings_QtWidgets[27623]
#define sipNameNr_CancelButtonOnLeft 27642
#define sipName_CancelButtonOnLeft &sipStrings_QtWidgets[27642]
#define sipNameNr_CenterPointChanged 27661
#define sipName_CenterPointChanged &sipStrings_QtWidgets[27661]
#define sipNameNr_DecelerationFactor 27680
#define sipName_DecelerationFactor &sipStrings_QtWidgets[27680]
#define sipNameNr_DockWidgetClosable 27699
#define sipName_DockWidgetClosable &sipStrings_QtWidgets[27699]
#define sipNameNr_DragSelectingState 27718
#define sipName_DragSelectingState &sipStrings_QtWidgets[27718]
#define sipNameNr_FullViewportUpdate 27737
#define sipName_FullViewportUpdate &sipStrings_QtWidgets[27737]
#define sipNameNr_GraphicsItemChange 5321
#define sipName_GraphicsItemChange &sipStrings_QtWidgets[5321]
#define sipNameNr_HeuristicMaskShape 27756
#define sipName_HeuristicMaskShape &sipStrings_QtWidgets[27756]
#define sipNameNr_InsertAfterCurrent 27775
#define sipName_InsertAfterCurrent &sipStrings_QtWidgets[27775]
#define sipNameNr_ItemPositionChange 27794
#define sipName_ItemPositionChange &sipStrings_QtWidgets[27794]
#define sipNameNr_ItemRotationChange 27813
#define sipName_ItemRotationChange &sipStrings_QtWidgets[27813]
#define sipNameNr_ItemSelectedChange 27832
#define sipName_ItemSelectedChange &sipStrings_QtWidgets[27832]
#define sipNameNr_NoEyeDropperButton 27851
#define sipName_NoEyeDropperButton &sipStrings_QtWidgets[27851]
#define sipNameNr_NoHorizontalHeader 27870
#define sipName_NoHorizontalHeader &sipStrings_QtWidgets[27870]
#define sipNameNr_OvershootAlwaysOff 27889
#define sipName_OvershootAlwaysOff &sipStrings_QtWidgets[27889]
#define sipNameNr_PE_FrameButtonTool 27908
#define sipName_PE_FrameButtonTool &sipStrings_QtWidgets[27908]
#define sipNameNr_PE_FrameDockWidget 27927
#define sipName_PE_FrameDockWidget &sipStrings_QtWidgets[27927]
#define sipNameNr_PE_FrameTabBarBase 27946
#define sipName_PE_FrameTabBarBase &sipStrings_QtWidgets[27946]
#define sipNameNr_PE_IndicatorBranch 27965
#define sipName_PE_IndicatorBranch &sipStrings_QtWidgets[27965]
#define sipNameNr_PE_IndicatorSpinUp 27984
#define sipName_PE_IndicatorSpinUp &sipStrings_QtWidgets[27984]
#define sipNameNr_PE_PanelButtonTool 28003
#define sipName_PE_PanelButtonTool &sipStrings_QtWidgets[28003]
#define sipNameNr_PM_IndicatorHeight 28022
#define sipName_PM_IndicatorHeight &sipStrings_QtWidgets[28022]
#define sipNameNr_PM_LayoutTopMargin 28041
#define sipName_PM_LayoutTopMargin &sipStrings_QtWidgets[28041]
#define sipNameNr_PM_ScrollBarExtent 28060
#define sipName_PM_ScrollBarExtent &sipStrings_QtWidgets[28060]
#define sipNameNr_PM_SliderThickness 28079
#define sipName_PM_SliderThickness &sipStrings_QtWidgets[28079]
#define sipNameNr_PM_TabBarTabHSpace 28098
#define sipName_PM_TabBarTabHSpace &sipStrings_QtWidgets[28098]
#define sipNameNr_PM_TabBarTabVSpace 28117
#define sipName_PM_TabBarTabVSpace &sipStrings_QtWidgets[28117]
#define sipNameNr_PM_TextCursorWidth 28136
#define sipName_PM_TextCursorWidth &sipStrings_QtWidgets[28136]
#define sipNameNr_PM_ToolBarIconSize 28155
#define sipName_PM_ToolBarIconSize &sipStrings_QtWidgets[28155]
#define sipNameNr_PasswordEchoOnEdit 28174
#define sipName_PasswordEchoOnEdit &sipStrings_QtWidgets[28174]
#define sipNameNr_PreviousIsSelected 28193
#define sipName_PreviousIsSelected &sipStrings_QtWidgets[28193]
#define sipNameNr_QCommandLinkButton 28212
#define sipName_QCommandLinkButton &sipStrings_QtWidgets[28212]
#define sipNameNr_QGestureRecognizer 28231
#define sipName_QGestureRecognizer &sipStrings_QtWidgets[28231]
#define sipNameNr_QGraphicsItemGroup 28250
#define sipName_QGraphicsItemGroup &sipStrings_QtWidgets[28250]
#define sipNameNr_QGraphicsTransform 28269
#define sipName_QGraphicsTransform &sipStrings_QtWidgets[28269]
#define sipNameNr_QItemEditorFactory 28288
#define sipName_QItemEditorFactory &sipStrings_QtWidgets[28288]
#define sipNameNr_QMdiArea__ViewMode 28307
#define sipName_QMdiArea__ViewMode &sipStrings_QtWidgets[28307]
#define sipNameNr_QRubberBand__Shape 28326
#define sipName_QRubberBand__Shape &sipStrings_QtWidgets[28326]
#define sipNameNr_QStyle__SubControl 28345
#define sipName_QStyle__SubControl &sipStrings_QtWidgets[28345]
#define sipNameNr_QStyle__SubElement 28364
#define sipName_QStyle__SubElement &sipStrings_QtWidgets[28364]
#define sipNameNr_QStyleOptionButton 28383
#define sipName_QStyleOptionButton &sipStrings_QtWidgets[28383]
#define sipNameNr_QStyleOptionHeader 28402
#define sipName_QStyleOptionHeader &sipStrings_QtWidgets[28402]
#define sipNameNr_QStyleOptionSlider 28421
#define sipName_QStyleOptionSlider &sipStrings_QtWidgets[28421]
#define sipNameNr_QTapAndHoldGesture 28440
#define sipName_QTapAndHoldGesture &sipStrings_QtWidgets[28440]
#define sipNameNr_SC_MdiNormalButton 28459
#define sipName_SC_MdiNormalButton &sipStrings_QtWidgets[28459]
#define sipNameNr_SC_ScrollBarGroove 28478
#define sipName_SC_ScrollBarGroove &sipStrings_QtWidgets[28478]
#define sipNameNr_SC_ScrollBarSlider 28497
#define sipName_SC_ScrollBarSlider &sipStrings_QtWidgets[28497]
#define sipNameNr_SC_SliderTickmarks 28516
#define sipName_SC_SliderTickmarks &sipStrings_QtWidgets[28516]
#define sipNameNr_SC_TitleBarSysMenu 28535
#define sipName_SC_TitleBarSysMenu &sipStrings_QtWidgets[28535]
#define sipNameNr_SE_FrameLayoutItem 28554
#define sipName_SE_FrameLayoutItem &sipStrings_QtWidgets[28554]
#define sipNameNr_SE_LabelLayoutItem 28573
#define sipName_SE_LabelLayoutItem &sipStrings_QtWidgets[28573]
#define sipNameNr_SE_PushButtonBevel 28592
#define sipName_SE_PushButtonBevel &sipStrings_QtWidgets[28592]
#define sipNameNr_SE_SliderFocusRect 28611
#define sipName_SE_SliderFocusRect &sipStrings_QtWidgets[28611]
#define sipNameNr_SE_TabWidgetTabBar 28630
#define sipName_SE_TabWidgetTabBar &sipStrings_QtWidgets[28630]
#define sipNameNr_SH_FocusFrame_Mask 28649
#define sipName_SH_FocusFrame_Mask &sipStrings_QtWidgets[28649]
#define sipNameNr_SH_Menu_Scrollable 28668
#define sipName_SH_Menu_Scrollable &sipStrings_QtWidgets[28668]
#define sipNameNr_SH_RubberBand_Mask 28687
#define sipName_SH_RubberBand_Mask &sipStrings_QtWidgets[28687]
#define sipNameNr_SH_ToolBar_Movable 28706
#define sipName_SH_ToolBar_Movable &sipStrings_QtWidgets[28706]
#define sipNameNr_SH_ToolButtonStyle 28725
#define sipName_SH_ToolButtonStyle &sipStrings_QtWidgets[28725]
#define sipNameNr_SP_DialogYesButton 28744
#define sipName_SP_DialogYesButton &sipStrings_QtWidgets[28744]
#define sipNameNr_SP_DirLinkOpenIcon 28763
#define sipName_SP_DirLinkOpenIcon &sipStrings_QtWidgets[28763]
#define sipNameNr_SP_FileDialogStart 28782
#define sipName_SP_FileDialogStart &sipStrings_QtWidgets[28782]
#define sipNameNr_ScaleFactorChanged 28801
#define sipName_ScaleFactorChanged &sipStrings_QtWidgets[28801]
#define sipNameNr_StyleOptionVersion 128
#define sipName_StyleOptionVersion &sipStrings_QtWidgets[128]
#define sipNameNr_ViewportUpdateMode 5355
#define sipName_ViewportUpdateMode &sipStrings_QtWidgets[5355]
#define sipNameNr_addChildLayoutItem 28820
#define sipName_addChildLayoutItem &sipStrings_QtWidgets[28820]
#define sipNameNr_addPermanentWidget 28839
#define sipName_addPermanentWidget &sipStrings_QtWidgets[28839]
#define sipNameNr_addScrollBarWidget 28858
#define sipName_addScrollBarWidget &sipStrings_QtWidgets[28858]
#define sipNameNr_autoFillBackground 28877
#define sipName_autoFillBackground &sipStrings_QtWidgets[28877]
#define sipNameNr_autoRepeatInterval 28896
#define sipName_autoRepeatInterval &sipStrings_QtWidgets[28896]
#define sipNameNr_buttonDownScenePos 28915
#define sipName_buttonDownScenePos &sipStrings_QtWidgets[28915]
#define sipNameNr_clearPropertyFlags 28934
#define sipName_clearPropertyFlags &sipStrings_QtWidgets[28934]
#define sipNameNr_closeAllSubWindows 28953
#define sipName_closeAllSubWindows &sipStrings_QtWidgets[28953]
#define sipNameNr_columnCountChanged 28972
#define sipName_columnCountChanged &sipStrings_QtWidgets[28972]
#define sipNameNr_columnMaximumWidth 28991
#define sipName_columnMaximumWidth &sipStrings_QtWidgets[28991]
#define sipNameNr_columnMinimumWidth 29010
#define sipName_columnMinimumWidth &sipStrings_QtWidgets[29010]
#define sipNameNr_commonAncestorItem 29029
#define sipName_commonAncestorItem &sipStrings_QtWidgets[29029]
#define sipNameNr_currentCellChanged 29048
#define sipName_currentCellChanged &sipStrings_QtWidgets[29048]
#define sipNameNr_currentFontChanged 29067
#define sipName_currentFontChanged &sipStrings_QtWidgets[29067]
#define sipNameNr_currentItemChanged 29086
#define sipName_currentItemChanged &sipStrings_QtWidgets[29086]
#define sipNameNr_currentPageChanged 29105
#define sipName_currentPageChanged &sipStrings_QtWidgets[29105]
#define sipNameNr_currentTextChanged 29124
#define sipName_currentTextChanged &sipStrings_QtWidgets[29124]
#define sipNameNr_cursorWordBackward 29143
#define sipName_cursorWordBackward &sipStrings_QtWidgets[29143]
#define sipNameNr_decorationPosition 29162
#define sipName_decorationPosition &sipStrings_QtWidgets[29162]
#define sipNameNr_defaultSectionSize 29181
#define sipName_defaultSectionSize &sipStrings_QtWidgets[29181]
#define sipNameNr_displayIntegerBase 29200
#define sipName_displayIntegerBase &sipStrings_QtWidgets[29200]
#define sipNameNr_doubleValueChanged 29219
#define sipName_doubleValueChanged &sipStrings_QtWidgets[29219]
#define sipNameNr_drawComplexControl 29238
#define sipName_drawComplexControl &sipStrings_QtWidgets[29238]
#define sipNameNr_enterWhatsThisMode 29257
#define sipName_enterWhatsThisMode &sipStrings_QtWidgets[29257]
#define sipNameNr_filtersChildEvents 29276
#define sipName_filtersChildEvents &sipStrings_QtWidgets[29276]
#define sipNameNr_focusNextPrevChild 29295
#define sipName_focusNextPrevChild &sipStrings_QtWidgets[29295]
#define sipNameNr_focusPreviousChild 29314
#define sipName_focusPreviousChild &sipStrings_QtWidgets[29314]
#define sipNameNr_getContentsMargins 29333
#define sipName_getContentsMargins &sipStrings_QtWidgets[29333]
#define sipNameNr_hasAcceptableInput 29352
#define sipName_hasAcceptableInput &sipStrings_QtWidgets[29352]
#define sipNameNr_hiddenSectionCount 29371
#define sipName_hiddenSectionCount &sipStrings_QtWidgets[29371]
#define sipNameNr_initViewItemOption 29390
#define sipName_initViewItemOption &sipStrings_QtWidgets[29390]
#define sipNameNr_initializeSections 29409
#define sipName_initializeSections &sipStrings_QtWidgets[29409]
#define sipNameNr_insertFromMimeData 29428
#define sipName_insertFromMimeData &sipStrings_QtWidgets[29428]
#define sipNameNr_insertToolBarBreak 29447
#define sipName_insertToolBarBreak &sipStrings_QtWidgets[29447]
#define sipNameNr_insertTopLevelItem 29466
#define sipName_insertTopLevelItem &sipStrings_QtWidgets[29466]
#define sipNameNr_invertedAppearance 29485
#define sipName_invertedAppearance &sipStrings_QtWidgets[29485]
#define sipNameNr_isComboBoxEditable 29504
#define sipName_isComboBoxEditable &sipStrings_QtWidgets[29504]
#define sipNameNr_isForwardAvailable 29523
#define sipName_isForwardAvailable &sipStrings_QtWidgets[29523]
#define sipNameNr_itemDelegateForRow 29542
#define sipName_itemDelegateForRow &sipStrings_QtWidgets[29542]
#define sipNameNr_keySequenceChanged 29561
#define sipName_keySequenceChanged &sipStrings_QtWidgets[29561]
#define sipNameNr_keyboardSingleStep 29580
#define sipName_keyboardSingleStep &sipStrings_QtWidgets[29580]
#define sipNameNr_leaveWhatsThisMode 29599
#define sipName_leaveWhatsThisMode &sipStrings_QtWidgets[29599]
#define sipNameNr_mapToGraphicsScene 29618
#define sipName_mapToGraphicsScene &sipStrings_QtWidgets[29618]
#define sipNameNr_mappedPropertyName 29637
#define sipName_mappedPropertyName &sipStrings_QtWidgets[29637]
#define sipNameNr_maximumSectionSize 29656
#define sipName_maximumSectionSize &sipStrings_QtWidgets[29656]
#define sipNameNr_minimumSectionSize 29675
#define sipName_minimumSectionSize &sipStrings_QtWidgets[29675]
#define sipNameNr_minimumTabSizeHint 29694
#define sipName_minimumTabSizeHint &sipStrings_QtWidgets[29694]
#define sipNameNr_nativeParentWidget 29713
#define sipName_nativeParentWidget &sipStrings_QtWidgets[29713]
#define sipNameNr_opacityMaskChanged 29732
#define sipName_opacityMaskChanged &sipStrings_QtWidgets[29732]
#define sipNameNr_orientationChanged 29751
#define sipName_orientationChanged &sipStrings_QtWidgets[29751]
#define sipNameNr_positionWithinLine 29770
#define sipName_positionWithinLine &sipStrings_QtWidgets[29770]
#define sipNameNr_registerRecognizer 24187
#define sipName_registerRecognizer &sipStrings_QtWidgets[24187]
#define sipNameNr_removeToolBarBreak 29789
#define sipName_removeToolBarBreak &sipStrings_QtWidgets[29789]
#define sipNameNr_resendPrepareEvent 29808
#define sipName_resendPrepareEvent &sipStrings_QtWidgets[29808]
#define sipNameNr_resetCachedContent 29827
#define sipName_resetCachedContent &sipStrings_QtWidgets[29827]
#define sipNameNr_resizeGripsVisible 29846
#define sipName_resizeGripsVisible &sipStrings_QtWidgets[29846]
#define sipNameNr_resizeInlineObject 29865
#define sipName_resizeInlineObject &sipStrings_QtWidgets[29865]
#define sipNameNr_rowPreferredHeight 29884
#define sipName_rowPreferredHeight &sipStrings_QtWidgets[29884]
#define sipNameNr_scrollerProperties 29903
#define sipName_scrollerProperties &sipStrings_QtWidgets[29903]
#define sipNameNr_selectedNameFilter 29922
#define sipName_selectedNameFilter &sipStrings_QtWidgets[29922]
#define sipNameNr_selectionOperation 29941
#define sipName_selectionOperation &sipStrings_QtWidgets[29941]
#define sipNameNr_setActivationOrder 29960
#define sipName_setActivationOrder &sipStrings_QtWidgets[29960]
#define sipNameNr_setActiveSubWindow 29979
#define sipName_setActiveSubWindow &sipStrings_QtWidgets[29979]
#define sipNameNr_setAutoExpandDelay 29998
#define sipName_setAutoExpandDelay &sipStrings_QtWidgets[29998]
#define sipNameNr_setAutoRepeatDelay 30017
#define sipName_setAutoRepeatDelay &sipStrings_QtWidgets[30017]
#define sipNameNr_setBackgroundBrush 30036
#define sipName_setBackgroundBrush &sipStrings_QtWidgets[30036]
#define sipNameNr_setCaseSensitivity 30055
#define sipName_setCaseSensitivity &sipStrings_QtWidgets[30055]
#define sipNameNr_setColumnAlignment 30074
#define sipName_setColumnAlignment &sipStrings_QtWidgets[30074]
#define sipNameNr_setContentsMargins 24208
#define sipName_setContentsMargins &sipStrings_QtWidgets[24208]
#define sipNameNr_setCursorFlashTime 30093
#define sipName_setCursorFlashTime &sipStrings_QtWidgets[30093]
#define sipNameNr_setCursorMoveStyle 30112
#define sipName_setCursorMoveStyle &sipStrings_QtWidgets[30112]
#define sipNameNr_setDateEditEnabled 30131
#define sipName_setDateEditEnabled &sipStrings_QtWidgets[30131]
#define sipNameNr_setDefaultProperty 30150
#define sipName_setDefaultProperty &sipStrings_QtWidgets[30150]
#define sipNameNr_setExtraSelections 30169
#define sipName_setExtraSelections &sipStrings_QtWidgets[30169]
#define sipNameNr_setForegroundBrush 30188
#define sipName_setForegroundBrush &sipStrings_QtWidgets[30188]
#define sipNameNr_setInformativeText 30207
#define sipName_setInformativeText &sipStrings_QtWidgets[30207]
#define sipNameNr_setItemIndexMethod 30226
#define sipName_setItemIndexMethod &sipStrings_QtWidgets[30226]
#define sipNameNr_setItemsExpandable 30245
#define sipName_setItemsExpandable &sipStrings_QtWidgets[30245]
#define sipNameNr_setLastCenterPoint 30264
#define sipName_setLastCenterPoint &sipStrings_QtWidgets[30264]
#define sipNameNr_setLastScaleFactor 30283
#define sipName_setLastScaleFactor &sipStrings_QtWidgets[30283]
#define sipNameNr_setLayoutDirection 24229
#define sipName_setLayoutDirection &sipStrings_QtWidgets[24229]
#define sipNameNr_setMaxVisibleItems 30302
#define sipName_setMaxVisibleItems &sipStrings_QtWidgets[30302]
#define sipNameNr_setMaximumDateTime 30321
#define sipName_setMaximumDateTime &sipStrings_QtWidgets[30321]
#define sipNameNr_setMimeTypeFilters 30340
#define sipName_setMimeTypeFilters &sipStrings_QtWidgets[30340]
#define sipNameNr_setMinimumDateTime 30359
#define sipName_setMinimumDateTime &sipStrings_QtWidgets[30359]
#define sipNameNr_setMinimumDuration 30378
#define sipName_setMinimumDuration &sipStrings_QtWidgets[30378]
#define sipNameNr_setPlaceholderText 30397
#define sipName_setPlaceholderText &sipStrings_QtWidgets[30397]
#define sipNameNr_setPreferredHeight 30416
#define sipName_setPreferredHeight &sipStrings_QtWidgets[30416]
#define sipNameNr_setRootIsDecorated 30435
#define sipName_setRootIsDecorated &sipStrings_QtWidgets[30435]
#define sipNameNr_setSectionsMovable 30454
#define sipName_setSectionsMovable &sipStrings_QtWidgets[30454]
#define sipNameNr_setSelectedSection 30473
#define sipName_setSelectedSection &sipStrings_QtWidgets[30473]
#define sipNameNr_setShortcutEnabled 30492
#define sipName_setShortcutEnabled &sipStrings_QtWidgets[30492]
#define sipNameNr_setSizeConstraints 30511
#define sipName_setSizeConstraints &sipStrings_QtWidgets[30511]
#define sipNameNr_setSizeGripEnabled 30530
#define sipName_setSizeGripEnabled &sipStrings_QtWidgets[30530]
#define sipNameNr_setStandardButtons 30549
#define sipName_setStandardButtons &sipStrings_QtWidgets[30549]
#define sipNameNr_setTabChangesFocus 30568
#define sipName_setTabChangesFocus &sipStrings_QtWidgets[30568]
#define sipNameNr_setTabStopDistance 30587
#define sipName_setTabStopDistance &sipStrings_QtWidgets[30587]
#define sipNameNr_setToolButtonStyle 30606
#define sipName_setToolButtonStyle &sipStrings_QtWidgets[30606]
#define sipNameNr_setToolTipDuration 30625
#define sipName_setToolTipDuration &sipStrings_QtWidgets[30625]
#define sipNameNr_setToolTipsVisible 30644
#define sipName_setToolTipsVisible &sipStrings_QtWidgets[30644]
#define sipNameNr_setTransformations 30663
#define sipName_setTransformations &sipStrings_QtWidgets[30663]
#define sipNameNr_setUndoRedoEnabled 30682
#define sipName_setUndoRedoEnabled &sipStrings_QtWidgets[30682]
#define sipNameNr_setUpdateThreshold 30701
#define sipName_setUpdateThreshold &sipStrings_QtWidgets[30701]
#define sipNameNr_setVerticalSpacing 30720
#define sipName_setVerticalSpacing &sipStrings_QtWidgets[30720]
#define sipNameNr_setVerticalStretch 30739
#define sipName_setVerticalStretch &sipStrings_QtWidgets[30739]
#define sipNameNr_setViewportMargins 30758
#define sipName_setViewportMargins &sipStrings_QtWidgets[30758]
#define sipNameNr_setWidgetResizable 30777
#define sipName_setWidgetResizable &sipStrings_QtWidgets[30777]
#define sipNameNr_sortIndicatorOrder 30796
#define sipName_sortIndicatorOrder &sipStrings_QtWidgets[30796]
#define sipNameNr_sourceBoundingRect 30815
#define sipName_sourceBoundingRect &sipStrings_QtWidgets[30815]
#define sipNameNr_stretchLastSection 30834
#define sipName_stretchLastSection &sipStrings_QtWidgets[30834]
#define sipNameNr_subWindowActivated 30853
#define sipName_subWindowActivated &sipStrings_QtWidgets[30853]
#define sipNameNr_totalRotationAngle 30872
#define sipName_totalRotationAngle &sipStrings_QtWidgets[30872]
#define sipNameNr_transformationMode 30891
#define sipName_transformationMode &sipStrings_QtWidgets[30891]
#define sipNameNr_updateBoundingRect 30910
#define sipName_updateBoundingRect &sipStrings_QtWidgets[30910]
#define sipNameNr_verticalHeaderItem 30929
#define sipName_verticalHeaderItem &sipStrings_QtWidgets[30929]
#define sipNameNr_verticalScrollMode 30948
#define sipName_verticalScrollMode &sipStrings_QtWidgets[30948]
#define sipNameNr_viewportUpdateMode 30967
#define sipName_viewportUpdateMode &sipStrings_QtWidgets[30967]
#define sipNameNr_windowStateChanged 30986
#define sipName_windowStateChanged &sipStrings_QtWidgets[30986]
#define sipNameNr_windowTitleChanged 31005
#define sipName_windowTitleChanged &sipStrings_QtWidgets[31005]
#define sipNameNr_AutoDefaultButton 31024
#define sipName_AutoDefaultButton &sipStrings_QtWidgets[31024]
#define sipNameNr_AxisLockThreshold 31042
#define sipName_AxisLockThreshold &sipStrings_QtWidgets[31042]
#define sipNameNr_BoundingRectShape 31060
#define sipName_BoundingRectShape &sipStrings_QtWidgets[31060]
#define sipNameNr_CE_ColumnViewGrip 31078
#define sipName_CE_ColumnViewGrip &sipStrings_QtWidgets[31078]
#define sipNameNr_CE_ScrollBarFirst 31096
#define sipName_CE_ScrollBarFirst &sipStrings_QtWidgets[31096]
#define sipNameNr_CE_TabBarTabLabel 31114
#define sipName_CE_TabBarTabLabel &sipStrings_QtWidgets[31114]
#define sipNameNr_CE_TabBarTabShape 31132
#define sipName_CE_TabBarTabShape &sipStrings_QtWidgets[31132]
#define sipNameNr_ColorDialogOption 6387
#define sipName_ColorDialogOption &sipStrings_QtWidgets[6387]
#define sipNameNr_CommandLinkButton 28213
#define sipName_CommandLinkButton &sipStrings_QtWidgets[28213]
#define sipNameNr_DateSections_Mask 31150
#define sipName_DateSections_Mask &sipStrings_QtWidgets[31150]
#define sipNameNr_DockWidgetFeature 7146
#define sipName_DockWidgetFeature &sipStrings_QtWidgets[7146]
#define sipNameNr_DockWidgetMovable 31168
#define sipName_DockWidgetMovable &sipStrings_QtWidgets[31168]
#define sipNameNr_DontShowIndicator 31186
#define sipName_DontShowIndicator &sipStrings_QtWidgets[31186]
#define sipNameNr_DragStartDistance 31204
#define sipName_DragStartDistance &sipStrings_QtWidgets[31204]
#define sipNameNr_ExtendedSelection 31222
#define sipName_ExtendedSelection &sipStrings_QtWidgets[31222]
#define sipNameNr_FieldGrowthPolicy 7208
#define sipName_FieldGrowthPolicy &sipStrings_QtWidgets[7208]
#define sipNameNr_HasCheckIndicator 31240
#define sipName_HasCheckIndicator &sipStrings_QtWidgets[31240]
#define sipNameNr_HaveCustomButton1 31258
#define sipName_HaveCustomButton1 &sipStrings_QtWidgets[31258]
#define sipNameNr_HaveCustomButton2 31276
#define sipName_HaveCustomButton2 &sipStrings_QtWidgets[31276]
#define sipNameNr_HaveCustomButton3 31294
#define sipName_HaveCustomButton3 &sipStrings_QtWidgets[31294]
#define sipNameNr_HelpButtonOnRight 31312
#define sipName_HelpButtonOnRight &sipStrings_QtWidgets[31312]
#define sipNameNr_InputDialogOption 6579
#define sipName_InputDialogOption &sipStrings_QtWidgets[6579]
#define sipNameNr_ItemEnabledChange 31330
#define sipName_ItemEnabledChange &sipStrings_QtWidgets[31330]
#define sipNameNr_ItemHasNoContents 31348
#define sipName_ItemHasNoContents &sipStrings_QtWidgets[31348]
#define sipNameNr_ItemOpacityChange 31366
#define sipName_ItemOpacityChange &sipStrings_QtWidgets[31366]
#define sipNameNr_ItemToolTipChange 31384
#define sipName_ItemToolTipChange &sipStrings_QtWidgets[31384]
#define sipNameNr_ItemVisibleChange 31402
#define sipName_ItemVisibleChange &sipStrings_QtWidgets[31402]
#define sipNameNr_OvershootAlwaysOn 31420
#define sipName_OvershootAlwaysOn &sipStrings_QtWidgets[31420]
#define sipNameNr_PE_FrameFocusRect 31438
#define sipName_PE_FrameFocusRect &sipStrings_QtWidgets[31438]
#define sipNameNr_PE_FrameTabWidget 31456
#define sipName_PE_FrameTabWidget &sipStrings_QtWidgets[31456]
#define sipNameNr_PE_PanelStatusBar 31474
#define sipName_PE_PanelStatusBar &sipStrings_QtWidgets[31474]
#define sipNameNr_PM_ButtonIconSize 31492
#define sipName_PM_ButtonIconSize &sipStrings_QtWidgets[31492]
#define sipNameNr_PM_HeaderMarkSize 31510
#define sipName_PM_HeaderMarkSize &sipStrings_QtWidgets[31510]
#define sipNameNr_PM_IndicatorWidth 31528
#define sipName_PM_IndicatorWidth &sipStrings_QtWidgets[31528]
#define sipNameNr_PM_MenuBarHMargin 31546
#define sipName_PM_MenuBarHMargin &sipStrings_QtWidgets[31546]
#define sipNameNr_PM_MenuBarVMargin 31564
#define sipName_PM_MenuBarVMargin &sipStrings_QtWidgets[31564]
#define sipNameNr_PM_MenuPanelWidth 31582
#define sipName_PM_MenuPanelWidth &sipStrings_QtWidgets[31582]
#define sipNameNr_PM_SubMenuOverlap 31600
#define sipName_PM_SubMenuOverlap &sipStrings_QtWidgets[31600]
#define sipNameNr_PM_TabBarIconSize 31618
#define sipName_PM_TabBarIconSize &sipStrings_QtWidgets[31618]
#define sipNameNr_PM_TitleBarHeight 31636
#define sipName_PM_TitleBarHeight &sipStrings_QtWidgets[31636]
#define sipNameNr_ProportionalFonts 31654
#define sipName_ProportionalFonts &sipStrings_QtWidgets[31654]
#define sipNameNr_QAbstractItemView 31672
#define sipName_QAbstractItemView &sipStrings_QtWidgets[31672]
#define sipNameNr_QDataWidgetMapper 31690
#define sipName_QDataWidgetMapper &sipStrings_QtWidgets[31690]
#define sipNameNr_QFileIconProvider 31708
#define sipName_QFileIconProvider &sipStrings_QtWidgets[31708]
#define sipNameNr_QFrame__StyleMask 31726
#define sipName_QFrame__StyleMask &sipStrings_QtWidgets[31726]
#define sipNameNr_QGraphicsLineItem 31744
#define sipName_QGraphicsLineItem &sipStrings_QtWidgets[31744]
#define sipNameNr_QGraphicsPathItem 31762
#define sipName_QGraphicsPathItem &sipStrings_QtWidgets[31762]
#define sipNameNr_QGraphicsRectItem 31780
#define sipName_QGraphicsRectItem &sipStrings_QtWidgets[31780]
#define sipNameNr_QGraphicsRotation 31798
#define sipName_QGraphicsRotation &sipStrings_QtWidgets[31798]
#define sipNameNr_QGraphicsTextItem 31816
#define sipName_QGraphicsTextItem &sipStrings_QtWidgets[31816]
#define sipNameNr_31834 31834
#define sipName_31834 &sipStrings_QtWidgets[31834]
#define sipNameNr_QMessageBox__Icon 31852
#define sipName_QMessageBox__Icon &sipStrings_QtWidgets[31852]
#define sipNameNr_QStyle__StateFlag 31870
#define sipName_QStyle__StateFlag &sipStrings_QtWidgets[31870]
#define sipNameNr_QStyle__StyleHint 31888
#define sipName_QStyle__StyleHint &sipStrings_QtWidgets[31888]
#define sipNameNr_QStyleOptionFrame 31906
#define sipName_QStyleOptionFrame &sipStrings_QtWidgets[31906]
#define sipNameNr_RSIP_OnMouseClick 31924
#define sipName_RSIP_OnMouseClick &sipStrings_QtWidgets[31924]
#define sipNameNr_RightCornerWidget 31942
#define sipName_RightCornerWidget &sipStrings_QtWidgets[31942]
#define sipNameNr_SC_MdiCloseButton 31960
#define sipName_SC_MdiCloseButton &sipStrings_QtWidgets[31960]
#define sipNameNr_SC_ScrollBarFirst 31978
#define sipName_SC_ScrollBarFirst &sipStrings_QtWidgets[31978]
#define sipNameNr_SC_ToolButtonMenu 31996
#define sipName_SC_ToolButtonMenu &sipStrings_QtWidgets[31996]
#define sipNameNr_SE_DockWidgetIcon 32014
#define sipName_SE_DockWidgetIcon &sipStrings_QtWidgets[32014]
#define sipNameNr_SH_ComboBox_Popup 32032
#define sipName_SH_ComboBox_Popup &sipStrings_QtWidgets[32032]
#define sipNameNr_SH_Widget_Animate 32050
#define sipName_SH_Widget_Animate &sipStrings_QtWidgets[32050]
#define sipNameNr_SO_TabWidgetFrame 32068
#define sipName_SO_TabWidgetFrame &sipStrings_QtWidgets[32068]
#define sipNameNr_SP_DialogNoButton 32086
#define sipName_SP_DialogNoButton &sipStrings_QtWidgets[32086]
#define sipNameNr_SP_DialogOkButton 32104
#define sipName_SP_DialogOkButton &sipStrings_QtWidgets[32104]
#define sipNameNr_SP_FileDialogBack 32122
#define sipName_SP_FileDialogBack &sipStrings_QtWidgets[32122]
#define sipNameNr_SP_TabCloseButton 32140
#define sipName_SP_TabCloseButton &sipStrings_QtWidgets[32140]
#define sipNameNr_ScrollMetricCount 32158
#define sipName_ScrollMetricCount &sipStrings_QtWidgets[32158]
#define sipNameNr_SelectPreviousTab 32176
#define sipName_SelectPreviousTab &sipStrings_QtWidgets[32176]
#define sipNameNr_SelectionBehavior 3748
#define sipName_SelectionBehavior &sipStrings_QtWidgets[3748]
#define sipNameNr_SliderPageStepAdd 32194
#define sipName_SliderPageStepAdd &sipStrings_QtWidgets[32194]
#define sipNameNr_SliderPageStepSub 32212
#define sipName_SliderPageStepSub &sipStrings_QtWidgets[32212]
#define sipNameNr_SliderRangeChange 32230
#define sipName_SliderRangeChange &sipStrings_QtWidgets[32230]
#define sipNameNr_SliderStepsChange 32248
#define sipName_SliderStepsChange &sipStrings_QtWidgets[32248]
#define sipNameNr_SliderValueChange 32266
#define sipName_SliderValueChange &sipStrings_QtWidgets[32266]
#define sipNameNr_SnapPositionRatio 32284
#define sipName_SnapPositionRatio &sipStrings_QtWidgets[32284]
#define sipNameNr_SourceInvalidated 32302
#define sipName_SourceInvalidated &sipStrings_QtWidgets[32302]
#define sipNameNr_TimeSections_Mask 32320
#define sipName_TimeSections_Mask &sipStrings_QtWidgets[32320]
#define sipNameNr_ToolButtonFeature 1000
#define sipName_ToolButtonFeature &sipStrings_QtWidgets[1000]
#define sipNameNr_acceptHoverEvents 32338
#define sipName_acceptHoverEvents &sipStrings_QtWidgets[32338]
#define sipNameNr_acceptTouchEvents 32356
#define sipName_acceptTouchEvents &sipStrings_QtWidgets[32356]
#define sipNameNr_accessibleTabName 32374
#define sipName_accessibleTabName &sipStrings_QtWidgets[32374]
#define sipNameNr_activeModalWidget 32392
#define sipName_activeModalWidget &sipStrings_QtWidgets[32392]
#define sipNameNr_activePopupWidget 32410
#define sipName_activePopupWidget &sipStrings_QtWidgets[32410]
#define sipNameNr_activeSubControls 32428
#define sipName_activeSubControls &sipStrings_QtWidgets[32428]
#define sipNameNr_backgroundVisible 32446
#define sipName_backgroundVisible &sipStrings_QtWidgets[32446]
#define sipNameNr_backwardAvailable 32464
#define sipName_backwardAvailable &sipStrings_QtWidgets[32464]
#define sipNameNr_blockBoundingRect 32482
#define sipName_blockBoundingRect &sipStrings_QtWidgets[32482]
#define sipNameNr_blockCountChanged 32500
#define sipName_blockCountChanged &sipStrings_QtWidgets[32500]
#define sipNameNr_blurRadiusChanged 32518
#define sipName_blurRadiusChanged &sipStrings_QtWidgets[32518]
#define sipNameNr_cascadeSubWindows 32536
#define sipName_cascadeSubWindows &sipStrings_QtWidgets[32536]
#define sipNameNr_cellDoubleClicked 32554
#define sipName_cellDoubleClicked &sipStrings_QtWidgets[32554]
#define sipNameNr_checkStateChanged 32572
#define sipName_checkStateChanged &sipStrings_QtWidgets[32572]
#define sipNameNr_contextMenuPolicy 32590
#define sipName_contextMenuPolicy &sipStrings_QtWidgets[32590]
#define sipNameNr_currentCharFormat 32608
#define sipName_currentCharFormat &sipStrings_QtWidgets[32608]
#define sipNameNr_currentCompletion 32626
#define sipName_currentCompletion &sipStrings_QtWidgets[32626]
#define sipNameNr_currentRowChanged 32644
#define sipName_currentRowChanged &sipStrings_QtWidgets[32644]
#define sipNameNr_currentUrlChanged 32662
#define sipName_currentUrlChanged &sipStrings_QtWidgets[32662]
#define sipNameNr_cursorForPosition 32680
#define sipName_cursorForPosition &sipStrings_QtWidgets[32680]
#define sipNameNr_cursorWordForward 32698
#define sipName_cursorWordForward &sipStrings_QtWidgets[32698]
#define sipNameNr_defaultDropAction 32716
#define sipName_defaultDropAction &sipStrings_QtWidgets[32716]
#define sipNameNr_destroySubWindows 32734
#define sipName_destroySubWindows &sipStrings_QtWidgets[32734]
#define sipNameNr_dirtyRegionOffset 32752
#define sipName_dirtyRegionOffset &sipStrings_QtWidgets[32752]
#define sipNameNr_displayedSections 32770
#define sipName_displayedSections &sipStrings_QtWidgets[32770]
#define sipNameNr_duplicatesEnabled 32788
#define sipName_duplicatesEnabled &sipStrings_QtWidgets[32788]
#define sipNameNr_effectiveSizeHint 32806
#define sipName_effectiveSizeHint &sipStrings_QtWidgets[32806]
#define sipNameNr_ensureBlockLayout 32824
#define sipName_ensureBlockLayout &sipStrings_QtWidgets[32824]
#define sipNameNr_expandRecursively 32842
#define sipName_expandRecursively &sipStrings_QtWidgets[32842]
#define sipNameNr_fieldGrowthPolicy 32860
#define sipName_fieldGrowthPolicy &sipStrings_QtWidgets[32860]
#define sipNameNr_firstVisibleBlock 32878
#define sipName_firstVisibleBlock &sipStrings_QtWidgets[32878]
#define sipNameNr_frameBoundingRect 32896
#define sipName_frameBoundingRect &sipStrings_QtWidgets[32896]
#define sipNameNr_geometriesChanged 32914
#define sipName_geometriesChanged &sipStrings_QtWidgets[32914]
#define sipNameNr_getLayoutPosition 32932
#define sipName_getLayoutPosition &sipStrings_QtWidgets[32932]
#define sipNameNr_getWidgetPosition 32950
#define sipName_getWidgetPosition &sipStrings_QtWidgets[32950]
#define sipNameNr_grabKeyboardEvent 27393
#define sipName_grabKeyboardEvent &sipStrings_QtWidgets[27393]
#define sipNameNr_handleEditorEvent 32968
#define sipName_handleEditorEvent &sipStrings_QtWidgets[32968]
#define sipNameNr_hasHeightForWidth 32986
#define sipName_hasHeightForWidth &sipStrings_QtWidgets[32986]
#define sipNameNr_hasScaledContents 33004
#define sipName_hasScaledContents &sipStrings_QtWidgets[33004]
#define sipNameNr_hasTabletTracking 33022
#define sipName_hasTabletTracking &sipStrings_QtWidgets[33022]
#define sipNameNr_hasWidthForHeight 33040
#define sipName_hasWidthForHeight &sipStrings_QtWidgets[33040]
#define sipNameNr_headerDataChanged 33058
#define sipName_headerDataChanged &sipStrings_QtWidgets[33058]
#define sipNameNr_highlightSections 33076
#define sipName_highlightSections &sipStrings_QtWidgets[33076]
#define sipNameNr_horizontalSpacing 33094
#define sipName_horizontalSpacing &sipStrings_QtWidgets[33094]
#define sipNameNr_horizontalStretch 33112
#define sipName_horizontalStretch &sipStrings_QtWidgets[33112]
#define sipNameNr_invisibleRootItem 33130
#define sipName_invisibleRootItem &sipStrings_QtWidgets[33130]
#define sipNameNr_isDateEditEnabled 33148
#define sipName_isDateEditEnabled &sipStrings_QtWidgets[33148]
#define sipNameNr_isSizeGripEnabled 33166
#define sipName_isSizeGripEnabled &sipStrings_QtWidgets[33166]
#define sipNameNr_isUndoRedoEnabled 33184
#define sipName_isUndoRedoEnabled &sipStrings_QtWidgets[33184]
#define sipNameNr_itemDoubleClicked 33202
#define sipName_itemDoubleClicked &sipStrings_QtWidgets[33202]
#define sipNameNr_itemEditorFactory 33220
#define sipName_itemEditorFactory &sipStrings_QtWidgets[33220]
#define sipNameNr_itemsBoundingRect 33238
#define sipName_itemsBoundingRect &sipStrings_QtWidgets[33238]
#define sipNameNr_keyboardModifiers 33256
#define sipName_keyboardModifiers &sipStrings_QtWidgets[33256]
#define sipNameNr_lastRotationAngle 33274
#define sipName_lastRotationAngle &sipStrings_QtWidgets[33274]
#define sipNameNr_mapRectFromParent 33292
#define sipName_mapRectFromParent &sipStrings_QtWidgets[33292]
#define sipNameNr_maximumBlockCount 33310
#define sipName_maximumBlockCount &sipStrings_QtWidgets[33310]
#define sipNameNr_minimumRenderSize 33328
#define sipName_minimumRenderSize &sipStrings_QtWidgets[33328]
#define sipNameNr_mouseReleaseEvent 33346
#define sipName_mouseReleaseEvent &sipStrings_QtWidgets[33346]
#define sipNameNr_openExternalLinks 33364
#define sipName_openExternalLinks &sipStrings_QtWidgets[33364]
#define sipNameNr_optimizationFlags 33382
#define sipName_optimizationFlags &sipStrings_QtWidgets[33382]
#define sipNameNr_qDrawBorderPixmap 33400
#define sipName_qDrawBorderPixmap &sipStrings_QtWidgets[33400]
#define sipNameNr_restoreDockWidget 33418
#define sipName_restoreDockWidget &sipStrings_QtWidgets[33418]
#define sipNameNr_rubberBandChanged 33436
#define sipName_rubberBandChanged &sipStrings_QtWidgets[33436]
#define sipNameNr_sampleTextForFont 33454
#define sipName_sampleTextForFont &sipStrings_QtWidgets[33454]
#define sipNameNr_sceneBoundingRect 33472
#define sipName_sceneBoundingRect &sipStrings_QtWidgets[33472]
#define sipNameNr_scrollDirtyRegion 33490
#define sipName_scrollDirtyRegion &sipStrings_QtWidgets[33490]
#define sipNameNr_scrollGestureType 33508
#define sipName_scrollGestureType &sipStrings_QtWidgets[33508]
#define sipNameNr_sectionResizeMode 33526
#define sipName_sectionResizeMode &sipStrings_QtWidgets[33526]
#define sipNameNr_sectionsClickable 33544
#define sipName_sectionsClickable &sipStrings_QtWidgets[33544]
#define sipNameNr_selectionBehavior 33562
#define sipName_selectionBehavior &sipStrings_QtWidgets[33562]
#define sipNameNr_setAcceptRichText 33580
#define sipName_setAcceptRichText &sipStrings_QtWidgets[33580]
#define sipNameNr_setAccessibleName 33598
#define sipName_setAccessibleName &sipStrings_QtWidgets[33598]
#define sipNameNr_setAutoFormatting 33616
#define sipName_setAutoFormatting &sipStrings_QtWidgets[33616]
#define sipNameNr_setAutoSipEnabled 33634
#define sipName_setAutoSipEnabled &sipStrings_QtWidgets[33634]
#define sipNameNr_setBackgroundRole 33652
#define sipName_setBackgroundRole &sipStrings_QtWidgets[33652]
#define sipNameNr_setCalendarWidget 33670
#define sipName_setCalendarWidget &sipStrings_QtWidgets[33670]
#define sipNameNr_setCenterOnScroll 33688
#define sipName_setCenterOnScroll &sipStrings_QtWidgets[33688]
#define sipNameNr_setCompletionMode 33706
#define sipName_setCompletionMode &sipStrings_QtWidgets[33706]
#define sipNameNr_setCompletionRole 33724
#define sipName_setCompletionRole &sipStrings_QtWidgets[33724]
#define sipNameNr_setCorrectionMode 33742
#define sipName_setCorrectionMode &sipStrings_QtWidgets[33742]
#define sipNameNr_setCurrentSection 33760
#define sipName_setCurrentSection &sipStrings_QtWidgets[33760]
#define sipNameNr_setCursorPosition 33778
#define sipName_setCursorPosition &sipStrings_QtWidgets[33778]
#define sipNameNr_setDateTextFormat 33796
#define sipName_setDateTextFormat &sipStrings_QtWidgets[33796]
#define sipNameNr_setDefaultFactory 33814
#define sipName_setDefaultFactory &sipStrings_QtWidgets[33814]
#define sipNameNr_setDoubleDecimals 33832
#define sipName_setDoubleDecimals &sipStrings_QtWidgets[33832]
#define sipNameNr_setFirstDayOfWeek 33850
#define sipName_setFirstDayOfWeek &sipStrings_QtWidgets[33850]
#define sipNameNr_setForegroundRole 33868
#define sipName_setForegroundRole &sipStrings_QtWidgets[33868]
#define sipNameNr_setGraphicsEffect 33886
#define sipName_setGraphicsEffect &sipStrings_QtWidgets[33886]
#define sipNameNr_setHeightForWidth 33904
#define sipName_setHeightForWidth &sipStrings_QtWidgets[33904]
#define sipNameNr_setLabelAlignment 33922
#define sipName_setLabelAlignment &sipStrings_QtWidgets[33922]
#define sipNameNr_setNotchesVisible 33940
#define sipName_setNotchesVisible &sipStrings_QtWidgets[33940]
#define sipNameNr_setPreferredWidth 33958
#define sipName_setPreferredWidth &sipStrings_QtWidgets[33958]
#define sipNameNr_setRootModelIndex 33976
#define sipName_setRootModelIndex &sipStrings_QtWidgets[33976]
#define sipNameNr_setRowFixedHeight 33994
#define sipName_setRowFixedHeight &sipStrings_QtWidgets[33994]
#define sipNameNr_setScaledContents 34012
#define sipName_setScaledContents &sipStrings_QtWidgets[34012]
#define sipNameNr_setSelectionModel 34030
#define sipName_setSelectionModel &sipStrings_QtWidgets[34030]
#define sipNameNr_setSizeConstraint 34048
#define sipName_setSizeConstraint &sipStrings_QtWidgets[34048]
#define sipNameNr_setSliderPosition 34066
#define sipName_setSliderPosition &sipStrings_QtWidgets[34066]
#define sipNameNr_setSnapPositionsX 34084
#define sipName_setSnapPositionsX &sipStrings_QtWidgets[34084]
#define sipNameNr_setSnapPositionsY 34102
#define sipName_setSnapPositionsY &sipStrings_QtWidgets[34102]
#define sipNameNr_setSortingEnabled 34120
#define sipName_setSortingEnabled &sipStrings_QtWidgets[34120]
#define sipNameNr_setSubTitleFormat 34138
#define sipName_setSubTitleFormat &sipStrings_QtWidgets[34138]
#define sipNameNr_setTabBarAutoHide 34156
#define sipName_setTabBarAutoHide &sipStrings_QtWidgets[34156]
#define sipNameNr_setTabletTracking 34174
#define sipName_setTabletTracking &sipStrings_QtWidgets[34174]
#define sipNameNr_setTearOffEnabled 34192
#define sipName_setTearOffEnabled &sipStrings_QtWidgets[34192]
#define sipNameNr_setTitleBarWidget 34210
#define sipName_setTitleBarWidget &sipStrings_QtWidgets[34210]
#define sipNameNr_setUpdatesEnabled 34228
#define sipName_setUpdatesEnabled &sipStrings_QtWidgets[34228]
#define sipNameNr_setVerticalHeader 34246
#define sipName_setVerticalHeader &sipStrings_QtWidgets[34246]
#define sipNameNr_setVerticalPolicy 34264
#define sipName_setVerticalPolicy &sipStrings_QtWidgets[34264]
#define sipNameNr_setWidthForHeight 34282
#define sipName_setWidthForHeight &sipStrings_QtWidgets[34282]
#define sipNameNr_setWindowFilePath 34300
#define sipName_setWindowFilePath &sipStrings_QtWidgets[34300]
#define sipNameNr_setWindowIconText 34318
#define sipName_setWindowIconText &sipStrings_QtWidgets[34318]
#define sipNameNr_setWindowModality 34336
#define sipName_setWindowModality &sipStrings_QtWidgets[34336]
#define sipNameNr_setWindowModified 34354
#define sipName_setWindowModified &sipStrings_QtWidgets[34354]
#define sipNameNr_showDropIndicator 34372
#define sipName_showDropIndicator &sipStrings_QtWidgets[34372]
#define sipNameNr_showPreviousMonth 34390
#define sipName_showPreviousMonth &sipStrings_QtWidgets[34390]
#define sipNameNr_sizeHintForColumn 34408
#define sipName_sizeHintForColumn &sipStrings_QtWidgets[34408]
#define sipNameNr_smallDecimalPoint 34426
#define sipName_smallDecimalPoint &sipStrings_QtWidgets[34426]
#define sipNameNr_startDragDistance 34444
#define sipName_startDragDistance &sipStrings_QtWidgets[34444]
#define sipNameNr_tabCloseRequested 34462
#define sipName_tabCloseRequested &sipStrings_QtWidgets[34462]
#define sipNameNr_takeCentralWidget 34480
#define sipName_takeCentralWidget &sipStrings_QtWidgets[34480]
#define sipNameNr_textValueSelected 34498
#define sipName_textValueSelected &sipStrings_QtWidgets[34498]
#define sipNameNr_topLevelItemCount 34516
#define sipName_topLevelItemCount &sipStrings_QtWidgets[34516]
#define sipNameNr_uniformRowHeights 34534
#define sipName_uniformRowHeights &sipStrings_QtWidgets[34534]
#define sipNameNr_usesScrollButtons 34552
#define sipName_usesScrollButtons &sipStrings_QtWidgets[34552]
#define sipNameNr_valuePropertyName 34570
#define sipName_valuePropertyName &sipStrings_QtWidgets[34570]
#define sipNameNr_verticalDirection 34588
#define sipName_verticalDirection &sipStrings_QtWidgets[34588]
#define sipNameNr_verticalScrollBar 34606
#define sipName_verticalScrollBar &sipStrings_QtWidgets[34606]
#define sipNameNr_viewportTransform 34624
#define sipName_viewportTransform &sipStrings_QtWidgets[34624]
#define sipNameNr_visibilityChanged 34642
#define sipName_visibilityChanged &sipStrings_QtWidgets[34642]
#define sipNameNr_weekdayTextFormat 34660
#define sipName_weekdayTextFormat &sipStrings_QtWidgets[34660]
#define sipNameNr_windowIconChanged 34678
#define sipName_windowIconChanged &sipStrings_QtWidgets[34678]
#define sipNameNr_ActivationReason 5629
#define sipName_ActivationReason &sipStrings_QtWidgets[5629]
#define sipNameNr_AdjustToContents 34696
#define sipName_AdjustToContents &sipStrings_QtWidgets[34696]
#define sipNameNr_AllowNestedDocks 34713
#define sipName_AllowNestedDocks &sipStrings_QtWidgets[34713]
#define sipNameNr_AllowTabbedDocks 34730
#define sipName_AllowTabbedDocks &sipStrings_QtWidgets[34730]
#define sipNameNr_AnchorUnderMouse 34747
#define sipName_AnchorUnderMouse &sipStrings_QtWidgets[34747]
#define sipNameNr_AnchorViewCenter 34764
#define sipName_AnchorViewCenter &sipStrings_QtWidgets[34764]
#define sipNameNr_BackgroundPixmap 34781
#define sipName_BackgroundPixmap &sipStrings_QtWidgets[34781]
#define sipNameNr_CE_CheckBoxLabel 34798
#define sipName_CE_CheckBoxLabel &sipStrings_QtWidgets[34798]
#define sipNameNr_CE_ComboBoxLabel 34815
#define sipName_CE_ComboBoxLabel &sipStrings_QtWidgets[34815]
#define sipNameNr_CE_HeaderSection 34832
#define sipName_CE_HeaderSection &sipStrings_QtWidgets[34832]
#define sipNameNr_CE_MenuEmptyArea 34849
#define sipName_CE_MenuEmptyArea &sipStrings_QtWidgets[34849]
#define sipNameNr_CE_ScrollBarLast 34866
#define sipName_CE_ScrollBarLast &sipStrings_QtWidgets[34866]
#define sipNameNr_CT_DialogButtons 34883
#define sipName_CT_DialogButtons &sipStrings_QtWidgets[34883]
#define sipNameNr_CT_HeaderSection 34900
#define sipName_CT_HeaderSection &sipStrings_QtWidgets[34900]
#define sipNameNr_ConsumeEventHint 34917
#define sipName_ConsumeEventHint &sipStrings_QtWidgets[34917]
#define sipNameNr_EditPreviousItem 34934
#define sipName_EditPreviousItem &sipStrings_QtWidgets[34934]
#define sipNameNr_FixedColumnWidth 34951
#define sipName_FixedColumnWidth &sipStrings_QtWidgets[34951]
#define sipNameNr_FontDialogOption 8096
#define sipName_FontDialogOption &sipStrings_QtWidgets[8096]
#define sipNameNr_ForceTabbedDocks 34968
#define sipName_ForceTabbedDocks &sipStrings_QtWidgets[34968]
#define sipNameNr_GraphicsItemFlag 6484
#define sipName_GraphicsItemFlag &sipStrings_QtWidgets[6484]
#define sipNameNr_IndependentPages 34985
#define sipName_IndependentPages &sipStrings_QtWidgets[34985]
#define sipNameNr_InlineCompletion 35002
#define sipName_InlineCompletion &sipStrings_QtWidgets[35002]
#define sipNameNr_ItemClipsToShape 35019
#define sipName_ItemClipsToShape &sipStrings_QtWidgets[35019]
#define sipNameNr_ItemCursorChange 35036
#define sipName_ItemCursorChange &sipStrings_QtWidgets[35036]
#define sipNameNr_ItemIsSelectable 35053
#define sipName_ItemIsSelectable &sipStrings_QtWidgets[35053]
#define sipNameNr_ItemParentChange 35070
#define sipName_ItemParentChange &sipStrings_QtWidgets[35070]
#define sipNameNr_ItemZValueChange 35087
#define sipName_ItemZValueChange &sipStrings_QtWidgets[35087]
#define sipNameNr_LabelDrawingMode 9841
#define sipName_LabelDrawingMode &sipStrings_QtWidgets[9841]
#define sipNameNr_LeftCornerWidget 35104
#define sipName_LeftCornerWidget &sipStrings_QtWidgets[35104]
#define sipNameNr_MinimumExpanding 35121
#define sipName_MinimumExpanding &sipStrings_QtWidgets[35121]
#define sipNameNr_NoVerticalHeader 35138
#define sipName_NoVerticalHeader &sipStrings_QtWidgets[35138]
#define sipNameNr_NoViewportUpdate 35155
#define sipName_NoViewportUpdate &sipStrings_QtWidgets[35155]
#define sipNameNr_NonScalableFonts 35172
#define sipName_NonScalableFonts &sipStrings_QtWidgets[35172]
#define sipNameNr_OptimizationFlag 6548
#define sipName_OptimizationFlag &sipStrings_QtWidgets[6548]
#define sipNameNr_PE_FrameGroupBox 35189
#define sipName_PE_FrameGroupBox &sipStrings_QtWidgets[35189]
#define sipNameNr_PE_FrameLineEdit 35206
#define sipName_PE_FrameLineEdit &sipStrings_QtWidgets[35206]
#define sipNameNr_PE_PanelLineEdit 35223
#define sipName_PE_PanelLineEdit &sipStrings_QtWidgets[35223]
#define sipNameNr_PE_PanelTipLabel 35240
#define sipName_PE_PanelTipLabel &sipStrings_QtWidgets[35240]
#define sipNameNr_PM_LargeIconSize 35257
#define sipName_PM_LargeIconSize &sipStrings_QtWidgets[35257]
#define sipNameNr_PM_SmallIconSize 35274
#define sipName_PM_SmallIconSize &sipStrings_QtWidgets[35274]
#define sipNameNr_PM_SplitterWidth 35291
#define sipName_PM_SplitterWidth &sipStrings_QtWidgets[35291]
#define sipNameNr_PositionAtBottom 35308
#define sipName_PositionAtBottom &sipStrings_QtWidgets[35308]
#define sipNameNr_PositionAtCenter 35325
#define sipName_PositionAtCenter &sipStrings_QtWidgets[35325]
#define sipNameNr_PrimitiveElement 13592
#define sipName_PrimitiveElement &sipStrings_QtWidgets[13592]
#define sipNameNr_QAbstractSpinBox 35342
#define sipName_QAbstractSpinBox &sipStrings_QtWidgets[35342]
#define sipNameNr_QDialogButtonBox 35359
#define sipName_QDialogButtonBox &sipStrings_QtWidgets[35359]
#define sipNameNr_QKeySequenceEdit 35376
#define sipName_QKeySequenceEdit &sipStrings_QtWidgets[35376]
#define sipNameNr_QLCDNumber__Mode 35393
#define sipName_QLCDNumber__Mode &sipStrings_QtWidgets[35393]
#define sipNameNr_35410 35410
#define sipName_35410 &sipStrings_QtWidgets[35410]
#define sipNameNr_QScroller__Input 35427
#define sipName_QScroller__Input &sipStrings_QtWidgets[35427]
#define sipNameNr_QScroller__State 35444
#define sipName_QScroller__State &sipStrings_QtWidgets[35444]
#define sipNameNr_QStyleHintReturn 35461
#define sipName_QStyleHintReturn &sipStrings_QtWidgets[35461]
#define sipNameNr_QTableWidgetItem 35478
#define sipName_QTableWidgetItem &sipStrings_QtWidgets[35478]
#define sipNameNr_ResizeToContents 35495
#define sipName_ResizeToContents &sipStrings_QtWidgets[35495]
#define sipNameNr_RevertModelCache 35512
#define sipName_RevertModelCache &sipStrings_QtWidgets[35512]
#define sipNameNr_RubberBandResize 35529
#define sipName_RubberBandResize &sipStrings_QtWidgets[35529]
#define sipNameNr_SC_ComboBoxArrow 35546
#define sipName_SC_ComboBoxArrow &sipStrings_QtWidgets[35546]
#define sipNameNr_SC_ComboBoxFrame 35563
#define sipName_SC_ComboBoxFrame &sipStrings_QtWidgets[35563]
#define sipNameNr_SC_DialTickmarks 35580
#define sipName_SC_DialTickmarks &sipStrings_QtWidgets[35580]
#define sipNameNr_SC_GroupBoxFrame 35597
#define sipName_SC_GroupBoxFrame &sipStrings_QtWidgets[35597]
#define sipNameNr_SC_GroupBoxLabel 35614
#define sipName_SC_GroupBoxLabel &sipStrings_QtWidgets[35614]
#define sipNameNr_SC_ScrollBarLast 35631
#define sipName_SC_ScrollBarLast &sipStrings_QtWidgets[35631]
#define sipNameNr_SC_TitleBarLabel 35648
#define sipName_SC_TitleBarLabel &sipStrings_QtWidgets[35648]
#define sipNameNr_SE_FrameContents 35665
#define sipName_SE_FrameContents &sipStrings_QtWidgets[35665]
#define sipNameNr_SE_TabBarTabText 35682
#define sipName_SE_TabBarTabText &sipStrings_QtWidgets[35682]
#define sipNameNr_SE_ToolBarHandle 35699
#define sipName_SE_ToolBarHandle &sipStrings_QtWidgets[35699]
#define sipNameNr_SP_BrowserReload 35716
#define sipName_SP_BrowserReload &sipStrings_QtWidgets[35716]
#define sipNameNr_SP_DirClosedIcon 35733
#define sipName_SP_DirClosedIcon &sipStrings_QtWidgets[35733]
#define sipNameNr_SP_FileDialogEnd 35750
#define sipName_SP_FileDialogEnd &sipStrings_QtWidgets[35750]
#define sipNameNr_SelectedPosition 3371
#define sipName_SelectedPosition &sipStrings_QtWidgets[3371]
#define sipNameNr_SetMinAndMaxSize 35767
#define sipName_SetMinAndMaxSize &sipStrings_QtWidgets[35767]
#define sipNameNr_ShowAlphaChannel 35784
#define sipName_ShowAlphaChannel &sipStrings_QtWidgets[35784]
#define sipNameNr_SizeAdjustPolicy 2839
#define sipName_SizeAdjustPolicy &sipStrings_QtWidgets[2839]
#define sipNameNr_State_Horizontal 35801
#define sipName_State_Horizontal &sipStrings_QtWidgets[35801]
#define sipNameNr_SubmitModelCache 35818
#define sipName_SubmitModelCache &sipStrings_QtWidgets[35818]
#define sipNameNr_TrailingPosition 35835
#define sipName_TrailingPosition &sipStrings_QtWidgets[35835]
#define sipNameNr_ViewItemPosition 2647
#define sipName_ViewItemPosition &sipStrings_QtWidgets[2647]
#define sipNameNr_addCornerAnchors 35852
#define sipName_addCornerAnchors &sipStrings_QtWidgets[35852]
#define sipNameNr_addTopLevelItems 35869
#define sipName_addTopLevelItems &sipStrings_QtWidgets[35869]
#define sipNameNr_autoScrollMargin 35886
#define sipName_autoScrollMargin &sipStrings_QtWidgets[35886]
#define sipNameNr_blurHintsChanged 35903
#define sipName_blurHintsChanged &sipStrings_QtWidgets[35903]
#define sipNameNr_cancelButtonText 35920
#define sipName_cancelButtonText &sipStrings_QtWidgets[35920]
#define sipNameNr_canceledGestures 35937
#define sipName_canceledGestures &sipStrings_QtWidgets[35937]
#define sipNameNr_clearMaximumDate 35954
#define sipName_clearMaximumDate &sipStrings_QtWidgets[35954]
#define sipNameNr_clearMaximumTime 35971
#define sipName_clearMaximumTime &sipStrings_QtWidgets[35971]
#define sipNameNr_clearMinimumDate 35988
#define sipName_clearMinimumDate &sipStrings_QtWidgets[35988]
#define sipNameNr_clearMinimumTime 36005
#define sipName_clearMinimumTime &sipStrings_QtWidgets[36005]
#define sipNameNr_collidesWithItem 36022
#define sipName_collidesWithItem &sipStrings_QtWidgets[36022]
#define sipNameNr_collidesWithPath 36039
#define sipName_collidesWithPath &sipStrings_QtWidgets[36039]
#define sipNameNr_completionColumn 36056
#define sipName_completionColumn &sipStrings_QtWidgets[36056]
#define sipNameNr_completionPrefix 36073
#define sipName_completionPrefix &sipStrings_QtWidgets[36073]
#define sipNameNr_contextMenuEvent 36090
#define sipName_contextMenuEvent &sipStrings_QtWidgets[36090]
#define sipNameNr_currentIdChanged 36107
#define sipName_currentIdChanged &sipStrings_QtWidgets[36107]
#define sipNameNr_currentSubWindow 36124
#define sipName_currentSubWindow &sipStrings_QtWidgets[36124]
#define sipNameNr_cursorPositionAt 36141
#define sipName_cursorPositionAt &sipStrings_QtWidgets[36141]
#define sipNameNr_dateTimeFromText 36158
#define sipName_dateTimeFromText &sipStrings_QtWidgets[36158]
#define sipNameNr_defaultAlignment 36175
#define sipName_defaultAlignment &sipStrings_QtWidgets[36175]
#define sipNameNr_defaultTextColor 36192
#define sipName_defaultTextColor &sipStrings_QtWidgets[36192]
#define sipNameNr_destroyItemGroup 36209
#define sipName_destroyItemGroup &sipStrings_QtWidgets[36209]
#define sipNameNr_destroyOldWindow 36226
#define sipName_destroyOldWindow &sipStrings_QtWidgets[36226]
#define sipNameNr_directoryEntered 36243
#define sipName_directoryEntered &sipStrings_QtWidgets[36243]
#define sipNameNr_disconnectNotify 36260
#define sipName_disconnectNotify &sipStrings_QtWidgets[36260]
#define sipNameNr_displayAlignment 36277
#define sipName_displayAlignment &sipStrings_QtWidgets[36277]
#define sipNameNr_drawInlineObject 36294
#define sipName_drawInlineObject &sipStrings_QtWidgets[36294]
#define sipNameNr_effectiveOpacity 36311
#define sipName_effectiveOpacity &sipStrings_QtWidgets[36311]
#define sipNameNr_focusItemChanged 36328
#define sipName_focusItemChanged &sipStrings_QtWidgets[36328]
#define sipNameNr_forwardAvailable 36345
#define sipName_forwardAvailable &sipStrings_QtWidgets[36345]
#define sipNameNr_getMultiLineText 36362
#define sipName_getMultiLineText &sipStrings_QtWidgets[36362]
#define sipNameNr_getOpenFileNames 36379
#define sipName_getOpenFileNames &sipStrings_QtWidgets[36379]
#define sipNameNr_hasMouseTracking 36396
#define sipName_hasMouseTracking &sipStrings_QtWidgets[36396]
#define sipNameNr_headerTextFormat 36413
#define sipName_headerTextFormat &sipStrings_QtWidgets[36413]
#define sipNameNr_horizontalHeader 36430
#define sipName_horizontalHeader &sipStrings_QtWidgets[36430]
#define sipNameNr_horizontalOffset 36447
#define sipName_horizontalOffset &sipStrings_QtWidgets[36447]
#define sipNameNr_horizontalPolicy 36464
#define sipName_horizontalPolicy &sipStrings_QtWidgets[36464]
#define sipNameNr_indexRowSizeHint 36481
#define sipName_indexRowSizeHint &sipStrings_QtWidgets[36481]
#define sipNameNr_initializeColumn 36498
#define sipName_initializeColumn &sipStrings_QtWidgets[36498]
#define sipNameNr_initializeWindow 36515
#define sipName_initializeWindow &sipStrings_QtWidgets[36515]
#define sipNameNr_inputMethodEvent 36532
#define sipName_inputMethodEvent &sipStrings_QtWidgets[36532]
#define sipNameNr_inputMethodHints 36549
#define sipName_inputMethodHints &sipStrings_QtWidgets[36549]
#define sipNameNr_inputMethodQuery 36566
#define sipName_inputMethodQuery &sipStrings_QtWidgets[36566]
#define sipNameNr_insertSpacerItem 36583
#define sipName_insertSpacerItem &sipStrings_QtWidgets[36583]
#define sipNameNr_intValueSelected 36600
#define sipName_intValueSelected &sipStrings_QtWidgets[36600]
#define sipNameNr_invertedControls 36617
#define sipName_invertedControls &sipStrings_QtWidgets[36617]
#define sipNameNr_isSortingEnabled 36634
#define sipName_isSortingEnabled &sipStrings_QtWidgets[36634]
#define sipNameNr_isTearOffEnabled 36651
#define sipName_isTearOffEnabled &sipStrings_QtWidgets[36651]
#define sipNameNr_isWindowModified 36668
#define sipName_isWindowModified &sipStrings_QtWidgets[36668]
#define sipNameNr_keyboardPageStep 36685
#define sipName_keyboardPageStep &sipStrings_QtWidgets[36685]
#define sipNameNr_keyboardTracking 36702
#define sipName_keyboardTracking &sipStrings_QtWidgets[36702]
#define sipNameNr_labelDrawingMode 36719
#define sipName_labelDrawingMode &sipStrings_QtWidgets[36719]
#define sipNameNr_logicalCacheSize 36736
#define sipName_logicalCacheSize &sipStrings_QtWidgets[36736]
#define sipNameNr_mapRectFromScene 36753
#define sipName_mapRectFromScene &sipStrings_QtWidgets[36753]
#define sipNameNr_mouseGrabberItem 36770
#define sipName_mouseGrabberItem &sipStrings_QtWidgets[36770]
#define sipNameNr_nextInFocusChain 36787
#define sipName_nextInFocusChain &sipStrings_QtWidgets[36787]
#define sipNameNr_paintWindowFrame 36804
#define sipName_paintWindowFrame &sipStrings_QtWidgets[36804]
#define sipNameNr_parentLayoutItem 36821
#define sipName_parentLayoutItem &sipStrings_QtWidgets[36821]
#define sipNameNr_removeCellWidget 36838
#define sipName_removeCellWidget &sipStrings_QtWidgets[36838]
#define sipNameNr_removeDockWidget 36855
#define sipName_removeDockWidget &sipStrings_QtWidgets[36855]
#define sipNameNr_removeItemWidget 36872
#define sipName_removeItemWidget &sipStrings_QtWidgets[36872]
#define sipNameNr_resetIndentation 36889
#define sipName_resetIndentation &sipStrings_QtWidgets[36889]
#define sipNameNr_resourceProvider 36906
#define sipName_resourceProvider &sipStrings_QtWidgets[36906]
#define sipNameNr_rowMaximumHeight 36923
#define sipName_rowMaximumHeight &sipStrings_QtWidgets[36923]
#define sipNameNr_rowMinimumHeight 36940
#define sipName_rowMinimumHeight &sipStrings_QtWidgets[36940]
#define sipNameNr_rowStretchFactor 36957
#define sipName_rowStretchFactor &sipStrings_QtWidgets[36957]
#define sipNameNr_sceneEventFilter 36974
#define sipName_sceneEventFilter &sipStrings_QtWidgets[36974]
#define sipNameNr_sceneRectChanged 36991
#define sipName_sceneRectChanged &sipStrings_QtWidgets[36991]
#define sipNameNr_scrollBarWidgets 37008
#define sipName_scrollBarWidgets &sipStrings_QtWidgets[37008]
#define sipNameNr_scrollContentsBy 37025
#define sipName_scrollContentsBy &sipStrings_QtWidgets[37025]
#define sipNameNr_sectionsInserted 37042
#define sipName_sectionsInserted &sipStrings_QtWidgets[37042]
#define sipNameNr_selectNameFilter 37059
#define sipName_selectNameFilter &sipStrings_QtWidgets[37059]
#define sipNameNr_selectedPosition 37076
#define sipName_selectedPosition &sipStrings_QtWidgets[37076]
#define sipNameNr_selectionChanged 37093
#define sipName_selectionChanged &sipStrings_QtWidgets[37093]
#define sipNameNr_selectionCommand 37110
#define sipName_selectionCommand &sipStrings_QtWidgets[37110]
#define sipNameNr_setAutoExclusive 37127
#define sipName_setAutoExclusive &sipStrings_QtWidgets[37127]
#define sipNameNr_setButtonSymbols 37144
#define sipName_setButtonSymbols &sipStrings_QtWidgets[37144]
#define sipNameNr_setCalendarPopup 37161
#define sipName_setCalendarPopup &sipStrings_QtWidgets[37161]
#define sipNameNr_setCenterButtons 37178
#define sipName_setCenterButtons &sipStrings_QtWidgets[37178]
#define sipNameNr_setCentralWidget 37195
#define sipName_setCentralWidget &sipStrings_QtWidgets[37195]
#define sipNameNr_setColumnSpacing 37212
#define sipName_setColumnSpacing &sipStrings_QtWidgets[37212]
#define sipNameNr_setColumnStretch 37229
#define sipName_setColumnStretch &sipStrings_QtWidgets[37229]
#define sipNameNr_setComboBoxItems 37246
#define sipName_setComboBoxItems &sipStrings_QtWidgets[37246]
#define sipNameNr_setCurrentWidget 37263
#define sipName_setCurrentWidget &sipStrings_QtWidgets[37263]
#define sipNameNr_setDateTimeRange 37280
#define sipName_setDateTimeRange &sipStrings_QtWidgets[37280]
#define sipNameNr_setDefaultAction 37297
#define sipName_setDefaultAction &sipStrings_QtWidgets[37297]
#define sipNameNr_setDefaultButton 37314
#define sipName_setDefaultButton &sipStrings_QtWidgets[37314]
#define sipNameNr_setDefaultSuffix 37331
#define sipName_setDefaultSuffix &sipStrings_QtWidgets[37331]
#define sipNameNr_setDefaultWidget 37348
#define sipName_setDefaultWidget &sipStrings_QtWidgets[37348]
#define sipNameNr_setDisplayFormat 37365
#define sipName_setDisplayFormat &sipStrings_QtWidgets[37365]
#define sipNameNr_setDocumentTitle 37382
#define sipName_setDocumentTitle &sipStrings_QtWidgets[37382]
#define sipNameNr_setDoubleMaximum 37399
#define sipName_setDoubleMaximum &sipStrings_QtWidgets[37399]
#define sipNameNr_setDoubleMinimum 37416
#define sipName_setDoubleMinimum &sipStrings_QtWidgets[37416]
#define sipNameNr_setEffectEnabled 37433
#define sipName_setEffectEnabled &sipStrings_QtWidgets[37433]
#define sipNameNr_setFontPointSize 37450
#define sipName_setFontPointSize &sipStrings_QtWidgets[37450]
#define sipNameNr_setFontUnderline 37467
#define sipName_setFontUnderline &sipStrings_QtWidgets[37467]
#define sipNameNr_setFormAlignment 37484
#define sipName_setFormAlignment &sipStrings_QtWidgets[37484]
#define sipNameNr_setItemAlignment 37501
#define sipName_setItemAlignment &sipStrings_QtWidgets[37501]
#define sipNameNr_setItemPrototype 37518
#define sipName_setItemPrototype &sipStrings_QtWidgets[37518]
#define sipNameNr_setMaximumHeight 37535
#define sipName_setMaximumHeight &sipStrings_QtWidgets[37535]
#define sipNameNr_setMinimumHeight 37552
#define sipName_setMinimumHeight &sipStrings_QtWidgets[37552]
#define sipNameNr_setMouseTracking 37569
#define sipName_setMouseTracking &sipStrings_QtWidgets[37569]
#define sipNameNr_setNativeMenuBar 37586
#define sipName_setNativeMenuBar &sipStrings_QtWidgets[37586]
#define sipNameNr_setOverwriteMode 37603
#define sipName_setOverwriteMode &sipStrings_QtWidgets[37603]
#define sipNameNr_setOwnedByLayout 37620
#define sipName_setOwnedByLayout &sipStrings_QtWidgets[37620]
#define sipNameNr_setPanelModality 37637
#define sipName_setPanelModality &sipStrings_QtWidgets[37637]
#define sipNameNr_setPreferredSize 37654
#define sipName_setPreferredSize &sipStrings_QtWidgets[37654]
#define sipNameNr_setPreviewWidget 37671
#define sipName_setPreviewWidget &sipStrings_QtWidgets[37671]
#define sipNameNr_setRangeSelected 37688
#define sipName_setRangeSelected &sipStrings_QtWidgets[37688]
#define sipNameNr_setRotationAngle 37705
#define sipName_setRotationAngle &sipStrings_QtWidgets[37705]
#define sipNameNr_setRowWrapPolicy 37722
#define sipName_setRowWrapPolicy &sipStrings_QtWidgets[37722]
#define sipNameNr_setSectionHidden 37739
#define sipName_setSectionHidden &sipStrings_QtWidgets[37739]
#define sipNameNr_setSelectionArea 37756
#define sipName_setSelectionArea &sipStrings_QtWidgets[37756]
#define sipNameNr_setSelectionMode 37773
#define sipName_setSelectionMode &sipStrings_QtWidgets[37773]
#define sipNameNr_setSizeIncrement 37790
#define sipName_setSizeIncrement &sipStrings_QtWidgets[37790]
#define sipNameNr_setSortIndicator 37807
#define sipName_setSortIndicator &sipStrings_QtWidgets[37807]
#define sipNameNr_setStandardColor 37824
#define sipName_setStandardColor &sipStrings_QtWidgets[37824]
#define sipNameNr_setStartDragTime 37841
#define sipName_setStartDragTime &sipStrings_QtWidgets[37841]
#define sipNameNr_setStretchFactor 37858
#define sipName_setStretchFactor &sipStrings_QtWidgets[37858]
#define sipNameNr_setTextAlignment 37875
#define sipName_setTextAlignment &sipStrings_QtWidgets[37875]
#define sipNameNr_setTextDirection 37892
#define sipName_setTextDirection &sipStrings_QtWidgets[37892]
#define sipNameNr_setTextElideMode 37909
#define sipName_setTextElideMode &sipStrings_QtWidgets[37909]
#define sipNameNr_setWindowOpacity 37926
#define sipName_setWindowOpacity &sipStrings_QtWidgets[37926]
#define sipNameNr_setWritingSystem 37943
#define sipName_setWritingSystem &sipStrings_QtWidgets[37943]
#define sipNameNr_showPreviousYear 37960
#define sipName_showPreviousYear &sipStrings_QtWidgets[37960]
#define sipNameNr_showSelectedDate 37977
#define sipName_showSelectedDate &sipStrings_QtWidgets[37977]
#define sipNameNr_sizeAdjustPolicy 37994
#define sipName_sizeAdjustPolicy &sipStrings_QtWidgets[37994]
#define sipNameNr_sizeFromContents 38011
#define sipName_sizeFromContents &sipStrings_QtWidgets[38011]
#define sipNameNr_sizeHintForIndex 38028
#define sipName_sizeHintForIndex &sipStrings_QtWidgets[38028]
#define sipNameNr_specialValueText 38045
#define sipName_specialValueText &sipStrings_QtWidgets[38045]
#define sipNameNr_startCenterPoint 38062
#define sipName_startCenterPoint &sipStrings_QtWidgets[38062]
#define sipNameNr_supportedSchemes 38079
#define sipName_supportedSchemes &sipStrings_QtWidgets[38079]
#define sipNameNr_supportsMessages 38096
#define sipName_supportsMessages &sipStrings_QtWidgets[38096]
#define sipNameNr_tabKeyNavigation 38113
#define sipName_tabKeyNavigation &sipStrings_QtWidgets[38113]
#define sipNameNr_tabifyDockWidget 38130
#define sipName_tabifyDockWidget &sipStrings_QtWidgets[38130]
#define sipNameNr_takeTopLevelItem 38147
#define sipName_takeTopLevelItem &sipStrings_QtWidgets[38147]
#define sipNameNr_textFromDateTime 38164
#define sipName_textFromDateTime &sipStrings_QtWidgets[38164]
#define sipNameNr_textValueChanged 38181
#define sipName_textValueChanged &sipStrings_QtWidgets[38181]
#define sipNameNr_toGraphicsObject 38198
#define sipName_toGraphicsObject &sipStrings_QtWidgets[38198]
#define sipNameNr_toggleViewAction 38215
#define sipName_toggleViewAction &sipStrings_QtWidgets[38215]
#define sipNameNr_totalChangeFlags 38232
#define sipName_totalChangeFlags &sipStrings_QtWidgets[38232]
#define sipNameNr_totalMaximumSize 38249
#define sipName_totalMaximumSize &sipStrings_QtWidgets[38249]
#define sipNameNr_totalMinimumSize 38266
#define sipName_totalMinimumSize &sipStrings_QtWidgets[38266]
#define sipNameNr_totalScaleFactor 38283
#define sipName_totalScaleFactor &sipStrings_QtWidgets[38283]
#define sipNameNr_ungrabMouseEvent 38300
#define sipName_ungrabMouseEvent &sipStrings_QtWidgets[38300]
#define sipNameNr_uniformItemSizes 38317
#define sipName_uniformItemSizes &sipStrings_QtWidgets[38317]
#define sipNameNr_updateEditorData 38334
#define sipName_updateEditorData &sipStrings_QtWidgets[38334]
#define sipNameNr_updateGeometries 38351
#define sipName_updateGeometries &sipStrings_QtWidgets[38351]
#define sipNameNr_updateMicroFocus 38368
#define sipName_updateMicroFocus &sipStrings_QtWidgets[38368]
#define sipNameNr_verticalTitleBar 38385
#define sipName_verticalTitleBar &sipStrings_QtWidgets[38385]
#define sipNameNr_viewItemPosition 38402
#define sipName_viewItemPosition &sipStrings_QtWidgets[38402]
#define sipNameNr_viewportSizeHint 38419
#define sipName_viewportSizeHint &sipStrings_QtWidgets[38419]
#define sipNameNr_wheelScrollLines 38436
#define sipName_wheelScrollLines &sipStrings_QtWidgets[38436]
#define sipNameNr_windowFrameEvent 38453
#define sipName_windowFrameEvent &sipStrings_QtWidgets[38453]
#define sipNameNr_AllEditTriggers 38470
#define sipName_AllEditTriggers &sipStrings_QtWidgets[38470]
#define sipNameNr_BackgroundLayer 38486
#define sipName_BackgroundLayer &sipStrings_QtWidgets[38486]
#define sipNameNr_CE_ItemViewItem 38502
#define sipName_CE_ItemViewItem &sipStrings_QtWidgets[38502]
#define sipNameNr_CE_MenuScroller 38518
#define sipName_CE_MenuScroller &sipStrings_QtWidgets[38518]
#define sipNameNr_CT_ItemViewItem 38534
#define sipName_CT_ItemViewItem &sipStrings_QtWidgets[38534]
#define sipNameNr_CacheBackground 38550
#define sipName_CacheBackground &sipStrings_QtWidgets[38550]
#define sipNameNr_CollapsingState 38566
#define sipName_CollapsingState &sipStrings_QtWidgets[38566]
#define sipNameNr_DefaultStepType 38582
#define sipName_DefaultStepType &sipStrings_QtWidgets[38582]
#define sipNameNr_DestructiveRole 38598
#define sipName_DestructiveRole &sipStrings_QtWidgets[38598]
#define sipNameNr_FixedPixelWidth 38614
#define sipName_FixedPixelWidth &sipStrings_QtWidgets[38614]
#define sipNameNr_ForegroundLayer 38630
#define sipName_ForegroundLayer &sipStrings_QtWidgets[38630]
#define sipNameNr_GroupedDragging 38646
#define sipName_GroupedDragging &sipStrings_QtWidgets[38646]
#define sipNameNr_IgnoreSubTitles 38662
#define sipName_IgnoreSubTitles &sipStrings_QtWidgets[38662]
#define sipNameNr_InsertAtCurrent 38678
#define sipName_InsertAtCurrent &sipStrings_QtWidgets[38678]
#define sipNameNr_ItemFlagsChange 38694
#define sipName_ItemFlagsChange &sipStrings_QtWidgets[38694]
#define sipNameNr_ItemIndexMethod 6517
#define sipName_ItemIndexMethod &sipStrings_QtWidgets[6517]
#define sipNameNr_ItemIsFocusable 38710
#define sipName_ItemIsFocusable &sipStrings_QtWidgets[38710]
#define sipNameNr_ItemScaleChange 38726
#define sipName_ItemScaleChange &sipStrings_QtWidgets[38726]
#define sipNameNr_ItemSceneChange 38742
#define sipName_ItemSceneChange &sipStrings_QtWidgets[38742]
#define sipNameNr_LeadingPosition 38758
#define sipName_LeadingPosition &sipStrings_QtWidgets[38758]
#define sipNameNr_MaximumVelocity 38774
#define sipName_MaximumVelocity &sipStrings_QtWidgets[38774]
#define sipNameNr_MenuButtonPopup 38790
#define sipName_MenuButtonPopup &sipStrings_QtWidgets[38790]
#define sipNameNr_MinimumSizeHint 38806
#define sipName_MinimumSizeHint &sipStrings_QtWidgets[38806]
#define sipNameNr_MinimumVelocity 38822
#define sipName_MinimumVelocity &sipStrings_QtWidgets[38822]
#define sipNameNr_MonospacedFonts 38838
#define sipName_MonospacedFonts &sipStrings_QtWidgets[38838]
#define sipNameNr_NoCornerWidgets 38854
#define sipName_NoCornerWidgets &sipStrings_QtWidgets[38854]
#define sipNameNr_NoDefaultButton 38870
#define sipName_NoDefaultButton &sipStrings_QtWidgets[38870]
#define sipNameNr_OvershootPolicy 3824
#define sipName_OvershootPolicy &sipStrings_QtWidgets[3824]
#define sipNameNr_PE_PanelMenuBar 38886
#define sipName_PE_PanelMenuBar &sipStrings_QtWidgets[38886]
#define sipNameNr_PE_PanelToolBar 38902
#define sipName_PE_PanelToolBar &sipStrings_QtWidgets[38902]
#define sipNameNr_PM_ButtonMargin 38918
#define sipName_PM_ButtonMargin &sipStrings_QtWidgets[38918]
#define sipNameNr_PM_HeaderMargin 38934
#define sipName_PM_HeaderMargin &sipStrings_QtWidgets[38934]
#define sipNameNr_PM_SizeGripSize 38950
#define sipName_PM_SizeGripSize &sipStrings_QtWidgets[38950]
#define sipNameNr_PM_SliderLength 38966
#define sipName_PM_SliderLength &sipStrings_QtWidgets[38966]
#define sipNameNr_PerformanceHint 38982
#define sipName_PerformanceHint &sipStrings_QtWidgets[38982]
#define sipNameNr_PopupCompletion 12604
#define sipName_PopupCompletion &sipStrings_QtWidgets[12604]
#define sipNameNr_PyQt6_QtWidgets 38998
#define sipName_PyQt6_QtWidgets &sipStrings_QtWidgets[38998]
#define sipNameNr_QAbstractButton 39014
#define sipName_QAbstractButton &sipStrings_QtWidgets[39014]
#define sipNameNr_QAbstractSlider 39030
#define sipName_QAbstractSlider &sipStrings_QtWidgets[39030]
#define sipNameNr_QCalendarWidget 39046
#define sipName_QCalendarWidget &sipStrings_QtWidgets[39046]
#define sipNameNr_QGraphicsAnchor 39062
#define sipName_QGraphicsAnchor &sipStrings_QtWidgets[39062]
#define sipNameNr_QGraphicsEffect 39078
#define sipName_QGraphicsEffect &sipStrings_QtWidgets[39078]
#define sipNameNr_QGraphicsLayout 39094
#define sipName_QGraphicsLayout &sipStrings_QtWidgets[39094]
#define sipNameNr_QGraphicsObject 39110
#define sipName_QGraphicsObject &sipStrings_QtWidgets[39110]
#define sipNameNr_QGraphicsWidget 39126
#define sipName_QGraphicsWidget &sipStrings_QtWidgets[39126]
#define sipNameNr_39142 39142
#define sipName_39142 &sipStrings_QtWidgets[39142]
#define sipNameNr_QListView__Flow 39158
#define sipName_QListView__Flow &sipStrings_QtWidgets[39158]
#define sipNameNr_QListWidgetItem 39174
#define sipName_QListWidgetItem &sipStrings_QtWidgets[39174]
#define sipNameNr_QProgressDialog 39190
#define sipName_QProgressDialog &sipStrings_QtWidgets[39190]
#define sipNameNr_QSplitterHandle 39206
#define sipName_QSplitterHandle &sipStrings_QtWidgets[39206]
#define sipNameNr_QStyleOptionTab 39222
#define sipName_QStyleOptionTab &sipStrings_QtWidgets[39222]
#define sipNameNr_QSystemTrayIcon 39238
#define sipName_QSystemTrayIcon &sipStrings_QtWidgets[39238]
#define sipNameNr_QTreeWidgetItem 39254
#define sipName_QTreeWidgetItem &sipStrings_QtWidgets[39254]
#define sipNameNr_QWIDGETSIZE_MAX 39270
#define sipName_QWIDGETSIZE_MAX &sipStrings_QtWidgets[39270]
#define sipNameNr_RestoreDefaults 39286
#define sipName_RestoreDefaults &sipStrings_QtWidgets[39286]
#define sipNameNr_SC_MdiMinButton 39302
#define sipName_SC_MdiMinButton &sipStrings_QtWidgets[39302]
#define sipNameNr_SC_SliderGroove 39318
#define sipName_SC_SliderGroove &sipStrings_QtWidgets[39318]
#define sipNameNr_SC_SliderHandle 39334
#define sipName_SC_SliderHandle &sipStrings_QtWidgets[39334]
#define sipNameNr_SC_SpinBoxFrame 39350
#define sipName_SC_SpinBoxFrame &sipStrings_QtWidgets[39350]
#define sipNameNr_SH_ToolTip_Mask 39366
#define sipName_SH_ToolTip_Mask &sipStrings_QtWidgets[39366]
#define sipNameNr_SO_GraphicsItem 39382
#define sipName_SO_GraphicsItem &sipStrings_QtWidgets[39382]
#define sipNameNr_SP_ArrowForward 39398
#define sipName_SP_ArrowForward &sipStrings_QtWidgets[39398]
#define sipNameNr_SP_ComputerIcon 39414
#define sipName_SP_ComputerIcon &sipStrings_QtWidgets[39414]
#define sipNameNr_SP_DriveDVDIcon 39430
#define sipName_SP_DriveDVDIcon &sipStrings_QtWidgets[39430]
#define sipNameNr_SP_DriveNetIcon 39446
#define sipName_SP_DriveNetIcon &sipStrings_QtWidgets[39446]
#define sipNameNr_SP_FileLinkIcon 39462
#define sipName_SP_FileLinkIcon &sipStrings_QtWidgets[39462]
#define sipNameNr_SectionPosition 4447
#define sipName_SectionPosition &sipStrings_QtWidgets[4447]
#define sipNameNr_SelectedClicked 39478
#define sipName_SelectedClicked &sipStrings_QtWidgets[39478]
#define sipNameNr_SetNoConstraint 39494
#define sipName_SetNoConstraint &sipStrings_QtWidgets[39494]
#define sipNameNr_SingleSelection 39510
#define sipName_SingleSelection &sipStrings_QtWidgets[39510]
#define sipNameNr_SliderToMaximum 39526
#define sipName_SliderToMaximum &sipStrings_QtWidgets[39526]
#define sipNameNr_SliderToMinimum 39542
#define sipName_SliderToMinimum &sipStrings_QtWidgets[39542]
#define sipNameNr_State_AutoRaise 39558
#define sipName_State_AutoRaise &sipStrings_QtWidgets[39558]
#define sipNameNr_State_DownArrow 39574
#define sipName_State_DownArrow &sipStrings_QtWidgets[39574]
#define sipNameNr_State_MouseOver 39590
#define sipName_State_MouseOver &sipStrings_QtWidgets[39590]
#define sipNameNr_StepDownEnabled 39606
#define sipName_StepDownEnabled &sipStrings_QtWidgets[39606]
#define sipNameNr_StepEnabledFlag 5222
#define sipName_StepEnabledFlag &sipStrings_QtWidgets[5222]
#define sipNameNr_StyleOptionType 489
#define sipName_StyleOptionType &sipStrings_QtWidgets[489]
#define sipNameNr_SubWindowOption 7365
#define sipName_SubWindowOption &sipStrings_QtWidgets[7365]
#define sipNameNr_ToolBarPosition 4046
#define sipName_ToolBarPosition &sipStrings_QtWidgets[4046]
#define sipNameNr_TriangularNorth 39622
#define sipName_TriangularNorth &sipStrings_QtWidgets[39622]
#define sipNameNr_TriangularSouth 39638
#define sipName_TriangularSouth &sipStrings_QtWidgets[39638]
#define sipNameNr_ViewItemFeature 3448
#define sipName_ViewItemFeature &sipStrings_QtWidgets[3448]
#define sipNameNr_WatermarkPixmap 14541
#define sipName_WatermarkPixmap &sipStrings_QtWidgets[14541]
#define sipNameNr_aboutToActivate 39654
#define sipName_aboutToActivate &sipStrings_QtWidgets[39654]
#define sipNameNr_actionTriggered 39670
#define sipName_actionTriggered &sipStrings_QtWidgets[39670]
#define sipNameNr_activationOrder 39686
#define sipName_activationOrder &sipStrings_QtWidgets[39686]
#define sipNameNr_activeScrollers 39702
#define sipName_activeScrollers &sipStrings_QtWidgets[39702]
#define sipNameNr_activeSubWindow 39718
#define sipName_activeSubWindow &sipStrings_QtWidgets[39718]
#define sipNameNr_addToolBarBreak 39734
#define sipName_addToolBarBreak &sipStrings_QtWidgets[39734]
#define sipNameNr_addTopLevelItem 39750
#define sipName_addTopLevelItem &sipStrings_QtWidgets[39750]
#define sipNameNr_appendPlainText 39766
#define sipName_appendPlainText &sipStrings_QtWidgets[39766]
#define sipNameNr_autoExpandDelay 39782
#define sipName_autoExpandDelay &sipStrings_QtWidgets[39782]
#define sipNameNr_autoRepeatDelay 39798
#define sipName_autoRepeatDelay &sipStrings_QtWidgets[39798]
#define sipNameNr_backgroundBrush 39814
#define sipName_backgroundBrush &sipStrings_QtWidgets[39814]
#define sipNameNr_backgroundColor 39830
#define sipName_backgroundColor &sipStrings_QtWidgets[39830]
#define sipNameNr_boundingRectFor 39846
#define sipName_boundingRectFor &sipStrings_QtWidgets[39846]
#define sipNameNr_caseSensitivity 39862
#define sipName_caseSensitivity &sipStrings_QtWidgets[39862]
#define sipNameNr_closeAllWindows 39878
#define sipName_closeAllWindows &sipStrings_QtWidgets[39878]
#define sipNameNr_columnAlignment 39894
#define sipName_columnAlignment &sipStrings_QtWidgets[39894]
#define sipNameNr_completeChanged 39910
#define sipName_completeChanged &sipStrings_QtWidgets[39910]
#define sipNameNr_completionCount 39926
#define sipName_completionCount &sipStrings_QtWidgets[39926]
#define sipNameNr_completionModel 39942
#define sipName_completionModel &sipStrings_QtWidgets[39942]
#define sipNameNr_contentsMargins 39958
#define sipName_contentsMargins &sipStrings_QtWidgets[39958]
#define sipNameNr_createItemGroup 39974
#define sipName_createItemGroup &sipStrings_QtWidgets[39974]
#define sipNameNr_createPopupMenu 39990
#define sipName_createPopupMenu &sipStrings_QtWidgets[39990]
#define sipNameNr_cursorFlashTime 40006
#define sipName_cursorFlashTime &sipStrings_QtWidgets[40006]
#define sipNameNr_cursorMoveStyle 40022
#define sipName_cursorMoveStyle &sipStrings_QtWidgets[40022]
#define sipNameNr_dateTimeChanged 40038
#define sipName_dateTimeChanged &sipStrings_QtWidgets[40038]
#define sipNameNr_deviceTransform 40054
#define sipName_deviceTransform &sipStrings_QtWidgets[40054]
#define sipNameNr_documentChanged 40070
#define sipName_documentChanged &sipStrings_QtWidgets[40070]
#define sipNameNr_editTextChanged 40086
#define sipName_editTextChanged &sipStrings_QtWidgets[40086]
#define sipNameNr_editingFinished 40102
#define sipName_editingFinished &sipStrings_QtWidgets[40102]
#define sipNameNr_editorDestroyed 40118
#define sipName_editorDestroyed &sipStrings_QtWidgets[40118]
#define sipNameNr_emitDataChanged 40134
#define sipName_emitDataChanged &sipStrings_QtWidgets[40134]
#define sipNameNr_extraSelections 40150
#define sipName_extraSelections &sipStrings_QtWidgets[40150]
#define sipNameNr_featuresChanged 40166
#define sipName_featuresChanged &sipStrings_QtWidgets[40166]
#define sipNameNr_foregroundBrush 40182
#define sipName_foregroundBrush &sipStrings_QtWidgets[40182]
#define sipNameNr_geometryChanged 40198
#define sipName_geometryChanged &sipStrings_QtWidgets[40198]
#define sipNameNr_getItemPosition 40214
#define sipName_getItemPosition &sipStrings_QtWidgets[40214]
#define sipNameNr_getOpenFileName 40230
#define sipName_getOpenFileName &sipStrings_QtWidgets[40230]
#define sipNameNr_getOpenFileUrls 40246
#define sipName_getOpenFileUrls &sipStrings_QtWidgets[40246]
#define sipNameNr_getPaintContext 40262
#define sipName_getPaintContext &sipStrings_QtWidgets[40262]
#define sipNameNr_getSaveFileName 40278
#define sipName_getSaveFileName &sipStrings_QtWidgets[40278]
#define sipNameNr_hasSelectedText 40294
#define sipName_hasSelectedText &sipStrings_QtWidgets[40294]
#define sipNameNr_hideTearOffMenu 40310
#define sipName_hideTearOffMenu &sipStrings_QtWidgets[40310]
#define sipNameNr_hoverEnterEvent 40326
#define sipName_hoverEnterEvent &sipStrings_QtWidgets[40326]
#define sipNameNr_hoverLeaveEvent 40342
#define sipName_hoverLeaveEvent &sipStrings_QtWidgets[40342]
#define sipNameNr_iconSizeChanged 40358
#define sipName_iconSizeChanged &sipStrings_QtWidgets[40358]
#define sipNameNr_inWhatsThisMode 40374
#define sipName_inWhatsThisMode &sipStrings_QtWidgets[40374]
#define sipNameNr_informativeText 40390
#define sipName_informativeText &sipStrings_QtWidgets[40390]
#define sipNameNr_initStyleOption 40406
#define sipName_initStyleOption &sipStrings_QtWidgets[40406]
#define sipNameNr_insertPlainText 40422
#define sipName_insertPlainText &sipStrings_QtWidgets[40422]
#define sipNameNr_insertSeparator 40438
#define sipName_insertSeparator &sipStrings_QtWidgets[40438]
#define sipNameNr_intValueChanged 40454
#define sipName_intValueChanged &sipStrings_QtWidgets[40454]
#define sipNameNr_invalidateScene 40470
#define sipName_invalidateScene &sipStrings_QtWidgets[40470]
#define sipNameNr_isEffectEnabled 40486
#define sipName_isEffectEnabled &sipStrings_QtWidgets[40486]
#define sipNameNr_isNativeMenuBar 40502
#define sipName_isNativeMenuBar &sipStrings_QtWidgets[40502]
#define sipNameNr_isRedoAvailable 40518
#define sipName_isRedoAvailable &sipStrings_QtWidgets[40518]
#define sipNameNr_isSectionHidden 40534
#define sipName_isSectionHidden &sipStrings_QtWidgets[40534]
#define sipNameNr_isUndoAvailable 40550
#define sipName_isUndoAvailable &sipStrings_QtWidgets[40550]
#define sipNameNr_itemIndexMethod 40566
#define sipName_itemIndexMethod &sipStrings_QtWidgets[40566]
#define sipNameNr_itemsExpandable 40582
#define sipName_itemsExpandable &sipStrings_QtWidgets[40582]
#define sipNameNr_keyReleaseEvent 40598
#define sipName_keyReleaseEvent &sipStrings_QtWidgets[40598]
#define sipNameNr_keyboardGrabber 40614
#define sipName_keyboardGrabber &sipStrings_QtWidgets[40614]
#define sipNameNr_lastCenterPoint 40630
#define sipName_lastCenterPoint &sipStrings_QtWidgets[40630]
#define sipNameNr_lastScaleFactor 40646
#define sipName_lastScaleFactor &sipStrings_QtWidgets[40646]
#define sipNameNr_layoutDirection 40662
#define sipName_layoutDirection &sipStrings_QtWidgets[40662]
#define sipNameNr_mapRectFromItem 40678
#define sipName_mapRectFromItem &sipStrings_QtWidgets[40678]
#define sipNameNr_mapRectToParent 40694
#define sipName_mapRectToParent &sipStrings_QtWidgets[40694]
#define sipNameNr_maxVisibleItems 40710
#define sipName_maxVisibleItems &sipStrings_QtWidgets[40710]
#define sipNameNr_maximumDateTime 40726
#define sipName_maximumDateTime &sipStrings_QtWidgets[40726]
#define sipNameNr_mimeTypeFilters 40742
#define sipName_mimeTypeFilters &sipStrings_QtWidgets[40742]
#define sipNameNr_minimumDateTime 40758
#define sipName_minimumDateTime &sipStrings_QtWidgets[40758]
#define sipNameNr_minimumDuration 40774
#define sipName_minimumDuration &sipStrings_QtWidgets[40774]
#define sipNameNr_minimumSizeHint 40790
#define sipName_minimumSizeHint &sipStrings_QtWidgets[40790]
#define sipNameNr_mousePressEvent 40806
#define sipName_mousePressEvent &sipStrings_QtWidgets[40806]
#define sipNameNr_placeholderText 40822
#define sipName_placeholderText &sipStrings_QtWidgets[40822]
#define sipNameNr_possibleActions 40838
#define sipName_possibleActions &sipStrings_QtWidgets[40838]
#define sipNameNr_preferredHeight 40854
#define sipName_preferredHeight &sipStrings_QtWidgets[40854]
#define sipNameNr_qDrawShadePanel 40870
#define sipName_qDrawShadePanel &sipStrings_QtWidgets[40870]
#define sipNameNr_releaseKeyboard 40886
#define sipName_releaseKeyboard &sipStrings_QtWidgets[40886]
#define sipNameNr_releaseShortcut 40902
#define sipName_releaseShortcut &sipStrings_QtWidgets[40902]
#define sipNameNr_removeFromGroup 40918
#define sipName_removeFromGroup &sipStrings_QtWidgets[40918]
#define sipNameNr_removeSubWindow 40934
#define sipName_removeSubWindow &sipStrings_QtWidgets[40934]
#define sipNameNr_restoreGeometry 40950
#define sipName_restoreGeometry &sipStrings_QtWidgets[40950]
#define sipNameNr_rightButtonSize 40966
#define sipName_rightButtonSize &sipStrings_QtWidgets[40966]
#define sipNameNr_rootIsDecorated 40982
#define sipName_rootIsDecorated &sipStrings_QtWidgets[40982]
#define sipNameNr_rotationChanged 40998
#define sipName_rotationChanged &sipStrings_QtWidgets[40998]
#define sipNameNr_rowCountChanged 41014
#define sipName_rowCountChanged &sipStrings_QtWidgets[41014]
#define sipNameNr_saveFileContent 41030
#define sipName_saveFileContent &sipStrings_QtWidgets[41030]
#define sipNameNr_sectionPosition 41046
#define sipName_sectionPosition &sipStrings_QtWidgets[41046]
#define sipNameNr_sectionSizeHint 41062
#define sipName_sectionSizeHint &sipStrings_QtWidgets[41062]
#define sipNameNr_sectionsMovable 41078
#define sipName_sectionsMovable &sipStrings_QtWidgets[41078]
#define sipNameNr_selectedIndexes 41094
#define sipName_selectedIndexes &sipStrings_QtWidgets[41094]
#define sipNameNr_selectedTabRect 41110
#define sipName_selectedTabRect &sipStrings_QtWidgets[41110]
#define sipNameNr_selectionLength 41126
#define sipName_selectionLength &sipStrings_QtWidgets[41126]
#define sipNameNr_setAcceleration 41142
#define sipName_setAcceleration &sipStrings_QtWidgets[41142]
#define sipNameNr_setActiveAction 41158
#define sipName_setActiveAction &sipStrings_QtWidgets[41158]
#define sipNameNr_setActiveWindow 41174
#define sipName_setActiveWindow &sipStrings_QtWidgets[41174]
#define sipNameNr_setAllowedAreas 41190
#define sipName_setAllowedAreas &sipStrings_QtWidgets[41190]
#define sipNameNr_setBspTreeDepth 41206
#define sipName_setBspTreeDepth &sipStrings_QtWidgets[41206]
#define sipNameNr_setButtonLayout 41222
#define sipName_setButtonLayout &sipStrings_QtWidgets[41222]
#define sipNameNr_setCancelButton 41238
#define sipName_setCancelButton &sipStrings_QtWidgets[41238]
#define sipNameNr_setColumnHidden 41254
#define sipName_setColumnHidden &sipStrings_QtWidgets[41254]
#define sipNameNr_setColumnWidths 41270
#define sipName_setColumnWidths &sipStrings_QtWidgets[41270]
#define sipNameNr_setCornerWidget 41286
#define sipName_setCornerWidget &sipStrings_QtWidgets[41286]
#define sipNameNr_setCurrentColor 41302
#define sipName_setCurrentColor &sipStrings_QtWidgets[41302]
#define sipNameNr_setCurrentIndex 41318
#define sipName_setCurrentIndex &sipStrings_QtWidgets[41318]
#define sipNameNr_setDetailedText 41334
#define sipName_setDetailedText &sipStrings_QtWidgets[41334]
#define sipNameNr_setDirectoryUrl 41350
#define sipName_setDirectoryUrl &sipStrings_QtWidgets[41350]
#define sipNameNr_setDockLocation 41366
#define sipName_setDockLocation &sipStrings_QtWidgets[41366]
#define sipNameNr_setDocumentMode 41382
#define sipName_setDocumentMode &sipStrings_QtWidgets[41382]
#define sipNameNr_setDragDropMode 41398
#define sipName_setDragDropMode &sipStrings_QtWidgets[41398]
#define sipNameNr_setEditTriggers 41414
#define sipName_setEditTriggers &sipStrings_QtWidgets[41414]
#define sipNameNr_setEscapeButton 41430
#define sipName_setEscapeButton &sipStrings_QtWidgets[41430]
#define sipNameNr_setFocusOnTouch 41446
#define sipName_setFocusOnTouch &sipStrings_QtWidgets[41446]
#define sipNameNr_setGraphicsItem 41462
#define sipName_setGraphicsItem &sipStrings_QtWidgets[41462]
#define sipNameNr_setHeaderHidden 41478
#define sipName_setHeaderHidden &sipStrings_QtWidgets[41478]
#define sipNameNr_setHeaderLabels 41494
#define sipName_setHeaderLabels &sipStrings_QtWidgets[41494]
#define sipNameNr_setIconProvider 41510
#define sipName_setIconProvider &sipStrings_QtWidgets[41510]
#define sipNameNr_setInsertPolicy 41526
#define sipName_setInsertPolicy &sipStrings_QtWidgets[41526]
#define sipNameNr_setItemDelegate 41542
#define sipName_setItemDelegate &sipStrings_QtWidgets[41542]
#define sipNameNr_setLineWrapMode 41558
#define sipName_setLineWrapMode &sipStrings_QtWidgets[41558]
#define sipNameNr_setMaximumWidth 41574
#define sipName_setMaximumWidth &sipStrings_QtWidgets[41574]
#define sipNameNr_setMidLineWidth 41590
#define sipName_setMidLineWidth &sipStrings_QtWidgets[41590]
#define sipNameNr_setMinimumWidth 41606
#define sipName_setMinimumWidth &sipStrings_QtWidgets[41606]
#define sipNameNr_setModelSorting 41622
#define sipName_setModelSorting &sipStrings_QtWidgets[41622]
#define sipNameNr_setOkButtonText 41638
#define sipName_setOkButtonText &sipStrings_QtWidgets[41638]
#define sipNameNr_setOpaqueResize 41654
#define sipName_setOpaqueResize &sipStrings_QtWidgets[41654]
#define sipNameNr_setOriginCorner 41670
#define sipName_setOriginCorner &sipStrings_QtWidgets[41670]
#define sipNameNr_setRepeatAction 41686
#define sipName_setRepeatAction &sipStrings_QtWidgets[41686]
#define sipNameNr_setResizeAnchor 41702
#define sipName_setResizeAnchor &sipStrings_QtWidgets[41702]
#define sipNameNr_setRowAlignment 41718
#define sipName_setRowAlignment &sipStrings_QtWidgets[41718]
#define sipNameNr_setScrollMetric 41734
#define sipName_setScrollMetric &sipStrings_QtWidgets[41734]
#define sipNameNr_setSegmentStyle 41750
#define sipName_setSegmentStyle &sipStrings_QtWidgets[41750]
#define sipNameNr_setSelectedDate 41766
#define sipName_setSelectedDate &sipStrings_QtWidgets[41766]
#define sipNameNr_setStackingMode 41782
#define sipName_setStackingMode &sipStrings_QtWidgets[41782]
#define sipNameNr_setSubmitPolicy 41798
#define sipName_setSubmitPolicy &sipStrings_QtWidgets[41798]
#define sipNameNr_setTabTextColor 41814
#define sipName_setTabTextColor &sipStrings_QtWidgets[41814]
#define sipNameNr_setTabWhatsThis 41830
#define sipName_setTabWhatsThis &sipStrings_QtWidgets[41830]
#define sipNameNr_setTabsClosable 41846
#define sipName_setTabsClosable &sipStrings_QtWidgets[41846]
#define sipNameNr_setTextEchoMode 41862
#define sipName_setTextEchoMode &sipStrings_QtWidgets[41862]
#define sipNameNr_setTickInterval 41878
#define sipName_setTickInterval &sipStrings_QtWidgets[41878]
#define sipNameNr_setTickPosition 41894
#define sipName_setTickPosition &sipStrings_QtWidgets[41894]
#define sipNameNr_setTreePosition 41910
#define sipName_setTreePosition &sipStrings_QtWidgets[41910]
#define sipNameNr_setWordWrapMode 41926
#define sipName_setWordWrapMode &sipStrings_QtWidgets[41926]
#define sipNameNr_showTearOffMenu 41942
#define sipName_showTearOffMenu &sipStrings_QtWidgets[41942]
#define sipNameNr_sizeHintChanged 41958
#define sipName_sizeHintChanged &sipStrings_QtWidgets[41958]
#define sipNameNr_splitDockWidget 41974
#define sipName_splitDockWidget &sipStrings_QtWidgets[41974]
#define sipNameNr_standardButtons 41990
#define sipName_standardButtons &sipStrings_QtWidgets[41990]
#define sipNameNr_standardPalette 42006
#define sipName_standardPalette &sipStrings_QtWidgets[42006]
#define sipNameNr_strengthChanged 42022
#define sipName_strengthChanged &sipStrings_QtWidgets[42022]
#define sipNameNr_tabChangesFocus 42038
#define sipName_tabChangesFocus &sipStrings_QtWidgets[42038]
#define sipNameNr_tabLayoutChange 42054
#define sipName_tabLayoutChange &sipStrings_QtWidgets[42054]
#define sipNameNr_tabStopDistance 42070
#define sipName_tabStopDistance &sipStrings_QtWidgets[42070]
#define sipNameNr_textHighlighted 42086
#define sipName_textHighlighted &sipStrings_QtWidgets[42086]
#define sipNameNr_toolButtonStyle 42102
#define sipName_toolButtonStyle &sipStrings_QtWidgets[42102]
#define sipNameNr_toolTipDuration 42118
#define sipName_toolTipDuration &sipStrings_QtWidgets[42118]
#define sipNameNr_toolTipsVisible 42134
#define sipName_toolTipsVisible &sipStrings_QtWidgets[42134]
#define sipNameNr_topLevelChanged 42150
#define sipName_topLevelChanged &sipStrings_QtWidgets[42150]
#define sipNameNr_topLevelWidgets 42166
#define sipName_topLevelWidgets &sipStrings_QtWidgets[42166]
#define sipNameNr_transformations 42182
#define sipName_transformations &sipStrings_QtWidgets[42182]
#define sipNameNr_updateSceneRect 42198
#define sipName_updateSceneRect &sipStrings_QtWidgets[42198]
#define sipNameNr_updateThreshold 42214
#define sipName_updateThreshold &sipStrings_QtWidgets[42214]
#define sipNameNr_verticalSpacing 42230
#define sipName_verticalSpacing &sipStrings_QtWidgets[42230]
#define sipNameNr_verticalStretch 42246
#define sipName_verticalStretch &sipStrings_QtWidgets[42246]
#define sipNameNr_viewportEntered 42262
#define sipName_viewportEntered &sipStrings_QtWidgets[42262]
#define sipNameNr_viewportMargins 42278
#define sipName_viewportMargins &sipStrings_QtWidgets[42278]
#define sipNameNr_visualAlignment 42294
#define sipName_visualAlignment &sipStrings_QtWidgets[42294]
#define sipNameNr_widgetForAction 42310
#define sipName_widgetForAction &sipStrings_QtWidgets[42310]
#define sipNameNr_widgetResizable 42326
#define sipName_widgetResizable &sipStrings_QtWidgets[42326]
#define sipNameNr_windowFrameRect 42342
#define sipName_windowFrameRect &sipStrings_QtWidgets[42342]
#define sipNameNr_ActionPosition 12111
#define sipName_ActionPosition &sipStrings_QtWidgets[12111]
#define sipNameNr_AnimatingState 42358
#define sipName_AnimatingState &sipStrings_QtWidgets[42358]
#define sipNameNr_AutoBulletList 42373
#define sipName_AutoBulletList &sipStrings_QtWidgets[42373]
#define sipNameNr_ButtonPosition 8578
#define sipName_ButtonPosition &sipStrings_QtWidgets[8578]
#define sipNameNr_CC_MdiControls 42388
#define sipName_CC_MdiControls &sipStrings_QtWidgets[42388]
#define sipNameNr_CE_HeaderLabel 42403
#define sipName_CE_HeaderLabel &sipStrings_QtWidgets[42403]
#define sipNameNr_CE_MenuBarItem 42418
#define sipName_CE_MenuBarItem &sipStrings_QtWidgets[42418]
#define sipNameNr_CE_MenuHMargin 42433
#define sipName_CE_MenuHMargin &sipStrings_QtWidgets[42433]
#define sipNameNr_CE_MenuTearoff 42448
#define sipName_CE_MenuTearoff &sipStrings_QtWidgets[42448]
#define sipNameNr_CE_MenuVMargin 42463
#define sipName_CE_MenuVMargin &sipStrings_QtWidgets[42463]
#define sipNameNr_CE_ProgressBar 42478
#define sipName_CE_ProgressBar &sipStrings_QtWidgets[42478]
#define sipNameNr_CE_RadioButton 42493
#define sipName_CE_RadioButton &sipStrings_QtWidgets[42493]
#define sipNameNr_CE_ShapedFrame 42508
#define sipName_CE_ShapedFrame &sipStrings_QtWidgets[42508]
#define sipNameNr_CT_MdiControls 42523
#define sipName_CT_MdiControls &sipStrings_QtWidgets[42523]
#define sipNameNr_CT_MenuBarItem 42538
#define sipName_CT_MenuBarItem &sipStrings_QtWidgets[42538]
#define sipNameNr_CT_ProgressBar 42553
#define sipName_CT_ProgressBar &sipStrings_QtWidgets[42553]
#define sipNameNr_CT_RadioButton 42568
#define sipName_CT_RadioButton &sipStrings_QtWidgets[42568]
#define sipNameNr_CompletionMode 10864
#define sipName_CompletionMode &sipStrings_QtWidgets[10864]
#define sipNameNr_ComplexControl 17182
#define sipName_ComplexControl &sipStrings_QtWidgets[17182]
#define sipNameNr_ControlElement 17205
#define sipName_ControlElement &sipStrings_QtWidgets[17205]
#define sipNameNr_CorrectionMode 5867
#define sipName_CorrectionMode &sipStrings_QtWidgets[5867]
#define sipNameNr_CurrentChanged 42583
#define sipName_CurrentChanged &sipStrings_QtWidgets[42583]
#define sipNameNr_EditKeyPressed 42598
#define sipName_EditKeyPressed &sipStrings_QtWidgets[42598]
#define sipNameNr_ExpandingState 42613
#define sipName_ExpandingState &sipStrings_QtWidgets[42613]
#define sipNameNr_ExtraSelection 12189
#define sipName_ExtraSelection &sipStrings_QtWidgets[12189]
#define sipNameNr_HaveHelpButton 42628
#define sipName_HaveHelpButton &sipStrings_QtWidgets[42628]
#define sipNameNr_HintReturnType 5999
#define sipName_HintReturnType &sipStrings_QtWidgets[5999]
#define sipNameNr_ISOWeekNumbers 42643
#define sipName_ISOWeekNumbers &sipStrings_QtWidgets[42643]
#define sipNameNr_InsertAtBottom 42658
#define sipName_InsertAtBottom &sipStrings_QtWidgets[42658]
#define sipNameNr_MultiSelection 42673
#define sipName_MultiSelection &sipStrings_QtWidgets[42673]
#define sipNameNr_NextIsSelected 42688
#define sipName_NextIsSelected &sipStrings_QtWidgets[42688]
#define sipNameNr_NoCancelButton 42703
#define sipName_NoCancelButton &sipStrings_QtWidgets[42703]
#define sipNameNr_NoEditTriggers 42718
#define sipName_NoEditTriggers &sipStrings_QtWidgets[42718]
#define sipNameNr_OnlyOneSection 42733
#define sipName_OnlyOneSection &sipStrings_QtWidgets[42733]
#define sipNameNr_PE_FrameWindow 42748
#define sipName_PE_FrameWindow &sipStrings_QtWidgets[42748]
#define sipNameNr_PM_MenuHMargin 42763
#define sipName_PM_MenuHMargin &sipStrings_QtWidgets[42763]
#define sipNameNr_PM_MenuVMargin 42778
#define sipName_PM_MenuVMargin &sipStrings_QtWidgets[42778]
#define sipNameNr_QDoubleSpinBox 42793
#define sipName_QDoubleSpinBox &sipStrings_QtWidgets[42793]
#define sipNameNr_QFrame__Shadow 42808
#define sipName_QFrame__Shadow &sipStrings_QtWidgets[42808]
#define sipNameNr_QGraphicsScale 42823
#define sipName_QGraphicsScale &sipStrings_QtWidgets[42823]
#define sipNameNr_QGraphicsScene 42838
#define sipName_QGraphicsScene &sipStrings_QtWidgets[42838]
#define sipNameNr_QPlainTextEdit 42853
#define sipName_QPlainTextEdit &sipStrings_QtWidgets[42853]
#define sipNameNr_QStackedLayout 42868
#define sipName_QStackedLayout &sipStrings_QtWidgets[42868]
#define sipNameNr_QStackedWidget 42883
#define sipName_QStackedWidget &sipStrings_QtWidgets[42883]
#define sipNameNr_QTabBar__Shape 42898
#define sipName_QTabBar__Shape &sipStrings_QtWidgets[42898]
#define sipNameNr_RubberBandDrag 42913
#define sipName_RubberBandDrag &sipStrings_QtWidgets[42913]
#define sipNameNr_RubberBandMove 42928
#define sipName_RubberBandMove &sipStrings_QtWidgets[42928]
#define sipNameNr_SC_SpinBoxDown 42943
#define sipName_SC_SpinBoxDown &sipStrings_QtWidgets[42943]
#define sipNameNr_SE_HeaderArrow 42958
#define sipName_SE_HeaderArrow &sipStrings_QtWidgets[42958]
#define sipNameNr_SE_HeaderLabel 42973
#define sipName_SE_HeaderLabel &sipStrings_QtWidgets[42973]
#define sipNameNr_SH_WizardStyle 42988
#define sipName_SH_WizardStyle &sipStrings_QtWidgets[42988]
#define sipNameNr_SO_ProgressBar 43003
#define sipName_SO_ProgressBar &sipStrings_QtWidgets[43003]
#define sipNameNr_SP_BrowserStop 43018
#define sipName_SP_BrowserStop &sipStrings_QtWidgets[43018]
#define sipNameNr_SP_CommandLink 43033
#define sipName_SP_CommandLink &sipStrings_QtWidgets[43033]
#define sipNameNr_SP_DesktopIcon 43048
#define sipName_SP_DesktopIcon &sipStrings_QtWidgets[43048]
#define sipNameNr_SP_DirHomeIcon 43063
#define sipName_SP_DirHomeIcon &sipStrings_QtWidgets[43063]
#define sipNameNr_SP_DirLinkIcon 43078
#define sipName_SP_DirLinkIcon &sipStrings_QtWidgets[43078]
#define sipNameNr_SP_DirOpenIcon 43093
#define sipName_SP_DirOpenIcon &sipStrings_QtWidgets[43093]
#define sipNameNr_SP_DriveCDIcon 43108
#define sipName_SP_DriveCDIcon &sipStrings_QtWidgets[43108]
#define sipNameNr_SP_DriveFDIcon 43123
#define sipName_SP_DriveFDIcon &sipStrings_QtWidgets[43123]
#define sipNameNr_SP_DriveHDIcon 43138
#define sipName_SP_DriveHDIcon &sipStrings_QtWidgets[43138]
#define sipNameNr_SP_MediaVolume 43153
#define sipName_SP_MediaVolume &sipStrings_QtWidgets[43153]
#define sipNameNr_SP_VistaShield 43168
#define sipName_SP_VistaShield &sipStrings_QtWidgets[43168]
#define sipNameNr_ScrollHandDrag 43183
#define sipName_ScrollHandDrag &sipStrings_QtWidgets[43183]
#define sipNameNr_ScrollPerPixel 43198
#define sipName_ScrollPerPixel &sipStrings_QtWidgets[43198]
#define sipNameNr_ScrollingCurve 43213
#define sipName_ScrollingCurve &sipStrings_QtWidgets[43213]
#define sipNameNr_SelectRightTab 43228
#define sipName_SelectRightTab &sipStrings_QtWidgets[43228]
#define sipNameNr_SetMaximumSize 43243
#define sipName_SetMaximumSize &sipStrings_QtWidgets[43243]
#define sipNameNr_SetMinimumSize 43258
#define sipName_SetMinimumSize &sipStrings_QtWidgets[43258]
#define sipNameNr_SizeConstraint 10403
#define sipName_SizeConstraint &sipStrings_QtWidgets[10403]
#define sipNameNr_SliderNoAction 43273
#define sipName_SliderNoAction &sipStrings_QtWidgets[43273]
#define sipNameNr_SourceAttached 43288
#define sipName_SourceAttached &sipStrings_QtWidgets[43288]
#define sipNameNr_SourceDetached 43303
#define sipName_SourceDetached &sipStrings_QtWidgets[43303]
#define sipNameNr_StandardButton 5900
#define sipName_StandardButton &sipStrings_QtWidgets[5900]
#define sipNameNr_StandardPixmap 17228
#define sipName_StandardPixmap &sipStrings_QtWidgets[17228]
#define sipNameNr_State_Children 43318
#define sipName_State_Children &sipStrings_QtWidgets[43318]
#define sipNameNr_State_HasFocus 43333
#define sipName_State_HasFocus &sipStrings_QtWidgets[43333]
#define sipNameNr_State_NoChange 43348
#define sipName_State_NoChange &sipStrings_QtWidgets[43348]
#define sipNameNr_State_ReadOnly 43363
#define sipName_State_ReadOnly &sipStrings_QtWidgets[43363]
#define sipNameNr_State_Selected 43378
#define sipName_State_Selected &sipStrings_QtWidgets[43378]
#define sipNameNr_SwipeDirection 8278
#define sipName_SwipeDirection &sipStrings_QtWidgets[8278]
#define sipNameNr_TicksBothSides 43393
#define sipName_TicksBothSides &sipStrings_QtWidgets[43393]
#define sipNameNr_ToolBarFeature 4592
#define sipName_ToolBarFeature &sipStrings_QtWidgets[4592]
#define sipNameNr_TriangularEast 43408
#define sipName_TriangularEast &sipStrings_QtWidgets[43408]
#define sipNameNr_TriangularWest 43423
#define sipName_TriangularWest &sipStrings_QtWidgets[43423]
#define sipNameNr_TriggerGesture 43438
#define sipName_TriggerGesture &sipStrings_QtWidgets[43438]
#define sipNameNr_ViewportAnchor 8188
#define sipName_ViewportAnchor &sipStrings_QtWidgets[8188]
#define sipNameNr_acceptRichText 43453
#define sipName_acceptRichText &sipStrings_QtWidgets[43453]
#define sipNameNr_accessibleName 43468
#define sipName_accessibleName &sipStrings_QtWidgets[43468]
#define sipNameNr_actionGeometry 43483
#define sipName_actionGeometry &sipStrings_QtWidgets[43483]
#define sipNameNr_activateWindow 43498
#define sipName_activateWindow &sipStrings_QtWidgets[43498]
#define sipNameNr_activeGestures 43513
#define sipName_activeGestures &sipStrings_QtWidgets[43513]
#define sipNameNr_addChildLayout 43528
#define sipName_addChildLayout &sipStrings_QtWidgets[43528]
#define sipNameNr_addChildWidget 43543
#define sipName_addChildWidget &sipStrings_QtWidgets[43543]
#define sipNameNr_autoFormatting 43558
#define sipName_autoFormatting &sipStrings_QtWidgets[43558]
#define sipNameNr_autoSipEnabled 43573
#define sipName_autoSipEnabled &sipStrings_QtWidgets[43573]
#define sipNameNr_backgroundRole 43588
#define sipName_backgroundRole &sipStrings_QtWidgets[43588]
#define sipNameNr_boundingRegion 43603
#define sipName_boundingRegion &sipStrings_QtWidgets[43603]
#define sipNameNr_buttonReleased 43618
#define sipName_buttonReleased &sipStrings_QtWidgets[43618]
#define sipNameNr_calendarWidget 43633
#define sipName_calendarWidget &sipStrings_QtWidgets[43633]
#define sipNameNr_centerOnScroll 43648
#define sipName_centerOnScroll &sipStrings_QtWidgets[43648]
#define sipNameNr_childrenRegion 43663
#define sipName_childrenRegion &sipStrings_QtWidgets[43663]
#define sipNameNr_clearSelection 43678
#define sipName_clearSelection &sipStrings_QtWidgets[43678]
#define sipNameNr_collidingItems 43693
#define sipName_collidingItems &sipStrings_QtWidgets[43693]
#define sipNameNr_completionMode 43708
#define sipName_completionMode &sipStrings_QtWidgets[43708]
#define sipNameNr_completionRole 43723
#define sipName_completionRole &sipStrings_QtWidgets[43723]
#define sipNameNr_correctionMode 43738
#define sipName_correctionMode &sipStrings_QtWidgets[43738]
#define sipNameNr_createdWidgets 43753
#define sipName_createdWidgets &sipStrings_QtWidgets[43753]
#define sipNameNr_currentChanged 43768
#define sipName_currentChanged &sipStrings_QtWidgets[43768]
#define sipNameNr_currentMessage 43783
#define sipName_currentMessage &sipStrings_QtWidgets[43783]
#define sipNameNr_currentSection 43798
#define sipName_currentSection &sipStrings_QtWidgets[43798]
#define sipNameNr_cursorBackward 43813
#define sipName_cursorBackward &sipStrings_QtWidgets[43813]
#define sipNameNr_cursorPosition 43828
#define sipName_cursorPosition &sipStrings_QtWidgets[43828]
#define sipNameNr_dateTextFormat 43843
#define sipName_dateTextFormat &sipStrings_QtWidgets[43843]
#define sipNameNr_decorationSize 43858
#define sipName_decorationSize &sipStrings_QtWidgets[43858]
#define sipNameNr_defaultFactory 43873
#define sipName_defaultFactory &sipStrings_QtWidgets[43873]
#define sipNameNr_dockWidgetArea 43888
#define sipName_dockWidgetArea &sipStrings_QtWidgets[43888]
#define sipNameNr_doubleDecimals 43903
#define sipName_doubleDecimals &sipStrings_QtWidgets[43903]
#define sipNameNr_dragEnterEvent 43918
#define sipName_dragEnterEvent &sipStrings_QtWidgets[43918]
#define sipNameNr_dragLeaveEvent 43933
#define sipName_dragLeaveEvent &sipStrings_QtWidgets[43933]
#define sipNameNr_drawBackground 43948
#define sipName_drawBackground &sipStrings_QtWidgets[43948]
#define sipNameNr_drawDecoration 43963
#define sipName_drawDecoration &sipStrings_QtWidgets[43963]
#define sipNameNr_drawForeground 43978
#define sipName_drawForeground &sipStrings_QtWidgets[43978]
#define sipNameNr_drawItemPixmap 43993
#define sipName_drawItemPixmap &sipStrings_QtWidgets[43993]
#define sipNameNr_effectiveWinId 44008
#define sipName_effectiveWinId &sipStrings_QtWidgets[44008]
#define sipNameNr_enabledChanged 44023
#define sipName_enabledChanged &sipStrings_QtWidgets[44023]
#define sipNameNr_ensurePolished 44038
#define sipName_ensurePolished &sipStrings_QtWidgets[44038]
#define sipNameNr_filterSelected 44053
#define sipName_filterSelected &sipStrings_QtWidgets[44053]
#define sipNameNr_firstDayOfWeek 44068
#define sipName_firstDayOfWeek &sipStrings_QtWidgets[44068]
#define sipNameNr_focusNextChild 44083
#define sipName_focusNextChild &sipStrings_QtWidgets[44083]
#define sipNameNr_foregroundRole 44098
#define sipName_foregroundRole &sipStrings_QtWidgets[44098]
#define sipNameNr_getOpenFileUrl 44113
#define sipName_getOpenFileUrl &sipStrings_QtWidgets[44113]
#define sipNameNr_getSaveFileUrl 44128
#define sipName_getSaveFileUrl &sipStrings_QtWidgets[44128]
#define sipNameNr_grabMouseEvent 38302
#define sipName_grabMouseEvent &sipStrings_QtWidgets[38302]
#define sipNameNr_grabbedGesture 44143
#define sipName_grabbedGesture &sipStrings_QtWidgets[44143]
#define sipNameNr_graphicsEffect 44158
#define sipName_graphicsEffect &sipStrings_QtWidgets[44158]
#define sipNameNr_hasVisitedPage 44173
#define sipName_hasVisitedPage &sipStrings_QtWidgets[44173]
#define sipNameNr_heightForWidth 44188
#define sipName_heightForWidth &sipStrings_QtWidgets[44188]
#define sipNameNr_historyChanged 44203
#define sipName_historyChanged &sipStrings_QtWidgets[44203]
#define sipNameNr_hoverMoveEvent 44218
#define sipName_hoverMoveEvent &sipStrings_QtWidgets[44218]
#define sipNameNr_initializePage 44233
#define sipName_initializePage &sipStrings_QtWidgets[44233]
#define sipNameNr_insertChildren 44248
#define sipName_insertChildren &sipStrings_QtWidgets[44248]
#define sipNameNr_isActiveWindow 44263
#define sipName_isActiveWindow &sipStrings_QtWidgets[44263]
#define sipNameNr_isColumnHidden 44278
#define sipName_isColumnHidden &sipStrings_QtWidgets[44278]
#define sipNameNr_isHeaderHidden 44293
#define sipName_isHeaderHidden &sipStrings_QtWidgets[44293]
#define sipNameNr_itemAtPosition 44308
#define sipName_itemAtPosition &sipStrings_QtWidgets[44308]
#define sipNameNr_itemPixmapRect 44323
#define sipName_itemPixmapRect &sipStrings_QtWidgets[44323]
#define sipNameNr_keyboardSearch 44338
#define sipName_keyboardSearch &sipStrings_QtWidgets[44338]
#define sipNameNr_labelAlignment 44353
#define sipName_labelAlignment &sipStrings_QtWidgets[44353]
#define sipNameNr_leftButtonSize 44368
#define sipName_leftButtonSize &sipStrings_QtWidgets[44368]
#define sipNameNr_logicalIndexAt 44383
#define sipName_logicalIndexAt &sipStrings_QtWidgets[44383]
#define sipNameNr_mapRectToScene 44398
#define sipName_mapRectToScene &sipStrings_QtWidgets[44398]
#define sipNameNr_mappedWidgetAt 44413
#define sipName_mappedWidgetAt &sipStrings_QtWidgets[44413]
#define sipNameNr_messageChanged 44428
#define sipName_messageChanged &sipStrings_QtWidgets[44428]
#define sipNameNr_messageClicked 44443
#define sipName_messageClicked &sipStrings_QtWidgets[44443]
#define sipNameNr_mouseMoveEvent 44458
#define sipName_mouseMoveEvent &sipStrings_QtWidgets[44458]
#define sipNameNr_movableChanged 44473
#define sipName_movableChanged &sipStrings_QtWidgets[44473]
#define sipNameNr_newProxyWidget 44488
#define sipName_newProxyWidget &sipStrings_QtWidgets[44488]
#define sipNameNr_nextCheckState 44503
#define sipName_nextCheckState &sipStrings_QtWidgets[44503]
#define sipNameNr_normalGeometry 44518
#define sipName_normalGeometry &sipStrings_QtWidgets[44518]
#define sipNameNr_notchesVisible 44533
#define sipName_notchesVisible &sipStrings_QtWidgets[44533]
#define sipNameNr_opacityChanged 44548
#define sipName_opacityChanged &sipStrings_QtWidgets[44548]
#define sipNameNr_positionOfLine 44563
#define sipName_positionOfLine &sipStrings_QtWidgets[44563]
#define sipNameNr_preferredWidth 44578
#define sipName_preferredWidth &sipStrings_QtWidgets[44578]
#define sipNameNr_proposedAction 44593
#define sipName_proposedAction &sipStrings_QtWidgets[44593]
#define sipNameNr_qDrawPlainRect 44608
#define sipName_qDrawPlainRect &sipStrings_QtWidgets[44608]
#define sipNameNr_qDrawShadeLine 44623
#define sipName_qDrawShadeLine &sipStrings_QtWidgets[44623]
#define sipNameNr_qDrawShadeRect 44638
#define sipName_qDrawShadeRect &sipStrings_QtWidgets[44638]
#define sipNameNr_qDrawWinButton 44653
#define sipName_qDrawWinButton &sipStrings_QtWidgets[44653]
#define sipNameNr_registerEditor 44668
#define sipName_registerEditor &sipStrings_QtWidgets[44668]
#define sipNameNr_resetTransform 44683
#define sipName_resetTransform &sipStrings_QtWidgets[44683]
#define sipNameNr_resizeSections 44698
#define sipName_resizeSections &sipStrings_QtWidgets[44698]
#define sipNameNr_rootModelIndex 44713
#define sipName_rootModelIndex &sipStrings_QtWidgets[44713]
#define sipNameNr_rubberBandRect 44728
#define sipName_rubberBandRect &sipStrings_QtWidgets[44728]
#define sipNameNr_sceneTransform 44743
#define sipName_sceneTransform &sipStrings_QtWidgets[44743]
#define sipNameNr_scrollToAnchor 44758
#define sipName_scrollToAnchor &sipStrings_QtWidgets[44758]
#define sipNameNr_scrollToBottom 44773
#define sipName_scrollToBottom &sipStrings_QtWidgets[44773]
#define sipNameNr_sectionClicked 44788
#define sipName_sectionClicked &sipStrings_QtWidgets[44788]
#define sipNameNr_sectionEntered 44803
#define sipName_sectionEntered &sipStrings_QtWidgets[44803]
#define sipNameNr_sectionPressed 44818
#define sipName_sectionPressed &sipStrings_QtWidgets[44818]
#define sipNameNr_sectionResized 44833
#define sipName_sectionResized &sipStrings_QtWidgets[44833]
#define sipNameNr_sectionsHidden 44848
#define sipName_sectionsHidden &sipStrings_QtWidgets[44848]
#define sipNameNr_selectedRanges 44863
#define sipName_selectedRanges &sipStrings_QtWidgets[44863]
#define sipNameNr_selectionModel 44878
#define sipName_selectionModel &sipStrings_QtWidgets[44878]
#define sipNameNr_selectionStart 44893
#define sipName_selectionStart &sipStrings_QtWidgets[44893]
#define sipNameNr_setAccelerated 44908
#define sipName_setAccelerated &sipStrings_QtWidgets[44908]
#define sipNameNr_setAcceptDrops 44923
#define sipName_setAcceptDrops &sipStrings_QtWidgets[44923]
#define sipNameNr_setActivePanel 44938
#define sipName_setActivePanel &sipStrings_QtWidgets[44938]
#define sipNameNr_setAutoDefault 44953
#define sipName_setAutoDefault &sipStrings_QtWidgets[44953]
#define sipNameNr_setCenterPoint 44968
#define sipName_setCenterPoint &sipStrings_QtWidgets[44968]
#define sipNameNr_setChangeFlags 44983
#define sipName_setChangeFlags &sipStrings_QtWidgets[44983]
#define sipNameNr_setCollapsible 44998
#define sipName_setCollapsible &sipStrings_QtWidgets[44998]
#define sipNameNr_setColumnCount 45013
#define sipName_setColumnCount &sipStrings_QtWidgets[45013]
#define sipNameNr_setColumnWidth 45028
#define sipName_setColumnWidth &sipStrings_QtWidgets[45028]
#define sipNameNr_setContextMenu 45043
#define sipName_setContextMenu &sipStrings_QtWidgets[45043]
#define sipNameNr_setControlType 45058
#define sipName_setControlType &sipStrings_QtWidgets[45058]
#define sipNameNr_setCurrentCell 45073
#define sipName_setCurrentCell &sipStrings_QtWidgets[45073]
#define sipNameNr_setCurrentFont 45088
#define sipName_setCurrentFont &sipStrings_QtWidgets[45088]
#define sipNameNr_setCurrentItem 45103
#define sipName_setCurrentItem &sipStrings_QtWidgets[45103]
#define sipNameNr_setCurrentPage 45118
#define sipName_setCurrentPage &sipStrings_QtWidgets[45118]
#define sipNameNr_setCurrentText 45133
#define sipName_setCurrentText &sipStrings_QtWidgets[45133]
#define sipNameNr_setCursorWidth 45148
#define sipName_setCursorWidth &sipStrings_QtWidgets[45148]
#define sipNameNr_setCustomColor 45163
#define sipName_setCustomColor &sipStrings_QtWidgets[45163]
#define sipNameNr_setDescription 45178
#define sipName_setDescription &sipStrings_QtWidgets[45178]
#define sipNameNr_setDirtyRegion 45193
#define sipName_setDirtyRegion &sipStrings_QtWidgets[45193]
#define sipNameNr_setDisplayFont 45208
#define sipName_setDisplayFont &sipStrings_QtWidgets[45208]
#define sipNameNr_setDockOptions 45223
#define sipName_setDockOptions &sipStrings_QtWidgets[45223]
#define sipNameNr_setDoubleRange 45238
#define sipName_setDoubleRange &sipStrings_QtWidgets[45238]
#define sipNameNr_setDoubleValue 45253
#define sipName_setDoubleValue &sipStrings_QtWidgets[45253]
#define sipNameNr_setDragEnabled 45268
#define sipName_setDragEnabled &sipStrings_QtWidgets[45268]
#define sipNameNr_setFixedHeight 45283
#define sipName_setFixedHeight &sipStrings_QtWidgets[45283]
#define sipNameNr_setFocusPolicy 45298
#define sipName_setFocusPolicy &sipStrings_QtWidgets[45298]
#define sipNameNr_setFontFilters 45313
#define sipName_setFontFilters &sipStrings_QtWidgets[45313]
#define sipNameNr_setFrameShadow 45328
#define sipName_setFrameShadow &sipStrings_QtWidgets[45328]
#define sipNameNr_setGridVisible 45343
#define sipName_setGridVisible &sipStrings_QtWidgets[45343]
#define sipNameNr_setHandleWidth 45358
#define sipName_setHandleWidth &sipStrings_QtWidgets[45358]
#define sipNameNr_setHeaderLabel 45373
#define sipName_setHeaderLabel &sipStrings_QtWidgets[45373]
#define sipNameNr_setIndentation 36891
#define sipName_setIndentation &sipStrings_QtWidgets[36891]
#define sipNameNr_setIndexWidget 45388
#define sipName_setIndexWidget &sipStrings_QtWidgets[45388]
#define sipNameNr_setInteractive 45403
#define sipName_setInteractive &sipStrings_QtWidgets[45403]
#define sipNameNr_setItemEnabled 45418
#define sipName_setItemEnabled &sipStrings_QtWidgets[45418]
#define sipNameNr_setItemSpacing 45433
#define sipName_setItemSpacing &sipStrings_QtWidgets[45433]
#define sipNameNr_setItemToolTip 45448
#define sipName_setItemToolTip &sipStrings_QtWidgets[45448]
#define sipNameNr_setKeySequence 45463
#define sipName_setKeySequence &sipStrings_QtWidgets[45463]
#define sipNameNr_setMaximumDate 45478
#define sipName_setMaximumDate &sipStrings_QtWidgets[45478]
#define sipNameNr_setMaximumSize 45493
#define sipName_setMaximumSize &sipStrings_QtWidgets[45493]
#define sipNameNr_setMaximumTime 45508
#define sipName_setMaximumTime &sipStrings_QtWidgets[45508]
#define sipNameNr_setMinimumDate 45523
#define sipName_setMinimumDate &sipStrings_QtWidgets[45523]
#define sipNameNr_setMinimumSize 45538
#define sipName_setMinimumSize &sipStrings_QtWidgets[45538]
#define sipNameNr_setMinimumTime 45553
#define sipName_setMinimumTime &sipStrings_QtWidgets[45553]
#define sipNameNr_setModelColumn 45568
#define sipName_setModelColumn &sipStrings_QtWidgets[45568]
#define sipNameNr_setNameFilters 45583
#define sipName_setNameFilters &sipStrings_QtWidgets[45583]
#define sipNameNr_setNoReplayFor 45598
#define sipName_setNoReplayFor &sipStrings_QtWidgets[45598]
#define sipNameNr_setNotchTarget 45613
#define sipName_setNotchTarget &sipStrings_QtWidgets[45613]
#define sipNameNr_setOpacityMask 45628
#define sipName_setOpacityMask &sipStrings_QtWidgets[45628]
#define sipNameNr_setOrientation 45643
#define sipName_setOrientation &sipStrings_QtWidgets[45643]
#define sipNameNr_setRenderHints 45658
#define sipName_setRenderHints &sipStrings_QtWidgets[45658]
#define sipNameNr_setScaleFactor 45673
#define sipName_setScaleFactor &sipStrings_QtWidgets[45673]
#define sipNameNr_setSearchPaths 45688
#define sipName_setSearchPaths &sipStrings_QtWidgets[45688]
#define sipNameNr_setSidebarUrls 45703
#define sipName_setSidebarUrls &sipStrings_QtWidgets[45703]
#define sipNameNr_setStickyFocus 45718
#define sipName_setStickyFocus &sipStrings_QtWidgets[45718]
#define sipNameNr_setTabPosition 45733
#define sipName_setTabPosition &sipStrings_QtWidgets[45733]
#define sipNameNr_setTabsMovable 45748
#define sipName_setTabsMovable &sipStrings_QtWidgets[45748]
#define sipNameNr_setTextMargins 45763
#define sipName_setTextMargins &sipStrings_QtWidgets[45763]
#define sipNameNr_setTextVisible 45778
#define sipName_setTextVisible &sipStrings_QtWidgets[45778]
#define sipNameNr_setTitleFormat 45793
#define sipName_setTitleFormat &sipStrings_QtWidgets[45793]
#define sipNameNr_setWindowFlags 45808
#define sipName_setWindowFlags &sipStrings_QtWidgets[45808]
#define sipNameNr_setWindowState 45823
#define sipName_setWindowState &sipStrings_QtWidgets[45823]
#define sipNameNr_setWindowTitle 45838
#define sipName_setWindowTitle &sipStrings_QtWidgets[45838]
#define sipNameNr_setWizardStyle 45853
#define sipName_setWizardStyle &sipStrings_QtWidgets[45853]
#define sipNameNr_showFullScreen 45868
#define sipName_showFullScreen &sipStrings_QtWidgets[45868]
#define sipNameNr_showSystemMenu 45883
#define sipName_showSystemMenu &sipStrings_QtWidgets[45883]
#define sipNameNr_sizeConstraint 45898
#define sipName_sizeConstraint &sipStrings_QtWidgets[45898]
#define sipNameNr_sizeHintForRow 45913
#define sipName_sizeHintForRow &sipStrings_QtWidgets[45913]
#define sipNameNr_sliderPosition 45928
#define sipName_sliderPosition &sipStrings_QtWidgets[45928]
#define sipNameNr_sliderReleased 45943
#define sipName_sliderReleased &sipStrings_QtWidgets[45943]
#define sipNameNr_sourceIsPixmap 45958
#define sipName_sourceIsPixmap &sipStrings_QtWidgets[45958]
#define sipNameNr_standardButton 45973
#define sipName_standardButton &sipStrings_QtWidgets[45973]
#define sipNameNr_standardPixmap 45988
#define sipName_standardPixmap &sipStrings_QtWidgets[45988]
#define sipNameNr_subControlRect 46003
#define sipName_subControlRect &sipStrings_QtWidgets[46003]
#define sipNameNr_subElementRect 46018
#define sipName_subElementRect &sipStrings_QtWidgets[46018]
#define sipNameNr_subTitleFormat 46033
#define sipName_subTitleFormat &sipStrings_QtWidgets[46033]
#define sipNameNr_tabBarAutoHide 46048
#define sipName_tabBarAutoHide &sipStrings_QtWidgets[46048]
#define sipNameNr_tileSubWindows 46063
#define sipName_tileSubWindows &sipStrings_QtWidgets[46063]
#define sipNameNr_titleBarWidget 46078
#define sipName_titleBarWidget &sipStrings_QtWidgets[46078]
#define sipNameNr_topLevelWidget 46093
#define sipName_topLevelWidget &sipStrings_QtWidgets[46093]
#define sipNameNr_ungrabKeyboard 46108
#define sipName_ungrabKeyboard &sipStrings_QtWidgets[46108]
#define sipNameNr_updateGeometry 46123
#define sipName_updateGeometry &sipStrings_QtWidgets[46123]
#define sipNameNr_updatesEnabled 46138
#define sipName_updatesEnabled &sipStrings_QtWidgets[46138]
#define sipNameNr_verticalHeader 46153
#define sipName_verticalHeader &sipStrings_QtWidgets[46153]
#define sipNameNr_verticalOffset 46168
#define sipName_verticalOffset &sipStrings_QtWidgets[46168]
#define sipNameNr_verticalPolicy 46183
#define sipName_verticalPolicy &sipStrings_QtWidgets[46183]
#define sipNameNr_visibleChanged 46198
#define sipName_visibleChanged &sipStrings_QtWidgets[46198]
#define sipNameNr_visualItemRect 46213
#define sipName_visualItemRect &sipStrings_QtWidgets[46213]
#define sipNameNr_windowFilePath 46228
#define sipName_windowFilePath &sipStrings_QtWidgets[46228]
#define sipNameNr_windowIconText 46243
#define sipName_windowIconText &sipStrings_QtWidgets[46243]
#define sipNameNr_windowModality 46258
#define sipName_windowModality &sipStrings_QtWidgets[46258]
#define sipNameNr_AdjustIgnored 46273
#define sipName_AdjustIgnored &sipStrings_QtWidgets[46273]
#define sipNameNr_AndroidLayout 46287
#define sipName_AndroidLayout &sipStrings_QtWidgets[46287]
#define sipNameNr_AnimatedDocks 46301
#define sipName_AnimatedDocks &sipStrings_QtWidgets[46301]
#define sipNameNr_AnimationHint 46315
#define sipName_AnimationHint &sipStrings_QtWidgets[46315]
#define sipNameNr_AnyKeyPressed 46329
#define sipName_AnyKeyPressed &sipStrings_QtWidgets[46329]
#define sipNameNr_ButtonFeature 1004
#define sipName_ButtonFeature &sipStrings_QtWidgets[1004]
#define sipNameNr_ButtonSymbols 6359
#define sipName_ButtonSymbols &sipStrings_QtWidgets[6359]
#define sipNameNr_CC_CustomBase 46343
#define sipName_CC_CustomBase &sipStrings_QtWidgets[46343]
#define sipNameNr_CC_ToolButton 46357
#define sipName_CC_ToolButton &sipStrings_QtWidgets[46357]
#define sipNameNr_CE_CustomBase 46371
#define sipName_CE_CustomBase &sipStrings_QtWidgets[46371]
#define sipNameNr_CE_FocusFrame 46385
#define sipName_CE_FocusFrame &sipStrings_QtWidgets[46385]
#define sipNameNr_CE_PushButton 46399
#define sipName_CE_PushButton &sipStrings_QtWidgets[46399]
#define sipNameNr_CE_RubberBand 46413
#define sipName_CE_RubberBand &sipStrings_QtWidgets[46413]
#define sipNameNr_CE_ToolBoxTab 46427
#define sipName_CE_ToolBoxTab &sipStrings_QtWidgets[46427]
#define sipNameNr_CT_CustomBase 46441
#define sipName_CT_CustomBase &sipStrings_QtWidgets[46441]
#define sipNameNr_CT_PushButton 46455
#define sipName_CT_PushButton &sipStrings_QtWidgets[46455]
#define sipNameNr_CT_ToolButton 46469
#define sipName_CT_ToolButton &sipStrings_QtWidgets[46469]
#define sipNameNr_CacheModeFlag 8987
#define sipName_CacheModeFlag &sipStrings_QtWidgets[8987]
#define sipNameNr_CancelGesture 46483
#define sipName_CancelGesture &sipStrings_QtWidgets[46483]
#define sipNameNr_CreationOrder 46497
#define sipName_CreationOrder &sipStrings_QtWidgets[46497]
#define sipNameNr_CustomButton1 31262
#define sipName_CustomButton1 &sipStrings_QtWidgets[31262]
#define sipNameNr_CustomButton2 31280
#define sipName_CustomButton2 &sipStrings_QtWidgets[31280]
#define sipNameNr_CustomButton3 31298
#define sipName_CustomButton3 &sipStrings_QtWidgets[31298]
#define sipNameNr_DefaultButton 7491
#define sipName_DefaultButton &sipStrings_QtWidgets[7491]
#define sipNameNr_DoubleClicked 11405
#define sipName_DoubleClicked &sipStrings_QtWidgets[11405]
#define sipNameNr_DraggingState 46511
#define sipName_DraggingState &sipStrings_QtWidgets[46511]
#define sipNameNr_EnsureVisible 46525
#define sipName_EnsureVisible &sipStrings_QtWidgets[46525]
#define sipNameNr_ExistingFiles 46539
#define sipName_ExistingFiles &sipStrings_QtWidgets[46539]
#define sipNameNr_FinishGesture 46553
#define sipName_FinishGesture &sipStrings_QtWidgets[46553]
#define sipNameNr_HasDecoration 46567
#define sipName_HasDecoration &sipStrings_QtWidgets[46567]
#define sipNameNr_ItemIsMovable 46581
#define sipName_ItemIsMovable &sipStrings_QtWidgets[46581]
#define sipNameNr_MinuteSection 46595
#define sipName_MinuteSection &sipStrings_QtWidgets[46595]
#define sipNameNr_NotSelectable 46609
#define sipName_NotSelectable &sipStrings_QtWidgets[46609]
#define sipNameNr_PE_CustomBase 46623
#define sipName_PE_CustomBase &sipStrings_QtWidgets[46623]
#define sipNameNr_PM_CustomBase 46637
#define sipName_PM_CustomBase &sipStrings_QtWidgets[46637]
#define sipNameNr_PanelModality 8958
#define sipName_PanelModality &sipStrings_QtWidgets[8958]
#define sipNameNr_PixmapPadMode 7274
#define sipName_PixmapPadMode &sipStrings_QtWidgets[7274]
#define sipNameNr_PositionAtTop 46651
#define sipName_PositionAtTop &sipStrings_QtWidgets[46651]
#define sipNameNr_QDateTimeEdit 46665
#define sipName_QDateTimeEdit &sipStrings_QtWidgets[46665]
#define sipNameNr_QErrorMessage 46679
#define sipName_QErrorMessage &sipStrings_QtWidgets[46679]
#define sipNameNr_QFontComboBox 46693
#define sipName_QFontComboBox &sipStrings_QtWidgets[46693]
#define sipNameNr_QFrame__Shape 46707
#define sipName_QFrame__Shape &sipStrings_QtWidgets[46707]
#define sipNameNr_QGestureEvent 46721
#define sipName_QGestureEvent &sipStrings_QtWidgets[46721]
#define sipNameNr_QGraphicsItem 46735
#define sipName_QGraphicsItem &sipStrings_QtWidgets[46735]
#define sipNameNr_QGraphicsView 46749
#define sipName_QGraphicsView &sipStrings_QtWidgets[46749]
#define sipNameNr_QItemDelegate 46763
#define sipName_QItemDelegate &sipStrings_QtWidgets[46763]
#define sipNameNr_46777 46777
#define sipName_46777 &sipStrings_QtWidgets[46777]
#define sipNameNr_QMdiSubWindow 46791
#define sipName_QMdiSubWindow &sipStrings_QtWidgets[46791]
#define sipNameNr_QPinchGesture 46805
#define sipName_QPinchGesture &sipStrings_QtWidgets[46805]
#define sipNameNr_QSplashScreen 46819
#define sipName_QSplashScreen &sipStrings_QtWidgets[46819]
#define sipNameNr_QStyleFactory 46833
#define sipName_QStyleFactory &sipStrings_QtWidgets[46833]
#define sipNameNr_QStylePainter 46847
#define sipName_QStylePainter &sipStrings_QtWidgets[46847]
#define sipNameNr_QSwipeGesture 46861
#define sipName_QSwipeGesture &sipStrings_QtWidgets[46861]
#define sipNameNr_QWidgetAction 46875
#define sipName_QWidgetAction &sipStrings_QtWidgets[46875]
#define sipNameNr_RowWrapPolicy 10919
#define sipName_RowWrapPolicy &sipStrings_QtWidgets[10919]
#define sipNameNr_SC_CustomBase 46889
#define sipName_SC_CustomBase &sipStrings_QtWidgets[46889]
#define sipNameNr_SC_DialGroove 46903
#define sipName_SC_DialGroove &sipStrings_QtWidgets[46903]
#define sipNameNr_SC_DialHandle 46917
#define sipName_SC_DialHandle &sipStrings_QtWidgets[46917]
#define sipNameNr_SC_ToolButton 46931
#define sipName_SC_ToolButton &sipStrings_QtWidgets[46931]
#define sipNameNr_SE_CustomBase 46945
#define sipName_SE_CustomBase &sipStrings_QtWidgets[46945]
#define sipNameNr_SH_CustomBase 46959
#define sipName_SH_CustomBase &sipStrings_QtWidgets[46959]
#define sipNameNr_SO_CustomBase 46973
#define sipName_SO_CustomBase &sipStrings_QtWidgets[46973]
#define sipNameNr_SO_DockWidget 46987
#define sipName_SO_DockWidget &sipStrings_QtWidgets[46987]
#define sipNameNr_SO_RubberBand 47001
#define sipName_SO_RubberBand &sipStrings_QtWidgets[47001]
#define sipNameNr_SO_TabBarBase 47015
#define sipName_SO_TabBarBase &sipStrings_QtWidgets[47015]
#define sipNameNr_SO_ToolButton 47029
#define sipName_SO_ToolButton &sipStrings_QtWidgets[47029]
#define sipNameNr_SP_ArrowRight 47043
#define sipName_SP_ArrowRight &sipStrings_QtWidgets[47043]
#define sipNameNr_SP_CustomBase 47057
#define sipName_SP_CustomBase &sipStrings_QtWidgets[47057]
#define sipNameNr_SP_MediaPause 47071
#define sipName_SP_MediaPause &sipStrings_QtWidgets[47071]
#define sipNameNr_ScalableFonts 35175
#define sipName_ScalableFonts &sipStrings_QtWidgets[35175]
#define sipNameNr_ScrollPerItem 47085
#define sipName_ScrollPerItem &sipStrings_QtWidgets[47085]
#define sipNameNr_SecondSection 47099
#define sipName_SecondSection &sipStrings_QtWidgets[47099]
#define sipNameNr_SelectColumns 47113
#define sipName_SelectColumns &sipStrings_QtWidgets[47113]
#define sipNameNr_SelectLeftTab 47127
#define sipName_SelectLeftTab &sipStrings_QtWidgets[47127]
#define sipNameNr_SelectionMode 5835
#define sipName_SelectionMode &sipStrings_QtWidgets[5835]
#define sipNameNr_ShortDayNames 47141
#define sipName_ShortDayNames &sipStrings_QtWidgets[47141]
#define sipNameNr_ShowIndicator 31190
#define sipName_ShowIndicator &sipStrings_QtWidgets[31190]
#define sipNameNr_SortIndicator 5564
#define sipName_SortIndicator &sipStrings_QtWidgets[5564]
#define sipNameNr_StackingOrder 47155
#define sipName_StackingOrder &sipStrings_QtWidgets[47155]
#define sipNameNr_State_Editing 47169
#define sipName_State_Editing &sipStrings_QtWidgets[47169]
#define sipNameNr_State_Enabled 47183
#define sipName_State_Enabled &sipStrings_QtWidgets[47183]
#define sipNameNr_State_Sibling 47197
#define sipName_State_Sibling &sipStrings_QtWidgets[47197]
#define sipNameNr_State_UpArrow 47211
#define sipName_State_UpArrow &sipStrings_QtWidgets[47211]
#define sipNameNr_StepUpEnabled 47225
#define sipName_StepUpEnabled &sipStrings_QtWidgets[47225]
#define sipNameNr_StretchBanner 47239
#define sipName_StretchBanner &sipStrings_QtWidgets[47239]
#define sipNameNr_SubWindowView 47253
#define sipName_SubWindowView &sipStrings_QtWidgets[47253]
#define sipNameNr_TakeRowResult 10946
#define sipName_TakeRowResult &sipStrings_QtWidgets[10946]
#define sipNameNr_UnsortedModel 47267
#define sipName_UnsortedModel &sipStrings_QtWidgets[47267]
#define sipNameNr_addDockWidget 47281
#define sipName_addDockWidget &sipStrings_QtWidgets[47281]
#define sipNameNr_addSimpleText 47295
#define sipName_addSimpleText &sipStrings_QtWidgets[47295]
#define sipNameNr_addSpacerItem 47309
#define sipName_addSpacerItem &sipStrings_QtWidgets[47309]
#define sipNameNr_alignmentRect 47323
#define sipName_alignmentRect &sipStrings_QtWidgets[47323]
#define sipNameNr_anchorClicked 47337
#define sipName_anchorClicked &sipStrings_QtWidgets[47337]
#define sipNameNr_autoExclusive 47351
#define sipName_autoExclusive &sipStrings_QtWidgets[47351]
#define sipNameNr_blockingPanel 47365
#define sipName_blockingPanel &sipStrings_QtWidgets[47365]
#define sipNameNr_buttonClicked 47379
#define sipName_buttonClicked &sipStrings_QtWidgets[47379]
#define sipNameNr_buttonDownPos 47393
#define sipName_buttonDownPos &sipStrings_QtWidgets[47393]
#define sipNameNr_buttonPressed 47407
#define sipName_buttonPressed &sipStrings_QtWidgets[47407]
#define sipNameNr_buttonSymbols 47421
#define sipName_buttonSymbols &sipStrings_QtWidgets[47421]
#define sipNameNr_buttonToggled 47435
#define sipName_buttonToggled &sipStrings_QtWidgets[47435]
#define sipNameNr_calendarPopup 47449
#define sipName_calendarPopup &sipStrings_QtWidgets[47449]
#define sipNameNr_cellActivated 47463
#define sipName_cellActivated &sipStrings_QtWidgets[47463]
#define sipNameNr_centerButtons 47477
#define sipName_centerButtons &sipStrings_QtWidgets[47477]
#define sipNameNr_centralWidget 47491
#define sipName_centralWidget &sipStrings_QtWidgets[47491]
#define sipNameNr_changedSignal 47505
#define sipName_changedSignal &sipStrings_QtWidgets[47505]
#define sipNameNr_checkOverflow 47519
#define sipName_checkOverflow &sipStrings_QtWidgets[47519]
#define sipNameNr_checkStateSet 47533
#define sipName_checkStateSet &sipStrings_QtWidgets[47533]
#define sipNameNr_checkedButton 47547
#define sipName_checkedButton &sipStrings_QtWidgets[47547]
#define sipNameNr_clearContents 47561
#define sipName_clearContents &sipStrings_QtWidgets[47561]
#define sipNameNr_clearEditText 47575
#define sipName_clearEditText &sipStrings_QtWidgets[47575]
#define sipNameNr_clickedButton 47589
#define sipName_clickedButton &sipStrings_QtWidgets[47589]
#define sipNameNr_colorSelected 47603
#define sipName_colorSelected &sipStrings_QtWidgets[47603]
#define sipNameNr_columnResized 47617
#define sipName_columnResized &sipStrings_QtWidgets[47617]
#define sipNameNr_columnSpacing 47631
#define sipName_columnSpacing &sipStrings_QtWidgets[47631]
#define sipNameNr_columnStretch 47645
#define sipName_columnStretch &sipStrings_QtWidgets[47645]
#define sipNameNr_comboBoxItems 47659
#define sipName_comboBoxItems &sipStrings_QtWidgets[47659]
#define sipNameNr_connectNotify 36263
#define sipName_connectNotify &sipStrings_QtWidgets[36263]
#define sipNameNr_contentOffset 47673
#define sipName_contentOffset &sipStrings_QtWidgets[47673]
#define sipNameNr_copyAvailable 47687
#define sipName_copyAvailable &sipStrings_QtWidgets[47687]
#define sipNameNr_cornerWidgets 47701
#define sipName_cornerWidgets &sipStrings_QtWidgets[47701]
#define sipNameNr_currentColumn 47715
#define sipName_currentColumn &sipStrings_QtWidgets[47715]
#define sipNameNr_currentWidget 47729
#define sipName_currentWidget &sipStrings_QtWidgets[47729]
#define sipNameNr_cursorForward 47743
#define sipName_cursorForward &sipStrings_QtWidgets[47743]
#define sipNameNr_defaultAction 47757
#define sipName_defaultAction &sipStrings_QtWidgets[47757]
#define sipNameNr_defaultButton 47771
#define sipName_defaultButton &sipStrings_QtWidgets[47771]
#define sipNameNr_defaultSuffix 47785
#define sipName_defaultSuffix &sipStrings_QtWidgets[47785]
#define sipNameNr_defaultWidget 47799
#define sipName_defaultWidget &sipStrings_QtWidgets[47799]
#define sipNameNr_destroyEditor 47813
#define sipName_destroyEditor &sipStrings_QtWidgets[47813]
#define sipNameNr_destroyWindow 47827
#define sipName_destroyWindow &sipStrings_QtWidgets[47827]
#define sipNameNr_displayFormat 47841
#define sipName_displayFormat &sipStrings_QtWidgets[47841]
#define sipNameNr_documentTitle 47855
#define sipName_documentTitle &sipStrings_QtWidgets[47855]
#define sipNameNr_doubleClicked 47869
#define sipName_doubleClicked &sipStrings_QtWidgets[47869]
#define sipNameNr_doubleMaximum 47883
#define sipName_doubleMaximum &sipStrings_QtWidgets[47883]
#define sipNameNr_doubleMinimum 47897
#define sipName_doubleMinimum &sipStrings_QtWidgets[47897]
#define sipNameNr_dragMoveEvent 47911
#define sipName_dragMoveEvent &sipStrings_QtWidgets[47911]
#define sipNameNr_drawPrimitive 47925
#define sipName_drawPrimitive &sipStrings_QtWidgets[47925]
#define sipNameNr_ensureVisible 47939
#define sipName_ensureVisible &sipStrings_QtWidgets[47939]
#define sipNameNr_expandToDepth 47953
#define sipName_expandToDepth &sipStrings_QtWidgets[47953]
#define sipNameNr_filesSelected 47967
#define sipName_filesSelected &sipStrings_QtWidgets[47967]
#define sipNameNr_finalPosition 47981
#define sipName_finalPosition &sipStrings_QtWidgets[47981]
#define sipNameNr_focusOutEvent 47995
#define sipName_focusOutEvent &sipStrings_QtWidgets[47995]
#define sipNameNr_fontPointSize 48009
#define sipName_fontPointSize &sipStrings_QtWidgets[48009]
#define sipNameNr_fontUnderline 48023
#define sipName_fontUnderline &sipStrings_QtWidgets[48023]
#define sipNameNr_formAlignment 48037
#define sipName_formAlignment &sipStrings_QtWidgets[48037]
#define sipNameNr_frameGeometry 48051
#define sipName_frameGeometry &sipStrings_QtWidgets[48051]
#define sipNameNr_hasAutoScroll 48065
#define sipName_hasAutoScroll &sipStrings_QtWidgets[48065]
#define sipNameNr_helpRequested 48079
#define sipName_helpRequested &sipStrings_QtWidgets[48079]
#define sipNameNr_iconAlignment 48093
#define sipName_iconAlignment &sipStrings_QtWidgets[48093]
#define sipNameNr_indexFromItem 48107
#define sipName_indexFromItem &sipStrings_QtWidgets[48107]
#define sipNameNr_initialFilter 48121
#define sipName_initialFilter &sipStrings_QtWidgets[48121]
#define sipNameNr_inputRejected 48135
#define sipName_inputRejected &sipStrings_QtWidgets[48135]
#define sipNameNr_insertActions 48149
#define sipName_insertActions &sipStrings_QtWidgets[48149]
#define sipNameNr_insertSection 48163
#define sipName_insertSection &sipStrings_QtWidgets[48163]
#define sipNameNr_insertSpacing 48177
#define sipName_insertSpacing &sipStrings_QtWidgets[48177]
#define sipNameNr_insertStretch 48191
#define sipName_insertStretch &sipStrings_QtWidgets[48191]
#define sipNameNr_insertToolBar 48205
#define sipName_insertToolBar &sipStrings_QtWidgets[48205]
#define sipNameNr_interpretText 48219
#define sipName_interpretText &sipStrings_QtWidgets[48219]
#define sipNameNr_isAccelerated 48233
#define sipName_isAccelerated &sipStrings_QtWidgets[48233]
#define sipNameNr_isAreaAllowed 48247
#define sipName_isAreaAllowed &sipStrings_QtWidgets[48247]
#define sipNameNr_isCollapsible 48261
#define sipName_isCollapsible &sipStrings_QtWidgets[48261]
#define sipNameNr_isGridVisible 48275
#define sipName_isGridVisible &sipStrings_QtWidgets[48275]
#define sipNameNr_isIndexHidden 48289
#define sipName_isIndexHidden &sipStrings_QtWidgets[48289]
#define sipNameNr_isInteractive 48303
#define sipName_isInteractive &sipStrings_QtWidgets[48303]
#define sipNameNr_isItemEnabled 48317
#define sipName_isItemEnabled &sipStrings_QtWidgets[48317]
#define sipNameNr_isLeftToRight 48331
#define sipName_isLeftToRight &sipStrings_QtWidgets[48331]
#define sipNameNr_isRightToLeft 48345
#define sipName_isRightToLeft &sipStrings_QtWidgets[48345]
#define sipNameNr_isTextVisible 48359
#define sipName_isTextVisible &sipStrings_QtWidgets[48359]
#define sipNameNr_isTransformed 48373
#define sipName_isTransformed &sipStrings_QtWidgets[48373]
#define sipNameNr_itemActivated 48387
#define sipName_itemActivated &sipStrings_QtWidgets[48387]
#define sipNameNr_itemAlignment 48401
#define sipName_itemAlignment &sipStrings_QtWidgets[48401]
#define sipNameNr_itemCollapsed 48415
#define sipName_itemCollapsed &sipStrings_QtWidgets[48415]
#define sipNameNr_itemFromIndex 48429
#define sipName_itemFromIndex &sipStrings_QtWidgets[48429]
#define sipNameNr_itemPrototype 48443
#define sipName_itemPrototype &sipStrings_QtWidgets[48443]
#define sipNameNr_itemTransform 48457
#define sipName_itemTransform &sipStrings_QtWidgets[48457]
#define sipNameNr_keyPressEvent 48471
#define sipName_keyPressEvent &sipStrings_QtWidgets[48471]
#define sipNameNr_labelForField 48485
#define sipName_labelForField &sipStrings_QtWidgets[48485]
#define sipNameNr_lastScreenPos 48499
#define sipName_lastScreenPos &sipStrings_QtWidgets[48499]
#define sipNameNr_layoutSpacing 48513
#define sipName_layoutSpacing &sipStrings_QtWidgets[48513]
#define sipNameNr_linkActivated 48527
#define sipName_linkActivated &sipStrings_QtWidgets[48527]
#define sipNameNr_mapFromGlobal 48541
#define sipName_mapFromGlobal &sipStrings_QtWidgets[48541]
#define sipNameNr_mapFromParent 48555
#define sipName_mapFromParent &sipStrings_QtWidgets[48555]
#define sipNameNr_mapRectToItem 48569
#define sipName_mapRectToItem &sipStrings_QtWidgets[48569]
#define sipNameNr_mappedSection 48583
#define sipName_mappedSection &sipStrings_QtWidgets[48583]
#define sipNameNr_maximumHeight 48597
#define sipName_maximumHeight &sipStrings_QtWidgets[48597]
#define sipNameNr_minimumHeight 48611
#define sipName_minimumHeight &sipStrings_QtWidgets[48611]
#define sipNameNr_offsetChanged 48625
#define sipName_offsetChanged &sipStrings_QtWidgets[48625]
#define sipNameNr_originChanged 48639
#define sipName_originChanged &sipStrings_QtWidgets[48639]
#define sipNameNr_overwriteMode 48653
#define sipName_overwriteMode &sipStrings_QtWidgets[48653]
#define sipNameNr_ownedByLayout 48667
#define sipName_ownedByLayout &sipStrings_QtWidgets[48667]
#define sipNameNr_panelModality 48681
#define sipName_panelModality &sipStrings_QtWidgets[48681]
#define sipNameNr_parentChanged 48695
#define sipName_parentChanged &sipStrings_QtWidgets[48695]
#define sipNameNr_pathFromIndex 48709
#define sipName_pathFromIndex &sipStrings_QtWidgets[48709]
#define sipNameNr_pixelPerMeter 48723
#define sipName_pixelPerMeter &sipStrings_QtWidgets[48723]
#define sipNameNr_preferredSize 48737
#define sipName_preferredSize &sipStrings_QtWidgets[48737]
#define sipNameNr_previewWidget 48751
#define sipName_previewWidget &sipStrings_QtWidgets[48751]
#define sipNameNr_qDrawWinPanel 48765
#define sipName_qDrawWinPanel &sipStrings_QtWidgets[48765]
#define sipNameNr_redoAvailable 48779
#define sipName_redoAvailable &sipStrings_QtWidgets[48779]
#define sipNameNr_registerField 48793
#define sipName_registerField &sipStrings_QtWidgets[48793]
#define sipNameNr_releaseWidget 48807
#define sipName_releaseWidget &sipStrings_QtWidgets[48807]
#define sipNameNr_removeMapping 48821
#define sipName_removeMapping &sipStrings_QtWidgets[48821]
#define sipNameNr_removeToolBar 48835
#define sipName_removeToolBar &sipStrings_QtWidgets[48835]
#define sipNameNr_replaceWidget 48849
#define sipName_replaceWidget &sipStrings_QtWidgets[48849]
#define sipNameNr_requestUpdate 48863
#define sipName_requestUpdate &sipStrings_QtWidgets[48863]
#define sipNameNr_requestWidget 48877
#define sipName_requestWidget &sipStrings_QtWidgets[48877]
#define sipNameNr_resizeSection 48891
#define sipName_resizeSection &sipStrings_QtWidgets[48891]
#define sipNameNr_returnPressed 48905
#define sipName_returnPressed &sipStrings_QtWidgets[48905]
#define sipNameNr_rotationAngle 48919
#define sipName_rotationAngle &sipStrings_QtWidgets[48919]
#define sipNameNr_rowWrapPolicy 48933
#define sipName_rowWrapPolicy &sipStrings_QtWidgets[48933]
#define sipNameNr_sectionsMoved 48947
#define sipName_sectionsMoved &sipStrings_QtWidgets[48947]
#define sipNameNr_selectedColor 48961
#define sipName_selectedColor &sipStrings_QtWidgets[48961]
#define sipNameNr_selectedFiles 48975
#define sipName_selectedFiles &sipStrings_QtWidgets[48975]
#define sipNameNr_selectedItems 48989
#define sipName_selectedItems &sipStrings_QtWidgets[48989]
#define sipNameNr_selectionArea 49003
#define sipName_selectionArea &sipStrings_QtWidgets[49003]
#define sipNameNr_selectionMode 49017
#define sipName_selectionMode &sipStrings_QtWidgets[49017]
#define sipNameNr_setAcceptMode 49031
#define sipName_setAcceptMode &sipStrings_QtWidgets[49031]
#define sipNameNr_setAutoRepeat 49045
#define sipName_setAutoRepeat &sipStrings_QtWidgets[49045]
#define sipNameNr_setAutoScroll 49059
#define sipName_setAutoScroll &sipStrings_QtWidgets[49059]
#define sipNameNr_setBackground 49073
#define sipName_setBackground &sipStrings_QtWidgets[49073]
#define sipNameNr_setBlurRadius 49087
#define sipName_setBlurRadius &sipStrings_QtWidgets[49087]
#define sipNameNr_setButtonText 49101
#define sipName_setButtonText &sipStrings_QtWidgets[49101]
#define sipNameNr_setCellWidget 49115
#define sipName_setCellWidget &sipStrings_QtWidgets[49115]
#define sipNameNr_setCheckState 49129
#define sipName_setCheckState &sipStrings_QtWidgets[49129]
#define sipNameNr_setCommitPage 49143
#define sipName_setCommitPage &sipStrings_QtWidgets[49143]
#define sipNameNr_setCurrentRow 49157
#define sipName_setCurrentRow &sipStrings_QtWidgets[49157]
#define sipNameNr_setDigitCount 49171
#define sipName_setDigitCount &sipStrings_QtWidgets[49171]
#define sipNameNr_setDoubleStep 49185
#define sipName_setDoubleStep &sipStrings_QtWidgets[49185]
#define sipNameNr_setDropAction 49199
#define sipName_setDropAction &sipStrings_QtWidgets[49199]
#define sipNameNr_setEditorData 49213
#define sipName_setEditorData &sipStrings_QtWidgets[49213]
#define sipNameNr_setEmptyLabel 49227
#define sipName_setEmptyLabel &sipStrings_QtWidgets[49227]
#define sipNameNr_setFilterMode 49241
#define sipName_setFilterMode &sipStrings_QtWidgets[49241]
#define sipNameNr_setFixedWidth 49255
#define sipName_setFixedWidth &sipStrings_QtWidgets[49255]
#define sipNameNr_setFocusProxy 49269
#define sipName_setFocusProxy &sipStrings_QtWidgets[49269]
#define sipNameNr_setFontFamily 49283
#define sipName_setFontFamily &sipStrings_QtWidgets[49283]
#define sipNameNr_setFontItalic 49297
#define sipName_setFontItalic &sipStrings_QtWidgets[49297]
#define sipNameNr_setFontWeight 49311
#define sipName_setFontWeight &sipStrings_QtWidgets[49311]
#define sipNameNr_setForeground 49325
#define sipName_setForeground &sipStrings_QtWidgets[49325]
#define sipNameNr_setFrameShape 49339
#define sipName_setFrameShape &sipStrings_QtWidgets[49339]
#define sipNameNr_setFrameStyle 49353
#define sipName_setFrameStyle &sipStrings_QtWidgets[49353]
#define sipNameNr_setHeaderItem 49367
#define sipName_setHeaderItem &sipStrings_QtWidgets[49367]
#define sipNameNr_setIconPixmap 49381
#define sipName_setIconPixmap &sipStrings_QtWidgets[49381]
#define sipNameNr_setIntMaximum 49395
#define sipName_setIntMaximum &sipStrings_QtWidgets[49395]
#define sipNameNr_setIntMinimum 49409
#define sipName_setIntMinimum &sipStrings_QtWidgets[49409]
#define sipNameNr_setItemWidget 49423
#define sipName_setItemWidget &sipStrings_QtWidgets[49423]
#define sipNameNr_setLastOffset 49437
#define sipName_setLastOffset &sipStrings_QtWidgets[49437]
#define sipNameNr_setLayoutMode 49451
#define sipName_setLayoutMode &sipStrings_QtWidgets[49451]
#define sipNameNr_setMenuWidget 49465
#define sipName_setMenuWidget &sipStrings_QtWidgets[49465]
#define sipNameNr_setNameFilter 49479
#define sipName_setNameFilter &sipStrings_QtWidgets[49479]
#define sipNameNr_setParentItem 49493
#define sipName_setParentItem &sipStrings_QtWidgets[49493]
#define sipNameNr_setProxyModel 49507
#define sipName_setProxyModel &sipStrings_QtWidgets[49507]
#define sipNameNr_setRenderHint 49521
#define sipName_setRenderHint &sipStrings_QtWidgets[49521]
#define sipNameNr_setResizeMode 49535
#define sipName_setResizeMode &sipStrings_QtWidgets[49535]
#define sipNameNr_setRowSpacing 49549
#define sipName_setRowSpacing &sipStrings_QtWidgets[49549]
#define sipNameNr_setRowStretch 49563
#define sipName_setRowStretch &sipStrings_QtWidgets[49563]
#define sipNameNr_setRowVisible 49577
#define sipName_setRowVisible &sipStrings_QtWidgets[49577]
#define sipNameNr_setRubberBand 49591
#define sipName_setRubberBand &sipStrings_QtWidgets[49591]
#define sipNameNr_setSideWidget 49605
#define sipName_setSideWidget &sipStrings_QtWidgets[49605]
#define sipNameNr_setSingleStep 49619
#define sipName_setSingleStep &sipStrings_QtWidgets[49619]
#define sipNameNr_setSizePolicy 49633
#define sipName_setSizePolicy &sipStrings_QtWidgets[49633]
#define sipNameNr_setSliderDown 49647
#define sipName_setSliderDown &sipStrings_QtWidgets[49647]
#define sipNameNr_setStartAngle 49661
#define sipName_setStartAngle &sipStrings_QtWidgets[49661]
#define sipNameNr_setStyleSheet 49675
#define sipName_setStyleSheet &sipStrings_QtWidgets[49675]
#define sipNameNr_setSwipeAngle 49689
#define sipName_setSwipeAngle &sipStrings_QtWidgets[49689]
#define sipNameNr_setSystemMenu 49703
#define sipName_setSystemMenu &sipStrings_QtWidgets[49703]
#define sipNameNr_setTabEnabled 49717
#define sipName_setTabEnabled &sipStrings_QtWidgets[49717]
#define sipNameNr_setTabToolTip 49731
#define sipName_setTabToolTip &sipStrings_QtWidgets[49731]
#define sipNameNr_setTabVisible 49745
#define sipName_setTabVisible &sipStrings_QtWidgets[49745]
#define sipNameNr_setTextCursor 49759
#define sipName_setTextCursor &sipStrings_QtWidgets[49759]
#define sipNameNr_setTextFormat 49773
#define sipName_setTextFormat &sipStrings_QtWidgets[49773]
#define sipNameNr_setWindowFlag 49787
#define sipName_setWindowFlag &sipStrings_QtWidgets[49787]
#define sipNameNr_setWindowIcon 49801
#define sipName_setWindowIcon &sipStrings_QtWidgets[49801]
#define sipNameNr_setWindowRole 49815
#define sipName_setWindowRole &sipStrings_QtWidgets[49815]
#define sipNameNr_setWrapAround 49829
#define sipName_setWrapAround &sipStrings_QtWidgets[49829]
#define sipNameNr_setupViewport 49843
#define sipName_setupViewport &sipStrings_QtWidgets[49843]
#define sipNameNr_sharedPainter 49857
#define sipName_sharedPainter &sipStrings_QtWidgets[49857]
#define sipNameNr_showMaximized 49871
#define sipName_showMaximized &sipStrings_QtWidgets[49871]
#define sipNameNr_showMinimized 49885
#define sipName_showMinimized &sipStrings_QtWidgets[49885]
#define sipNameNr_showNextMonth 49899
#define sipName_showNextMonth &sipStrings_QtWidgets[49899]
#define sipNameNr_sizeIncrement 49913
#define sipName_sizeIncrement &sipStrings_QtWidgets[49913]
#define sipNameNr_sliderPressed 49927
#define sipName_sliderPressed &sipStrings_QtWidgets[49927]
#define sipNameNr_sortIndicator 49941
#define sipName_sortIndicator &sipStrings_QtWidgets[49941]
#define sipNameNr_sourceChanged 49955
#define sipName_sourceChanged &sipStrings_QtWidgets[49955]
#define sipNameNr_splitterMoved 49969
#define sipName_splitterMoved &sipStrings_QtWidgets[49969]
#define sipNameNr_standardColor 49983
#define sipName_standardColor &sipStrings_QtWidgets[49983]
#define sipNameNr_startDragTime 49997
#define sipName_startDragTime &sipStrings_QtWidgets[49997]
#define sipNameNr_stretchFactor 50011
#define sipName_stretchFactor &sipStrings_QtWidgets[50011]
#define sipNameNr_subWidgetRect 50025
#define sipName_subWidgetRect &sipStrings_QtWidgets[50025]
#define sipNameNr_subWindowList 50039
#define sipName_subWindowList &sipStrings_QtWidgets[50039]
#define sipNameNr_tabBarClicked 50053
#define sipName_tabBarClicked &sipStrings_QtWidgets[50053]
#define sipNameNr_testAttribute 50067
#define sipName_testAttribute &sipStrings_QtWidgets[50067]
#define sipNameNr_textActivated 50081
#define sipName_textActivated &sipStrings_QtWidgets[50081]
#define sipNameNr_textAlignment 50095
#define sipName_textAlignment &sipStrings_QtWidgets[50095]
#define sipNameNr_textElideMode 50109
#define sipName_textElideMode &sipStrings_QtWidgets[50109]
#define sipNameNr_textFromValue 50123
#define sipName_textFromValue &sipStrings_QtWidgets[50123]
#define sipNameNr_thresholdTime 50137
#define sipName_thresholdTime &sipStrings_QtWidgets[50137]
#define sipNameNr_titleBarFlags 50151
#define sipName_titleBarFlags &sipStrings_QtWidgets[50151]
#define sipNameNr_titleBarState 50165
#define sipName_titleBarState &sipStrings_QtWidgets[50165]
#define sipNameNr_totalSizeHint 50179
#define sipName_totalSizeHint &sipStrings_QtWidgets[50179]
#define sipNameNr_triggerAction 50193
#define sipName_triggerAction &sipStrings_QtWidgets[50193]
#define sipNameNr_undoAvailable 50207
#define sipName_undoAvailable &sipStrings_QtWidgets[50207]
#define sipNameNr_ungrabGesture 50221
#define sipName_ungrabGesture &sipStrings_QtWidgets[50221]
#define sipNameNr_updateRequest 50235
#define sipName_updateRequest &sipStrings_QtWidgets[50235]
#define sipNameNr_updateSection 50249
#define sipName_updateSection &sipStrings_QtWidgets[50249]
#define sipNameNr_valueFromText 50263
#define sipName_valueFromText &sipStrings_QtWidgets[50263]
#define sipNameNr_viewportEvent 50277
#define sipName_viewportEvent &sipStrings_QtWidgets[50277]
#define sipNameNr_visibleRegion 50291
#define sipName_visibleRegion &sipStrings_QtWidgets[50291]
#define sipNameNr_visualIndexAt 50305
#define sipName_visualIndexAt &sipStrings_QtWidgets[50305]
#define sipNameNr_widgetRemoved 50319
#define sipName_widgetRemoved &sipStrings_QtWidgets[50319]
#define sipNameNr_windowOpacity 50333
#define sipName_windowOpacity &sipStrings_QtWidgets[50333]
#define sipNameNr_writingSystem 50347
#define sipName_writingSystem &sipStrings_QtWidgets[50347]
#define sipNameNr_xScaleChanged 50361
#define sipName_xScaleChanged &sipStrings_QtWidgets[50361]
#define sipNameNr_yScaleChanged 50375
#define sipName_yScaleChanged &sipStrings_QtWidgets[50375]
#define sipNameNr_zScaleChanged 50389
#define sipName_zScaleChanged &sipStrings_QtWidgets[50389]
#define sipNameNr_BannerPixmap 50403
#define sipName_BannerPixmap &sipStrings_QtWidgets[50403]
#define sipNameNr_BspTreeIndex 50416
#define sipName_BspTreeIndex &sipStrings_QtWidgets[50416]
#define sipNameNr_ButtonLayout 7120
#define sipName_ButtonLayout &sipStrings_QtWidgets[7120]
#define sipNameNr_CC_ScrollBar 50429
#define sipName_CC_ScrollBar &sipStrings_QtWidgets[50429]
#define sipNameNr_CE_TabBarTab 50442
#define sipName_CE_TabBarTab &sipStrings_QtWidgets[50442]
#define sipNameNr_CT_ScrollBar 50455
#define sipName_CT_ScrollBar &sipStrings_QtWidgets[50455]
#define sipNameNr_CT_TabBarTab 50468
#define sipName_CT_TabBarTab &sipStrings_QtWidgets[50468]
#define sipNameNr_CT_TabWidget 50481
#define sipName_CT_TabWidget &sipStrings_QtWidgets[50481]
#define sipNameNr_CancelButton 4197
#define sipName_CancelButton &sipStrings_QtWidgets[4197]
#define sipNameNr_ClassicStyle 50494
#define sipName_ClassicStyle &sipStrings_QtWidgets[50494]
#define sipNameNr_CommitButton 50507
#define sipName_CommitButton &sipStrings_QtWidgets[50507]
#define sipNameNr_ContentsType 22009
#define sipName_ContentsType &sipStrings_QtWidgets[22009]
#define sipNameNr_CornerWidget 8250
#define sipName_CornerWidget &sipStrings_QtWidgets[8250]
#define sipNameNr_CursorAction 6296
#define sipName_CursorAction &sipStrings_QtWidgets[6296]
#define sipNameNr_DelayedPopup 50520
#define sipName_DelayedPopup &sipStrings_QtWidgets[50520]
#define sipNameNr_DontWrapRows 50533
#define sipName_DontWrapRows &sipStrings_QtWidgets[50533]
#define sipNameNr_DragDisabled 50546
#define sipName_DragDisabled &sipStrings_QtWidgets[50546]
#define sipNameNr_DragDropMode 6328
#define sipName_DragDropMode &sipStrings_QtWidgets[6328]
#define sipNameNr_DrawChildren 50559
#define sipName_DrawChildren &sipStrings_QtWidgets[50559]
#define sipNameNr_DropDisabled 50572
#define sipName_DropDisabled &sipStrings_QtWidgets[50572]
#define sipNameNr_EditNextItem 50585
#define sipName_EditNextItem &sipStrings_QtWidgets[50585]
#define sipNameNr_EditingState 50598
#define sipName_EditingState &sipStrings_QtWidgets[50598]
#define sipNameNr_ExistingFile 50611
#define sipName_ExistingFile &sipStrings_QtWidgets[50611]
#define sipNameNr_FinishButton 50624
#define sipName_FinishButton &sipStrings_QtWidgets[50624]
#define sipNameNr_FrameFeature 6648
#define sipName_FrameFeature &sipStrings_QtWidgets[6648]
#define sipNameNr_InputRelease 50637
#define sipName_InputRelease &sipStrings_QtWidgets[50637]
#define sipNameNr_InsertPolicy 14832
#define sipName_InsertPolicy &sipStrings_QtWidgets[14832]
#define sipNameNr_InstantPopup 50650
#define sipName_InstantPopup &sipStrings_QtWidgets[50650]
#define sipNameNr_InternalMove 50663
#define sipName_InternalMove &sipStrings_QtWidgets[50663]
#define sipNameNr_IteratorFlag 3527
#define sipName_IteratorFlag &sipStrings_QtWidgets[3527]
#define sipNameNr_LineWrapMode 9046
#define sipName_LineWrapMode &sipStrings_QtWidgets[9046]
#define sipNameNr_LongDayNames 50676
#define sipName_LongDayNames &sipStrings_QtWidgets[50676]
#define sipNameNr_ManualSubmit 50689
#define sipName_ManualSubmit &sipStrings_QtWidgets[50689]
#define sipNameNr_MayBeGesture 50702
#define sipName_MayBeGesture &sipStrings_QtWidgets[50702]
#define sipNameNr_MenuItemType 4948
#define sipName_MenuItemType &sipStrings_QtWidgets[4948]
#define sipNameNr_ModelSorting 13346
#define sipName_ModelSorting &sipStrings_QtWidgets[13346]
#define sipNameNr_MonthSection 50715
#define sipName_MonthSection &sipStrings_QtWidgets[50715]
#define sipNameNr_MovePageDown 50728
#define sipName_MovePageDown &sipStrings_QtWidgets[50728]
#define sipNameNr_MovePrevious 50741
#define sipName_MovePrevious &sipStrings_QtWidgets[50741]
#define sipNameNr_NonExclusive 50754
#define sipName_NonExclusive &sipStrings_QtWidgets[50754]
#define sipNameNr_NotCheckable 50767
#define sipName_NotCheckable &sipStrings_QtWidgets[50767]
#define sipNameNr_PE_FrameMenu 50780
#define sipName_PE_FrameMenu &sipStrings_QtWidgets[50780]
#define sipNameNr_PE_PanelMenu 50793
#define sipName_PE_PanelMenu &sipStrings_QtWidgets[50793]
#define sipNameNr_QApplication 50806
#define sipName_QApplication &sipStrings_QtWidgets[50806]
#define sipNameNr_QButtonGroup 50819
#define sipName_QButtonGroup &sipStrings_QtWidgets[50819]
#define sipNameNr_QColorDialog 50832
#define sipName_QColorDialog &sipStrings_QtWidgets[50832]
#define sipNameNr_QCommonStyle 50845
#define sipName_QCommonStyle &sipStrings_QtWidgets[50845]
#define sipNameNr_QInputDialog 50858
#define sipName_QInputDialog &sipStrings_QtWidgets[50858]
#define sipNameNr_QProgressBar 50871
#define sipName_QProgressBar &sipStrings_QtWidgets[50871]
#define sipNameNr_QRadioButton 50884
#define sipName_QRadioButton &sipStrings_QtWidgets[50884]
#define sipNameNr_QStyleOption 50897
#define sipName_QStyleOption &sipStrings_QtWidgets[50897]
#define sipNameNr_QTableWidget 50910
#define sipName_QTableWidget &sipStrings_QtWidgets[50910]
#define sipNameNr_QTextBrowser 50923
#define sipName_QTextBrowser &sipStrings_QtWidgets[50923]
#define sipNameNr_RoundedNorth 50936
#define sipName_RoundedNorth &sipStrings_QtWidgets[50936]
#define sipNameNr_RoundedSouth 50949
#define sipName_RoundedSouth &sipStrings_QtWidgets[50949]
#define sipNameNr_SC_SpinBoxUp 50962
#define sipName_SC_SpinBoxUp &sipStrings_QtWidgets[50962]
#define sipNameNr_SH_Menu_Mask 50975
#define sipName_SH_Menu_Mask &sipStrings_QtWidgets[50975]
#define sipNameNr_SO_FocusRect 50988
#define sipName_SO_FocusRect &sipStrings_QtWidgets[50988]
#define sipNameNr_SP_ArrowBack 51001
#define sipName_SP_ArrowBack &sipStrings_QtWidgets[51001]
#define sipNameNr_SP_ArrowDown 51014
#define sipName_SP_ArrowDown &sipStrings_QtWidgets[51014]
#define sipNameNr_SP_ArrowLeft 51027
#define sipName_SP_ArrowLeft &sipStrings_QtWidgets[51027]
#define sipNameNr_SP_MediaPlay 51040
#define sipName_SP_MediaPlay &sipStrings_QtWidgets[51040]
#define sipNameNr_SP_MediaStop 51053
#define sipName_SP_MediaStop &sipStrings_QtWidgets[51053]
#define sipNameNr_SP_TrashIcon 51066
#define sipName_SP_TrashIcon &sipStrings_QtWidgets[51066]
#define sipNameNr_ScrollMetric 5429
#define sipName_ScrollMetric &sipStrings_QtWidgets[5429]
#define sipNameNr_SegmentStyle 13496
#define sipName_SegmentStyle &sipStrings_QtWidgets[13496]
#define sipNameNr_SetFixedSize 51079
#define sipName_SetFixedSize &sipStrings_QtWidgets[51079]
#define sipNameNr_ShowDirsOnly 51092
#define sipName_ShowDirsOnly &sipStrings_QtWidgets[51092]
#define sipNameNr_SliderAction 8010
#define sipName_SliderAction &sipStrings_QtWidgets[8010]
#define sipNameNr_SliderChange 8040
#define sipName_SliderChange &sipStrings_QtWidgets[8040]
#define sipNameNr_SpanningRole 51105
#define sipName_SpanningRole &sipStrings_QtWidgets[51105]
#define sipNameNr_StackingMode 9075
#define sipName_StackingMode &sipStrings_QtWidgets[9075]
#define sipNameNr_State_Active 51118
#define sipName_State_Active &sipStrings_QtWidgets[51118]
#define sipNameNr_State_Bottom 51131
#define sipName_State_Bottom &sipStrings_QtWidgets[51131]
#define sipNameNr_State_Raised 51144
#define sipName_State_Raised &sipStrings_QtWidgets[51144]
#define sipNameNr_State_Sunken 51157
#define sipName_State_Sunken &sipStrings_QtWidgets[51157]
#define sipNameNr_State_Window 51170
#define sipName_State_Window &sipStrings_QtWidgets[51170]
#define sipNameNr_SubmitPolicy 6424
#define sipName_SubmitPolicy &sipStrings_QtWidgets[6424]
#define sipNameNr_TickPosition 19468
#define sipName_TickPosition &sipStrings_QtWidgets[19468]
#define sipNameNr_TouchGesture 51183
#define sipName_TouchGesture &sipStrings_QtWidgets[51183]
#define sipNameNr_UpDownArrows 51196
#define sipName_UpDownArrows &sipStrings_QtWidgets[51196]
#define sipNameNr_VerticalTabs 51209
#define sipName_VerticalTabs &sipStrings_QtWidgets[51209]
#define sipNameNr_WizardButton 19512
#define sipName_WizardButton &sipStrings_QtWidgets[19512]
#define sipNameNr_WizardOption 19534
#define sipName_WizardOption &sipStrings_QtWidgets[19534]
#define sipNameNr_WizardPixmap 19556
#define sipName_WizardPixmap &sipStrings_QtWidgets[19556]
#define sipNameNr_WrapLongRows 51222
#define sipName_WrapLongRows &sipStrings_QtWidgets[51222]
#define sipNameNr_acceleration 51235
#define sipName_acceleration &sipStrings_QtWidgets[51235]
#define sipNameNr_activeAction 51248
#define sipName_activeAction &sipStrings_QtWidgets[51248]
#define sipNameNr_activeWindow 51261
#define sipName_activeWindow &sipStrings_QtWidgets[51261]
#define sipNameNr_addSeparator 51274
#define sipName_addSeparator &sipStrings_QtWidgets[51274]
#define sipNameNr_addSubWindow 51287
#define sipName_addSubWindow &sipStrings_QtWidgets[51287]
#define sipNameNr_allowedAreas 51300
#define sipName_allowedAreas &sipStrings_QtWidgets[51300]
#define sipNameNr_angleChanged 51313
#define sipName_angleChanged &sipStrings_QtWidgets[51313]
#define sipNameNr_animateClick 51326
#define sipName_animateClick &sipStrings_QtWidgets[51326]
#define sipNameNr_boundingRect 51339
#define sipName_boundingRect &sipStrings_QtWidgets[51339]
#define sipNameNr_bspTreeDepth 51352
#define sipName_bspTreeDepth &sipStrings_QtWidgets[51352]
#define sipNameNr_centerCursor 51365
#define sipName_centerCursor &sipStrings_QtWidgets[51365]
#define sipNameNr_childrenRect 51378
#define sipName_childrenRect &sipStrings_QtWidgets[51378]
#define sipNameNr_clearHistory 51391
#define sipName_clearHistory &sipStrings_QtWidgets[51391]
#define sipNameNr_clearMapping 51404
#define sipName_clearMapping &sipStrings_QtWidgets[51404]
#define sipNameNr_clearMessage 51417
#define sipName_clearMessage &sipStrings_QtWidgets[51417]
#define sipNameNr_collapseItem 51430
#define sipName_collapseItem &sipStrings_QtWidgets[51430]
#define sipNameNr_colorChanged 51443
#define sipName_colorChanged &sipStrings_QtWidgets[51443]
#define sipNameNr_columnWidths 51456
#define sipName_columnWidths &sipStrings_QtWidgets[51456]
#define sipNameNr_contentsRect 51469
#define sipName_contentsRect &sipStrings_QtWidgets[51469]
#define sipNameNr_controlTypes 51482
#define sipName_controlTypes &sipStrings_QtWidgets[51482]
#define sipNameNr_cornerWidget 51495
#define sipName_cornerWidget &sipStrings_QtWidgets[51495]
#define sipNameNr_createAction 51508
#define sipName_createAction &sipStrings_QtWidgets[51508]
#define sipNameNr_createColumn 51521
#define sipName_createColumn &sipStrings_QtWidgets[51521]
#define sipNameNr_createEditor 51534
#define sipName_createEditor &sipStrings_QtWidgets[51534]
#define sipNameNr_createHandle 51547
#define sipName_createHandle &sipStrings_QtWidgets[51547]
#define sipNameNr_createWidget 51560
#define sipName_createWidget &sipStrings_QtWidgets[51560]
#define sipNameNr_currentColor 51573
#define sipName_currentColor &sipStrings_QtWidgets[51573]
#define sipNameNr_currentIndex 51586
#define sipName_currentIndex &sipStrings_QtWidgets[51586]
#define sipNameNr_deleteWidget 51599
#define sipName_deleteWidget &sipStrings_QtWidgets[51599]
#define sipNameNr_detailedText 51612
#define sipName_detailedText &sipStrings_QtWidgets[51612]
#define sipNameNr_dialWrapping 51625
#define sipName_dialWrapping &sipStrings_QtWidgets[51625]
#define sipNameNr_directoryUrl 51638
#define sipName_directoryUrl &sipStrings_QtWidgets[51638]
#define sipNameNr_dockLocation 51651
#define sipName_dockLocation &sipStrings_QtWidgets[51651]
#define sipNameNr_documentMode 51664
#define sipName_documentMode &sipStrings_QtWidgets[51664]
#define sipNameNr_documentSize 51677
#define sipName_documentSize &sipStrings_QtWidgets[51677]
#define sipNameNr_dragDropMode 51690
#define sipName_dragDropMode &sipStrings_QtWidgets[51690]
#define sipNameNr_drawBranches 51703
#define sipName_drawBranches &sipStrings_QtWidgets[51703]
#define sipNameNr_drawContents 51716
#define sipName_drawContents &sipStrings_QtWidgets[51716]
#define sipNameNr_drawItemText 51729
#define sipName_drawItemText &sipStrings_QtWidgets[51729]
#define sipNameNr_dropMimeData 51742
#define sipName_dropMimeData &sipStrings_QtWidgets[51742]
#define sipNameNr_editTriggers 51755
#define sipName_editTriggers &sipStrings_QtWidgets[51755]
#define sipNameNr_escapeButton 51768
#define sipName_escapeButton &sipStrings_QtWidgets[51768]
#define sipNameNr_fileNameHint 51781
#define sipName_fileNameHint &sipStrings_QtWidgets[51781]
#define sipNameNr_fileSelected 51794
#define sipName_fileSelected &sipStrings_QtWidgets[51794]
#define sipNameNr_focusChanged 51807
#define sipName_focusChanged &sipStrings_QtWidgets[51807]
#define sipNameNr_focusInEvent 51820
#define sipName_focusInEvent &sipStrings_QtWidgets[51820]
#define sipNameNr_focusOnTouch 51833
#define sipName_focusOnTouch &sipStrings_QtWidgets[51833]
#define sipNameNr_fontSelected 51846
#define sipName_fontSelected &sipStrings_QtWidgets[51846]
#define sipNameNr_grabKeyboard 46110
#define sipName_grabKeyboard &sipStrings_QtWidgets[46110]
#define sipNameNr_grabShortcut 51859
#define sipName_grabShortcut &sipStrings_QtWidgets[51859]
#define sipNameNr_graphicsItem 51872
#define sipName_graphicsItem &sipStrings_QtWidgets[51872]
#define sipNameNr_historyTitle 51885
#define sipName_historyTitle &sipStrings_QtWidgets[51885]
#define sipNameNr_iconProvider 51898
#define sipName_iconProvider &sipStrings_QtWidgets[51898]
#define sipNameNr_indexOfChild 51911
#define sipName_indexOfChild &sipStrings_QtWidgets[51911]
#define sipNameNr_indexesMoved 51924
#define sipName_indexesMoved &sipStrings_QtWidgets[51924]
#define sipNameNr_insertAction 51937
#define sipName_insertAction &sipStrings_QtWidgets[51937]
#define sipNameNr_insertColumn 51950
#define sipName_insertColumn &sipStrings_QtWidgets[51950]
#define sipNameNr_insertLayout 51963
#define sipName_insertLayout &sipStrings_QtWidgets[51963]
#define sipNameNr_insertPolicy 51976
#define sipName_insertPolicy &sipStrings_QtWidgets[51976]
#define sipNameNr_insertWidget 51989
#define sipName_insertWidget &sipStrings_QtWidgets[51989]
#define sipNameNr_isAncestorOf 52002
#define sipName_isAncestorOf &sipStrings_QtWidgets[52002]
#define sipNameNr_isCommitPage 52015
#define sipName_isCommitPage &sipStrings_QtWidgets[52015]
#define sipNameNr_isFullScreen 52028
#define sipName_isFullScreen &sipStrings_QtWidgets[52028]
#define sipNameNr_isObscuredBy 52041
#define sipName_isObscuredBy &sipStrings_QtWidgets[52041]
#define sipNameNr_isRowVisible 52054
#define sipName_isRowVisible &sipStrings_QtWidgets[52054]
#define sipNameNr_isSliderDown 52067
#define sipName_isSliderDown &sipStrings_QtWidgets[52067]
#define sipNameNr_isTabEnabled 52080
#define sipName_isTabEnabled &sipStrings_QtWidgets[52080]
#define sipNameNr_isTabVisible 52093
#define sipName_isTabVisible &sipStrings_QtWidgets[52093]
#define sipNameNr_isUnderMouse 52106
#define sipName_isUnderMouse &sipStrings_QtWidgets[52106]
#define sipNameNr_itemDelegate 52119
#define sipName_itemDelegate &sipStrings_QtWidgets[52119]
#define sipNameNr_itemExpanded 52132
#define sipName_itemExpanded &sipStrings_QtWidgets[52132]
#define sipNameNr_itemInserted 52145
#define sipName_itemInserted &sipStrings_QtWidgets[52145]
#define sipNameNr_itemTextRect 52158
#define sipName_itemTextRect &sipStrings_QtWidgets[52158]
#define sipNameNr_lastScenePos 52171
#define sipName_lastScenePos &sipStrings_QtWidgets[52171]
#define sipNameNr_lineWrapMode 52184
#define sipName_lineWrapMode &sipStrings_QtWidgets[52184]
#define sipNameNr_loadResource 52197
#define sipName_loadResource &sipStrings_QtWidgets[52197]
#define sipNameNr_logicalIndex 52210
#define sipName_logicalIndex &sipStrings_QtWidgets[52210]
#define sipNameNr_mapFromScene 52223
#define sipName_mapFromScene &sipStrings_QtWidgets[52223]
#define sipNameNr_maxIconWidth 52236
#define sipName_maxIconWidth &sipStrings_QtWidgets[52236]
#define sipNameNr_maximumWidth 52249
#define sipName_maximumWidth &sipStrings_QtWidgets[52249]
#define sipNameNr_menuInAction 52262
#define sipName_menuInAction &sipStrings_QtWidgets[52262]
#define sipNameNr_menuItemType 52275
#define sipName_menuItemType &sipStrings_QtWidgets[52275]
#define sipNameNr_midLineWidth 52288
#define sipName_midLineWidth &sipStrings_QtWidgets[52288]
#define sipNameNr_minimumWidth 52301
#define sipName_minimumWidth &sipStrings_QtWidgets[52301]
#define sipNameNr_modelSorting 52314
#define sipName_modelSorting &sipStrings_QtWidgets[52314]
#define sipNameNr_mouseGrabber 52327
#define sipName_mouseGrabber &sipStrings_QtWidgets[52327]
#define sipNameNr_moveSplitter 52340
#define sipName_moveSplitter &sipStrings_QtWidgets[52340]
#define sipNameNr_msecShowTime 52353
#define sipName_msecShowTime &sipStrings_QtWidgets[52353]
#define sipNameNr_okButtonText 52366
#define sipName_okButtonText &sipStrings_QtWidgets[52366]
#define sipNameNr_opaqueResize 52379
#define sipName_opaqueResize &sipStrings_QtWidgets[52379]
#define sipNameNr_orientations 52392
#define sipName_orientations &sipStrings_QtWidgets[52392]
#define sipNameNr_originCorner 52405
#define sipName_originCorner &sipStrings_QtWidgets[52405]
#define sipNameNr_paintSection 52418
#define sipName_paintSection &sipStrings_QtWidgets[52418]
#define sipNameNr_parentObject 52431
#define sipName_parentObject &sipStrings_QtWidgets[52431]
#define sipNameNr_parentWidget 52444
#define sipName_parentWidget &sipStrings_QtWidgets[52444]
#define sipNameNr_rangeChanged 52457
#define sipName_rangeChanged &sipStrings_QtWidgets[52457]
#define sipNameNr_rectForIndex 52470
#define sipName_rectForIndex &sipStrings_QtWidgets[52470]
#define sipNameNr_releaseMouse 52483
#define sipName_releaseMouse &sipStrings_QtWidgets[52483]
#define sipNameNr_removeAction 52496
#define sipName_removeAction &sipStrings_QtWidgets[52496]
#define sipNameNr_removeButton 52509
#define sipName_removeButton &sipStrings_QtWidgets[52509]
#define sipNameNr_removeColumn 52522
#define sipName_removeColumn &sipStrings_QtWidgets[52522]
#define sipNameNr_removeWidget 52535
#define sipName_removeWidget &sipStrings_QtWidgets[52535]
#define sipNameNr_repeatAction 52548
#define sipName_repeatAction &sipStrings_QtWidgets[52548]
#define sipNameNr_resizeAnchor 52561
#define sipName_resizeAnchor &sipStrings_QtWidgets[52561]
#define sipNameNr_restoreState 52574
#define sipName_restoreState &sipStrings_QtWidgets[52574]
#define sipNameNr_rowAlignment 13821
#define sipName_rowAlignment &sipStrings_QtWidgets[13821]
#define sipNameNr_rowsInserted 52587
#define sipName_rowsInserted &sipStrings_QtWidgets[52587]
#define sipNameNr_saveGeometry 52600
#define sipName_saveGeometry &sipStrings_QtWidgets[52600]
#define sipNameNr_scaleChanged 52613
#define sipName_scaleChanged &sipStrings_QtWidgets[52613]
#define sipNameNr_scrollMetric 52626
#define sipName_scrollMetric &sipStrings_QtWidgets[52626]
#define sipNameNr_scrollToItem 52639
#define sipName_scrollToItem &sipStrings_QtWidgets[52639]
#define sipNameNr_sectionCount 52652
#define sipName_sectionCount &sipStrings_QtWidgets[52652]
#define sipNameNr_sectionMoved 52665
#define sipName_sectionMoved &sipStrings_QtWidgets[52665]
#define sipNameNr_segmentStyle 52678
#define sipName_segmentStyle &sipStrings_QtWidgets[52678]
#define sipNameNr_selectColumn 52691
#define sipName_selectColumn &sipStrings_QtWidgets[52691]
#define sipNameNr_selectedDate 52704
#define sipName_selectedDate &sipStrings_QtWidgets[52704]
#define sipNameNr_selectedFont 52717
#define sipName_selectedFont &sipStrings_QtWidgets[52717]
#define sipNameNr_selectedText 52730
#define sipName_selectedText &sipStrings_QtWidgets[52730]
#define sipNameNr_selectedUrls 52743
#define sipName_selectedUrls &sipStrings_QtWidgets[52743]
#define sipNameNr_selectionEnd 52756
#define sipName_selectionEnd &sipStrings_QtWidgets[52756]
#define sipNameNr_setAlignment 52769
#define sipName_setAlignment &sipStrings_QtWidgets[52769]
#define sipNameNr_setArrowType 52782
#define sipName_setArrowType &sipStrings_QtWidgets[52782]
#define sipNameNr_setAttribute 52795
#define sipName_setAttribute &sipStrings_QtWidgets[52795]
#define sipNameNr_setAutoClose 52808
#define sipName_setAutoClose &sipStrings_QtWidgets[52808]
#define sipNameNr_setAutoRaise 52821
#define sipName_setAutoRaise &sipStrings_QtWidgets[52821]
#define sipNameNr_setAutoReset 52834
#define sipName_setAutoReset &sipStrings_QtWidgets[52834]
#define sipNameNr_setBaseStyle 52847
#define sipName_setBaseStyle &sipStrings_QtWidgets[52847]
#define sipNameNr_setBatchSize 52860
#define sipName_setBatchSize &sipStrings_QtWidgets[52860]
#define sipNameNr_setBlurHints 52873
#define sipName_setBlurHints &sipStrings_QtWidgets[52873]
#define sipNameNr_setCacheMode 52886
#define sipName_setCacheMode &sipStrings_QtWidgets[52886]
#define sipNameNr_setCheckable 52899
#define sipName_setCheckable &sipStrings_QtWidgets[52899]
#define sipNameNr_setCleanIcon 52912
#define sipName_setCleanIcon &sipStrings_QtWidgets[52912]
#define sipNameNr_setCompleter 52925
#define sipName_setCompleter &sipStrings_QtWidgets[52925]
#define sipNameNr_setCurrentId 52938
#define sipName_setCurrentId &sipStrings_QtWidgets[52938]
#define sipNameNr_setDateRange 52951
#define sipName_setDateRange &sipStrings_QtWidgets[52951]
#define sipNameNr_setDefaultUp 52964
#define sipName_setDefaultUp &sipStrings_QtWidgets[52964]
#define sipNameNr_setDirection 52977
#define sipName_setDirection &sipStrings_QtWidgets[52977]
#define sipNameNr_setDirectory 52990
#define sipName_setDirectory &sipStrings_QtWidgets[52990]
#define sipNameNr_setElideMode 53003
#define sipName_setElideMode &sipStrings_QtWidgets[53003]
#define sipNameNr_setExclusive 53016
#define sipName_setExclusive &sipStrings_QtWidgets[53016]
#define sipNameNr_setExpanding 53029
#define sipName_setExpanding &sipStrings_QtWidgets[53029]
#define sipNameNr_setFinalPage 53042
#define sipName_setFinalPage &sipStrings_QtWidgets[53042]
#define sipNameNr_setFixedSize 53055
#define sipName_setFixedSize &sipStrings_QtWidgets[53055]
#define sipNameNr_setFloatable 53068
#define sipName_setFloatable &sipStrings_QtWidgets[53068]
#define sipNameNr_setFocusItem 53081
#define sipName_setFocusItem &sipStrings_QtWidgets[53081]
#define sipNameNr_setFrameRect 53094
#define sipName_setFrameRect &sipStrings_QtWidgets[53094]
#define sipNameNr_setGridStyle 53107
#define sipName_setGridStyle &sipStrings_QtWidgets[53107]
#define sipNameNr_setInputMask 53120
#define sipName_setInputMask &sipStrings_QtWidgets[53120]
#define sipNameNr_setInputMode 53133
#define sipName_setInputMode &sipStrings_QtWidgets[53133]
#define sipNameNr_setLabelText 53146
#define sipName_setLabelText &sipStrings_QtWidgets[53146]
#define sipNameNr_setLineWidth 53159
#define sipName_setLineWidth &sipStrings_QtWidgets[53159]
#define sipNameNr_setMaxLength 53172
#define sipName_setMaxLength &sipStrings_QtWidgets[53172]
#define sipNameNr_setModelData 53185
#define sipName_setModelData &sipStrings_QtWidgets[53185]
#define sipNameNr_setNumDigits 53198
#define sipName_setNumDigits &sipStrings_QtWidgets[53198]
#define sipNameNr_setOpenLinks 53211
#define sipName_setOpenLinks &sipStrings_QtWidgets[53211]
#define sipNameNr_setPlainText 53224
#define sipName_setPlainText &sipStrings_QtWidgets[53224]
#define sipNameNr_setPopupMode 53237
#define sipName_setPopupMode &sipStrings_QtWidgets[53237]
#define sipNameNr_setRootIndex 53250
#define sipName_setRootIndex &sipStrings_QtWidgets[53250]
#define sipNameNr_setRowHeight 53263
#define sipName_setRowHeight &sipStrings_QtWidgets[53263]
#define sipNameNr_setRowHidden 53276
#define sipName_setRowHidden &sipStrings_QtWidgets[53276]
#define sipNameNr_setSceneRect 53289
#define sipName_setSceneRect &sipStrings_QtWidgets[53289]
#define sipNameNr_setSelection 53302
#define sipName_setSelection &sipStrings_QtWidgets[53302]
#define sipNameNr_setShapeMode 53315
#define sipName_setShapeMode &sipStrings_QtWidgets[53315]
#define sipNameNr_setSpanAngle 53328
#define sipName_setSpanAngle &sipStrings_QtWidgets[53328]
#define sipNameNr_setStatusBar 53341
#define sipName_setStatusBar &sipStrings_QtWidgets[53341]
#define sipNameNr_setStatusTip 53354
#define sipName_setStatusTip &sipStrings_QtWidgets[53354]
#define sipNameNr_setTabButton 53367
#define sipName_setTabButton &sipStrings_QtWidgets[53367]
#define sipNameNr_setTextColor 53380
#define sipName_setTextColor &sipStrings_QtWidgets[53380]
#define sipNameNr_setTextValue 53393
#define sipName_setTextValue &sipStrings_QtWidgets[53393]
#define sipNameNr_setTextWidth 53406
#define sipName_setTextWidth &sipStrings_QtWidgets[53406]
#define sipNameNr_setTimeRange 53419
#define sipName_setTimeRange &sipStrings_QtWidgets[53419]
#define sipNameNr_setTransform 44685
#define sipName_setTransform &sipStrings_QtWidgets[44685]
#define sipNameNr_setValidator 53432
#define sipName_setValidator &sipStrings_QtWidgets[53432]
#define sipNameNr_setWhatsThis 53445
#define sipName_setWhatsThis &sipStrings_QtWidgets[53445]
#define sipNameNr_showNextYear 53458
#define sipName_showNextYear &sipStrings_QtWidgets[53458]
#define sipNameNr_sliderChange 53471
#define sipName_sliderChange &sipStrings_QtWidgets[53471]
#define sipNameNr_sortByColumn 53484
#define sipName_sortByColumn &sipStrings_QtWidgets[53484]
#define sipNameNr_sortChildren 53497
#define sipName_sortChildren &sipStrings_QtWidgets[53497]
#define sipNameNr_sourcePixmap 53510
#define sipName_sourcePixmap &sipStrings_QtWidgets[53510]
#define sipNameNr_sourceRegion 53523
#define sipName_sourceRegion &sipStrings_QtWidgets[53523]
#define sipNameNr_stackingMode 53536
#define sipName_stackingMode &sipStrings_QtWidgets[53536]
#define sipNameNr_standardIcon 53549
#define sipName_standardIcon &sipStrings_QtWidgets[53549]
#define sipNameNr_stateChanged 53562
#define sipName_stateChanged &sipStrings_QtWidgets[53562]
#define sipNameNr_submitPolicy 53575
#define sipName_submitPolicy &sipStrings_QtWidgets[53575]
#define sipNameNr_swapSections 53588
#define sipName_swapSections &sipStrings_QtWidgets[53588]
#define sipNameNr_tabTextColor 53601
#define sipName_tabTextColor &sipStrings_QtWidgets[53601]
#define sipNameNr_tabWhatsThis 53614
#define sipName_tabWhatsThis &sipStrings_QtWidgets[53614]
#define sipNameNr_tabsClosable 53627
#define sipName_tabsClosable &sipStrings_QtWidgets[53627]
#define sipNameNr_takeChildren 53640
#define sipName_takeChildren &sipStrings_QtWidgets[53640]
#define sipNameNr_targetOffset 53653
#define sipName_targetOffset &sipStrings_QtWidgets[53653]
#define sipNameNr_textEchoMode 53666
#define sipName_textEchoMode &sipStrings_QtWidgets[53666]
#define sipNameNr_tickInterval 53679
#define sipName_tickInterval &sipStrings_QtWidgets[53679]
#define sipNameNr_tickPosition 53692
#define sipName_tickPosition &sipStrings_QtWidgets[53692]
#define sipNameNr_toolBarBreak 53705
#define sipName_toolBarBreak &sipStrings_QtWidgets[53705]
#define sipNameNr_topLevelItem 53718
#define sipName_topLevelItem &sipStrings_QtWidgets[53718]
#define sipNameNr_treePosition 53731
#define sipName_treePosition &sipStrings_QtWidgets[53731]
#define sipNameNr_unsetHotSpot 53744
#define sipName_unsetHotSpot &sipStrings_QtWidgets[53744]
#define sipNameNr_unsetSpacing 53757
#define sipName_unsetSpacing &sipStrings_QtWidgets[53757]
#define sipNameNr_urlsSelected 53770
#define sipName_urlsSelected &sipStrings_QtWidgets[53770]
#define sipNameNr_validatePage 53783
#define sipName_validatePage &sipStrings_QtWidgets[53783]
#define sipNameNr_valueChanged 53796
#define sipName_valueChanged &sipStrings_QtWidgets[53796]
#define sipNameNr_visualColumn 53809
#define sipName_visualColumn &sipStrings_QtWidgets[53809]
#define sipNameNr_windowHandle 53822
#define sipName_windowHandle &sipStrings_QtWidgets[53822]
#define sipNameNr_wordWrapMode 53835
#define sipName_wordWrapMode &sipStrings_QtWidgets[53835]
#define sipNameNr_AmPmSection 53848
#define sipName_AmPmSection &sipStrings_QtWidgets[53848]
#define sipNameNr_BottomToTop 53860
#define sipName_BottomToTop &sipStrings_QtWidgets[53860]
#define sipNameNr_CC_ComboBox 53872
#define sipName_CC_ComboBox &sipStrings_QtWidgets[53872]
#define sipNameNr_CC_GroupBox 53884
#define sipName_CC_GroupBox &sipStrings_QtWidgets[53884]
#define sipNameNr_CC_TitleBar 53896
#define sipName_CC_TitleBar &sipStrings_QtWidgets[53896]
#define sipNameNr_CE_CheckBox 53908
#define sipName_CE_CheckBox &sipStrings_QtWidgets[53908]
#define sipNameNr_CE_MenuItem 53920
#define sipName_CE_MenuItem &sipStrings_QtWidgets[53920]
#define sipNameNr_CE_SizeGrip 53932
#define sipName_CE_SizeGrip &sipStrings_QtWidgets[53932]
#define sipNameNr_CE_Splitter 53944
#define sipName_CE_Splitter &sipStrings_QtWidgets[53944]
#define sipNameNr_CT_CheckBox 53956
#define sipName_CT_CheckBox &sipStrings_QtWidgets[53956]
#define sipNameNr_CT_ComboBox 53968
#define sipName_CT_ComboBox &sipStrings_QtWidgets[53968]
#define sipNameNr_CT_GroupBox 53980
#define sipName_CT_GroupBox &sipStrings_QtWidgets[53980]
#define sipNameNr_CT_LineEdit 53992
#define sipName_CT_LineEdit &sipStrings_QtWidgets[53992]
#define sipNameNr_CT_MenuItem 54004
#define sipName_CT_MenuItem &sipStrings_QtWidgets[54004]
#define sipNameNr_CT_SizeGrip 54016
#define sipName_CT_SizeGrip &sipStrings_QtWidgets[54016]
#define sipNameNr_CT_Splitter 54028
#define sipName_CT_Splitter &sipStrings_QtWidgets[54028]
#define sipNameNr_ControlType 13572
#define sipName_ControlType &sipStrings_QtWidgets[13572]
#define sipNameNr_DefaultItem 54040
#define sipName_DefaultItem &sipStrings_QtWidgets[54040]
#define sipNameNr_DefaultType 54052
#define sipName_DefaultType &sipStrings_QtWidgets[54052]
#define sipNameNr_DialogLabel 13372
#define sipName_DialogLabel &sipStrings_QtWidgets[13372]
#define sipNameNr_DoubleClick 16249
#define sipName_DoubleClick &sipStrings_QtWidgets[16249]
#define sipNameNr_DoubleInput 54064
#define sipName_DoubleInput &sipStrings_QtWidgets[54064]
#define sipNameNr_DragEnabled 45271
#define sipName_DragEnabled &sipStrings_QtWidgets[45271]
#define sipNameNr_DropEnabled 54076
#define sipName_DropEnabled &sipStrings_QtWidgets[54076]
#define sipNameNr_EditTrigger 7059
#define sipName_EditTrigger &sipStrings_QtWidgets[7059]
#define sipNameNr_EndEditHint 4844
#define sipName_EndEditHint &sipStrings_QtWidgets[4844]
#define sipNameNr_FirstButton 54088
#define sipName_FirstButton &sipStrings_QtWidgets[54088]
#define sipNameNr_GnomeLayout 54100
#define sipName_GnomeLayout &sipStrings_QtWidgets[54100]
#define sipNameNr_HasChildren 54112
#define sipName_HasChildren &sipStrings_QtWidgets[54112]
#define sipNameNr_HourSection 54124
#define sipName_HourSection &sipStrings_QtWidgets[54124]
#define sipNameNr_Information 14072
#define sipName_Information &sipStrings_QtWidgets[14072]
#define sipNameNr_InsertAtTop 54136
#define sipName_InsertAtTop &sipStrings_QtWidgets[54136]
#define sipNameNr_Interactive 45406
#define sipName_Interactive &sipStrings_QtWidgets[45406]
#define sipNameNr_InvalidRole 54148
#define sipName_InvalidRole &sipStrings_QtWidgets[54148]
#define sipNameNr_ItemIsPanel 54160
#define sipName_ItemIsPanel &sipStrings_QtWidgets[54160]
#define sipNameNr_LeftToRight 48333
#define sipName_LeftToRight &sipStrings_QtWidgets[48333]
#define sipNameNr_MSecSection 54172
#define sipName_MSecSection &sipStrings_QtWidgets[54172]
#define sipNameNr_MessageIcon 9134
#define sipName_MessageIcon &sipStrings_QtWidgets[9134]
#define sipNameNr_MiddleClick 54184
#define sipName_MiddleClick &sipStrings_QtWidgets[54184]
#define sipNameNr_ModernStyle 54196
#define sipName_ModernStyle &sipStrings_QtWidgets[54196]
#define sipNameNr_NoDirection 54208
#define sipName_NoDirection &sipStrings_QtWidgets[54208]
#define sipNameNr_NoSelection 54220
#define sipName_NoSelection &sipStrings_QtWidgets[54220]
#define sipNameNr_NotAdjacent 54232
#define sipName_NotAdjacent &sipStrings_QtWidgets[54232]
#define sipNameNr_NotEditable 54244
#define sipName_NotEditable &sipStrings_QtWidgets[54244]
#define sipNameNr_PixelMetric 25219
#define sipName_PixelMetric &sipStrings_QtWidgets[25219]
#define sipNameNr_QColumnView 54256
#define sipName_QColumnView &sipStrings_QtWidgets[54256]
#define sipNameNr_QDockWidget 54268
#define sipName_QDockWidget &sipStrings_QtWidgets[54268]
#define sipNameNr_QFileDialog 54280
#define sipName_QFileDialog &sipStrings_QtWidgets[54280]
#define sipNameNr_QFocusFrame 54292
#define sipName_QFocusFrame &sipStrings_QtWidgets[54292]
#define sipNameNr_QFontDialog 54304
#define sipName_QFontDialog &sipStrings_QtWidgets[54304]
#define sipNameNr_QFormLayout 54316
#define sipName_QFormLayout &sipStrings_QtWidgets[54316]
#define sipNameNr_QGridLayout 54328
#define sipName_QGridLayout &sipStrings_QtWidgets[54328]
#define sipNameNr_QHBoxLayout 54340
#define sipName_QHBoxLayout &sipStrings_QtWidgets[54340]
#define sipNameNr_QHeaderView 54352
#define sipName_QHeaderView &sipStrings_QtWidgets[54352]
#define sipNameNr_QLayoutItem 54364
#define sipName_QLayoutItem &sipStrings_QtWidgets[54364]
#define sipNameNr_QListWidget 54376
#define sipName_QListWidget &sipStrings_QtWidgets[54376]
#define sipNameNr_QMainWindow 54388
#define sipName_QMainWindow &sipStrings_QtWidgets[54388]
#define sipNameNr_QMessageBox 54400
#define sipName_QMessageBox &sipStrings_QtWidgets[54400]
#define sipNameNr_QPanGesture 54412
#define sipName_QPanGesture &sipStrings_QtWidgets[54412]
#define sipNameNr_QProxyStyle 54424
#define sipName_QProxyStyle &sipStrings_QtWidgets[54424]
#define sipNameNr_QPushButton 54436
#define sipName_QPushButton &sipStrings_QtWidgets[54436]
#define sipNameNr_QRubberBand 54448
#define sipName_QRubberBand &sipStrings_QtWidgets[54448]
#define sipNameNr_QScrollArea 54460
#define sipName_QScrollArea &sipStrings_QtWidgets[54460]
#define sipNameNr_QSizePolicy 54472
#define sipName_QSizePolicy &sipStrings_QtWidgets[54472]
#define sipNameNr_QSpacerItem 54484
#define sipName_QSpacerItem &sipStrings_QtWidgets[54484]
#define sipNameNr_QTapGesture 54496
#define sipName_QTapGesture &sipStrings_QtWidgets[54496]
#define sipNameNr_QToolButton 54508
#define sipName_QToolButton &sipStrings_QtWidgets[54508]
#define sipNameNr_QTreeWidget 54520
#define sipName_QTreeWidget &sipStrings_QtWidgets[54520]
#define sipNameNr_QVBoxLayout 54532
#define sipName_QVBoxLayout &sipStrings_QtWidgets[54532]
#define sipNameNr_QWidgetItem 54544
#define sipName_QWidgetItem &sipStrings_QtWidgets[54544]
#define sipNameNr_QWizardPage 54556
#define sipName_QWizardPage &sipStrings_QtWidgets[54556]
#define sipNameNr_QualityHint 54568
#define sipName_QualityHint &sipStrings_QtWidgets[54568]
#define sipNameNr_RadioButton 14665
#define sipName_RadioButton &sipStrings_QtWidgets[14665]
#define sipNameNr_RightToLeft 48347
#define sipName_RightToLeft &sipStrings_QtWidgets[48347]
#define sipNameNr_RoundedEast 54580
#define sipName_RoundedEast &sipStrings_QtWidgets[54580]
#define sipNameNr_RoundedWest 54592
#define sipName_RoundedWest &sipStrings_QtWidgets[54592]
#define sipNameNr_SO_ComboBox 54604
#define sipName_SO_ComboBox &sipStrings_QtWidgets[54604]
#define sipNameNr_SO_GroupBox 54616
#define sipName_SO_GroupBox &sipStrings_QtWidgets[54616]
#define sipNameNr_SO_MenuItem 54628
#define sipName_SO_MenuItem &sipStrings_QtWidgets[54628]
#define sipNameNr_SO_SizeGrip 54640
#define sipName_SO_SizeGrip &sipStrings_QtWidgets[54640]
#define sipNameNr_SO_TitleBar 54652
#define sipName_SO_TitleBar &sipStrings_QtWidgets[54652]
#define sipNameNr_SO_ViewItem 54664
#define sipName_SO_ViewItem &sipStrings_QtWidgets[54664]
#define sipNameNr_SP_FileIcon 54676
#define sipName_SP_FileIcon &sipStrings_QtWidgets[54676]
#define sipNameNr_SelectItems 54688
#define sipName_SelectItems &sipStrings_QtWidgets[54688]
#define sipNameNr_Shadow_Mask 54700
#define sipName_Shadow_Mask &sipStrings_QtWidgets[54700]
#define sipNameNr_State_Small 54712
#define sipName_State_Small &sipStrings_QtWidgets[54712]
#define sipNameNr_StyledPanel 54724
#define sipName_StyledPanel &sipStrings_QtWidgets[54724]
#define sipNameNr_TabPosition 6101
#define sipName_TabPosition &sipStrings_QtWidgets[6101]
#define sipNameNr_TopToBottom 54736
#define sipName_TopToBottom &sipStrings_QtWidgets[54736]
#define sipNameNr_UseDelegate 54748
#define sipName_UseDelegate &sipStrings_QtWidgets[54748]
#define sipNameNr_WidgetWidth 54760
#define sipName_WidgetWidth &sipStrings_QtWidgets[54760]
#define sipNameNr_WindowOrder 19447
#define sipName_WindowOrder &sipStrings_QtWidgets[19447]
#define sipNameNr_WizardStyle 22220
#define sipName_WizardStyle &sipStrings_QtWidgets[22220]
#define sipNameNr_WrapAllRows 54772
#define sipName_WrapAllRows &sipStrings_QtWidgets[54772]
#define sipNameNr_YearSection 54784
#define sipName_YearSection &sipStrings_QtWidgets[54784]
#define sipNameNr_aboutToHide 54796
#define sipName_aboutToHide &sipStrings_QtWidgets[54796]
#define sipNameNr_aboutToShow 54808
#define sipName_aboutToShow &sipStrings_QtWidgets[54808]
#define sipNameNr_acceptDrops 54820
#define sipName_acceptDrops &sipStrings_QtWidgets[54820]
#define sipNameNr_actionEvent 54832
#define sipName_actionEvent &sipStrings_QtWidgets[54832]
#define sipNameNr_activePanel 54844
#define sipName_activePanel &sipStrings_QtWidgets[54844]
#define sipNameNr_addChildren 54856
#define sipName_addChildren &sipStrings_QtWidgets[54856]
#define sipNameNr_alignedRect 54868
#define sipName_alignedRect &sipStrings_QtWidgets[54868]
#define sipNameNr_autoDefault 54880
#define sipName_autoDefault &sipStrings_QtWidgets[54880]
#define sipNameNr_axisChanged 54892
#define sipName_axisChanged &sipStrings_QtWidgets[54892]
#define sipNameNr_bottomToTop 54904
#define sipName_bottomToTop &sipStrings_QtWidgets[54904]
#define sipNameNr_cellChanged 54916
#define sipName_cellChanged &sipStrings_QtWidgets[54916]
#define sipNameNr_cellClicked 54928
#define sipName_cellClicked &sipStrings_QtWidgets[54928]
#define sipNameNr_cellEntered 54940
#define sipName_cellEntered &sipStrings_QtWidgets[54940]
#define sipNameNr_cellPressed 54952
#define sipName_cellPressed &sipStrings_QtWidgets[54952]
#define sipNameNr_centerPoint 54964
#define sipName_centerPoint &sipStrings_QtWidgets[54964]
#define sipNameNr_changeEvent 54976
#define sipName_changeEvent &sipStrings_QtWidgets[54976]
#define sipNameNr_changeFlags 54988
#define sipName_changeFlags &sipStrings_QtWidgets[54988]
#define sipNameNr_cleanupPage 55000
#define sipName_cleanupPage &sipStrings_QtWidgets[55000]
#define sipNameNr_closeEditor 55012
#define sipName_closeEditor &sipStrings_QtWidgets[55012]
#define sipNameNr_collapseAll 55024
#define sipName_collapseAll &sipStrings_QtWidgets[55024]
#define sipNameNr_columnCount 55036
#define sipName_columnCount &sipStrings_QtWidgets[55036]
#define sipNameNr_columnMoved 55048
#define sipName_columnMoved &sipStrings_QtWidgets[55048]
#define sipNameNr_columnWidth 55060
#define sipName_columnWidth &sipStrings_QtWidgets[55060]
#define sipNameNr_contextMenu 55072
#define sipName_contextMenu &sipStrings_QtWidgets[55072]
#define sipNameNr_controlType 55084
#define sipName_controlType &sipStrings_QtWidgets[55084]
#define sipNameNr_currentData 55096
#define sipName_currentData &sipStrings_QtWidgets[55096]
#define sipNameNr_currentFont 55108
#define sipName_currentFont &sipStrings_QtWidgets[55108]
#define sipNameNr_currentIcon 55120
#define sipName_currentIcon &sipStrings_QtWidgets[55120]
#define sipNameNr_currentItem 55132
#define sipName_currentItem &sipStrings_QtWidgets[55132]
#define sipNameNr_currentPage 55144
#define sipName_currentPage &sipStrings_QtWidgets[55144]
#define sipNameNr_currentText 55156
#define sipName_currentText &sipStrings_QtWidgets[55156]
#define sipNameNr_cursorWidth 55168
#define sipName_cursorWidth &sipStrings_QtWidgets[55168]
#define sipNameNr_customColor 55180
#define sipName_customColor &sipStrings_QtWidgets[55180]
#define sipNameNr_customCount 55192
#define sipName_customCount &sipStrings_QtWidgets[55192]
#define sipNameNr_customEvent 55204
#define sipName_customEvent &sipStrings_QtWidgets[55204]
#define sipNameNr_dataChanged 55216
#define sipName_dataChanged &sipStrings_QtWidgets[55216]
#define sipNameNr_dateChanged 55228
#define sipName_dateChanged &sipStrings_QtWidgets[55228]
#define sipNameNr_description 55240
#define sipName_description &sipStrings_QtWidgets[55240]
#define sipNameNr_displayFont 55252
#define sipName_displayFont &sipStrings_QtWidgets[55252]
#define sipNameNr_displayText 55264
#define sipName_displayText &sipStrings_QtWidgets[55264]
#define sipNameNr_doSetSource 55276
#define sipName_doSetSource &sipStrings_QtWidgets[55276]
#define sipNameNr_dockOptions 55288
#define sipName_dockOptions &sipStrings_QtWidgets[55288]
#define sipNameNr_doubleValue 55300
#define sipName_doubleValue &sipStrings_QtWidgets[55300]
#define sipNameNr_dragEnabled 55312
#define sipName_dragEnabled &sipStrings_QtWidgets[55312]
#define sipNameNr_drawControl 55324
#define sipName_drawControl &sipStrings_QtWidgets[55324]
#define sipNameNr_drawDisplay 55336
#define sipName_drawDisplay &sipStrings_QtWidgets[55336]
#define sipNameNr_editorEvent 55348
#define sipName_editorEvent &sipStrings_QtWidgets[55348]
#define sipNameNr_eventFilter 55360
#define sipName_eventFilter &sipStrings_QtWidgets[55360]
#define sipNameNr_exposedRect 55372
#define sipName_exposedRect &sipStrings_QtWidgets[55372]
#define sipNameNr_focusPolicy 55384
#define sipName_focusPolicy &sipStrings_QtWidgets[55384]
#define sipNameNr_focusReason 55396
#define sipName_focusReason &sipStrings_QtWidgets[55396]
#define sipNameNr_focusWidget 55408
#define sipName_focusWidget &sipStrings_QtWidgets[55408]
#define sipNameNr_fontFilters 55420
#define sipName_fontFilters &sipStrings_QtWidgets[55420]
#define sipNameNr_fontMetrics 55432
#define sipName_fontMetrics &sipStrings_QtWidgets[55432]
#define sipNameNr_frameShadow 55444
#define sipName_frameShadow &sipStrings_QtWidgets[55444]
#define sipNameNr_gestureType 55456
#define sipName_gestureType &sipStrings_QtWidgets[55456]
#define sipNameNr_grabGesture 50223
#define sipName_grabGesture &sipStrings_QtWidgets[50223]
#define sipNameNr_handleInput 55468
#define sipName_handleInput &sipStrings_QtWidgets[55468]
#define sipNameNr_handleWidth 55480
#define sipName_handleWidth &sipStrings_QtWidgets[55480]
#define sipNameNr_hasClipping 55492
#define sipName_hasClipping &sipStrings_QtWidgets[55492]
#define sipNameNr_hasScroller 55504
#define sipName_hasScroller &sipStrings_QtWidgets[55504]
#define sipNameNr_hasTracking 55516
#define sipName_hasTracking &sipStrings_QtWidgets[55516]
#define sipNameNr_hideSection 55528
#define sipName_hideSection &sipStrings_QtWidgets[55528]
#define sipNameNr_highlighted 55540
#define sipName_highlighted &sipStrings_QtWidgets[55540]
#define sipNameNr_indentation 55552
#define sipName_indentation &sipStrings_QtWidgets[55552]
#define sipNameNr_indexWidget 55564
#define sipName_indexWidget &sipStrings_QtWidgets[55564]
#define sipNameNr_information 55576
#define sipName_information &sipStrings_QtWidgets[55576]
#define sipNameNr_initPainter 55588
#define sipName_initPainter &sipStrings_QtWidgets[55588]
#define sipNameNr_insertChild 55600
#define sipName_insertChild &sipStrings_QtWidgets[55600]
#define sipNameNr_insertItems 55612
#define sipName_insertItems &sipStrings_QtWidgets[55612]
#define sipNameNr_isActivated 55624
#define sipName_isActivated &sipStrings_QtWidgets[55624]
#define sipNameNr_isCheckable 55636
#define sipName_isCheckable &sipStrings_QtWidgets[55636]
#define sipNameNr_isDefaultUp 55648
#define sipName_isDefaultUp &sipStrings_QtWidgets[55648]
#define sipNameNr_isEnabledTo 55660
#define sipName_isEnabledTo &sipStrings_QtWidgets[55660]
#define sipNameNr_isFinalPage 55672
#define sipName_isFinalPage &sipStrings_QtWidgets[55672]
#define sipNameNr_isFloatable 55684
#define sipName_isFloatable &sipStrings_QtWidgets[55684]
#define sipNameNr_isMaximized 55696
#define sipName_isMaximized &sipStrings_QtWidgets[55696]
#define sipNameNr_isMinimized 55708
#define sipName_isMinimized &sipStrings_QtWidgets[55708]
#define sipNameNr_isRowHidden 55720
#define sipName_isRowHidden &sipStrings_QtWidgets[55720]
#define sipNameNr_isSeparator 55732
#define sipName_isSeparator &sipStrings_QtWidgets[55732]
#define sipNameNr_isVisibleTo 55744
#define sipName_isVisibleTo &sipStrings_QtWidgets[55744]
#define sipNameNr_itemChanged 55756
#define sipName_itemChanged &sipStrings_QtWidgets[55756]
#define sipNameNr_itemClicked 55768
#define sipName_itemClicked &sipStrings_QtWidgets[55768]
#define sipNameNr_itemEntered 55780
#define sipName_itemEntered &sipStrings_QtWidgets[55780]
#define sipNameNr_itemPressed 55792
#define sipName_itemPressed &sipStrings_QtWidgets[55792]
#define sipNameNr_itemRemoved 55804
#define sipName_itemRemoved &sipStrings_QtWidgets[55804]
#define sipNameNr_itemSpacing 55816
#define sipName_itemSpacing &sipStrings_QtWidgets[55816]
#define sipNameNr_itemToolTip 55828
#define sipName_itemToolTip &sipStrings_QtWidgets[55828]
#define sipNameNr_keySequence 55840
#define sipName_keySequence &sipStrings_QtWidgets[55840]
#define sipNameNr_linkHovered 55852
#define sipName_linkHovered &sipStrings_QtWidgets[55852]
#define sipNameNr_mapFromItem 55864
#define sipName_mapFromItem &sipStrings_QtWidgets[55864]
#define sipNameNr_mapToGlobal 55876
#define sipName_mapToGlobal &sipStrings_QtWidgets[55876]
#define sipNameNr_mapToParent 55888
#define sipName_mapToParent &sipStrings_QtWidgets[55888]
#define sipNameNr_maximumDate 55900
#define sipName_maximumDate &sipStrings_QtWidgets[55900]
#define sipNameNr_maximumSize 55912
#define sipName_maximumSize &sipStrings_QtWidgets[55912]
#define sipNameNr_maximumTime 55924
#define sipName_maximumTime &sipStrings_QtWidgets[55924]
#define sipNameNr_minimumDate 55936
#define sipName_minimumDate &sipStrings_QtWidgets[55936]
#define sipNameNr_minimumSize 55948
#define sipName_minimumSize &sipStrings_QtWidgets[55948]
#define sipNameNr_minimumTime 55960
#define sipName_minimumTime &sipStrings_QtWidgets[55960]
#define sipNameNr_modelColumn 55972
#define sipName_modelColumn &sipStrings_QtWidgets[55972]
#define sipNameNr_moveSection 55984
#define sipName_moveSection &sipStrings_QtWidgets[55984]
#define sipNameNr_nameFilters 55996
#define sipName_nameFilters &sipStrings_QtWidgets[55996]
#define sipNameNr_nativeEvent 56008
#define sipName_nativeEvent &sipStrings_QtWidgets[56008]
#define sipNameNr_notchTarget 56020
#define sipName_notchTarget &sipStrings_QtWidgets[56020]
#define sipNameNr_opacityMask 56032
#define sipName_opacityMask &sipStrings_QtWidgets[56032]
#define sipNameNr_orientation 56044
#define sipName_orientation &sipStrings_QtWidgets[56044]
#define sipNameNr_pageRemoved 56056
#define sipName_pageRemoved &sipStrings_QtWidgets[56056]
#define sipNameNr_paintEngine 56068
#define sipName_paintEngine &sipStrings_QtWidgets[56068]
#define sipNameNr_pixelMetric 56080
#define sipName_pixelMetric &sipStrings_QtWidgets[56080]
#define sipNameNr_polishEvent 56092
#define sipName_polishEvent &sipStrings_QtWidgets[56092]
#define sipNameNr_removeChild 56104
#define sipName_removeChild &sipStrings_QtWidgets[56104]
#define sipNameNr_renderHints 56116
#define sipName_renderHints &sipStrings_QtWidgets[56116]
#define sipNameNr_resetFormat 56128
#define sipName_resetFormat &sipStrings_QtWidgets[56128]
#define sipNameNr_resizeDocks 56140
#define sipName_resizeDocks &sipStrings_QtWidgets[56140]
#define sipNameNr_resizeEvent 56152
#define sipName_resizeEvent &sipStrings_QtWidgets[56152]
#define sipNameNr_rightColumn 56164
#define sipName_rightColumn &sipStrings_QtWidgets[56164]
#define sipNameNr_rowsRemoved 56176
#define sipName_rowsRemoved &sipStrings_QtWidgets[56176]
#define sipNameNr_scaleFactor 56188
#define sipName_scaleFactor &sipStrings_QtWidgets[56188]
#define sipNameNr_scrollToTop 56200
#define sipName_scrollToTop &sipStrings_QtWidgets[56200]
#define sipNameNr_searchPaths 56212
#define sipName_searchPaths &sipStrings_QtWidgets[56212]
#define sipNameNr_sectionSize 56224
#define sipName_sectionSize &sipStrings_QtWidgets[56224]
#define sipNameNr_sectionText 56236
#define sipName_sectionText &sipStrings_QtWidgets[56236]
#define sipNameNr_setAccepted 56248
#define sipName_setAccepted &sipStrings_QtWidgets[56248]
#define sipNameNr_setAnimated 56260
#define sipName_setAnimated &sipStrings_QtWidgets[56260]
#define sipNameNr_setAutoHide 56272
#define sipName_setAutoHide &sipStrings_QtWidgets[56272]
#define sipNameNr_setBaseSize 56284
#define sipName_setBaseSize &sipStrings_QtWidgets[56284]
#define sipNameNr_setCalendar 56296
#define sipName_setCalendar &sipStrings_QtWidgets[56296]
#define sipNameNr_setCheckBox 56308
#define sipName_setCheckBox &sipStrings_QtWidgets[56308]
#define sipNameNr_setClipping 56320
#define sipName_setClipping &sipStrings_QtWidgets[56320]
#define sipNameNr_setDateTime 56332
#define sipName_setDateTime &sipStrings_QtWidgets[56332]
#define sipNameNr_setDecimals 56344
#define sipName_setDecimals &sipStrings_QtWidgets[56344]
#define sipNameNr_setDisabled 56356
#define sipName_setDisabled &sipStrings_QtWidgets[56356]
#define sipNameNr_setDocument 56368
#define sipName_setDocument &sipStrings_QtWidgets[56368]
#define sipNameNr_setDragMode 56380
#define sipName_setDragMode &sipStrings_QtWidgets[56380]
#define sipNameNr_setDrawBase 56392
#define sipName_setDrawBase &sipStrings_QtWidgets[56392]
#define sipNameNr_setEchoMode 56404
#define sipName_setEchoMode &sipStrings_QtWidgets[56404]
#define sipNameNr_setEditText 56416
#define sipName_setEditText &sipStrings_QtWidgets[56416]
#define sipNameNr_setEditable 56428
#define sipName_setEditable &sipStrings_QtWidgets[56428]
#define sipNameNr_setExpanded 56440
#define sipName_setExpanded &sipStrings_QtWidgets[56440]
#define sipNameNr_setFeatures 56452
#define sipName_setFeatures &sipStrings_QtWidgets[56452]
#define sipNameNr_setFileMode 56464
#define sipName_setFileMode &sipStrings_QtWidgets[56464]
#define sipNameNr_setFillRule 56476
#define sipName_setFillRule &sipStrings_QtWidgets[56476]
#define sipNameNr_setFloating 56488
#define sipName_setFloating &sipStrings_QtWidgets[56488]
#define sipNameNr_setGeometry 56500
#define sipName_setGeometry &sipStrings_QtWidgets[56500]
#define sipNameNr_setGridSize 56512
#define sipName_setGridSize &sipStrings_QtWidgets[56512]
#define sipNameNr_setIconSize 56524
#define sipName_setIconSize &sipStrings_QtWidgets[56524]
#define sipNameNr_setIntRange 56536
#define sipName_setIntRange &sipStrings_QtWidgets[56536]
#define sipNameNr_setIntValue 56548
#define sipName_setIntValue &sipStrings_QtWidgets[56548]
#define sipNameNr_setItemData 56560
#define sipName_setItemData &sipStrings_QtWidgets[56560]
#define sipNameNr_setItemIcon 56572
#define sipName_setItemIcon &sipStrings_QtWidgets[56572]
#define sipNameNr_setItemText 56584
#define sipName_setItemText &sipStrings_QtWidgets[56584]
#define sipNameNr_setLineEdit 56596
#define sipName_setLineEdit &sipStrings_QtWidgets[56596]
#define sipNameNr_setMarkdown 56608
#define sipName_setMarkdown &sipStrings_QtWidgets[56608]
#define sipNameNr_setMaxCount 56620
#define sipName_setMaxCount &sipStrings_QtWidgets[56620]
#define sipNameNr_setModified 56632
#define sipName_setModified &sipStrings_QtWidgets[56632]
#define sipNameNr_setMovement 56644
#define sipName_setMovement &sipStrings_QtWidgets[56644]
#define sipNameNr_setPageStep 56656
#define sipName_setPageStep &sipStrings_QtWidgets[56656]
#define sipNameNr_setPosition 56668
#define sipName_setPosition &sipStrings_QtWidgets[56668]
#define sipNameNr_setReadOnly 56680
#define sipName_setReadOnly &sipStrings_QtWidgets[56680]
#define sipNameNr_setRotation 56692
#define sipName_setRotation &sipStrings_QtWidgets[56692]
#define sipNameNr_setRowCount 56704
#define sipName_setRowCount &sipStrings_QtWidgets[56704]
#define sipNameNr_setSelected 56716
#define sipName_setSelected &sipStrings_QtWidgets[56716]
#define sipNameNr_setShortcut 56728
#define sipName_setShortcut &sipStrings_QtWidgets[56728]
#define sipNameNr_setShowGrid 56740
#define sipName_setShowGrid &sipStrings_QtWidgets[56740]
#define sipNameNr_setSizeHint 56752
#define sipName_setSizeHint &sipStrings_QtWidgets[56752]
#define sipNameNr_setStepType 56764
#define sipName_setStepType &sipStrings_QtWidgets[56764]
#define sipNameNr_setStrength 56776
#define sipName_setStrength &sipStrings_QtWidgets[56776]
#define sipNameNr_setSubTitle 56788
#define sipName_setSubTitle &sipStrings_QtWidgets[56788]
#define sipNameNr_setTabOrder 56800
#define sipName_setTabOrder &sipStrings_QtWidgets[56800]
#define sipNameNr_setTabShape 56812
#define sipName_setTabShape &sipStrings_QtWidgets[56812]
#define sipNameNr_setTimeSpec 56824
#define sipName_setTimeSpec &sipStrings_QtWidgets[56824]
#define sipNameNr_setTimeZone 56836
#define sipName_setTimeZone &sipStrings_QtWidgets[56836]
#define sipNameNr_setTracking 56848
#define sipName_setTracking &sipStrings_QtWidgets[56848]
#define sipNameNr_setTristate 56860
#define sipName_setTristate &sipStrings_QtWidgets[56860]
#define sipNameNr_setViewMode 56872
#define sipName_setViewMode &sipStrings_QtWidgets[56872]
#define sipNameNr_setViewport 56884
#define sipName_setViewport &sipStrings_QtWidgets[56884]
#define sipNameNr_setWordWrap 56896
#define sipName_setWordWrap &sipStrings_QtWidgets[56896]
#define sipNameNr_setWrapping 56908
#define sipName_setWrapping &sipStrings_QtWidgets[56908]
#define sipNameNr_showMessage 56920
#define sipName_showMessage &sipStrings_QtWidgets[56920]
#define sipNameNr_showSection 56932
#define sipName_showSection &sipStrings_QtWidgets[56932]
#define sipNameNr_sidebarUrls 56944
#define sipName_sidebarUrls &sipStrings_QtWidgets[56944]
#define sipNameNr_sliderMoved 56956
#define sipName_sliderMoved &sipStrings_QtWidgets[56956]
#define sipNameNr_sliderValue 56968
#define sipName_sliderValue &sipStrings_QtWidgets[56968]
#define sipNameNr_stackBefore 56980
#define sipName_stackBefore &sipStrings_QtWidgets[56980]
#define sipNameNr_stepEnabled 56992
#define sipName_stepEnabled &sipStrings_QtWidgets[56992]
#define sipNameNr_stickyFocus 57004
#define sipName_stickyFocus &sipStrings_QtWidgets[57004]
#define sipNameNr_styleObject 57016
#define sipName_styleObject &sipStrings_QtWidgets[57016]
#define sipNameNr_subControls 57028
#define sipName_subControls &sipStrings_QtWidgets[57028]
#define sipNameNr_tabInserted 57040
#define sipName_tabInserted &sipStrings_QtWidgets[57040]
#define sipNameNr_tabPosition 57052
#define sipName_tabPosition &sipStrings_QtWidgets[57052]
#define sipNameNr_tabSizeHint 57064
#define sipName_tabSizeHint &sipStrings_QtWidgets[57064]
#define sipNameNr_tableWidget 57076
#define sipName_tableWidget &sipStrings_QtWidgets[57076]
#define sipNameNr_tabletEvent 57088
#define sipName_tabletEvent &sipStrings_QtWidgets[57088]
#define sipNameNr_tabsMovable 57100
#define sipName_tabsMovable &sipStrings_QtWidgets[57100]
#define sipNameNr_textChanged 57112
#define sipName_textChanged &sipStrings_QtWidgets[57112]
#define sipNameNr_textMargins 57124
#define sipName_textMargins &sipStrings_QtWidgets[57124]
#define sipNameNr_textVisible 57136
#define sipName_textVisible &sipStrings_QtWidgets[57136]
#define sipNameNr_timeChanged 57148
#define sipName_timeChanged &sipStrings_QtWidgets[57148]
#define sipNameNr_titleFormat 57160
#define sipName_titleFormat &sipStrings_QtWidgets[57160]
#define sipNameNr_toPlainText 57172
#define sipName_toPlainText &sipStrings_QtWidgets[57172]
#define sipNameNr_toolBarArea 57184
#define sipName_toolBarArea &sipStrings_QtWidgets[57184]
#define sipNameNr_ungrabMouse 57196
#define sipName_ungrabMouse &sipStrings_QtWidgets[57196]
#define sipNameNr_unsetCursor 57208
#define sipName_unsetCursor &sipStrings_QtWidgets[57208]
#define sipNameNr_unsetLocale 57220
#define sipName_unsetLocale &sipStrings_QtWidgets[57220]
#define sipNameNr_updateCells 57232
#define sipName_updateCells &sipStrings_QtWidgets[57232]
#define sipNameNr_updateScene 57244
#define sipName_updateScene &sipStrings_QtWidgets[57244]
#define sipNameNr_urlSelected 57256
#define sipName_urlSelected &sipStrings_QtWidgets[57256]
#define sipNameNr_visualIndex 57268
#define sipName_visualIndex &sipStrings_QtWidgets[57268]
#define sipNameNr_wasCanceled 57280
#define sipName_wasCanceled &sipStrings_QtWidgets[57280]
#define sipNameNr_widgetAdded 57292
#define sipName_widgetAdded &sipStrings_QtWidgets[57292]
#define sipNameNr_widgetEvent 57304
#define sipName_widgetEvent &sipStrings_QtWidgets[57304]
#define sipNameNr_windowFlags 57316
#define sipName_windowFlags &sipStrings_QtWidgets[57316]
#define sipNameNr_windowState 57328
#define sipName_windowState &sipStrings_QtWidgets[57328]
#define sipNameNr_windowTitle 57340
#define sipName_windowTitle &sipStrings_QtWidgets[57340]
#define sipNameNr_wizardStyle 57352
#define sipName_wizardStyle &sipStrings_QtWidgets[57352]
#define sipNameNr_AcceptMode 14858
#define sipName_AcceptMode &sipStrings_QtWidgets[14858]
#define sipNameNr_AcceptOpen 57364
#define sipName_AcceptOpen &sipStrings_QtWidgets[57364]
#define sipNameNr_AcceptRole 57375
#define sipName_AcceptRole &sipStrings_QtWidgets[57375]
#define sipNameNr_AcceptSave 57386
#define sipName_AcceptSave &sipStrings_QtWidgets[57386]
#define sipNameNr_ActionRole 57397
#define sipName_ActionRole &sipStrings_QtWidgets[57397]
#define sipNameNr_AreaOption 21990
#define sipName_AreaOption &sipStrings_QtWidgets[21990]
#define sipNameNr_AutoSubmit 57408
#define sipName_AutoSubmit &sipStrings_QtWidgets[57408]
#define sipNameNr_BackButton 57419
#define sipName_BackButton &sipStrings_QtWidgets[57419]
#define sipNameNr_ButtonMask 57430
#define sipName_ButtonMask &sipStrings_QtWidgets[57430]
#define sipNameNr_ButtonRole 8903
#define sipName_ButtonRole &sipStrings_QtWidgets[8903]
#define sipNameNr_CC_SpinBox 57441
#define sipName_CC_SpinBox &sipStrings_QtWidgets[57441]
#define sipNameNr_CE_ToolBar 57452
#define sipName_CE_ToolBar &sipStrings_QtWidgets[57452]
#define sipNameNr_CT_MenuBar 57463
#define sipName_CT_MenuBar &sipStrings_QtWidgets[57463]
#define sipNameNr_CT_SpinBox 57474
#define sipName_CT_SpinBox &sipStrings_QtWidgets[57474]
#define sipNameNr_CancelNone 57485
#define sipName_CancelNone &sipStrings_QtWidgets[57485]
#define sipNameNr_ChangeFlag 9987
#define sipName_ChangeFlag &sipStrings_QtWidgets[9987]
#define sipNameNr_DaySection 57496
#define sipName_DaySection &sipStrings_QtWidgets[57496]
#define sipNameNr_DialogCode 24940
#define sipName_DialogCode &sipStrings_QtWidgets[24940]
#define sipNameNr_DockOption 15146
#define sipName_DockOption &sipStrings_QtWidgets[15146]
#define sipNameNr_ExpandFlag 57507
#define sipName_ExpandFlag &sipStrings_QtWidgets[57507]
#define sipNameNr_FontFilter 12037
#define sipName_FontFilter &sipStrings_QtWidgets[12037]
#define sipNameNr_FrameRates 6618
#define sipName_FrameRates &sipStrings_QtWidgets[6618]
#define sipNameNr_HasDisplay 57518
#define sipName_HasDisplay &sipStrings_QtWidgets[57518]
#define sipNameNr_HelpButton 9164
#define sipName_HelpButton &sipStrings_QtWidgets[9164]
#define sipNameNr_IgnoreFlag 57529
#define sipName_IgnoreFlag &sipStrings_QtWidgets[57529]
#define sipNameNr_IgnoreMask 57540
#define sipName_IgnoreMask &sipStrings_QtWidgets[57540]
#define sipNameNr_InputPress 57551
#define sipName_InputPress &sipStrings_QtWidgets[57551]
#define sipNameNr_LastButton 57562
#define sipName_LastButton &sipStrings_QtWidgets[57562]
#define sipNameNr_LayoutMode 19404
#define sipName_LayoutMode &sipStrings_QtWidgets[19404]
#define sipNameNr_LogoPixmap 57573
#define sipName_LogoPixmap &sipStrings_QtWidgets[57573]
#define sipNameNr_MovePageUp 57584
#define sipName_MovePageUp &sipStrings_QtWidgets[57584]
#define sipNameNr_NextButton 57595
#define sipName_NextButton &sipStrings_QtWidgets[57595]
#define sipNameNr_NoChildren 57606
#define sipName_NoChildren &sipStrings_QtWidgets[57606]
#define sipNameNr_NoDragDrop 57617
#define sipName_NoDragDrop &sipStrings_QtWidgets[57617]
#define sipNameNr_NotChecked 57628
#define sipName_NotChecked &sipStrings_QtWidgets[57628]
#define sipNameNr_OnViewport 57639
#define sipName_OnViewport &sipStrings_QtWidgets[57639]
#define sipNameNr_OnlyOneTab 57650
#define sipName_OnlyOneTab &sipStrings_QtWidgets[57650]
#define sipNameNr_OptionType 494
#define sipName_OptionType &sipStrings_QtWidgets[494]
#define sipNameNr_PanelModal 57661
#define sipName_PanelModal &sipStrings_QtWidgets[57661]
#define sipNameNr_PolicyFlag 15218
#define sipName_PolicyFlag &sipStrings_QtWidgets[15218]
#define sipNameNr_PopupDelay 12401
#define sipName_PopupDelay &sipStrings_QtWidgets[12401]
#define sipNameNr_PushButton 46402
#define sipName_PushButton &sipStrings_QtWidgets[46402]
#define sipNameNr_QBoxLayout 57672
#define sipName_QBoxLayout &sipStrings_QtWidgets[57672]
#define sipNameNr_QCompleter 57683
#define sipName_QCompleter &sipStrings_QtWidgets[57683]
#define sipNameNr_QLCDNumber 57694
#define sipName_QLCDNumber &sipStrings_QtWidgets[57694]
#define sipNameNr_QScrollBar 57705
#define sipName_QScrollBar &sipStrings_QtWidgets[57705]
#define sipNameNr_QStatusBar 57716
#define sipName_QStatusBar &sipStrings_QtWidgets[57716]
#define sipNameNr_QTabWidget 57727
#define sipName_QTabWidget &sipStrings_QtWidgets[57727]
#define sipNameNr_QTableView 57738
#define sipName_QTableView &sipStrings_QtWidgets[57738]
#define sipNameNr_QWhatsThis 57749
#define sipName_QWhatsThis &sipStrings_QtWidgets[57749]
#define sipNameNr_RejectRole 57760
#define sipName_RejectRole &sipStrings_QtWidgets[57760]
#define sipNameNr_RenderFlag 25340
#define sipName_RenderFlag &sipStrings_QtWidgets[25340]
#define sipNameNr_ResizeMode 15002
#define sipName_ResizeMode &sipStrings_QtWidgets[15002]
#define sipNameNr_ResultFlag 7246
#define sipName_ResultFlag &sipStrings_QtWidgets[7246]
#define sipNameNr_SH_Default 57771
#define sipName_SH_Default &sipStrings_QtWidgets[57771]
#define sipNameNr_SH_Variant 57782
#define sipName_SH_Variant &sipStrings_QtWidgets[57782]
#define sipNameNr_SO_Complex 57793
#define sipName_SO_Complex &sipStrings_QtWidgets[57793]
#define sipNameNr_SO_Default 57804
#define sipName_SO_Default &sipStrings_QtWidgets[57804]
#define sipNameNr_SO_SpinBox 57815
#define sipName_SO_SpinBox &sipStrings_QtWidgets[57815]
#define sipNameNr_SO_ToolBar 57826
#define sipName_SO_ToolBar &sipStrings_QtWidgets[57826]
#define sipNameNr_SO_ToolBox 57837
#define sipName_SO_ToolBox &sipStrings_QtWidgets[57837]
#define sipNameNr_SP_ArrowUp 57848
#define sipName_SP_ArrowUp &sipStrings_QtWidgets[57848]
#define sipNameNr_SP_DirIcon 57859
#define sipName_SP_DirIcon &sipStrings_QtWidgets[57859]
#define sipNameNr_SceneLayer 10976
#define sipName_SceneLayer &sipStrings_QtWidgets[10976]
#define sipNameNr_SceneModal 57870
#define sipName_SceneModal &sipStrings_QtWidgets[57870]
#define sipNameNr_ScrollHint 7952
#define sipName_ScrollHint &sipStrings_QtWidgets[7952]
#define sipNameNr_ScrollMode 7982
#define sipName_ScrollMode &sipStrings_QtWidgets[7982]
#define sipNameNr_SelectRows 57881
#define sipName_SelectRows &sipStrings_QtWidgets[57881]
#define sipNameNr_Selectable 35059
#define sipName_Selectable &sipStrings_QtWidgets[35059]
#define sipNameNr_Shape_Mask 57892
#define sipName_Shape_Mask &sipStrings_QtWidgets[57892]
#define sipNameNr_ShrinkFlag 57903
#define sipName_ShrinkFlag &sipStrings_QtWidgets[57903]
#define sipNameNr_SinglePass 57914
#define sipName_SinglePass &sipStrings_QtWidgets[57914]
#define sipNameNr_SliderMove 57925
#define sipName_SliderMove &sipStrings_QtWidgets[57925]
#define sipNameNr_State_Item 57936
#define sipName_State_Item &sipStrings_QtWidgets[57936]
#define sipNameNr_State_Mini 57947
#define sipName_State_Mini &sipStrings_QtWidgets[57947]
#define sipNameNr_State_None 57958
#define sipName_State_None &sipStrings_QtWidgets[57958]
#define sipNameNr_State_Open 57969
#define sipName_State_Open &sipStrings_QtWidgets[57969]
#define sipNameNr_SubControl 28353
#define sipName_SubControl &sipStrings_QtWidgets[28353]
#define sipNameNr_SubElement 28372
#define sipName_SubElement &sipStrings_QtWidgets[28372]
#define sipNameNr_TabFeature 10099
#define sipName_TabFeature &sipStrings_QtWidgets[10099]
#define sipNameNr_TabbedView 57980
#define sipName_TabbedView &sipStrings_QtWidgets[57980]
#define sipNameNr_TicksAbove 57991
#define sipName_TicksAbove &sipStrings_QtWidgets[57991]
#define sipNameNr_TicksBelow 58002
#define sipName_TicksBelow &sipStrings_QtWidgets[58002]
#define sipNameNr_TicksRight 58013
#define sipName_TicksRight &sipStrings_QtWidgets[58013]
#define sipNameNr_ToolButton 17347
#define sipName_ToolButton &sipStrings_QtWidgets[17347]
#define sipNameNr_Triangular 58024
#define sipName_Triangular &sipStrings_QtWidgets[58024]
#define sipNameNr_Unselected 58035
#define sipName_Unselected &sipStrings_QtWidgets[58035]
#define sipNameNr___lshift__ 58046
#define sipName___lshift__ &sipStrings_QtWidgets[58046]
#define sipNameNr___rshift__ 58057
#define sipName___rshift__ &sipStrings_QtWidgets[58057]
#define sipNameNr_acceptMode 58068
#define sipName_acceptMode &sipStrings_QtWidgets[58068]
#define sipNameNr_addActions 58079
#define sipName_addActions &sipStrings_QtWidgets[58079]
#define sipNameNr_addAnchors 58090
#define sipName_addAnchors &sipStrings_QtWidgets[58090]
#define sipNameNr_addEllipse 58101
#define sipName_addEllipse &sipStrings_QtWidgets[58101]
#define sipNameNr_addMapping 58112
#define sipName_addMapping &sipStrings_QtWidgets[58112]
#define sipNameNr_addPolygon 58123
#define sipName_addPolygon &sipStrings_QtWidgets[58123]
#define sipNameNr_addSection 58134
#define sipName_addSection &sipStrings_QtWidgets[58134]
#define sipNameNr_addSpacing 58145
#define sipName_addSpacing &sipStrings_QtWidgets[58145]
#define sipNameNr_addStretch 58156
#define sipName_addStretch &sipStrings_QtWidgets[58156]
#define sipNameNr_addToGroup 58167
#define sipName_addToGroup &sipStrings_QtWidgets[58167]
#define sipNameNr_addToolBar 58178
#define sipName_addToolBar &sipStrings_QtWidgets[58178]
#define sipNameNr_adjustSize 58189
#define sipName_adjustSize &sipStrings_QtWidgets[58189]
#define sipNameNr_allWidgets 58200
#define sipName_allWidgets &sipStrings_QtWidgets[58200]
#define sipNameNr_appendHtml 58211
#define sipName_appendHtml &sipStrings_QtWidgets[58211]
#define sipNameNr_autoRepeat 58222
#define sipName_autoRepeat &sipStrings_QtWidgets[58222]
#define sipNameNr_background 58233
#define sipName_background &sipStrings_QtWidgets[58233]
#define sipNameNr_blockCount 58244
#define sipName_blockCount &sipStrings_QtWidgets[58244]
#define sipNameNr_blurRadius 58255
#define sipName_blurRadius &sipStrings_QtWidgets[58255]
#define sipNameNr_buttonRole 58266
#define sipName_buttonRole &sipStrings_QtWidgets[58266]
#define sipNameNr_buttonText 58277
#define sipName_buttonText &sipStrings_QtWidgets[58277]
#define sipNameNr_cellWidget 58288
#define sipName_cellWidget &sipStrings_QtWidgets[58288]
#define sipNameNr_changeSize 58299
#define sipName_changeSize &sipStrings_QtWidgets[58299]
#define sipNameNr_checkState 58310
#define sipName_checkState &sipStrings_QtWidgets[58310]
#define sipNameNr_childCount 58321
#define sipName_childCount &sipStrings_QtWidgets[58321]
#define sipNameNr_childEvent 58332
#define sipName_childEvent &sipStrings_QtWidgets[58332]
#define sipNameNr_childItems 58343
#define sipName_childItems &sipStrings_QtWidgets[58343]
#define sipNameNr_clearFocus 58354
#define sipName_clearFocus &sipStrings_QtWidgets[58354]
#define sipNameNr_clearSpans 58365
#define sipName_clearSpans &sipStrings_QtWidgets[58365]
#define sipNameNr_closeEvent 58376
#define sipName_closeEvent &sipStrings_QtWidgets[58376]
#define sipNameNr_columnSpan 58387
#define sipName_columnSpan &sipStrings_QtWidgets[58387]
#define sipNameNr_commitData 58398
#define sipName_commitData &sipStrings_QtWidgets[58398]
#define sipNameNr_constraint 58409
#define sipName_constraint &sipStrings_QtWidgets[58409]
#define sipNameNr_currentRow 58420
#define sipName_currentRow &sipStrings_QtWidgets[58420]
#define sipNameNr_cursorRect 58431
#define sipName_cursorRect &sipStrings_QtWidgets[58431]
#define sipNameNr_digitCount 58442
#define sipName_digitCount &sipStrings_QtWidgets[58442]
#define sipNameNr_doubleStep 58453
#define sipName_doubleStep &sipStrings_QtWidgets[58453]
#define sipNameNr_drawSource 58464
#define sipName_drawSource &sipStrings_QtWidgets[58464]
#define sipNameNr_dropAction 58475
#define sipName_dropAction &sipStrings_QtWidgets[58475]
#define sipNameNr_emptyLabel 58486
#define sipName_emptyLabel &sipStrings_QtWidgets[58486]
#define sipNameNr_enterEvent 58497
#define sipName_enterEvent &sipStrings_QtWidgets[58497]
#define sipNameNr_expandItem 58508
#define sipName_expandItem &sipStrings_QtWidgets[58508]
#define sipNameNr_filterMode 58519
#define sipName_filterMode &sipStrings_QtWidgets[58519]
#define sipNameNr_focusProxy 58530
#define sipName_focusProxy &sipStrings_QtWidgets[58530]
#define sipNameNr_fontFamily 58541
#define sipName_fontFamily &sipStrings_QtWidgets[58541]
#define sipNameNr_fontItalic 58552
#define sipName_fontItalic &sipStrings_QtWidgets[58552]
#define sipNameNr_fontWeight 58563
#define sipName_fontWeight &sipStrings_QtWidgets[58563]
#define sipNameNr_foreground 58574
#define sipName_foreground &sipStrings_QtWidgets[58574]
#define sipNameNr_frameShape 58585
#define sipName_frameShape &sipStrings_QtWidgets[58585]
#define sipNameNr_frameStyle 58596
#define sipName_frameStyle &sipStrings_QtWidgets[58596]
#define sipNameNr_frameWidth 58607
#define sipName_frameWidth &sipStrings_QtWidgets[58607]
#define sipNameNr_hasHotSpot 58618
#define sipName_hasHotSpot &sipStrings_QtWidgets[58618]
#define sipNameNr_headerItem 58629
#define sipName_headerItem &sipStrings_QtWidgets[58629]
#define sipNameNr_hideColumn 58640
#define sipName_hideColumn &sipStrings_QtWidgets[58640]
#define sipNameNr_hideOrShow 58651
#define sipName_hideOrShow &sipStrings_QtWidgets[58651]
#define sipNameNr_historyUrl 58662
#define sipName_historyUrl &sipStrings_QtWidgets[58662]
#define sipNameNr_iconPixmap 58673
#define sipName_iconPixmap &sipStrings_QtWidgets[58673]
#define sipNameNr_idReleased 58684
#define sipName_idReleased &sipStrings_QtWidgets[58684]
#define sipNameNr_indexAbove 58695
#define sipName_indexAbove &sipStrings_QtWidgets[58695]
#define sipNameNr_indexBelow 58706
#define sipName_indexBelow &sipStrings_QtWidgets[58706]
#define sipNameNr_initialize 58717
#define sipName_initialize &sipStrings_QtWidgets[58717]
#define sipNameNr_insertHtml 58728
#define sipName_insertHtml &sipStrings_QtWidgets[58728]
#define sipNameNr_insertItem 58739
#define sipName_insertItem &sipStrings_QtWidgets[58739]
#define sipNameNr_insertMenu 58750
#define sipName_insertMenu &sipStrings_QtWidgets[58750]
#define sipNameNr_intMaximum 58761
#define sipName_intMaximum &sipStrings_QtWidgets[58761]
#define sipNameNr_intMinimum 58772
#define sipName_intMinimum &sipStrings_QtWidgets[58772]
#define sipNameNr_invalidate 58783
#define sipName_invalidate &sipStrings_QtWidgets[58783]
#define sipNameNr_isAccepted 58794
#define sipName_isAccepted &sipStrings_QtWidgets[58794]
#define sipNameNr_isAnimated 58805
#define sipName_isAnimated &sipStrings_QtWidgets[58805]
#define sipNameNr_isComplete 58816
#define sipName_isComplete &sipStrings_QtWidgets[58816]
#define sipNameNr_isDisabled 58827
#define sipName_isDisabled &sipStrings_QtWidgets[58827]
#define sipNameNr_isEditable 58838
#define sipName_isEditable &sipStrings_QtWidgets[58838]
#define sipNameNr_isExpanded 58849
#define sipName_isExpanded &sipStrings_QtWidgets[58849]
#define sipNameNr_isFloating 58860
#define sipName_isFloating &sipStrings_QtWidgets[58860]
#define sipNameNr_isInverted 58871
#define sipName_isInverted &sipStrings_QtWidgets[58871]
#define sipNameNr_isModified 58882
#define sipName_isModified &sipStrings_QtWidgets[58882]
#define sipNameNr_isObscured 58893
#define sipName_isObscured &sipStrings_QtWidgets[58893]
#define sipNameNr_isReadOnly 58904
#define sipName_isReadOnly &sipStrings_QtWidgets[58904]
#define sipNameNr_isSelected 58915
#define sipName_isSelected &sipStrings_QtWidgets[58915]
#define sipNameNr_isTristate 58926
#define sipName_isTristate &sipStrings_QtWidgets[58926]
#define sipNameNr_isWrapping 58937
#define sipName_isWrapping &sipStrings_QtWidgets[58937]
#define sipNameNr_itemChange 58948
#define sipName_itemChange &sipStrings_QtWidgets[58948]
#define sipNameNr_itemWidget 58959
#define sipName_itemWidget &sipStrings_QtWidgets[58959]
#define sipNameNr_lastOffset 58970
#define sipName_lastOffset &sipStrings_QtWidgets[58970]
#define sipNameNr_layoutMode 58981
#define sipName_layoutMode &sipStrings_QtWidgets[58981]
#define sipNameNr_leaveEvent 58992
#define sipName_leaveEvent &sipStrings_QtWidgets[58992]
#define sipNameNr_leftColumn 59003
#define sipName_leftColumn &sipStrings_QtWidgets[59003]
#define sipNameNr_listWidget 59014
#define sipName_listWidget &sipStrings_QtWidgets[59014]
#define sipNameNr_mapToScene 59025
#define sipName_mapToScene &sipStrings_QtWidgets[59025]
#define sipNameNr_menuAction 59036
#define sipName_menuAction &sipStrings_QtWidgets[59036]
#define sipNameNr_menuWidget 59047
#define sipName_menuWidget &sipStrings_QtWidgets[59047]
#define sipNameNr_monthShown 59058
#define sipName_monthShown &sipStrings_QtWidgets[59058]
#define sipNameNr_moveCursor 59069
#define sipName_moveCursor &sipStrings_QtWidgets[59069]
#define sipNameNr_opaqueArea 59080
#define sipName_opaqueArea &sipStrings_QtWidgets[59080]
#define sipNameNr_paintEvent 59091
#define sipName_paintEvent &sipStrings_QtWidgets[59091]
#define sipNameNr_parentItem 59102
#define sipName_parentItem &sipStrings_QtWidgets[59102]
#define sipNameNr_pixelDelta 59113
#define sipName_pixelDelta &sipStrings_QtWidgets[59113]
#define sipNameNr_proxyModel 59124
#define sipName_proxyModel &sipStrings_QtWidgets[59124]
#define sipNameNr_removeItem 59135
#define sipName_removeItem &sipStrings_QtWidgets[59135]
#define sipNameNr_removePage 59146
#define sipName_removePage &sipStrings_QtWidgets[59146]
#define sipNameNr_repeatTime 59157
#define sipName_repeatTime &sipStrings_QtWidgets[59157]
#define sipNameNr_resizeMode 59168
#define sipName_resizeMode &sipStrings_QtWidgets[59168]
#define sipNameNr_returnData 59179
#define sipName_returnData &sipStrings_QtWidgets[59179]
#define sipNameNr_rowResized 59190
#define sipName_rowResized &sipStrings_QtWidgets[59190]
#define sipNameNr_rowSpacing 59201
#define sipName_rowSpacing &sipStrings_QtWidgets[59201]
#define sipNameNr_rowStretch 59212
#define sipName_rowStretch &sipStrings_QtWidgets[59212]
#define sipNameNr_sceneEvent 59223
#define sipName_sceneEvent &sipStrings_QtWidgets[59223]
#define sipNameNr_selectFile 59234
#define sipName_selectFile &sipStrings_QtWidgets[59234]
#define sipNameNr_setBinMode 59245
#define sipName_setBinMode &sipStrings_QtWidgets[59245]
#define sipNameNr_setChecked 59256
#define sipName_setChecked &sipStrings_QtWidgets[59256]
#define sipNameNr_setDecMode 59267
#define sipName_setDecMode &sipStrings_QtWidgets[59267]
#define sipNameNr_setDefault 59278
#define sipName_setDefault &sipStrings_QtWidgets[59278]
#define sipNameNr_setEnabled 59289
#define sipName_setEnabled &sipStrings_QtWidgets[59289]
#define sipNameNr_setHexMode 59300
#define sipName_setHexMode &sipStrings_QtWidgets[59300]
#define sipNameNr_setHistory 59311
#define sipName_setHistory &sipStrings_QtWidgets[59311]
#define sipNameNr_setHotSpot 53746
#define sipName_setHotSpot &sipStrings_QtWidgets[53746]
#define sipNameNr_setIntStep 59322
#define sipName_setIntStep &sipStrings_QtWidgets[59322]
#define sipNameNr_setMaximum 59333
#define sipName_setMaximum &sipStrings_QtWidgets[59333]
#define sipNameNr_setMenuBar 59344
#define sipName_setMenuBar &sipStrings_QtWidgets[59344]
#define sipNameNr_setMinimum 59355
#define sipName_setMinimum &sipStrings_QtWidgets[59355]
#define sipNameNr_setMovable 59366
#define sipName_setMovable &sipStrings_QtWidgets[59366]
#define sipNameNr_setOctMode 59377
#define sipName_setOctMode &sipStrings_QtWidgets[59377]
#define sipNameNr_setOpacity 59388
#define sipName_setOpacity &sipStrings_QtWidgets[59388]
#define sipNameNr_setOptions 59399
#define sipName_setOptions &sipStrings_QtWidgets[59399]
#define sipNameNr_setPalette 59410
#define sipName_setPalette &sipStrings_QtWidgets[59410]
#define sipNameNr_setPicture 59421
#define sipName_setPicture &sipStrings_QtWidgets[59421]
#define sipNameNr_setPolygon 59432
#define sipName_setPolygon &sipStrings_QtWidgets[59432]
#define sipNameNr_setSpacing 53759
#define sipName_setSpacing &sipStrings_QtWidgets[53759]
#define sipNameNr_setStartId 59443
#define sipName_setStartId &sipStrings_QtWidgets[59443]
#define sipNameNr_setStretch 59454
#define sipName_setStretch &sipStrings_QtWidgets[59454]
#define sipNameNr_setTabData 59465
#define sipName_setTabData &sipStrings_QtWidgets[59465]
#define sipNameNr_setTabIcon 59476
#define sipName_setTabIcon &sipStrings_QtWidgets[59476]
#define sipNameNr_setTabText 59487
#define sipName_setTabText &sipStrings_QtWidgets[59487]
#define sipNameNr_setTimeout 59498
#define sipName_setTimeout &sipStrings_QtWidgets[59498]
#define sipNameNr_setToolTip 59509
#define sipName_setToolTip &sipStrings_QtWidgets[59509]
#define sipNameNr_setVisible 59520
#define sipName_setVisible &sipStrings_QtWidgets[59520]
#define sipNameNr_setXOffset 59531
#define sipName_setXOffset &sipStrings_QtWidgets[59531]
#define sipNameNr_setYOffset 59542
#define sipName_setYOffset &sipStrings_QtWidgets[59542]
#define sipNameNr_showColumn 59553
#define sipName_showColumn &sipStrings_QtWidgets[59553]
#define sipNameNr_showNormal 59564
#define sipName_showNormal &sipStrings_QtWidgets[59564]
#define sipNameNr_showShaded 59575
#define sipName_showShaded &sipStrings_QtWidgets[59575]
#define sipNameNr_sideWidget 59586
#define sipName_sideWidget &sipStrings_QtWidgets[59586]
#define sipNameNr_singleStep 59597
#define sipName_singleStep &sipStrings_QtWidgets[59597]
#define sipNameNr_sizePolicy 59608
#define sipName_sizePolicy &sipStrings_QtWidgets[59608]
#define sipNameNr_sortColumn 59619
#define sipName_sortColumn &sipStrings_QtWidgets[59619]
#define sipNameNr_sourceType 59630
#define sipName_sourceType &sipStrings_QtWidgets[59630]
#define sipNameNr_spacerItem 59641
#define sipName_spacerItem &sipStrings_QtWidgets[59641]
#define sipNameNr_stackUnder 59652
#define sipName_stackUnder &sipStrings_QtWidgets[59652]
#define sipNameNr_startAngle 59663
#define sipName_startAngle &sipStrings_QtWidgets[59663]
#define sipNameNr_styleSheet 59674
#define sipName_styleSheet &sipStrings_QtWidgets[59674]
#define sipNameNr_swipeAngle 59685
#define sipName_swipeAngle &sipStrings_QtWidgets[59685]
#define sipNameNr_systemMenu 59696
#define sipName_systemMenu &sipStrings_QtWidgets[59696]
#define sipNameNr_tabBarRect 59707
#define sipName_tabBarRect &sipStrings_QtWidgets[59707]
#define sipNameNr_tabBarSize 59718
#define sipName_tabBarSize &sipStrings_QtWidgets[59718]
#define sipNameNr_tabRemoved 59729
#define sipName_tabRemoved &sipStrings_QtWidgets[59729]
#define sipNameNr_tabToolTip 59740
#define sipName_tabToolTip &sipStrings_QtWidgets[59740]
#define sipNameNr_takeWidget 59751
#define sipName_takeWidget &sipStrings_QtWidgets[59751]
#define sipNameNr_testOption 59762
#define sipName_testOption &sipStrings_QtWidgets[59762]
#define sipNameNr_textCursor 59773
#define sipName_textCursor &sipStrings_QtWidgets[59773]
#define sipNameNr_textEdited 59784
#define sipName_textEdited &sipStrings_QtWidgets[59784]
#define sipNameNr_textFormat 59795
#define sipName_textFormat &sipStrings_QtWidgets[59795]
#define sipNameNr_timerEvent 59806
#define sipName_timerEvent &sipStrings_QtWidgets[59806]
#define sipNameNr_toMarkdown 59817
#define sipName_toMarkdown &sipStrings_QtWidgets[59817]
#define sipNameNr_toPrevious 59828
#define sipName_toPrevious &sipStrings_QtWidgets[59828]
#define sipNameNr_topLevelAt 59839
#define sipName_topLevelAt &sipStrings_QtWidgets[59839]
#define sipNameNr_transposed 59850
#define sipName_transposed &sipStrings_QtWidgets[59850]
#define sipNameNr_treeWidget 59861
#define sipName_treeWidget &sipStrings_QtWidgets[59861]
#define sipNameNr_underMouse 59872
#define sipName_underMouse &sipStrings_QtWidgets[59872]
#define sipNameNr_updateCell 59883
#define sipName_updateCell &sipStrings_QtWidgets[59883]
#define sipNameNr_upsideDown 59894
#define sipName_upsideDown &sipStrings_QtWidgets[59894]
#define sipNameNr_visitedIds 59905
#define sipName_visitedIds &sipStrings_QtWidgets[59905]
#define sipNameNr_visualRect 59916
#define sipName_visualRect &sipStrings_QtWidgets[59916]
#define sipNameNr_wheelEvent 59927
#define sipName_wheelEvent &sipStrings_QtWidgets[59927]
#define sipNameNr_windowIcon 59938
#define sipName_windowIcon &sipStrings_QtWidgets[59938]
#define sipNameNr_windowRole 59949
#define sipName_windowRole &sipStrings_QtWidgets[59949]
#define sipNameNr_windowType 59960
#define sipName_windowType &sipStrings_QtWidgets[59960]
#define sipNameNr_wrapAround 59971
#define sipName_wrapAround &sipStrings_QtWidgets[59971]
#define sipNameNr_AboveItem 59982
#define sipName_AboveItem &sipStrings_QtWidgets[59982]
#define sipNameNr_AeroStyle 59992
#define sipName_AeroStyle &sipStrings_QtWidgets[59992]
#define sipNameNr_AllLayers 60002
#define sipName_AllLayers &sipStrings_QtWidgets[60002]
#define sipNameNr_Alternate 60012
#define sipName_Alternate &sipStrings_QtWidgets[60012]
#define sipNameNr_ApplyRole 60022
#define sipName_ApplyRole &sipStrings_QtWidgets[60022]
#define sipNameNr_Beginning 60032
#define sipName_Beginning &sipStrings_QtWidgets[60032]
#define sipNameNr_BelowItem 60042
#define sipName_BelowItem &sipStrings_QtWidgets[60042]
#define sipNameNr_ButtonBox 35366
#define sipName_ButtonBox &sipStrings_QtWidgets[35366]
#define sipNameNr_CC_Slider 60052
#define sipName_CC_Slider &sipStrings_QtWidgets[60052]
#define sipNameNr_CE_Header 60062
#define sipName_CE_Header &sipStrings_QtWidgets[60062]
#define sipNameNr_CT_Slider 60072
#define sipName_CT_Slider &sipStrings_QtWidgets[60072]
#define sipNameNr_CacheMode 13399
#define sipName_CacheMode &sipStrings_QtWidgets[13399]
#define sipNameNr_CacheNone 60082
#define sipName_CacheNone &sipStrings_QtWidgets[60082]
#define sipNameNr_CheckType 6683
#define sipName_CheckType &sipStrings_QtWidgets[6683]
#define sipNameNr_Direction 8283
#define sipName_Direction &sipStrings_QtWidgets[8283]
#define sipNameNr_Directory 23041
#define sipName_Directory &sipStrings_QtWidgets[23041]
#define sipNameNr_EmptyArea 90
#define sipName_EmptyArea &sipStrings_QtWidgets[90]
#define sipNameNr_Exclusive 37134
#define sipName_Exclusive &sipStrings_QtWidgets[37134]
#define sipNameNr_Expanding 35128
#define sipName_Expanding &sipStrings_QtWidgets[35128]
#define sipNameNr_FieldRole 60092
#define sipName_FieldRole &sipStrings_QtWidgets[60092]
#define sipNameNr_FrameRate 60102
#define sipName_FrameRate &sipStrings_QtWidgets[60102]
#define sipNameNr_InputMode 15027
#define sipName_InputMode &sipStrings_QtWidgets[15027]
#define sipNameNr_InputMove 60112
#define sipName_InputMove &sipStrings_QtWidgets[60112]
#define sipNameNr_ItemLayer 60122
#define sipName_ItemLayer &sipStrings_QtWidgets[60122]
#define sipNameNr_KdeLayout 60132
#define sipName_KdeLayout &sipStrings_QtWidgets[60132]
#define sipNameNr_LabelRole 60142
#define sipName_LabelRole &sipStrings_QtWidgets[60142]
#define sipNameNr_MacLayout 60152
#define sipName_MacLayout &sipStrings_QtWidgets[60152]
#define sipNameNr_MaskShape 27765
#define sipName_MaskShape &sipStrings_QtWidgets[27765]
#define sipNameNr_MoveRight 60162
#define sipName_MoveRight &sipStrings_QtWidgets[60162]
#define sipNameNr_NoButtons 60172
#define sipName_NoButtons &sipStrings_QtWidgets[60172]
#define sipNameNr_NoSection 60182
#define sipName_NoSection &sipStrings_QtWidgets[60182]
#define sipNameNr_NotHidden 60192
#define sipName_NotHidden &sipStrings_QtWidgets[60192]
#define sipNameNr_PE_Widget 60202
#define sipName_PE_Widget &sipStrings_QtWidgets[60202]
#define sipNameNr_PlusMinus 60212
#define sipName_PlusMinus &sipStrings_QtWidgets[60212]
#define sipNameNr_Preferred 60222
#define sipName_Preferred &sipStrings_QtWidgets[60222]
#define sipNameNr_QCheckBox 60232
#define sipName_QCheckBox &sipStrings_QtWidgets[60232]
#define sipNameNr_QComboBox 60242
#define sipName_QComboBox &sipStrings_QtWidgets[60242]
#define sipNameNr_QDateEdit 60252
#define sipName_QDateEdit &sipStrings_QtWidgets[60252]
#define sipNameNr_QGroupBox 60262
#define sipName_QGroupBox &sipStrings_QtWidgets[60262]
#define sipNameNr_QLineEdit 60272
#define sipName_QLineEdit &sipStrings_QtWidgets[60272]
#define sipNameNr_QListView 60282
#define sipName_QListView &sipStrings_QtWidgets[60282]
#define sipNameNr_QScroller 60292
#define sipName_QScroller &sipStrings_QtWidgets[60292]
#define sipNameNr_QSizeGrip 60302
#define sipName_QSizeGrip &sipStrings_QtWidgets[60302]
#define sipNameNr_QSplitter 60312
#define sipName_QSplitter &sipStrings_QtWidgets[60312]
#define sipNameNr_QTextEdit 60322
#define sipName_QTextEdit &sipStrings_QtWidgets[60322]
#define sipNameNr_QTimeEdit 60332
#define sipName_QTimeEdit &sipStrings_QtWidgets[60332]
#define sipNameNr_QTreeView 60342
#define sipName_QTreeView &sipStrings_QtWidgets[60342]
#define sipNameNr_QUndoView 60352
#define sipName_QUndoView &sipStrings_QtWidgets[60352]
#define sipNameNr_Rectangle 60362
#define sipName_Rectangle &sipStrings_QtWidgets[60362]
#define sipNameNr_ResetRole 60372
#define sipName_ResetRole &sipStrings_QtWidgets[60372]
#define sipNameNr_RightSide 60382
#define sipName_RightSide &sipStrings_QtWidgets[60382]
#define sipNameNr_SO_Button 60392
#define sipName_SO_Button &sipStrings_QtWidgets[60392]
#define sipNameNr_SO_Header 60402
#define sipName_SO_Header &sipStrings_QtWidgets[60402]
#define sipNameNr_SO_Slider 60412
#define sipName_SO_Slider &sipStrings_QtWidgets[60412]
#define sipNameNr_Scrolling 6715
#define sipName_Scrolling &sipStrings_QtWidgets[6715]
#define sipNameNr_Separator 8817
#define sipName_Separator &sipStrings_QtWidgets[8817]
#define sipNameNr_ShapeMode 7309
#define sipName_ShapeMode &sipStrings_QtWidgets[7309]
#define sipNameNr_StateFlag 31878
#define sipName_StateFlag &sipStrings_QtWidgets[31878]
#define sipNameNr_State_Off 60422
#define sipName_State_Off &sipStrings_QtWidgets[60422]
#define sipNameNr_State_Top 60432
#define sipName_State_Top &sipStrings_QtWidgets[60432]
#define sipNameNr_StyleHint 31896
#define sipName_StyleHint &sipStrings_QtWidgets[31896]
#define sipNameNr_StyleMask 31734
#define sipName_StyleMask &sipStrings_QtWidgets[31734]
#define sipNameNr_TabWidget 31464
#define sipName_TabWidget &sipStrings_QtWidgets[31464]
#define sipNameNr_TextInput 9397
#define sipName_TextInput &sipStrings_QtWidgets[9397]
#define sipNameNr_TicksLeft 60442
#define sipName_TicksLeft &sipStrings_QtWidgets[60442]
#define sipNameNr_WinLayout 60452
#define sipName_WinLayout &sipStrings_QtWidgets[60452]
#define sipNameNr_activated 60462
#define sipName_activated &sipStrings_QtWidgets[60462]
#define sipNameNr_addAction 60472
#define sipName_addAction &sipStrings_QtWidgets[60472]
#define sipNameNr_addAnchor 60482
#define sipName_addAnchor &sipStrings_QtWidgets[60482]
#define sipNameNr_addButton 60492
#define sipName_addButton &sipStrings_QtWidgets[60492]
#define sipNameNr_addLayout 60502
#define sipName_addLayout &sipStrings_QtWidgets[60502]
#define sipNameNr_addPixmap 60512
#define sipName_addPixmap &sipStrings_QtWidgets[60512]
#define sipNameNr_addWidget 60522
#define sipName_addWidget &sipStrings_QtWidgets[60522]
#define sipNameNr_alignment 60532
#define sipName_alignment &sipStrings_QtWidgets[60532]
#define sipNameNr_arrowType 60542
#define sipName_arrowType &sipStrings_QtWidgets[60542]
#define sipNameNr_autoClose 60552
#define sipName_autoClose &sipStrings_QtWidgets[60552]
#define sipNameNr_autoRaise 60562
#define sipName_autoRaise &sipStrings_QtWidgets[60562]
#define sipNameNr_autoReset 60572
#define sipName_autoReset &sipStrings_QtWidgets[60572]
#define sipNameNr_backspace 60582
#define sipName_backspace &sipStrings_QtWidgets[60582]
#define sipNameNr_baseStyle 60592
#define sipName_baseStyle &sipStrings_QtWidgets[60592]
#define sipNameNr_batchSize 60602
#define sipName_batchSize &sipStrings_QtWidgets[60602]
#define sipNameNr_blurHints 60612
#define sipName_blurHints &sipStrings_QtWidgets[60612]
#define sipNameNr_bottomRow 60622
#define sipName_bottomRow &sipStrings_QtWidgets[60622]
#define sipNameNr_cacheMode 60632
#define sipName_cacheMode &sipStrings_QtWidgets[60632]
#define sipNameNr_checkType 60642
#define sipName_checkType &sipStrings_QtWidgets[60642]
#define sipNameNr_checkedId 60652
#define sipName_checkedId &sipStrings_QtWidgets[60652]
#define sipNameNr_className 60662
#define sipName_className &sipStrings_QtWidgets[60662]
#define sipNameNr_cleanIcon 60672
#define sipName_cleanIcon &sipStrings_QtWidgets[60672]
#define sipNameNr_cleanText 60682
#define sipName_cleanText &sipStrings_QtWidgets[60682]
#define sipNameNr_clearMask 60692
#define sipName_clearMask &sipStrings_QtWidgets[60692]
#define sipNameNr_collapsed 60702
#define sipName_collapsed &sipStrings_QtWidgets[60702]
#define sipNameNr_completer 60712
#define sipName_completer &sipStrings_QtWidgets[60712]
#define sipNameNr_currentId 60722
#define sipName_currentId &sipStrings_QtWidgets[60722]
#define sipNameNr_direction 60732
#define sipName_direction &sipStrings_QtWidgets[60732]
#define sipNameNr_directory 60742
#define sipName_directory &sipStrings_QtWidgets[60742]
#define sipNameNr_drawCheck 60752
#define sipName_drawCheck &sipStrings_QtWidgets[60752]
#define sipNameNr_drawFocus 60762
#define sipName_drawFocus &sipStrings_QtWidgets[60762]
#define sipNameNr_drawFrame 60772
#define sipName_drawFrame &sipStrings_QtWidgets[60772]
#define sipNameNr_dropEvent 60782
#define sipName_dropEvent &sipStrings_QtWidgets[60782]
#define sipNameNr_elideMode 60792
#define sipName_elideMode &sipStrings_QtWidgets[60792]
#define sipNameNr_exclusive 60802
#define sipName_exclusive &sipStrings_QtWidgets[60802]
#define sipNameNr_expandAll 60812
#define sipName_expandAll &sipStrings_QtWidgets[60812]
#define sipNameNr_expanding 60822
#define sipName_expanding &sipStrings_QtWidgets[60822]
#define sipNameNr_fieldItem 60832
#define sipName_fieldItem &sipStrings_QtWidgets[60832]
#define sipNameNr_findItems 60842
#define sipName_findItems &sipStrings_QtWidgets[60842]
#define sipNameNr_fitInView 60852
#define sipName_fitInView &sipStrings_QtWidgets[60852]
#define sipNameNr_floatable 60862
#define sipName_floatable &sipStrings_QtWidgets[60862]
#define sipNameNr_focusItem 60872
#define sipName_focusItem &sipStrings_QtWidgets[60872]
#define sipNameNr_forceShow 60882
#define sipName_forceShow &sipStrings_QtWidgets[60882]
#define sipNameNr_frameRect 60892
#define sipName_frameRect &sipStrings_QtWidgets[60892]
#define sipNameNr_frameSize 60902
#define sipName_frameSize &sipStrings_QtWidgets[60902]
#define sipNameNr_getDouble 60912
#define sipName_getDouble &sipStrings_QtWidgets[60912]
#define sipNameNr_grabMouse 57198
#define sipName_grabMouse &sipStrings_QtWidgets[57198]
#define sipNameNr_gridStyle 60922
#define sipName_gridStyle &sipStrings_QtWidgets[60922]
#define sipNameNr_hasCursor 60932
#define sipName_hasCursor &sipStrings_QtWidgets[60932]
#define sipNameNr_helpEvent 60942
#define sipName_helpEvent &sipStrings_QtWidgets[60942]
#define sipNameNr_hideEvent 60952
#define sipName_hideEvent &sipStrings_QtWidgets[60952]
#define sipNameNr_hidePopup 60962
#define sipName_hidePopup &sipStrings_QtWidgets[60962]
#define sipNameNr_hitButton 60972
#define sipName_hitButton &sipStrings_QtWidgets[60972]
#define sipNameNr_idClicked 60982
#define sipName_idClicked &sipStrings_QtWidgets[60982]
#define sipNameNr_idPressed 60992
#define sipName_idPressed &sipStrings_QtWidgets[60992]
#define sipNameNr_idToggled 61002
#define sipName_idToggled &sipStrings_QtWidgets[61002]
#define sipNameNr_inputMask 61012
#define sipName_inputMask &sipStrings_QtWidgets[61012]
#define sipNameNr_inputMode 61022
#define sipName_inputMode &sipStrings_QtWidgets[61022]
#define sipNameNr_insertRow 61032
#define sipName_insertRow &sipStrings_QtWidgets[61032]
#define sipNameNr_insertTab 61042
#define sipName_insertTab &sipStrings_QtWidgets[61042]
#define sipNameNr_isChecked 61052
#define sipName_isChecked &sipStrings_QtWidgets[61052]
#define sipNameNr_isClipped 61062
#define sipName_isClipped &sipStrings_QtWidgets[61062]
#define sipNameNr_isDefault 61072
#define sipName_isDefault &sipStrings_QtWidgets[61072]
#define sipNameNr_isEnabled 61082
#define sipName_isEnabled &sipStrings_QtWidgets[61082]
#define sipNameNr_isMovable 61092
#define sipName_isMovable &sipStrings_QtWidgets[61092]
#define sipNameNr_isVisible 61102
#define sipName_isVisible &sipStrings_QtWidgets[61102]
#define sipNameNr_itemAbove 61112
#define sipName_itemAbove &sipStrings_QtWidgets[61112]
#define sipNameNr_itemBelow 61122
#define sipName_itemBelow &sipStrings_QtWidgets[61122]
#define sipNameNr_labelItem 61132
#define sipName_labelItem &sipStrings_QtWidgets[61132]
#define sipNameNr_labelText 61142
#define sipName_labelText &sipStrings_QtWidgets[61142]
#define sipNameNr_lineWidth 61152
#define sipName_lineWidth &sipStrings_QtWidgets[61152]
#define sipNameNr_mapToItem 61162
#define sipName_mapToItem &sipStrings_QtWidgets[61162]
#define sipNameNr_maxLength 61172
#define sipName_maxLength &sipStrings_QtWidgets[61172]
#define sipNameNr_mimeTypes 61182
#define sipName_mimeTypes &sipStrings_QtWidgets[61182]
#define sipNameNr_modifiers 61192
#define sipName_modifiers &sipStrings_QtWidgets[61192]
#define sipNameNr_mouseDown 61202
#define sipName_mouseDown &sipStrings_QtWidgets[61202]
#define sipNameNr_moveEvent 61212
#define sipName_moveEvent &sipStrings_QtWidgets[61212]
#define sipNameNr_notchSize 61222
#define sipName_notchSize &sipStrings_QtWidgets[61222]
#define sipNameNr_openLinks 61232
#define sipName_openLinks &sipStrings_QtWidgets[61232]
#define sipNameNr_pageAdded 61242
#define sipName_pageAdded &sipStrings_QtWidgets[61242]
#define sipNameNr_pageCount 61252
#define sipName_pageCount &sipStrings_QtWidgets[61252]
#define sipNameNr_paintCell 61262
#define sipName_paintCell &sipStrings_QtWidgets[61262]
#define sipNameNr_popupMode 61272
#define sipName_popupMode &sipStrings_QtWidgets[61272]
#define sipNameNr_popupRect 61282
#define sipName_popupRect &sipStrings_QtWidgets[61282]
#define sipNameNr_qtHandler 61292
#define sipName_qtHandler &sipStrings_QtWidgets[61292]
#define sipNameNr_recognize 61302
#define sipName_recognize &sipStrings_QtWidgets[61302]
#define sipNameNr_rectangle 61312
#define sipName_rectangle &sipStrings_QtWidgets[61312]
#define sipNameNr_removeRow 61322
#define sipName_removeRow &sipStrings_QtWidgets[61322]
#define sipNameNr_removeTab 61332
#define sipName_removeTab &sipStrings_QtWidgets[61332]
#define sipNameNr_rootIndex 61342
#define sipName_rootIndex &sipStrings_QtWidgets[61342]
#define sipNameNr_rowHeight 61352
#define sipName_rowHeight &sipStrings_QtWidgets[61352]
#define sipNameNr_saveState 61362
#define sipName_saveState &sipStrings_QtWidgets[61362]
#define sipNameNr_sceneRect 61372
#define sipName_sceneRect &sipStrings_QtWidgets[61372]
#define sipNameNr_screenPos 61382
#define sipName_screenPos &sipStrings_QtWidgets[61382]
#define sipNameNr_sectionAt 61392
#define sipName_sectionAt &sipStrings_QtWidgets[61392]
#define sipNameNr_selectAll 61402
#define sipName_selectAll &sipStrings_QtWidgets[61402]
#define sipNameNr_selectRow 61412
#define sipName_selectRow &sipStrings_QtWidgets[61412]
#define sipNameNr_selectUrl 61422
#define sipName_selectUrl &sipStrings_QtWidgets[61422]
#define sipNameNr_sendEvent 61432
#define sipName_sendEvent &sipStrings_QtWidgets[61432]
#define sipNameNr_setActive 61442
#define sipName_setActive &sipStrings_QtWidgets[61442]
#define sipNameNr_setButton 22579
#define sipName_setButton &sipStrings_QtWidgets[22579]
#define sipNameNr_setCorner 61452
#define sipName_setCorner &sipStrings_QtWidgets[61452]
#define sipNameNr_setCursor 57210
#define sipName_setCursor &sipStrings_QtWidgets[57210]
#define sipNameNr_setFilter 61462
#define sipName_setFilter &sipStrings_QtWidgets[61462]
#define sipNameNr_setFormat 56130
#define sipName_setFormat &sipStrings_QtWidgets[56130]
#define sipNameNr_setHeader 61472
#define sipName_setHeader &sipStrings_QtWidgets[61472]
#define sipNameNr_setHidden 61482
#define sipName_setHidden &sipStrings_QtWidgets[61482]
#define sipNameNr_setIndent 61492
#define sipName_setIndent &sipStrings_QtWidgets[61492]
#define sipNameNr_setLayout 61502
#define sipName_setLayout &sipStrings_QtWidgets[61502]
#define sipNameNr_setLocale 57222
#define sipName_setLocale &sipStrings_QtWidgets[57222]
#define sipNameNr_setMargin 61512
#define sipName_setMargin &sipStrings_QtWidgets[61512]
#define sipNameNr_setOffset 61522
#define sipName_setOffset &sipStrings_QtWidgets[61522]
#define sipNameNr_setOption 61532
#define sipName_setOption &sipStrings_QtWidgets[61532]
#define sipNameNr_setOrigin 61542
#define sipName_setOrigin &sipStrings_QtWidgets[61542]
#define sipNameNr_setParent 61552
#define sipName_setParent &sipStrings_QtWidgets[61552]
#define sipNameNr_setPixmap 61562
#define sipName_setPixmap &sipStrings_QtWidgets[61562]
#define sipNameNr_setPrefix 61572
#define sipName_setPrefix &sipStrings_QtWidgets[61572]
#define sipNameNr_setResult 61582
#define sipName_setResult &sipStrings_QtWidgets[61582]
#define sipNameNr_setScreen 61592
#define sipName_setScreen &sipStrings_QtWidgets[61592]
#define sipNameNr_setSource 61602
#define sipName_setSource &sipStrings_QtWidgets[61602]
#define sipNameNr_setSuffix 61612
#define sipName_setSuffix &sipStrings_QtWidgets[61612]
#define sipNameNr_setTabBar 61622
#define sipName_setTabBar &sipStrings_QtWidgets[61622]
#define sipNameNr_setWidget 61632
#define sipName_setWidget &sipStrings_QtWidgets[61632]
#define sipNameNr_setXScale 61642
#define sipName_setXScale &sipStrings_QtWidgets[61642]
#define sipNameNr_setYScale 61652
#define sipName_setYScale &sipStrings_QtWidgets[61652]
#define sipNameNr_setZScale 61662
#define sipName_setZScale &sipStrings_QtWidgets[61662]
#define sipNameNr_setZValue 61672
#define sipName_setZValue &sipStrings_QtWidgets[61672]
#define sipNameNr_shapeMode 61682
#define sipName_shapeMode &sipStrings_QtWidgets[61682]
#define sipNameNr_showEvent 61692
#define sipName_showEvent &sipStrings_QtWidgets[61692]
#define sipNameNr_showPopup 61702
#define sipName_showPopup &sipStrings_QtWidgets[61702]
#define sipNameNr_showToday 61712
#define sipName_showToday &sipStrings_QtWidgets[61712]
#define sipNameNr_sortItems 61722
#define sipName_sortItems &sipStrings_QtWidgets[61722]
#define sipNameNr_spanAngle 61732
#define sipName_spanAngle &sipStrings_QtWidgets[61732]
#define sipNameNr_splitPath 61742
#define sipName_splitPath &sipStrings_QtWidgets[61742]
#define sipNameNr_startDrag 61752
#define sipName_startDrag &sipStrings_QtWidgets[61752]
#define sipNameNr_statusBar 61762
#define sipName_statusBar &sipStrings_QtWidgets[61762]
#define sipNameNr_statusTip 61772
#define sipName_statusTip &sipStrings_QtWidgets[61772]
#define sipNameNr_styleHint 61782
#define sipName_styleHint &sipStrings_QtWidgets[61782]
#define sipNameNr_tabButton 61792
#define sipName_tabButton &sipStrings_QtWidgets[61792]
#define sipNameNr_takeChild 61802
#define sipName_takeChild &sipStrings_QtWidgets[61802]
#define sipNameNr_textColor 61812
#define sipName_textColor &sipStrings_QtWidgets[61812]
#define sipNameNr_textValue 61822
#define sipName_textValue &sipStrings_QtWidgets[61822]
#define sipNameNr_textWidth 61832
#define sipName_textWidth &sipStrings_QtWidgets[61832]
#define sipNameNr_timestamp 61842
#define sipName_timestamp &sipStrings_QtWidgets[61842]
#define sipNameNr_transform 61852
#define sipName_transform &sipStrings_QtWidgets[61852]
#define sipNameNr_translate 61862
#define sipName_translate &sipStrings_QtWidgets[61862]
#define sipNameNr_transpose 61872
#define sipName_transpose &sipStrings_QtWidgets[61872]
#define sipNameNr_triggered 61882
#define sipName_triggered &sipStrings_QtWidgets[61882]
#define sipNameNr_validator 61892
#define sipName_validator &sipStrings_QtWidgets[61892]
#define sipNameNr_visualPos 61902
#define sipName_visualPos &sipStrings_QtWidgets[61902]
#define sipNameNr_visualRow 61912
#define sipName_visualRow &sipStrings_QtWidgets[61912]
#define sipNameNr_whatsThis 61922
#define sipName_whatsThis &sipStrings_QtWidgets[61922]
#define sipNameNr_yearShown 61932
#define sipName_yearShown &sipStrings_QtWidgets[61932]
#define sipNameNr_Accepted 56251
#define sipName_Accepted &sipStrings_QtWidgets[56251]
#define sipNameNr_AllFonts 61942
#define sipName_AllFonts &sipStrings_QtWidgets[61942]
#define sipNameNr_AutoNone 61951
#define sipName_AutoNone &sipStrings_QtWidgets[61951]
#define sipNameNr_BlurHint 8164
#define sipName_BlurHint &sipStrings_QtWidgets[8164]
#define sipNameNr_CheckBox 21614
#define sipName_CheckBox &sipStrings_QtWidgets[21614]
#define sipNameNr_ComboBox 22055
#define sipName_ComboBox &sipStrings_QtWidgets[22055]
#define sipNameNr_Critical 19978
#define sipName_Critical &sipStrings_QtWidgets[19978]
#define sipNameNr_Disabled 7589
#define sipName_Disabled &sipStrings_QtWidgets[7589]
#define sipNameNr_DragDrop 57619
#define sipName_DragDrop &sipStrings_QtWidgets[57619]
#define sipNameNr_DragMode 14980
#define sipName_DragMode &sipStrings_QtWidgets[14980]
#define sipNameNr_DragOnly 61960
#define sipName_DragOnly &sipStrings_QtWidgets[61960]
#define sipNameNr_Dragging 38653
#define sipName_Dragging &sipStrings_QtWidgets[38653]
#define sipNameNr_DropOnly 61969
#define sipName_DropOnly &sipStrings_QtWidgets[61969]
#define sipNameNr_EchoMode 25082
#define sipName_EchoMode &sipStrings_QtWidgets[25082]
#define sipNameNr_Editable 26722
#define sipName_Editable &sipStrings_QtWidgets[26722]
#define sipNameNr_FileMode 19230
#define sipName_FileMode &sipStrings_QtWidgets[19230]
#define sipNameNr_FileName 40237
#define sipName_FileName &sipStrings_QtWidgets[40237]
#define sipNameNr_FileType 61978
#define sipName_FileType &sipStrings_QtWidgets[61978]
#define sipNameNr_FlagMask 61987
#define sipName_FlagMask &sipStrings_QtWidgets[61987]
#define sipNameNr_GroupBox 22076
#define sipName_GroupBox &sipStrings_QtWidgets[22076]
#define sipNameNr_GrowFlag 61996
#define sipName_GrowFlag &sipStrings_QtWidgets[61996]
#define sipNameNr_HasFrame 62005
#define sipName_HasFrame &sipStrings_QtWidgets[62005]
#define sipNameNr_HelpRole 62014
#define sipName_HelpRole &sipStrings_QtWidgets[62014]
#define sipNameNr_IconMode 62023
#define sipName_IconMode &sipStrings_QtWidgets[62023]
#define sipNameNr_Inactive 62032
#define sipName_Inactive &sipStrings_QtWidgets[62032]
#define sipNameNr_IntInput 62041
#define sipName_IntInput &sipStrings_QtWidgets[62041]
#define sipNameNr_ItemRole 19274
#define sipName_ItemRole &sipStrings_QtWidgets[19274]
#define sipNameNr_ItemType 4952
#define sipName_ItemType &sipStrings_QtWidgets[4952]
#define sipNameNr_Keyboard 40893
#define sipName_Keyboard &sipStrings_QtWidgets[40893]
#define sipNameNr_LeftSide 62050
#define sipName_LeftSide &sipStrings_QtWidgets[62050]
#define sipNameNr_LineEdit 35214
#define sipName_LineEdit &sipStrings_QtWidgets[35214]
#define sipNameNr_ListMode 62059
#define sipName_ListMode &sipStrings_QtWidgets[62059]
#define sipNameNr_MacStyle 62068
#define sipName_MacStyle &sipStrings_QtWidgets[62068]
#define sipNameNr_MoveDown 62077
#define sipName_MoveDown &sipStrings_QtWidgets[62077]
#define sipNameNr_MoveHome 62086
#define sipName_MoveHome &sipStrings_QtWidgets[62086]
#define sipNameNr_MoveLeft 62095
#define sipName_MoveLeft &sipStrings_QtWidgets[62095]
#define sipNameNr_MoveNext 62104
#define sipName_MoveNext &sipStrings_QtWidgets[62104]
#define sipNameNr_Movement 25122
#define sipName_Movement &sipStrings_QtWidgets[25122]
#define sipNameNr_NoAnchor 62113
#define sipName_NoAnchor &sipStrings_QtWidgets[62113]
#define sipNameNr_NoButton 32095
#define sipName_NoButton &sipStrings_QtWidgets[32095]
#define sipNameNr_NoInsert 62122
#define sipName_NoInsert &sipStrings_QtWidgets[62122]
#define sipNameNr_NonModal 62131
#define sipName_NonModal &sipStrings_QtWidgets[62131]
#define sipNameNr_PE_Frame 62140
#define sipName_PE_Frame &sipStrings_QtWidgets[62140]
#define sipNameNr_Password 62149
#define sipName_Password &sipStrings_QtWidgets[62149]
#define sipNameNr_Position 1092
#define sipName_Position &sipStrings_QtWidgets[1092]
#define sipNameNr_QGesture 62158
#define sipName_QGesture &sipStrings_QtWidgets[62158]
#define sipNameNr_QMdiArea 62167
#define sipName_QMdiArea &sipStrings_QtWidgets[62167]
#define sipNameNr_QMenuBar 62176
#define sipName_QMenuBar &sipStrings_QtWidgets[62176]
#define sipNameNr_QSpinBox 62185
#define sipName_QSpinBox &sipStrings_QtWidgets[62185]
#define sipNameNr_QToolBar 62194
#define sipName_QToolBar &sipStrings_QtWidgets[62194]
#define sipNameNr_QToolBox 62203
#define sipName_QToolBox &sipStrings_QtWidgets[62203]
#define sipNameNr_QToolTip 62212
#define sipName_QToolTip &sipStrings_QtWidgets[62212]
#define sipNameNr_Question 20000
#define sipName_Question &sipStrings_QtWidgets[20000]
#define sipNameNr_ReadOnly 43369
#define sipName_ReadOnly &sipStrings_QtWidgets[43369]
#define sipNameNr_Rejected 48140
#define sipName_Rejected &sipStrings_QtWidgets[48140]
#define sipNameNr_SO_Frame 62221
#define sipName_SO_Frame &sipStrings_QtWidgets[62221]
#define sipNameNr_Scroller 38525
#define sipName_Scroller &sipStrings_QtWidgets[38525]
#define sipNameNr_Selected 5092
#define sipName_Selected &sipStrings_QtWidgets[5092]
#define sipNameNr_SnapTime 62230
#define sipName_SnapTime &sipStrings_QtWidgets[62230]
#define sipNameNr_SortDown 62239
#define sipName_SortDown &sipStrings_QtWidgets[62239]
#define sipNameNr_StackAll 62248
#define sipName_StackAll &sipStrings_QtWidgets[62248]
#define sipNameNr_StackOne 62257
#define sipName_StackOne &sipStrings_QtWidgets[62257]
#define sipNameNr_Standard 62266
#define sipName_Standard &sipStrings_QtWidgets[62266]
#define sipNameNr_State_On 62275
#define sipName_State_On &sipStrings_QtWidgets[62275]
#define sipNameNr_StepNone 62284
#define sipName_StepNone &sipStrings_QtWidgets[62284]
#define sipNameNr_StepType 10843
#define sipName_StepType &sipStrings_QtWidgets[10843]
#define sipNameNr_TabShape 22202
#define sipName_TabShape &sipStrings_QtWidgets[22202]
#define sipNameNr_UseStyle 62293
#define sipName_UseStyle &sipStrings_QtWidgets[62293]
#define sipNameNr_UserFlag 62302
#define sipName_UserFlag &sipStrings_QtWidgets[62302]
#define sipNameNr_UserType 62311
#define sipName_UserType &sipStrings_QtWidgets[62311]
#define sipNameNr_ViewMode 19252
#define sipName_ViewMode &sipStrings_QtWidgets[19252]
#define sipNameNr_WinPanel 48770
#define sipName_WinPanel &sipStrings_QtWidgets[48770]
#define sipNameNr_WrapText 62320
#define sipName_WrapText &sipStrings_QtWidgets[62320]
#define sipNameNr_YesToAll 62329
#define sipName_YesToAll &sipStrings_QtWidgets[62329]
#define sipNameNr___hash__ 62338
#define sipName___hash__ &sipStrings_QtWidgets[62338]
#define sipNameNr___iadd__ 62347
#define sipName___iadd__ &sipStrings_QtWidgets[62347]
#define sipNameNr___isub__ 62356
#define sipName___isub__ &sipStrings_QtWidgets[62356]
#define sipNameNr_accepted 62365
#define sipName_accepted &sipStrings_QtWidgets[62365]
#define sipNameNr_actionAt 62374
#define sipName_actionAt &sipStrings_QtWidgets[62374]
#define sipNameNr_activate 62383
#define sipName_activate &sipStrings_QtWidgets[62383]
#define sipNameNr_addChild 62392
#define sipName_addChild &sipStrings_QtWidgets[62392]
#define sipNameNr_addItems 62401
#define sipName_addItems &sipStrings_QtWidgets[62401]
#define sipNameNr_addStrut 62410
#define sipName_addStrut &sipStrings_QtWidgets[62410]
#define sipNameNr_anchorAt 62419
#define sipName_anchorAt &sipStrings_QtWidgets[62419]
#define sipNameNr_autoHide 62428
#define sipName_autoHide &sipStrings_QtWidgets[62428]
#define sipNameNr_backward 62437
#define sipName_backward &sipStrings_QtWidgets[62437]
#define sipNameNr_baseSize 62446
#define sipName_baseSize &sipStrings_QtWidgets[62446]
#define sipNameNr_calendar 62455
#define sipName_calendar &sipStrings_QtWidgets[62455]
#define sipNameNr_canPaste 62464
#define sipName_canPaste &sipStrings_QtWidgets[62464]
#define sipNameNr_canceled 62473
#define sipName_canceled &sipStrings_QtWidgets[62473]
#define sipNameNr_cellRect 62482
#define sipName_cellRect &sipStrings_QtWidgets[62482]
#define sipNameNr_centerOn 62491
#define sipName_centerOn &sipStrings_QtWidgets[62491]
#define sipNameNr_checkBox 62500
#define sipName_checkBox &sipStrings_QtWidgets[62500]
#define sipNameNr_clipPath 62509
#define sipName_clipPath &sipStrings_QtWidgets[62509]
#define sipNameNr_closable 62518
#define sipName_closable &sipStrings_QtWidgets[62518]
#define sipNameNr_collapse 62527
#define sipName_collapse &sipStrings_QtWidgets[62527]
#define sipNameNr_columnAt 62536
#define sipName_columnAt &sipStrings_QtWidgets[62536]
#define sipNameNr_complete 62545
#define sipName_complete &sipStrings_QtWidgets[62545]
#define sipNameNr_contains 62554
#define sipName_contains &sipStrings_QtWidgets[62554]
#define sipNameNr_critical 62563
#define sipName_critical &sipStrings_QtWidgets[62563]
#define sipNameNr_dateTime 62572
#define sipName_dateTime &sipStrings_QtWidgets[62572]
#define sipNameNr_decimals 62581
#define sipName_decimals &sipStrings_QtWidgets[62581]
#define sipNameNr_deselect 62590
#define sipName_deselect &sipStrings_QtWidgets[62590]
#define sipNameNr_document 62599
#define sipName_document &sipStrings_QtWidgets[62599]
#define sipNameNr_dragMode 62608
#define sipName_dragMode &sipStrings_QtWidgets[62608]
#define sipNameNr_drawBase 62617
#define sipName_drawBase &sipStrings_QtWidgets[62617]
#define sipNameNr_drawTree 62626
#define sipName_drawTree &sipStrings_QtWidgets[62626]
#define sipNameNr_echoMode 62635
#define sipName_echoMode &sipStrings_QtWidgets[62635]
#define sipNameNr_editItem 62644
#define sipName_editItem &sipStrings_QtWidgets[62644]
#define sipNameNr_editable 62653
#define sipName_editable &sipStrings_QtWidgets[62653]
#define sipNameNr_expanded 62662
#define sipName_expanded &sipStrings_QtWidgets[62662]
#define sipNameNr_features 62671
#define sipName_features &sipStrings_QtWidgets[62671]
#define sipNameNr_fileMode 62680
#define sipName_fileMode &sipStrings_QtWidgets[62680]
#define sipNameNr_fillRule 62689
#define sipName_fillRule &sipStrings_QtWidgets[62689]
#define sipNameNr_findData 62698
#define sipName_findData &sipStrings_QtWidgets[62698]
#define sipNameNr_findText 62707
#define sipName_findText &sipStrings_QtWidgets[62707]
#define sipNameNr_finished 62716
#define sipName_finished &sipStrings_QtWidgets[62716]
#define sipNameNr_fontInfo 62725
#define sipName_fontInfo &sipStrings_QtWidgets[62725]
#define sipNameNr_geometry 62734
#define sipName_geometry &sipStrings_QtWidgets[62734]
#define sipNameNr_gestures 62743
#define sipName_gestures &sipStrings_QtWidgets[62743]
#define sipNameNr_getColor 62752
#define sipName_getColor &sipStrings_QtWidgets[62752]
#define sipNameNr_getRange 62761
#define sipName_getRange &sipStrings_QtWidgets[62761]
#define sipNameNr_gridSize 62770
#define sipName_gridSize &sipStrings_QtWidgets[62770]
#define sipNameNr_hasFocus 62779
#define sipName_hasFocus &sipStrings_QtWidgets[62779]
#define sipNameNr_hasFrame 62788
#define sipName_hasFrame &sipStrings_QtWidgets[62788]
#define sipNameNr_hideText 62797
#define sipName_hideText &sipStrings_QtWidgets[62797]
#define sipNameNr_iconSize 62806
#define sipName_iconSize &sipStrings_QtWidgets[62806]
#define sipNameNr_initFrom 62815
#define sipName_initFrom &sipStrings_QtWidgets[62815]
#define sipNameNr_intValue 62824
#define sipName_intValue &sipStrings_QtWidgets[62824]
#define sipNameNr_isActive 62833
#define sipName_isActive &sipStrings_QtWidgets[62833]
#define sipNameNr_isHidden 62842
#define sipName_isHidden &sipStrings_QtWidgets[62842]
#define sipNameNr_isLayout 62851
#define sipName_isLayout &sipStrings_QtWidgets[62851]
#define sipNameNr_isShaded 62860
#define sipName_isShaded &sipStrings_QtWidgets[62860]
#define sipNameNr_isWidget 62869
#define sipName_isWidget &sipStrings_QtWidgets[62869]
#define sipNameNr_isWindow 62878
#define sipName_isWindow &sipStrings_QtWidgets[62878]
#define sipNameNr_itemData 62887
#define sipName_itemData &sipStrings_QtWidgets[62887]
#define sipNameNr_itemIcon 62896
#define sipName_itemIcon &sipStrings_QtWidgets[62896]
#define sipNameNr_itemText 62905
#define sipName_itemText &sipStrings_QtWidgets[62905]
#define sipNameNr_lineEdit 62914
#define sipName_lineEdit &sipStrings_QtWidgets[62914]
#define sipNameNr_maxCount 62923
#define sipName_maxCount &sipStrings_QtWidgets[62923]
#define sipNameNr_menuRect 62932
#define sipName_menuRect &sipStrings_QtWidgets[62932]
#define sipNameNr_mimeData 62941
#define sipName_mimeData &sipStrings_QtWidgets[62941]
#define sipNameNr_movement 62950
#define sipName_movement &sipStrings_QtWidgets[62950]
#define sipNameNr_overflow 62959
#define sipName_overflow &sipStrings_QtWidgets[62959]
#define sipNameNr_pageStep 62968
#define sipName_pageStep &sipStrings_QtWidgets[62968]
#define sipNameNr_position 62977
#define sipName_position &sipStrings_QtWidgets[62977]
#define sipNameNr_progress 62986
#define sipName_progress &sipStrings_QtWidgets[62986]
#define sipNameNr_property 62995
#define sipName_property &sipStrings_QtWidgets[62995]
#define sipNameNr_question 63004
#define sipName_question &sipStrings_QtWidgets[63004]
#define sipNameNr_reexpand 63013
#define sipName_reexpand &sipStrings_QtWidgets[63013]
#define sipNameNr_reformat 63022
#define sipName_reformat &sipStrings_QtWidgets[63022]
#define sipNameNr_rejected 63031
#define sipName_rejected &sipStrings_QtWidgets[63031]
#define sipNameNr_released 63040
#define sipName_released &sipStrings_QtWidgets[63040]
#define sipNameNr_removeAt 63049
#define sipName_removeAt &sipStrings_QtWidgets[63049]
#define sipNameNr_rotation 63058
#define sipName_rotation &sipStrings_QtWidgets[63058]
#define sipNameNr_rowCount 63067
#define sipName_rowCount &sipStrings_QtWidgets[63067]
#define sipNameNr_rowMoved 63076
#define sipName_rowMoved &sipStrings_QtWidgets[63076]
#define sipNameNr_scenePos 63085
#define sipName_scenePos &sipStrings_QtWidgets[63085]
#define sipNameNr_scrollTo 63094
#define sipName_scrollTo &sipStrings_QtWidgets[63094]
#define sipNameNr_scroller 63103
#define sipName_scroller &sipStrings_QtWidgets[63103]
#define sipNameNr_setAngle 63112
#define sipName_setAngle &sipStrings_QtWidgets[63112]
#define sipNameNr_setBrush 63121
#define sipName_setBrush &sipStrings_QtWidgets[63121]
#define sipNameNr_setBuddy 63130
#define sipName_setBuddy &sipStrings_QtWidgets[63130]
#define sipNameNr_setColor 63139
#define sipName_setColor &sipStrings_QtWidgets[63139]
#define sipNameNr_setField 63148
#define sipName_setField &sipStrings_QtWidgets[63148]
#define sipNameNr_setFlags 63157
#define sipName_setFlags &sipStrings_QtWidgets[63157]
#define sipNameNr_setFocus 63166
#define sipName_setFocus &sipStrings_QtWidgets[63166]
#define sipNameNr_setFrame 63175
#define sipName_setFrame &sipStrings_QtWidgets[63175]
#define sipNameNr_setGroup 63184
#define sipName_setGroup &sipStrings_QtWidgets[63184]
#define sipNameNr_setLabel 63193
#define sipName_setLabel &sipStrings_QtWidgets[63193]
#define sipNameNr_setModal 63202
#define sipName_setModal &sipStrings_QtWidgets[63202]
#define sipNameNr_setModel 63211
#define sipName_setModel &sipStrings_QtWidgets[63211]
#define sipNameNr_setMovie 63220
#define sipName_setMovie &sipStrings_QtWidgets[63220]
#define sipNameNr_setPopup 63229
#define sipName_setPopup &sipStrings_QtWidgets[63229]
#define sipNameNr_setRange 63238
#define sipName_setRange &sipStrings_QtWidgets[63238]
#define sipNameNr_setScale 63247
#define sipName_setScale &sipStrings_QtWidgets[63247]
#define sipNameNr_setScene 63256
#define sipName_setScene &sipStrings_QtWidgets[63256]
#define sipNameNr_setShape 63265
#define sipName_setShape &sipStrings_QtWidgets[63265]
#define sipNameNr_setSizes 63274
#define sipName_setSizes &sipStrings_QtWidgets[63274]
#define sipNameNr_setStack 63283
#define sipName_setStack &sipStrings_QtWidgets[63283]
#define sipNameNr_setState 63292
#define sipName_setState &sipStrings_QtWidgets[63292]
#define sipNameNr_setStyle 63301
#define sipName_setStyle &sipStrings_QtWidgets[63301]
#define sipNameNr_setTitle 63310
#define sipName_setTitle &sipStrings_QtWidgets[63310]
#define sipNameNr_setValue 63319
#define sipName_setValue &sipStrings_QtWidgets[63319]
#define sipNameNr_shortcut 63328
#define sipName_shortcut &sipStrings_QtWidgets[63328]
#define sipNameNr_showGrid 63337
#define sipName_showGrid &sipStrings_QtWidgets[63337]
#define sipNameNr_showMenu 63346
#define sipName_showMenu &sipStrings_QtWidgets[63346]
#define sipNameNr_showText 63355
#define sipName_showText &sipStrings_QtWidgets[63355]
#define sipNameNr_sizeHint 63364
#define sipName_sizeHint &sipStrings_QtWidgets[63364]
#define sipNameNr_splitter 63373
#define sipName_splitter &sipStrings_QtWidgets[63373]
#define sipNameNr_stepDown 63382
#define sipName_stepDown &sipStrings_QtWidgets[63382]
#define sipNameNr_stepType 63391
#define sipName_stepType &sipStrings_QtWidgets[63391]
#define sipNameNr_strength 63400
#define sipName_strength &sipStrings_QtWidgets[63400]
#define sipNameNr_subTitle 63409
#define sipName_subTitle &sipStrings_QtWidgets[63409]
#define sipNameNr_tabIndex 63418
#define sipName_tabIndex &sipStrings_QtWidgets[63418]
#define sipNameNr_tabMoved 63427
#define sipName_tabMoved &sipStrings_QtWidgets[63427]
#define sipNameNr_tabShape 63436
#define sipName_tabShape &sipStrings_QtWidgets[63436]
#define sipNameNr_takeItem 63445
#define sipName_takeItem &sipStrings_QtWidgets[63445]
#define sipNameNr_textRole 63454
#define sipName_textRole &sipStrings_QtWidgets[63454]
#define sipNameNr_timeSpec 63463
#define sipName_timeSpec &sipStrings_QtWidgets[63463]
#define sipNameNr_timeZone 63472
#define sipName_timeZone &sipStrings_QtWidgets[63472]
#define sipNameNr_unpolish 63481
#define sipName_unpolish &sipStrings_QtWidgets[63481]
#define sipNameNr_userData 63490
#define sipName_userData &sipStrings_QtWidgets[63490]
#define sipNameNr_validate 58785
#define sipName_validate &sipStrings_QtWidgets[58785]
#define sipNameNr_velocity 63499
#define sipName_velocity &sipStrings_QtWidgets[63499]
#define sipNameNr_viewMode 63508
#define sipName_viewMode &sipStrings_QtWidgets[63508]
#define sipNameNr_viewport 63517
#define sipName_viewport &sipStrings_QtWidgets[63517]
#define sipNameNr_widgetAt 63526
#define sipName_widgetAt &sipStrings_QtWidgets[63526]
#define sipNameNr_wordWrap 63535
#define sipName_wordWrap &sipStrings_QtWidgets[63535]
#define sipNameNr_wrapping 63544
#define sipName_wrapping &sipStrings_QtWidgets[63544]
#define sipNameNr_xChanged 26042
#define sipName_xChanged &sipStrings_QtWidgets[26042]
#define sipNameNr_yChanged 34651
#define sipName_yChanged &sipStrings_QtWidgets[34651]
#define sipNameNr_zChanged 63553
#define sipName_zChanged &sipStrings_QtWidgets[63553]
#define sipNameNr_AnyFile 63562
#define sipName_AnyFile &sipStrings_QtWidgets[63562]
#define sipNameNr_AutoAll 63570
#define sipName_AutoAll &sipStrings_QtWidgets[63570]
#define sipNameNr_Batched 63578
#define sipName_Batched &sipStrings_QtWidgets[63578]
#define sipNameNr_CC_Dial 63586
#define sipName_CC_Dial &sipStrings_QtWidgets[63586]
#define sipNameNr_CT_Menu 63594
#define sipName_CT_Menu &sipStrings_QtWidgets[63594]
#define sipNameNr_Checked 57631
#define sipName_Checked &sipStrings_QtWidgets[57631]
#define sipNameNr_Context 27634
#define sipName_Context &sipStrings_QtWidgets[27634]
#define sipNameNr_Default 44960
#define sipName_Default &sipStrings_QtWidgets[44960]
#define sipNameNr_Discard 63602
#define sipName_Discard &sipStrings_QtWidgets[63602]
#define sipNameNr_Enabled 18247
#define sipName_Enabled &sipStrings_QtWidgets[18247]
#define sipNameNr_HasMenu 63610
#define sipName_HasMenu &sipStrings_QtWidgets[63610]
#define sipNameNr_Ignored 46279
#define sipName_Ignored &sipStrings_QtWidgets[46279]
#define sipNameNr_Invalid 63618
#define sipName_Invalid &sipStrings_QtWidgets[63618]
#define sipNameNr_Maximum 37408
#define sipName_Maximum &sipStrings_QtWidgets[37408]
#define sipNameNr_Minimum 37425
#define sipName_Minimum &sipStrings_QtWidgets[37425]
#define sipNameNr_Movable 18339
#define sipName_Movable &sipStrings_QtWidgets[18339]
#define sipNameNr_MoveEnd 63626
#define sipName_MoveEnd &sipStrings_QtWidgets[63626]
#define sipNameNr_NoCache 63634
#define sipName_NoCache &sipStrings_QtWidgets[63634]
#define sipNameNr_NoFrame 63642
#define sipName_NoFrame &sipStrings_QtWidgets[63642]
#define sipNameNr_NoIndex 63650
#define sipName_NoIndex &sipStrings_QtWidgets[63650]
#define sipNameNr_NoState 63658
#define sipName_NoState &sipStrings_QtWidgets[63658]
#define sipNameNr_NoTicks 63666
#define sipName_NoTicks &sipStrings_QtWidgets[63666]
#define sipNameNr_NoToAll 63674
#define sipName_NoToAll &sipStrings_QtWidgets[63674]
#define sipNameNr_OnlyOne 63682
#define sipName_OnlyOne &sipStrings_QtWidgets[63682]
#define sipNameNr_Outline 63690
#define sipName_Outline &sipStrings_QtWidgets[63690]
#define sipNameNr_Pressed 42605
#define sipName_Pressed &sipStrings_QtWidgets[42605]
#define sipNameNr_QDialog 63698
#define sipName_QDialog &sipStrings_QtWidgets[63698]
#define sipNameNr_QLayout 63706
#define sipName_QLayout &sipStrings_QtWidgets[63706]
#define sipNameNr_QSlider 63714
#define sipName_QSlider &sipStrings_QtWidgets[63714]
#define sipNameNr_QTabBar 63722
#define sipName_QTabBar &sipStrings_QtWidgets[63722]
#define sipNameNr_QWidget 63730
#define sipName_QWidget &sipStrings_QtWidgets[63730]
#define sipNameNr_QWizard 63738
#define sipName_QWizard &sipStrings_QtWidgets[63738]
#define sipNameNr_Rounded 63746
#define sipName_Rounded &sipStrings_QtWidgets[63746]
#define sipNameNr_SC_None 63754
#define sipName_SC_None &sipStrings_QtWidgets[63754]
#define sipNameNr_SH_Mask 63762
#define sipName_SH_Mask &sipStrings_QtWidgets[63762]
#define sipNameNr_SaveAll 63770
#define sipName_SaveAll &sipStrings_QtWidgets[63770]
#define sipNameNr_Section 17097
#define sipName_Section &sipStrings_QtWidgets[17097]
#define sipNameNr_SpinBox 25263
#define sipName_SpinBox &sipStrings_QtWidgets[25263]
#define sipNameNr_Stretch 23694
#define sipName_Stretch &sipStrings_QtWidgets[23694]
#define sipNameNr_SubMenu 63778
#define sipName_SubMenu &sipStrings_QtWidgets[63778]
#define sipNameNr_TearOff 63786
#define sipName_TearOff &sipStrings_QtWidgets[63786]
#define sipNameNr_Trigger 7063
#define sipName_Trigger &sipStrings_QtWidgets[7063]
#define sipNameNr_Unknown 63794
#define sipName_Unknown &sipStrings_QtWidgets[63794]
#define sipNameNr_Version 139
#define sipName_Version &sipStrings_QtWidgets[139]
#define sipNameNr_Warning 22665
#define sipName_Warning &sipStrings_QtWidgets[22665]
#define sipNameNr_YesRole 63802
#define sipName_YesRole &sipStrings_QtWidgets[63802]
#define sipNameNr___len__ 63810
#define sipName___len__ &sipStrings_QtWidgets[63810]
#define sipNameNr_aboutQt 63818
#define sipName_aboutQt &sipStrings_QtWidgets[63818]
#define sipNameNr_actions 63826
#define sipName_actions &sipStrings_QtWidgets[63826]
#define sipNameNr_addItem 63834
#define sipName_addItem &sipStrings_QtWidgets[63834]
#define sipNameNr_addLine 63842
#define sipName_addLine &sipStrings_QtWidgets[63842]
#define sipNameNr_addMenu 63850
#define sipName_addMenu &sipStrings_QtWidgets[63850]
#define sipNameNr_addPage 63858
#define sipName_addPage &sipStrings_QtWidgets[63858]
#define sipNameNr_addPath 63866
#define sipName_addPath &sipStrings_QtWidgets[63866]
#define sipNameNr_addRect 63874
#define sipName_addRect &sipStrings_QtWidgets[63874]
#define sipNameNr_addText 63882
#define sipName_addText &sipStrings_QtWidgets[63882]
#define sipNameNr_advance 63890
#define sipName_advance &sipStrings_QtWidgets[63890]
#define sipNameNr_applyTo 63898
#define sipName_applyTo &sipStrings_QtWidgets[63898]
#define sipNameNr_buttons 63906
#define sipName_buttons &sipStrings_QtWidgets[63906]
#define sipNameNr_caption 63914
#define sipName_caption &sipStrings_QtWidgets[63914]
#define sipNameNr_changed 63922
#define sipName_changed &sipStrings_QtWidgets[63922]
#define sipNameNr_checked 63930
#define sipName_checked &sipStrings_QtWidgets[63930]
#define sipNameNr_childAt 63938
#define sipName_childAt &sipStrings_QtWidgets[63938]
#define sipNameNr_clicked 63946
#define sipName_clicked &sipStrings_QtWidgets[63946]
#define sipNameNr_combine 63954
#define sipName_combine &sipStrings_QtWidgets[63954]
#define sipNameNr_context 63962
#define sipName_context &sipStrings_QtWidgets[63962]
#define sipNameNr_current 63970
#define sipName_current &sipStrings_QtWidgets[63970]
#define sipNameNr_destroy 63978
#define sipName_destroy &sipStrings_QtWidgets[63978]
#define sipNameNr_devType 63986
#define sipName_devType &sipStrings_QtWidgets[63986]
#define sipNameNr_display 63994
#define sipName_display &sipStrings_QtWidgets[63994]
#define sipNameNr_drawRow 64002
#define sipName_drawRow &sipStrings_QtWidgets[64002]
#define sipNameNr_enabled 64010
#define sipName_enabled &sipStrings_QtWidgets[64010]
#define sipNameNr_entered 64018
#define sipName_entered &sipStrings_QtWidgets[64018]
#define sipNameNr_forward 64026
#define sipName_forward &sipStrings_QtWidgets[64026]
#define sipNameNr_gesture 64034
#define sipName_gesture &sipStrings_QtWidgets[64034]
#define sipNameNr_getFont 64042
#define sipName_getFont &sipStrings_QtWidgets[64042]
#define sipNameNr_getItem 35487
#define sipName_getItem &sipStrings_QtWidgets[35487]
#define sipNameNr_getText 64050
#define sipName_getText &sipStrings_QtWidgets[64050]
#define sipNameNr_hPolicy 7218
#define sipName_hPolicy &sipStrings_QtWidgets[7218]
#define sipNameNr_hideRow 64058
#define sipName_hideRow &sipStrings_QtWidgets[64058]
#define sipNameNr_history 64066
#define sipName_history &sipStrings_QtWidgets[64066]
#define sipNameNr_hitTest 64074
#define sipName_hitTest &sipStrings_QtWidgets[64074]
#define sipNameNr_hotSpot 64082
#define sipName_hotSpot &sipStrings_QtWidgets[64082]
#define sipNameNr_hovered 64090
#define sipName_hovered &sipStrings_QtWidgets[64090]
#define sipNameNr_indexAt 64098
#define sipName_indexAt &sipStrings_QtWidgets[64098]
#define sipNameNr_indexOf 64106
#define sipName_indexOf &sipStrings_QtWidgets[64106]
#define sipNameNr_initial 64114
#define sipName_initial &sipStrings_QtWidgets[64114]
#define sipNameNr_intStep 64122
#define sipName_intStep &sipStrings_QtWidgets[64122]
#define sipNameNr_isEmpty 64130
#define sipName_isEmpty &sipStrings_QtWidgets[64130]
#define sipNameNr_isModal 64138
#define sipName_isModal &sipStrings_QtWidgets[64138]
#define sipNameNr_isPanel 64146
#define sipName_isPanel &sipStrings_QtWidgets[64146]
#define sipNameNr_lastPos 64154
#define sipName_lastPos &sipStrings_QtWidgets[64154]
#define sipNameNr_mapFrom 64162
#define sipName_mapFrom &sipStrings_QtWidgets[64162]
#define sipNameNr_maximum 64170
#define sipName_maximum &sipStrings_QtWidgets[64170]
#define sipNameNr_mdiArea 64178
#define sipName_mdiArea &sipStrings_QtWidgets[64178]
#define sipNameNr_menuBar 64186
#define sipName_menuBar &sipStrings_QtWidgets[64186]
#define sipNameNr_message 64194
#define sipName_message &sipStrings_QtWidgets[64194]
#define sipNameNr_minimum 64202
#define sipName_minimum &sipStrings_QtWidgets[64202]
#define sipNameNr_movable 64210
#define sipName_movable &sipStrings_QtWidgets[64210]
#define sipNameNr_moveTab 61334
#define sipName_moveTab &sipStrings_QtWidgets[61334]
#define sipNameNr_newSize 64218
#define sipName_newSize &sipStrings_QtWidgets[64218]
#define sipNameNr_oldSize 64226
#define sipName_oldSize &sipStrings_QtWidgets[64226]
#define sipNameNr_opacity 64234
#define sipName_opacity &sipStrings_QtWidgets[64234]
#define sipNameNr_options 64242
#define sipName_options &sipStrings_QtWidgets[64242]
#define sipNameNr_pageIds 64250
#define sipName_pageIds &sipStrings_QtWidgets[64250]
#define sipNameNr_palette 64258
#define sipName_palette &sipStrings_QtWidgets[64258]
#define sipNameNr_picture 64266
#define sipName_picture &sipStrings_QtWidgets[64266]
#define sipNameNr_polygon 64274
#define sipName_polygon &sipStrings_QtWidgets[64274]
#define sipNameNr_pressed 64282
#define sipName_pressed &sipStrings_QtWidgets[64282]
#define sipNameNr_refresh 64290
#define sipName_refresh &sipStrings_QtWidgets[64290]
#define sipNameNr_repaint 64298
#define sipName_repaint &sipStrings_QtWidgets[64298]
#define sipNameNr_restart 64306
#define sipName_restart &sipStrings_QtWidgets[64306]
#define sipNameNr_rowSpan 64314
#define sipName_rowSpan &sipStrings_QtWidgets[64314]
#define sipNameNr_section 64322
#define sipName_section &sipStrings_QtWidgets[64322]
#define sipNameNr_setAxis 64330
#define sipName_setAxis &sipStrings_QtWidgets[64330]
#define sipNameNr_setData 64338
#define sipName_setData &sipStrings_QtWidgets[64338]
#define sipNameNr_setDate 64346
#define sipName_setDate &sipStrings_QtWidgets[64346]
#define sipNameNr_setDown 64354
#define sipName_setDown &sipStrings_QtWidgets[64354]
#define sipNameNr_setFlag 64362
#define sipName_setFlag &sipStrings_QtWidgets[64362]
#define sipNameNr_setFlat 64370
#define sipName_setFlat &sipStrings_QtWidgets[64370]
#define sipNameNr_setFlow 64378
#define sipName_setFlow &sipStrings_QtWidgets[64378]
#define sipNameNr_setFont 64386
#define sipName_setFont &sipStrings_QtWidgets[64386]
#define sipNameNr_setHtml 64394
#define sipName_setHtml &sipStrings_QtWidgets[64394]
#define sipNameNr_setIcon 64402
#define sipName_setIcon &sipStrings_QtWidgets[64402]
#define sipNameNr_setItem 64410
#define sipName_setItem &sipStrings_QtWidgets[64410]
#define sipNameNr_setLine 64418
#define sipName_setLine &sipStrings_QtWidgets[64418]
#define sipNameNr_setMask 64426
#define sipName_setMask &sipStrings_QtWidgets[64426]
#define sipNameNr_setMenu 64434
#define sipName_setMenu &sipStrings_QtWidgets[64434]
#define sipNameNr_setMode 64442
#define sipName_setMode &sipStrings_QtWidgets[64442]
#define sipNameNr_setPage 64450
#define sipName_setPage &sipStrings_QtWidgets[64450]
#define sipNameNr_setPath 64458
#define sipName_setPath &sipStrings_QtWidgets[64458]
#define sipNameNr_setRect 64466
#define sipName_setRect &sipStrings_QtWidgets[64466]
#define sipNameNr_setSpan 64474
#define sipName_setSpan &sipStrings_QtWidgets[64474]
#define sipNameNr_setText 64482
#define sipName_setText &sipStrings_QtWidgets[64482]
#define sipNameNr_setTime 64490
#define sipName_setTime &sipStrings_QtWidgets[64490]
#define sipNameNr_setView 64498
#define sipName_setView &sipStrings_QtWidgets[64498]
#define sipNameNr_showRow 64506
#define sipName_showRow &sipStrings_QtWidgets[64506]
#define sipNameNr_spacing 64514
#define sipName_spacing &sipStrings_QtWidgets[64514]
#define sipNameNr_startId 64522
#define sipName_startId &sipStrings_QtWidgets[64522]
#define sipNameNr_stretch 64530
#define sipName_stretch &sipStrings_QtWidgets[64530]
#define sipNameNr_tabData 64538
#define sipName_tabData &sipStrings_QtWidgets[64538]
#define sipNameNr_tabIcon 64546
#define sipName_tabIcon &sipStrings_QtWidgets[64546]
#define sipNameNr_tabRect 64554
#define sipName_tabRect &sipStrings_QtWidgets[64554]
#define sipNameNr_tabText 64562
#define sipName_tabText &sipStrings_QtWidgets[64562]
#define sipNameNr_takeRow 64570
#define sipName_takeRow &sipStrings_QtWidgets[64570]
#define sipNameNr_timeout 64578
#define sipName_timeout &sipStrings_QtWidgets[64578]
#define sipNameNr_toFirst 64586
#define sipName_toFirst &sipStrings_QtWidgets[64586]
#define sipNameNr_toggled 64594
#define sipName_toggled &sipStrings_QtWidgets[64594]
#define sipNameNr_toolTip 64602
#define sipName_toolTip &sipStrings_QtWidgets[64602]
#define sipNameNr_vPolicy 64610
#define sipName_vPolicy &sipStrings_QtWidgets[64610]
#define sipNameNr_variant 64618
#define sipName_variant &sipStrings_QtWidgets[64618]
#define sipNameNr_version 64626
#define sipName_version &sipStrings_QtWidgets[64626]
#define sipNameNr_warning 64634
#define sipName_warning &sipStrings_QtWidgets[64634]
#define sipNameNr_xMargin 64642
#define sipName_xMargin &sipStrings_QtWidgets[64642]
#define sipNameNr_xOffset 64650
#define sipName_xOffset &sipStrings_QtWidgets[64650]
#define sipNameNr_yMargin 64658
#define sipName_yMargin &sipStrings_QtWidgets[64658]
#define sipNameNr_yOffset 64666
#define sipName_yOffset &sipStrings_QtWidgets[64666]
#define sipNameNr_zoomOut 64674
#define sipName_zoomOut &sipStrings_QtWidgets[64674]
#define sipNameNr_Accept 64682
#define sipName_Accept &sipStrings_QtWidgets[64682]
#define sipNameNr_Adjust 64689
#define sipName_Adjust &sipStrings_QtWidgets[64689]
#define sipNameNr_Bottom 35318
#define sipName_Bottom &sipStrings_QtWidgets[35318]
#define sipNameNr_Cancel 64696
#define sipName_Cancel &sipStrings_QtWidgets[64696]
#define sipNameNr_Custom 64703
#define sipName_Custom &sipStrings_QtWidgets[64703]
#define sipNameNr_Detail 64710
#define sipName_Detail &sipStrings_QtWidgets[64710]
#define sipNameNr_Escape 64717
#define sipName_Escape &sipStrings_QtWidgets[64717]
#define sipNameNr_Filled 64724
#define sipName_Filled &sipStrings_QtWidgets[64724]
#define sipNameNr_Hidden 16350
#define sipName_Hidden &sipStrings_QtWidgets[16350]
#define sipNameNr_Ignore 64731
#define sipName_Ignore &sipStrings_QtWidgets[64731]
#define sipNameNr_LookIn 64738
#define sipName_LookIn &sipStrings_QtWidgets[64738]
#define sipNameNr_Margin 5197
#define sipName_Margin &sipStrings_QtWidgets[5197]
#define sipNameNr_Middle 64745
#define sipName_Middle &sipStrings_QtWidgets[64745]
#define sipNameNr_MoveUp 64752
#define sipName_MoveUp &sipStrings_QtWidgets[64752]
#define sipNameNr_Moving 64759
#define sipName_Moving &sipStrings_QtWidgets[64759]
#define sipNameNr_NoDrag 64766
#define sipName_NoDrag &sipStrings_QtWidgets[64766]
#define sipNameNr_NoEcho 64773
#define sipName_NoEcho &sipStrings_QtWidgets[64773]
#define sipNameNr_NoHint 64780
#define sipName_NoHint &sipStrings_QtWidgets[64780]
#define sipNameNr_NoIcon 64787
#define sipName_NoIcon &sipStrings_QtWidgets[64787]
#define sipNameNr_NoRole 64794
#define sipName_NoRole &sipStrings_QtWidgets[64794]
#define sipNameNr_NoWrap 64801
#define sipName_NoWrap &sipStrings_QtWidgets[64801]
#define sipNameNr_Normal 59568
#define sipName_Normal &sipStrings_QtWidgets[59568]
#define sipNameNr_OnItem 64808
#define sipName_OnItem &sipStrings_QtWidgets[64808]
#define sipNameNr_Option 6398
#define sipName_Option &sipStrings_QtWidgets[6398]
#define sipNameNr_Policy 2849
#define sipName_Policy &sipStrings_QtWidgets[2849]
#define sipNameNr_QFrame 64815
#define sipName_QFrame &sipStrings_QtWidgets[64815]
#define sipNameNr_QLabel 64822
#define sipName_QLabel &sipStrings_QtWidgets[64822]
#define sipNameNr_QStyle 64829
#define sipName_QStyle &sipStrings_QtWidgets[64829]
#define sipNameNr_Raised 51150
#define sipName_Raised &sipStrings_QtWidgets[51150]
#define sipNameNr_Reason 2462
#define sipName_Reason &sipStrings_QtWidgets[2462]
#define sipNameNr_Reject 64836
#define sipName_Reject &sipStrings_QtWidgets[64836]
#define sipNameNr_SC_All 64843
#define sipName_SC_All &sipStrings_QtWidgets[64843]
#define sipNameNr_SO_Tab 64850
#define sipName_SO_Tab &sipStrings_QtWidgets[64850]
#define sipNameNr_Shadow 42816
#define sipName_Shadow &sipStrings_QtWidgets[42816]
#define sipNameNr_Slider 8496
#define sipName_Slider &sipStrings_QtWidgets[8496]
#define sipNameNr_SortUp 64857
#define sipName_SortUp &sipStrings_QtWidgets[64857]
#define sipNameNr_Static 64864
#define sipName_Static &sipStrings_QtWidgets[64864]
#define sipNameNr_Sunken 51163
#define sipName_Sunken &sipStrings_QtWidgets[51163]
#define sipNameNr_YesAll 64871
#define sipName_YesAll &sipStrings_QtWidgets[64871]
#define sipNameNr___eq__ 64878
#define sipName___eq__ &sipStrings_QtWidgets[64878]
#define sipNameNr___ge__ 64885
#define sipName___ge__ &sipStrings_QtWidgets[64885]
#define sipNameNr___lt__ 64892
#define sipName___lt__ &sipStrings_QtWidgets[64892]
#define sipNameNr___ne__ 64899
#define sipName___ne__ &sipStrings_QtWidgets[64899]
#define sipNameNr_accept 64906
#define sipName_accept &sipStrings_QtWidgets[64906]
#define sipNameNr_action 64913
#define sipName_action &sipStrings_QtWidgets[64913]
#define sipNameNr_addRow 64920
#define sipName_addRow &sipStrings_QtWidgets[64920]
#define sipNameNr_addTab 64927
#define sipName_addTab &sipStrings_QtWidgets[64927]
#define sipNameNr_anchor 64934
#define sipName_anchor &sipStrings_QtWidgets[64934]
#define sipNameNr_append 64941
#define sipName_append &sipStrings_QtWidgets[64941]
#define sipNameNr_button 64948
#define sipName_button &sipStrings_QtWidgets[64948]
#define sipNameNr_cancel 64955
#define sipName_cancel &sipStrings_QtWidgets[64955]
#define sipNameNr_column 64962
#define sipName_column &sipStrings_QtWidgets[64962]
#define sipNameNr_corner 64969
#define sipName_corner &sipStrings_QtWidgets[64969]
#define sipNameNr_create 64976
#define sipName_create &sipStrings_QtWidgets[64976]
#define sipNameNr_cursor 64983
#define sipName_cursor &sipStrings_QtWidgets[64983]
#define sipNameNr_expand 63015
#define sipName_expand &sipStrings_QtWidgets[63015]
#define sipNameNr_filter 64990
#define sipName_filter &sipStrings_QtWidgets[64990]
#define sipNameNr_finish 64997
#define sipName_finish &sipStrings_QtWidgets[64997]
#define sipNameNr_format 63024
#define sipName_format &sipStrings_QtWidgets[63024]
#define sipNameNr_getInt 65004
#define sipName_getInt &sipStrings_QtWidgets[65004]
#define sipNameNr_handle 65011
#define sipName_handle &sipStrings_QtWidgets[65011]
#define sipNameNr_header 65018
#define sipName_header &sipStrings_QtWidgets[65018]
#define sipNameNr_height 65025
#define sipName_height &sipStrings_QtWidgets[65025]
#define sipNameNr_ignore 65032
#define sipName_ignore &sipStrings_QtWidgets[65032]
#define sipNameNr_indent 65039
#define sipName_indent &sipStrings_QtWidgets[65039]
#define sipNameNr_insert 65046
#define sipName_insert &sipStrings_QtWidgets[65046]
#define sipNameNr_isDown 65053
#define sipName_isDown &sipStrings_QtWidgets[65053]
#define sipNameNr_isFlat 65060
#define sipName_isFlat &sipStrings_QtWidgets[65060]
#define sipNameNr_itemAt 65067
#define sipName_itemAt &sipStrings_QtWidgets[65067]
#define sipNameNr_layers 65074
#define sipName_layers &sipStrings_QtWidgets[65074]
#define sipNameNr_layout 65081
#define sipName_layout &sipStrings_QtWidgets[65081]
#define sipNameNr_length 65088
#define sipName_length &sipStrings_QtWidgets[65088]
#define sipNameNr_locale 65095
#define sipName_locale &sipStrings_QtWidgets[65095]
#define sipNameNr_margin 65102
#define sipName_margin &sipStrings_QtWidgets[65102]
#define sipNameNr_metric 65109
#define sipName_metric &sipStrings_QtWidgets[65109]
#define sipNameNr_moveBy 65116
#define sipName_moveBy &sipStrings_QtWidgets[65116]
#define sipNameNr_newPos 65123
#define sipName_newPos &sipStrings_QtWidgets[65123]
#define sipNameNr_nextId 65130
#define sipName_nextId &sipStrings_QtWidgets[65130]
#define sipNameNr_notify 65137
#define sipName_notify &sipStrings_QtWidgets[65137]
#define sipNameNr_offset 65144
#define sipName_offset &sipStrings_QtWidgets[65144]
#define sipNameNr_oldPos 65151
#define sipName_oldPos &sipStrings_QtWidgets[65151]
#define sipNameNr_opaque 65158
#define sipName_opaque &sipStrings_QtWidgets[65158]
#define sipNameNr_option 65165
#define sipName_option &sipStrings_QtWidgets[65165]
#define sipNameNr_origin 65172
#define sipName_origin &sipStrings_QtWidgets[65172]
#define sipNameNr_parent 65179
#define sipName_parent &sipStrings_QtWidgets[65179]
#define sipNameNr_pixmap 65186
#define sipName_pixmap &sipStrings_QtWidgets[65186]
#define sipNameNr_polish 63483
#define sipName_polish &sipStrings_QtWidgets[63483]
#define sipNameNr_prefix 65193
#define sipName_prefix &sipStrings_QtWidgets[65193]
#define sipNameNr_raise_ 65200
#define sipName_raise_ &sipStrings_QtWidgets[65200]
#define sipNameNr_reason 65207
#define sipName_reason &sipStrings_QtWidgets[65207]
#define sipNameNr_region 65214
#define sipName_region &sipStrings_QtWidgets[65214]
#define sipNameNr_reject 65221
#define sipName_reject &sipStrings_QtWidgets[65221]
#define sipNameNr_reload 65228
#define sipName_reload &sipStrings_QtWidgets[65228]
#define sipNameNr_render 65235
#define sipName_render &sipStrings_QtWidgets[65235]
#define sipNameNr_resize 65242
#define sipName_resize &sipStrings_QtWidgets[65242]
#define sipNameNr_result 65249
#define sipName_result &sipStrings_QtWidgets[65249]
#define sipNameNr_revert 65256
#define sipName_revert &sipStrings_QtWidgets[65256]
#define sipNameNr_rotate 65263
#define sipName_rotate &sipStrings_QtWidgets[65263]
#define sipNameNr_screen 65270
#define sipName_screen &sipStrings_QtWidgets[65270]
#define sipNameNr_scroll 65277
#define sipName_scroll &sipStrings_QtWidgets[65277]
#define sipNameNr_setBar 65284
#define sipName_setBar &sipStrings_QtWidgets[65284]
#define sipNameNr_setNum 65291
#define sipName_setNum &sipStrings_QtWidgets[65291]
#define sipNameNr_setPen 65298
#define sipName_setPen &sipStrings_QtWidgets[65298]
#define sipNameNr_setPos 65305
#define sipName_setPos &sipStrings_QtWidgets[65305]
#define sipNameNr_source 52203
#define sipName_source &sipStrings_QtWidgets[52203]
#define sipNameNr_stepBy 65312
#define sipName_stepBy &sipStrings_QtWidgets[65312]
#define sipNameNr_stepUp 65319
#define sipName_stepUp &sipStrings_QtWidgets[65319]
#define sipNameNr_submit 65326
#define sipName_submit &sipStrings_QtWidgets[65326]
#define sipNameNr_suffix 65333
#define sipName_suffix &sipStrings_QtWidgets[65333]
#define sipNameNr_sunken 65340
#define sipName_sunken &sipStrings_QtWidgets[65340]
#define sipNameNr_system 65347
#define sipName_system &sipStrings_QtWidgets[65347]
#define sipNameNr_tabBar 65354
#define sipName_tabBar &sipStrings_QtWidgets[65354]
#define sipNameNr_takeAt 65361
#define sipName_takeAt &sipStrings_QtWidgets[65361]
#define sipNameNr_target 65368
#define sipName_target &sipStrings_QtWidgets[65368]
#define sipNameNr_toHtml 65375
#define sipName_toHtml &sipStrings_QtWidgets[65375]
#define sipNameNr_toLast 65382
#define sipName_toLast &sipStrings_QtWidgets[65382]
#define sipNameNr_toNext 65389
#define sipName_toNext &sipStrings_QtWidgets[65389]
#define sipNameNr_toggle 65396
#define sipName_toggle &sipStrings_QtWidgets[65396]
#define sipNameNr_topRow 65403
#define sipName_topRow &sipStrings_QtWidgets[65403]
#define sipNameNr_update 65410
#define sipName_update &sipStrings_QtWidgets[65410]
#define sipNameNr_widget 65417
#define sipName_widget &sipStrings_QtWidgets[65417]
#define sipNameNr_window 65424
#define sipName_window &sipStrings_QtWidgets[65424]
#define sipNameNr_wizard 65431
#define sipName_wizard &sipStrings_QtWidgets[65431]
#define sipNameNr_xScale 65438
#define sipName_xScale &sipStrings_QtWidgets[65438]
#define sipNameNr_yScale 65445
#define sipName_yScale &sipStrings_QtWidgets[65445]
#define sipNameNr_zScale 65452
#define sipName_zScale &sipStrings_QtWidgets[65452]
#define sipNameNr_zValue 65459
#define sipName_zValue &sipStrings_QtWidgets[65459]
#define sipNameNr_zoomIn 65466
#define sipName_zoomIn &sipStrings_QtWidgets[65466]
#define sipNameNr_Abort 65473
#define sipName_Abort &sipStrings_QtWidgets[65473]
#define sipNameNr_Apply 65479
#define sipName_Apply &sipStrings_QtWidgets[65479]
#define sipNameNr_Arrow 9740
#define sipName_Arrow &sipStrings_QtWidgets[9740]
#define sipNameNr_Close 21680
#define sipName_Close &sipStrings_QtWidgets[21680]
#define sipNameNr_Fixed 65485
#define sipName_Fixed &sipStrings_QtWidgets[65485]
#define sipNameNr_Fps20 65491
#define sipName_Fps20 &sipStrings_QtWidgets[65491]
#define sipNameNr_Fps30 65497
#define sipName_Fps30 &sipStrings_QtWidgets[65497]
#define sipNameNr_Fps60 65503
#define sipName_Fps60 &sipStrings_QtWidgets[65503]
#define sipNameNr_Frame 7530
#define sipName_Frame &sipStrings_QtWidgets[7530]
#define sipNameNr_HLine 65509
#define sipName_HLine &sipStrings_QtWidgets[65509]
#define sipNameNr_Input 9401
#define sipName_Input &sipStrings_QtWidgets[9401]
#define sipNameNr_Label 13378
#define sipName_Label &sipStrings_QtWidgets[13378]
#define sipNameNr_Mouse 34758
#define sipName_Mouse &sipStrings_QtWidgets[34758]
#define sipNameNr_NoAll 65515
#define sipName_NoAll &sipStrings_QtWidgets[65515]
#define sipNameNr_NoPad 65521
#define sipName_NoPad &sipStrings_QtWidgets[65521]
#define sipNameNr_None_ 65527
#define sipName_None_ &sipStrings_QtWidgets[65527]
#define sipNameNr_North 39632
#define sipName_North &sipStrings_QtWidgets[39632]
#define sipNameNr_Other 65533
#define sipName_Other &sipStrings_QtWidgets[65533]
#define sipNameNr_Panel 5470
#define sipName_Panel &sipStrings_QtWidgets[5470]
#define sipNameNr_Plain 65539
#define sipName_Plain &sipStrings_QtWidgets[65539]
#define sipNameNr_QDial 65545
#define sipName_QDial &sipStrings_QtWidgets[65545]
#define sipNameNr_QMenu 65551
#define sipName_QMenu &sipStrings_QtWidgets[65551]
#define sipNameNr_Reset 52841
#define sipName_Reset &sipStrings_QtWidgets[52841]
#define sipNameNr_Retry 65557
#define sipName_Retry &sipStrings_QtWidgets[65557]
#define sipNameNr_Right 10132
#define sipName_Right &sipStrings_QtWidgets[10132]
#define sipNameNr_Shape 9600
#define sipName_Shape &sipStrings_QtWidgets[9600]
#define sipNameNr_South 39648
#define sipName_South &sipStrings_QtWidgets[39648]
#define sipNameNr_State 13328
#define sipName_State &sipStrings_QtWidgets[13328]
#define sipNameNr_VLine 65563
#define sipName_VLine &sipStrings_QtWidgets[65563]
#define sipNameNr_about 65569
#define sipName_about &sipStrings_QtWidgets[65569]
#define sipNameNr_alert 65575
#define sipName_alert &sipStrings_QtWidgets[65575]
#define sipNameNr_angle 60366
#define sipName_angle &sipStrings_QtWidgets[60366]
#define sipNameNr_begin 65581
#define sipName_begin &sipStrings_QtWidgets[65581]
#define sipNameNr_brush 65587
#define sipName_brush &sipStrings_QtWidgets[65587]
#define sipNameNr_buddy 65593
#define sipName_buddy &sipStrings_QtWidgets[65593]
#define sipNameNr_child 65599
#define sipName_child &sipStrings_QtWidgets[65599]
#define sipNameNr_clear 65605
#define sipName_clear &sipStrings_QtWidgets[65605]
#define sipNameNr_click 65611
#define sipName_click &sipStrings_QtWidgets[65611]
#define sipNameNr_clone 65617
#define sipName_clone &sipStrings_QtWidgets[65617]
#define sipNameNr_close 65623
#define sipName_close &sipStrings_QtWidgets[65623]
#define sipNameNr_color 65629
#define sipName_color &sipStrings_QtWidgets[65629]
#define sipNameNr_count 65635
#define sipName_count &sipStrings_QtWidgets[65635]
#define sipNameNr_delta 65641
#define sipName_delta &sipStrings_QtWidgets[65641]
#define sipNameNr_depth 65647
#define sipName_depth &sipStrings_QtWidgets[65647]
#define sipNameNr_event 65653
#define sipName_event &sipStrings_QtWidgets[65653]
#define sipNameNr_field 65659
#define sipName_field &sipStrings_QtWidgets[65659]
#define sipNameNr_fixup 65665
#define sipName_fixup &sipStrings_QtWidgets[65665]
#define sipNameNr_flags 65671
#define sipName_flags &sipStrings_QtWidgets[65671]
#define sipNameNr_frame 65677
#define sipName_frame &sipStrings_QtWidgets[65677]
#define sipNameNr_group 65683
#define sipName_group &sipStrings_QtWidgets[65683]
#define sipNameNr_index 65689
#define sipName_index &sipStrings_QtWidgets[65689]
#define sipNameNr_items 65695
#define sipName_items &sipStrings_QtWidgets[65695]
#define sipNameNr_lower 65701
#define sipName_lower &sipStrings_QtWidgets[65701]
#define sipNameNr_mapTo 65707
#define sipName_mapTo &sipStrings_QtWidgets[65707]
#define sipNameNr_model 65713
#define sipName_model &sipStrings_QtWidgets[65713]
#define sipNameNr_movie 65719
#define sipName_movie &sipStrings_QtWidgets[65719]
#define sipNameNr_msecs 65725
#define sipName_msecs &sipStrings_QtWidgets[65725]
#define sipNameNr_order 17076
#define sipName_order &sipStrings_QtWidgets[17076]
#define sipNameNr_paint 64300
#define sipName_paint &sipStrings_QtWidgets[64300]
#define sipNameNr_panel 65731
#define sipName_panel &sipStrings_QtWidgets[65731]
#define sipNameNr_paste 65737
#define sipName_paste &sipStrings_QtWidgets[65737]
#define sipNameNr_phase 65743
#define sipName_phase &sipStrings_QtWidgets[65743]
#define sipNameNr_popup 65749
#define sipName_popup &sipStrings_QtWidgets[65749]
#define sipNameNr_print 65755
#define sipName_print &sipStrings_QtWidgets[65755]
#define sipNameNr_proxy 65761
#define sipName_proxy &sipStrings_QtWidgets[65761]
#define sipNameNr_query 65767
#define sipName_query &sipStrings_QtWidgets[65767]
#define sipNameNr_range 65773
#define sipName_range &sipStrings_QtWidgets[65773]
#define sipNameNr_reset 65779
#define sipName_reset &sipStrings_QtWidgets[65779]
#define sipNameNr_roles 65785
#define sipName_roles &sipStrings_QtWidgets[65785]
#define sipNameNr_rowAt 65791
#define sipName_rowAt &sipStrings_QtWidgets[65791]
#define sipNameNr_scale 65797
#define sipName_scale &sipStrings_QtWidgets[65797]
#define sipNameNr_scene 65803
#define sipName_scene &sipStrings_QtWidgets[65803]
#define sipNameNr_setId 65809
#define sipName_setId &sipStrings_QtWidgets[65809]
#define sipNameNr_shape 65815
#define sipName_shape &sipStrings_QtWidgets[65815]
#define sipNameNr_shear 65821
#define sipName_shear &sipStrings_QtWidgets[65821]
#define sipNameNr_sizes 11440
#define sipName_sizes &sipStrings_QtWidgets[11440]
#define sipNameNr_stack 65827
#define sipName_stack &sipStrings_QtWidgets[65827]
#define sipNameNr_state 56866
#define sipName_state &sipStrings_QtWidgets[56866]
#define sipNameNr_steps 65833
#define sipName_steps &sipStrings_QtWidgets[65833]
#define sipNameNr_style 65839
#define sipName_style &sipStrings_QtWidgets[65839]
#define sipNameNr_tabAt 65845
#define sipName_tabAt &sipStrings_QtWidgets[65845]
#define sipNameNr_title 65851
#define sipName_title &sipStrings_QtWidgets[65851]
#define sipNameNr_value 65857
#define sipName_value &sipStrings_QtWidgets[65857]
#define sipNameNr_views 65863
#define sipName_views &sipStrings_QtWidgets[65863]
#define sipNameNr_width 65869
#define sipName_width &sipStrings_QtWidgets[65869]
#define sipNameNr_winId 65875
#define sipName_winId &sipStrings_QtWidgets[65875]
#define sipNameNr_write 21365
#define sipName_write &sipStrings_QtWidgets[21365]
#define sipNameNr_Down 10631
#define sipName_Down &sipStrings_QtWidgets[10631]
#define sipNameNr_East 43418
#define sipName_East &sipStrings_QtWidgets[43418]
#define sipNameNr_Flat 64373
#define sipName_Flat &sipStrings_QtWidgets[64373]
#define sipNameNr_Flow 39169
#define sipName_Flow &sipStrings_QtWidgets[39169]
#define sipNameNr_Free 65881
#define sipName_Free &sipStrings_QtWidgets[65881]
#define sipNameNr_Help 65886
#define sipName_Help &sipStrings_QtWidgets[65886]
#define sipNameNr_Icon 2775
#define sipName_Icon &sipStrings_QtWidgets[2775]
#define sipNameNr_Left 11171
#define sipName_Left &sipStrings_QtWidgets[11171]
#define sipNameNr_Line 24386
#define sipName_Line &sipStrings_QtWidgets[24386]
#define sipNameNr_List 42383
#define sipName_List &sipStrings_QtWidgets[42383]
#define sipNameNr_Menu 12719
#define sipName_Menu &sipStrings_QtWidgets[12719]
#define sipNameNr_Mode 5369
#define sipName_Mode &sipStrings_QtWidgets[5369]
#define sipNameNr_Open 17997
#define sipName_Open &sipStrings_QtWidgets[17997]
#define sipNameNr_Save 57392
#define sipName_Save &sipStrings_QtWidgets[57392]
#define sipNameNr_Snap 65891
#define sipName_Snap &sipStrings_QtWidgets[65891]
#define sipNameNr_Type 500
#define sipName_Type &sipStrings_QtWidgets[500]
#define sipNameNr_West 43433
#define sipName_West &sipStrings_QtWidgets[43433]
#define sipNameNr_area 65896
#define sipName_area &sipStrings_QtWidgets[65896]
#define sipNameNr_axis 65901
#define sipName_axis &sipStrings_QtWidgets[65901]
#define sipNameNr_back 65906
#define sipName_back &sipStrings_QtWidgets[65906]
#define sipNameNr_beep 65911
#define sipName_beep &sipStrings_QtWidgets[65911]
#define sipNameNr_copy 65916
#define sipName_copy &sipStrings_QtWidgets[65916]
#define sipNameNr_data 65921
#define sipName_data &sipStrings_QtWidgets[65921]
#define sipNameNr_date 10496
#define sipName_date &sipStrings_QtWidgets[10496]
#define sipNameNr_del_ 65926
#define sipName_del_ &sipStrings_QtWidgets[65926]
#define sipNameNr_done 65931
#define sipName_done &sipStrings_QtWidgets[65931]
#define sipNameNr_draw 65936
#define sipName_draw &sipStrings_QtWidgets[65936]
#define sipNameNr_echo 65941
#define sipName_echo &sipStrings_QtWidgets[65941]
#define sipNameNr_edit 65946
#define sipName_edit &sipStrings_QtWidgets[65946]
#define sipNameNr_exec 65951
#define sipName_exec &sipStrings_QtWidgets[65951]
#define sipNameNr_fill 65956
#define sipName_fill &sipStrings_QtWidgets[65956]
#define sipNameNr_find 65961
#define sipName_find &sipStrings_QtWidgets[65961]
#define sipNameNr_flow 47528
#define sipName_flow &sipStrings_QtWidgets[47528]
#define sipNameNr_font 65966
#define sipName_font &sipStrings_QtWidgets[65966]
#define sipNameNr_grab 65971
#define sipName_grab &sipStrings_QtWidgets[65971]
#define sipNameNr_hide 65976
#define sipName_hide &sipStrings_QtWidgets[65976]
#define sipNameNr_hint 65981
#define sipName_hint &sipStrings_QtWidgets[65981]
#define sipNameNr_home 65986
#define sipName_home &sipStrings_QtWidgets[65986]
#define sipNameNr_icon 65991
#define sipName_icon &sipStrings_QtWidgets[65991]
#define sipNameNr_item 65996
#define sipName_item &sipStrings_QtWidgets[65996]
#define sipNameNr_keys 66001
#define sipName_keys &sipStrings_QtWidgets[66001]
#define sipNameNr_line 37479
#define sipName_line &sipStrings_QtWidgets[37479]
#define sipNameNr_mask 66006
#define sipName_mask &sipStrings_QtWidgets[66006]
#define sipNameNr_menu 66011
#define sipName_menu &sipStrings_QtWidgets[66011]
#define sipNameNr_mode 66016
#define sipName_mode &sipStrings_QtWidgets[66016]
#define sipNameNr_move 9489
#define sipName_move &sipStrings_QtWidgets[9489]
#define sipNameNr_name 66021
#define sipName_name &sipStrings_QtWidgets[66021]
#define sipNameNr_next 66026
#define sipName_next &sipStrings_QtWidgets[66026]
#define sipNameNr_open 66031
#define sipName_open &sipStrings_QtWidgets[66031]
#define sipNameNr_page 66036
#define sipName_page &sipStrings_QtWidgets[66036]
#define sipNameNr_path 66041
#define sipName_path &sipStrings_QtWidgets[66041]
#define sipNameNr_read 66046
#define sipName_read &sipStrings_QtWidgets[66046]
#define sipNameNr_rect 66051
#define sipName_rect &sipStrings_QtWidgets[66051]
#define sipNameNr_redo 66056
#define sipName_redo &sipStrings_QtWidgets[66056]
#define sipNameNr_role 66061
#define sipName_role &sipStrings_QtWidgets[66061]
#define sipNameNr_setX 66066
#define sipName_setX &sipStrings_QtWidgets[66066]
#define sipNameNr_setY 66071
#define sipName_setY &sipStrings_QtWidgets[66071]
#define sipNameNr_show 66076
#define sipName_show &sipStrings_QtWidgets[66076]
#define sipNameNr_size 13979
#define sipName_size &sipStrings_QtWidgets[13979]
#define sipNameNr_step 66081
#define sipName_step &sipStrings_QtWidgets[66081]
#define sipNameNr_stop 66086
#define sipName_stop &sipStrings_QtWidgets[66086]
#define sipNameNr_text 27637
#define sipName_text &sipStrings_QtWidgets[27637]
#define sipNameNr_time 66091
#define sipName_time &sipStrings_QtWidgets[66091]
#define sipNameNr_type 37530
#define sipName_type &sipStrings_QtWidgets[37530]
#define sipNameNr_undo 66096
#define sipName_undo &sipStrings_QtWidgets[66096]
#define sipNameNr_view 66101
#define sipName_view &sipStrings_QtWidgets[66101]
#define sipNameNr_All 55032
#define sipName_All &sipStrings_QtWidgets[55032]
#define sipNameNr_Bin 66106
#define sipName_Bin &sipStrings_QtWidgets[66106]
#define sipNameNr_Box 21619
#define sipName_Box &sipStrings_QtWidgets[21619]
#define sipNameNr_Dec 66110
#define sipName_Dec &sipStrings_QtWidgets[66110]
#define sipNameNr_End 35763
#define sipName_End &sipStrings_QtWidgets[35763]
#define sipNameNr_Hex 66114
#define sipName_Hex &sipStrings_QtWidgets[66114]
#define sipNameNr_Oct 66118
#define sipName_Oct &sipStrings_QtWidgets[66118]
#define sipNameNr_Top 46661
#define sipName_Top &sipStrings_QtWidgets[46661]
#define sipNameNr_Yes 66122
#define sipName_Yes &sipStrings_QtWidgets[66122]
#define sipNameNr_cut 22480
#define sipName_cut &sipStrings_QtWidgets[22480]
#define sipNameNr_end 64944
#define sipName_end &sipStrings_QtWidgets[64944]
#define sipNameNr_max 66126
#define sipName_max &sipStrings_QtWidgets[66126]
#define sipNameNr_min 66130
#define sipName_min &sipStrings_QtWidgets[66130]
#define sipNameNr_pen 17998
#define sipName_pen &sipStrings_QtWidgets[17998]
#define sipNameNr_pos 66134
#define sipName_pos &sipStrings_QtWidgets[66134]
#define sipNameNr_row 9742
#define sipName_row &sipStrings_QtWidgets[9742]
#define sipNameNr_No 66138
#define sipName_No &sipStrings_QtWidgets[66138]
#define sipNameNr_Ok 66141
#define sipName_Ok &sipStrings_QtWidgets[66141]
#define sipNameNr_Up 24708
#define sipName_Up &sipStrings_QtWidgets[24708]
#define sipNameNr_at 590
#define sipName_at &sipStrings_QtWidgets[590]
#define sipNameNr_id 56749
#define sipName_id &sipStrings_QtWidgets[56749]
#define sipNameNr_ok 66144
#define sipName_ok &sipStrings_QtWidgets[66144]
#define sipNameNr_on 144
#define sipName_on &sipStrings_QtWidgets[144]
#define sipNameNr_x 15923
#define sipName_x &sipStrings_QtWidgets[15923]
#define sipNameNr_y 2854
#define sipName_y &sipStrings_QtWidgets[2854]

#define sipMalloc                   sipAPI_QtWidgets->api_malloc
#define sipFree                     sipAPI_QtWidgets->api_free
#define sipBuildResult              sipAPI_QtWidgets->api_build_result
#define sipCallMethod               sipAPI_QtWidgets->api_call_method
#define sipCallProcedureMethod      sipAPI_QtWidgets->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtWidgets->api_call_error_handler
#define sipParseResultEx            sipAPI_QtWidgets->api_parse_result_ex
#define sipParseResult              sipAPI_QtWidgets->api_parse_result
#define sipParseArgs                sipAPI_QtWidgets->api_parse_args
#define sipParseKwdArgs             sipAPI_QtWidgets->api_parse_kwd_args
#define sipParsePair                sipAPI_QtWidgets->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtWidgets->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtWidgets->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtWidgets->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtWidgets->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtWidgets->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtWidgets->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtWidgets->api_add_exception
#define sipNoFunction               sipAPI_QtWidgets->api_no_function
#define sipNoMethod                 sipAPI_QtWidgets->api_no_method
#define sipAbstractMethod           sipAPI_QtWidgets->api_abstract_method
#define sipBadClass                 sipAPI_QtWidgets->api_bad_class
#define sipBadCatcherResult         sipAPI_QtWidgets->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtWidgets->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtWidgets->api_bad_operator_arg
#define sipTrace                    sipAPI_QtWidgets->api_trace
#define sipTransferBack             sipAPI_QtWidgets->api_transfer_back
#define sipTransferTo               sipAPI_QtWidgets->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtWidgets->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtWidgets->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtWidgets->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtWidgets->api_voidptr_type
#define sipGetPyObject              sipAPI_QtWidgets->api_get_pyobject
#define sipGetAddress               sipAPI_QtWidgets->api_get_address
#define sipGetMixinAddress          sipAPI_QtWidgets->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtWidgets->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtWidgets->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtWidgets->api_call_hook
#define sipEndThread                sipAPI_QtWidgets->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtWidgets->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtWidgets->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtWidgets->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtWidgets->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtWidgets->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtWidgets->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtWidgets->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtWidgets->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtWidgets->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtWidgets->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtWidgets->api_convert_to_bool
#define sipReleaseType              sipAPI_QtWidgets->api_release_type
#define sipConvertFromType          sipAPI_QtWidgets->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtWidgets->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtWidgets->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtWidgets->api_convert_from_enum
#define sipGetState                 sipAPI_QtWidgets->api_get_state
#define sipExportSymbol             sipAPI_QtWidgets->api_export_symbol
#define sipImportSymbol             sipAPI_QtWidgets->api_import_symbol
#define sipFindType                 sipAPI_QtWidgets->api_find_type
#define sipBytes_AsChar             sipAPI_QtWidgets->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtWidgets->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtWidgets->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtWidgets->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtWidgets->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtWidgets->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtWidgets->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtWidgets->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtWidgets->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtWidgets->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtWidgets->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtWidgets->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtWidgets->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtWidgets->api_get_reference
#define sipKeepReference            sipAPI_QtWidgets->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtWidgets->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtWidgets->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtWidgets->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtWidgets->api_type_scope
#define sipResolveTypedef           sipAPI_QtWidgets->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtWidgets->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtWidgets->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtWidgets->api_init_mixin
#define sipExportModule             sipAPI_QtWidgets->api_export_module
#define sipInitModule               sipAPI_QtWidgets->api_init_module
#define sipGetInterpreter           sipAPI_QtWidgets->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtWidgets->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtWidgets->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtWidgets->api_py_type_dict
#define sipPyTypeName               sipAPI_QtWidgets->api_py_type_name
#define sipGetCFunction             sipAPI_QtWidgets->api_get_c_function
#define sipGetMethod                sipAPI_QtWidgets->api_get_method
#define sipFromMethod               sipAPI_QtWidgets->api_from_method
#define sipGetDate                  sipAPI_QtWidgets->api_get_date
#define sipFromDate                 sipAPI_QtWidgets->api_from_date
#define sipGetDateTime              sipAPI_QtWidgets->api_get_datetime
#define sipFromDateTime             sipAPI_QtWidgets->api_from_datetime
#define sipGetTime                  sipAPI_QtWidgets->api_get_time
#define sipFromTime                 sipAPI_QtWidgets->api_from_time
#define sipIsUserType               sipAPI_QtWidgets->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtWidgets->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtWidgets->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtWidgets->api_unicode_write
#define sipUnicodeData              sipAPI_QtWidgets->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtWidgets->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtWidgets->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtWidgets->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtWidgets->api_is_derived_class
#define sipGetUserObject            sipAPI_QtWidgets->api_get_user_object
#define sipSetUserObject            sipAPI_QtWidgets->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtWidgets->api_register_event_handler
#define sipConvertToArray           sipAPI_QtWidgets->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtWidgets->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtWidgets->api_enable_gc
#define sipPrintObject              sipAPI_QtWidgets->api_print_object
#define sipLong_AsChar              sipAPI_QtWidgets->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtWidgets->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtWidgets->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtWidgets->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtWidgets->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtWidgets->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtWidgets->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtWidgets->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtWidgets->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtWidgets->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtWidgets->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtWidgets->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtWidgets->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtWidgets->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtWidgets->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtWidgets->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtWidgets->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtWidgets->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtWidgets->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtWidgets->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtWidgets->api_release_type_us
#define sipIsPyMethod               sipAPI_QtWidgets->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtWidgets[];

#define sipType_QWidget sipExportedTypes_QtWidgets[444]

#define sipType_QWidget_RenderFlag sipExportedTypes_QtWidgets[445]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWidget;

#define sipType_QAbstractButton sipExportedTypes_QtWidgets[0]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractButton;

#define sipType_QAbstractItemDelegate sipExportedTypes_QtWidgets[2]

#define sipType_QAbstractItemDelegate_EndEditHint sipExportedTypes_QtWidgets[3]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractItemDelegate;

#define sipType_QFrame sipExportedTypes_QtWidgets[115]

#define sipType_QFrame_StyleMask sipExportedTypes_QtWidgets[118]

#define sipType_QFrame_Shape sipExportedTypes_QtWidgets[117]

#define sipType_QFrame_Shadow sipExportedTypes_QtWidgets[116]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFrame;

#define sipType_QAbstractScrollArea sipExportedTypes_QtWidgets[14]

#define sipType_QAbstractScrollArea_SizeAdjustPolicy sipExportedTypes_QtWidgets[15]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractScrollArea;

#define sipType_QAbstractItemView sipExportedTypes_QtWidgets[4]

#define sipType_QAbstractItemView_DropIndicatorPosition sipExportedTypes_QtWidgets[7]

#define sipType_QAbstractItemView_State sipExportedTypes_QtWidgets[13]

#define sipType_QAbstractItemView_CursorAction sipExportedTypes_QtWidgets[5]

#define sipType_QAbstractItemView_SelectionMode sipExportedTypes_QtWidgets[12]

#define sipType_QAbstractItemView_SelectionBehavior sipExportedTypes_QtWidgets[11]

#define sipType_QAbstractItemView_ScrollMode sipExportedTypes_QtWidgets[10]

#define sipType_QAbstractItemView_ScrollHint sipExportedTypes_QtWidgets[9]

#define sipType_QAbstractItemView_EditTrigger sipExportedTypes_QtWidgets[8]

#define sipType_QAbstractItemView_DragDropMode sipExportedTypes_QtWidgets[6]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractItemView;

#define sipType_QAbstractSlider sipExportedTypes_QtWidgets[16]

#define sipType_QAbstractSlider_SliderChange sipExportedTypes_QtWidgets[18]

#define sipType_QAbstractSlider_SliderAction sipExportedTypes_QtWidgets[17]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractSlider;

#define sipType_QAbstractSpinBox sipExportedTypes_QtWidgets[19]

#define sipType_QAbstractSpinBox_StepType sipExportedTypes_QtWidgets[23]

#define sipType_QAbstractSpinBox_CorrectionMode sipExportedTypes_QtWidgets[21]

#define sipType_QAbstractSpinBox_ButtonSymbols sipExportedTypes_QtWidgets[20]

#define sipType_QAbstractSpinBox_StepEnabledFlag sipExportedTypes_QtWidgets[22]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractSpinBox;

#define sipType_QApplication sipExportedTypes_QtWidgets[24]

extern sipClassTypeDef sipTypeDef_QtWidgets_QApplication;

#define sipType_QLayoutItem sipExportedTypes_QtWidgets[196]

extern sipClassTypeDef sipTypeDef_QtWidgets_QLayoutItem;

#define sipType_QLayout sipExportedTypes_QtWidgets[194]

#define sipType_QLayout_SizeConstraint sipExportedTypes_QtWidgets[195]

extern sipClassTypeDef sipTypeDef_QtWidgets_QLayout;

#define sipType_QBoxLayout sipExportedTypes_QtWidgets[25]

#define sipType_QBoxLayout_Direction sipExportedTypes_QtWidgets[26]

extern sipClassTypeDef sipTypeDef_QtWidgets_QBoxLayout;

#define sipType_QHBoxLayout sipExportedTypes_QtWidgets[180]

extern sipClassTypeDef sipTypeDef_QtWidgets_QHBoxLayout;

#define sipType_QVBoxLayout sipExportedTypes_QtWidgets[442]

extern sipClassTypeDef sipTypeDef_QtWidgets_QVBoxLayout;

#define sipType_QButtonGroup sipExportedTypes_QtWidgets[27]

extern sipClassTypeDef sipTypeDef_QtWidgets_QButtonGroup;

#define sipType_QCalendarWidget sipExportedTypes_QtWidgets[28]

#define sipType_QCalendarWidget_SelectionMode sipExportedTypes_QtWidgets[30]

#define sipType_QCalendarWidget_VerticalHeaderFormat sipExportedTypes_QtWidgets[31]

#define sipType_QCalendarWidget_HorizontalHeaderFormat sipExportedTypes_QtWidgets[29]

extern sipClassTypeDef sipTypeDef_QtWidgets_QCalendarWidget;

#define sipType_QCheckBox sipExportedTypes_QtWidgets[32]

extern sipClassTypeDef sipTypeDef_QtWidgets_QCheckBox;

#define sipType_QDialog sipExportedTypes_QtWidgets[51]

#define sipType_QDialog_DialogCode sipExportedTypes_QtWidgets[52]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDialog;

#define sipType_QColorDialog sipExportedTypes_QtWidgets[33]

#define sipType_QColorDialog_ColorDialogOption sipExportedTypes_QtWidgets[34]

extern sipClassTypeDef sipTypeDef_QtWidgets_QColorDialog;

#define sipType_QColumnView sipExportedTypes_QtWidgets[35]

extern sipClassTypeDef sipTypeDef_QtWidgets_QColumnView;

#define sipType_QComboBox sipExportedTypes_QtWidgets[36]

#define sipType_QComboBox_LabelDrawingMode sipExportedTypes_QtWidgets[38]

#define sipType_QComboBox_SizeAdjustPolicy sipExportedTypes_QtWidgets[39]

#define sipType_QComboBox_InsertPolicy sipExportedTypes_QtWidgets[37]

extern sipClassTypeDef sipTypeDef_QtWidgets_QComboBox;

#define sipType_QPushButton sipExportedTypes_QtWidgets[252]

extern sipClassTypeDef sipTypeDef_QtWidgets_QPushButton;

#define sipType_QCommandLinkButton sipExportedTypes_QtWidgets[40]

extern sipClassTypeDef sipTypeDef_QtWidgets_QCommandLinkButton;

#define sipType_QStyle sipExportedTypes_QtWidgets[282]

#define sipType_QStyle_RequestSoftwareInputPanel sipExportedTypes_QtWidgets[288]

#define sipType_QStyle_StandardPixmap sipExportedTypes_QtWidgets[289]

#define sipType_QStyle_StyleHint sipExportedTypes_QtWidgets[291]

#define sipType_QStyle_ContentsType sipExportedTypes_QtWidgets[284]

#define sipType_QStyle_PixelMetric sipExportedTypes_QtWidgets[286]

#define sipType_QStyle_SubControl sipExportedTypes_QtWidgets[292]

#define sipType_QStyle_ComplexControl sipExportedTypes_QtWidgets[283]

#define sipType_QStyle_SubElement sipExportedTypes_QtWidgets[293]

#define sipType_QStyle_ControlElement sipExportedTypes_QtWidgets[285]

#define sipType_QStyle_PrimitiveElement sipExportedTypes_QtWidgets[287]

#define sipType_QStyle_StateFlag sipExportedTypes_QtWidgets[290]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyle;

#define sipType_QCommonStyle sipExportedTypes_QtWidgets[41]

extern sipClassTypeDef sipTypeDef_QtWidgets_QCommonStyle;

#define sipType_QCompleter sipExportedTypes_QtWidgets[42]

#define sipType_QCompleter_ModelSorting sipExportedTypes_QtWidgets[44]

#define sipType_QCompleter_CompletionMode sipExportedTypes_QtWidgets[43]

extern sipClassTypeDef sipTypeDef_QtWidgets_QCompleter;

#define sipType_QDataWidgetMapper sipExportedTypes_QtWidgets[45]

#define sipType_QDataWidgetMapper_SubmitPolicy sipExportedTypes_QtWidgets[46]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDataWidgetMapper;

#define sipType_QDateTimeEdit sipExportedTypes_QtWidgets[48]

#define sipType_QDateTimeEdit_Section sipExportedTypes_QtWidgets[49]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDateTimeEdit;

#define sipType_QTimeEdit sipExportedTypes_QtWidgets[428]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTimeEdit;

#define sipType_QDateEdit sipExportedTypes_QtWidgets[47]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDateEdit;

#define sipType_QDial sipExportedTypes_QtWidgets[50]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDial;

#define sipType_QDialogButtonBox sipExportedTypes_QtWidgets[53]

#define sipType_QDialogButtonBox_StandardButton sipExportedTypes_QtWidgets[56]

#define sipType_QDialogButtonBox_ButtonRole sipExportedTypes_QtWidgets[55]

#define sipType_QDialogButtonBox_ButtonLayout sipExportedTypes_QtWidgets[54]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDialogButtonBox;

#define sipType_QDockWidget sipExportedTypes_QtWidgets[57]

#define sipType_QDockWidget_DockWidgetFeature sipExportedTypes_QtWidgets[58]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDockWidget;

#define sipType_QErrorMessage sipExportedTypes_QtWidgets[60]

extern sipClassTypeDef sipTypeDef_QtWidgets_QErrorMessage;

#define sipType_QFileDialog sipExportedTypes_QtWidgets[61]

#define sipType_QFileDialog_Option sipExportedTypes_QtWidgets[65]

#define sipType_QFileDialog_DialogLabel sipExportedTypes_QtWidgets[63]

#define sipType_QFileDialog_AcceptMode sipExportedTypes_QtWidgets[62]

#define sipType_QFileDialog_FileMode sipExportedTypes_QtWidgets[64]

#define sipType_QFileDialog_ViewMode sipExportedTypes_QtWidgets[66]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileDialog;

#define sipType_QFileIconProvider sipExportedTypes_QtWidgets[67]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileIconProvider;

#define sipType_QFocusFrame sipExportedTypes_QtWidgets[105]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFocusFrame;

#define sipType_QFontComboBox sipExportedTypes_QtWidgets[106]

#define sipType_QFontComboBox_FontFilter sipExportedTypes_QtWidgets[107]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFontComboBox;

#define sipType_QFontDialog sipExportedTypes_QtWidgets[108]

#define sipType_QFontDialog_FontDialogOption sipExportedTypes_QtWidgets[109]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFontDialog;

#define sipType_QFormLayout sipExportedTypes_QtWidgets[110]

#define sipType_QFormLayout_ItemRole sipExportedTypes_QtWidgets[112]

#define sipType_QFormLayout_RowWrapPolicy sipExportedTypes_QtWidgets[113]

#define sipType_QFormLayout_FieldGrowthPolicy sipExportedTypes_QtWidgets[111]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFormLayout;

#define sipType_QFormLayout_TakeRowResult sipExportedTypes_QtWidgets[114]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFormLayout_TakeRowResult;

#define sipType_QGesture sipExportedTypes_QtWidgets[119]

#define sipType_QGesture_GestureCancelPolicy sipExportedTypes_QtWidgets[120]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGesture;

#define sipType_QPanGesture sipExportedTypes_QtWidgets[242]

extern sipClassTypeDef sipTypeDef_QtWidgets_QPanGesture;

#define sipType_QPinchGesture sipExportedTypes_QtWidgets[243]

#define sipType_QPinchGesture_ChangeFlag sipExportedTypes_QtWidgets[244]

extern sipClassTypeDef sipTypeDef_QtWidgets_QPinchGesture;

#define sipType_QSwipeGesture sipExportedTypes_QtWidgets[404]

#define sipType_QSwipeGesture_SwipeDirection sipExportedTypes_QtWidgets[405]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSwipeGesture;

#define sipType_QTapGesture sipExportedTypes_QtWidgets[422]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTapGesture;

#define sipType_QTapAndHoldGesture sipExportedTypes_QtWidgets[421]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTapAndHoldGesture;

#define sipType_QGestureEvent sipExportedTypes_QtWidgets[121]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGestureEvent;

#define sipType_QGestureRecognizer sipExportedTypes_QtWidgets[122]

#define sipType_QGestureRecognizer_ResultFlag sipExportedTypes_QtWidgets[123]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGestureRecognizer;

#define sipType_QGraphicsAnchor sipExportedTypes_QtWidgets[124]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsAnchor;

#define sipType_QGraphicsLayoutItem sipExportedTypes_QtWidgets[142]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLayoutItem;

#define sipType_QGraphicsLayout sipExportedTypes_QtWidgets[141]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLayout;

#define sipType_QGraphicsAnchorLayout sipExportedTypes_QtWidgets[125]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsAnchorLayout;

#define sipType_QGraphicsEffect sipExportedTypes_QtWidgets[130]

#define sipType_QGraphicsEffect_PixmapPadMode sipExportedTypes_QtWidgets[132]

#define sipType_QGraphicsEffect_ChangeFlag sipExportedTypes_QtWidgets[131]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsEffect;

#define sipType_QGraphicsColorizeEffect sipExportedTypes_QtWidgets[128]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsColorizeEffect;

#define sipType_QGraphicsBlurEffect sipExportedTypes_QtWidgets[126]

#define sipType_QGraphicsBlurEffect_BlurHint sipExportedTypes_QtWidgets[127]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsBlurEffect;

#define sipType_QGraphicsDropShadowEffect sipExportedTypes_QtWidgets[129]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsDropShadowEffect;

#define sipType_QGraphicsOpacityEffect sipExportedTypes_QtWidgets[146]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsOpacityEffect;

#define sipType_QGraphicsGridLayout sipExportedTypes_QtWidgets[134]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsGridLayout;

#define sipType_QGraphicsItem sipExportedTypes_QtWidgets[135]

#define sipType_QGraphicsItem_PanelModality sipExportedTypes_QtWidgets[139]

#define sipType_QGraphicsItem_GraphicsItemFlag sipExportedTypes_QtWidgets[138]

#define sipType_QGraphicsItem_GraphicsItemChange sipExportedTypes_QtWidgets[137]

#define sipType_QGraphicsItem_CacheMode sipExportedTypes_QtWidgets[136]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsItem;

#define sipType_QAbstractGraphicsShapeItem sipExportedTypes_QtWidgets[1]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractGraphicsShapeItem;

#define sipType_QGraphicsPathItem sipExportedTypes_QtWidgets[147]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsPathItem;

#define sipType_QGraphicsRectItem sipExportedTypes_QtWidgets[152]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsRectItem;

#define sipType_QGraphicsEllipseItem sipExportedTypes_QtWidgets[133]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsEllipseItem;

#define sipType_QGraphicsPolygonItem sipExportedTypes_QtWidgets[150]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsPolygonItem;

#define sipType_QGraphicsLineItem sipExportedTypes_QtWidgets[143]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLineItem;

#define sipType_QGraphicsPixmapItem sipExportedTypes_QtWidgets[148]

#define sipType_QGraphicsPixmapItem_ShapeMode sipExportedTypes_QtWidgets[149]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsPixmapItem;

#define sipType_QGraphicsSimpleTextItem sipExportedTypes_QtWidgets[168]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSimpleTextItem;

#define sipType_QGraphicsItemGroup sipExportedTypes_QtWidgets[140]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsItemGroup;

#define sipType_QGraphicsObject sipExportedTypes_QtWidgets[145]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsObject;

#define sipType_QGraphicsTextItem sipExportedTypes_QtWidgets[169]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsTextItem;

#define sipType_QGraphicsLinearLayout sipExportedTypes_QtWidgets[144]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLinearLayout;

#define sipType_QGraphicsWidget sipExportedTypes_QtWidgets[177]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsWidget;

#define sipType_QGraphicsProxyWidget sipExportedTypes_QtWidgets[151]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsProxyWidget;

#define sipType_QGraphicsScene sipExportedTypes_QtWidgets[155]

#define sipType_QGraphicsScene_SceneLayer sipExportedTypes_QtWidgets[157]

#define sipType_QGraphicsScene_ItemIndexMethod sipExportedTypes_QtWidgets[156]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsScene;

#define sipType_QGraphicsSceneEvent sipExportedTypes_QtWidgets[161]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneEvent;

#define sipType_QGraphicsSceneMouseEvent sipExportedTypes_QtWidgets[164]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneMouseEvent;

#define sipType_QGraphicsSceneWheelEvent sipExportedTypes_QtWidgets[167]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneWheelEvent;

#define sipType_QGraphicsSceneContextMenuEvent sipExportedTypes_QtWidgets[158]

#define sipType_QGraphicsSceneContextMenuEvent_Reason sipExportedTypes_QtWidgets[159]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneContextMenuEvent;

#define sipType_QGraphicsSceneHoverEvent sipExportedTypes_QtWidgets[163]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneHoverEvent;

#define sipType_QGraphicsSceneHelpEvent sipExportedTypes_QtWidgets[162]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneHelpEvent;

#define sipType_QGraphicsSceneDragDropEvent sipExportedTypes_QtWidgets[160]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneDragDropEvent;

#define sipType_QGraphicsSceneResizeEvent sipExportedTypes_QtWidgets[166]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneResizeEvent;

#define sipType_QGraphicsSceneMoveEvent sipExportedTypes_QtWidgets[165]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneMoveEvent;

#define sipType_QGraphicsTransform sipExportedTypes_QtWidgets[170]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsTransform;

#define sipType_QGraphicsScale sipExportedTypes_QtWidgets[154]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsScale;

#define sipType_QGraphicsRotation sipExportedTypes_QtWidgets[153]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsRotation;

#define sipType_QGraphicsView sipExportedTypes_QtWidgets[171]

#define sipType_QGraphicsView_OptimizationFlag sipExportedTypes_QtWidgets[174]

#define sipType_QGraphicsView_ViewportUpdateMode sipExportedTypes_QtWidgets[176]

#define sipType_QGraphicsView_ViewportAnchor sipExportedTypes_QtWidgets[175]

#define sipType_QGraphicsView_DragMode sipExportedTypes_QtWidgets[173]

#define sipType_QGraphicsView_CacheModeFlag sipExportedTypes_QtWidgets[172]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsView;

#define sipType_QGridLayout sipExportedTypes_QtWidgets[178]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGridLayout;

#define sipType_QGroupBox sipExportedTypes_QtWidgets[179]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGroupBox;

#define sipType_QHeaderView sipExportedTypes_QtWidgets[181]

#define sipType_QHeaderView_ResizeMode sipExportedTypes_QtWidgets[182]

extern sipClassTypeDef sipTypeDef_QtWidgets_QHeaderView;

#define sipType_QInputDialog sipExportedTypes_QtWidgets[183]

#define sipType_QInputDialog_InputMode sipExportedTypes_QtWidgets[185]

#define sipType_QInputDialog_InputDialogOption sipExportedTypes_QtWidgets[184]

extern sipClassTypeDef sipTypeDef_QtWidgets_QInputDialog;

#define sipType_QItemDelegate sipExportedTypes_QtWidgets[186]

extern sipClassTypeDef sipTypeDef_QtWidgets_QItemDelegate;

#define sipType_QItemEditorCreatorBase sipExportedTypes_QtWidgets[187]

extern sipClassTypeDef sipTypeDef_QtWidgets_QItemEditorCreatorBase;

#define sipType_QItemEditorFactory sipExportedTypes_QtWidgets[188]

extern sipClassTypeDef sipTypeDef_QtWidgets_QItemEditorFactory;

#define sipType_QKeySequenceEdit sipExportedTypes_QtWidgets[189]

extern sipClassTypeDef sipTypeDef_QtWidgets_QKeySequenceEdit;

#define sipType_QLabel sipExportedTypes_QtWidgets[193]

extern sipClassTypeDef sipTypeDef_QtWidgets_QLabel;

#define sipType_QSpacerItem sipExportedTypes_QtWidgets[273]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSpacerItem;

#define sipType_QWidgetItem sipExportedTypes_QtWidgets[447]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWidgetItem;

#define sipType_QLCDNumber sipExportedTypes_QtWidgets[190]

#define sipType_QLCDNumber_SegmentStyle sipExportedTypes_QtWidgets[192]

#define sipType_QLCDNumber_Mode sipExportedTypes_QtWidgets[191]

extern sipClassTypeDef sipTypeDef_QtWidgets_QLCDNumber;

#define sipType_QLineEdit sipExportedTypes_QtWidgets[197]

#define sipType_QLineEdit_ActionPosition sipExportedTypes_QtWidgets[198]

#define sipType_QLineEdit_EchoMode sipExportedTypes_QtWidgets[199]

extern sipClassTypeDef sipTypeDef_QtWidgets_QLineEdit;

#define sipType_QListView sipExportedTypes_QtWidgets[217]

#define sipType_QListView_ViewMode sipExportedTypes_QtWidgets[222]

#define sipType_QListView_LayoutMode sipExportedTypes_QtWidgets[219]

#define sipType_QListView_ResizeMode sipExportedTypes_QtWidgets[221]

#define sipType_QListView_Flow sipExportedTypes_QtWidgets[218]

#define sipType_QListView_Movement sipExportedTypes_QtWidgets[220]

extern sipClassTypeDef sipTypeDef_QtWidgets_QListView;

#define sipType_QListWidgetItem sipExportedTypes_QtWidgets[224]

#define sipType_QListWidgetItem_ItemType sipExportedTypes_QtWidgets[225]

extern sipClassTypeDef sipTypeDef_QtWidgets_QListWidgetItem;

#define sipType_QListWidget sipExportedTypes_QtWidgets[223]

extern sipClassTypeDef sipTypeDef_QtWidgets_QListWidget;

#define sipType_QMainWindow sipExportedTypes_QtWidgets[226]

#define sipType_QMainWindow_DockOption sipExportedTypes_QtWidgets[227]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMainWindow;

#define sipType_QMdiArea sipExportedTypes_QtWidgets[229]

#define sipType_QMdiArea_WindowOrder sipExportedTypes_QtWidgets[232]

#define sipType_QMdiArea_ViewMode sipExportedTypes_QtWidgets[231]

#define sipType_QMdiArea_AreaOption sipExportedTypes_QtWidgets[230]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMdiArea;

#define sipType_QMdiSubWindow sipExportedTypes_QtWidgets[233]

#define sipType_QMdiSubWindow_SubWindowOption sipExportedTypes_QtWidgets[234]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMdiSubWindow;

#define sipType_QMenu sipExportedTypes_QtWidgets[235]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMenu;

#define sipType_QMenuBar sipExportedTypes_QtWidgets[236]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMenuBar;

#define sipType_QMessageBox sipExportedTypes_QtWidgets[237]

#define sipType_QMessageBox_Option sipExportedTypes_QtWidgets[240]

#define sipType_QMessageBox_StandardButton sipExportedTypes_QtWidgets[241]

#define sipType_QMessageBox_Icon sipExportedTypes_QtWidgets[239]

#define sipType_QMessageBox_ButtonRole sipExportedTypes_QtWidgets[238]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMessageBox;

#define sipType_QPlainTextEdit sipExportedTypes_QtWidgets[246]

#define sipType_QPlainTextEdit_LineWrapMode sipExportedTypes_QtWidgets[247]

extern sipClassTypeDef sipTypeDef_QtWidgets_QPlainTextEdit;

#define sipType_QPlainTextDocumentLayout sipExportedTypes_QtWidgets[245]

extern sipClassTypeDef sipTypeDef_QtWidgets_QPlainTextDocumentLayout;

#define sipType_QProgressBar sipExportedTypes_QtWidgets[248]

#define sipType_QProgressBar_Direction sipExportedTypes_QtWidgets[249]

extern sipClassTypeDef sipTypeDef_QtWidgets_QProgressBar;

#define sipType_QProgressDialog sipExportedTypes_QtWidgets[250]

extern sipClassTypeDef sipTypeDef_QtWidgets_QProgressDialog;

#define sipType_QProxyStyle sipExportedTypes_QtWidgets[251]

extern sipClassTypeDef sipTypeDef_QtWidgets_QProxyStyle;

#define sipType_QRadioButton sipExportedTypes_QtWidgets[253]

extern sipClassTypeDef sipTypeDef_QtWidgets_QRadioButton;

#define sipType_QRubberBand sipExportedTypes_QtWidgets[254]

#define sipType_QRubberBand_Shape sipExportedTypes_QtWidgets[255]

extern sipClassTypeDef sipTypeDef_QtWidgets_QRubberBand;

#define sipType_QScrollArea sipExportedTypes_QtWidgets[256]

extern sipClassTypeDef sipTypeDef_QtWidgets_QScrollArea;

#define sipType_QScrollBar sipExportedTypes_QtWidgets[257]

extern sipClassTypeDef sipTypeDef_QtWidgets_QScrollBar;

#define sipType_QScroller sipExportedTypes_QtWidgets[258]

#define sipType_QScroller_Input sipExportedTypes_QtWidgets[259]

#define sipType_QScroller_ScrollerGestureType sipExportedTypes_QtWidgets[260]

#define sipType_QScroller_State sipExportedTypes_QtWidgets[261]

extern sipClassTypeDef sipTypeDef_QtWidgets_QScroller;

#define sipType_QScrollerProperties sipExportedTypes_QtWidgets[262]

#define sipType_QScrollerProperties_ScrollMetric sipExportedTypes_QtWidgets[265]

#define sipType_QScrollerProperties_FrameRates sipExportedTypes_QtWidgets[263]

#define sipType_QScrollerProperties_OvershootPolicy sipExportedTypes_QtWidgets[264]

extern sipClassTypeDef sipTypeDef_QtWidgets_QScrollerProperties;

#define sipType_QSizeGrip sipExportedTypes_QtWidgets[266]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSizeGrip;

#define sipType_QSizePolicy sipExportedTypes_QtWidgets[267]

#define sipType_QSizePolicy_ControlType sipExportedTypes_QtWidgets[268]

#define sipType_QSizePolicy_Policy sipExportedTypes_QtWidgets[269]

#define sipType_QSizePolicy_PolicyFlag sipExportedTypes_QtWidgets[270]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSizePolicy;

#define sipType_QSlider sipExportedTypes_QtWidgets[271]

#define sipType_QSlider_TickPosition sipExportedTypes_QtWidgets[272]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSlider;

#define sipType_QSpinBox sipExportedTypes_QtWidgets[274]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSpinBox;

#define sipType_QDoubleSpinBox sipExportedTypes_QtWidgets[59]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDoubleSpinBox;

#define sipType_QSplashScreen sipExportedTypes_QtWidgets[275]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSplashScreen;

#define sipType_QSplitter sipExportedTypes_QtWidgets[276]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSplitter;

#define sipType_QSplitterHandle sipExportedTypes_QtWidgets[277]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSplitterHandle;

#define sipType_QStackedLayout sipExportedTypes_QtWidgets[278]

#define sipType_QStackedLayout_StackingMode sipExportedTypes_QtWidgets[279]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStackedLayout;

#define sipType_QStackedWidget sipExportedTypes_QtWidgets[280]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStackedWidget;

#define sipType_QStatusBar sipExportedTypes_QtWidgets[281]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStatusBar;

#define sipType_QStyledItemDelegate sipExportedTypes_QtWidgets[403]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyledItemDelegate;

#define sipType_QStyleFactory sipExportedTypes_QtWidgets[294]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleFactory;

#define sipType_QStyleOption sipExportedTypes_QtWidgets[305]

#define sipType_QStyleOption_StyleOptionVersion sipExportedTypes_QtWidgets[308]

#define sipType_QStyleOption_StyleOptionType sipExportedTypes_QtWidgets[307]

#define sipType_QStyleOption_OptionType sipExportedTypes_QtWidgets[306]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOption;

#define sipType_QStyleOptionFocusRect sipExportedTypes_QtWidgets[322]

#define sipType_QStyleOptionFocusRect_StyleOptionVersion sipExportedTypes_QtWidgets[324]

#define sipType_QStyleOptionFocusRect_StyleOptionType sipExportedTypes_QtWidgets[323]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionFocusRect;

#define sipType_QStyleOptionFrame sipExportedTypes_QtWidgets[325]

#define sipType_QStyleOptionFrame_FrameFeature sipExportedTypes_QtWidgets[326]

#define sipType_QStyleOptionFrame_StyleOptionVersion sipExportedTypes_QtWidgets[328]

#define sipType_QStyleOptionFrame_StyleOptionType sipExportedTypes_QtWidgets[327]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionFrame;

#define sipType_QStyleOptionTabWidgetFrame sipExportedTypes_QtWidgets[376]

#define sipType_QStyleOptionTabWidgetFrame_StyleOptionVersion sipExportedTypes_QtWidgets[378]

#define sipType_QStyleOptionTabWidgetFrame_StyleOptionType sipExportedTypes_QtWidgets[377]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTabWidgetFrame;

#define sipType_QStyleOptionTabBarBase sipExportedTypes_QtWidgets[373]

#define sipType_QStyleOptionTabBarBase_StyleOptionVersion sipExportedTypes_QtWidgets[375]

#define sipType_QStyleOptionTabBarBase_StyleOptionType sipExportedTypes_QtWidgets[374]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTabBarBase;

#define sipType_QStyleOptionHeader sipExportedTypes_QtWidgets[335]

#define sipType_QStyleOptionHeader_SortIndicator sipExportedTypes_QtWidgets[338]

#define sipType_QStyleOptionHeader_SelectedPosition sipExportedTypes_QtWidgets[337]

#define sipType_QStyleOptionHeader_SectionPosition sipExportedTypes_QtWidgets[336]

#define sipType_QStyleOptionHeader_StyleOptionVersion sipExportedTypes_QtWidgets[340]

#define sipType_QStyleOptionHeader_StyleOptionType sipExportedTypes_QtWidgets[339]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionHeader;

#define sipType_QStyleOptionHeaderV2 sipExportedTypes_QtWidgets[341]

#define sipType_QStyleOptionHeaderV2_StyleOptionVersion sipExportedTypes_QtWidgets[343]

#define sipType_QStyleOptionHeaderV2_StyleOptionType sipExportedTypes_QtWidgets[342]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionHeaderV2;

#define sipType_QStyleOptionButton sipExportedTypes_QtWidgets[309]

#define sipType_QStyleOptionButton_ButtonFeature sipExportedTypes_QtWidgets[310]

#define sipType_QStyleOptionButton_StyleOptionVersion sipExportedTypes_QtWidgets[312]

#define sipType_QStyleOptionButton_StyleOptionType sipExportedTypes_QtWidgets[311]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionButton;

#define sipType_QStyleOptionTab sipExportedTypes_QtWidgets[366]

#define sipType_QStyleOptionTab_TabFeature sipExportedTypes_QtWidgets[371]

#define sipType_QStyleOptionTab_CornerWidget sipExportedTypes_QtWidgets[367]

#define sipType_QStyleOptionTab_SelectedPosition sipExportedTypes_QtWidgets[368]

#define sipType_QStyleOptionTab_TabPosition sipExportedTypes_QtWidgets[372]

#define sipType_QStyleOptionTab_StyleOptionVersion sipExportedTypes_QtWidgets[370]

#define sipType_QStyleOptionTab_StyleOptionType sipExportedTypes_QtWidgets[369]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTab;

#define sipType_QStyleOptionProgressBar sipExportedTypes_QtWidgets[351]

#define sipType_QStyleOptionProgressBar_StyleOptionVersion sipExportedTypes_QtWidgets[353]

#define sipType_QStyleOptionProgressBar_StyleOptionType sipExportedTypes_QtWidgets[352]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionProgressBar;

#define sipType_QStyleOptionMenuItem sipExportedTypes_QtWidgets[344]

#define sipType_QStyleOptionMenuItem_CheckType sipExportedTypes_QtWidgets[345]

#define sipType_QStyleOptionMenuItem_MenuItemType sipExportedTypes_QtWidgets[346]

#define sipType_QStyleOptionMenuItem_StyleOptionVersion sipExportedTypes_QtWidgets[348]

#define sipType_QStyleOptionMenuItem_StyleOptionType sipExportedTypes_QtWidgets[347]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionMenuItem;

#define sipType_QStyleOptionMenuItemV2 sipExportedTypes_QtWidgets[349]

#define sipType_QStyleOptionMenuItemV2_StyleOptionVersion sipExportedTypes_QtWidgets[350]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionMenuItemV2;

#define sipType_QStyleOptionDockWidget sipExportedTypes_QtWidgets[319]

#define sipType_QStyleOptionDockWidget_StyleOptionVersion sipExportedTypes_QtWidgets[321]

#define sipType_QStyleOptionDockWidget_StyleOptionType sipExportedTypes_QtWidgets[320]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionDockWidget;

#define sipType_QStyleOptionViewItem sipExportedTypes_QtWidgets[396]

#define sipType_QStyleOptionViewItem_ViewItemPosition sipExportedTypes_QtWidgets[401]

#define sipType_QStyleOptionViewItem_ViewItemFeature sipExportedTypes_QtWidgets[400]

#define sipType_QStyleOptionViewItem_Position sipExportedTypes_QtWidgets[397]

#define sipType_QStyleOptionViewItem_StyleOptionVersion sipExportedTypes_QtWidgets[399]

#define sipType_QStyleOptionViewItem_StyleOptionType sipExportedTypes_QtWidgets[398]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionViewItem;

#define sipType_QStyleOptionToolBox sipExportedTypes_QtWidgets[387]

#define sipType_QStyleOptionToolBox_SelectedPosition sipExportedTypes_QtWidgets[388]

#define sipType_QStyleOptionToolBox_TabPosition sipExportedTypes_QtWidgets[391]

#define sipType_QStyleOptionToolBox_StyleOptionVersion sipExportedTypes_QtWidgets[390]

#define sipType_QStyleOptionToolBox_StyleOptionType sipExportedTypes_QtWidgets[389]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolBox;

#define sipType_QStyleOptionRubberBand sipExportedTypes_QtWidgets[354]

#define sipType_QStyleOptionRubberBand_StyleOptionVersion sipExportedTypes_QtWidgets[356]

#define sipType_QStyleOptionRubberBand_StyleOptionType sipExportedTypes_QtWidgets[355]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionRubberBand;

#define sipType_QStyleOptionComplex sipExportedTypes_QtWidgets[316]

#define sipType_QStyleOptionComplex_StyleOptionVersion sipExportedTypes_QtWidgets[318]

#define sipType_QStyleOptionComplex_StyleOptionType sipExportedTypes_QtWidgets[317]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionComplex;

#define sipType_QStyleOptionSlider sipExportedTypes_QtWidgets[360]

#define sipType_QStyleOptionSlider_StyleOptionVersion sipExportedTypes_QtWidgets[362]

#define sipType_QStyleOptionSlider_StyleOptionType sipExportedTypes_QtWidgets[361]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionSlider;

#define sipType_QStyleOptionSpinBox sipExportedTypes_QtWidgets[363]

#define sipType_QStyleOptionSpinBox_StyleOptionVersion sipExportedTypes_QtWidgets[365]

#define sipType_QStyleOptionSpinBox_StyleOptionType sipExportedTypes_QtWidgets[364]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionSpinBox;

#define sipType_QStyleOptionToolButton sipExportedTypes_QtWidgets[392]

#define sipType_QStyleOptionToolButton_ToolButtonFeature sipExportedTypes_QtWidgets[395]

#define sipType_QStyleOptionToolButton_StyleOptionVersion sipExportedTypes_QtWidgets[394]

#define sipType_QStyleOptionToolButton_StyleOptionType sipExportedTypes_QtWidgets[393]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolButton;

#define sipType_QStyleOptionComboBox sipExportedTypes_QtWidgets[313]

#define sipType_QStyleOptionComboBox_StyleOptionVersion sipExportedTypes_QtWidgets[315]

#define sipType_QStyleOptionComboBox_StyleOptionType sipExportedTypes_QtWidgets[314]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionComboBox;

#define sipType_QStyleOptionTitleBar sipExportedTypes_QtWidgets[379]

#define sipType_QStyleOptionTitleBar_StyleOptionVersion sipExportedTypes_QtWidgets[381]

#define sipType_QStyleOptionTitleBar_StyleOptionType sipExportedTypes_QtWidgets[380]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTitleBar;

#define sipType_QStyleHintReturn sipExportedTypes_QtWidgets[295]

#define sipType_QStyleHintReturn_StyleOptionVersion sipExportedTypes_QtWidgets[298]

#define sipType_QStyleHintReturn_StyleOptionType sipExportedTypes_QtWidgets[297]

#define sipType_QStyleHintReturn_HintReturnType sipExportedTypes_QtWidgets[296]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleHintReturn;

#define sipType_QStyleHintReturnMask sipExportedTypes_QtWidgets[299]

#define sipType_QStyleHintReturnMask_StyleOptionVersion sipExportedTypes_QtWidgets[301]

#define sipType_QStyleHintReturnMask_StyleOptionType sipExportedTypes_QtWidgets[300]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleHintReturnMask;

#define sipType_QStyleOptionToolBar sipExportedTypes_QtWidgets[382]

#define sipType_QStyleOptionToolBar_ToolBarFeature sipExportedTypes_QtWidgets[385]

#define sipType_QStyleOptionToolBar_ToolBarPosition sipExportedTypes_QtWidgets[386]

#define sipType_QStyleOptionToolBar_StyleOptionVersion sipExportedTypes_QtWidgets[384]

#define sipType_QStyleOptionToolBar_StyleOptionType sipExportedTypes_QtWidgets[383]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolBar;

#define sipType_QStyleOptionGroupBox sipExportedTypes_QtWidgets[332]

#define sipType_QStyleOptionGroupBox_StyleOptionVersion sipExportedTypes_QtWidgets[334]

#define sipType_QStyleOptionGroupBox_StyleOptionType sipExportedTypes_QtWidgets[333]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionGroupBox;

#define sipType_QStyleOptionSizeGrip sipExportedTypes_QtWidgets[357]

#define sipType_QStyleOptionSizeGrip_StyleOptionVersion sipExportedTypes_QtWidgets[359]

#define sipType_QStyleOptionSizeGrip_StyleOptionType sipExportedTypes_QtWidgets[358]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionSizeGrip;

#define sipType_QStyleOptionGraphicsItem sipExportedTypes_QtWidgets[329]

#define sipType_QStyleOptionGraphicsItem_StyleOptionVersion sipExportedTypes_QtWidgets[331]

#define sipType_QStyleOptionGraphicsItem_StyleOptionType sipExportedTypes_QtWidgets[330]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionGraphicsItem;

#define sipType_QStyleHintReturnVariant sipExportedTypes_QtWidgets[302]

#define sipType_QStyleHintReturnVariant_StyleOptionVersion sipExportedTypes_QtWidgets[304]

#define sipType_QStyleHintReturnVariant_StyleOptionType sipExportedTypes_QtWidgets[303]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleHintReturnVariant;

#define sipType_QStylePainter sipExportedTypes_QtWidgets[402]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStylePainter;

#define sipType_QSystemTrayIcon sipExportedTypes_QtWidgets[406]

#define sipType_QSystemTrayIcon_MessageIcon sipExportedTypes_QtWidgets[408]

#define sipType_QSystemTrayIcon_ActivationReason sipExportedTypes_QtWidgets[407]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSystemTrayIcon;

#define sipType_QTabBar sipExportedTypes_QtWidgets[409]

#define sipType_QTabBar_SelectionBehavior sipExportedTypes_QtWidgets[411]

#define sipType_QTabBar_ButtonPosition sipExportedTypes_QtWidgets[410]

#define sipType_QTabBar_Shape sipExportedTypes_QtWidgets[412]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTabBar;

#define sipType_QTableView sipExportedTypes_QtWidgets[416]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableView;

#define sipType_QTableWidgetSelectionRange sipExportedTypes_QtWidgets[420]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableWidgetSelectionRange;

#define sipType_QTableWidgetItem sipExportedTypes_QtWidgets[418]

#define sipType_QTableWidgetItem_ItemType sipExportedTypes_QtWidgets[419]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableWidgetItem;

#define sipType_QTableWidget sipExportedTypes_QtWidgets[417]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableWidget;

#define sipType_QTabWidget sipExportedTypes_QtWidgets[413]

#define sipType_QTabWidget_TabShape sipExportedTypes_QtWidgets[415]

#define sipType_QTabWidget_TabPosition sipExportedTypes_QtWidgets[414]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTabWidget;

#define sipType_QTextEdit sipExportedTypes_QtWidgets[424]

#define sipType_QTextEdit_AutoFormattingFlag sipExportedTypes_QtWidgets[425]

#define sipType_QTextEdit_LineWrapMode sipExportedTypes_QtWidgets[427]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTextEdit;

#define sipType_QTextBrowser sipExportedTypes_QtWidgets[423]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTextBrowser;

#define sipType_QTextEdit_ExtraSelection sipExportedTypes_QtWidgets[426]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTextEdit_ExtraSelection;

#define sipType_QToolBar sipExportedTypes_QtWidgets[429]

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolBar;

#define sipType_QToolBox sipExportedTypes_QtWidgets[430]

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolBox;

#define sipType_QToolButton sipExportedTypes_QtWidgets[431]

#define sipType_QToolButton_ToolButtonPopupMode sipExportedTypes_QtWidgets[432]

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolButton;

#define sipType_QToolTip sipExportedTypes_QtWidgets[433]

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolTip;

#define sipType_QTreeView sipExportedTypes_QtWidgets[434]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeView;

#define sipType_QTreeWidgetItem sipExportedTypes_QtWidgets[436]

#define sipType_QTreeWidgetItem_ChildIndicatorPolicy sipExportedTypes_QtWidgets[437]

#define sipType_QTreeWidgetItem_ItemType sipExportedTypes_QtWidgets[438]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidgetItem;

#define sipType_QTreeWidget sipExportedTypes_QtWidgets[435]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidget;

#define sipType_QTreeWidgetItemIterator sipExportedTypes_QtWidgets[439]

#define sipType_QTreeWidgetItemIterator_IteratorFlag sipExportedTypes_QtWidgets[440]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidgetItemIterator;

#define sipType_QUndoView sipExportedTypes_QtWidgets[441]

extern sipClassTypeDef sipTypeDef_QtWidgets_QUndoView;

#define sipType_QWhatsThis sipExportedTypes_QtWidgets[443]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWhatsThis;

#define sipType_QWidgetAction sipExportedTypes_QtWidgets[446]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWidgetAction;

#define sipType_QWizard sipExportedTypes_QtWidgets[448]

#define sipType_QWizard_WizardOption sipExportedTypes_QtWidgets[450]

#define sipType_QWizard_WizardStyle sipExportedTypes_QtWidgets[452]

#define sipType_QWizard_WizardPixmap sipExportedTypes_QtWidgets[451]

#define sipType_QWizard_WizardButton sipExportedTypes_QtWidgets[449]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWizard;

#define sipType_QWizardPage sipExportedTypes_QtWidgets[453]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWizardPage;

#define sipType_QList_0101QTreeWidgetItem sipExportedTypes_QtWidgets[214]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QTreeWidgetItem;

#define sipType_QList_0101QTableWidgetItem sipExportedTypes_QtWidgets[211]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QTableWidgetItem;

#define sipType_QList_0100QTableWidgetSelectionRange sipExportedTypes_QtWidgets[212]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QTableWidgetSelectionRange;

#define sipType_QList_0101QScroller sipExportedTypes_QtWidgets[210]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QScroller;

#define sipType_QList_0100QTextEdit_ExtraSelection sipExportedTypes_QtWidgets[213]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QTextEdit_ExtraSelection;

#define sipType_QList_0101QMdiSubWindow sipExportedTypes_QtWidgets[208]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QMdiSubWindow;

#define sipType_QList_0101QDockWidget sipExportedTypes_QtWidgets[201]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QDockWidget;

#define sipType_QList_0101QListWidgetItem sipExportedTypes_QtWidgets[207]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QListWidgetItem;

#define sipType_QList_0100QKeyCombination sipExportedTypes_QtWidgets[206]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QKeyCombination;

#define sipType_QList_0100QRectF sipExportedTypes_QtWidgets[209]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QRectF;

#define sipType_QList_0101QGraphicsView sipExportedTypes_QtWidgets[205]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGraphicsView;

#define sipType_QList_0101QGraphicsTransform sipExportedTypes_QtWidgets[204]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGraphicsTransform;

#define sipType_QList_0101QGraphicsItem sipExportedTypes_QtWidgets[203]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGraphicsItem;

#define sipType_QList_0101QGesture sipExportedTypes_QtWidgets[202]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGesture;

#define sipType_QMap_0100QDate_0100QTextCharFormat sipExportedTypes_QtWidgets[228]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QMap_0100QDate_0100QTextCharFormat;

#define sipType_QList_0101QAbstractButton sipExportedTypes_QtWidgets[200]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QAbstractButton;

#define sipType_QFlags_0100QWizard_WizardOption sipExportedTypes_QtWidgets[104]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QWizard_WizardOption;

#define sipType_QList_0101QWidget sipExportedTypes_QtWidgets[215]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QWidget;

#define sipType_QFlags_0100QWidget_RenderFlag sipExportedTypes_QtWidgets[103]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QWidget_RenderFlag;

#define sipType_QFlags_0100QTreeWidgetItemIterator_IteratorFlag sipExportedTypes_QtWidgets[102]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QTreeWidgetItemIterator_IteratorFlag;

#define sipType_QFlags_0100QTextEdit_AutoFormattingFlag sipExportedTypes_QtWidgets[101]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QTextEdit_AutoFormattingFlag;

#define sipType_QFlags_0100QStyleOptionViewItem_ViewItemFeature sipExportedTypes_QtWidgets[100]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QStyleOptionViewItem_ViewItemFeature;

#define sipType_QFlags_0100QStyleOptionToolButton_ToolButtonFeature sipExportedTypes_QtWidgets[99]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QStyleOptionToolButton_ToolButtonFeature;

#define sipType_QFlags_0100QStyleOptionToolBar_ToolBarFeature sipExportedTypes_QtWidgets[98]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QStyleOptionToolBar_ToolBarFeature;

#define sipType_QFlags_0100QStyleOptionTab_TabFeature sipExportedTypes_QtWidgets[97]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QStyleOptionTab_TabFeature;

#define sipType_QFlags_0100QStyleOptionTab_CornerWidget sipExportedTypes_QtWidgets[96]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QStyleOptionTab_CornerWidget;

#define sipType_QFlags_0100QStyleOptionFrame_FrameFeature sipExportedTypes_QtWidgets[95]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QStyleOptionFrame_FrameFeature;

#define sipType_QFlags_0100QStyleOptionButton_ButtonFeature sipExportedTypes_QtWidgets[94]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QStyleOptionButton_ButtonFeature;

#define sipType_QFlags_0100QStyle_SubControl sipExportedTypes_QtWidgets[93]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QStyle_SubControl;

#define sipType_QFlags_0100QStyle_StateFlag sipExportedTypes_QtWidgets[92]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QStyle_StateFlag;

#define sipType_QFlags_0100QSizePolicy_ControlType sipExportedTypes_QtWidgets[91]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QSizePolicy_ControlType;

#define sipType_QFlags_0100QPinchGesture_ChangeFlag sipExportedTypes_QtWidgets[90]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QPinchGesture_ChangeFlag;

#define sipType_QFlags_0100QMessageBox_StandardButton sipExportedTypes_QtWidgets[89]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QMessageBox_StandardButton;

#define sipType_QFlags_0100QMessageBox_Option sipExportedTypes_QtWidgets[88]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QMessageBox_Option;

#define sipType_QFlags_0100QMdiSubWindow_SubWindowOption sipExportedTypes_QtWidgets[87]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QMdiSubWindow_SubWindowOption;

#define sipType_QFlags_0100QMdiArea_AreaOption sipExportedTypes_QtWidgets[86]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QMdiArea_AreaOption;

#define sipType_QFlags_0100QMainWindow_DockOption sipExportedTypes_QtWidgets[85]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QMainWindow_DockOption;

#define sipType_QFlags_0100QInputDialog_InputDialogOption sipExportedTypes_QtWidgets[84]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QInputDialog_InputDialogOption;

#define sipType_QFlags_0100QGraphicsView_OptimizationFlag sipExportedTypes_QtWidgets[83]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QGraphicsView_OptimizationFlag;

#define sipType_QFlags_0100QGraphicsView_CacheModeFlag sipExportedTypes_QtWidgets[82]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QGraphicsView_CacheModeFlag;

#define sipType_QFlags_0100QGraphicsScene_SceneLayer sipExportedTypes_QtWidgets[81]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QGraphicsScene_SceneLayer;

#define sipType_QFlags_0100QGraphicsItem_GraphicsItemFlag sipExportedTypes_QtWidgets[80]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QGraphicsItem_GraphicsItemFlag;

#define sipType_QFlags_0100QGraphicsEffect_ChangeFlag sipExportedTypes_QtWidgets[79]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QGraphicsEffect_ChangeFlag;

#define sipType_QFlags_0100QGraphicsBlurEffect_BlurHint sipExportedTypes_QtWidgets[78]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QGraphicsBlurEffect_BlurHint;

#define sipType_QFlags_0100QGestureRecognizer_ResultFlag sipExportedTypes_QtWidgets[77]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QGestureRecognizer_ResultFlag;

#define sipType_QFlags_0100QFontDialog_FontDialogOption sipExportedTypes_QtWidgets[76]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QFontDialog_FontDialogOption;

#define sipType_QFlags_0100QFontComboBox_FontFilter sipExportedTypes_QtWidgets[75]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QFontComboBox_FontFilter;

#define sipType_QFlags_0100QFileDialog_Option sipExportedTypes_QtWidgets[74]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QFileDialog_Option;

#define sipType_QFlags_0100QDockWidget_DockWidgetFeature sipExportedTypes_QtWidgets[73]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QDockWidget_DockWidgetFeature;

#define sipType_QFlags_0100QDialogButtonBox_StandardButton sipExportedTypes_QtWidgets[72]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QDialogButtonBox_StandardButton;

#define sipType_QFlags_0100QDateTimeEdit_Section sipExportedTypes_QtWidgets[71]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QDateTimeEdit_Section;

#define sipType_QFlags_0100QColorDialog_ColorDialogOption sipExportedTypes_QtWidgets[70]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QColorDialog_ColorDialogOption;

#define sipType_QFlags_0100QAbstractSpinBox_StepEnabledFlag sipExportedTypes_QtWidgets[69]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QAbstractSpinBox_StepEnabledFlag;

#define sipType_QFlags_0100QAbstractItemView_EditTrigger sipExportedTypes_QtWidgets[68]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QFlags_0100QAbstractItemView_EditTrigger;

#define sipType_QList_0100QWizard_WizardButton sipExportedTypes_QtWidgets[216]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QWizard_WizardButton;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtWidgets;
extern sipExportedModuleDef sipModuleAPI_QtWidgets;
extern sipTypeDef *sipExportedTypes_QtWidgets[];

#define sipType_Qt_ItemSelectionOperation sipImportedTypes_QtWidgets_QtCore[81].it_td

#define sipType_Qt_MouseEventSource sipImportedTypes_QtWidgets_QtCore[84].it_td

#define sipType_Qt_ScrollPhase sipImportedTypes_QtWidgets_QtCore[88].it_td

#define sipType_Qt_HitTestAccuracy sipImportedTypes_QtWidgets_QtCore[78].it_td

#define sipType_Qt_CursorMoveStyle sipImportedTypes_QtWidgets_QtCore[69].it_td

#define sipType_Qt_GestureType sipImportedTypes_QtWidgets_QtCore[77].it_td

#define sipType_Qt_GestureState sipImportedTypes_QtWidgets_QtCore[76].it_td

#define sipType_Qt_CoordinateSystem sipImportedTypes_QtWidgets_QtCore[67].it_td

#define sipType_Qt_AnchorPoint sipImportedTypes_QtWidgets_QtCore[59].it_td

#define sipType_Qt_WindowFrameSection sipImportedTypes_QtWidgets_QtCore[100].it_td

#define sipType_Qt_SizeHint sipImportedTypes_QtWidgets_QtCore[90].it_td

#define sipType_Qt_Axis sipImportedTypes_QtWidgets_QtCore[62].it_td

#define sipType_Qt_ItemSelectionMode sipImportedTypes_QtWidgets_QtCore[80].it_td

#define sipType_Qt_WindowModality sipImportedTypes_QtWidgets_QtCore[101].it_td

#define sipType_Qt_CheckState sipImportedTypes_QtWidgets_QtCore[64].it_td

#define sipType_Qt_DropAction sipImportedTypes_QtWidgets_QtCore[72].it_td

#define sipType_Qt_LayoutDirection sipImportedTypes_QtWidgets_QtCore[82].it_td

#define sipType_Qt_ToolButtonStyle sipImportedTypes_QtWidgets_QtCore[96].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtWidgets_QtCore[79].it_td

#define sipType_Qt_ContextMenuPolicy sipImportedTypes_QtWidgets_QtCore[66].it_td

#define sipType_Qt_FocusReason sipImportedTypes_QtWidgets_QtCore[75].it_td

#define sipType_Qt_TransformationMode sipImportedTypes_QtWidgets_QtCore[97].it_td

#define sipType_Qt_FillRule sipImportedTypes_QtWidgets_QtCore[73].it_td

#define sipType_Qt_ShortcutContext sipImportedTypes_QtWidgets_QtCore[89].it_td

#define sipType_Qt_ConnectionType sipImportedTypes_QtWidgets_QtCore[65].it_td

#define sipType_Qt_Corner sipImportedTypes_QtWidgets_QtCore[68].it_td

#define sipType_Qt_CaseSensitivity sipImportedTypes_QtWidgets_QtCore[63].it_td

#define sipType_Qt_ScrollBarPolicy sipImportedTypes_QtWidgets_QtCore[87].it_td

#define sipType_Qt_DayOfWeek sipImportedTypes_QtWidgets_QtCore[70].it_td

#define sipType_Qt_TimeSpec sipImportedTypes_QtWidgets_QtCore[94].it_td

#define sipType_Qt_ToolBarArea sipImportedTypes_QtWidgets_QtCore[95].it_td

#define sipType_Qt_DockWidgetArea sipImportedTypes_QtWidgets_QtCore[71].it_td

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtWidgets_QtCore[61].it_td

#define sipType_Qt_TextFormat sipImportedTypes_QtWidgets_QtCore[93].it_td

#define sipType_Qt_UIEffect sipImportedTypes_QtWidgets_QtCore[98].it_td

#define sipType_Qt_PenStyle sipImportedTypes_QtWidgets_QtCore[86].it_td

#define sipType_Qt_ArrowType sipImportedTypes_QtWidgets_QtCore[60].it_td

#define sipType_Qt_WidgetAttribute sipImportedTypes_QtWidgets_QtCore[99].it_td

#define sipType_Qt_WindowType sipImportedTypes_QtWidgets_QtCore[102].it_td

#define sipType_Qt_TextElideMode sipImportedTypes_QtWidgets_QtCore[92].it_td

#define sipType_Qt_SortOrder sipImportedTypes_QtWidgets_QtCore[91].it_td

#define sipType_Qt_FocusPolicy sipImportedTypes_QtWidgets_QtCore[74].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtWidgets_QtCore[85].it_td

#define sipType_Qt_MouseButton sipImportedTypes_QtWidgets_QtCore[83].it_td

#define sipType_QKeyCombination sipImportedTypes_QtWidgets_QtCore[32].it_td

#define sipType_QObject sipImportedTypes_QtWidgets_QtCore[44].it_td

#define sipType_QModelIndex sipImportedTypes_QtWidgets_QtCore[43].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtWidgets_QtCore[0].it_td

#define sipType_QAbstractProxyModel sipImportedTypes_QtWidgets_QtCore[1].it_td

#define sipType_QByteArray sipImportedTypes_QtWidgets_QtCore[2].it_td

#define sipType_QCalendar sipImportedTypes_QtWidgets_QtCore[3].it_td

#define sipType_QCoreApplication sipImportedTypes_QtWidgets_QtCore[5].it_td

#define sipType_QEvent sipImportedTypes_QtWidgets_QtCore[10].it_td

#define sipType_QTimerEvent sipImportedTypes_QtWidgets_QtCore[56].it_td

#define sipType_QChildEvent sipImportedTypes_QtWidgets_QtCore[4].it_td

#define sipType_QDataStream sipImportedTypes_QtWidgets_QtCore[6].it_td

#define sipType_QDate sipImportedTypes_QtWidgets_QtCore[7].it_td

#define sipType_QTime sipImportedTypes_QtWidgets_QtCore[54].it_td

#define sipType_QDateTime sipImportedTypes_QtWidgets_QtCore[8].it_td

#define sipType_QDir sipImportedTypes_QtWidgets_QtCore[9].it_td

#define sipType_QFileInfo sipImportedTypes_QtWidgets_QtCore[11].it_td

#define sipType_QItemSelectionModel sipImportedTypes_QtWidgets_QtCore[31].it_td

#define sipType_QItemSelection sipImportedTypes_QtWidgets_QtCore[30].it_td

#define sipType_QLineF sipImportedTypes_QtWidgets_QtCore[33].it_td

#define sipType_QLocale sipImportedTypes_QtWidgets_QtCore[38].it_td

#define sipType_QMargins sipImportedTypes_QtWidgets_QtCore[39].it_td

#define sipType_QMarginsF sipImportedTypes_QtWidgets_QtCore[40].it_td

#define sipType_QMetaMethod sipImportedTypes_QtWidgets_QtCore[41].it_td

#define sipType_QMimeData sipImportedTypes_QtWidgets_QtCore[42].it_td

#define sipType_QPoint sipImportedTypes_QtWidgets_QtCore[45].it_td

#define sipType_QPointF sipImportedTypes_QtWidgets_QtCore[46].it_td

#define sipType_QRect sipImportedTypes_QtWidgets_QtCore[47].it_td

#define sipType_QRectF sipImportedTypes_QtWidgets_QtCore[48].it_td

#define sipType_QRegularExpression sipImportedTypes_QtWidgets_QtCore[49].it_td

#define sipType_QSize sipImportedTypes_QtWidgets_QtCore[50].it_td

#define sipType_QSizeF sipImportedTypes_QtWidgets_QtCore[51].it_td

#define sipType_QTimeZone sipImportedTypes_QtWidgets_QtCore[55].it_td

#define sipType_QUrl sipImportedTypes_QtWidgets_QtCore[57].it_td

#define sipType_QVariant sipImportedTypes_QtWidgets_QtCore[58].it_td

#define sipType_QList_0100QUrl sipImportedTypes_QtWidgets_QtCore[35].it_td

#define sipType_QFlags_0100Qt_WindowState sipImportedTypes_QtWidgets_QtCore[28].it_td

#define sipType_QFlags_0100Qt_WindowType sipImportedTypes_QtWidgets_QtCore[29].it_td

#define sipType_QFlags_0100Qt_ToolBarArea sipImportedTypes_QtWidgets_QtCore[27].it_td

#define sipType_QFlags_0100Qt_TextInteractionFlag sipImportedTypes_QtWidgets_QtCore[26].it_td

#define sipType_QFlags_0100Qt_Orientation sipImportedTypes_QtWidgets_QtCore[25].it_td

#define sipType_QFlags_0100Qt_MouseEventFlag sipImportedTypes_QtWidgets_QtCore[24].it_td

#define sipType_QFlags_0100Qt_MouseButton sipImportedTypes_QtWidgets_QtCore[23].it_td

#define sipType_QFlags_0100Qt_MatchFlag sipImportedTypes_QtWidgets_QtCore[22].it_td

#define sipType_QFlags_0100Qt_KeyboardModifier sipImportedTypes_QtWidgets_QtCore[21].it_td

#define sipType_QFlags_0100Qt_ItemFlag sipImportedTypes_QtWidgets_QtCore[20].it_td

#define sipType_QFlags_0100Qt_InputMethodHint sipImportedTypes_QtWidgets_QtCore[19].it_td

#define sipType_QFlags_0100Qt_GestureFlag sipImportedTypes_QtWidgets_QtCore[18].it_td

#define sipType_QFlags_0100Qt_FindChildOption sipImportedTypes_QtWidgets_QtCore[17].it_td

#define sipType_QFlags_0100Qt_DropAction sipImportedTypes_QtWidgets_QtCore[16].it_td

#define sipType_QFlags_0100Qt_DockWidgetArea sipImportedTypes_QtWidgets_QtCore[15].it_td

#define sipType_QFlags_0100Qt_AlignmentFlag sipImportedTypes_QtWidgets_QtCore[14].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtWidgets_QtCore[34].it_td

#define sipType_QFlags_0100QItemSelectionModel_SelectionFlag sipImportedTypes_QtWidgets_QtCore[13].it_td

#define sipType_QFlags_0100QDir_Filter sipImportedTypes_QtWidgets_QtCore[12].it_td

#define sipType_QStringList sipImportedTypes_QtWidgets_QtCore[53].it_td

#define sipType_QList_2400 sipImportedTypes_QtWidgets_QtCore[37].it_td

#define sipType_QList_1800 sipImportedTypes_QtWidgets_QtCore[36].it_td

#define sipType_QString sipImportedTypes_QtWidgets_QtCore[52].it_td

#define sipType_quintptr sipImportedTypes_QtWidgets_QtCore[104].it_td

#define sipType_qintptr sipImportedTypes_QtWidgets_QtCore[103].it_td
extern sipImportedTypeDef sipImportedTypes_QtWidgets_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtWidgets_QtCore[];

#define sipType_QAbstractFileIconProvider sipImportedTypes_QtWidgets_QtGui[0].it_td

#define sipType_QAbstractFileIconProvider_IconType sipImportedTypes_QtWidgets_QtGui[1].it_td

#define sipType_QAbstractTextDocumentLayout sipImportedTypes_QtWidgets_QtGui[2].it_td

#define sipType_QAbstractTextDocumentLayout_PaintContext sipImportedTypes_QtWidgets_QtGui[3].it_td

#define sipType_QAction sipImportedTypes_QtWidgets_QtGui[4].it_td

#define sipType_QPaintDevice sipImportedTypes_QtWidgets_QtGui[40].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtWidgets_QtGui[41].it_td

#define sipType_QPixmap sipImportedTypes_QtWidgets_QtGui[51].it_td

#define sipType_QBitmap sipImportedTypes_QtWidgets_QtGui[6].it_td

#define sipType_QColor sipImportedTypes_QtWidgets_QtGui[9].it_td

#define sipType_QBrush sipImportedTypes_QtWidgets_QtGui[7].it_td

#define sipType_QCursor sipImportedTypes_QtWidgets_QtGui[11].it_td

#define sipType_QKeyEvent sipImportedTypes_QtWidgets_QtGui[32].it_td

#define sipType_QFocusEvent sipImportedTypes_QtWidgets_QtGui[21].it_td

#define sipType_QPaintEvent sipImportedTypes_QtWidgets_QtGui[43].it_td

#define sipType_QMoveEvent sipImportedTypes_QtWidgets_QtGui[37].it_td

#define sipType_QResizeEvent sipImportedTypes_QtWidgets_QtGui[55].it_td

#define sipType_QCloseEvent sipImportedTypes_QtWidgets_QtGui[8].it_td

#define sipType_QShowEvent sipImportedTypes_QtWidgets_QtGui[57].it_td

#define sipType_QHideEvent sipImportedTypes_QtWidgets_QtGui[28].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtWidgets_QtGui[10].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtWidgets_QtGui[31].it_td

#define sipType_QDropEvent sipImportedTypes_QtWidgets_QtGui[15].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtWidgets_QtGui[14].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtWidgets_QtGui[12].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtWidgets_QtGui[13].it_td

#define sipType_QHelpEvent sipImportedTypes_QtWidgets_QtGui[27].it_td

#define sipType_QActionEvent sipImportedTypes_QtWidgets_QtGui[5].it_td

#define sipType_QEnterEvent sipImportedTypes_QtWidgets_QtGui[16].it_td

#define sipType_QMouseEvent sipImportedTypes_QtWidgets_QtGui[36].it_td

#define sipType_QWheelEvent sipImportedTypes_QtWidgets_QtGui[76].it_td

#define sipType_QTabletEvent sipImportedTypes_QtWidgets_QtGui[58].it_td

#define sipType_QFont sipImportedTypes_QtWidgets_QtGui[22].it_td

#define sipType_QFontDatabase_WritingSystem sipImportedTypes_QtWidgets_QtGui[23].it_td

#define sipType_QFontInfo sipImportedTypes_QtWidgets_QtGui[24].it_td

#define sipType_QFontMetrics sipImportedTypes_QtWidgets_QtGui[25].it_td

#define sipType_QGuiApplication sipImportedTypes_QtWidgets_QtGui[26].it_td

#define sipType_QIcon sipImportedTypes_QtWidgets_QtGui[29].it_td

#define sipType_QIcon_Mode sipImportedTypes_QtWidgets_QtGui[30].it_td

#define sipType_QKeySequence sipImportedTypes_QtWidgets_QtGui[33].it_td

#define sipType_QMatrix4x4 sipImportedTypes_QtWidgets_QtGui[35].it_td

#define sipType_QMovie sipImportedTypes_QtWidgets_QtGui[38].it_td

#define sipType_QPagedPaintDevice sipImportedTypes_QtWidgets_QtGui[39].it_td

#define sipType_QWindow sipImportedTypes_QtWidgets_QtGui[77].it_td

#define sipType_QPaintEngine sipImportedTypes_QtWidgets_QtGui[42].it_td

#define sipType_QPainter sipImportedTypes_QtWidgets_QtGui[44].it_td

#define sipType_QPainter_RenderHint sipImportedTypes_QtWidgets_QtGui[45].it_td

#define sipType_QPainterPath sipImportedTypes_QtWidgets_QtGui[46].it_td

#define sipType_QPalette sipImportedTypes_QtWidgets_QtGui[47].it_td

#define sipType_QPalette_ColorRole sipImportedTypes_QtWidgets_QtGui[48].it_td

#define sipType_QPen sipImportedTypes_QtWidgets_QtGui[49].it_td

#define sipType_QPicture sipImportedTypes_QtWidgets_QtGui[50].it_td

#define sipType_QPolygon sipImportedTypes_QtWidgets_QtGui[52].it_td

#define sipType_QPolygonF sipImportedTypes_QtWidgets_QtGui[53].it_td

#define sipType_QRegion sipImportedTypes_QtWidgets_QtGui[54].it_td

#define sipType_QScreen sipImportedTypes_QtWidgets_QtGui[56].it_td

#define sipType_QTextCursor sipImportedTypes_QtWidgets_QtGui[61].it_td

#define sipType_QTextCursor_MoveOperation sipImportedTypes_QtWidgets_QtGui[63].it_td

#define sipType_QTextCursor_MoveMode sipImportedTypes_QtWidgets_QtGui[62].it_td

#define sipType_QTextDocument sipImportedTypes_QtWidgets_QtGui[64].it_td

#define sipType_QTextDocument_ResourceType sipImportedTypes_QtWidgets_QtGui[65].it_td

#define sipType_QTextFormat sipImportedTypes_QtWidgets_QtGui[66].it_td

#define sipType_QTextCharFormat sipImportedTypes_QtWidgets_QtGui[60].it_td

#define sipType_QTextInlineObject sipImportedTypes_QtWidgets_QtGui[68].it_td

#define sipType_QTextFrame sipImportedTypes_QtWidgets_QtGui[67].it_td

#define sipType_QTextBlock sipImportedTypes_QtWidgets_QtGui[59].it_td

#define sipType_QTextOption_WrapMode sipImportedTypes_QtWidgets_QtGui[69].it_td

#define sipType_QTransform sipImportedTypes_QtWidgets_QtGui[70].it_td

#define sipType_QUndoGroup sipImportedTypes_QtWidgets_QtGui[71].it_td

#define sipType_QUndoStack sipImportedTypes_QtWidgets_QtGui[72].it_td

#define sipType_QValidator sipImportedTypes_QtWidgets_QtGui[73].it_td

#define sipType_QValidator_State sipImportedTypes_QtWidgets_QtGui[74].it_td

#define sipType_QVector3D sipImportedTypes_QtWidgets_QtGui[75].it_td

#define sipType_QList_0101QAction sipImportedTypes_QtWidgets_QtGui[34].it_td

#define sipType_QFlags_0100QTextDocument_MarkdownFeature sipImportedTypes_QtWidgets_QtGui[20].it_td

#define sipType_QFlags_0100QTextDocument_FindFlag sipImportedTypes_QtWidgets_QtGui[19].it_td

#define sipType_QFlags_0100QPainter_RenderHint sipImportedTypes_QtWidgets_QtGui[18].it_td

#define sipType_QFlags_0100QAbstractFileIconProvider_Option sipImportedTypes_QtWidgets_QtGui[17].it_td
extern sipImportedTypeDef sipImportedTypes_QtWidgets_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtWidgets_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtWidgets_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtWidgets_qt_metacast;
#line 259 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qapplication.sip"
// Imports from QtCore.
typedef void (*pyqt6_qtwidgets_cleanup_qobjects_t)();
extern pyqt6_qtwidgets_cleanup_qobjects_t pyqt6_qtwidgets_cleanup_qobjects;

typedef char **(*pyqt6_qtwidgets_from_argv_list_t)(PyObject *, int &);
extern pyqt6_qtwidgets_from_argv_list_t pyqt6_qtwidgets_from_argv_list;

typedef sipErrorState (*pyqt6_qtwidgets_get_connection_parts_t)(PyObject *, QObject *, const char *, bool, QObject **, QByteArray &);
extern pyqt6_qtwidgets_get_connection_parts_t pyqt6_qtwidgets_get_connection_parts;

typedef sipErrorState (*pyqt6_qtwidgets_get_signal_signature_t)(PyObject *, QObject *, QByteArray &);
extern pyqt6_qtwidgets_get_signal_signature_t pyqt6_qtwidgets_get_signal_signature;

typedef void (*pyqt6_qtwidgets_update_argv_list_t)(PyObject *, int, char **);
extern pyqt6_qtwidgets_update_argv_list_t pyqt6_qtwidgets_update_argv_list;

// This is needed for Qt v5.0.0.
#if defined(B0)
#undef B0
#endif
#line 177 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlabel.sip"
// Imports from QtCore.
typedef void (*pyqt6_qtwidgets_err_print_t)();
extern pyqt6_qtwidgets_err_print_t pyqt6_qtwidgets_err_print;
#line 10629 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipAPIQtWidgets.h"

#endif
