/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtGuiAPI_H
#define _QtGuiAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QTextCharFormat__FontPropertiesInheritanceBehavior 0
#define sipName_QTextCharFormat__FontPropertiesInheritanceBehavior &sipStrings_QtGui[0]
#define sipNameNr_51 51
#define sipName_51 &sipStrings_QtGui[51]
#define sipNameNr_97 97
#define sipName_97 &sipStrings_QtGui[97]
#define sipNameNr_QAbstractTextDocumentLayout__PaintContext 140
#define sipName_QAbstractTextDocumentLayout__PaintContext &sipStrings_QtGui[140]
#define sipNameNr_182 182
#define sipName_182 &sipStrings_QtGui[182]
#define sipNameNr_224 224
#define sipName_224 &sipStrings_QtGui[224]
#define sipNameNr_265 265
#define sipName_265 &sipStrings_QtGui[265]
#define sipNameNr_QPlatformSurfaceEvent__SurfaceEventType 305
#define sipName_QPlatformSurfaceEvent__SurfaceEventType &sipStrings_QtGui[305]
#define sipNameNr_QAbstractTextDocumentLayout__Selection 345
#define sipName_QAbstractTextDocumentLayout__Selection &sipStrings_QtGui[345]
#define sipNameNr_384 384
#define sipName_384 &sipStrings_QtGui[384]
#define sipNameNr_AddSpaceForLineAndParagraphSeparators 423
#define sipName_AddSpaceForLineAndParagraphSeparators &sipStrings_QtGui[423]
#define sipNameNr_QNativeInterface__QWaylandApplication 461
#define sipName_QNativeInterface__QWaylandApplication &sipStrings_QtGui[461]
#define sipNameNr_499 499
#define sipName_499 &sipStrings_QtGui[499]
#define sipNameNr_536 536
#define sipName_536 &sipStrings_QtGui[536]
#define sipNameNr_573 573
#define sipName_573 &sipStrings_QtGui[573]
#define sipNameNr_QSurfaceFormat__OpenGLContextProfile 610
#define sipName_QSurfaceFormat__OpenGLContextProfile &sipStrings_QtGui[610]
#define sipNameNr_QAbstractFileIconProvider__IconType 647
#define sipName_QAbstractFileIconProvider__IconType &sipStrings_QtGui[647]
#define sipNameNr_683 683
#define sipName_683 &sipStrings_QtGui[683]
#define sipNameNr_719 719
#define sipName_719 &sipStrings_QtGui[719]
#define sipNameNr_RasterOp_NotSourceAndNotDestination 755
#define sipName_RasterOp_NotSourceAndNotDestination &sipStrings_QtGui[755]
#define sipNameNr_mouseQuickSelectionThresholdChanged 791
#define sipName_mouseQuickSelectionThresholdChanged &sipStrings_QtGui[791]
#define sipNameNr_removeApplicationFallbackFontFamily 827
#define sipName_removeApplicationFallbackFontFamily &sipStrings_QtGui[827]
#define sipNameNr_setHighDpiScaleFactorRoundingPolicy 863
#define sipName_setHighDpiScaleFactorRoundingPolicy &sipStrings_QtGui[863]
#define sipNameNr_899 899
#define sipName_899 &sipStrings_QtGui[899]
#define sipNameNr_QTextCharFormat__VerticalAlignment 934
#define sipName_QTextCharFormat__VerticalAlignment &sipStrings_QtGui[934]
#define sipNameNr_QTextLayout__GlyphRunRetrievalFlag 969
#define sipName_QTextLayout__GlyphRunRetrievalFlag &sipStrings_QtGui[969]
#define sipNameNr_RasterOp_NotSourceOrNotDestination 1004
#define sipName_RasterOp_NotSourceOrNotDestination &sipStrings_QtGui[1004]
#define sipNameNr_setApplicationFallbackFontFamilies 1039
#define sipName_setApplicationFallbackFontFamilies &sipStrings_QtGui[1039]
#define sipNameNr_showShortcutsInContextMenusChanged 1074
#define sipName_showShortcutsInContextMenusChanged &sipStrings_QtGui[1074]
#define sipNameNr_BlockTrailingHorizontalRulerWidth 1109
#define sipName_BlockTrailingHorizontalRulerWidth &sipStrings_QtGui[1109]
#define sipNameNr_FontPropertiesInheritanceBehavior 17
#define sipName_FontPropertiesInheritanceBehavior &sipStrings_QtGui[17]
#define sipNameNr_QAbstractFileIconProvider__Option 1143
#define sipName_QAbstractFileIconProvider__Option &sipStrings_QtGui[1143]
#define sipNameNr_QIconEngine__ScaledPixmapArgument 1177
#define sipName_QIconEngine__ScaledPixmapArgument &sipStrings_QtGui[1177]
#define sipNameNr_QNativeInterface__QX11Application 1211
#define sipName_QNativeInterface__QX11Application &sipStrings_QtGui[1211]
#define sipNameNr_QTextBlockFormat__LineHeightTypes 1245
#define sipName_QTextBlockFormat__LineHeightTypes &sipStrings_QtGui[1245]
#define sipNameNr_1279 1279
#define sipName_1279 &sipStrings_QtGui[1279]
#define sipNameNr_1312 1312
#define sipName_1312 &sipStrings_QtGui[1312]
#define sipNameNr_1345 1345
#define sipName_1345 &sipStrings_QtGui[1345]
#define sipNameNr_QInputMethodEvent__AttributeType 1378
#define sipName_QInputMethodEvent__AttributeType &sipStrings_QtGui[1378]
#define sipNameNr_QOpenGLContext__OpenGLModuleType 1411
#define sipName_QOpenGLContext__OpenGLModuleType &sipStrings_QtGui[1411]
#define sipNameNr_QPaintEngine__PaintEngineFeature 1444
#define sipName_QPaintEngine__PaintEngineFeature &sipStrings_QtGui[1444]
#define sipNameNr_QPainterStateGuard__InitialState 1477
#define sipName_QPainterStateGuard__InitialState &sipStrings_QtGui[1477]
#define sipNameNr_QPixelFormat__AlphaPremultiplied 1510
#define sipName_QPixelFormat__AlphaPremultiplied &sipStrings_QtGui[1510]
#define sipNameNr_QPixelFormat__TypeInterpretation 1543
#define sipName_QPixelFormat__TypeInterpretation &sipStrings_QtGui[1543]
#define sipNameNr_RasterOp_NotSourceAndDestination 1576
#define sipName_RasterOp_NotSourceAndDestination &sipStrings_QtGui[1576]
#define sipNameNr_RasterOp_NotSourceXorDestination 1609
#define sipName_RasterOp_NotSourceXorDestination &sipStrings_QtGui[1609]
#define sipNameNr_RasterOp_SourceAndNotDestination 1642
#define sipName_RasterOp_SourceAndNotDestination &sipStrings_QtGui[1642]
#define sipNameNr_addApplicationFallbackFontFamily 1675
#define sipName_addApplicationFallbackFontFamily &sipStrings_QtGui[1675]
#define sipNameNr_highDpiScaleFactorRoundingPolicy 1708
#define sipName_highDpiScaleFactorRoundingPolicy &sipStrings_QtGui[1708]
#define sipNameNr_mousePressAndHoldIntervalChanged 1741
#define sipName_mousePressAndHoldIntervalChanged &sipStrings_QtGui[1741]
#define sipNameNr_removeApplicationEmojiFontFamily 1774
#define sipName_removeApplicationEmojiFontFamily &sipStrings_QtGui[1774]
#define sipNameNr_CompositionMode_DestinationAtop 1807
#define sipName_CompositionMode_DestinationAtop &sipStrings_QtGui[1807]
#define sipNameNr_CompositionMode_DestinationOver 1839
#define sipName_CompositionMode_DestinationOver &sipStrings_QtGui[1839]
#define sipNameNr_Format_RGBA16FPx4_Premultiplied 1871
#define sipName_Format_RGBA16FPx4_Premultiplied &sipStrings_QtGui[1871]
#define sipNameNr_Format_RGBA32FPx4_Premultiplied 1903
#define sipName_Format_RGBA32FPx4_Premultiplied &sipStrings_QtGui[1903]
#define sipNameNr_1935 1935
#define sipName_1935 &sipStrings_QtGui[1935]
#define sipNameNr_1967 1967
#define sipName_1967 &sipStrings_QtGui[1967]
#define sipNameNr_1999 1999
#define sipName_1999 &sipStrings_QtGui[1999]
#define sipNameNr_QImageIOHandler__Transformation 2031
#define sipName_QImageIOHandler__Transformation &sipStrings_QtGui[2031]
#define sipNameNr_2063 2063
#define sipName_2063 &sipStrings_QtGui[2063]
#define sipNameNr_2095 2095
#define sipName_2095 &sipStrings_QtGui[2095]
#define sipNameNr_QPaintDevice__PaintDeviceMetric 2127
#define sipName_QPaintDevice__PaintDeviceMetric &sipStrings_QtGui[2127]
#define sipNameNr_QTextCharFormat__UnderlineStyle 2159
#define sipName_QTextCharFormat__UnderlineStyle &sipStrings_QtGui[2159]
#define sipNameNr_RasterOp_NotSourceOrDestination 2191
#define sipName_RasterOp_NotSourceOrDestination &sipStrings_QtGui[2191]
#define sipNameNr_RasterOp_SourceOrNotDestination 2223
#define sipName_RasterOp_SourceOrNotDestination &sipStrings_QtGui[2223]
#define sipNameNr_TransformationMirrorAndRotate90 2255
#define sipName_TransformationMirrorAndRotate90 &sipStrings_QtGui[2255]
#define sipNameNr_applicationFallbackFontFamilies 2287
#define sipName_applicationFallbackFontFamilies &sipStrings_QtGui[2287]
#define sipNameNr_availableVirtualGeometryChanged 2319
#define sipName_availableVirtualGeometryChanged &sipStrings_QtGui[2319]
#define sipNameNr_mouseDoubleClickIntervalChanged 2351
#define sipName_mouseDoubleClickIntervalChanged &sipStrings_QtGui[2351]
#define sipNameNr_setApplicationEmojiFontFamilies 2383
#define sipName_setApplicationEmojiFontFamilies &sipStrings_QtGui[2383]
#define sipNameNr_setShortcutVisibleInContextMenu 2415
#define sipName_setShortcutVisibleInContextMenu &sipStrings_QtGui[2415]
#define sipNameNr_CompositionMode_DestinationOut 2447
#define sipName_CompositionMode_DestinationOut &sipStrings_QtGui[2447]
#define sipNameNr_QImageReader__ImageReaderError 2478
#define sipName_QImageReader__ImageReaderError &sipStrings_QtGui[2478]
#define sipNameNr_QImageWriter__ImageWriterError 2509
#define sipName_QImageWriter__ImageWriterError &sipStrings_QtGui[2509]
#define sipNameNr_QPageLayout__OutOfBoundsPolicy 2540
#define sipName_QPageLayout__OutOfBoundsPolicy &sipStrings_QtGui[2540]
#define sipNameNr_QSurfaceFormat__RenderableType 2571
#define sipName_QSurfaceFormat__RenderableType &sipStrings_QtGui[2571]
#define sipNameNr_QTextDocument__MarkdownFeature 2602
#define sipName_QTextDocument__MarkdownFeature &sipStrings_QtGui[2602]
#define sipNameNr_QTextDocument__MetaInformation 2633
#define sipName_QTextDocument__MetaInformation &sipStrings_QtGui[2633]
#define sipNameNr_QTransform__TransformationType 2664
#define sipName_QTransform__TransformationType &sipStrings_QtGui[2664]
#define sipNameNr_ShowLineAndParagraphSeparators 2695
#define sipName_ShowLineAndParagraphSeparators &sipStrings_QtGui[2695]
#define sipNameNr_isShortcutVisibleInContextMenu 2726
#define sipName_isShortcutVisibleInContextMenu &sipStrings_QtGui[2726]
#define sipNameNr_reportContentOrientationChange 2757
#define sipName_reportContentOrientationChange &sipStrings_QtGui[2757]
#define sipNameNr_setShowShortcutsInContextMenus 2788
#define sipName_setShowShortcutsInContextMenus &sipStrings_QtGui[2788]
#define sipNameNr_CompositionMode_DestinationIn 2819
#define sipName_CompositionMode_DestinationIn &sipStrings_QtGui[2819]
#define sipNameNr_Format_ARGB4444_Premultiplied 2849
#define sipName_Format_ARGB4444_Premultiplied &sipStrings_QtGui[2849]
#define sipNameNr_Format_ARGB6666_Premultiplied 2879
#define sipName_Format_ARGB6666_Premultiplied &sipStrings_QtGui[2879]
#define sipNameNr_Format_ARGB8555_Premultiplied 2909
#define sipName_Format_ARGB8555_Premultiplied &sipStrings_QtGui[2909]
#define sipNameNr_Format_ARGB8565_Premultiplied 2939
#define sipName_Format_ARGB8565_Premultiplied &sipStrings_QtGui[2939]
#define sipNameNr_Format_RGBA8888_Premultiplied 2969
#define sipName_Format_RGBA8888_Premultiplied &sipStrings_QtGui[2969]
#define sipNameNr_PdmDevicePixelRatioF_EncodedA 2999
#define sipName_PdmDevicePixelRatioF_EncodedA &sipStrings_QtGui[2999]
#define sipNameNr_PdmDevicePixelRatioF_EncodedB 3029
#define sipName_PdmDevicePixelRatioF_EncodedB &sipStrings_QtGui[3029]
#define sipNameNr_QActionGroup__ExclusionPolicy 3059
#define sipName_QActionGroup__ExclusionPolicy &sipStrings_QtGui[3059]
#define sipNameNr_QColorSpace__TransferFunction 3089
#define sipName_QColorSpace__TransferFunction &sipStrings_QtGui[3089]
#define sipNameNr_3119 3119
#define sipName_3119 &sipStrings_QtGui[3119]
#define sipNameNr_QPagedPaintDevice__PdfVersion 3149
#define sipName_QPagedPaintDevice__PdfVersion &sipStrings_QtGui[3149]
#define sipNameNr_QPaintEngine__PolygonDrawMode 3179
#define sipName_QPaintEngine__PolygonDrawMode &sipStrings_QtGui[3179]
#define sipNameNr_QTextFrameFormat__BorderStyle 3209
#define sipName_QTextFrameFormat__BorderStyle &sipStrings_QtGui[3209]
#define sipNameNr_RasterOp_SourceAndDestination 3239
#define sipName_RasterOp_SourceAndDestination &sipStrings_QtGui[3239]
#define sipNameNr_RasterOp_SourceXorDestination 3269
#define sipName_RasterOp_SourceXorDestination &sipStrings_QtGui[3269]
#define sipNameNr_TransformationFlipAndRotate90 3299
#define sipName_TransformationFlipAndRotate90 &sipStrings_QtGui[3299]
#define sipNameNr_addApplicationEmojiFontFamily 3329
#define sipName_addApplicationEmojiFontFamily &sipStrings_QtGui[3329]
#define sipNameNr_applicationDisplayNameChanged 3359
#define sipName_applicationDisplayNameChanged &sipStrings_QtGui[3359]
#define sipNameNr_inputItemClipRectangleChanged 3389
#define sipName_inputItemClipRectangleChanged &sipStrings_QtGui[3389]
#define sipNameNr_qt_set_sequence_auto_mnemonic 3419
#define sipName_qt_set_sequence_auto_mnemonic &sipStrings_QtGui[3419]
#define sipNameNr_Format_A2BGR30_Premultiplied 3449
#define sipName_Format_A2BGR30_Premultiplied &sipStrings_QtGui[3449]
#define sipNameNr_Format_A2RGB30_Premultiplied 3478
#define sipName_Format_A2RGB30_Premultiplied &sipStrings_QtGui[3478]
#define sipNameNr_QColorSpace__NamedColorSpace 3507
#define sipName_QColorSpace__NamedColorSpace &sipStrings_QtGui[3507]
#define sipNameNr_3536 3536
#define sipName_3536 &sipStrings_QtGui[3536]
#define sipNameNr_3565 3565
#define sipName_3565 &sipStrings_QtGui[3565]
#define sipNameNr_QFontDatabase__WritingSystem 3594
#define sipName_QFontDatabase__WritingSystem &sipStrings_QtGui[3594]
#define sipNameNr_QImageIOHandler__ImageOption 3623
#define sipName_QImageIOHandler__ImageOption &sipStrings_QtGui[3623]
#define sipNameNr_QInputMethodEvent__Attribute 3652
#define sipName_QInputMethodEvent__Attribute &sipStrings_QtGui[3652]
#define sipNameNr_QKeySequence__SequenceFormat 3681
#define sipName_QKeySequence__SequenceFormat &sipStrings_QtGui[3681]
#define sipNameNr_QPainter__PixmapFragmentHint 3710
#define sipName_QPainter__PixmapFragmentHint &sipStrings_QtGui[3710]
#define sipNameNr_QPointingDevice__PointerType 3739
#define sipName_QPointingDevice__PointerType &sipStrings_QtGui[3739]
#define sipNameNr_QSessionManager__RestartHint 3768
#define sipName_QSessionManager__RestartHint &sipStrings_QtGui[3768]
#define sipNameNr_QStaticText__PerformanceHint 3797
#define sipName_QStaticText__PerformanceHint &sipStrings_QtGui[3797]
#define sipNameNr_QSurfaceFormat__FormatOption 3826
#define sipName_QSurfaceFormat__FormatOption &sipStrings_QtGui[3826]
#define sipNameNr_QSurfaceFormat__SwapBehavior 3855
#define sipName_QSurfaceFormat__SwapBehavior &sipStrings_QtGui[3855]
#define sipNameNr_QTextBlockFormat__MarkerType 3884
#define sipName_QTextBlockFormat__MarkerType &sipStrings_QtGui[3884]
#define sipNameNr_RasterOp_SourceOrDestination 3913
#define sipName_RasterOp_SourceOrDestination &sipStrings_QtGui[3913]
#define sipNameNr_WrapAtWordBoundaryOrAnywhere 3942
#define sipName_WrapAtWordBoundaryOrAnywhere &sipStrings_QtGui[3942]
#define sipNameNr_applicationEmojiFontFamilies 3971
#define sipName_applicationEmojiFontFamilies &sipStrings_QtGui[3971]
#define sipNameNr_keyboardInputIntervalChanged 4000
#define sipName_keyboardInputIntervalChanged &sipStrings_QtGui[4000]
#define sipNameNr_mouseQuickSelectionThreshold 4029
#define sipName_mouseQuickSelectionThreshold &sipStrings_QtGui[4029]
#define sipNameNr_setOutputConditionIdentifier 4058
#define sipName_setOutputConditionIdentifier &sipStrings_QtGui[4058]
#define sipNameNr_CompositionMode_Destination 4087
#define sipName_CompositionMode_Destination &sipStrings_QtGui[4087]
#define sipNameNr_DontUseCustomDirectoryIcons 4115
#define sipName_DontUseCustomDirectoryIcons &sipStrings_QtGui[4115]
#define sipNameNr_FontPropertiesSpecifiedOnly 4143
#define sipName_FontPropertiesSpecifiedOnly &sipStrings_QtGui[4143]
#define sipNameNr_Format_ARGB32_Premultiplied 4171
#define sipName_Format_ARGB32_Premultiplied &sipStrings_QtGui[4171]
#define sipNameNr_Format_RGBA64_Premultiplied 4199
#define sipName_Format_RGBA64_Premultiplied &sipStrings_QtGui[4199]
#define sipNameNr_ObjectBoundingModeGradients 4227
#define sipName_ObjectBoundingModeGradients &sipStrings_QtGui[4227]
#define sipNameNr_QAbstractTextDocumentLayout 4255
#define sipName_QAbstractTextDocumentLayout &sipStrings_QtGui[4255]
#define sipNameNr_QColorSpace__TransformModel 4283
#define sipName_QColorSpace__TransformModel &sipStrings_QtGui[4283]
#define sipNameNr_QIconEngine__IconEngineHook 4311
#define sipName_QIconEngine__IconEngineHook &sipStrings_QtGui[4311]
#define sipNameNr_QKeySequence__SequenceMatch 4339
#define sipName_QKeySequence__SequenceMatch &sipStrings_QtGui[4339]
#define sipNameNr_QPixelFormat__AlphaPosition 4367
#define sipName_QPixelFormat__AlphaPosition &sipStrings_QtGui[4367]
#define sipNameNr_QRegularExpressionValidator 4395
#define sipName_QRegularExpressionValidator &sipStrings_QtGui[4395]
#define sipNameNr_QTextDocument__ResourceType 4423
#define sipName_QTextDocument__ResourceType &sipStrings_QtGui[4423]
#define sipNameNr_TableColumnWidthConstraints 4451
#define sipName_TableColumnWidthConstraints &sipStrings_QtGui[4451]
#define sipNameNr_VerticalSubpixelPositioning 4479
#define sipName_VerticalSubpixelPositioning &sipStrings_QtGui[4479]
#define sipNameNr_clearColumnWidthConstraints 4507
#define sipName_clearColumnWidthConstraints &sipStrings_QtGui[4507]
#define sipNameNr_showShortcutsInContextMenus 4535
#define sipName_showShortcutsInContextMenus &sipStrings_QtGui[4535]
#define sipNameNr_CompositionMode_ColorDodge 4563
#define sipName_CompositionMode_ColorDodge &sipStrings_QtGui[4563]
#define sipNameNr_CompositionMode_Difference 4590
#define sipName_CompositionMode_Difference &sipStrings_QtGui[4590]
#define sipNameNr_CompositionMode_SourceAtop 4617
#define sipName_CompositionMode_SourceAtop &sipStrings_QtGui[4617]
#define sipNameNr_CompositionMode_SourceOver 4644
#define sipName_CompositionMode_SourceOver &sipStrings_QtGui[4644]
#define sipNameNr_QColorSpace__PrimaryPoints 4671
#define sipName_QColorSpace__PrimaryPoints &sipStrings_QtGui[4671]
#define sipNameNr_QDoubleValidator__Notation 4698
#define sipName_QDoubleValidator__Notation &sipStrings_QtGui[4698]
#define sipNameNr_4725 4725
#define sipName_4725 &sipStrings_QtGui[4725]
#define sipNameNr_QPageSize__SizeMatchPolicy 4752
#define sipName_QPageSize__SizeMatchPolicy &sipStrings_QtGui[4752]
#define sipNameNr_QRawFont__AntialiasingType 4779
#define sipName_QRawFont__AntialiasingType &sipStrings_QtGui[4779]
#define sipNameNr_QTextCursor__MoveOperation 4806
#define sipName_QTextCursor__MoveOperation &sipStrings_QtGui[4806]
#define sipNameNr_QTextCursor__SelectionType 4833
#define sipName_QTextCursor__SelectionType &sipStrings_QtGui[4833]
#define sipNameNr_QTextFormat__PageBreakFlag 4860
#define sipName_QTextFormat__PageBreakFlag &sipStrings_QtGui[4860]
#define sipNameNr_QTextFrameFormat__Position 4887
#define sipName_QTextFrameFormat__Position &sipStrings_QtGui[4887]
#define sipNameNr_TableCellBottomBorderBrush 4914
#define sipName_TableCellBottomBorderBrush &sipStrings_QtGui[4914]
#define sipNameNr_TableCellBottomBorderStyle 4941
#define sipName_TableCellBottomBorderStyle &sipStrings_QtGui[4941]
#define sipNameNr_addApplicationFontFromData 4968
#define sipName_addApplicationFontFromData &sipStrings_QtGui[4968]
#define sipNameNr_physicalDotsPerInchChanged 4995
#define sipName_physicalDotsPerInchChanged &sipStrings_QtGui[4995]
#define sipNameNr_setDecideFormatFromContent 5022
#define sipName_setDecideFormatFromContent &sipStrings_QtGui[5022]
#define sipNameNr_setDefaultResourceProvider 5049
#define sipName_setDefaultResourceProvider &sipStrings_QtGui[5049]
#define sipNameNr_transformationToColorSpace 5076
#define sipName_transformationToColorSpace &sipStrings_QtGui[5076]
#define sipNameNr_CompositionMode_ColorBurn 5103
#define sipName_CompositionMode_ColorBurn &sipStrings_QtGui[5103]
#define sipNameNr_CompositionMode_Exclusion 5129
#define sipName_CompositionMode_Exclusion &sipStrings_QtGui[5129]
#define sipNameNr_CompositionMode_HardLight 5155
#define sipName_CompositionMode_HardLight &sipStrings_QtGui[5155]
#define sipNameNr_CompositionMode_SoftLight 5181
#define sipName_CompositionMode_SoftLight &sipStrings_QtGui[5181]
#define sipNameNr_CompositionMode_SourceOut 5207
#define sipName_CompositionMode_SourceOut &sipStrings_QtGui[5207]
#define sipNameNr_MarkdownDialectCommonMark 5233
#define sipName_MarkdownDialectCommonMark &sipStrings_QtGui[5233]
#define sipNameNr_PdmDevicePixelRatioScaled 5259
#define sipName_PdmDevicePixelRatioScaled &sipStrings_QtGui[5259]
#define sipNameNr_QAbstractFileIconProvider 5285
#define sipName_QAbstractFileIconProvider &sipStrings_QtGui[5285]
#define sipNameNr_QContextMenuEvent__Reason 5311
#define sipName_QContextMenuEvent__Reason &sipStrings_QtGui[5311]
#define sipNameNr_5337 5337
#define sipName_5337 &sipStrings_QtGui[5337]
#define sipNameNr_QFontDatabase__SystemFont 5363
#define sipName_QFontDatabase__SystemFont &sipStrings_QtGui[5363]
#define sipNameNr_QGradient__CoordinateMode 5389
#define sipName_QGradient__CoordinateMode &sipStrings_QtGui[5389]
#define sipNameNr_QKeySequence__StandardKey 5415
#define sipName_QKeySequence__StandardKey &sipStrings_QtGui[5415]
#define sipNameNr_5441 5441
#define sipName_5441 &sipStrings_QtGui[5441]
#define sipNameNr_QPainter__CompositionMode 5467
#define sipName_QPainter__CompositionMode &sipStrings_QtGui[5467]
#define sipNameNr_QPainterPath__ElementType 5493
#define sipName_QPainterPath__ElementType &sipStrings_QtGui[5493]
#define sipNameNr_QScrollEvent__ScrollState 5519
#define sipName_QScrollEvent__ScrollState &sipStrings_QtGui[5519]
#define sipNameNr_QTextLine__CursorPosition 5545
#define sipName_QTextLine__CursorPosition &sipStrings_QtGui[5545]
#define sipNameNr_RasterOp_ClearDestination 5571
#define sipName_RasterOp_ClearDestination &sipStrings_QtGui[5571]
#define sipNameNr_SurfaceAboutToBeDestroyed 5597
#define sipName_SurfaceAboutToBeDestroyed &sipStrings_QtGui[5597]
#define sipNameNr_TableCellRightBorderBrush 5623
#define sipName_TableCellRightBorderBrush &sipStrings_QtGui[5623]
#define sipNameNr_TableCellRightBorderStyle 5649
#define sipName_TableCellRightBorderStyle &sipStrings_QtGui[5649]
#define sipNameNr_contentOrientationChanged 5675
#define sipName_contentOrientationChanged &sipStrings_QtGui[5675]
#define sipNameNr_contextMenuTriggerChanged 5701
#define sipName_contextMenuTriggerChanged &sipStrings_QtGui[5701]
#define sipNameNr_contrastPreferenceChanged 5727
#define sipName_contrastPreferenceChanged &sipStrings_QtGui[5727]
#define sipNameNr_logicalDotsPerInchChanged 5753
#define sipName_logicalDotsPerInchChanged &sipStrings_QtGui[5753]
#define sipNameNr_mousePressAndHoldInterval 5779
#define sipName_mousePressAndHoldInterval &sipStrings_QtGui[5779]
#define sipNameNr_outputConditionIdentifier 5805
#define sipName_outputConditionIdentifier &sipStrings_QtGui[5805]
#define sipNameNr_primaryOrientationChanged 5831
#define sipName_primaryOrientationChanged &sipStrings_QtGui[5831]
#define sipNameNr_removeAllApplicationFonts 5857
#define sipName_removeAllApplicationFonts &sipStrings_QtGui[5857]
#define sipNameNr_setApplicationDisplayName 5883
#define sipName_setApplicationDisplayName &sipStrings_QtGui[5883]
#define sipNameNr_setColumnWidthConstraints 5909
#define sipName_setColumnWidthConstraints &sipStrings_QtGui[5909]
#define sipNameNr_setDefaultCursorMoveStyle 5935
#define sipName_setDefaultCursorMoveStyle &sipStrings_QtGui[5935]
#define sipNameNr_setHorizontalHeaderLabels 5961
#define sipName_setHorizontalHeaderLabels &sipStrings_QtGui[5961]
#define sipNameNr_setQuitOnLastWindowClosed 5987
#define sipName_setQuitOnLastWindowClosed &sipStrings_QtGui[5987]
#define sipNameNr_6013 6013
#define sipName_6013 &sipStrings_QtGui[6013]
#define sipNameNr_CompositionMode_Multiply 6039
#define sipName_CompositionMode_Multiply &sipStrings_QtGui[6039]
#define sipNameNr_CompositionMode_SourceIn 6064
#define sipName_CompositionMode_SourceIn &sipStrings_QtGui[6064]
#define sipNameNr_InsertParagraphSeparator 6089
#define sipName_InsertParagraphSeparator &sipStrings_QtGui[6089]
#define sipNameNr_NonCosmeticBrushPatterns 6114
#define sipName_NonCosmeticBrushPatterns &sipStrings_QtGui[6114]
#define sipNameNr_OldFontLetterSpacingType 6139
#define sipName_OldFontLetterSpacingType &sipStrings_QtGui[6139]
#define sipNameNr_QFileSystemModel__Option 6164
#define sipName_QFileSystemModel__Option &sipStrings_QtGui[6164]
#define sipNameNr_QFont__HintingPreference 6189
#define sipName_QFont__HintingPreference &sipStrings_QtGui[6189]
#define sipNameNr_QInputDevice__Capability 6214
#define sipName_QInputDevice__Capability &sipStrings_QtGui[6214]
#define sipNameNr_QInputDevice__DeviceType 6239
#define sipName_QInputDevice__DeviceType &sipStrings_QtGui[6239]
#define sipNameNr_6264 6264
#define sipName_6264 &sipStrings_QtGui[6264]
#define sipNameNr_6289 6289
#define sipName_6289 &sipStrings_QtGui[6289]
#define sipNameNr_QPageLayout__Orientation 6314
#define sipName_QPageLayout__Orientation &sipStrings_QtGui[6314]
#define sipNameNr_QPainter__PixmapFragment 6339
#define sipName_QPainter__PixmapFragment &sipStrings_QtGui[6339]
#define sipNameNr_QPixelFormat__AlphaUsage 6364
#define sipName_QPixelFormat__AlphaUsage &sipStrings_QtGui[6364]
#define sipNameNr_QPixelFormat__ColorModel 6389
#define sipName_QPixelFormat__ColorModel &sipStrings_QtGui[6389]
#define sipNameNr_QTextFormat__ObjectTypes 6414
#define sipName_QTextFormat__ObjectTypes &sipStrings_QtGui[6414]
#define sipNameNr_QTextLayout__FormatRange 6439
#define sipName_QTextLayout__FormatRange &sipStrings_QtGui[6439]
#define sipNameNr_TableCellLeftBorderBrush 6464
#define sipName_TableCellLeftBorderBrush &sipStrings_QtGui[6464]
#define sipNameNr_TableCellLeftBorderStyle 6489
#define sipName_TableCellLeftBorderStyle &sipStrings_QtGui[6489]
#define sipNameNr_availableGeometryChanged 6514
#define sipName_availableGeometryChanged &sipStrings_QtGui[6514]
#define sipNameNr_availableVirtualGeometry 6539
#define sipName_availableVirtualGeometry &sipStrings_QtGui[6539]
#define sipNameNr_defaultFramebufferObject 6564
#define sipName_defaultFramebufferObject &sipStrings_QtGui[6564]
#define sipNameNr_keyboardRectangleChanged 6589
#define sipName_keyboardRectangleChanged &sipStrings_QtGui[6589]
#define sipNameNr_mouseDoubleClickDistance 6614
#define sipName_mouseDoubleClickDistance &sipStrings_QtGui[6614]
#define sipNameNr_mouseDoubleClickInterval 6639
#define sipName_mouseDoubleClickInterval &sipStrings_QtGui[6639]
#define sipNameNr_setAccessibleDescription 6664
#define sipName_setAccessibleDescription &sipStrings_QtGui[6664]
#define sipNameNr_setAutoDetectImageFormat 6689
#define sipName_setAutoDetectImageFormat &sipStrings_QtGui[6689]
#define sipNameNr_setExclusivePointGrabber 6714
#define sipName_setExclusivePointGrabber &sipStrings_QtGui[6714]
#define sipNameNr_setFontHintingPreference 6739
#define sipName_setFontHintingPreference &sipStrings_QtGui[6739]
#define sipNameNr_setFontLetterSpacingType 6764
#define sipName_setFontLetterSpacingType &sipStrings_QtGui[6764]
#define sipNameNr_startDragDistanceChanged 6789
#define sipName_startDragDistanceChanged &sipStrings_QtGui[6789]
#define sipNameNr_supportedDocumentFormats 6814
#define sipName_supportedDocumentFormats &sipStrings_QtGui[6814]
#define sipNameNr_takeHorizontalHeaderItem 6839
#define sipName_takeHorizontalHeaderItem &sipStrings_QtGui[6839]
#define sipNameNr_ApplicationSpecificRole 6864
#define sipName_ApplicationSpecificRole &sipStrings_QtGui[6864]
#define sipNameNr_CompositionMode_Lighten 6888
#define sipName_CompositionMode_Lighten &sipStrings_QtGui[6888]
#define sipNameNr_CompositionMode_Overlay 6912
#define sipName_CompositionMode_Overlay &sipStrings_QtGui[6912]
#define sipNameNr_CursorBetweenCharacters 6936
#define sipName_CursorBetweenCharacters &sipStrings_QtGui[6936]
#define sipNameNr_FormatTextStrikethrough 6960
#define sipName_FormatTextStrikethrough &sipStrings_QtGui[6960]
#define sipNameNr_PyQt6_sip_simplewrapper 6984
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtGui[6984]
#define sipNameNr_QColorSpace__ColorModel 7008
#define sipName_QColorSpace__ColorModel &sipStrings_QtGui[7008]
#define sipNameNr_QFileSystemModel__Roles 7032
#define sipName_QFileSystemModel__Roles &sipStrings_QtGui[7032]
#define sipNameNr_QGlyphRun__GlyphRunFlag 7056
#define sipName_QGlyphRun__GlyphRunFlag &sipStrings_QtGui[7056]
#define sipNameNr_7080 7080
#define sipName_7080 &sipStrings_QtGui[7080]
#define sipNameNr_QPaintEngine__DirtyFlag 7104
#define sipName_QPaintEngine__DirtyFlag &sipStrings_QtGui[7104]
#define sipNameNr_QPixelFormat__ByteOrder 7128
#define sipName_QPixelFormat__ByteOrder &sipStrings_QtGui[7128]
#define sipNameNr_QPixelFormat__YUVLayout 7152
#define sipName_QPixelFormat__YUVLayout &sipStrings_QtGui[7152]
#define sipNameNr_QPointingDeviceUniqueId 7176
#define sipName_QPointingDeviceUniqueId &sipStrings_QtGui[7176]
#define sipNameNr_QStandardItem__ItemType 7200
#define sipName_QStandardItem__ItemType &sipStrings_QtGui[7200]
#define sipNameNr_QTextDocument__FindFlag 7224
#define sipName_QTextDocument__FindFlag &sipStrings_QtGui[7224]
#define sipNameNr_QTextFormat__FormatType 7248
#define sipName_QTextFormat__FormatType &sipStrings_QtGui[7248]
#define sipNameNr_QTextLayout__CursorMode 7272
#define sipName_QTextLayout__CursorMode &sipStrings_QtGui[7272]
#define sipNameNr_QWindowStateChangeEvent 7296
#define sipName_QWindowStateChangeEvent &sipStrings_QtGui[7296]
#define sipNameNr_RasterOp_NotDestination 7320
#define sipName_RasterOp_NotDestination &sipStrings_QtGui[7320]
#define sipNameNr_RasterOp_SetDestination 7344
#define sipName_RasterOp_SetDestination &sipStrings_QtGui[7344]
#define sipNameNr_SoftwareUpdateAvailable 7368
#define sipName_SoftwareUpdateAvailable &sipStrings_QtGui[7368]
#define sipNameNr_TableCellTopBorderBrush 7392
#define sipName_TableCellTopBorderBrush &sipStrings_QtGui[7392]
#define sipNameNr_TableCellTopBorderStyle 7416
#define sipName_TableCellTopBorderStyle &sipStrings_QtGui[7416]
#define sipNameNr_TextSuperScriptBaseline 7440
#define sipName_TextSuperScriptBaseline &sipStrings_QtGui[7440]
#define sipNameNr_TransformationRotate180 7464
#define sipName_TransformationRotate180 &sipStrings_QtGui[7464]
#define sipNameNr_TransformationRotate270 7488
#define sipName_TransformationRotate270 &sipStrings_QtGui[7488]
#define sipNameNr_advancesForGlyphIndexes 7512
#define sipName_advancesForGlyphIndexes &sipStrings_QtGui[7512]
#define sipNameNr_applicationFontFamilies 7536
#define sipName_applicationFontFamilies &sipStrings_QtGui[7536]
#define sipNameNr_applicationStateChanged 7560
#define sipName_applicationStateChanged &sipStrings_QtGui[7560]
#define sipNameNr_decideFormatFromContent 7584
#define sipName_decideFormatFromContent &sipStrings_QtGui[7584]
#define sipNameNr_defaultResourceProvider 7608
#define sipName_defaultResourceProvider &sipStrings_QtGui[7608]
#define sipNameNr_imageFormatsForMimeType 7632
#define sipName_imageFormatsForMimeType &sipStrings_QtGui[7632]
#define sipNameNr_keyboardAutoRepeatRateF 7656
#define sipName_keyboardAutoRepeatRateF &sipStrings_QtGui[7656]
#define sipNameNr_setCurrentBlockUserData 7680
#define sipName_setCurrentBlockUserData &sipStrings_QtGui[7680]
#define sipNameNr_setDesktopSettingsAware 7704
#define sipName_setDesktopSettingsAware &sipStrings_QtGui[7704]
#define sipNameNr_setHorizontalHeaderItem 7728
#define sipName_setHorizontalHeaderItem &sipStrings_QtGui[7728]
#define sipNameNr_setKeepPositionOnInsert 7752
#define sipName_setKeepPositionOnInsert &sipStrings_QtGui[7752]
#define sipNameNr_setProgressiveScanWrite 7776
#define sipName_setProgressiveScanWrite &sipStrings_QtGui[7776]
#define sipNameNr_setVerticalHeaderLabels 7800
#define sipName_setVerticalHeaderLabels &sipStrings_QtGui[7800]
#define sipNameNr_setViewTransformEnabled 7824
#define sipName_setViewTransformEnabled &sipStrings_QtGui[7824]
#define sipNameNr_supportedWritingSystems 7848
#define sipName_supportedWritingSystems &sipStrings_QtGui[7848]
#define sipNameNr_tabFocusBehaviorChanged 7872
#define sipName_tabFocusBehaviorChanged &sipStrings_QtGui[7872]
#define sipNameNr_wheelScrollLinesChanged 7896
#define sipName_wheelScrollLinesChanged &sipStrings_QtGui[7896]
#define sipNameNr_BlockNonBreakableLines 7920
#define sipName_BlockNonBreakableLines &sipStrings_QtGui[7920]
#define sipNameNr_BorderStyle_DotDotDash 7943
#define sipName_BorderStyle_DotDotDash &sipStrings_QtGui[7943]
#define sipNameNr_CompositionMode_Darken 7966
#define sipName_CompositionMode_Darken &sipStrings_QtGui[7966]
#define sipNameNr_CompositionMode_Screen 7989
#define sipName_CompositionMode_Screen &sipStrings_QtGui[7989]
#define sipNameNr_CompositionMode_Source 8012
#define sipName_CompositionMode_Source &sipStrings_QtGui[8012]
#define sipNameNr_FormatTextDirectionLtr 8035
#define sipName_FormatTextDirectionLtr &sipStrings_QtGui[8035]
#define sipNameNr_FormatTextDirectionRtl 8058
#define sipName_FormatTextDirectionRtl &sipStrings_QtGui[8058]
#define sipNameNr_LosslessImageRendering 8081
#define sipName_LosslessImageRendering &sipStrings_QtGui[8081]
#define sipNameNr_PageBreak_AlwaysBefore 8104
#define sipName_PageBreak_AlwaysBefore &sipStrings_QtGui[8104]
#define sipNameNr_PaintOutsidePaintEvent 8127
#define sipName_PaintOutsidePaintEvent &sipStrings_QtGui[8127]
#define sipNameNr_QColorSpace__Primaries 8150
#define sipName_QColorSpace__Primaries &sipStrings_QtGui[8150]
#define sipNameNr_QInputMethodQueryEvent 8173
#define sipName_QInputMethodQueryEvent &sipStrings_QtGui[8173]
#define sipNameNr_8196 8196
#define sipName_8196 &sipStrings_QtGui[8196]
#define sipNameNr_8219 8219
#define sipName_8219 &sipStrings_QtGui[8219]
#define sipNameNr_QPdfWriter__ColorModel 8242
#define sipName_QPdfWriter__ColorModel &sipStrings_QtGui[8242]
#define sipNameNr_QSurface__SurfaceClass 8265
#define sipName_QSurface__SurfaceClass &sipStrings_QtGui[8265]
#define sipNameNr_QTextListFormat__Style 8288
#define sipName_QTextListFormat__Style &sipStrings_QtGui[8288]
#define sipNameNr_QWhatsThisClickedEvent 8311
#define sipName_QWhatsThisClickedEvent &sipStrings_QtGui[8311]
#define sipNameNr_RetrieveGlyphPositions 8334
#define sipName_RetrieveGlyphPositions &sipStrings_QtGui[8334]
#define sipNameNr_ShowDocumentTerminator 8357
#define sipName_ShowDocumentTerminator &sipStrings_QtGui[8357]
#define sipNameNr_TableCellBottomPadding 8380
#define sipName_TableCellBottomPadding &sipStrings_QtGui[8380]
#define sipNameNr_TransformationRotate90 8403
#define sipName_TransformationRotate90 &sipStrings_QtGui[8403]
#define sipNameNr_UnsupportedFormatError 8426
#define sipName_UnsupportedFormatError &sipStrings_QtGui[8426]
#define sipNameNr_allowsErrorInteraction 8449
#define sipName_allowsErrorInteraction &sipStrings_QtGui[8449]
#define sipNameNr_anchorRectangleChanged 8472
#define sipName_anchorRectangleChanged &sipStrings_QtGui[8472]
#define sipNameNr_applicationDisplayName 8495
#define sipName_applicationDisplayName &sipStrings_QtGui[8495]
#define sipNameNr_columnWidthConstraints 8518
#define sipName_columnWidthConstraints &sipStrings_QtGui[8518]
#define sipNameNr_cursorFlashTimeChanged 8541
#define sipName_cursorFlashTimeChanged &sipStrings_QtGui[8541]
#define sipNameNr_cursorRectangleChanged 8564
#define sipName_cursorRectangleChanged &sipStrings_QtGui[8564]
#define sipNameNr_defaultCursorMoveStyle 8587
#define sipName_defaultCursorMoveStyle &sipStrings_QtGui[8587]
#define sipNameNr_devicePixelRatioFScale 8610
#define sipName_devicePixelRatioFScale &sipStrings_QtGui[8610]
#define sipNameNr_inputItemClipRectangle 8633
#define sipName_inputItemClipRectangle &sipStrings_QtGui[8633]
#define sipNameNr_keyboardAutoRepeatRate 8656
#define sipName_keyboardAutoRepeatRate &sipStrings_QtGui[8656]
#define sipNameNr_layoutDirectionChanged 8679
#define sipName_layoutDirectionChanged &sipStrings_QtGui[8679]
#define sipNameNr_previousCursorPosition 8702
#define sipName_previousCursorPosition &sipStrings_QtGui[8702]
#define sipNameNr_queryKeyboardModifiers 8725
#define sipName_queryKeyboardModifiers &sipStrings_QtGui[8725]
#define sipNameNr_quitOnLastWindowClosed 8748
#define sipName_quitOnLastWindowClosed &sipStrings_QtGui[8748]
#define sipNameNr_safeAreaMarginsChanged 8771
#define sipName_safeAreaMarginsChanged &sipStrings_QtGui[8771]
#define sipNameNr_setDocumentXmpMetadata 8794
#define sipName_setDocumentXmpMetadata &sipStrings_QtGui[8794]
#define sipNameNr_setFallbackSearchPaths 8817
#define sipName_setFallbackSearchPaths &sipStrings_QtGui[8817]
#define sipNameNr_setFocusOnTouchRelease 8840
#define sipName_setFocusOnTouchRelease &sipStrings_QtGui[8840]
#define sipNameNr_setKeyboardGrabEnabled 8863
#define sipName_setKeyboardGrabEnabled &sipStrings_QtGui[8863]
#define sipNameNr_setSuperScriptBaseline 8886
#define sipName_setSuperScriptBaseline &sipStrings_QtGui[8886]
#define sipNameNr_setTableCellColumnSpan 8909
#define sipName_setTableCellColumnSpan &sipStrings_QtGui[8909]
#define sipNameNr_supportsThreadedOpenGL 8932
#define sipName_supportsThreadedOpenGL &sipStrings_QtGui[8932]
#define sipNameNr_takeVerticalHeaderItem 8955
#define sipName_takeVerticalHeaderItem &sipStrings_QtGui[8955]
#define sipNameNr_touchDoubleTapDistance 8978
#define sipName_touchDoubleTapDistance &sipStrings_QtGui[8978]
#define sipNameNr_useHoverEffectsChanged 9001
#define sipName_useHoverEffectsChanged &sipStrings_QtGui[9001]
#define sipNameNr_virtualGeometryChanged 9024
#define sipName_virtualGeometryChanged &sipStrings_QtGui[9024]
#define sipNameNr_CompositionMode_Clear 9047
#define sipName_CompositionMode_Clear &sipStrings_QtGui[9047]
#define sipNameNr_DefaultRenderableType 9069
#define sipName_DefaultRenderableType &sipStrings_QtGui[9069]
#define sipNameNr_DefaultRetrievalFlags 9091
#define sipName_DefaultRetrievalFlags &sipStrings_QtGui[9091]
#define sipNameNr_ElementListProcessing 9113
#define sipName_ElementListProcessing &sipStrings_QtGui[9113]
#define sipNameNr_FontHintingPreference 6742
#define sipName_FontHintingPreference &sipStrings_QtGui[6742]
#define sipNameNr_FontLetterSpacingType 6142
#define sipName_FontLetterSpacingType &sipStrings_QtGui[6142]
#define sipNameNr_FuzzyOrientationMatch 9135
#define sipName_FuzzyOrientationMatch &sipStrings_QtGui[9135]
#define sipNameNr_GlyphRunRetrievalFlag 982
#define sipName_GlyphRunRetrievalFlag &sipStrings_QtGui[982]
#define sipNameNr_IncludeTrailingSpaces 9157
#define sipName_IncludeTrailingSpaces &sipStrings_QtGui[9157]
#define sipNameNr_MarkdownDialectGitHub 9179
#define sipName_MarkdownDialectGitHub &sipStrings_QtGui[9179]
#define sipNameNr_MoveToStartOfDocument 9201
#define sipName_MoveToStartOfDocument &sipStrings_QtGui[9201]
#define sipNameNr_OldTextUnderlineColor 9223
#define sipName_OldTextUnderlineColor &sipStrings_QtGui[9223]
#define sipNameNr_PageBreak_AlwaysAfter 9245
#define sipName_PageBreak_AlwaysAfter &sipStrings_QtGui[9245]
#define sipNameNr_PreferTypoLineMetrics 9267
#define sipName_PreferTypoLineMetrics &sipStrings_QtGui[9267]
#define sipNameNr_PreferVerticalHinting 9289
#define sipName_PreferVerticalHinting &sipStrings_QtGui[9289]
#define sipNameNr_QFont__Capitalization 9311
#define sipName_QFont__Capitalization &sipStrings_QtGui[9311]
#define sipNameNr_9333 9333
#define sipName_9333 &sipStrings_QtGui[9333]
#define sipNameNr_QPageSize__PageSizeId 9355
#define sipName_QPageSize__PageSizeId &sipStrings_QtGui[9355]
#define sipNameNr_QPainterPath__Element 9377
#define sipName_QPainterPath__Element &sipStrings_QtGui[9377]
#define sipNameNr_QPlatformSurfaceEvent 9399
#define sipName_QPlatformSurfaceEvent &sipStrings_QtGui[9399]
#define sipNameNr_QSurface__SurfaceType 9421
#define sipName_QSurface__SurfaceType &sipStrings_QtGui[9421]
#define sipNameNr_QTextCursor__MoveMode 9443
#define sipName_QTextCursor__MoveMode &sipStrings_QtGui[9443]
#define sipNameNr_QTextDocument__Stacks 9465
#define sipName_QTextDocument__Stacks &sipStrings_QtGui[9465]
#define sipNameNr_QTextDocumentFragment 9487
#define sipName_QTextDocumentFragment &sipStrings_QtGui[9487]
#define sipNameNr_QTextFormat__Property 9509
#define sipName_QTextFormat__Property &sipStrings_QtGui[9509]
#define sipNameNr_QTextItem__RenderFlag 9531
#define sipName_QTextItem__RenderFlag &sipStrings_QtGui[9531]
#define sipNameNr_QTextOption__WrapMode 9553
#define sipName_QTextOption__WrapMode &sipStrings_QtGui[9553]
#define sipNameNr_QWindow__AncestorMode 9575
#define sipName_QWindow__AncestorMode &sipStrings_QtGui[9575]
#define sipNameNr_RetrieveStringIndexes 9597
#define sipName_RetrieveStringIndexes &sipStrings_QtGui[9597]
#define sipNameNr_SelectStartOfDocument 9619
#define sipName_SelectStartOfDocument &sipStrings_QtGui[9619]
#define sipNameNr_ShowDefaultIgnorables 9641
#define sipName_ShowDefaultIgnorables &sipStrings_QtGui[9641]
#define sipNameNr_SmoothPixmapTransform 9663
#define sipName_SmoothPixmapTransform &sipStrings_QtGui[9663]
#define sipNameNr_TableCellBottomBorder 9685
#define sipName_TableCellBottomBorder &sipStrings_QtGui[9685]
#define sipNameNr_TableCellRightPadding 9707
#define sipName_TableCellRightPadding &sipStrings_QtGui[9707]
#define sipNameNr_TextSubScriptBaseline 9729
#define sipName_TextSubScriptBaseline &sipStrings_QtGui[9729]
#define sipNameNr_TextVerticalAlignment 9751
#define sipName_TextVerticalAlignment &sipStrings_QtGui[9751]
#define sipNameNr_WeatherFewCloudsNight 9773
#define sipName_WeatherFewCloudsNight &sipStrings_QtGui[9773]
#define sipNameNr_accessibleDescription 9795
#define sipName_accessibleDescription &sipStrings_QtGui[9795]
#define sipNameNr_autoDetectImageFormat 9817
#define sipName_autoDetectImageFormat &sipStrings_QtGui[9817]
#define sipNameNr_convertedToColorSpace 9839
#define sipName_convertedToColorSpace &sipStrings_QtGui[9839]
#define sipNameNr_cursorPositionChanged 9861
#define sipName_cursorPositionChanged &sipStrings_QtGui[9861]
#define sipNameNr_deviceIndependentSize 9883
#define sipName_deviceIndependentSize &sipStrings_QtGui[9883]
#define sipNameNr_documentLayoutChanged 9905
#define sipName_documentLayoutChanged &sipStrings_QtGui[9905]
#define sipNameNr_exclusivePointGrabber 9927
#define sipName_exclusivePointGrabber &sipStrings_QtGui[9927]
#define sipNameNr_findBlockByLineNumber 9949
#define sipName_findBlockByLineNumber &sipStrings_QtGui[9949]
#define sipNameNr_fontHintingPreference 9971
#define sipName_fontHintingPreference &sipStrings_QtGui[9971]
#define sipNameNr_fontLetterSpacingType 9993
#define sipName_fontLetterSpacingType &sipStrings_QtGui[9993]
#define sipNameNr_glyphIndexesForString 10015
#define sipName_glyphIndexesForString &sipStrings_QtGui[10015]
#define sipNameNr_inputDirectionChanged 10037
#define sipName_inputDirectionChanged &sipStrings_QtGui[10037]
#define sipNameNr_isValidCursorPosition 10059
#define sipName_isValidCursorPosition &sipStrings_QtGui[10059]
#define sipNameNr_joinPreviousEditBlock 10081
#define sipName_joinPreviousEditBlock &sipStrings_QtGui[10081]
#define sipNameNr_keyboardInputInterval 10103
#define sipName_keyboardInputInterval &sipStrings_QtGui[10103]
#define sipNameNr_mouseDoubleClickEvent 10125
#define sipName_mouseDoubleClickEvent &sipStrings_QtGui[10125]
#define sipNameNr_passwordMaskCharacter 10147
#define sipName_passwordMaskCharacter &sipStrings_QtGui[10147]
#define sipNameNr_primaryPointingDevice 10169
#define sipName_primaryPointingDevice &sipStrings_QtGui[10169]
#define sipNameNr_qPixelFormatGrayscale 10191
#define sipName_qPixelFormatGrayscale &sipStrings_QtGui[10191]
#define sipNameNr_removeApplicationFont 10213
#define sipName_removeApplicationFont &sipStrings_QtGui[10213]
#define sipNameNr_restoreOverrideCursor 10235
#define sipName_restoreOverrideCursor &sipStrings_QtGui[10235]
#define sipNameNr_setContextMenuTrigger 10257
#define sipName_setContextMenuTrigger &sipStrings_QtGui[10257]
#define sipNameNr_setFontCapitalization 10279
#define sipName_setFontCapitalization &sipStrings_QtGui[10279]
#define sipNameNr_setInputItemRectangle 10301
#define sipName_setInputItemRectangle &sipStrings_QtGui[10301]
#define sipNameNr_setInputItemTransform 10323
#define sipName_setInputItemTransform &sipStrings_QtGui[10323]
#define sipNameNr_setNameFilterDisables 10345
#define sipName_setNameFilterDisables &sipStrings_QtGui[10345]
#define sipNameNr_setVerticalHeaderItem 10367
#define sipName_setVerticalHeaderItem &sipStrings_QtGui[10367]
#define sipNameNr_setWorldMatrixEnabled 10389
#define sipName_setWorldMatrixEnabled &sipStrings_QtGui[10389]
#define sipNameNr_singleClickActivation 10411
#define sipName_singleClickActivation &sipStrings_QtGui[10411]
#define sipNameNr_supportedImageFormats 10433
#define sipName_supportedImageFormats &sipStrings_QtGui[10433]
#define sipNameNr_withTransferFunctions 10455
#define sipName_withTransferFunctions &sipStrings_QtGui[10455]
#define sipNameNr_AudioInputMicrophone 10477
#define sipName_AudioInputMicrophone &sipStrings_QtGui[10477]
#define sipNameNr_CompatibilityProfile 10498
#define sipName_CompatibilityProfile &sipStrings_QtGui[10498]
#define sipNameNr_CompositionMode_Plus 10519
#define sipName_CompositionMode_Plus &sipStrings_QtGui[10519]
#define sipNameNr_DirtyCompositionMode 10540
#define sipName_DirtyCompositionMode &sipStrings_QtGui[10540]
#define sipNameNr_DocumentPrintPreview 10561
#define sipName_DocumentPrintPreview &sipStrings_QtGui[10561]
#define sipNameNr_MediaPlaylistShuffle 10582
#define sipName_MediaPlaylistShuffle &sipStrings_QtGui[10582]
#define sipNameNr_OpenGLContextProfile 626
#define sipName_OpenGLContextProfile &sipStrings_QtGui[626]
#define sipNameNr_PerspectiveTransform 10603
#define sipName_PerspectiveTransform &sipStrings_QtGui[10603]
#define sipNameNr_PreferDefaultHinting 10624
#define sipName_PreferDefaultHinting &sipStrings_QtGui[10624]
#define sipNameNr_ProgressiveScanWrite 7779
#define sipName_ProgressiveScanWrite &sipStrings_QtGui[7779]
#define sipNameNr_QAction__ActionEvent 10645
#define sipName_QAction__ActionEvent &sipStrings_QtGui[10645]
#define sipNameNr_QColorConstants__Svg 10666
#define sipName_QColorConstants__Svg &sipStrings_QtGui[10666]
#define sipNameNr_QFont__StyleStrategy 10687
#define sipName_QFont__StyleStrategy &sipStrings_QtGui[10687]
#define sipNameNr_QInputMethod__Action 10708
#define sipName_QInputMethod__Action &sipStrings_QtGui[10708]
#define sipNameNr_10729 10729
#define sipName_10729 &sipStrings_QtGui[10729]
#define sipNameNr_QPainter__RenderHint 10750
#define sipName_QPainter__RenderHint &sipStrings_QtGui[10750]
#define sipNameNr_QPalette__ColorGroup 10771
#define sipName_QPalette__ColorGroup &sipStrings_QtGui[10771]
#define sipNameNr_QRawFont__LayoutFlag 10792
#define sipName_QRawFont__LayoutFlag &sipStrings_QtGui[10792]
#define sipNameNr_QTextBlock__iterator 10813
#define sipName_QTextBlock__iterator &sipStrings_QtGui[10813]
#define sipNameNr_QTextFrame__iterator 10834
#define sipName_QTextFrame__iterator &sipStrings_QtGui[10834]
#define sipNameNr_QTextObjectInterface 10855
#define sipName_QTextObjectInterface &sipStrings_QtGui[10855]
#define sipNameNr_QTextOption__TabType 10876
#define sipName_QTextOption__TabType &sipStrings_QtGui[10876]
#define sipNameNr_QTextTableCellFormat 10897
#define sipName_QTextTableCellFormat &sipStrings_QtGui[10897]
#define sipNameNr_RetrieveGlyphIndexes 10918
#define sipName_RetrieveGlyphIndexes &sipStrings_QtGui[10918]
#define sipNameNr_ScaledPixmapArgument 1190
#define sipName_ScaledPixmapArgument &sipStrings_QtGui[1190]
#define sipNameNr_SmallestReadableFont 10939
#define sipName_SmallestReadableFont &sipStrings_QtGui[10939]
#define sipNameNr_SoftwareUpdateUrgent 10960
#define sipName_SoftwareUpdateUrgent &sipStrings_QtGui[10960]
#define sipNameNr_SubPixelAntialiasing 10981
#define sipName_SubPixelAntialiasing &sipStrings_QtGui[10981]
#define sipNameNr_TableCellLeftPadding 11002
#define sipName_TableCellLeftPadding &sipStrings_QtGui[11002]
#define sipNameNr_TableCellRightBorder 11023
#define sipName_TableCellRightBorder &sipStrings_QtGui[11023]
#define sipNameNr_ThreeComponentMatrix 11044
#define sipName_ThreeComponentMatrix &sipStrings_QtGui[11044]
#define sipNameNr_TransformationMirror 11065
#define sipName_TransformationMirror &sipStrings_QtGui[11065]
#define sipNameNr_acceptProposedAction 11086
#define sipName_acceptProposedAction &sipStrings_QtGui[11086]
#define sipNameNr_activatedAmbiguously 11107
#define sipName_activatedAmbiguously &sipStrings_QtGui[11107]
#define sipNameNr_availableVirtualSize 11128
#define sipName_availableVirtualSize &sipStrings_QtGui[11128]
#define sipNameNr_changeOverrideCursor 11149
#define sipName_changeOverrideCursor &sipStrings_QtGui[11149]
#define sipNameNr_convertFromPlainText 11170
#define sipName_convertFromPlainText &sipStrings_QtGui[11170]
#define sipNameNr_currentBlockUserData 11191
#define sipName_currentBlockUserData &sipStrings_QtGui[11191]
#define sipNameNr_desktopSettingsAware 11212
#define sipName_desktopSettingsAware &sipStrings_QtGui[11212]
#define sipNameNr_horizontalHeaderItem 11233
#define sipName_horizontalHeaderItem &sipStrings_QtGui[11233]
#define sipNameNr_keepPositionOnInsert 11254
#define sipName_keepPositionOnInsert &sipStrings_QtGui[11254]
#define sipNameNr_lengthVectorProperty 11275
#define sipName_lengthVectorProperty &sipStrings_QtGui[11275]
#define sipNameNr_lightgoldenrodyellow 11296
#define sipName_lightgoldenrodyellow &sipStrings_QtGui[11296]
#define sipNameNr_maximumHeightChanged 11317
#define sipName_maximumHeightChanged &sipStrings_QtGui[11317]
#define sipNameNr_mergeBlockCharFormat 11338
#define sipName_mergeBlockCharFormat &sipStrings_QtGui[11338]
#define sipNameNr_minimumHeightChanged 11359
#define sipName_minimumHeightChanged &sipStrings_QtGui[11359]
#define sipNameNr_physicalDotsPerInchX 11380
#define sipName_physicalDotsPerInchX &sipStrings_QtGui[11380]
#define sipNameNr_physicalDotsPerInchY 11401
#define sipName_physicalDotsPerInchY &sipStrings_QtGui[11401]
#define sipNameNr_positionInlineObject 11422
#define sipName_positionInlineObject &sipStrings_QtGui[11422]
#define sipNameNr_primaryScreenChanged 11443
#define sipName_primaryScreenChanged &sipStrings_QtGui[11443]
#define sipNameNr_progressiveScanWrite 11464
#define sipName_progressiveScanWrite &sipStrings_QtGui[11464]
#define sipNameNr_setBottomBorderBrush 11485
#define sipName_setBottomBorderBrush &sipStrings_QtGui[11485]
#define sipNameNr_setBottomBorderStyle 11506
#define sipName_setBottomBorderStyle &sipStrings_QtGui[11506]
#define sipNameNr_setCurrentBlockState 11527
#define sipName_setCurrentBlockState &sipStrings_QtGui[11527]
#define sipNameNr_setCurrentColorGroup 11548
#define sipName_setCurrentColorGroup &sipStrings_QtGui[11548]
#define sipNameNr_setDefaultStyleSheet 11569
#define sipName_setDefaultStyleSheet &sipStrings_QtGui[11569]
#define sipNameNr_setDefaultTextOption 11590
#define sipName_setDefaultTextOption &sipStrings_QtGui[11590]
#define sipNameNr_setElementPositionAt 11611
#define sipName_setElementPositionAt &sipStrings_QtGui[11611]
#define sipNameNr_setFallbackThemeName 11632
#define sipName_setFallbackThemeName &sipStrings_QtGui[11632]
#define sipNameNr_setFontLetterSpacing 11653
#define sipName_setFontLetterSpacing &sipStrings_QtGui[11653]
#define sipNameNr_setFontStyleStrategy 11674
#define sipName_setFontStyleStrategy &sipStrings_QtGui[11674]
#define sipNameNr_setHintingPreference 11695
#define sipName_setHintingPreference &sipStrings_QtGui[11695]
#define sipNameNr_setIconVisibleInMenu 11716
#define sipName_setIconVisibleInMenu &sipStrings_QtGui[11716]
#define sipNameNr_setMaximumBlockCount 11737
#define sipName_setMaximumBlockCount &sipStrings_QtGui[11737]
#define sipNameNr_setNonBreakableLines 11758
#define sipName_setNonBreakableLines &sipStrings_QtGui[11758]
#define sipNameNr_setRegularExpression 11779
#define sipName_setRegularExpression &sipStrings_QtGui[11779]
#define sipNameNr_setStencilBufferSize 11800
#define sipName_setStencilBufferSize &sipStrings_QtGui[11800]
#define sipNameNr_setSubScriptBaseline 11821
#define sipName_setSubScriptBaseline &sipStrings_QtGui[11821]
#define sipNameNr_setTransferFunctions 11842
#define sipName_setTransferFunctions &sipStrings_QtGui[11842]
#define sipNameNr_setVerticalAlignment 11863
#define sipName_setVerticalAlignment &sipStrings_QtGui[11863]
#define sipNameNr_setVerticalMovementX 11884
#define sipName_setVerticalMovementX &sipStrings_QtGui[11884]
#define sipNameNr_startDragTimeChanged 11905
#define sipName_startDragTimeChanged &sipStrings_QtGui[11905]
#define sipNameNr_supportedDragActions 11926
#define sipName_supportedDragActions &sipStrings_QtGui[11926]
#define sipNameNr_supportedDropActions 11947
#define sipName_supportedDropActions &sipStrings_QtGui[11947]
#define sipNameNr_tableCellFormatIndex 11968
#define sipName_tableCellFormatIndex &sipStrings_QtGui[11968]
#define sipNameNr_viewTransformEnabled 11989
#define sipName_viewTransformEnabled &sipStrings_QtGui[11989]
#define sipNameNr_withTransferFunction 12010
#define sipName_withTransferFunction &sipStrings_QtGui[12010]
#define sipNameNr_AutomaticVisibility 12031
#define sipName_AutomaticVisibility &sipStrings_QtGui[12031]
#define sipNameNr_BorderStyle_DotDash 12051
#define sipName_BorderStyle_DotDash &sipStrings_QtGui[12051]
#define sipNameNr_CompositionMode_Xor 12071
#define sipName_CompositionMode_Xor &sipStrings_QtGui[12071]
#define sipNameNr_ConicalGradientFill 12091
#define sipName_ConicalGradientFill &sipStrings_QtGui[12091]
#define sipNameNr_CurrentSystemEndian 12111
#define sipName_CurrentSystemEndian &sipStrings_QtGui[12111]
#define sipNameNr_DefaultSwapBehavior 12131
#define sipName_DefaultSwapBehavior &sipStrings_QtGui[12131]
#define sipNameNr_DeprecatedFunctions 12151
#define sipName_DeprecatedFunctions &sipStrings_QtGui[12151]
#define sipNameNr_DirtyBackgroundMode 12171
#define sipName_DirtyBackgroundMode &sipStrings_QtGui[12171]
#define sipNameNr_DisableEmojiParsing 12191
#define sipName_DisableEmojiParsing &sipStrings_QtGui[12191]
#define sipNameNr_DontResolveSymlinks 12211
#define sipName_DontResolveSymlinks &sipStrings_QtGui[12211]
#define sipNameNr_DontWatchForChanges 12231
#define sipName_DontWatchForChanges &sipStrings_QtGui[12231]
#define sipNameNr_FindCaseSensitively 12251
#define sipName_FindCaseSensitively &sipStrings_QtGui[12251]
#define sipNameNr_FormatJustifyCenter 12271
#define sipName_FormatJustifyCenter &sipStrings_QtGui[12271]
#define sipNameNr_FormatTextUnderline 12291
#define sipName_FormatTextUnderline &sipStrings_QtGui[12291]
#define sipNameNr_ImageTransformation 12311
#define sipName_ImageTransformation &sipStrings_QtGui[12311]
#define sipNameNr_InsertLineSeparator 12331
#define sipName_InsertLineSeparator &sipStrings_QtGui[12331]
#define sipNameNr_MediaPlaylistRepeat 12351
#define sipName_MediaPlaylistRepeat &sipStrings_QtGui[12351]
#define sipNameNr_MoveToEndOfDocument 12371
#define sipName_MoveToEndOfDocument &sipStrings_QtGui[12371]
#define sipNameNr_NoSubpixelAntialias 12391
#define sipName_NoSubpixelAntialias &sipStrings_QtGui[12391]
#define sipNameNr_PdmDevicePixelRatio 12411
#define sipName_PdmDevicePixelRatio &sipStrings_QtGui[12411]
#define sipNameNr_QAccessibilityHints 12431
#define sipName_QAccessibilityHints &sipStrings_QtGui[12431]
#define sipNameNr_12451 12451
#define sipName_12451 &sipStrings_QtGui[12451]
#define sipNameNr_QNativeGestureEvent 12471
#define sipName_QNativeGestureEvent &sipStrings_QtGui[12471]
#define sipNameNr_QOpenGLContextGroup 12491
#define sipName_QOpenGLContextGroup &sipStrings_QtGui[12491]
#define sipNameNr_QPainterPathStroker 12511
#define sipName_QPainterPathStroker &sipStrings_QtGui[12511]
#define sipNameNr_QPalette__ColorRole 12531
#define sipName_QPalette__ColorRole &sipStrings_QtGui[12531]
#define sipNameNr_QRegion__RegionType 12551
#define sipName_QRegion__RegionType &sipStrings_QtGui[12551]
#define sipNameNr_QScrollPrepareEvent 12571
#define sipName_QScrollPrepareEvent &sipStrings_QtGui[12571]
#define sipNameNr_QTextDocumentWriter 12591
#define sipName_QTextDocumentWriter &sipStrings_QtGui[12591]
#define sipNameNr_QWaylandApplication 479
#define sipName_QWaylandApplication &sipStrings_QtGui[479]
#define sipNameNr_QWindow__Visibility 12611
#define sipName_QWindow__Visibility &sipStrings_QtGui[12611]
#define sipNameNr_SelectEndOfDocument 12631
#define sipName_SelectEndOfDocument &sipStrings_QtGui[12631]
#define sipNameNr_SpellCheckUnderline 12651
#define sipName_SpellCheckUnderline &sipStrings_QtGui[12651]
#define sipNameNr_StretchToDeviceMode 12671
#define sipName_StretchToDeviceMode &sipStrings_QtGui[12671]
#define sipNameNr_TableBorderCollapse 12691
#define sipName_TableBorderCollapse &sipStrings_QtGui[12691]
#define sipNameNr_TableCellColumnSpan 8912
#define sipName_TableCellColumnSpan &sipStrings_QtGui[8912]
#define sipNameNr_TableCellLeftBorder 12711
#define sipName_TableCellLeftBorder &sipStrings_QtGui[12711]
#define sipNameNr_TableCellTopPadding 12731
#define sipName_TableCellTopPadding &sipStrings_QtGui[12731]
#define sipNameNr_TableHeaderRowCount 12751
#define sipName_TableHeaderRowCount &sipStrings_QtGui[12751]
#define sipNameNr_applyColorTransform 12771
#define sipName_applyColorTransform &sipStrings_QtGui[12771]
#define sipNameNr_beginNativePainting 12791
#define sipName_beginNativePainting &sipStrings_QtGui[12791]
#define sipNameNr_brushNeedsResolving 12811
#define sipName_brushNeedsResolving &sipStrings_QtGui[12811]
#define sipNameNr_capabilitiesChanged 12831
#define sipName_capabilitiesChanged &sipStrings_QtGui[12831]
#define sipNameNr_clearUndoRedoStacks 12851
#define sipName_clearUndoRedoStacks &sipStrings_QtGui[12851]
#define sipNameNr_convertToColorSpace 12871
#define sipName_convertToColorSpace &sipStrings_QtGui[12871]
#define sipNameNr_createHeuristicMask 12891
#define sipName_createHeuristicMask &sipStrings_QtGui[12891]
#define sipNameNr_createMaskFromColor 12911
#define sipName_createMaskFromColor &sipStrings_QtGui[12911]
#define sipNameNr_currentContextGroup 12931
#define sipName_currentContextGroup &sipStrings_QtGui[12931]
#define sipNameNr_documentSizeChanged 12951
#define sipName_documentSizeChanged &sipStrings_QtGui[12951]
#define sipNameNr_documentXmpMetadata 12971
#define sipName_documentXmpMetadata &sipStrings_QtGui[12971]
#define sipNameNr_drawPixmapFragments 12991
#define sipName_drawPixmapFragments &sipStrings_QtGui[12991]
#define sipNameNr_fallbackSearchPaths 13011
#define sipName_fallbackSearchPaths &sipStrings_QtGui[13011]
#define sipNameNr_firstCursorPosition 13031
#define sipName_firstCursorPosition &sipStrings_QtGui[13031]
#define sipNameNr_fontDatabaseChanged 13051
#define sipName_fontDatabaseChanged &sipStrings_QtGui[13051]
#define sipNameNr_globalPressPosition 13071
#define sipName_globalPressPosition &sipStrings_QtGui[13071]
#define sipNameNr_hasComplexSelection 13091
#define sipName_hasComplexSelection &sipStrings_QtGui[13091]
#define sipNameNr_insertSubstitutions 13111
#define sipName_insertSubstitutions &sipStrings_QtGui[13111]
#define sipNameNr_isIconVisibleInMenu 13131
#define sipName_isIconVisibleInMenu &sipStrings_QtGui[13131]
#define sipNameNr_lineForTextPosition 13151
#define sipName_lineForTextPosition &sipStrings_QtGui[13151]
#define sipNameNr_logicalDotsPerInchX 13171
#define sipName_logicalDotsPerInchX &sipStrings_QtGui[13171]
#define sipNameNr_logicalDotsPerInchY 13191
#define sipName_logicalDotsPerInchY &sipStrings_QtGui[13191]
#define sipNameNr_maximumWidthChanged 13211
#define sipName_maximumWidthChanged &sipStrings_QtGui[13211]
#define sipNameNr_minimumWidthChanged 13231
#define sipName_minimumWidthChanged &sipStrings_QtGui[13231]
#define sipNameNr_modificationChanged 13251
#define sipName_modificationChanged &sipStrings_QtGui[13251]
#define sipNameNr_physicalDotsPerInch 13271
#define sipName_physicalDotsPerInch &sipStrings_QtGui[13271]
#define sipNameNr_physicalSizeChanged 13291
#define sipName_physicalSizeChanged &sipStrings_QtGui[13291]
#define sipNameNr_preeditAreaPosition 13311
#define sipName_preeditAreaPosition &sipStrings_QtGui[13311]
#define sipNameNr_reinterpretAsFormat 13331
#define sipName_reinterpretAsFormat &sipStrings_QtGui[13331]
#define sipNameNr_removeSubstitutions 13351
#define sipName_removeSubstitutions &sipStrings_QtGui[13351]
#define sipNameNr_rightCursorPosition 13371
#define sipName_rightCursorPosition &sipStrings_QtGui[13371]
#define sipNameNr_setDevicePixelRatio 13391
#define sipName_setDevicePixelRatio &sipStrings_QtGui[13391]
#define sipNameNr_setFontVariableAxes 13411
#define sipName_setFontVariableAxes &sipStrings_QtGui[13411]
#define sipNameNr_setMouseGrabEnabled 13431
#define sipName_setMouseGrabEnabled &sipStrings_QtGui[13431]
#define sipNameNr_setResourceProvider 13451
#define sipName_setResourceProvider &sipStrings_QtGui[13451]
#define sipNameNr_setRightBorderBrush 13471
#define sipName_setRightBorderBrush &sipStrings_QtGui[13471]
#define sipNameNr_setRightBorderStyle 13491
#define sipName_setRightBorderStyle &sipStrings_QtGui[13491]
#define sipNameNr_setTableCellRowSpan 13511
#define sipName_setTableCellRowSpan &sipStrings_QtGui[13511]
#define sipNameNr_setThemeSearchPaths 13531
#define sipName_setThemeSearchPaths &sipStrings_QtGui[13531]
#define sipNameNr_setTransferFunction 13551
#define sipName_setTransferFunction &sipStrings_QtGui[13551]
#define sipNameNr_setUseDesignMetrics 13571
#define sipName_setUseDesignMetrics &sipStrings_QtGui[13571]
#define sipNameNr_setVisualNavigation 13591
#define sipName_setVisualNavigation &sipStrings_QtGui[13591]
#define sipNameNr_superScriptBaseline 13611
#define sipName_superScriptBaseline &sipStrings_QtGui[13611]
#define sipNameNr_tableCellColumnSpan 13631
#define sipName_tableCellColumnSpan &sipStrings_QtGui[13631]
#define sipNameNr_writingSystemSample 13651
#define sipName_writingSystemSample &sipStrings_QtGui[13651]
#define sipNameNr_AlphaPremultiplied 1524
#define sipName_AlphaPremultiplied &sipStrings_QtGui[1524]
#define sipNameNr_BackgroundImageUrl 13671
#define sipName_BackgroundImageUrl &sipStrings_QtGui[13671]
#define sipNameNr_BorderStyle_Dashed 13690
#define sipName_BorderStyle_Dashed &sipStrings_QtGui[13690]
#define sipNameNr_BorderStyle_Dotted 13709
#define sipName_BorderStyle_Dotted &sipStrings_QtGui[13709]
#define sipNameNr_BorderStyle_Double 13728
#define sipName_BorderStyle_Double &sipStrings_QtGui[13728]
#define sipNameNr_BorderStyle_Groove 13747
#define sipName_BorderStyle_Groove &sipStrings_QtGui[13747]
#define sipNameNr_BorderStyle_Outset 13766
#define sipName_BorderStyle_Outset &sipStrings_QtGui[13766]
#define sipNameNr_ContextFontMerging 13785
#define sipName_ContextFontMerging &sipStrings_QtGui[13785]
#define sipNameNr_CurveToDataElement 13804
#define sipName_CurveToDataElement &sipStrings_QtGui[13804]
#define sipNameNr_DeleteCompleteLine 13823
#define sipName_DeleteCompleteLine &sipStrings_QtGui[13823]
#define sipNameNr_DocumentOpenRecent 13842
#define sipName_DocumentOpenRecent &sipStrings_QtGui[13842]
#define sipNameNr_DocumentProperties 13861
#define sipName_DocumentProperties &sipStrings_QtGui[13861]
#define sipNameNr_FanFoldGermanLegal 13880
#define sipName_FanFoldGermanLegal &sipStrings_QtGui[13880]
#define sipNameNr_FontCapitalization 10282
#define sipName_FontCapitalization &sipStrings_QtGui[10282]
#define sipNameNr_FontSizeAdjustment 13899
#define sipName_FontSizeAdjustment &sipStrings_QtGui[13899]
#define sipNameNr_FormatJustifyRight 13918
#define sipName_FormatJustifyRight &sipStrings_QtGui[13918]
#define sipNameNr_Format_Grayscale16 13937
#define sipName_Format_Grayscale16 &sipStrings_QtGui[13937]
#define sipNameNr_FullWidthSelection 13956
#define sipName_FullWidthSelection &sipStrings_QtGui[13956]
#define sipNameNr_IncrementalReading 13975
#define sipName_IncrementalReading &sipStrings_QtGui[13975]
#define sipNameNr_LineDistanceHeight 13994
#define sipName_LineDistanceHeight &sipStrings_QtGui[13994]
#define sipNameNr_LinearGradientFill 14013
#define sipName_LinearGradientFill &sipStrings_QtGui[14013]
#define sipNameNr_MediaPlaybackPause 14032
#define sipName_MediaPlaybackPause &sipStrings_QtGui[14032]
#define sipNameNr_MediaPlaybackStart 14051
#define sipName_MediaPlaybackStart &sipStrings_QtGui[14051]
#define sipNameNr_MoveToPreviousChar 14070
#define sipName_MoveToPreviousChar &sipStrings_QtGui[14070]
#define sipNameNr_MoveToPreviousLine 14089
#define sipName_MoveToPreviousLine &sipStrings_QtGui[14089]
#define sipNameNr_MoveToPreviousPage 14108
#define sipName_MoveToPreviousPage &sipStrings_QtGui[14108]
#define sipNameNr_MoveToPreviousWord 14127
#define sipName_MoveToPreviousWord &sipStrings_QtGui[14127]
#define sipNameNr_MoveToStartOfBlock 14146
#define sipName_MoveToStartOfBlock &sipStrings_QtGui[14146]
#define sipNameNr_NormalizedPosition 14165
#define sipName_NormalizedPosition &sipStrings_QtGui[14165]
#define sipNameNr_ObjectBoundingMode 14184
#define sipName_ObjectBoundingMode &sipStrings_QtGui[14184]
#define sipNameNr_PaintEngineFeature 1458
#define sipName_PaintEngineFeature &sipStrings_QtGui[1458]
#define sipNameNr_PixmapFragmentHint 3720
#define sipName_PixmapFragmentHint &sipStrings_QtGui[3720]
#define sipNameNr_PrimitiveTransform 14203
#define sipName_PrimitiveTransform &sipStrings_QtGui[14203]
#define sipNameNr_ProportionalHeight 14222
#define sipName_ProportionalHeight &sipStrings_QtGui[14222]
#define sipNameNr_QColor__NameFormat 14241
#define sipName_QColor__NameFormat &sipStrings_QtGui[14241]
#define sipNameNr_QEventPoint__State 14260
#define sipName_QEventPoint__State &sipStrings_QtGui[14260]
#define sipNameNr_QFont__SpacingType 14279
#define sipName_QFont__SpacingType &sipStrings_QtGui[14279]
#define sipNameNr_QImage__InvertMode 14298
#define sipName_QImage__InvertMode &sipStrings_QtGui[14298]
#define sipNameNr_14317 14317
#define sipName_14317 &sipStrings_QtGui[14317]
#define sipNameNr_14336 14336
#define sipName_14336 &sipStrings_QtGui[14336]
#define sipNameNr_14355 14355
#define sipName_14355 &sipStrings_QtGui[14355]
#define sipNameNr_14374 14374
#define sipName_14374 &sipStrings_QtGui[14374]
#define sipNameNr_14393 14393
#define sipName_14393 &sipStrings_QtGui[14393]
#define sipNameNr_QMovie__MovieState 14412
#define sipName_QMovie__MovieState &sipStrings_QtGui[14412]
#define sipNameNr_QPageRanges__Range 14431
#define sipName_QPageRanges__Range &sipStrings_QtGui[14431]
#define sipNameNr_QPaintDeviceWindow 14450
#define sipName_QPaintDeviceWindow &sipStrings_QtGui[14450]
#define sipNameNr_QPaintEngine__Type 14469
#define sipName_QPaintEngine__Type &sipStrings_QtGui[14469]
#define sipNameNr_QPainterStateGuard 14488
#define sipName_QPainterStateGuard &sipStrings_QtGui[14488]
#define sipNameNr_QStandardItemModel 14507
#define sipName_QStandardItemModel &sipStrings_QtGui[14507]
#define sipNameNr_QSyntaxHighlighter 14526
#define sipName_QSyntaxHighlighter &sipStrings_QtGui[14526]
#define sipNameNr_QTextBlockUserData 14545
#define sipName_QTextBlockUserData &sipStrings_QtGui[14545]
#define sipNameNr_RadialGradientFill 14564
#define sipName_RadialGradientFill &sipStrings_QtGui[14564]
#define sipNameNr_RasterOp_NotSource 14583
#define sipName_RasterOp_NotSource &sipStrings_QtGui[14583]
#define sipNameNr_RestartImmediately 14602
#define sipName_RestartImmediately &sipStrings_QtGui[14602]
#define sipNameNr_ScientificNotation 14621
#define sipName_ScientificNotation &sipStrings_QtGui[14621]
#define sipNameNr_SelectPreviousChar 14640
#define sipName_SelectPreviousChar &sipStrings_QtGui[14640]
#define sipNameNr_SelectPreviousLine 14659
#define sipName_SelectPreviousLine &sipStrings_QtGui[14659]
#define sipNameNr_SelectPreviousPage 14678
#define sipName_SelectPreviousPage &sipStrings_QtGui[14678]
#define sipNameNr_SelectPreviousWord 14697
#define sipName_SelectPreviousWord &sipStrings_QtGui[14697]
#define sipNameNr_SelectStartOfBlock 14716
#define sipName_SelectStartOfBlock &sipStrings_QtGui[14716]
#define sipNameNr_StyleSheetResource 14735
#define sipName_StyleSheetResource &sipStrings_QtGui[14735]
#define sipNameNr_TableCellTopBorder 14754
#define sipName_TableCellTopBorder &sipStrings_QtGui[14754]
#define sipNameNr_TangentialPressure 14773
#define sipName_TangentialPressure &sipStrings_QtGui[14773]
#define sipNameNr_TextBaselineOffset 14792
#define sipName_TextBaselineOffset &sipStrings_QtGui[14792]
#define sipNameNr_TextUnderlineColor 9226
#define sipName_TextUnderlineColor &sipStrings_QtGui[9226]
#define sipNameNr_TextUnderlineStyle 14811
#define sipName_TextUnderlineStyle &sipStrings_QtGui[14811]
#define sipNameNr_ToolsCheckSpelling 14830
#define sipName_ToolsCheckSpelling &sipStrings_QtGui[14830]
#define sipNameNr_TraditionalChinese 14849
#define sipName_TraditionalChinese &sipStrings_QtGui[14849]
#define sipNameNr_TransformationFlip 14868
#define sipName_TransformationFlip &sipStrings_QtGui[14868]
#define sipNameNr_TransformationNone 14887
#define sipName_TransformationNone &sipStrings_QtGui[14887]
#define sipNameNr_TransformationType 2676
#define sipName_TransformationType &sipStrings_QtGui[2676]
#define sipNameNr_TypeInterpretation 1557
#define sipName_TypeInterpretation &sipStrings_QtGui[1557]
#define sipNameNr_aboutToBeDestroyed 14906
#define sipName_aboutToBeDestroyed &sipStrings_QtGui[14906]
#define sipNameNr_activeStackChanged 14925
#define sipName_activeStackChanged &sipStrings_QtGui[14925]
#define sipNameNr_addApplicationFont 14944
#define sipName_addApplicationFont &sipStrings_QtGui[14944]
#define sipNameNr_availableRedoSteps 14963
#define sipName_availableRedoSteps &sipStrings_QtGui[14963]
#define sipNameNr_availableUndoSteps 14982
#define sipName_availableUndoSteps &sipStrings_QtGui[14982]
#define sipNameNr_blockFormatChanged 15001
#define sipName_blockFormatChanged &sipStrings_QtGui[15001]
#define sipNameNr_colorSchemeChanged 15020
#define sipName_colorSchemeChanged &sipStrings_QtGui[15020]
#define sipNameNr_contentOrientation 15039
#define sipName_contentOrientation &sipStrings_QtGui[15039]
#define sipNameNr_contextMenuTrigger 15058
#define sipName_contextMenuTrigger &sipStrings_QtGui[15058]
#define sipNameNr_contrastPreference 15077
#define sipName_contrastPreference &sipStrings_QtGui[15077]
#define sipNameNr_currentFrameNumber 15096
#define sipName_currentFrameNumber &sipStrings_QtGui[15096]
#define sipNameNr_currentImageNumber 15115
#define sipName_currentImageNumber &sipStrings_QtGui[15115]
#define sipNameNr_deletePreviousChar 15134
#define sipName_deletePreviousChar &sipStrings_QtGui[15134]
#define sipNameNr_focusObjectChanged 15153
#define sipName_focusObjectChanged &sipStrings_QtGui[15153]
#define sipNameNr_focusWindowChanged 15172
#define sipName_focusWindowChanged &sipStrings_QtGui[15172]
#define sipNameNr_fontCapitalization 15191
#define sipName_fontCapitalization &sipStrings_QtGui[15191]
#define sipNameNr_fontSmoothingGamma 15210
#define sipName_fontSmoothingGamma &sipStrings_QtGui[15210]
#define sipNameNr_fromRotationMatrix 15229
#define sipName_fromRotationMatrix &sipStrings_QtGui[15229]
#define sipNameNr_globalGrabPosition 15248
#define sipName_globalGrabPosition &sipStrings_QtGui[15248]
#define sipNameNr_globalLastPosition 15267
#define sipName_globalLastPosition &sipStrings_QtGui[15267]
#define sipNameNr_globalShareContext 15286
#define sipName_globalShareContext &sipStrings_QtGui[15286]
#define sipNameNr_inputItemRectangle 15305
#define sipName_inputItemRectangle &sipStrings_QtGui[15305]
#define sipNameNr_inputItemTransform 15324
#define sipName_inputItemTransform &sipStrings_QtGui[15324]
#define sipNameNr_insertSubstitution 15343
#define sipName_insertSubstitution &sipStrings_QtGui[15343]
#define sipNameNr_isSmoothlyScalable 15362
#define sipName_isSmoothlyScalable &sipStrings_QtGui[15362]
#define sipNameNr_lastCursorPosition 15381
#define sipName_lastCursorPosition &sipStrings_QtGui[15381]
#define sipNameNr_leftCursorPosition 15400
#define sipName_leftCursorPosition &sipStrings_QtGui[15400]
#define sipNameNr_logicalDotsPerInch 15419
#define sipName_logicalDotsPerInch &sipStrings_QtGui[15419]
#define sipNameNr_menuSelectionWraps 15438
#define sipName_menuSelectionWraps &sipStrings_QtGui[15438]
#define sipNameNr_nameFilterDisables 15457
#define sipName_nameFilterDisables &sipStrings_QtGui[15457]
#define sipNameNr_nextCursorPosition 15476
#define sipName_nextCursorPosition &sipStrings_QtGui[15476]
#define sipNameNr_normalizedPosition 15495
#define sipName_normalizedPosition &sipStrings_QtGui[15495]
#define sipNameNr_orientationChanged 15514
#define sipName_orientationChanged &sipStrings_QtGui[15514]
#define sipNameNr_previousBlockState 15533
#define sipName_previousBlockState &sipStrings_QtGui[15533]
#define sipNameNr_primaryOrientation 15552
#define sipName_primaryOrientation &sipStrings_QtGui[15552]
#define sipNameNr_refreshRateChanged 15571
#define sipName_refreshRateChanged &sipStrings_QtGui[15571]
#define sipNameNr_removeSelectedText 15590
#define sipName_removeSelectedText &sipStrings_QtGui[15590]
#define sipNameNr_resizeInlineObject 15609
#define sipName_resizeInlineObject &sipStrings_QtGui[15609]
#define sipNameNr_scenePressPosition 15628
#define sipName_scenePressPosition &sipStrings_QtGui[15628]
#define sipNameNr_selectedTableCells 15647
#define sipName_selectedTableCells &sipStrings_QtGui[15647]
#define sipNameNr_setAllocationLimit 15666
#define sipName_setAllocationLimit &sipStrings_QtGui[15666]
#define sipNameNr_setAlphaBufferSize 15685
#define sipName_setAlphaBufferSize &sipStrings_QtGui[15685]
#define sipNameNr_setBackgroundColor 15704
#define sipName_setBackgroundColor &sipStrings_QtGui[15704]
#define sipNameNr_setBlockCharFormat 15723
#define sipName_setBlockCharFormat &sipStrings_QtGui[15723]
#define sipNameNr_setCompositionMode 15742
#define sipName_setCompositionMode &sipStrings_QtGui[15742]
#define sipNameNr_setContentPosRange 15761
#define sipName_setContentPosRange &sipStrings_QtGui[15761]
#define sipNameNr_setCursorMoveStyle 15780
#define sipName_setCursorMoveStyle &sipStrings_QtGui[15780]
#define sipNameNr_setDepthBufferSize 15799
#define sipName_setDepthBufferSize &sipStrings_QtGui[15799]
#define sipNameNr_setDesktopFileName 15818
#define sipName_setDesktopFileName &sipStrings_QtGui[15818]
#define sipNameNr_setExclusionPolicy 15837
#define sipName_setExclusionPolicy &sipStrings_QtGui[15837]
#define sipNameNr_setFontWordSpacing 15856
#define sipName_setFontWordSpacing &sipStrings_QtGui[15856]
#define sipNameNr_setGreenBufferSize 15875
#define sipName_setGreenBufferSize &sipStrings_QtGui[15875]
#define sipNameNr_setLayoutDirection 15894
#define sipName_setLayoutDirection &sipStrings_QtGui[15894]
#define sipNameNr_setLeadingIncluded 15913
#define sipName_setLeadingIncluded &sipStrings_QtGui[15913]
#define sipNameNr_setLeftBorderBrush 15932
#define sipName_setLeftBorderBrush &sipStrings_QtGui[15932]
#define sipNameNr_setLeftBorderStyle 15951
#define sipName_setLeftBorderStyle &sipStrings_QtGui[15951]
#define sipNameNr_setManagerProperty 15970
#define sipName_setManagerProperty &sipStrings_QtGui[15970]
#define sipNameNr_setMetaInformation 15989
#define sipName_setMetaInformation &sipStrings_QtGui[15989]
#define sipNameNr_setOutputCondition 16008
#define sipName_setOutputCondition &sipStrings_QtGui[16008]
#define sipNameNr_setPageBreakPolicy 16027
#define sipName_setPageBreakPolicy &sipStrings_QtGui[16027]
#define sipNameNr_setPageOrientation 16046
#define sipName_setPageOrientation &sipStrings_QtGui[16046]
#define sipNameNr_setPerformanceHint 16065
#define sipName_setPerformanceHint &sipStrings_QtGui[16065]
#define sipNameNr_setResolveSymlinks 16084
#define sipName_setResolveSymlinks &sipStrings_QtGui[16084]
#define sipNameNr_setShortcutContext 16103
#define sipName_setShortcutContext &sipStrings_QtGui[16103]
#define sipNameNr_setTabStopDistance 16122
#define sipName_setTabStopDistance &sipStrings_QtGui[16122]
#define sipNameNr_setTransientParent 16141
#define sipName_setTransientParent &sipStrings_QtGui[16141]
#define sipNameNr_setUndoRedoEnabled 16160
#define sipName_setUndoRedoEnabled &sipStrings_QtGui[16160]
#define sipNameNr_setUseHoverEffects 16179
#define sipName_setUseHoverEffects &sipStrings_QtGui[16179]
#define sipNameNr_supportedMimeTypes 16198
#define sipName_supportedMimeTypes &sipStrings_QtGui[16198]
#define sipNameNr_supportsFindBuffer 16217
#define sipName_supportsFindBuffer &sipStrings_QtGui[16217]
#define sipNameNr_tangentialPressure 16236
#define sipName_tangentialPressure &sipStrings_QtGui[16236]
#define sipNameNr_typeInterpretation 16255
#define sipName_typeInterpretation &sipStrings_QtGui[16255]
#define sipNameNr_verticalHeaderItem 16274
#define sipName_verticalHeaderItem &sipStrings_QtGui[16274]
#define sipNameNr_windowStateChanged 16293
#define sipName_windowStateChanged &sipStrings_QtGui[16293]
#define sipNameNr_windowTitleChanged 16312
#define sipName_windowTitleChanged &sipStrings_QtGui[16312]
#define sipNameNr_worldMatrixEnabled 16331
#define sipName_worldMatrixEnabled &sipStrings_QtGui[16331]
#define sipNameNr_AggressiveCaching 16350
#define sipName_AggressiveCaching &sipStrings_QtGui[16350]
#define sipNameNr_AppointmentMissed 16368
#define sipName_AppointmentMissed &sipStrings_QtGui[16368]
#define sipNameNr_AudioVolumeMedium 16386
#define sipName_AudioVolumeMedium &sipStrings_QtGui[16386]
#define sipNameNr_BlockBottomMargin 16404
#define sipName_BlockBottomMargin &sipStrings_QtGui[16404]
#define sipNameNr_BlockCodeLanguage 16422
#define sipName_BlockCodeLanguage &sipStrings_QtGui[16422]
#define sipNameNr_BorderStyle_Inset 16440
#define sipName_BorderStyle_Inset &sipStrings_QtGui[16440]
#define sipNameNr_BorderStyle_Ridge 16458
#define sipName_BorderStyle_Ridge &sipStrings_QtGui[16458]
#define sipNameNr_BorderStyle_Solid 16476
#define sipName_BorderStyle_Solid &sipStrings_QtGui[16476]
#define sipNameNr_CursorOnCharacter 16494
#define sipName_CursorOnCharacter &sipStrings_QtGui[16494]
#define sipNameNr_DeleteStartOfWord 16512
#define sipName_DeleteStartOfWord &sipStrings_QtGui[16512]
#define sipNameNr_DialogInformation 16530
#define sipName_DialogInformation &sipStrings_QtGui[16530]
#define sipNameNr_DocumentPageSetup 16548
#define sipName_DocumentPageSetup &sipStrings_QtGui[16548]
#define sipNameNr_ExcludeTransients 16566
#define sipName_ExcludeTransients &sipStrings_QtGui[16566]
#define sipNameNr_ExclusiveOptional 16584
#define sipName_ExclusiveOptional &sipStrings_QtGui[16584]
#define sipNameNr_ExecutiveStandard 16602
#define sipName_ExecutiveStandard &sipStrings_QtGui[16602]
#define sipNameNr_FileNotFoundError 16620
#define sipName_FileNotFoundError &sipStrings_QtGui[16620]
#define sipNameNr_FirstFontProperty 16638
#define sipName_FirstFontProperty &sipStrings_QtGui[16638]
#define sipNameNr_FontLetterSpacing 11656
#define sipName_FontLetterSpacing &sipStrings_QtGui[11656]
#define sipNameNr_FontPropertiesAll 16656
#define sipName_FontPropertiesAll &sipStrings_QtGui[16656]
#define sipNameNr_FontSizeIncrement 16674
#define sipName_FontSizeIncrement &sipStrings_QtGui[16674]
#define sipNameNr_FontStyleStrategy 11677
#define sipName_FontStyleStrategy &sipStrings_QtGui[11677]
#define sipNameNr_FormatJustifyFill 16692
#define sipName_FormatJustifyFill &sipStrings_QtGui[16692]
#define sipNameNr_FormatJustifyLeft 16710
#define sipName_FormatJustifyLeft &sipStrings_QtGui[16710]
#define sipNameNr_Format_Grayscale8 16728
#define sipName_Format_Grayscale8 &sipStrings_QtGui[16728]
#define sipNameNr_Format_RGBA16FPx4 16746
#define sipName_Format_RGBA16FPx4 &sipStrings_QtGui[16746]
#define sipNameNr_Format_RGBA32FPx4 16764
#define sipName_Format_RGBA32FPx4 &sipStrings_QtGui[16764]
#define sipNameNr_Format_RGBX16FPx4 16782
#define sipName_Format_RGBX16FPx4 &sipStrings_QtGui[16782]
#define sipNameNr_Format_RGBX32FPx4 16800
#define sipName_Format_RGBX32FPx4 &sipStrings_QtGui[16800]
#define sipNameNr_FrameBottomMargin 16818
#define sipName_FrameBottomMargin &sipStrings_QtGui[16818]
#define sipNameNr_HintingPreference 6196
#define sipName_HintingPreference &sipStrings_QtGui[6196]
#define sipNameNr_IncludeTransients 16836
#define sipName_IncludeTransients &sipStrings_QtGui[16836]
#define sipNameNr_InvalidImageError 16854
#define sipName_InvalidImageError &sipStrings_QtGui[16854]
#define sipNameNr_MailMarkImportant 16872
#define sipName_MailMarkImportant &sipStrings_QtGui[16872]
#define sipNameNr_MediaPlaybackStop 16890
#define sipName_MediaPlaybackStop &sipStrings_QtGui[16890]
#define sipNameNr_MediaSeekBackward 16908
#define sipName_MediaSeekBackward &sipStrings_QtGui[16908]
#define sipNameNr_MediaSkipBackward 16926
#define sipName_MediaSkipBackward &sipStrings_QtGui[16926]
#define sipNameNr_MoveToStartOfLine 16944
#define sipName_MoveToStartOfLine &sipStrings_QtGui[16944]
#define sipNameNr_ObjectRotateRight 16962
#define sipName_ObjectRotateRight &sipStrings_QtGui[16962]
#define sipNameNr_OutOfBoundsPolicy 2553
#define sipName_OutOfBoundsPolicy &sipStrings_QtGui[2553]
#define sipNameNr_PaintDeviceMetric 2141
#define sipName_PaintDeviceMetric &sipStrings_QtGui[2141]
#define sipNameNr_PercentageSpacing 16980
#define sipName_PercentageSpacing &sipStrings_QtGui[16980]
#define sipNameNr_PixelAntialiasing 10984
#define sipName_PixelAntialiasing &sipStrings_QtGui[10984]
#define sipNameNr_PreferFullHinting 16998
#define sipName_PreferFullHinting &sipStrings_QtGui[16998]
#define sipNameNr_PreviousCharacter 17016
#define sipName_PreviousCharacter &sipStrings_QtGui[17016]
#define sipNameNr_QAction__MenuRole 17034
#define sipName_QAction__MenuRole &sipStrings_QtGui[17034]
#define sipNameNr_QAction__Priority 17052
#define sipName_QAction__Priority &sipStrings_QtGui[17052]
#define sipNameNr_QChildWindowEvent 17070
#define sipName_QChildWindowEvent &sipStrings_QtGui[17070]
#define sipNameNr_QContextMenuEvent 17088
#define sipName_QContextMenuEvent &sipStrings_QtGui[17088]
#define sipNameNr_QFontVariableAxis 17106
#define sipName_QFontVariableAxis &sipStrings_QtGui[17106]
#define sipNameNr_QGradient__Preset 17124
#define sipName_QGradient__Preset &sipStrings_QtGui[17124]
#define sipNameNr_QGradient__Spread 17142
#define sipName_QGradient__Spread &sipStrings_QtGui[17142]
#define sipNameNr_QInputMethodEvent 17160
#define sipName_QInputMethodEvent &sipStrings_QtGui[17160]
#define sipNameNr_17178 17178
#define sipName_17178 &sipStrings_QtGui[17178]
#define sipNameNr_17196 17196
#define sipName_17196 &sipStrings_QtGui[17196]
#define sipNameNr_QMovie__CacheMode 17214
#define sipName_QMovie__CacheMode &sipStrings_QtGui[17214]
#define sipNameNr_QOffscreenSurface 17232
#define sipName_QOffscreenSurface &sipStrings_QtGui[17232]
#define sipNameNr_QPageLayout__Mode 17250
#define sipName_QPageLayout__Mode &sipStrings_QtGui[17250]
#define sipNameNr_QPageLayout__Unit 17268
#define sipName_QPageLayout__Unit &sipStrings_QtGui[17268]
#define sipNameNr_QPagedPaintDevice 17286
#define sipName_QPagedPaintDevice &sipStrings_QtGui[17286]
#define sipNameNr_QPaintEngineState 17304
#define sipName_QPaintEngineState &sipStrings_QtGui[17304]
#define sipNameNr_QPixmapCache__Key 17322
#define sipName_QPixmapCache__Key &sipStrings_QtGui[17322]
#define sipNameNr_QQuaternion__Axes 17340
#define sipName_QQuaternion__Axes &sipStrings_QtGui[17340]
#define sipNameNr_QQuaternion__Axis 17358
#define sipName_QQuaternion__Axis &sipStrings_QtGui[17358]
#define sipNameNr_QSinglePointEvent 17376
#define sipName_QSinglePointEvent &sipStrings_QtGui[17376]
#define sipNameNr_QTextInlineObject 17394
#define sipName_QTextInlineObject &sipStrings_QtGui[17394]
#define sipNameNr_QTextLength__Type 17412
#define sipName_QTextLength__Type &sipStrings_QtGui[17412]
#define sipNameNr_QTextOption__Flag 17430
#define sipName_QTextOption__Flag &sipStrings_QtGui[17430]
#define sipNameNr_QValidator__State 17448
#define sipName_QValidator__State &sipStrings_QtGui[17448]
#define sipNameNr_ResetNotification 17466
#define sipName_ResetNotification &sipStrings_QtGui[17466]
#define sipNameNr_SelectStartOfLine 17484
#define sipName_SelectStartOfLine &sipStrings_QtGui[17484]
#define sipNameNr_ShowTabsAndSpaces 17502
#define sipName_ShowTabsAndSpaces &sipStrings_QtGui[17502]
#define sipNameNr_SimplifiedChinese 17520
#define sipName_SimplifiedChinese &sipStrings_QtGui[17520]
#define sipNameNr_SupportedSubTypes 17538
#define sipName_SupportedSubTypes &sipStrings_QtGui[17538]
#define sipNameNr_SyncSynchronizing 17556
#define sipName_SyncSynchronizing &sipStrings_QtGui[17556]
#define sipNameNr_TextHeuristicRole 17574
#define sipName_TextHeuristicRole &sipStrings_QtGui[17574]
#define sipNameNr_UndoAndRedoStacks 17592
#define sipName_UndoAndRedoStacks &sipStrings_QtGui[17592]
#define sipNameNr_VerticalAlignment 951
#define sipName_VerticalAlignment &sipStrings_QtGui[951]
#define sipNameNr_WeatherClearNight 17610
#define sipName_WeatherClearNight &sipStrings_QtGui[17610]
#define sipNameNr_addFileAttachment 17628
#define sipName_addFileAttachment &sipStrings_QtGui[17628]
#define sipNameNr_allPointsAccepted 17646
#define sipName_allPointsAccepted &sipStrings_QtGui[17646]
#define sipNameNr_allowsInteraction 17664
#define sipName_allowsInteraction &sipStrings_QtGui[17664]
#define sipNameNr_associatedObjects 17682
#define sipName_associatedObjects &sipStrings_QtGui[17682]
#define sipNameNr_availableGeometry 17700
#define sipName_availableGeometry &sipStrings_QtGui[17700]
#define sipNameNr_blockBoundingRect 17718
#define sipName_blockBoundingRect &sipStrings_QtGui[17718]
#define sipNameNr_blockCountChanged 17736
#define sipName_blockCountChanged &sipStrings_QtGui[17736]
#define sipNameNr_blockWithMarkerAt 17754
#define sipName_blockWithMarkerAt &sipStrings_QtGui[17754]
#define sipNameNr_bottomBorderBrush 17772
#define sipName_bottomBorderBrush &sipStrings_QtGui[17772]
#define sipNameNr_bottomBorderStyle 17790
#define sipName_bottomBorderStyle &sipStrings_QtGui[17790]
#define sipNameNr_clearVariableAxes 17808
#define sipName_clearVariableAxes &sipStrings_QtGui[17808]
#define sipNameNr_combinedTransform 17826
#define sipName_combinedTransform &sipStrings_QtGui[17826]
#define sipNameNr_commitDataRequest 17844
#define sipName_commitDataRequest &sipStrings_QtGui[17844]
#define sipNameNr_currentBlockState 17862
#define sipName_currentBlockState &sipStrings_QtGui[17862]
#define sipNameNr_currentColorGroup 17880
#define sipName_currentColorGroup &sipStrings_QtGui[17880]
#define sipNameNr_defaultStyleSheet 17898
#define sipName_defaultStyleSheet &sipStrings_QtGui[17898]
#define sipNameNr_defaultTextOption 17916
#define sipName_defaultTextOption &sipStrings_QtGui[17916]
#define sipNameNr_devicePixelRatioF 17934
#define sipName_devicePixelRatioF &sipStrings_QtGui[17934]
#define sipNameNr_drawConvexPolygon 17952
#define sipName_drawConvexPolygon &sipStrings_QtGui[17952]
#define sipNameNr_endNativePainting 17970
#define sipName_endNativePainting &sipStrings_QtGui[17970]
#define sipNameNr_fallbackThemeName 17988
#define sipName_fallbackThemeName &sipStrings_QtGui[17988]
#define sipNameNr_findBlockByNumber 18006
#define sipName_findBlockByNumber &sipStrings_QtGui[18006]
#define sipNameNr_findBufferChanged 18024
#define sipName_findBufferChanged &sipStrings_QtGui[18024]
#define sipNameNr_fontLetterSpacing 18042
#define sipName_fontLetterSpacing &sipStrings_QtGui[18042]
#define sipNameNr_fontStyleStrategy 18060
#define sipName_fontStyleStrategy &sipStrings_QtGui[18060]
#define sipNameNr_frameBoundingRect 18078
#define sipName_frameBoundingRect &sipStrings_QtGui[18078]
#define sipNameNr_hasStaticContents 18096
#define sipName_hasStaticContents &sipStrings_QtGui[18096]
#define sipNameNr_hintingPreference 18114
#define sipName_hintingPreference &sipStrings_QtGui[18114]
#define sipNameNr_horizontalAdvance 18132
#define sipName_horizontalAdvance &sipStrings_QtGui[18132]
#define sipNameNr_invisibleRootItem 18150
#define sipName_invisibleRootItem &sipStrings_QtGui[18150]
#define sipNameNr_isSessionRestored 18168
#define sipName_isSessionRestored &sipStrings_QtGui[18168]
#define sipNameNr_isTableCellFormat 18186
#define sipName_isTableCellFormat &sipStrings_QtGui[18186]
#define sipNameNr_isUndoRedoEnabled 18204
#define sipName_isUndoRedoEnabled &sipStrings_QtGui[18204]
#define sipNameNr_isVariableAxisSet 18222
#define sipName_isVariableAxisSet &sipStrings_QtGui[18222]
#define sipNameNr_keyboardModifiers 18240
#define sipName_keyboardModifiers &sipStrings_QtGui[18240]
#define sipNameNr_keyboardRectangle 18258
#define sipName_keyboardRectangle &sipStrings_QtGui[18258]
#define sipNameNr_letterSpacingType 18276
#define sipName_letterSpacingType &sipStrings_QtGui[18276]
#define sipNameNr_markContentsDirty 18294
#define sipName_markContentsDirty &sipStrings_QtGui[18294]
#define sipNameNr_maximumBlockCount 18312
#define sipName_maximumBlockCount &sipStrings_QtGui[18312]
#define sipNameNr_mediumspringgreen 18330
#define sipName_mediumspringgreen &sipStrings_QtGui[18330]
#define sipNameNr_mouseReleaseEvent 18348
#define sipName_mouseReleaseEvent &sipStrings_QtGui[18348]
#define sipNameNr_nativeOrientation 18366
#define sipName_nativeOrientation &sipStrings_QtGui[18366]
#define sipNameNr_nonBreakableLines 18384
#define sipName_nonBreakableLines &sipStrings_QtGui[18384]
#define sipNameNr_outOfBoundsPolicy 18402
#define sipName_outOfBoundsPolicy &sipStrings_QtGui[18402]
#define sipNameNr_overshootDistance 18420
#define sipName_overshootDistance &sipStrings_QtGui[18420]
#define sipNameNr_passwordMaskDelay 18438
#define sipName_passwordMaskDelay &sipStrings_QtGui[18438]
#define sipNameNr_penNeedsResolving 18456
#define sipName_penNeedsResolving &sipStrings_QtGui[18456]
#define sipNameNr_qPixelFormatAlpha 18474
#define sipName_qPixelFormatAlpha &sipStrings_QtGui[18474]
#define sipNameNr_regularExpression 18492
#define sipName_regularExpression &sipStrings_QtGui[18492]
#define sipNameNr_replacementLength 18510
#define sipName_replacementLength &sipStrings_QtGui[18510]
#define sipNameNr_resetInternalData 18528
#define sipName_resetInternalData &sipStrings_QtGui[18528]
#define sipNameNr_sceneGrabPosition 18546
#define sipName_sceneGrabPosition &sipStrings_QtGui[18546]
#define sipNameNr_sceneLastPosition 18564
#define sipName_sceneLastPosition &sipStrings_QtGui[18564]
#define sipNameNr_setAccessibleText 18582
#define sipName_setAccessibleText &sipStrings_QtGui[18582]
#define sipNameNr_setBackgroundMode 18600
#define sipName_setBackgroundMode &sipStrings_QtGui[18600]
#define sipNameNr_setBaselineOffset 18618
#define sipName_setBaselineOffset &sipStrings_QtGui[18618]
#define sipNameNr_setBlueBufferSize 18636
#define sipName_setBlueBufferSize &sipStrings_QtGui[18636]
#define sipNameNr_setBorderCollapse 18654
#define sipName_setBorderCollapse &sipStrings_QtGui[18654]
#define sipNameNr_setCachingEnabled 18672
#define sipName_setCachingEnabled &sipStrings_QtGui[18672]
#define sipNameNr_setCapitalization 18690
#define sipName_setCapitalization &sipStrings_QtGui[18690]
#define sipNameNr_setCoordinateMode 18708
#define sipName_setCoordinateMode &sipStrings_QtGui[18708]
#define sipNameNr_setCurveThreshold 18726
#define sipName_setCurveThreshold &sipStrings_QtGui[18726]
#define sipNameNr_setDiscardCommand 18744
#define sipName_setDiscardCommand &sipStrings_QtGui[18744]
#define sipNameNr_setDocumentLayout 18762
#define sipName_setDocumentLayout &sipStrings_QtGui[18762]
#define sipNameNr_setDocumentMargin 18780
#define sipName_setDocumentMargin &sipStrings_QtGui[18780]
#define sipNameNr_setFontFixedPitch 18798
#define sipName_setFontFixedPitch &sipStrings_QtGui[18798]
#define sipNameNr_setHeaderRowCount 18816
#define sipName_setHeaderRowCount &sipStrings_QtGui[18816]
#define sipNameNr_setMinimumMargins 18834
#define sipName_setMinimumMargins &sipStrings_QtGui[18834]
#define sipNameNr_setOptimizedWrite 18852
#define sipName_setOptimizedWrite &sipStrings_QtGui[18852]
#define sipNameNr_setOverrideCursor 18870
#define sipName_setOverrideCursor &sipStrings_QtGui[18870]
#define sipNameNr_setRenderableType 18888
#define sipName_setRenderableType &sipStrings_QtGui[18888]
#define sipNameNr_setRestartCommand 18906
#define sipName_setRestartCommand &sipStrings_QtGui[18906]
#define sipNameNr_setScaledClipRect 18924
#define sipName_setScaledClipRect &sipStrings_QtGui[18924]
#define sipNameNr_setStaticContents 18942
#define sipName_setStaticContents &sipStrings_QtGui[18942]
#define sipNameNr_setTopBorderBrush 18960
#define sipName_setTopBorderBrush &sipStrings_QtGui[18960]
#define sipNameNr_setTopBorderStyle 18978
#define sipName_setTopBorderStyle &sipStrings_QtGui[18978]
#define sipNameNr_setTransformation 18996
#define sipName_setTransformation &sipStrings_QtGui[18996]
#define sipNameNr_setUnderlineColor 19014
#define sipName_setUnderlineColor &sipStrings_QtGui[19014]
#define sipNameNr_setUnderlineStyle 19032
#define sipName_setUnderlineStyle &sipStrings_QtGui[19032]
#define sipNameNr_setWorldTransform 19050
#define sipName_setWorldTransform &sipStrings_QtGui[19050]
#define sipNameNr_startDragDistance 19068
#define sipName_startDragDistance &sipStrings_QtGui[19068]
#define sipNameNr_startDragVelocity 19086
#define sipName_startDragVelocity &sipStrings_QtGui[19086]
#define sipNameNr_startSystemResize 19104
#define sipName_startSystemResize &sipStrings_QtGui[19104]
#define sipNameNr_stencilBufferSize 19122
#define sipName_stencilBufferSize &sipStrings_QtGui[19122]
#define sipNameNr_subScriptBaseline 19140
#define sipName_subScriptBaseline &sipStrings_QtGui[19140]
#define sipNameNr_supportedSubTypes 19158
#define sipName_supportedSubTypes &sipStrings_QtGui[19158]
#define sipNameNr_supportsAnimation 19176
#define sipName_supportsAnimation &sipStrings_QtGui[19176]
#define sipNameNr_supportsCharacter 19194
#define sipName_supportsCharacter &sipStrings_QtGui[19194]
#define sipNameNr_supportsSelection 19212
#define sipName_supportsSelection &sipStrings_QtGui[19212]
#define sipNameNr_tightBoundingRect 19230
#define sipName_tightBoundingRect &sipStrings_QtGui[19230]
#define sipNameNr_toSubpathPolygons 19248
#define sipName_toSubpathPolygons &sipStrings_QtGui[19248]
#define sipNameNr_toTableCellFormat 19266
#define sipName_toTableCellFormat &sipStrings_QtGui[19266]
#define sipNameNr_underlinePosition 19284
#define sipName_underlinePosition &sipStrings_QtGui[19284]
#define sipNameNr_unregisterHandler 19302
#define sipName_unregisterHandler &sipStrings_QtGui[19302]
#define sipNameNr_unsetVariableAxis 19320
#define sipName_unsetVariableAxis &sipStrings_QtGui[19320]
#define sipNameNr_variableAxisValue 19338
#define sipName_variableAxisValue &sipStrings_QtGui[19338]
#define sipNameNr_verticalAlignment 19356
#define sipName_verticalAlignment &sipStrings_QtGui[19356]
#define sipNameNr_verticalMovementX 19374
#define sipName_verticalMovementX &sipStrings_QtGui[19374]
#define sipNameNr_visibilityChanged 19392
#define sipName_visibilityChanged &sipStrings_QtGui[19392]
#define sipNameNr_writingSystemName 19410
#define sipName_writingSystemName &sipStrings_QtGui[19410]
#define sipNameNr_AlignSuperScript 19428
#define sipName_AlignSuperScript &sipStrings_QtGui[19428]
#define sipNameNr_AntialiasingType 4789
#define sipName_AntialiasingType &sipStrings_QtGui[4789]
#define sipNameNr_AudioVolumeMuted 19445
#define sipName_AudioVolumeMuted &sipStrings_QtGui[19445]
#define sipNameNr_BlockRightMargin 19462
#define sipName_BlockRightMargin &sipStrings_QtGui[19462]
#define sipNameNr_BlockUnderCursor 19479
#define sipName_BlockUnderCursor &sipStrings_QtGui[19479]
#define sipNameNr_BorderStyle_None 19496
#define sipName_BorderStyle_None &sipStrings_QtGui[19496]
#define sipNameNr_CompressionRatio 19513
#define sipName_CompressionRatio &sipStrings_QtGui[19513]
#define sipNameNr_DirtyBrushOrigin 19530
#define sipName_DirtyBrushOrigin &sipStrings_QtGui[19530]
#define sipNameNr_DirtyClipEnabled 19547
#define sipName_DirtyClipEnabled &sipStrings_QtGui[19547]
#define sipNameNr_EnvelopePersonal 19564
#define sipName_EnvelopePersonal &sipStrings_QtGui[19564]
#define sipNameNr_EternalConstance 19581
#define sipName_EternalConstance &sipStrings_QtGui[19581]
#define sipNameNr_FolderDragAccept 19598
#define sipName_FolderDragAccept &sipStrings_QtGui[19598]
#define sipNameNr_FontVariableAxes 13414
#define sipName_FontVariableAxes &sipStrings_QtGui[13414]
#define sipNameNr_FormatIndentLess 19615
#define sipName_FormatIndentLess &sipStrings_QtGui[19615]
#define sipNameNr_FormatIndentMore 19632
#define sipName_FormatIndentMore &sipStrings_QtGui[19632]
#define sipNameNr_FormatTextItalic 19649
#define sipName_FormatTextItalic &sipStrings_QtGui[19649]
#define sipNameNr_FrameBorderBrush 19666
#define sipName_FrameBorderBrush &sipStrings_QtGui[19666]
#define sipNameNr_FrameBorderStyle 19683
#define sipName_FrameBorderStyle &sipStrings_QtGui[19683]
#define sipNameNr_FrameRightMargin 19700
#define sipName_FrameRightMargin &sipStrings_QtGui[19700]
#define sipNameNr_ImageReaderError 2492
#define sipName_ImageReaderError &sipStrings_QtGui[2492]
#define sipNameNr_ImageWriterError 2523
#define sipName_ImageWriterError &sipStrings_QtGui[2523]
#define sipNameNr_InvalidDataError 19717
#define sipName_InvalidDataError &sipStrings_QtGui[19717]
#define sipNameNr_LastFontProperty 19734
#define sipName_LastFontProperty &sipStrings_QtGui[19734]
#define sipNameNr_ListNumberPrefix 19751
#define sipName_ListNumberPrefix &sipStrings_QtGui[19751]
#define sipNameNr_ListNumberSuffix 19768
#define sipName_ListNumberSuffix &sipStrings_QtGui[19768]
#define sipNameNr_MarkdownResource 19785
#define sipName_MarkdownResource &sipStrings_QtGui[19785]
#define sipNameNr_MediaSeekForward 19802
#define sipName_MediaSeekForward &sipStrings_QtGui[19802]
#define sipNameNr_MediaSkipForward 19819
#define sipName_MediaSkipForward &sipStrings_QtGui[19819]
#define sipNameNr_MoveToEndOfBlock 19836
#define sipName_MoveToEndOfBlock &sipStrings_QtGui[19836]
#define sipNameNr_MultimediaPlayer 19853
#define sipName_MultimediaPlayer &sipStrings_QtGui[19853]
#define sipNameNr_NotPremultiplied 19870
#define sipName_NotPremultiplied &sipStrings_QtGui[19870]
#define sipNameNr_ObjectRotateLeft 19887
#define sipName_ObjectRotateLeft &sipStrings_QtGui[19887]
#define sipNameNr_OpenGLModuleType 1427
#define sipName_OpenGLModuleType &sipStrings_QtGui[1427]
#define sipNameNr_PatternTransform 19904
#define sipName_PatternTransform &sipStrings_QtGui[19904]
#define sipNameNr_PercentageLength 19921
#define sipName_PercentageLength &sipStrings_QtGui[19921]
#define sipNameNr_ProtectedContent 19938
#define sipName_ProtectedContent &sipStrings_QtGui[19938]
#define sipNameNr_QClipboard__Mode 19955
#define sipName_QClipboard__Mode &sipStrings_QtGui[19955]
#define sipNameNr_QConicalGradient 19972
#define sipName_QConicalGradient &sipStrings_QtGui[19972]
#define sipNameNr_QDesktopServices 19989
#define sipName_QDesktopServices &sipStrings_QtGui[19989]
#define sipNameNr_QDoubleValidator 20006
#define sipName_QDoubleValidator &sipStrings_QtGui[20006]
#define sipNameNr_QFileSystemModel 20023
#define sipName_QFileSystemModel &sipStrings_QtGui[20023]
#define sipNameNr_QFont__StyleHint 20040
#define sipName_QFont__StyleHint &sipStrings_QtGui[20040]
#define sipNameNr_QIcon__ThemeIcon 20057
#define sipName_QIcon__ThemeIcon &sipStrings_QtGui[20057]
#define sipNameNr_20074 20074
#define sipName_20074 &sipStrings_QtGui[20074]
#define sipNameNr_20091 20091
#define sipName_20091 &sipStrings_QtGui[20091]
#define sipNameNr_QNativeInterface 20108
#define sipName_QNativeInterface &sipStrings_QtGui[20108]
#define sipNameNr_QPdfOutputIntent 20125
#define sipName_QPdfOutputIntent &sipStrings_QtGui[20125]
#define sipNameNr_20142 20142
#define sipName_20142 &sipStrings_QtGui[20142]
#define sipNameNr_QTextBlockFormat 20159
#define sipName_QTextBlockFormat &sipStrings_QtGui[20159]
#define sipNameNr_QTextFrameFormat 20176
#define sipName_QTextFrameFormat &sipStrings_QtGui[20176]
#define sipNameNr_QTextImageFormat 20193
#define sipName_QTextImageFormat &sipStrings_QtGui[20193]
#define sipNameNr_QTextOption__Tab 20210
#define sipName_QTextOption__Tab &sipStrings_QtGui[20210]
#define sipNameNr_QTextTableFormat 20227
#define sipName_QTextTableFormat &sipStrings_QtGui[20227]
#define sipNameNr_RestartIfRunning 20244
#define sipName_RestartIfRunning &sipStrings_QtGui[20244]
#define sipNameNr_ScaledPixmapHook 20261
#define sipName_ScaledPixmapHook &sipStrings_QtGui[20261]
#define sipNameNr_SelectEndOfBlock 20278
#define sipName_SelectEndOfBlock &sipStrings_QtGui[20278]
#define sipNameNr_SeparateAdvances 20295
#define sipName_SeparateAdvances &sipStrings_QtGui[20295]
#define sipNameNr_StandardNotation 20312
#define sipName_StandardNotation &sipStrings_QtGui[20312]
#define sipNameNr_SurfaceEventType 328
#define sipName_SurfaceEventType &sipStrings_QtGui[328]
#define sipNameNr_SystemLockScreen 20329
#define sipName_SystemLockScreen &sipStrings_QtGui[20329]
#define sipNameNr_TableCellPadding 20346
#define sipName_TableCellPadding &sipStrings_QtGui[20346]
#define sipNameNr_TableCellRowSpan 13514
#define sipName_TableCellRowSpan &sipStrings_QtGui[13514]
#define sipNameNr_TableCellSpacing 20363
#define sipName_TableCellSpacing &sipStrings_QtGui[20363]
#define sipNameNr_TextAntialiasing 20380
#define sipName_TextAntialiasing &sipStrings_QtGui[20380]
#define sipNameNr_TransferFunction 3102
#define sipName_TransferFunction &sipStrings_QtGui[3102]
#define sipNameNr_UseDesignMetrics 13574
#define sipName_UseDesignMetrics &sipStrings_QtGui[13574]
#define sipNameNr_WeatherFewClouds 20397
#define sipName_WeatherFewClouds &sipStrings_QtGui[20397]
#define sipNameNr_alphaMapForGlyph 20414
#define sipName_alphaMapForGlyph &sipStrings_QtGui[20414]
#define sipNameNr_animatingChanged 20431
#define sipName_animatingChanged &sipStrings_QtGui[20431]
#define sipNameNr_antialiasingType 20448
#define sipName_antialiasingType &sipStrings_QtGui[20448]
#define sipNameNr_applicationState 20465
#define sipName_applicationState &sipStrings_QtGui[20465]
#define sipNameNr_averageCharWidth 20482
#define sipName_averageCharWidth &sipStrings_QtGui[20482]
#define sipNameNr_blockFormatIndex 20499
#define sipName_blockFormatIndex &sipStrings_QtGui[20499]
#define sipNameNr_boundingRectChar 20516
#define sipName_boundingRectChar &sipStrings_QtGui[20516]
#define sipNameNr_checkableChanged 20533
#define sipName_checkableChanged &sipStrings_QtGui[20533]
#define sipNameNr_clipBoundingRect 20550
#define sipName_clipBoundingRect &sipStrings_QtGui[20550]
#define sipNameNr_colorTransformed 20567
#define sipName_colorTransformed &sipStrings_QtGui[20567]
#define sipNameNr_controlPointRect 20584
#define sipName_controlPointRect &sipStrings_QtGui[20584]
#define sipNameNr_convertFromImage 20601
#define sipName_convertFromImage &sipStrings_QtGui[20601]
#define sipNameNr_createRedoAction 20618
#define sipName_createRedoAction &sipStrings_QtGui[20618]
#define sipNameNr_createUndoAction 20635
#define sipName_createUndoAction &sipStrings_QtGui[20635]
#define sipNameNr_currentImageRect 20652
#define sipName_currentImageRect &sipStrings_QtGui[20652]
#define sipNameNr_devicePixelRatio 20669
#define sipName_devicePixelRatio &sipStrings_QtGui[20669]
#define sipNameNr_disconnectNotify 20686
#define sipName_disconnectNotify &sipStrings_QtGui[20686]
#define sipNameNr_drawInlineObject 20703
#define sipName_drawInlineObject &sipStrings_QtGui[20703]
#define sipNameNr_ellipseDiameters 20720
#define sipName_ellipseDiameters &sipStrings_QtGui[20720]
#define sipNameNr_fontVariableAxes 20737
#define sipName_fontVariableAxes &sipStrings_QtGui[20737]
#define sipNameNr_fromAxisAndAngle 20754
#define sipName_fromAxisAndAngle &sipStrings_QtGui[20754]
#define sipNameNr_handlerForObject 20771
#define sipName_handlerForObject &sipStrings_QtGui[20771]
#define sipNameNr_isBitmapScalable 20788
#define sipName_isBitmapScalable &sipStrings_QtGui[20788]
#define sipNameNr_isCachingEnabled 20805
#define sipName_isCachingEnabled &sipStrings_QtGui[20805]
#define sipNameNr_isValidColorName 20822
#define sipName_isValidColorName &sipStrings_QtGui[20822]
#define sipNameNr_lastWindowClosed 20839
#define sipName_lastWindowClosed &sipStrings_QtGui[20839]
#define sipNameNr_mediumaquamarine 20856
#define sipName_mediumaquamarine &sipStrings_QtGui[20856]
#define sipNameNr_mergeBlockFormat 20873
#define sipName_mergeBlockFormat &sipStrings_QtGui[20873]
#define sipNameNr_nativeVirtualKey 20890
#define sipName_nativeVirtualKey &sipStrings_QtGui[20890]
#define sipNameNr_naturalTextWidth 20907
#define sipName_naturalTextWidth &sipStrings_QtGui[20907]
#define sipNameNr_openGLModuleType 20924
#define sipName_openGLModuleType &sipStrings_QtGui[20924]
#define sipNameNr_pageCountChanged 20941
#define sipName_pageCountChanged &sipStrings_QtGui[20941]
#define sipNameNr_qPixelFormatCmyk 20958
#define sipName_qPixelFormatCmyk &sipStrings_QtGui[20958]
#define sipNameNr_qPixelFormatRgba 20975
#define sipName_qPixelFormatRgba &sipStrings_QtGui[20975]
#define sipNameNr_queryFocusObject 20992
#define sipName_queryFocusObject &sipStrings_QtGui[20992]
#define sipNameNr_rehighlightBlock 21009
#define sipName_rehighlightBlock &sipStrings_QtGui[21009]
#define sipNameNr_replacementStart 21026
#define sipName_replacementStart &sipStrings_QtGui[21026]
#define sipNameNr_resourceProvider 21043
#define sipName_resourceProvider &sipStrings_QtGui[21043]
#define sipNameNr_rightBorderBrush 21060
#define sipName_rightBorderBrush &sipStrings_QtGui[21060]
#define sipNameNr_rightBorderStyle 21077
#define sipName_rightBorderStyle &sipStrings_QtGui[21077]
#define sipNameNr_saveStateRequest 21094
#define sipName_saveStateRequest &sipStrings_QtGui[21094]
#define sipNameNr_selectionChanged 21111
#define sipName_selectionChanged &sipStrings_QtGui[21111]
#define sipNameNr_setAutoTransform 21128
#define sipName_setAutoTransform &sipStrings_QtGui[21128]
#define sipNameNr_setBottomPadding 21145
#define sipName_setBottomPadding &sipStrings_QtGui[21145]
#define sipNameNr_setDefaultFormat 21162
#define sipName_setDefaultFormat &sipStrings_QtGui[21162]
#define sipNameNr_setDotsPerMeterX 21179
#define sipName_setDotsPerMeterX &sipStrings_QtGui[21179]
#define sipNameNr_setDotsPerMeterY 21196
#define sipName_setDotsPerMeterY &sipStrings_QtGui[21196]
#define sipNameNr_setFontPointSize 21213
#define sipName_setFontPointSize &sipStrings_QtGui[21213]
#define sipNameNr_setFontStrikeOut 21230
#define sipName_setFontStrikeOut &sipStrings_QtGui[21230]
#define sipNameNr_setFontStyleHint 21247
#define sipName_setFontStyleHint &sipStrings_QtGui[21247]
#define sipNameNr_setFontStyleName 21264
#define sipName_setFontStyleName &sipStrings_QtGui[21264]
#define sipNameNr_setFontUnderline 21281
#define sipName_setFontUnderline &sipStrings_QtGui[21281]
#define sipNameNr_setFramePosition 21298
#define sipName_setFramePosition &sipStrings_QtGui[21298]
#define sipNameNr_setItemPrototype 21315
#define sipName_setItemPrototype &sipStrings_QtGui[21315]
#define sipNameNr_setItemRoleNames 21332
#define sipName_setItemRoleNames &sipStrings_QtGui[21332]
#define sipNameNr_setLayoutEnabled 21349
#define sipName_setLayoutEnabled &sipStrings_QtGui[21349]
#define sipNameNr_setLetterSpacing 21366
#define sipName_setLetterSpacing &sipStrings_QtGui[21366]
#define sipNameNr_setMaximumHeight 21383
#define sipName_setMaximumHeight &sipStrings_QtGui[21383]
#define sipNameNr_setMinimumHeight 21400
#define sipName_setMinimumHeight &sipStrings_QtGui[21400]
#define sipNameNr_setOutputProfile 21417
#define sipName_setOutputProfile &sipStrings_QtGui[21417]
#define sipNameNr_setPrimaryPoints 21434
#define sipName_setPrimaryPoints &sipStrings_QtGui[21434]
#define sipNameNr_setRedBufferSize 21451
#define sipName_setRedBufferSize &sipStrings_QtGui[21451]
#define sipNameNr_setSizeIncrement 21468
#define sipName_setSizeIncrement &sipStrings_QtGui[21468]
#define sipNameNr_setStringIndexes 21485
#define sipName_setStringIndexes &sipStrings_QtGui[21485]
#define sipNameNr_setStyleStrategy 21502
#define sipName_setStyleStrategy &sipStrings_QtGui[21502]
#define sipNameNr_setTextAlignment 21519
#define sipName_setTextAlignment &sipStrings_QtGui[21519]
#define sipNameNr_setTextDirection 21536
#define sipName_setTextDirection &sipStrings_QtGui[21536]
#define sipNameNr_showIsFullScreen 21553
#define sipName_showIsFullScreen &sipStrings_QtGui[21553]
#define sipNameNr_supportedActions 21570
#define sipName_supportedActions &sipStrings_QtGui[21570]
#define sipNameNr_supportedFormats 21587
#define sipName_supportedFormats &sipStrings_QtGui[21587]
#define sipNameNr_surfaceEventType 21604
#define sipName_surfaceEventType &sipStrings_QtGui[21604]
#define sipNameNr_tabFocusBehavior 21621
#define sipName_tabFocusBehavior &sipStrings_QtGui[21621]
#define sipNameNr_tableCellRowSpan 21638
#define sipName_tableCellRowSpan &sipStrings_QtGui[21638]
#define sipNameNr_themeSearchPaths 21655
#define sipName_themeSearchPaths &sipStrings_QtGui[21655]
#define sipNameNr_toRotationMatrix 21672
#define sipName_toRotationMatrix &sipStrings_QtGui[21672]
#define sipNameNr_toVector2DAffine 21689
#define sipName_toVector2DAffine &sipStrings_QtGui[21689]
#define sipNameNr_toVector3DAffine 21706
#define sipName_toVector3DAffine &sipStrings_QtGui[21706]
#define sipNameNr_touchPointStates 21723
#define sipName_touchPointStates &sipStrings_QtGui[21723]
#define sipNameNr_transferFunction 21740
#define sipName_transferFunction &sipStrings_QtGui[21740]
#define sipNameNr_transformBetween 21757
#define sipName_transformBetween &sipStrings_QtGui[21757]
#define sipNameNr_undoCommandAdded 21774
#define sipName_undoCommandAdded &sipStrings_QtGui[21774]
#define sipNameNr_unsetColorScheme 21791
#define sipName_unsetColorScheme &sipStrings_QtGui[21791]
#define sipNameNr_useDesignMetrics 21808
#define sipName_useDesignMetrics &sipStrings_QtGui[21808]
#define sipNameNr_useRtlExtensions 21825
#define sipName_useRtlExtensions &sipStrings_QtGui[21825]
#define sipNameNr_variableAxisTags 21842
#define sipName_variableAxisTags &sipStrings_QtGui[21842]
#define sipNameNr_virtualSiblingAt 21859
#define sipName_virtualSiblingAt &sipStrings_QtGui[21859]
#define sipNameNr_visualNavigation 21876
#define sipName_visualNavigation &sipStrings_QtGui[21876]
#define sipNameNr_wheelScrollLines 21893
#define sipName_wheelScrollLines &sipStrings_QtGui[21893]
#define sipNameNr_AbsoluteSpacing 21910
#define sipName_AbsoluteSpacing &sipStrings_QtGui[21910]
#define sipNameNr_AllPointerTypes 21926
#define sipName_AllPointerTypes &sipStrings_QtGui[21926]
#define sipNameNr_ApplicationExit 21942
#define sipName_ApplicationExit &sipStrings_QtGui[21942]
#define sipNameNr_AppointmentSoon 21958
#define sipName_AppointmentSoon &sipStrings_QtGui[21958]
#define sipNameNr_AudioVolumeHigh 21974
#define sipName_AudioVolumeHigh &sipStrings_QtGui[21974]
#define sipNameNr_BackgroundBrush 21990
#define sipName_BackgroundBrush &sipStrings_QtGui[21990]
#define sipNameNr_BackgroundColor 15707
#define sipName_BackgroundColor &sipStrings_QtGui[15707]
#define sipNameNr_BlockLeftMargin 22006
#define sipName_BlockLeftMargin &sipStrings_QtGui[22006]
#define sipNameNr_BlockQuoteLevel 22022
#define sipName_BlockQuoteLevel &sipStrings_QtGui[22022]
#define sipNameNr_CheerfulCaramel 22038
#define sipName_CheerfulCaramel &sipStrings_QtGui[22038]
#define sipNameNr_CloudyKnoxville 22054
#define sipName_CloudyKnoxville &sipStrings_QtGui[22054]
#define sipNameNr_CompositionMode 5477
#define sipName_CompositionMode &sipStrings_QtGui[5477]
#define sipNameNr_ConicalGradient 19973
#define sipName_ConicalGradient &sipStrings_QtGui[19973]
#define sipNameNr_ConstantOpacity 22070
#define sipName_ConstantOpacity &sipStrings_QtGui[22070]
#define sipNameNr_DeleteEndOfLine 22086
#define sipName_DeleteEndOfLine &sipStrings_QtGui[22086]
#define sipNameNr_DeleteEndOfWord 22102
#define sipName_DeleteEndOfWord &sipStrings_QtGui[22102]
#define sipNameNr_Direct3DSurface 22118
#define sipName_Direct3DSurface &sipStrings_QtGui[22118]
#define sipNameNr_DirtyBackground 22134
#define sipName_DirtyBackground &sipStrings_QtGui[22134]
#define sipNameNr_DirtyClipRegion 22150
#define sipName_DirtyClipRegion &sipStrings_QtGui[22150]
#define sipNameNr_EnvelopeItalian 22166
#define sipName_EnvelopeItalian &sipStrings_QtGui[22166]
#define sipNameNr_EnvelopeMonarch 22182
#define sipName_EnvelopeMonarch &sipStrings_QtGui[22182]
#define sipNameNr_ExclusionPolicy 3073
#define sipName_ExclusionPolicy &sipStrings_QtGui[3073]
#define sipNameNr_FilePermissions 22198
#define sipName_FilePermissions &sipStrings_QtGui[22198]
#define sipNameNr_FontWordSpacing 15859
#define sipName_FontWordSpacing &sipStrings_QtGui[15859]
#define sipNameNr_ForegroundBrush 22214
#define sipName_ForegroundBrush &sipStrings_QtGui[22214]
#define sipNameNr_Format_CMYK8888 22230
#define sipName_Format_CMYK8888 &sipStrings_QtGui[22230]
#define sipNameNr_Format_Indexed8 22246
#define sipName_Format_Indexed8 &sipStrings_QtGui[22246]
#define sipNameNr_Format_RGBA8888 22262
#define sipName_Format_RGBA8888 &sipStrings_QtGui[22262]
#define sipNameNr_Format_RGBX8888 22278
#define sipName_Format_RGBX8888 &sipStrings_QtGui[22278]
#define sipNameNr_FrameLeftMargin 22294
#define sipName_FrameLeftMargin &sipStrings_QtGui[22294]
#define sipNameNr_HighlightedText 22310
#define sipName_HighlightedText &sipStrings_QtGui[22310]
#define sipNameNr_LandingAircraft 22326
#define sipName_LandingAircraft &sipStrings_QtGui[22326]
#define sipNameNr_LayoutDirection 15897
#define sipName_LayoutDirection &sipStrings_QtGui[15897]
#define sipNameNr_LineHeightTypes 1263
#define sipName_LineHeightTypes &sipStrings_QtGui[1263]
#define sipNameNr_LineUnderCursor 22342
#define sipName_LineUnderCursor &sipStrings_QtGui[22342]
#define sipNameNr_MailReplySender 22358
#define sipName_MailReplySender &sipStrings_QtGui[22358]
#define sipNameNr_MarkdownFeature 2617
#define sipName_MarkdownFeature &sipStrings_QtGui[2617]
#define sipNameNr_MetaInformation 2648
#define sipName_MetaInformation &sipStrings_QtGui[2648]
#define sipNameNr_ModerateCaching 22374
#define sipName_ModerateCaching &sipStrings_QtGui[22374]
#define sipNameNr_MoveToEndOfLine 22390
#define sipName_MoveToEndOfLine &sipStrings_QtGui[22390]
#define sipNameNr_NamedColorSpace 3520
#define sipName_NamedColorSpace &sipStrings_QtGui[3520]
#define sipNameNr_NetworkWireless 22406
#define sipName_NetworkWireless &sipStrings_QtGui[22406]
#define sipNameNr_PageBreakPolicy 16030
#define sipName_PageBreakPolicy &sipStrings_QtGui[16030]
#define sipNameNr_PdmPhysicalDpiX 22422
#define sipName_PdmPhysicalDpiX &sipStrings_QtGui[22422]
#define sipNameNr_PdmPhysicalDpiY 22438
#define sipName_PdmPhysicalDpiY &sipStrings_QtGui[22438]
#define sipNameNr_PerformanceHint 3810
#define sipName_PerformanceHint &sipStrings_QtGui[3810]
#define sipNameNr_PixmapTransform 9669
#define sipName_PixmapTransform &sipStrings_QtGui[9669]
#define sipNameNr_PlaceholderText 22454
#define sipName_PlaceholderText &sipStrings_QtGui[22454]
#define sipNameNr_PolygonDrawMode 3193
#define sipName_PolygonDrawMode &sipStrings_QtGui[3193]
#define sipNameNr_PreferAntialias 22470
#define sipName_PreferAntialias &sipStrings_QtGui[22470]
#define sipNameNr_PreferNoHinting 22486
#define sipName_PreferNoHinting &sipStrings_QtGui[22486]
#define sipNameNr_PreferNoShaping 22502
#define sipName_PreferNoShaping &sipStrings_QtGui[22502]
#define sipNameNr_PreferencesRole 22518
#define sipName_PreferencesRole &sipStrings_QtGui[22518]
#define sipNameNr_PrinterPrinting 22534
#define sipName_PrinterPrinting &sipStrings_QtGui[22534]
#define sipNameNr_QColorConstants 22550
#define sipName_QColorConstants &sipStrings_QtGui[22550]
#define sipNameNr_QColorTransform 22566
#define sipName_QColorTransform &sipStrings_QtGui[22566]
#define sipNameNr_QDragEnterEvent 22582
#define sipName_QDragEnterEvent &sipStrings_QtGui[22582]
#define sipNameNr_QDragLeaveEvent 22598
#define sipName_QDragLeaveEvent &sipStrings_QtGui[22598]
#define sipNameNr_QGradient__Type 22614
#define sipName_QGradient__Type &sipStrings_QtGui[22614]
#define sipNameNr_QGuiApplication 22630
#define sipName_QGuiApplication &sipStrings_QtGui[22630]
#define sipNameNr_QImageIOHandler 22646
#define sipName_QImageIOHandler &sipStrings_QtGui[22646]
#define sipNameNr_QLinearGradient 22662
#define sipName_QLinearGradient &sipStrings_QtGui[22662]
#define sipNameNr_22678 22678
#define sipName_22678 &sipStrings_QtGui[22678]
#define sipNameNr_22694 22694
#define sipName_22694 &sipStrings_QtGui[22694]
#define sipNameNr_22710 22710
#define sipName_22710 &sipStrings_QtGui[22710]
#define sipNameNr_QPageSize__Unit 22726
#define sipName_QPageSize__Unit &sipStrings_QtGui[22726]
#define sipNameNr_QPointingDevice 22742
#define sipName_QPointingDevice &sipStrings_QtGui[22742]
#define sipNameNr_QRadialGradient 22758
#define sipName_QRadialGradient &sipStrings_QtGui[22758]
#define sipNameNr_QSessionManager 22774
#define sipName_QSessionManager &sipStrings_QtGui[22774]
#define sipNameNr_QStatusTipEvent 22790
#define sipName_QStatusTipEvent &sipStrings_QtGui[22790]
#define sipNameNr_QTextBlockGroup 22806
#define sipName_QTextBlockGroup &sipStrings_QtGui[22806]
#define sipNameNr_QTextCharFormat 22822
#define sipName_QTextCharFormat &sipStrings_QtGui[22822]
#define sipNameNr_QTextLine__Edge 22838
#define sipName_QTextLine__Edge &sipStrings_QtGui[22838]
#define sipNameNr_QTextListFormat 22854
#define sipName_QTextListFormat &sipStrings_QtGui[22854]
#define sipNameNr_QX11Application 1229
#define sipName_QX11Application &sipStrings_QtGui[1229]
#define sipNameNr_RasterGLSurface 22870
#define sipName_RasterGLSurface &sipStrings_QtGui[22870]
#define sipNameNr_SaintPetersburg 22886
#define sipName_SaintPetersburg &sipStrings_QtGui[22886]
#define sipNameNr_SelectEndOfLine 22902
#define sipName_SelectEndOfLine &sipStrings_QtGui[22902]
#define sipNameNr_SingleUnderline 22918
#define sipName_SingleUnderline &sipStrings_QtGui[22918]
#define sipNameNr_SizeMatchPolicy 4763
#define sipName_SizeMatchPolicy &sipStrings_QtGui[4763]
#define sipNameNr_TableCellObject 22934
#define sipName_TableCellObject &sipStrings_QtGui[22934]
#define sipNameNr_UnknownResource 22950
#define sipName_UnknownResource &sipStrings_QtGui[22950]
#define sipNameNr_UnsignedInteger 22966
#define sipName_UnsignedInteger &sipStrings_QtGui[22966]
#define sipNameNr_WordUnderCursor 22982
#define sipName_WordUnderCursor &sipStrings_QtGui[22982]
#define sipNameNr_allocationLimit 22998
#define sipName_allocationLimit &sipStrings_QtGui[22998]
#define sipNameNr_alphaBufferSize 23014
#define sipName_alphaBufferSize &sipStrings_QtGui[23014]
#define sipNameNr_ambiguousMember 23030
#define sipName_ambiguousMember &sipStrings_QtGui[23030]
#define sipNameNr_anchorRectangle 23046
#define sipName_anchorRectangle &sipStrings_QtGui[23046]
#define sipNameNr_aspectRatioMode 23062
#define sipName_aspectRatioMode &sipStrings_QtGui[23062]
#define sipNameNr_backgroundBrush 23078
#define sipName_backgroundBrush &sipStrings_QtGui[23078]
#define sipNameNr_backgroundColor 23094
#define sipName_backgroundColor &sipStrings_QtGui[23094]
#define sipNameNr_blockCharFormat 23110
#define sipName_blockCharFormat &sipStrings_QtGui[23110]
#define sipNameNr_cacheStatistics 23126
#define sipName_cacheStatistics &sipStrings_QtGui[23126]
#define sipNameNr_canDropMimeData 23142
#define sipName_canDropMimeData &sipStrings_QtGui[23142]
#define sipNameNr_charFormatIndex 23158
#define sipName_charFormatIndex &sipStrings_QtGui[23158]
#define sipNameNr_cleanupFunction 23174
#define sipName_cleanupFunction &sipStrings_QtGui[23174]
#define sipNameNr_clearBackground 23190
#define sipName_clearBackground &sipStrings_QtGui[23190]
#define sipNameNr_clearForeground 23206
#define sipName_clearForeground &sipStrings_QtGui[23206]
#define sipNameNr_compositionMode 23222
#define sipName_compositionMode &sipStrings_QtGui[23222]
#define sipNameNr_contentPosRange 23238
#define sipName_contentPosRange &sipStrings_QtGui[23238]
#define sipNameNr_contentsChanged 23254
#define sipName_contentsChanged &sipStrings_QtGui[23254]
#define sipNameNr_convertToFormat 23270
#define sipName_convertToFormat &sipStrings_QtGui[23270]
#define sipNameNr_createAlphaMask 23286
#define sipName_createAlphaMask &sipStrings_QtGui[23286]
#define sipNameNr_currentPosition 23302
#define sipName_currentPosition &sipStrings_QtGui[23302]
#define sipNameNr_cursorFlashTime 23318
#define sipName_cursorFlashTime &sipStrings_QtGui[23318]
#define sipNameNr_cursorMoveStyle 23334
#define sipName_cursorMoveStyle &sipStrings_QtGui[23334]
#define sipNameNr_cursorRectangle 23350
#define sipName_cursorRectangle &sipStrings_QtGui[23350]
#define sipNameNr_definitionUnits 23366
#define sipName_definitionUnits &sipStrings_QtGui[23366]
#define sipNameNr_depthBufferSize 23382
#define sipName_depthBufferSize &sipStrings_QtGui[23382]
#define sipNameNr_desktopFileName 23398
#define sipName_desktopFileName &sipStrings_QtGui[23398]
#define sipNameNr_deviceTransform 23414
#define sipName_deviceTransform &sipStrings_QtGui[23414]
#define sipNameNr_directoryLoaded 23430
#define sipName_directoryLoaded &sipStrings_QtGui[23430]
#define sipNameNr_distanceToPlane 23446
#define sipName_distanceToPlane &sipStrings_QtGui[23446]
#define sipNameNr_distanceToPoint 23462
#define sipName_distanceToPoint &sipStrings_QtGui[23462]
#define sipNameNr_documentChanged 23478
#define sipName_documentChanged &sipStrings_QtGui[23478]
#define sipNameNr_drawRoundedRect 23494
#define sipName_drawRoundedRect &sipStrings_QtGui[23494]
#define sipNameNr_drawTiledPixmap 23510
#define sipName_drawTiledPixmap &sipStrings_QtGui[23510]
#define sipNameNr_emitDataChanged 23526
#define sipName_emitDataChanged &sipStrings_QtGui[23526]
#define sipNameNr_exclusionPolicy 23542
#define sipName_exclusionPolicy &sipStrings_QtGui[23542]
#define sipNameNr_firstLineNumber 23558
#define sipName_firstLineNumber &sipStrings_QtGui[23558]
#define sipNameNr_fontWordSpacing 23574
#define sipName_fontWordSpacing &sipStrings_QtGui[23574]
#define sipNameNr_fromEulerAngles 23590
#define sipName_fromEulerAngles &sipStrings_QtGui[23590]
#define sipNameNr_fromImageReader 23606
#define sipName_fromImageReader &sipStrings_QtGui[23606]
#define sipNameNr_geometryChanged 23622
#define sipName_geometryChanged &sipStrings_QtGui[23622]
#define sipNameNr_getAxisAndAngle 23638
#define sipName_getAxisAndAngle &sipStrings_QtGui[23638]
#define sipNameNr_greenBufferSize 23654
#define sipName_greenBufferSize &sipStrings_QtGui[23654]
#define sipNameNr_hasAlphaChannel 23670
#define sipName_hasAlphaChannel &sipStrings_QtGui[23670]
#define sipNameNr_highlightedText 23686
#define sipName_highlightedText &sipStrings_QtGui[23686]
#define sipNameNr_isLayoutEnabled 23702
#define sipName_isLayoutEnabled &sipStrings_QtGui[23702]
#define sipNameNr_isPrivateFamily 23718
#define sipName_isPrivateFamily &sipStrings_QtGui[23718]
#define sipNameNr_isRedoAvailable 23734
#define sipName_isRedoAvailable &sipStrings_QtGui[23734]
#define sipNameNr_isSavingSession 23750
#define sipName_isSavingSession &sipStrings_QtGui[23750]
#define sipNameNr_isUndoAvailable 23766
#define sipName_isUndoAvailable &sipStrings_QtGui[23766]
#define sipNameNr_jumpToNextFrame 23782
#define sipName_jumpToNextFrame &sipStrings_QtGui[23782]
#define sipNameNr_jumpToNextImage 23798
#define sipName_jumpToNextImage &sipStrings_QtGui[23798]
#define sipNameNr_keyReleaseEvent 23814
#define sipName_keyReleaseEvent &sipStrings_QtGui[23814]
#define sipNameNr_lastErrorString 23830
#define sipName_lastErrorString &sipStrings_QtGui[23830]
#define sipNameNr_layoutDirection 23846
#define sipName_layoutDirection &sipStrings_QtGui[23846]
#define sipNameNr_leadingIncluded 23862
#define sipName_leadingIncluded &sipStrings_QtGui[23862]
#define sipNameNr_leftBorderBrush 23878
#define sipName_leftBorderBrush &sipStrings_QtGui[23878]
#define sipNameNr_leftBorderStyle 23894
#define sipName_leftBorderStyle &sipStrings_QtGui[23894]
#define sipNameNr_mediumslateblue 23910
#define sipName_mediumslateblue &sipStrings_QtGui[23910]
#define sipNameNr_mediumturquoise 23926
#define sipName_mediumturquoise &sipStrings_QtGui[23926]
#define sipNameNr_mediumvioletred 23942
#define sipName_mediumvioletred &sipStrings_QtGui[23942]
#define sipNameNr_mergeCharFormat 23958
#define sipName_mergeCharFormat &sipStrings_QtGui[23958]
#define sipNameNr_metaInformation 23974
#define sipName_metaInformation &sipStrings_QtGui[23974]
#define sipNameNr_mightBeRichText 23990
#define sipName_mightBeRichText &sipStrings_QtGui[23990]
#define sipNameNr_minRightBearing 24006
#define sipName_minRightBearing &sipStrings_QtGui[24006]
#define sipNameNr_modalityChanged 24022
#define sipName_modalityChanged &sipStrings_QtGui[24022]
#define sipNameNr_mousePressEvent 24038
#define sipName_mousePressEvent &sipStrings_QtGui[24038]
#define sipNameNr_nativeInterface 24054
#define sipName_nativeInterface &sipStrings_QtGui[24054]
#define sipNameNr_nativeModifiers 24070
#define sipName_nativeModifiers &sipStrings_QtGui[24070]
#define sipNameNr_naturalTextRect 24086
#define sipName_naturalTextRect &sipStrings_QtGui[24086]
#define sipNameNr_objectForFormat 24102
#define sipName_objectForFormat &sipStrings_QtGui[24102]
#define sipNameNr_outputCondition 24118
#define sipName_outputCondition &sipStrings_QtGui[24118]
#define sipNameNr_pageBreakPolicy 24134
#define sipName_pageBreakPolicy &sipStrings_QtGui[24134]
#define sipNameNr_paintRectPixels 24150
#define sipName_paintRectPixels &sipStrings_QtGui[24150]
#define sipNameNr_paintRectPoints 24166
#define sipName_paintRectPoints &sipStrings_QtGui[24166]
#define sipNameNr_percentAtLength 24182
#define sipName_percentAtLength &sipStrings_QtGui[24182]
#define sipNameNr_performanceHint 24198
#define sipName_performanceHint &sipStrings_QtGui[24198]
#define sipNameNr_placeholderText 24214
#define sipName_placeholderText &sipStrings_QtGui[24214]
#define sipNameNr_positionInBlock 24230
#define sipName_positionInBlock &sipStrings_QtGui[24230]
#define sipNameNr_possibleActions 24246
#define sipName_possibleActions &sipStrings_QtGui[24246]
#define sipNameNr_preeditAreaText 24262
#define sipName_preeditAreaText &sipStrings_QtGui[24262]
#define sipNameNr_primaryKeyboard 24278
#define sipName_primaryKeyboard &sipStrings_QtGui[24278]
#define sipNameNr_qPixelFormatHsl 24294
#define sipName_qPixelFormatHsl &sipStrings_QtGui[24294]
#define sipNameNr_qPixelFormatHsv 24310
#define sipName_qPixelFormatHsv &sipStrings_QtGui[24310]
#define sipNameNr_qPixelFormatYuv 24326
#define sipName_qPixelFormatYuv &sipStrings_QtGui[24326]
#define sipNameNr_redoTextChanged 24342
#define sipName_redoTextChanged &sipStrings_QtGui[24342]
#define sipNameNr_registerHandler 19304
#define sipName_registerHandler &sipStrings_QtGui[19304]
#define sipNameNr_requestActivate 24358
#define sipName_requestActivate &sipStrings_QtGui[24358]
#define sipNameNr_requestedFormat 24374
#define sipName_requestedFormat &sipStrings_QtGui[24374]
#define sipNameNr_resolveSymlinks 24390
#define sipName_resolveSymlinks &sipStrings_QtGui[24390]
#define sipNameNr_rootPathChanged 24406
#define sipName_rootPathChanged &sipStrings_QtGui[24406]
#define sipNameNr_safeAreaMargins 24422
#define sipName_safeAreaMargins &sipStrings_QtGui[24422]
#define sipNameNr_setAlphaChannel 24438
#define sipName_setAlphaChannel &sipStrings_QtGui[24438]
#define sipNameNr_setAutoTristate 24454
#define sipName_setAutoTristate &sipStrings_QtGui[24454]
#define sipNameNr_setBottomBorder 24470
#define sipName_setBottomBorder &sipStrings_QtGui[24470]
#define sipNameNr_setBottomMargin 24486
#define sipName_setBottomMargin &sipStrings_QtGui[24486]
#define sipNameNr_setBoundingRect 24502
#define sipName_setBoundingRect &sipStrings_QtGui[24502]
#define sipNameNr_setCacheEnabled 24518
#define sipName_setCacheEnabled &sipStrings_QtGui[24518]
#define sipNameNr_setCenterRadius 24534
#define sipName_setCenterRadius &sipStrings_QtGui[24534]
#define sipNameNr_setCommitString 24550
#define sipName_setCommitString &sipStrings_QtGui[24550]
#define sipNameNr_setDefaultValue 24566
#define sipName_setDefaultValue &sipStrings_QtGui[24566]
#define sipNameNr_setFontFamilies 24582
#define sipName_setFontFamilies &sipStrings_QtGui[24582]
#define sipNameNr_setFontFeatures 24598
#define sipName_setFontFeatures &sipStrings_QtGui[24598]
#define sipNameNr_setFontOverline 24614
#define sipName_setFontOverline &sipStrings_QtGui[24614]
#define sipNameNr_setGlyphIndexes 24630
#define sipName_setGlyphIndexes &sipStrings_QtGui[24630]
#define sipNameNr_setHeadingLevel 24646
#define sipName_setHeadingLevel &sipStrings_QtGui[24646]
#define sipNameNr_setIconProvider 24662
#define sipName_setIconProvider &sipStrings_QtGui[24662]
#define sipNameNr_setMajorVersion 24678
#define sipName_setMajorVersion &sipStrings_QtGui[24678]
#define sipNameNr_setMaximumValue 24694
#define sipName_setMaximumValue &sipStrings_QtGui[24694]
#define sipNameNr_setMaximumWidth 24710
#define sipName_setMaximumWidth &sipStrings_QtGui[24710]
#define sipNameNr_setMinimumValue 24726
#define sipName_setMinimumValue &sipStrings_QtGui[24726]
#define sipNameNr_setMinimumWidth 24742
#define sipName_setMinimumWidth &sipStrings_QtGui[24742]
#define sipNameNr_setMinorVersion 24758
#define sipName_setMinorVersion &sipStrings_QtGui[24758]
#define sipNameNr_setNumberPrefix 24774
#define sipName_setNumberPrefix &sipStrings_QtGui[24774]
#define sipNameNr_setNumberSuffix 24790
#define sipName_setNumberSuffix &sipStrings_QtGui[24790]
#define sipNameNr_setOutputIntent 24806
#define sipName_setOutputIntent &sipStrings_QtGui[24806]
#define sipNameNr_setRegistryName 24822
#define sipName_setRegistryName &sipStrings_QtGui[24822]
#define sipNameNr_setRightPadding 24838
#define sipName_setRightPadding &sipStrings_QtGui[24838]
#define sipNameNr_setShareContext 24854
#define sipName_setShareContext &sipStrings_QtGui[24854]
#define sipNameNr_setSourceString 24870
#define sipName_setSourceString &sipStrings_QtGui[24870]
#define sipNameNr_setSwapBehavior 24886
#define sipName_setSwapBehavior &sipStrings_QtGui[24886]
#define sipNameNr_setSwapInterval 24902
#define sipName_setSwapInterval &sipStrings_QtGui[24902]
#define sipNameNr_setTabPositions 24918
#define sipName_setTabPositions &sipStrings_QtGui[24918]
#define sipNameNr_setTextureImage 24934
#define sipName_setTextureImage &sipStrings_QtGui[24934]
#define sipNameNr_setUserTristate 24950
#define sipName_setUserTristate &sipStrings_QtGui[24950]
#define sipNameNr_setVariableAxis 19322
#define sipName_setVariableAxis &sipStrings_QtGui[19322]
#define sipNameNr_setViewportSize 24966
#define sipName_setViewportSize &sipStrings_QtGui[24966]
#define sipNameNr_setWindowStates 24982
#define sipName_setWindowStates &sipStrings_QtGui[24982]
#define sipNameNr_shortcutContext 24998
#define sipName_shortcutContext &sipStrings_QtGui[24998]
#define sipNameNr_showIsMaximized 25014
#define sipName_showIsMaximized &sipStrings_QtGui[25014]
#define sipNameNr_startSystemMove 25030
#define sipName_startSystemMove &sipStrings_QtGui[25030]
#define sipNameNr_tabStopDistance 25046
#define sipName_tabStopDistance &sipStrings_QtGui[25046]
#define sipNameNr_topLevelWindows 25062
#define sipName_topLevelWindows &sipStrings_QtGui[25062]
#define sipNameNr_transientParent 25078
#define sipName_transientParent &sipStrings_QtGui[25078]
#define sipNameNr_undoTextChanged 25094
#define sipName_undoTextChanged &sipStrings_QtGui[25094]
#define sipNameNr_unpremultiplied 25110
#define sipName_unpremultiplied &sipStrings_QtGui[25110]
#define sipNameNr_unsetUrlHandler 25126
#define sipName_unsetUrlHandler &sipStrings_QtGui[25126]
#define sipNameNr_useHoverEffects 25142
#define sipName_useHoverEffects &sipStrings_QtGui[25142]
#define sipNameNr_virtualGeometry 25158
#define sipName_virtualGeometry &sipStrings_QtGui[25158]
#define sipNameNr_virtualSiblings 25174
#define sipName_virtualSiblings &sipStrings_QtGui[25174]
#define sipNameNr_AddressBookNew 25190
#define sipName_AddressBookNew &sipStrings_QtGui[25190]
#define sipNameNr_AlignSubScript 25205
#define sipName_AlignSubScript &sipStrings_QtGui[25205]
#define sipNameNr_AppointmentNew 25220
#define sipName_AppointmentNew &sipStrings_QtGui[25220]
#define sipNameNr_AudioVolumeLow 25235
#define sipName_AudioVolumeLow &sipStrings_QtGui[25235]
#define sipNameNr_BatteryCaution 25250
#define sipName_BatteryCaution &sipStrings_QtGui[25250]
#define sipNameNr_BlockAlignment 25265
#define sipName_BlockAlignment &sipStrings_QtGui[25265]
#define sipNameNr_BlockCodeFence 25280
#define sipName_BlockCodeFence &sipStrings_QtGui[25280]
#define sipNameNr_BlockTopMargin 25295
#define sipName_BlockTopMargin &sipStrings_QtGui[25295]
#define sipNameNr_Capitalization 9318
#define sipName_Capitalization &sipStrings_QtGui[9318]
#define sipNameNr_ConfidentCloud 25310
#define sipName_ConfidentCloud &sipStrings_QtGui[25310]
#define sipNameNr_CoordinateMode 5400
#define sipName_CoordinateMode &sipStrings_QtGui[5400]
#define sipNameNr_CursorPosition 5556
#define sipName_CursorPosition &sipStrings_QtGui[5556]
#define sipNameNr_CurveToElement 25325
#define sipName_CurveToElement &sipStrings_QtGui[25325]
#define sipNameNr_DashDotDotLine 25340
#define sipName_DashDotDotLine &sipStrings_QtGui[25340]
#define sipNameNr_DialogPassword 25355
#define sipName_DialogPassword &sipStrings_QtGui[25355]
#define sipNameNr_DialogQuestion 25370
#define sipName_DialogQuestion &sipStrings_QtGui[25370]
#define sipNameNr_DirtyTransform 25385
#define sipName_DirtyTransform &sipStrings_QtGui[25385]
#define sipNameNr_DocumentRevert 25400
#define sipName_DocumentRevert &sipStrings_QtGui[25400]
#define sipNameNr_DocumentSaveAs 25415
#define sipName_DocumentSaveAs &sipStrings_QtGui[25415]
#define sipNameNr_DoublePostcard 25430
#define sipName_DoublePostcard &sipStrings_QtGui[25430]
#define sipNameNr_EnvelopeInvite 25445
#define sipName_EnvelopeInvite &sipStrings_QtGui[25445]
#define sipNameNr_EverlastingSky 25460
#define sipName_EverlastingSky &sipStrings_QtGui[25460]
#define sipNameNr_ExtraCondensed 25475
#define sipName_ExtraCondensed &sipStrings_QtGui[25475]
#define sipNameNr_FindWholeWords 25490
#define sipName_FindWholeWords &sipStrings_QtGui[25490]
#define sipNameNr_FolderVisiting 25505
#define sipName_FolderVisiting &sipStrings_QtGui[25505]
#define sipNameNr_FontFixedPitch 18801
#define sipName_FontFixedPitch &sipStrings_QtGui[18801]
#define sipNameNr_FormatTextBold 25520
#define sipName_FormatTextBold &sipStrings_QtGui[25520]
#define sipNameNr_Format_Invalid 25535
#define sipName_Format_Invalid &sipStrings_QtGui[25535]
#define sipNameNr_Format_MonoLSB 25550
#define sipName_Format_MonoLSB &sipStrings_QtGui[25550]
#define sipNameNr_FrameTopMargin 25565
#define sipName_FrameTopMargin &sipStrings_QtGui[25565]
#define sipNameNr_IconEngineHook 4324
#define sipName_IconEngineHook &sipStrings_QtGui[4324]
#define sipNameNr_KernedAdvances 25580
#define sipName_KernedAdvances &sipStrings_QtGui[25580]
#define sipNameNr_LineHeightType 25595
#define sipName_LineHeightType &sipStrings_QtGui[25595]
#define sipNameNr_LinearGradient 22663
#define sipName_LinearGradient &sipStrings_QtGui[22663]
#define sipNameNr_ListLowerAlpha 25610
#define sipName_ListLowerAlpha &sipStrings_QtGui[25610]
#define sipNameNr_ListLowerRoman 25625
#define sipName_ListLowerRoman &sipStrings_QtGui[25625]
#define sipNameNr_ListUpperAlpha 25640
#define sipName_ListUpperAlpha &sipStrings_QtGui[25640]
#define sipNameNr_ListUpperRoman 25655
#define sipName_ListUpperRoman &sipStrings_QtGui[25655]
#define sipNameNr_MailAttachment 25670
#define sipName_MailAttachment &sipStrings_QtGui[25670]
#define sipNameNr_MailMarkUnread 25685
#define sipName_MailMarkUnread &sipStrings_QtGui[25685]
#define sipNameNr_MailMessageNew 25700
#define sipName_MailMessageNew &sipStrings_QtGui[25700]
#define sipNameNr_MarkdownNoHTML 25715
#define sipName_MarkdownNoHTML &sipStrings_QtGui[25715]
#define sipNameNr_MillenniumPine 25730
#define sipName_MillenniumPine &sipStrings_QtGui[25730]
#define sipNameNr_MouseEmulation 25745
#define sipName_MouseEmulation &sipStrings_QtGui[25745]
#define sipNameNr_MoveToNextChar 25760
#define sipName_MoveToNextChar &sipStrings_QtGui[25760]
#define sipNameNr_MoveToNextLine 25775
#define sipName_MoveToNextLine &sipStrings_QtGui[25775]
#define sipNameNr_MoveToNextPage 25790
#define sipName_MoveToNextPage &sipStrings_QtGui[25790]
#define sipNameNr_MoveToNextWord 25805
#define sipName_MoveToNextWord &sipStrings_QtGui[25805]
#define sipNameNr_NetworkOffline 25820
#define sipName_NetworkOffline &sipStrings_QtGui[25820]
#define sipNameNr_NormalPriority 25835
#define sipName_NormalPriority &sipStrings_QtGui[25835]
#define sipNameNr_OctoberSilence 25850
#define sipName_OctoberSilence &sipStrings_QtGui[25850]
#define sipNameNr_OldFontStretch 25865
#define sipName_OldFontStretch &sipStrings_QtGui[25865]
#define sipNameNr_OptimizedWrite 18855
#define sipName_OptimizedWrite &sipStrings_QtGui[18855]
#define sipNameNr_PageBreak_Auto 25880
#define sipName_PageBreak_Auto &sipStrings_QtGui[25880]
#define sipNameNr_PdfVersion_1_4 25895
#define sipName_PdfVersion_1_4 &sipStrings_QtGui[25895]
#define sipNameNr_PdfVersion_1_6 25910
#define sipName_PdfVersion_1_6 &sipStrings_QtGui[25910]
#define sipNameNr_PdfVersion_A1b 25925
#define sipName_PdfVersion_A1b &sipStrings_QtGui[25925]
#define sipNameNr_PixmapFragment 6349
#define sipName_PixmapFragment &sipStrings_QtGui[6349]
#define sipNameNr_PurpleDivision 25940
#define sipName_PurpleDivision &sipStrings_QtGui[25940]
#define sipNameNr_QDragMoveEvent 25955
#define sipName_QDragMoveEvent &sipStrings_QtGui[25955]
#define sipNameNr_QFileOpenEvent 25970
#define sipName_QFileOpenEvent &sipStrings_QtGui[25970]
#define sipNameNr_QFont__Stretch 25985
#define sipName_QFont__Stretch &sipStrings_QtGui[25985]
#define sipNameNr_QIconDragEvent 26000
#define sipName_QIconDragEvent &sipStrings_QtGui[26000]
#define sipNameNr_QImage__Format 26015
#define sipName_QImage__Format &sipStrings_QtGui[26015]
#define sipNameNr_QOpenGLContext 26030
#define sipName_QOpenGLContext &sipStrings_QtGui[26030]
#define sipNameNr_QShortcutEvent 26045
#define sipName_QShortcutEvent &sipStrings_QtGui[26045]
#define sipNameNr_QSurfaceFormat 26060
#define sipName_QSurfaceFormat &sipStrings_QtGui[26060]
#define sipNameNr_QTextTableCell 26075
#define sipName_QTextTableCell &sipStrings_QtGui[26075]
#define sipNameNr_RadialGradient 22759
#define sipName_RadialGradient &sipStrings_QtGui[22759]
#define sipNameNr_RenderableType 2587
#define sipName_RenderableType &sipStrings_QtGui[2587]
#define sipNameNr_RetrieveString 26090
#define sipName_RetrieveString &sipStrings_QtGui[26090]
#define sipNameNr_ScaledClipRect 18927
#define sipName_ScaledClipRect &sipStrings_QtGui[18927]
#define sipNameNr_ScrollFinished 26105
#define sipName_ScrollFinished &sipStrings_QtGui[26105]
#define sipNameNr_SelectNextChar 26120
#define sipName_SelectNextChar &sipStrings_QtGui[26120]
#define sipNameNr_SelectNextLine 26135
#define sipName_SelectNextLine &sipStrings_QtGui[26135]
#define sipNameNr_SelectNextPage 26150
#define sipName_SelectNextPage &sipStrings_QtGui[26150]
#define sipNameNr_SelectNextWord 26165
#define sipName_SelectNextWord &sipStrings_QtGui[26165]
#define sipNameNr_SequenceFormat 3695
#define sipName_SequenceFormat &sipStrings_QtGui[3695]
#define sipNameNr_SkipCharacters 26180
#define sipName_SkipCharacters &sipStrings_QtGui[26180]
#define sipNameNr_SleeplessNight 26195
#define sipName_SleeplessNight &sipStrings_QtGui[26195]
#define sipNameNr_StrictNovember 26210
#define sipName_StrictNovember &sipStrings_QtGui[26210]
#define sipNameNr_SuppressColors 26225
#define sipName_SuppressColors &sipStrings_QtGui[26225]
#define sipNameNr_SurfaceCreated 26240
#define sipName_SurfaceCreated &sipStrings_QtGui[26240]
#define sipNameNr_SystemShutdown 26255
#define sipName_SystemShutdown &sipStrings_QtGui[26255]
#define sipNameNr_TransformModel 4296
#define sipName_TransformModel &sipStrings_QtGui[4296]
#define sipNameNr_Transformation 2048
#define sipName_Transformation &sipStrings_QtGui[2048]
#define sipNameNr_UltraCondensed 26270
#define sipName_UltraCondensed &sipStrings_QtGui[26270]
#define sipNameNr_UnderlineStyle 2176
#define sipName_UnderlineStyle &sipStrings_QtGui[2176]
#define sipNameNr_VariableLength 26285
#define sipName_VariableLength &sipStrings_QtGui[26285]
#define sipNameNr_ViewFullscreen 26300
#define sipName_ViewFullscreen &sipStrings_QtGui[26300]
#define sipNameNr_WeatherShowers 26315
#define sipName_WeatherShowers &sipStrings_QtGui[26315]
#define sipNameNr_accessibleText 26330
#define sipName_accessibleText &sipStrings_QtGui[26330]
#define sipNameNr_addRoundedRect 26345
#define sipName_addRoundedRect &sipStrings_QtGui[26345]
#define sipNameNr_angleAtPercent 26360
#define sipName_angleAtPercent &sipStrings_QtGui[26360]
#define sipNameNr_availableSizes 26375
#define sipName_availableSizes &sipStrings_QtGui[26375]
#define sipNameNr_backgroundMode 26390
#define sipName_backgroundMode &sipStrings_QtGui[26390]
#define sipNameNr_baseUrlChanged 26405
#define sipName_baseUrlChanged &sipStrings_QtGui[26405]
#define sipNameNr_baselineOffset 26420
#define sipName_baselineOffset &sipStrings_QtGui[26420]
#define sipNameNr_beginEditBlock 26435
#define sipName_beginEditBlock &sipStrings_QtGui[26435]
#define sipNameNr_blanchedalmond 26450
#define sipName_blanchedalmond &sipStrings_QtGui[26450]
#define sipNameNr_blueBufferSize 26465
#define sipName_blueBufferSize &sipStrings_QtGui[26465]
#define sipNameNr_borderCollapse 26480
#define sipName_borderCollapse &sipStrings_QtGui[26480]
#define sipNameNr_brightnessSize 26495
#define sipName_brightnessSize &sipStrings_QtGui[26495]
#define sipNameNr_canRedoChanged 26510
#define sipName_canRedoChanged &sipStrings_QtGui[26510]
#define sipNameNr_canUndoChanged 26525
#define sipName_canUndoChanged &sipStrings_QtGui[26525]
#define sipNameNr_capitalization 26540
#define sipName_capitalization &sipStrings_QtGui[26540]
#define sipNameNr_characterCount 26555
#define sipName_characterCount &sipStrings_QtGui[26555]
#define sipNameNr_clearSelection 26570
#define sipName_clearSelection &sipStrings_QtGui[26570]
#define sipNameNr_contentsChange 26585
#define sipName_contentsChange &sipStrings_QtGui[26585]
#define sipNameNr_coordinateMode 26600
#define sipName_coordinateMode &sipStrings_QtGui[26600]
#define sipNameNr_cornflowerblue 26615
#define sipName_cornflowerblue &sipStrings_QtGui[26615]
#define sipNameNr_currentContext 26630
#define sipName_currentContext &sipStrings_QtGui[26630]
#define sipNameNr_cursorPosition 26645
#define sipName_cursorPosition &sipStrings_QtGui[26645]
#define sipNameNr_curveThreshold 26660
#define sipName_curveThreshold &sipStrings_QtGui[26660]
#define sipNameNr_darkolivegreen 26675
#define sipName_darkolivegreen &sipStrings_QtGui[26675]
#define sipNameNr_definitionSize 26690
#define sipName_definitionSize &sipStrings_QtGui[26690]
#define sipNameNr_discardCommand 26705
#define sipName_discardCommand &sipStrings_QtGui[26705]
#define sipNameNr_distanceToLine 26720
#define sipName_distanceToLine &sipStrings_QtGui[26720]
#define sipNameNr_documentLayout 26735
#define sipName_documentLayout &sipStrings_QtGui[26735]
#define sipNameNr_documentMargin 26750
#define sipName_documentMargin &sipStrings_QtGui[26750]
#define sipNameNr_doubleProperty 26765
#define sipName_doubleProperty &sipStrings_QtGui[26765]
#define sipNameNr_drawStaticText 26780
#define sipName_drawStaticText &sipStrings_QtGui[26780]
#define sipNameNr_enabledChanged 26795
#define sipName_enabledChanged &sipStrings_QtGui[26795]
#define sipNameNr_fontFixedPitch 26810
#define sipName_fontFixedPitch &sipStrings_QtGui[26810]
#define sipNameNr_fromIccProfile 26825
#define sipName_fromIccProfile &sipStrings_QtGui[26825]
#define sipNameNr_fullRectPixels 26840
#define sipName_fullRectPixels &sipStrings_QtGui[26840]
#define sipNameNr_fullRectPoints 26855
#define sipName_fullRectPoints &sipStrings_QtGui[26855]
#define sipNameNr_getEulerAngles 26870
#define sipName_getEulerAngles &sipStrings_QtGui[26870]
#define sipNameNr_getProcAddress 26885
#define sipName_getProcAddress &sipStrings_QtGui[26885]
#define sipNameNr_globalPosition 26900
#define sipName_globalPosition &sipStrings_QtGui[26900]
#define sipNameNr_headerRowCount 26915
#define sipName_headerRowCount &sipStrings_QtGui[26915]
#define sipNameNr_highlightBlock 21011
#define sipName_highlightBlock &sipStrings_QtGui[21011]
#define sipNameNr_hslSaturationF 26930
#define sipName_hslSaturationF &sipStrings_QtGui[26930]
#define sipNameNr_hsvSaturationF 26945
#define sipName_hsvSaturationF &sipStrings_QtGui[26945]
#define sipNameNr_inputDirection 26960
#define sipName_inputDirection &sipStrings_QtGui[26960]
#define sipNameNr_insertFragment 26975
#define sipName_insertFragment &sipStrings_QtGui[26975]
#define sipNameNr_insertMarkdown 26990
#define sipName_insertMarkdown &sipStrings_QtGui[26990]
#define sipNameNr_isAutoTristate 27005
#define sipName_isAutoTristate &sipStrings_QtGui[27005]
#define sipNameNr_isEquivalentTo 27020
#define sipName_isEquivalentTo &sipStrings_QtGui[27020]
#define sipNameNr_isUserTristate 27035
#define sipName_isUserTristate &sipStrings_QtGui[27035]
#define sipNameNr_keyCombination 27050
#define sipName_keyCombination &sipStrings_QtGui[27050]
#define sipNameNr_lengthProperty 27065
#define sipName_lengthProperty &sipStrings_QtGui[27065]
#define sipNameNr_lightslategray 27080
#define sipName_lightslategray &sipStrings_QtGui[27080]
#define sipNameNr_lightslategrey 27095
#define sipName_lightslategrey &sipStrings_QtGui[27095]
#define sipNameNr_lightsteelblue 27110
#define sipName_lightsteelblue &sipStrings_QtGui[27110]
#define sipNameNr_lineHeightType 27125
#define sipName_lineHeightType &sipStrings_QtGui[27125]
#define sipNameNr_listFromString 27140
#define sipName_listFromString &sipStrings_QtGui[27140]
#define sipNameNr_maximumMargins 27155
#define sipName_maximumMargins &sipStrings_QtGui[27155]
#define sipNameNr_mediumseagreen 27170
#define sipName_mediumseagreen &sipStrings_QtGui[27170]
#define sipNameNr_minLeftBearing 27185
#define sipName_minLeftBearing &sipStrings_QtGui[27185]
#define sipNameNr_minimumMargins 27200
#define sipName_minimumMargins &sipStrings_QtGui[27200]
#define sipNameNr_mouseMoveEvent 27215
#define sipName_mouseMoveEvent &sipStrings_QtGui[27215]
#define sipNameNr_nativeScanCode 27230
#define sipName_nativeScanCode &sipStrings_QtGui[27230]
#define sipNameNr_nextFrameDelay 27245
#define sipName_nextFrameDelay &sipStrings_QtGui[27245]
#define sipNameNr_nextImageDelay 27260
#define sipName_nextImageDelay &sipStrings_QtGui[27260]
#define sipNameNr_opacityChanged 27275
#define sipName_opacityChanged &sipStrings_QtGui[27275]
#define sipNameNr_optimizedWrite 27290
#define sipName_optimizedWrite &sipStrings_QtGui[27290]
#define sipNameNr_overrideCursor 27305
#define sipName_overrideCursor &sipStrings_QtGui[27305]
#define sipNameNr_ownsFindBuffer 27320
#define sipName_ownsFindBuffer &sipStrings_QtGui[27320]
#define sipNameNr_paintingActive 27335
#define sipName_paintingActive &sipStrings_QtGui[27335]
#define sipNameNr_pointAtPercent 27350
#define sipName_pointAtPercent &sipStrings_QtGui[27350]
#define sipNameNr_pointingDevice 27365
#define sipName_pointingDevice &sipStrings_QtGui[27365]
#define sipNameNr_pressTimestamp 27380
#define sipName_pressTimestamp &sipStrings_QtGui[27380]
#define sipNameNr_proposedAction 27395
#define sipName_proposedAction &sipStrings_QtGui[27395]
#define sipNameNr_qUnpremultiply 27410
#define sipName_qUnpremultiply &sipStrings_QtGui[27410]
#define sipNameNr_renderableType 27425
#define sipName_renderableType &sipStrings_QtGui[27425]
#define sipNameNr_resetTransform 27440
#define sipName_resetTransform &sipStrings_QtGui[27440]
#define sipNameNr_restartCommand 27455
#define sipName_restartCommand &sipStrings_QtGui[27455]
#define sipNameNr_saturationSize 27470
#define sipName_saturationSize &sipStrings_QtGui[27470]
#define sipNameNr_scaledClipRect 27485
#define sipName_scaledClipRect &sipStrings_QtGui[27485]
#define sipNameNr_scaledToHeight 27500
#define sipName_scaledToHeight &sipStrings_QtGui[27500]
#define sipNameNr_selectionStart 27515
#define sipName_selectionStart &sipStrings_QtGui[27515]
#define sipNameNr_setActionGroup 27530
#define sipName_setActionGroup &sipStrings_QtGui[27530]
#define sipNameNr_setActiveStack 27545
#define sipName_setActiveStack &sipStrings_QtGui[27545]
#define sipNameNr_setAnchorNames 27560
#define sipName_setAnchorNames &sipStrings_QtGui[27560]
#define sipNameNr_setBadgeNumber 27575
#define sipName_setBadgeNumber &sipStrings_QtGui[27575]
#define sipNameNr_setBlockFormat 27590
#define sipName_setBlockFormat &sipStrings_QtGui[27590]
#define sipNameNr_setBorderBrush 27605
#define sipName_setBorderBrush &sipStrings_QtGui[27605]
#define sipNameNr_setBorderStyle 27620
#define sipName_setBorderStyle &sipStrings_QtGui[27620]
#define sipNameNr_setBrushOrigin 27635
#define sipName_setBrushOrigin &sipStrings_QtGui[27635]
#define sipNameNr_setCellPadding 27650
#define sipName_setCellPadding &sipStrings_QtGui[27650]
#define sipNameNr_setCellSpacing 27665
#define sipName_setCellSpacing &sipStrings_QtGui[27665]
#define sipNameNr_setColorScheme 21793
#define sipName_setColorScheme &sipStrings_QtGui[21793]
#define sipNameNr_setColumnCount 27680
#define sipName_setColumnCount &sipStrings_QtGui[27680]
#define sipNameNr_setCompression 27695
#define sipName_setCompression &sipStrings_QtGui[27695]
#define sipNameNr_setDashPattern 27710
#define sipName_setDashPattern &sipStrings_QtGui[27710]
#define sipNameNr_setDefaultFont 27725
#define sipName_setDefaultFont &sipStrings_QtGui[27725]
#define sipNameNr_setDescription 27740
#define sipName_setDescription &sipStrings_QtGui[27740]
#define sipNameNr_setDragEnabled 27755
#define sipName_setDragEnabled &sipStrings_QtGui[27755]
#define sipNameNr_setDropEnabled 27770
#define sipName_setDropEnabled &sipStrings_QtGui[27770]
#define sipNameNr_setFocalRadius 27785
#define sipName_setFocalRadius &sipStrings_QtGui[27785]
#define sipNameNr_setFontKerning 27800
#define sipName_setFontKerning &sipStrings_QtGui[27800]
#define sipNameNr_setFontStretch 27815
#define sipName_setFontStretch &sipStrings_QtGui[27815]
#define sipNameNr_setFrameFormat 27830
#define sipName_setFrameFormat &sipStrings_QtGui[27830]
#define sipNameNr_setIndentWidth 27845
#define sipName_setIndentWidth &sipStrings_QtGui[27845]
#define sipNameNr_setLeftPadding 27860
#define sipName_setLeftPadding &sipStrings_QtGui[27860]
#define sipNameNr_setMaximumSize 27875
#define sipName_setMaximumSize &sipStrings_QtGui[27875]
#define sipNameNr_setMinimumSize 27890
#define sipName_setMinimumSize &sipStrings_QtGui[27890]
#define sipNameNr_setNameFilters 27905
#define sipName_setNameFilters &sipStrings_QtGui[27905]
#define sipNameNr_setObjectIndex 27920
#define sipName_setObjectIndex &sipStrings_QtGui[27920]
#define sipNameNr_setOrientation 27935
#define sipName_setOrientation &sipStrings_QtGui[27935]
#define sipNameNr_setPageMargins 27950
#define sipName_setPageMargins &sipStrings_QtGui[27950]
#define sipNameNr_setPaintDevice 27965
#define sipName_setPaintDevice &sipStrings_QtGui[27965]
#define sipNameNr_setPreeditArea 27980
#define sipName_setPreeditArea &sipStrings_QtGui[27980]
#define sipNameNr_setRenderHints 27995
#define sipName_setRenderHints &sipStrings_QtGui[27995]
#define sipNameNr_setRestartHint 28010
#define sipName_setRestartHint &sipStrings_QtGui[28010]
#define sipNameNr_setRightBorder 28025
#define sipName_setRightBorder &sipStrings_QtGui[28025]
#define sipNameNr_setRightMargin 28040
#define sipName_setRightMargin &sipStrings_QtGui[28040]
#define sipNameNr_setRightToLeft 28055
#define sipName_setRightToLeft &sipStrings_QtGui[28055]
#define sipNameNr_setSurfaceType 28070
#define sipName_setSurfaceType &sipStrings_QtGui[28070]
#define sipNameNr_setTextOutline 28085
#define sipName_setTextOutline &sipStrings_QtGui[28085]
#define sipNameNr_setWindowState 28100
#define sipName_setWindowState &sipStrings_QtGui[28100]
#define sipNameNr_setWordSpacing 28115
#define sipName_setWordSpacing &sipStrings_QtGui[28115]
#define sipNameNr_showFullScreen 28130
#define sipName_showFullScreen &sipStrings_QtGui[28130]
#define sipNameNr_showStatusText 28145
#define sipName_showStatusText &sipStrings_QtGui[28145]
#define sipNameNr_slopeAtPercent 28160
#define sipName_slopeAtPercent &sipStrings_QtGui[28160]
#define sipNameNr_staticContents 28175
#define sipName_staticContents &sipStrings_QtGui[28175]
#define sipNameNr_stringProperty 28190
#define sipName_stringProperty &sipStrings_QtGui[28190]
#define sipNameNr_supportsOpenGL 28205
#define sipName_supportsOpenGL &sipStrings_QtGui[28205]
#define sipNameNr_supportsOption 28220
#define sipName_supportsOption &sipStrings_QtGui[28220]
#define sipNameNr_testRenderHint 28235
#define sipName_testRenderHint &sipStrings_QtGui[28235]
#define sipNameNr_toFillPolygons 28250
#define sipName_toFillPolygons &sipStrings_QtGui[28250]
#define sipNameNr_topBorderBrush 28265
#define sipName_topBorderBrush &sipStrings_QtGui[28265]
#define sipNameNr_topBorderStyle 28280
#define sipName_topBorderStyle &sipStrings_QtGui[28280]
#define sipNameNr_transformModel 28295
#define sipName_transformModel &sipStrings_QtGui[28295]
#define sipNameNr_transformation 28310
#define sipName_transformation &sipStrings_QtGui[28310]
#define sipNameNr_underlineColor 28325
#define sipName_underlineColor &sipStrings_QtGui[28325]
#define sipNameNr_underlineStyle 28340
#define sipName_underlineStyle &sipStrings_QtGui[28340]
#define sipNameNr_visibleChanged 28355
#define sipName_visibleChanged &sipStrings_QtGui[28355]
#define sipNameNr_worldTransform 28370
#define sipName_worldTransform &sipStrings_QtGui[28370]
#define sipNameNr_writingSystems 28385
#define sipName_writingSystems &sipStrings_QtGui[28385]
#define sipNameNr_AlignBaseline 28400
#define sipName_AlignBaseline &sipStrings_QtGui[28400]
#define sipNameNr_AlphaPosition 4381
#define sipName_AlphaPosition &sipStrings_QtGui[4381]
#define sipNameNr_AlternateBase 28414
#define sipName_AlternateBase &sipStrings_QtGui[28414]
#define sipNameNr_AttributeType 1397
#define sipName_AttributeType &sipStrings_QtGui[1397]
#define sipNameNr_BurningSpring 28428
#define sipName_BurningSpring &sipStrings_QtGui[28428]
#define sipNameNr_ColorfulPeach 28442
#define sipName_ColorfulPeach &sipStrings_QtGui[28442]
#define sipNameNr_DashUnderline 28456
#define sipName_DashUnderline &sipStrings_QtGui[28456]
#define sipNameNr_DialogWarning 28470
#define sipName_DialogWarning &sipStrings_QtGui[28470]
#define sipNameNr_DirtyClipPath 28484
#define sipName_DirtyClipPath &sipStrings_QtGui[28484]
#define sipNameNr_DocumentPrint 28498
#define sipName_DocumentPrint &sipStrings_QtGui[28498]
#define sipNameNr_DocumentTitle 28512
#define sipName_DocumentTitle &sipStrings_QtGui[28512]
#define sipNameNr_DriveHarddisk 28526
#define sipName_DriveHarddisk &sipStrings_QtGui[28526]
#define sipNameNr_EditSelectAll 28540
#define sipName_EditSelectAll &sipStrings_QtGui[28540]
#define sipNameNr_EnvelopeChou3 28554
#define sipName_EnvelopeChou3 &sipStrings_QtGui[28554]
#define sipNameNr_EnvelopeChou4 28568
#define sipName_EnvelopeChou4 &sipStrings_QtGui[28568]
#define sipNameNr_EnvelopeKaku2 28582
#define sipName_EnvelopeKaku2 &sipStrings_QtGui[28582]
#define sipNameNr_EnvelopeKaku3 28596
#define sipName_EnvelopeKaku3 &sipStrings_QtGui[28596]
#define sipNameNr_EnvelopePrc10 28610
#define sipName_EnvelopePrc10 &sipStrings_QtGui[28610]
#define sipNameNr_ExtraExpanded 28624
#define sipName_ExtraExpanded &sipStrings_QtGui[28624]
#define sipNameNr_FanFoldGerman 28638
#define sipName_FanFoldGerman &sipStrings_QtGui[28638]
#define sipNameNr_FloatingPoint 28652
#define sipName_FloatingPoint &sipStrings_QtGui[28652]
#define sipNameNr_FontPixelSize 28666
#define sipName_FontPixelSize &sipStrings_QtGui[28666]
#define sipNameNr_FontPointSize 21216
#define sipName_FontPointSize &sipStrings_QtGui[21216]
#define sipNameNr_FontStrikeOut 21233
#define sipName_FontStrikeOut &sipStrings_QtGui[21233]
#define sipNameNr_FontStyleHint 21250
#define sipName_FontStyleHint &sipStrings_QtGui[21250]
#define sipNameNr_FontStyleName 21267
#define sipName_FontStyleName &sipStrings_QtGui[21267]
#define sipNameNr_FontUnderline 21284
#define sipName_FontUnderline &sipStrings_QtGui[21284]
#define sipNameNr_Format_ARGB32 28680
#define sipName_Format_ARGB32 &sipStrings_QtGui[28680]
#define sipNameNr_Format_Alpha8 28694
#define sipName_Format_Alpha8 &sipStrings_QtGui[28694]
#define sipNameNr_Format_BGR888 28708
#define sipName_Format_BGR888 &sipStrings_QtGui[28708]
#define sipNameNr_Format_RGB444 28722
#define sipName_Format_RGB444 &sipStrings_QtGui[28722]
#define sipNameNr_Format_RGB555 28736
#define sipName_Format_RGB555 &sipStrings_QtGui[28736]
#define sipNameNr_Format_RGB666 28750
#define sipName_Format_RGB666 &sipStrings_QtGui[28750]
#define sipNameNr_Format_RGB888 28764
#define sipName_Format_RGB888 &sipStrings_QtGui[28764]
#define sipNameNr_Format_RGBA64 28778
#define sipName_Format_RGBA64 &sipStrings_QtGui[28778]
#define sipNameNr_Format_RGBX64 28792
#define sipName_Format_RGBX64 &sipStrings_QtGui[28792]
#define sipNameNr_HappyMemories 28806
#define sipName_HappyMemories &sipStrings_QtGui[28806]
#define sipNameNr_ImageMaxWidth 28820
#define sipName_ImageMaxWidth &sipStrings_QtGui[28820]
#define sipNameNr_ImageResource 28834
#define sipName_ImageResource &sipStrings_QtGui[28834]
#define sipNameNr_Imperial10x11 28848
#define sipName_Imperial10x11 &sipStrings_QtGui[28848]
#define sipNameNr_Imperial10x13 28862
#define sipName_Imperial10x13 &sipStrings_QtGui[28862]
#define sipNameNr_Imperial10x14 28876
#define sipName_Imperial10x14 &sipStrings_QtGui[28876]
#define sipNameNr_Imperial12x11 28890
#define sipName_Imperial12x11 &sipStrings_QtGui[28890]
#define sipNameNr_Imperial15x11 28904
#define sipName_Imperial15x11 &sipStrings_QtGui[28904]
#define sipNameNr_InputKeyboard 28918
#define sipName_InputKeyboard &sipStrings_QtGui[28918]
#define sipNameNr_InvalidFormat 28932
#define sipName_InvalidFormat &sipStrings_QtGui[28932]
#define sipNameNr_ItmeoBranding 28946
#define sipName_ItmeoBranding &sipStrings_QtGui[28946]
#define sipNameNr_LineToElement 28960
#define sipName_LineToElement &sipStrings_QtGui[28960]
#define sipNameNr_MidnightBloom 28974
#define sipName_MidnightBloom &sipStrings_QtGui[28974]
#define sipNameNr_MinimumHeight 21403
#define sipName_MinimumHeight &sipStrings_QtGui[21403]
#define sipNameNr_MoveOperation 4819
#define sipName_MoveOperation &sipStrings_QtGui[4819]
#define sipNameNr_MoveToElement 28988
#define sipName_MoveToElement &sipStrings_QtGui[28988]
#define sipNameNr_NextCharacter 29002
#define sipName_NextCharacter &sipStrings_QtGui[29002]
#define sipNameNr_NoFontMerging 29016
#define sipName_NoFontMerging &sipStrings_QtGui[29016]
#define sipNameNr_OldFontFamily 29030
#define sipName_OldFontFamily &sipStrings_QtGui[29030]
#define sipNameNr_OpenGLSurface 29044
#define sipName_OpenGLSurface &sipStrings_QtGui[29044]
#define sipNameNr_OpenVGSurface 29058
#define sipName_OpenVGSurface &sipStrings_QtGui[29058]
#define sipNameNr_PageBreakFlag 4873
#define sipName_PageBreakFlag &sipStrings_QtGui[4873]
#define sipNameNr_PassionateBed 29072
#define sipName_PassionateBed &sipStrings_QtGui[29072]
#define sipNameNr_PdfVersion_X4 29086
#define sipName_PdfVersion_X4 &sipStrings_QtGui[29086]
#define sipNameNr_PreferDefault 29100
#define sipName_PreferDefault &sipStrings_QtGui[29100]
#define sipNameNr_PreferOutline 29114
#define sipName_PreferOutline &sipStrings_QtGui[29114]
#define sipNameNr_PreferQuality 29128
#define sipName_PreferQuality &sipStrings_QtGui[29128]
#define sipNameNr_Premultiplied 1529
#define sipName_Premultiplied &sipStrings_QtGui[1529]
#define sipNameNr_PreviousBlock 29142
#define sipName_PreviousBlock &sipStrings_QtGui[29142]
#define sipNameNr_PreviousChild 29156
#define sipName_PreviousChild &sipStrings_QtGui[29156]
#define sipNameNr_PrimaryPoints 4684
#define sipName_PrimaryPoints &sipStrings_QtGui[4684]
#define sipNameNr_QBackingStore 29170
#define sipName_QBackingStore &sipStrings_QtGui[29170]
#define sipNameNr_QFont__Weight 29184
#define sipName_QFont__Weight &sipStrings_QtGui[29184]
#define sipNameNr_QFontDatabase 29198
#define sipName_QFontDatabase &sipStrings_QtGui[29198]
#define sipNameNr_QFontMetricsF 29212
#define sipName_QFontMetricsF &sipStrings_QtGui[29212]
#define sipNameNr_QIntValidator 29226
#define sipName_QIntValidator &sipStrings_QtGui[29226]
#define sipNameNr_29240 29240
#define sipName_29240 &sipStrings_QtGui[29240]
#define sipNameNr_QPointerEvent 29254
#define sipName_QPointerEvent &sipStrings_QtGui[29254]
#define sipNameNr_QRasterWindow 29268
#define sipName_QRasterWindow &sipStrings_QtGui[29268]
#define sipNameNr_QStandardItem 29282
#define sipName_QStandardItem &sipStrings_QtGui[29282]
#define sipNameNr_QTextDocument 29296
#define sipName_QTextDocument &sipStrings_QtGui[29296]
#define sipNameNr_QTextFragment 29310
#define sipName_QTextFragment &sipStrings_QtGui[29310]
#define sipNameNr_QWindowSystem 29324
#define sipName_QWindowSystem &sipStrings_QtGui[29324]
#define sipNameNr_RainyAshville 29338
#define sipName_RainyAshville &sipStrings_QtGui[29338]
#define sipNameNr_RasterOpModes 29352
#define sipName_RasterOpModes &sipStrings_QtGui[29352]
#define sipNameNr_RasterSurface 29366
#define sipName_RasterSurface &sipStrings_QtGui[29366]
#define sipNameNr_ReflectSpread 29380
#define sipName_ReflectSpread &sipStrings_QtGui[29380]
#define sipNameNr_RestartAnyway 29394
#define sipName_RestartAnyway &sipStrings_QtGui[29394]
#define sipNameNr_RiskyConcrete 29408
#define sipName_RiskyConcrete &sipStrings_QtGui[29408]
#define sipNameNr_ScrollStarted 29422
#define sipName_ScrollStarted &sipStrings_QtGui[29422]
#define sipNameNr_ScrollUpdated 29436
#define sipName_ScrollUpdated &sipStrings_QtGui[29436]
#define sipNameNr_SelectionType 4846
#define sipName_SelectionType &sipStrings_QtGui[4846]
#define sipNameNr_SemiCondensed 29450
#define sipName_SemiCondensed &sipStrings_QtGui[29450]
#define sipNameNr_SequenceMatch 4353
#define sipName_SequenceMatch &sipStrings_QtGui[4353]
#define sipNameNr_SharpeyeEagle 29464
#define sipName_SharpeyeEagle &sipStrings_QtGui[29464]
#define sipNameNr_SplitLigature 29478
#define sipName_SplitLigature &sipStrings_QtGui[29478]
#define sipNameNr_StereoBuffers 29492
#define sipName_StereoBuffers &sipStrings_QtGui[29492]
#define sipNameNr_StyleStrategy 10694
#define sipName_StyleStrategy &sipStrings_QtGui[10694]
#define sipNameNr_SugarLollipop 29506
#define sipName_SugarLollipop &sipStrings_QtGui[29506]
#define sipNameNr_TemptingAzure 29520
#define sipName_TemptingAzure &sipStrings_QtGui[29520]
#define sipNameNr_UltraExpanded 29534
#define sipName_UltraExpanded &sipStrings_QtGui[29534]
#define sipNameNr_UnsignedShort 29548
#define sipName_UnsignedShort &sipStrings_QtGui[29548]
#define sipNameNr_UserAvailable 29562
#define sipName_UserAvailable &sipStrings_QtGui[29562]
#define sipNameNr_ViciousStance 29576
#define sipName_ViciousStance &sipStrings_QtGui[29576]
#define sipNameNr_VulkanSurface 29590
#define sipName_VulkanSurface &sipStrings_QtGui[29590]
#define sipNameNr_WaveUnderline 29604
#define sipName_WaveUnderline &sipStrings_QtGui[29604]
#define sipNameNr_WritingSystem 3609
#define sipName_WritingSystem &sipStrings_QtGui[3609]
#define sipNameNr_accessibility 29618
#define sipName_accessibility &sipStrings_QtGui[29618]
#define sipNameNr_actionChanged 29632
#define sipName_actionChanged &sipStrings_QtGui[29632]
#define sipNameNr_activeChanged 29646
#define sipName_activeChanged &sipStrings_QtGui[29646]
#define sipNameNr_alphaPosition 29660
#define sipName_alphaPosition &sipStrings_QtGui[29660]
#define sipNameNr_alternateBase 29674
#define sipName_alternateBase &sipStrings_QtGui[29674]
#define sipNameNr_appendColumns 29688
#define sipName_appendColumns &sipStrings_QtGui[29688]
#define sipNameNr_autoTransform 29702
#define sipName_autoTransform &sipStrings_QtGui[29702]
#define sipNameNr_availableSize 29716
#define sipName_availableSize &sipStrings_QtGui[29716]
#define sipNameNr_bitPlaneCount 29730
#define sipName_bitPlaneCount &sipStrings_QtGui[29730]
#define sipNameNr_blockInserted 29744
#define sipName_blockInserted &sipStrings_QtGui[29744]
#define sipNameNr_bottomPadding 29758
#define sipName_bottomPadding &sipStrings_QtGui[29758]
#define sipNameNr_brushProperty 29772
#define sipName_brushProperty &sipStrings_QtGui[29772]
#define sipNameNr_checkedAction 29786
#define sipName_checkedAction &sipStrings_QtGui[29786]
#define sipNameNr_clearFeatures 29800
#define sipName_clearFeatures &sipStrings_QtGui[29800]
#define sipNameNr_clearItemData 29814
#define sipName_clearItemData &sipStrings_QtGui[29814]
#define sipNameNr_clearProperty 29828
#define sipName_clearProperty &sipStrings_QtGui[29828]
#define sipNameNr_clipOperation 29842
#define sipName_clipOperation &sipStrings_QtGui[29842]
#define sipNameNr_colorProperty 29856
#define sipName_colorProperty &sipStrings_QtGui[29856]
#define sipNameNr_connectNotify 20689
#define sipName_connectNotify &sipStrings_QtGui[20689]
#define sipNameNr_constScanLine 29870
#define sipName_constScanLine &sipStrings_QtGui[29870]
#define sipNameNr_containsPoint 29884
#define sipName_containsPoint &sipStrings_QtGui[29884]
#define sipNameNr_currentPixmap 29898
#define sipName_currentPixmap &sipStrings_QtGui[29898]
#define sipNameNr_darkgoldenrod 29912
#define sipName_darkgoldenrod &sipStrings_QtGui[29912]
#define sipNameNr_darkslateblue 29926
#define sipName_darkslateblue &sipStrings_QtGui[29926]
#define sipNameNr_darkslategray 29940
#define sipName_darkslategray &sipStrings_QtGui[29940]
#define sipNameNr_darkslategrey 29954
#define sipName_darkslategrey &sipStrings_QtGui[29954]
#define sipNameNr_darkturquoise 29968
#define sipName_darkturquoise &sipStrings_QtGui[29968]
#define sipNameNr_defaultAction 29982
#define sipName_defaultAction &sipStrings_QtGui[29982]
#define sipNameNr_defaultFamily 29996
#define sipName_defaultFamily &sipStrings_QtGui[29996]
#define sipNameNr_defaultFormat 30010
#define sipName_defaultFormat &sipStrings_QtGui[30010]
#define sipNameNr_dotsPerMeterX 30024
#define sipName_dotsPerMeterX &sipStrings_QtGui[30024]
#define sipNameNr_dotsPerMeterY 30038
#define sipName_dotsPerMeterY &sipStrings_QtGui[30038]
#define sipNameNr_firstPosition 30052
#define sipName_firstPosition &sipStrings_QtGui[30052]
#define sipNameNr_focusOutEvent 30066
#define sipName_focusOutEvent &sipStrings_QtGui[30066]
#define sipNameNr_fontPointSize 30080
#define sipName_fontPointSize &sipStrings_QtGui[30080]
#define sipNameNr_fontStrikeOut 30094
#define sipName_fontStrikeOut &sipStrings_QtGui[30094]
#define sipNameNr_fontStyleHint 30108
#define sipName_fontStyleHint &sipStrings_QtGui[30108]
#define sipNameNr_fontStyleName 30122
#define sipName_fontStyleName &sipStrings_QtGui[30122]
#define sipNameNr_fontUnderline 30136
#define sipName_fontUnderline &sipStrings_QtGui[30136]
#define sipNameNr_formatVersion 30150
#define sipName_formatVersion &sipStrings_QtGui[30150]
#define sipNameNr_frameGeometry 30164
#define sipName_frameGeometry &sipStrings_QtGui[30164]
#define sipNameNr_framePosition 30178
#define sipName_framePosition &sipStrings_QtGui[30178]
#define sipNameNr_fromDirection 30192
#define sipName_fromDirection &sipStrings_QtGui[30192]
#define sipNameNr_fromNumericId 30206
#define sipName_fromNumericId &sipStrings_QtGui[30206]
#define sipNameNr_fromPlainText 30220
#define sipName_fromPlainText &sipStrings_QtGui[30220]
#define sipNameNr_fromPrimaries 30234
#define sipName_fromPrimaries &sipStrings_QtGui[30234]
#define sipNameNr_fromTranslate 30248
#define sipName_fromTranslate &sipStrings_QtGui[30248]
#define sipNameNr_hasCapability 30262
#define sipName_hasCapability &sipStrings_QtGui[30262]
#define sipNameNr_heightChanged 30276
#define sipName_heightChanged &sipStrings_QtGui[30276]
#define sipNameNr_hslSaturation 30290
#define sipName_hslSaturation &sipStrings_QtGui[30290]
#define sipNameNr_hsvSaturation 30304
#define sipName_hsvSaturation &sipStrings_QtGui[30304]
#define sipNameNr_indexFromItem 30318
#define sipName_indexFromItem &sipStrings_QtGui[30318]
#define sipNameNr_insertColumns 30332
#define sipName_insertColumns &sipStrings_QtGui[30332]
#define sipNameNr_intrinsicSize 30346
#define sipName_intrinsicSize &sipStrings_QtGui[30346]
#define sipNameNr_isBlockFormat 30360
#define sipName_isBlockFormat &sipStrings_QtGui[30360]
#define sipNameNr_isClipEnabled 30374
#define sipName_isClipEnabled &sipStrings_QtGui[30374]
#define sipNameNr_isDragEnabled 30388
#define sipName_isDragEnabled &sipStrings_QtGui[30388]
#define sipNameNr_isDropEnabled 30402
#define sipName_isDropEnabled &sipStrings_QtGui[30402]
#define sipNameNr_isFrameFormat 30416
#define sipName_isFrameFormat &sipStrings_QtGui[30416]
#define sipNameNr_isImageFormat 30430
#define sipName_isImageFormat &sipStrings_QtGui[30430]
#define sipNameNr_isLeftToRight 30444
#define sipName_isLeftToRight &sipStrings_QtGui[30444]
#define sipNameNr_isRightToLeft 30458
#define sipName_isRightToLeft &sipStrings_QtGui[30458]
#define sipNameNr_isTableFormat 30472
#define sipName_isTableFormat &sipStrings_QtGui[30472]
#define sipNameNr_isTranslating 30486
#define sipName_isTranslating &sipStrings_QtGui[30486]
#define sipNameNr_isTransparent 30500
#define sipName_isTransparent &sipStrings_QtGui[30500]
#define sipNameNr_isUpdateEvent 30514
#define sipName_isUpdateEvent &sipStrings_QtGui[30514]
#define sipNameNr_isValidTarget 30528
#define sipName_isValidTarget &sipStrings_QtGui[30528]
#define sipNameNr_itemFromIndex 30542
#define sipName_itemFromIndex &sipStrings_QtGui[30542]
#define sipNameNr_itemPrototype 30556
#define sipName_itemPrototype &sipStrings_QtGui[30556]
#define sipNameNr_keyPressEvent 30570
#define sipName_keyPressEvent &sipStrings_QtGui[30570]
#define sipNameNr_lastTimestamp 30584
#define sipName_lastTimestamp &sipStrings_QtGui[30584]
#define sipNameNr_lavenderblush 30598
#define sipName_lavenderblush &sipStrings_QtGui[30598]
#define sipNameNr_lengthSquared 30612
#define sipName_lengthSquared &sipStrings_QtGui[30612]
#define sipNameNr_letterSpacing 30626
#define sipName_letterSpacing &sipStrings_QtGui[30626]
#define sipNameNr_lightnessSize 30640
#define sipName_lightnessSize &sipStrings_QtGui[30640]
#define sipNameNr_lightseagreen 30654
#define sipName_lightseagreen &sipStrings_QtGui[30654]
#define sipNameNr_lineThickness 30668
#define sipName_lineThickness &sipStrings_QtGui[30668]
#define sipNameNr_localeChanged 30682
#define sipName_localeChanged &sipStrings_QtGui[30682]
#define sipNameNr_mapFromGlobal 30696
#define sipName_mapFromGlobal &sipStrings_QtGui[30696]
#define sipNameNr_marginsPixels 30710
#define sipName_marginsPixels &sipStrings_QtGui[30710]
#define sipNameNr_marginsPoints 30724
#define sipName_marginsPoints &sipStrings_QtGui[30724]
#define sipNameNr_maximumHeight 30738
#define sipName_maximumHeight &sipStrings_QtGui[30738]
#define sipNameNr_maximumPoints 30752
#define sipName_maximumPoints &sipStrings_QtGui[30752]
#define sipNameNr_minimumHeight 30766
#define sipName_minimumHeight &sipStrings_QtGui[30766]
#define sipNameNr_outputProfile 30780
#define sipName_outputProfile &sipStrings_QtGui[30780]
#define sipNameNr_ownsClipboard 30794
#define sipName_ownsClipboard &sipStrings_QtGui[30794]
#define sipNameNr_ownsSelection 30808
#define sipName_ownsSelection &sipStrings_QtGui[30808]
#define sipNameNr_palegoldenrod 30822
#define sipName_palegoldenrod &sipStrings_QtGui[30822]
#define sipNameNr_paleturquoise 30836
#define sipName_paleturquoise &sipStrings_QtGui[30836]
#define sipNameNr_palevioletred 30850
#define sipName_palevioletred &sipStrings_QtGui[30850]
#define sipNameNr_preeditString 30864
#define sipName_preeditString &sipStrings_QtGui[30864]
#define sipNameNr_premultiplied 25112
#define sipName_premultiplied &sipStrings_QtGui[25112]
#define sipNameNr_pressPosition 30878
#define sipName_pressPosition &sipStrings_QtGui[30878]
#define sipNameNr_primaryPoints 30892
#define sipName_primaryPoints &sipStrings_QtGui[30892]
#define sipNameNr_primaryScreen 30906
#define sipName_primaryScreen &sipStrings_QtGui[30906]
#define sipNameNr_propertyCount 30920
#define sipName_propertyCount &sipStrings_QtGui[30920]
#define sipNameNr_qFuzzyCompare 30934
#define sipName_qFuzzyCompare &sipStrings_QtGui[30934]
#define sipNameNr_redBufferSize 30948
#define sipName_redBufferSize &sipStrings_QtGui[30948]
#define sipNameNr_redoAvailable 30962
#define sipName_redoAvailable &sipStrings_QtGui[30962]
#define sipNameNr_removeColumns 30976
#define sipName_removeColumns &sipStrings_QtGui[30976]
#define sipNameNr_requestPhase2 30990
#define sipName_requestPhase2 &sipStrings_QtGui[30990]
#define sipNameNr_requestUpdate 31004
#define sipName_requestUpdate &sipStrings_QtGui[31004]
#define sipNameNr_rootDirectory 31018
#define sipName_rootDirectory &sipStrings_QtGui[31018]
#define sipNameNr_rotateRadians 31032
#define sipName_rotateRadians &sipStrings_QtGui[31032]
#define sipNameNr_rotatedVector 31046
#define sipName_rotatedVector &sipStrings_QtGui[31046]
#define sipNameNr_scaledToWidth 31060
#define sipName_scaledToWidth &sipStrings_QtGui[31060]
#define sipNameNr_scenePosition 31074
#define sipName_scenePosition &sipStrings_QtGui[31074]
#define sipNameNr_screenChanged 31088
#define sipName_screenChanged &sipStrings_QtGui[31088]
#define sipNameNr_screenRemoved 31102
#define sipName_screenRemoved &sipStrings_QtGui[31102]
#define sipNameNr_setAnchorHref 31116
#define sipName_setAnchorHref &sipStrings_QtGui[31116]
#define sipNameNr_setAutoRepeat 31130
#define sipName_setAutoRepeat &sipStrings_QtGui[31130]
#define sipNameNr_setBackground 31144
#define sipName_setBackground &sipStrings_QtGui[31144]
#define sipNameNr_setCacheLimit 31158
#define sipName_setCacheLimit &sipStrings_QtGui[31158]
#define sipNameNr_setCharFormat 31172
#define sipName_setCharFormat &sipStrings_QtGui[31172]
#define sipNameNr_setCheckState 31186
#define sipName_setCheckState &sipStrings_QtGui[31186]
#define sipNameNr_setClipRegion 31200
#define sipName_setClipRegion &sipStrings_QtGui[31200]
#define sipNameNr_setColorCount 31214
#define sipName_setColorCount &sipStrings_QtGui[31214]
#define sipNameNr_setColorGroup 31228
#define sipName_setColorGroup &sipStrings_QtGui[31228]
#define sipNameNr_setColorModel 31242
#define sipName_setColorModel &sipStrings_QtGui[31242]
#define sipNameNr_setColorSpace 31256
#define sipName_setColorSpace &sipStrings_QtGui[31256]
#define sipNameNr_setColorTable 31270
#define sipName_setColorTable &sipStrings_QtGui[31270]
#define sipNameNr_setContentPos 31284
#define sipName_setContentPos &sipStrings_QtGui[31284]
#define sipNameNr_setDashOffset 31298
#define sipName_setDashOffset &sipStrings_QtGui[31298]
#define sipNameNr_setDocumentId 31312
#define sipName_setDocumentId &sipStrings_QtGui[31312]
#define sipNameNr_setDragCursor 31326
#define sipName_setDragCursor &sipStrings_QtGui[31326]
#define sipNameNr_setDropAction 31340
#define sipName_setDropAction &sipStrings_QtGui[31340]
#define sipNameNr_setFixedPitch 31354
#define sipName_setFixedPitch &sipStrings_QtGui[31354]
#define sipNameNr_setFocalPoint 31368
#define sipName_setFocalPoint &sipStrings_QtGui[31368]
#define sipNameNr_setFontFamily 31382
#define sipName_setFontFamily &sipStrings_QtGui[31382]
#define sipNameNr_setFontItalic 31396
#define sipName_setFontItalic &sipStrings_QtGui[31396]
#define sipNameNr_setFontWeight 31410
#define sipName_setFontWeight &sipStrings_QtGui[31410]
#define sipNameNr_setForeground 31424
#define sipName_setForeground &sipStrings_QtGui[31424]
#define sipNameNr_setHeaderData 31438
#define sipName_setHeaderData &sipStrings_QtGui[31438]
#define sipNameNr_setLeftBorder 31452
#define sipName_setLeftBorder &sipStrings_QtGui[31452]
#define sipNameNr_setLeftMargin 31466
#define sipName_setLeftMargin &sipStrings_QtGui[31466]
#define sipNameNr_setLineHeight 31480
#define sipName_setLineHeight &sipStrings_QtGui[31480]
#define sipNameNr_setMiterLimit 31494
#define sipName_setMiterLimit &sipStrings_QtGui[31494]
#define sipNameNr_setNamedColor 31508
#define sipName_setNamedColor &sipStrings_QtGui[31508]
#define sipNameNr_setNumColumns 31522
#define sipName_setNumColumns &sipStrings_QtGui[31522]
#define sipNameNr_setObjectType 31536
#define sipName_setObjectType &sipStrings_QtGui[31536]
#define sipNameNr_setPageLayout 31550
#define sipName_setPageLayout &sipStrings_QtGui[31550]
#define sipNameNr_setPageRanges 31564
#define sipName_setPageRanges &sipStrings_QtGui[31564]
#define sipNameNr_setPdfVersion 31578
#define sipName_setPdfVersion &sipStrings_QtGui[31578]
#define sipNameNr_setPixelColor 31592
#define sipName_setPixelColor &sipStrings_QtGui[31592]
#define sipNameNr_setPointSizeF 31606
#define sipName_setPointSizeF &sipStrings_QtGui[31606]
#define sipNameNr_setRenderHint 31620
#define sipName_setRenderHint &sipStrings_QtGui[31620]
#define sipNameNr_setResolution 31634
#define sipName_setResolution &sipStrings_QtGui[31634]
#define sipNameNr_setScaledSize 31648
#define sipName_setScaledSize &sipStrings_QtGui[31648]
#define sipNameNr_setSelectable 31662
#define sipName_setSelectable &sipStrings_QtGui[31662]
#define sipNameNr_setTextFormat 31676
#define sipName_setTextFormat &sipStrings_QtGui[31676]
#define sipNameNr_setTextIndent 31690
#define sipName_setTextIndent &sipStrings_QtGui[31690]
#define sipNameNr_setTextOption 31704
#define sipName_setTextOption &sipStrings_QtGui[31704]
#define sipNameNr_setToIdentity 31718
#define sipName_setToIdentity &sipStrings_QtGui[31718]
#define sipNameNr_setTopPadding 31732
#define sipName_setTopPadding &sipStrings_QtGui[31732]
#define sipNameNr_setUrlHandler 25128
#define sipName_setUrlHandler &sipStrings_QtGui[25128]
#define sipNameNr_setVisibility 31746
#define sipName_setVisibility &sipStrings_QtGui[31746]
#define sipNameNr_setWhitePoint 31760
#define sipName_setWhitePoint &sipStrings_QtGui[31760]
#define sipNameNr_setWindowIcon 31774
#define sipName_setWindowIcon &sipStrings_QtGui[31774]
#define sipNameNr_showMaximized 31788
#define sipName_showMaximized &sipStrings_QtGui[31788]
#define sipNameNr_showMinimized 31802
#define sipName_showMinimized &sipStrings_QtGui[31802]
#define sipNameNr_sizeIncrement 31816
#define sipName_sizeIncrement &sipStrings_QtGui[31816]
#define sipNameNr_standardSizes 31830
#define sipName_standardSizes &sipStrings_QtGui[31830]
#define sipNameNr_startDragTime 31844
#define sipName_startDragTime &sipStrings_QtGui[31844]
#define sipNameNr_stringIndexes 31858
#define sipName_stringIndexes &sipStrings_QtGui[31858]
#define sipNameNr_styleStrategy 31872
#define sipName_styleStrategy &sipStrings_QtGui[31872]
#define sipNameNr_substitutions 31886
#define sipName_substitutions &sipStrings_QtGui[31886]
#define sipNameNr_targetChanged 31900
#define sipName_targetChanged &sipStrings_QtGui[31900]
#define sipNameNr_textAlignment 31914
#define sipName_textAlignment &sipStrings_QtGui[31914]
#define sipNameNr_textDirection 31928
#define sipName_textDirection &sipStrings_QtGui[31928]
#define sipNameNr_toBlockFormat 31942
#define sipName_toBlockFormat &sipStrings_QtGui[31942]
#define sipNameNr_toEulerAngles 31956
#define sipName_toEulerAngles &sipStrings_QtGui[31956]
#define sipNameNr_toExtendedRgb 31970
#define sipName_toExtendedRgb &sipStrings_QtGui[31970]
#define sipNameNr_toFillPolygon 31984
#define sipName_toFillPolygon &sipStrings_QtGui[31984]
#define sipNameNr_toFrameFormat 31998
#define sipName_toFrameFormat &sipStrings_QtGui[31998]
#define sipNameNr_toImageFormat 32012
#define sipName_toImageFormat &sipStrings_QtGui[32012]
#define sipNameNr_toPixelFormat 32026
#define sipName_toPixelFormat &sipStrings_QtGui[32026]
#define sipNameNr_toTableFormat 32040
#define sipName_toTableFormat &sipStrings_QtGui[32040]
#define sipNameNr_transformMode 32054
#define sipName_transformMode &sipStrings_QtGui[32054]
#define sipNameNr_undoAvailable 32068
#define sipName_undoAvailable &sipStrings_QtGui[32068]
#define sipNameNr_writingSystem 32082
#define sipName_writingSystem &sipStrings_QtGui[32082]
#define sipNameNr_AfricanField 32096
#define sipName_AfricanField &sipStrings_QtGui[32096]
#define sipNameNr_AlchemistLab 32109
#define sipName_AlchemistLab &sipStrings_QtGui[32109]
#define sipNameNr_AllLowercase 32122
#define sipName_AllLowercase &sipStrings_QtGui[32122]
#define sipNameNr_AllUppercase 32135
#define sipName_AllUppercase &sipStrings_QtGui[32135]
#define sipNameNr_AncestorMode 9584
#define sipName_AncestorMode &sipStrings_QtGui[9584]
#define sipNameNr_Antialiasing 10989
#define sipName_Antialiasing &sipStrings_QtGui[10989]
#define sipNameNr_AquaGuidance 32148
#define sipName_AquaGuidance &sipStrings_QtGui[32148]
#define sipNameNr_CoreGraphics 32161
#define sipName_CoreGraphics &sipStrings_QtGui[32161]
#define sipNameNr_CrystalRiver 32174
#define sipName_CrystalRiver &sipStrings_QtGui[32174]
#define sipNameNr_DebugContext 32187
#define sipName_DebugContext &sipStrings_QtGui[32187]
#define sipNameNr_DelimiterTab 32200
#define sipName_DelimiterTab &sipStrings_QtGui[32200]
#define sipNameNr_DirtyOpacity 32213
#define sipName_DirtyOpacity &sipStrings_QtGui[32213]
#define sipNameNr_DocumentOpen 32226
#define sipName_DocumentOpen &sipStrings_QtGui[32226]
#define sipNameNr_DocumentSave 32239
#define sipName_DocumentSave &sipStrings_QtGui[32239]
#define sipNameNr_DocumentSend 32252
#define sipName_DocumentSend &sipStrings_QtGui[32252]
#define sipNameNr_DoubleBuffer 32265
#define sipName_DoubleBuffer &sipStrings_QtGui[32265]
#define sipNameNr_DriveOptical 32278
#define sipName_DriveOptical &sipStrings_QtGui[32278]
#define sipNameNr_EnvelopePrc1 32291
#define sipName_EnvelopePrc1 &sipStrings_QtGui[32291]
#define sipNameNr_EnvelopePrc2 32304
#define sipName_EnvelopePrc2 &sipStrings_QtGui[32304]
#define sipNameNr_EnvelopePrc3 32317
#define sipName_EnvelopePrc3 &sipStrings_QtGui[32317]
#define sipNameNr_EnvelopePrc4 32330
#define sipName_EnvelopePrc4 &sipStrings_QtGui[32330]
#define sipNameNr_EnvelopePrc5 32343
#define sipName_EnvelopePrc5 &sipStrings_QtGui[32343]
#define sipNameNr_EnvelopePrc6 32356
#define sipName_EnvelopePrc6 &sipStrings_QtGui[32356]
#define sipNameNr_EnvelopePrc7 32369
#define sipName_EnvelopePrc7 &sipStrings_QtGui[32369]
#define sipNameNr_EnvelopePrc8 32382
#define sipName_EnvelopePrc8 &sipStrings_QtGui[32382]
#define sipNameNr_EnvelopePrc9 32395
#define sipName_EnvelopePrc9 &sipStrings_QtGui[32395]
#define sipNameNr_EnvelopeYou4 32408
#define sipName_EnvelopeYou4 &sipStrings_QtGui[32408]
#define sipNameNr_FabledSunset 32421
#define sipName_FabledSunset &sipStrings_QtGui[32421]
#define sipNameNr_FarawayRiver 32434
#define sipName_FarawayRiver &sipStrings_QtGui[32434]
#define sipNameNr_FileIconRole 32447
#define sipName_FileIconRole &sipStrings_QtGui[32447]
#define sipNameNr_FileInfoRole 32460
#define sipName_FileInfoRole &sipStrings_QtGui[32460]
#define sipNameNr_FileNameRole 32473
#define sipName_FileNameRole &sipStrings_QtGui[32473]
#define sipNameNr_FilePathRole 32486
#define sipName_FilePathRole &sipStrings_QtGui[32486]
#define sipNameNr_FindBackward 32499
#define sipName_FindBackward &sipStrings_QtGui[32499]
#define sipNameNr_FindPrevious 32512
#define sipName_FindPrevious &sipStrings_QtGui[32512]
#define sipNameNr_FontFamilies 1061
#define sipName_FontFamilies &sipStrings_QtGui[1061]
#define sipNameNr_FontFeatures 24601
#define sipName_FontFeatures &sipStrings_QtGui[24601]
#define sipNameNr_FontOverline 24617
#define sipName_FontOverline &sipStrings_QtGui[24617]
#define sipNameNr_ForceOutline 32525
#define sipName_ForceOutline &sipStrings_QtGui[32525]
#define sipNameNr_FormatOption 3842
#define sipName_FormatOption &sipStrings_QtGui[3842]
#define sipNameNr_Format_BGR30 32538
#define sipName_Format_BGR30 &sipStrings_QtGui[32538]
#define sipNameNr_Format_RGB16 32551
#define sipName_Format_RGB16 &sipStrings_QtGui[32551]
#define sipNameNr_Format_RGB30 32564
#define sipName_Format_RGB30 &sipStrings_QtGui[32564]
#define sipNameNr_Format_RGB32 32577
#define sipName_Format_RGB32 &sipStrings_QtGui[32577]
#define sipNameNr_FramePadding 32590
#define sipName_FramePadding &sipStrings_QtGui[32590]
#define sipNameNr_FrozenDreams 32603
#define sipName_FrozenDreams &sipStrings_QtGui[32603]
#define sipNameNr_FullPageMode 32616
#define sipName_FullPageMode &sipStrings_QtGui[32616]
#define sipNameNr_GlyphRunFlag 7067
#define sipName_GlyphRunFlag &sipStrings_QtGui[7067]
#define sipNameNr_GrassShampoo 32629
#define sipName_GrassShampoo &sipStrings_QtGui[32629]
#define sipNameNr_HappyUnicorn 32642
#define sipName_HappyUnicorn &sipStrings_QtGui[32642]
#define sipNameNr_HeadingLevel 24649
#define sipName_HeadingLevel &sipStrings_QtGui[24649]
#define sipNameNr_HealthyWater 32655
#define sipName_HealthyWater &sipStrings_QtGui[32655]
#define sipNameNr_HelpContents 32668
#define sipName_HelpContents &sipStrings_QtGui[32668]
#define sipNameNr_HiddenJaguar 32681
#define sipName_HiddenJaguar &sipStrings_QtGui[32681]
#define sipNameNr_HighPriority 32694
#define sipName_HighPriority &sipStrings_QtGui[32694]
#define sipNameNr_HtmlResource 32707
#define sipName_HtmlResource &sipStrings_QtGui[32707]
#define sipNameNr_IgnoresAlpha 32720
#define sipName_IgnoresAlpha &sipStrings_QtGui[32720]
#define sipNameNr_ImageAltText 32733
#define sipName_ImageAltText &sipStrings_QtGui[32733]
#define sipNameNr_ImageLoading 32746
#define sipName_ImageLoading &sipStrings_QtGui[32746]
#define sipNameNr_ImageMissing 32759
#define sipName_ImageMissing &sipStrings_QtGui[32759]
#define sipNameNr_ImageQuality 32772
#define sipName_ImageQuality &sipStrings_QtGui[32772]
#define sipNameNr_Imperial8x10 32785
#define sipName_Imperial8x10 &sipStrings_QtGui[32785]
#define sipNameNr_Imperial9x11 32798
#define sipName_Imperial9x11 &sipStrings_QtGui[32798]
#define sipNameNr_Imperial9x12 32811
#define sipName_Imperial9x12 &sipStrings_QtGui[32811]
#define sipNameNr_InitialState 1497
#define sipName_InitialState &sipStrings_QtGui[1497]
#define sipNameNr_Intermediate 32824
#define sipName_Intermediate &sipStrings_QtGui[32824]
#define sipNameNr_LadogaBottom 32837
#define sipName_LadogaBottom &sipStrings_QtGui[32837]
#define sipNameNr_LastPageSize 32850
#define sipName_LastPageSize &sipStrings_QtGui[32850]
#define sipNameNr_LittleEndian 32863
#define sipName_LittleEndian &sipStrings_QtGui[32863]
#define sipNameNr_MailMarkRead 32876
#define sipName_MailMarkRead &sipStrings_QtGui[32876]
#define sipNameNr_MailReplyAll 32889
#define sipName_MailReplyAll &sipStrings_QtGui[32889]
#define sipNameNr_MediaOptical 32902
#define sipName_MediaOptical &sipStrings_QtGui[32902]
#define sipNameNr_MetalSurface 32915
#define sipName_MetalSurface &sipStrings_QtGui[32915]
#define sipNameNr_MorningSalad 32928
#define sipName_MorningSalad &sipStrings_QtGui[32928]
#define sipNameNr_MountainRock 32941
#define sipName_MountainRock &sipStrings_QtGui[32941]
#define sipNameNr_NColorGroups 32954
#define sipName_NColorGroups &sipStrings_QtGui[32954]
#define sipNameNr_NetworkWired 32967
#define sipName_NetworkWired &sipStrings_QtGui[32967]
#define sipNameNr_NewRetrowave 32980
#define sipName_NewRetrowave &sipStrings_QtGui[32980]
#define sipNameNr_NorthMiracle 32993
#define sipName_NorthMiracle &sipStrings_QtGui[32993]
#define sipNameNr_PaintContext 169
#define sipName_PaintContext &sipStrings_QtGui[169]
#define sipNameNr_PainterPaths 33006
#define sipName_PainterPaths &sipStrings_QtGui[33006]
#define sipNameNr_PartialMatch 33019
#define sipName_PartialMatch &sipStrings_QtGui[33019]
#define sipNameNr_PatternBrush 33032
#define sipName_PatternBrush &sipStrings_QtGui[33032]
#define sipNameNr_PdmNumColors 33045
#define sipName_PdmNumColors &sipStrings_QtGui[33045]
#define sipNameNr_PerfectWhite 33058
#define sipName_PerfectWhite &sipStrings_QtGui[33058]
#define sipNameNr_PhoenixStart 33071
#define sipName_PhoenixStart &sipStrings_QtGui[33071]
#define sipNameNr_PoliteRumors 33084
#define sipName_PoliteRumors &sipStrings_QtGui[33084]
#define sipNameNr_PolylineMode 33097
#define sipName_PolylineMode &sipStrings_QtGui[33097]
#define sipNameNr_PortableText 33110
#define sipName_PortableText &sipStrings_QtGui[33110]
#define sipNameNr_PreferBitmap 33123
#define sipName_PreferBitmap &sipStrings_QtGui[33123]
#define sipNameNr_PreferDevice 33136
#define sipName_PreferDevice &sipStrings_QtGui[33136]
#define sipNameNr_PremiumWhite 33149
#define sipName_PremiumWhite &sipStrings_QtGui[33149]
#define sipNameNr_PreviousCell 33162
#define sipName_PreviousCell &sipStrings_QtGui[33162]
#define sipNameNr_PreviousWord 14133
#define sipName_PreviousWord &sipStrings_QtGui[14133]
#define sipNameNr_QActionEvent 33175
#define sipName_QActionEvent &sipStrings_QtGui[33175]
#define sipNameNr_QActionGroup 33188
#define sipName_QActionGroup &sipStrings_QtGui[33188]
#define sipNameNr_QColor__Spec 33201
#define sipName_QColor__Spec &sipStrings_QtGui[33201]
#define sipNameNr_QExposeEvent 33214
#define sipName_QExposeEvent &sipStrings_QtGui[33214]
#define sipNameNr_QFont__Style 33227
#define sipName_QFont__Style &sipStrings_QtGui[33227]
#define sipNameNr_QFontMetrics 33240
#define sipName_QFontMetrics &sipStrings_QtGui[33240]
#define sipNameNr_QIcon__State 33253
#define sipName_QIcon__State &sipStrings_QtGui[33253]
#define sipNameNr_QImageReader 33266
#define sipName_QImageReader &sipStrings_QtGui[33266]
#define sipNameNr_QImageWriter 33279
#define sipName_QImageWriter &sipStrings_QtGui[33279]
#define sipNameNr_QInputDevice 33292
#define sipName_QInputDevice &sipStrings_QtGui[33292]
#define sipNameNr_QInputMethod 33305
#define sipName_QInputMethod &sipStrings_QtGui[33305]
#define sipNameNr_QKeySequence 33318
#define sipName_QKeySequence &sipStrings_QtGui[33318]
#define sipNameNr_33331 33331
#define sipName_33331 &sipStrings_QtGui[33331]
#define sipNameNr_33344 33344
#define sipName_33344 &sipStrings_QtGui[33344]
#define sipNameNr_QPaintDevice 33357
#define sipName_QPaintDevice &sipStrings_QtGui[33357]
#define sipNameNr_QPaintEngine 33370
#define sipName_QPaintEngine &sipStrings_QtGui[33370]
#define sipNameNr_QPainterPath 33383
#define sipName_QPainterPath &sipStrings_QtGui[33383]
#define sipNameNr_QPixelFormat 33396
#define sipName_QPixelFormat &sipStrings_QtGui[33396]
#define sipNameNr_QPixmapCache 33409
#define sipName_QPixmapCache &sipStrings_QtGui[33409]
#define sipNameNr_QResizeEvent 33422
#define sipName_QResizeEvent &sipStrings_QtGui[33422]
#define sipNameNr_QScrollEvent 33435
#define sipName_QScrollEvent &sipStrings_QtGui[33435]
#define sipNameNr_QTabletEvent 33448
#define sipName_QTabletEvent &sipStrings_QtGui[33448]
#define sipNameNr_QUndoCommand 33461
#define sipName_QUndoCommand &sipStrings_QtGui[33461]
#define sipNameNr_RedSalvation 33474
#define sipName_RedSalvation &sipStrings_QtGui[33474]
#define sipNameNr_RepeatSpread 33487
#define sipName_RepeatSpread &sipStrings_QtGui[33487]
#define sipNameNr_ResourceType 4438
#define sipName_ResourceType &sipStrings_QtGui[4438]
#define sipNameNr_RestartNever 33500
#define sipName_RestartNever &sipStrings_QtGui[33500]
#define sipNameNr_SaltMountain 33513
#define sipName_SaltMountain &sipStrings_QtGui[33513]
#define sipNameNr_SecurityHigh 33526
#define sipName_SecurityHigh &sipStrings_QtGui[33526]
#define sipNameNr_SemiExpanded 33539
#define sipName_SemiExpanded &sipStrings_QtGui[33539]
#define sipNameNr_SingleBuffer 33552
#define sipName_SingleBuffer &sipStrings_QtGui[33552]
#define sipNameNr_SingleHeight 33565
#define sipName_SingleHeight &sipStrings_QtGui[33565]
#define sipNameNr_SoftLipstick 33578
#define sipName_SoftLipstick &sipStrings_QtGui[33578]
#define sipNameNr_SpringWarmth 33591
#define sipName_SpringWarmth &sipStrings_QtGui[33591]
#define sipNameNr_StandardMode 33604
#define sipName_StandardMode &sipStrings_QtGui[33604]
#define sipNameNr_StartOfBlock 14152
#define sipName_StartOfBlock &sipStrings_QtGui[14152]
#define sipNameNr_StyleOblique 33617
#define sipName_StyleOblique &sipStrings_QtGui[33617]
#define sipNameNr_SunnyMorning 33630
#define sipName_SunnyMorning &sipStrings_QtGui[33630]
#define sipNameNr_SurfaceClass 8275
#define sipName_SurfaceClass &sipStrings_QtGui[8275]
#define sipNameNr_SwapBehavior 3871
#define sipName_SwapBehavior &sipStrings_QtGui[3871]
#define sipNameNr_SweetDessert 33643
#define sipName_SweetDessert &sipStrings_QtGui[33643]
#define sipNameNr_SystemLogOut 33656
#define sipName_SystemLogOut &sipStrings_QtGui[33656]
#define sipNameNr_SystemReboot 33669
#define sipName_SystemReboot &sipStrings_QtGui[33669]
#define sipNameNr_SystemSearch 33682
#define sipName_SystemSearch &sipStrings_QtGui[33682]
#define sipNameNr_TabPositions 24921
#define sipName_TabPositions &sipStrings_QtGui[24921]
#define sipNameNr_TableColumns 33695
#define sipName_TableColumns &sipStrings_QtGui[33695]
#define sipNameNr_TabloidExtra 33708
#define sipName_TabloidExtra &sipStrings_QtGui[33708]
#define sipNameNr_TeenNotebook 33721
#define sipName_TeenNotebook &sipStrings_QtGui[33721]
#define sipNameNr_TripleBuffer 33734
#define sipName_TripleBuffer &sipStrings_QtGui[33734]
#define sipNameNr_UnknownError 33747
#define sipName_UnknownError &sipStrings_QtGui[33747]
#define sipNameNr_UnsignedByte 33760
#define sipName_UnsignedByte &sipStrings_QtGui[33760]
#define sipNameNr_UserProperty 33773
#define sipName_UserProperty &sipStrings_QtGui[33773]
#define sipNameNr_UserResource 33786
#define sipName_UserResource &sipStrings_QtGui[33786]
#define sipNameNr_VideoDisplay 33799
#define sipName_VideoDisplay &sipStrings_QtGui[33799]
#define sipNameNr_WeatherClear 33812
#define sipName_WeatherClear &sipStrings_QtGui[33812]
#define sipNameNr_WeatherStorm 33825
#define sipName_WeatherStorm &sipStrings_QtGui[33825]
#define sipNameNr_WrapAnywhere 33838
#define sipName_WrapAnywhere &sipStrings_QtGui[33838]
#define sipNameNr_YoungPassion 33851
#define sipName_YoungPassion &sipStrings_QtGui[33851]
#define sipNameNr___contains__ 33864
#define sipName___contains__ &sipStrings_QtGui[33864]
#define sipNameNr___itruediv__ 33877
#define sipName___itruediv__ &sipStrings_QtGui[33877]
#define sipNameNr_angleBetween 33890
#define sipName_angleBetween &sipStrings_QtGui[33890]
#define sipNameNr_antiquewhite 33903
#define sipName_antiquewhite &sipStrings_QtGui[33903]
#define sipNameNr_appendColumn 33916
#define sipName_appendColumn &sipStrings_QtGui[33916]
#define sipNameNr_atBlockStart 33929
#define sipName_atBlockStart &sipStrings_QtGui[33929]
#define sipNameNr_bitsPerPixel 33942
#define sipName_bitsPerPixel &sipStrings_QtGui[33942]
#define sipNameNr_blockRemoved 33955
#define sipName_blockRemoved &sipStrings_QtGui[33955]
#define sipNameNr_boolProperty 33968
#define sipName_boolProperty &sipStrings_QtGui[33968]
#define sipNameNr_bottomBorder 33981
#define sipName_bottomBorder &sipStrings_QtGui[33981]
#define sipNameNr_bottomMargin 33994
#define sipName_bottomMargin &sipStrings_QtGui[33994]
#define sipNameNr_boundingRect 34007
#define sipName_boundingRect &sipStrings_QtGui[34007]
#define sipNameNr_brushOriginF 34020
#define sipName_brushOriginF &sipStrings_QtGui[34020]
#define sipNameNr_bytesPerLine 34033
#define sipName_bytesPerLine &sipStrings_QtGui[34033]
#define sipNameNr_cacheEnabled 34046
#define sipName_cacheEnabled &sipStrings_QtGui[34046]
#define sipNameNr_canFetchMore 34059
#define sipName_canFetchMore &sipStrings_QtGui[34059]
#define sipNameNr_capabilities 34072
#define sipName_capabilities &sipStrings_QtGui[34072]
#define sipNameNr_centerRadius 34085
#define sipName_centerRadius &sipStrings_QtGui[34085]
#define sipNameNr_channelCount 34098
#define sipName_channelCount &sipStrings_QtGui[34098]
#define sipNameNr_cleanChanged 34111
#define sipName_cleanChanged &sipStrings_QtGui[34111]
#define sipNameNr_clearFormats 34124
#define sipName_clearFormats &sipStrings_QtGui[34124]
#define sipNameNr_closeSubpath 34137
#define sipName_closeSubpath &sipStrings_QtGui[34137]
#define sipNameNr_columnNumber 34150
#define sipName_columnNumber &sipStrings_QtGui[34150]
#define sipNameNr_commitString 34163
#define sipName_commitString &sipStrings_QtGui[34163]
#define sipNameNr_createObject 34176
#define sipName_createObject &sipStrings_QtGui[34176]
#define sipNameNr_createStroke 34189
#define sipName_createStroke &sipStrings_QtGui[34189]
#define sipNameNr_crossProduct 34202
#define sipName_crossProduct &sipStrings_QtGui[34202]
#define sipNameNr_currentBlock 34215
#define sipName_currentBlock &sipStrings_QtGui[34215]
#define sipNameNr_currentFrame 34228
#define sipName_currentFrame &sipStrings_QtGui[34228]
#define sipNameNr_currentImage 34241
#define sipName_currentImage &sipStrings_QtGui[34241]
#define sipNameNr_currentTable 34254
#define sipName_currentTable &sipStrings_QtGui[34254]
#define sipNameNr_darkseagreen 34267
#define sipName_darkseagreen &sipStrings_QtGui[34267]
#define sipNameNr_defaultDepth 34280
#define sipName_defaultDepth &sipStrings_QtGui[34280]
#define sipNameNr_defaultValue 34293
#define sipName_defaultValue &sipStrings_QtGui[34293]
#define sipNameNr_documentSize 34306
#define sipName_documentSize &sipStrings_QtGui[34306]
#define sipNameNr_drawContents 34319
#define sipName_drawContents &sipStrings_QtGui[34319]
#define sipNameNr_drawGlyphRun 34332
#define sipName_drawGlyphRun &sipStrings_QtGui[34332]
#define sipNameNr_drawPolyline 34345
#define sipName_drawPolyline &sipStrings_QtGui[34345]
#define sipNameNr_drawTextItem 34358
#define sipName_drawTextItem &sipStrings_QtGui[34358]
#define sipNameNr_dropMimeData 34371
#define sipName_dropMimeData &sipStrings_QtGui[34371]
#define sipNameNr_elementCount 34384
#define sipName_elementCount &sipStrings_QtGui[34384]
#define sipNameNr_endEditBlock 34397
#define sipName_endEditBlock &sipStrings_QtGui[34397]
#define sipNameNr_featureValue 34410
#define sipName_featureValue &sipStrings_QtGui[34410]
#define sipNameNr_flagsChanged 34423
#define sipName_flagsChanged &sipStrings_QtGui[34423]
#define sipNameNr_focusInEvent 34436
#define sipName_focusInEvent &sipStrings_QtGui[34436]
#define sipNameNr_fontFamilies 34449
#define sipName_fontFamilies &sipStrings_QtGui[34449]
#define sipNameNr_fontFeatures 34462
#define sipName_fontFeatures &sipStrings_QtGui[34462]
#define sipNameNr_fontOverline 34475
#define sipName_fontOverline &sipStrings_QtGui[34475]
#define sipNameNr_frameChanged 34488
#define sipName_frameChanged &sipStrings_QtGui[34488]
#define sipNameNr_frameMargins 34501
#define sipName_frameMargins &sipStrings_QtGui[34501]
#define sipNameNr_fromMarkdown 34514
#define sipName_fromMarkdown &sipStrings_QtGui[34514]
#define sipNameNr_fromVector3D 34527
#define sipName_fromVector3D &sipStrings_QtGui[34527]
#define sipNameNr_glyphIndexes 34540
#define sipName_glyphIndexes &sipStrings_QtGui[34540]
#define sipNameNr_grabPosition 34553
#define sipName_grabPosition &sipStrings_QtGui[34553]
#define sipNameNr_hasExtension 34566
#define sipName_hasExtension &sipStrings_QtGui[34566]
#define sipNameNr_hasSelection 34579
#define sipName_hasSelection &sipStrings_QtGui[34579]
#define sipNameNr_hasThemeIcon 34592
#define sipName_hasThemeIcon &sipStrings_QtGui[34592]
#define sipNameNr_headingLevel 34605
#define sipName_headingLevel &sipStrings_QtGui[34605]
#define sipNameNr_iconProvider 34618
#define sipName_iconProvider &sipStrings_QtGui[34618]
#define sipNameNr_indexChanged 34631
#define sipName_indexChanged &sipStrings_QtGui[34631]
#define sipNameNr_insertColumn 34644
#define sipName_insertColumn &sipStrings_QtGui[34644]
#define sipNameNr_invertPixels 34657
#define sipName_invertPixels &sipStrings_QtGui[34657]
#define sipNameNr_invokeAction 34670
#define sipName_invokeAction &sipStrings_QtGui[34670]
#define sipNameNr_isAncestorOf 34683
#define sipName_isAncestorOf &sipStrings_QtGui[34683]
#define sipNameNr_isAutoRepeat 34696
#define sipName_isAutoRepeat &sipStrings_QtGui[34696]
#define sipNameNr_isBeginEvent 34709
#define sipName_isBeginEvent &sipStrings_QtGui[34709]
#define sipNameNr_isCharFormat 34722
#define sipName_isCharFormat &sipStrings_QtGui[34722]
#define sipNameNr_isFeatureSet 34735
#define sipName_isFeatureSet &sipStrings_QtGui[34735]
#define sipNameNr_isFixedPitch 34748
#define sipName_isFixedPitch &sipStrings_QtGui[34748]
#define sipNameNr_isInvertible 34761
#define sipName_isInvertible &sipStrings_QtGui[34761]
#define sipNameNr_isListFormat 34774
#define sipName_isListFormat &sipStrings_QtGui[34774]
#define sipNameNr_isSelectable 34787
#define sipName_isSelectable &sipStrings_QtGui[34787]
#define sipNameNr_isValidColor 34800
#define sipName_isValidColor &sipStrings_QtGui[34800]
#define sipNameNr_lastModified 34813
#define sipName_lastModified &sipStrings_QtGui[34813]
#define sipNameNr_lastPosition 34826
#define sipName_lastPosition &sipStrings_QtGui[34826]
#define sipNameNr_lemonchiffon 34839
#define sipName_lemonchiffon &sipStrings_QtGui[34839]
#define sipNameNr_lightskyblue 34852
#define sipName_lightskyblue &sipStrings_QtGui[34852]
#define sipNameNr_listToString 34865
#define sipName_listToString &sipStrings_QtGui[34865]
#define sipNameNr_loadFromData 34878
#define sipName_loadFromData &sipStrings_QtGui[34878]
#define sipNameNr_loadFromFile 34891
#define sipName_loadFromFile &sipStrings_QtGui[34891]
#define sipNameNr_loadResource 34904
#define sipName_loadResource &sipStrings_QtGui[34904]
#define sipNameNr_majorVersion 34917
#define sipName_majorVersion &sipStrings_QtGui[34917]
#define sipNameNr_manufacturer 34930
#define sipName_manufacturer &sipStrings_QtGui[34930]
#define sipNameNr_mapToPolygon 34943
#define sipName_mapToPolygon &sipStrings_QtGui[34943]
#define sipNameNr_maxCharWidth 34956
#define sipName_maxCharWidth &sipStrings_QtGui[34956]
#define sipNameNr_maximumValue 34969
#define sipName_maximumValue &sipStrings_QtGui[34969]
#define sipNameNr_maximumWidth 34982
#define sipName_maximumWidth &sipStrings_QtGui[34982]
#define sipNameNr_mediumorchid 34995
#define sipName_mediumorchid &sipStrings_QtGui[34995]
#define sipNameNr_mediumpurple 35008
#define sipName_mediumpurple &sipStrings_QtGui[35008]
#define sipNameNr_midnightblue 35021
#define sipName_midnightblue &sipStrings_QtGui[35021]
#define sipNameNr_minimumValue 35034
#define sipName_minimumValue &sipStrings_QtGui[35034]
#define sipNameNr_minimumWidth 35047
#define sipName_minimumWidth &sipStrings_QtGui[35047]
#define sipNameNr_minorVersion 35060
#define sipName_minorVersion &sipStrings_QtGui[35060]
#define sipNameNr_mouseButtons 35073
#define sipName_mouseButtons &sipStrings_QtGui[35073]
#define sipNameNr_movePosition 35086
#define sipName_movePosition &sipStrings_QtGui[35086]
#define sipNameNr_normalMatrix 35099
#define sipName_normalMatrix &sipStrings_QtGui[35099]
#define sipNameNr_numberPrefix 35112
#define sipName_numberPrefix &sipStrings_QtGui[35112]
#define sipNameNr_numberSuffix 35125
#define sipName_numberSuffix &sipStrings_QtGui[35125]
#define sipNameNr_outputIntent 35138
#define sipName_outputIntent &sipStrings_QtGui[35138]
#define sipNameNr_pathForGlyph 35151
#define sipName_pathForGlyph &sipStrings_QtGui[35151]
#define sipNameNr_physicalDpiX 35164
#define sipName_physicalDpiX &sipStrings_QtGui[35164]
#define sipNameNr_physicalDpiY 35177
#define sipName_physicalDpiY &sipStrings_QtGui[35177]
#define sipNameNr_physicalSize 35190
#define sipName_physicalSize &sipStrings_QtGui[35190]
#define sipNameNr_platformName 35203
#define sipName_platformName &sipStrings_QtGui[35203]
#define sipNameNr_qPremultiply 35216
#define sipName_qPremultiply &sipStrings_QtGui[35216]
#define sipNameNr_quadToSquare 35229
#define sipName_quadToSquare &sipStrings_QtGui[35229]
#define sipNameNr_registryName 35242
#define sipName_registryName &sipStrings_QtGui[35242]
#define sipNameNr_removeAction 35255
#define sipName_removeAction &sipStrings_QtGui[35255]
#define sipNameNr_removeColumn 35268
#define sipName_removeColumn &sipStrings_QtGui[35268]
#define sipNameNr_resetEnabled 35281
#define sipName_resetEnabled &sipStrings_QtGui[35281]
#define sipNameNr_rightBearing 35294
#define sipName_rightBearing &sipStrings_QtGui[35294]
#define sipNameNr_rightPadding 35307
#define sipName_rightPadding &sipStrings_QtGui[35307]
#define sipNameNr_scaledPixmap 35320
#define sipName_scaledPixmap &sipStrings_QtGui[35320]
#define sipNameNr_selectedText 35333
#define sipName_selectedText &sipStrings_QtGui[35333]
#define sipNameNr_selectionEnd 35346
#define sipName_selectionEnd &sipStrings_QtGui[35346]
#define sipNameNr_serialNumber 35359
#define sipName_serialNumber &sipStrings_QtGui[35359]
#define sipNameNr_setAlignment 35372
#define sipName_setAlignment &sipStrings_QtGui[35372]
#define sipNameNr_setCacheMode 35385
#define sipName_setCacheMode &sipStrings_QtGui[35385]
#define sipNameNr_setCheckable 35398
#define sipName_setCheckable &sipStrings_QtGui[35398]
#define sipNameNr_setExclusive 35411
#define sipName_setExclusive &sipStrings_QtGui[35411]
#define sipNameNr_setFinalStop 35424
#define sipName_setFinalStop &sipStrings_QtGui[35424]
#define sipNameNr_setJoinStyle 35437
#define sipName_setJoinStyle &sipStrings_QtGui[35437]
#define sipNameNr_setLineCount 35450
#define sipName_setLineCount &sipStrings_QtGui[35450]
#define sipNameNr_setLineWidth 35463
#define sipName_setLineWidth &sipStrings_QtGui[35463]
#define sipNameNr_setPixelSize 35476
#define sipName_setPixelSize &sipStrings_QtGui[35476]
#define sipNameNr_setPlainText 35489
#define sipName_setPlainText &sipStrings_QtGui[35489]
#define sipNameNr_setPointSize 35502
#define sipName_setPointSize &sipStrings_QtGui[35502]
#define sipNameNr_setPositions 35515
#define sipName_setPositions &sipStrings_QtGui[35515]
#define sipNameNr_setPrimaries 35528
#define sipName_setPrimaries &sipStrings_QtGui[35528]
#define sipNameNr_setSeparator 35541
#define sipName_setSeparator &sipStrings_QtGui[35541]
#define sipNameNr_setShortcuts 35554
#define sipName_setShortcuts &sipStrings_QtGui[35554]
#define sipNameNr_setStatusTip 35567
#define sipName_setStatusTip &sipStrings_QtGui[35567]
#define sipNameNr_setStrikeOut 35580
#define sipName_setStrikeOut &sipStrings_QtGui[35580]
#define sipNameNr_setStyleHint 35593
#define sipName_setStyleHint &sipStrings_QtGui[35593]
#define sipNameNr_setStyleName 35606
#define sipName_setStyleName &sipStrings_QtGui[35606]
#define sipNameNr_setTextWidth 35619
#define sipName_setTextWidth &sipStrings_QtGui[35619]
#define sipNameNr_setThemeName 35632
#define sipName_setThemeName &sipStrings_QtGui[35632]
#define sipNameNr_setTopBorder 35645
#define sipName_setTopBorder &sipStrings_QtGui[35645]
#define sipNameNr_setTopMargin 35658
#define sipName_setTopMargin &sipStrings_QtGui[35658]
#define sipNameNr_setTransform 27442
#define sipName_setTransform &sipStrings_QtGui[27442]
#define sipNameNr_setUnderline 35671
#define sipName_setUnderline &sipStrings_QtGui[35671]
#define sipNameNr_setUndoLimit 35684
#define sipName_setUndoLimit &sipStrings_QtGui[35684]
#define sipNameNr_setUserState 35697
#define sipName_setUserState &sipStrings_QtGui[35697]
#define sipNameNr_setWhatsThis 35710
#define sipName_setWhatsThis &sipStrings_QtGui[35710]
#define sipNameNr_shareContext 35723
#define sipName_shareContext &sipStrings_QtGui[35723]
#define sipNameNr_sortChildren 35736
#define sipName_sortChildren &sipStrings_QtGui[35736]
#define sipNameNr_sourceString 35749
#define sipName_sourceString &sipStrings_QtGui[35749]
#define sipNameNr_squareToQuad 35762
#define sipName_squareToQuad &sipStrings_QtGui[35762]
#define sipNameNr_stateChanged 35775
#define sipName_stateChanged &sipStrings_QtGui[35775]
#define sipNameNr_strikeOutPos 35788
#define sipName_strikeOutPos &sipStrings_QtGui[35788]
#define sipNameNr_surfaceClass 35801
#define sipName_surfaceClass &sipStrings_QtGui[35801]
#define sipNameNr_swapBehavior 35814
#define sipName_swapBehavior &sipStrings_QtGui[35814]
#define sipNameNr_swapInterval 35827
#define sipName_swapInterval &sipStrings_QtGui[35827]
#define sipNameNr_tabPositions 35840
#define sipName_tabPositions &sipStrings_QtGui[35840]
#define sipNameNr_textPosition 35853
#define sipName_textPosition &sipStrings_QtGui[35853]
#define sipNameNr_textureImage 35866
#define sipName_textureImage &sipStrings_QtGui[35866]
#define sipNameNr_toCharFormat 35879
#define sipName_toCharFormat &sipStrings_QtGui[35879]
#define sipNameNr_toListFormat 35892
#define sipName_toListFormat &sipStrings_QtGui[35892]
#define sipNameNr_underlinePos 35905
#define sipName_underlinePos &sipStrings_QtGui[35905]
#define sipNameNr_unsetFeature 35918
#define sipName_unsetFeature &sipStrings_QtGui[35918]
#define sipNameNr_variableAxes 35931
#define sipName_variableAxes &sipStrings_QtGui[35931]
#define sipNameNr_viewportSize 35944
#define sipName_viewportSize &sipStrings_QtGui[35944]
#define sipNameNr_widthChanged 35957
#define sipName_widthChanged &sipStrings_QtGui[35957]
#define sipNameNr_windowStates 35970
#define sipName_windowStates &sipStrings_QtGui[35970]
#define sipNameNr_AboutQtRole 35983
#define sipName_AboutQtRole &sipStrings_QtGui[35983]
#define sipNameNr_AboveTheSky 35995
#define sipName_AboveTheSky &sipStrings_QtGui[35995]
#define sipNameNr_ActionEvent 10654
#define sipName_ActionEvent &sipStrings_QtGui[10654]
#define sipNameNr_AlignBottom 36007
#define sipName_AlignBottom &sipStrings_QtGui[36007]
#define sipNameNr_AlignMiddle 36019
#define sipName_AlignMiddle &sipStrings_QtGui[36019]
#define sipNameNr_AlignNormal 36031
#define sipName_AlignNormal &sipStrings_QtGui[36031]
#define sipNameNr_AllFeatures 36043
#define sipName_AllFeatures &sipStrings_QtGui[36043]
#define sipNameNr_AtBeginning 36055
#define sipName_AtBeginning &sipStrings_QtGui[36055]
#define sipNameNr_AwesomePine 36067
#define sipName_AwesomePine &sipStrings_QtGui[36067]
#define sipNameNr_BlockFormat 20164
#define sipName_BlockFormat &sipStrings_QtGui[20164]
#define sipNameNr_BlockIndent 36079
#define sipName_BlockIndent &sipStrings_QtGui[36079]
#define sipNameNr_BlockMarker 36091
#define sipName_BlockMarker &sipStrings_QtGui[36091]
#define sipNameNr_BorderStyle 3227
#define sipName_BorderStyle &sipStrings_QtGui[3227]
#define sipNameNr_BrushStroke 36103
#define sipName_BrushStroke &sipStrings_QtGui[36103]
#define sipNameNr_CameraPhoto 36115
#define sipName_CameraPhoto &sipStrings_QtGui[36115]
#define sipNameNr_CameraVideo 36127
#define sipName_CameraVideo &sipStrings_QtGui[36127]
#define sipNameNr_CleanMirror 36139
#define sipName_CleanMirror &sipStrings_QtGui[36139]
#define sipNameNr_CloudyApple 36151
#define sipName_CloudyApple &sipStrings_QtGui[36151]
#define sipNameNr_CochitiLake 36163
#define sipName_CochitiLake &sipStrings_QtGui[36163]
#define sipNameNr_ColdEvening 36175
#define sipName_ColdEvening &sipStrings_QtGui[36175]
#define sipNameNr_ContextMenu 2435
#define sipName_ContextMenu &sipStrings_QtGui[2435]
#define sipNameNr_CoreProfile 36187
#define sipName_CoreProfile &sipStrings_QtGui[36187]
#define sipNameNr_Crystalline 36199
#define sipName_Crystalline &sipStrings_QtGui[36199]
#define sipNameNr_DarkMagenta 36211
#define sipName_DarkMagenta &sipStrings_QtGui[36211]
#define sipNameNr_DashDotLine 36223
#define sipName_DashDotLine &sipStrings_QtGui[36223]
#define sipNameNr_Description 6677
#define sipName_Description &sipStrings_QtGui[6677]
#define sipNameNr_DeviceError 36235
#define sipName_DeviceError &sipStrings_QtGui[36235]
#define sipNameNr_DialogError 36247
#define sipName_DialogError &sipStrings_QtGui[36247]
#define sipNameNr_DirtyBeauty 36259
#define sipName_DirtyBeauty &sipStrings_QtGui[36259]
#define sipNameNr_DocumentNew 36271
#define sipName_DocumentNew &sipStrings_QtGui[36271]
#define sipNameNr_DocumentUrl 36283
#define sipName_DocumentUrl &sipStrings_QtGui[36283]
#define sipNameNr_ElementType 5507
#define sipName_ElementType &sipStrings_QtGui[5507]
#define sipNameNr_EnvelopeC65 36295
#define sipName_EnvelopeC65 &sipStrings_QtGui[36295]
#define sipNameNr_ExtendedRgb 31972
#define sipName_ExtendedRgb &sipStrings_QtGui[31972]
#define sipNameNr_FebruaryInk 36307
#define sipName_FebruaryInk &sipStrings_QtGui[36307]
#define sipNameNr_FixedHeight 36319
#define sipName_FixedHeight &sipStrings_QtGui[36319]
#define sipNameNr_FixedLength 36331
#define sipName_FixedLength &sipStrings_QtGui[36331]
#define sipNameNr_FlyingLemon 36343
#define sipName_FlyingLemon &sipStrings_QtGui[36343]
#define sipNameNr_FontKerning 27803
#define sipName_FontKerning &sipStrings_QtGui[27803]
#define sipNameNr_FontStretch 25868
#define sipName_FontStretch &sipStrings_QtGui[25868]
#define sipNameNr_FormatRange 6452
#define sipName_FormatRange &sipStrings_QtGui[6452]
#define sipNameNr_Format_Mono 36355
#define sipName_Format_Mono &sipStrings_QtGui[36355]
#define sipNameNr_FrameBorder 36367
#define sipName_FrameBorder &sipStrings_QtGui[36367]
#define sipNameNr_FrameFormat 20181
#define sipName_FrameFormat &sipStrings_QtGui[20181]
#define sipNameNr_FrameHeight 36379
#define sipName_FrameHeight &sipStrings_QtGui[36379]
#define sipNameNr_FrameMargin 36391
#define sipName_FrameMargin &sipStrings_QtGui[36391]
#define sipNameNr_FrontMatter 36403
#define sipName_FrontMatter &sipStrings_QtGui[36403]
#define sipNameNr_FrozenBerry 36415
#define sipName_FrozenBerry &sipStrings_QtGui[36415]
#define sipNameNr_GagarinView 36427
#define sipName_GagarinView &sipStrings_QtGui[36427]
#define sipNameNr_GeneralFont 36439
#define sipName_GeneralFont &sipStrings_QtGui[36439]
#define sipNameNr_HappyFisher 36451
#define sipName_HappyFisher &sipStrings_QtGui[36451]
#define sipNameNr_HeavenPeach 36463
#define sipName_HeavenPeach &sipStrings_QtGui[36463]
#define sipNameNr_ImageHeight 36475
#define sipName_ImageHeight &sipStrings_QtGui[36475]
#define sipNameNr_ImageObject 36487
#define sipName_ImageObject &sipStrings_QtGui[36487]
#define sipNameNr_ImageOption 3640
#define sipName_ImageOption &sipStrings_QtGui[3640]
#define sipNameNr_Imperial7x9 36499
#define sipName_Imperial7x9 &sipStrings_QtGui[36499]
#define sipNameNr_InputGaming 36511
#define sipName_InputGaming &sipStrings_QtGui[36511]
#define sipNameNr_InputTablet 36523
#define sipName_InputTablet &sipStrings_QtGui[36523]
#define sipNameNr_InsertImage 36535
#define sipName_InsertImage &sipStrings_QtGui[36535]
#define sipNameNr_LetterExtra 36547
#define sipName_LetterExtra &sipStrings_QtGui[36547]
#define sipNameNr_LetterSmall 36559
#define sipName_LetterSmall &sipStrings_QtGui[36559]
#define sipNameNr_LinkVisited 36571
#define sipName_LinkVisited &sipStrings_QtGui[36571]
#define sipNameNr_ListDecimal 36583
#define sipName_ListDecimal &sipStrings_QtGui[36583]
#define sipNameNr_LogicalMode 36595
#define sipName_LogicalMode &sipStrings_QtGui[36595]
#define sipNameNr_LowPriority 36607
#define sipName_LowPriority &sipStrings_QtGui[36607]
#define sipNameNr_MailForward 36619
#define sipName_MailForward &sipStrings_QtGui[36619]
#define sipNameNr_MailReplied 36631
#define sipName_MailReplied &sipStrings_QtGui[36631]
#define sipNameNr_MalibuBeach 36643
#define sipName_MalibuBeach &sipStrings_QtGui[36643]
#define sipNameNr_MaskedBrush 36655
#define sipName_MaskedBrush &sipStrings_QtGui[36655]
#define sipNameNr_MediaRecord 36667
#define sipName_MediaRecord &sipStrings_QtGui[36667]
#define sipNameNr_MorpheusDen 36679
#define sipName_MorpheusDen &sipStrings_QtGui[36679]
#define sipNameNr_NColorRoles 36691
#define sipName_NColorRoles &sipStrings_QtGui[36691]
#define sipNameNr_NoAntialias 36703
#define sipName_NoAntialias &sipStrings_QtGui[36703]
#define sipNameNr_NoUnderline 36715
#define sipName_NoUnderline &sipStrings_QtGui[36715]
#define sipNameNr_NorseBeauty 36727
#define sipName_NorseBeauty &sipStrings_QtGui[36727]
#define sipNameNr_ObjectIndex 27923
#define sipName_ObjectIndex &sipStrings_QtGui[27923]
#define sipNameNr_ObjectTypes 6427
#define sipName_ObjectTypes &sipStrings_QtGui[6427]
#define sipNameNr_OddEvenMode 36739
#define sipName_OddEvenMode &sipStrings_QtGui[36739]
#define sipNameNr_OrangeJuice 36751
#define sipName_OrangeJuice &sipStrings_QtGui[36751]
#define sipNameNr_Orientation 6327
#define sipName_Orientation &sipStrings_QtGui[6327]
#define sipNameNr_PaintBuffer 36763
#define sipName_PaintBuffer &sipStrings_QtGui[36763]
#define sipNameNr_PdmHeightMM 36775
#define sipName_PdmHeightMM &sipStrings_QtGui[36775]
#define sipNameNr_PerfectBlue 36787
#define sipName_PerfectBlue &sipStrings_QtGui[36787]
#define sipNameNr_PixelScroll 36799
#define sipName_PixelScroll &sipStrings_QtGui[36799]
#define sipNameNr_PointerType 3756
#define sipName_PointerType &sipStrings_QtGui[3756]
#define sipNameNr_PreferMatch 36811
#define sipName_PreferMatch &sipStrings_QtGui[36811]
#define sipNameNr_Preferences 36823
#define sipName_Preferences &sipStrings_QtGui[36823]
#define sipNameNr_PremiumDark 36835
#define sipName_PremiumDark &sipStrings_QtGui[36835]
#define sipNameNr_PreviousRow 36847
#define sipName_PreviousRow &sipStrings_QtGui[36847]
#define sipNameNr_ProPhotoRgb 36859
#define sipName_ProPhotoRgb &sipStrings_QtGui[36859]
#define sipNameNr_ProcessStop 36871
#define sipName_ProcessStop &sipStrings_QtGui[36871]
#define sipNameNr_PyQt6_QtGui 36883
#define sipName_PyQt6_QtGui &sipStrings_QtGui[36883]
#define sipNameNr_QCloseEvent 36895
#define sipName_QCloseEvent &sipStrings_QtGui[36895]
#define sipNameNr_QColorSpace 36907
#define sipName_QColorSpace &sipStrings_QtGui[36907]
#define sipNameNr_QEnterEvent 36919
#define sipName_QEnterEvent &sipStrings_QtGui[36919]
#define sipNameNr_QEventPoint 36931
#define sipName_QEventPoint &sipStrings_QtGui[36931]
#define sipNameNr_QFocusEvent 36943
#define sipName_QFocusEvent &sipStrings_QtGui[36943]
#define sipNameNr_QHoverEvent 36955
#define sipName_QHoverEvent &sipStrings_QtGui[36955]
#define sipNameNr_QIcon__Mode 36967
#define sipName_QIcon__Mode &sipStrings_QtGui[36967]
#define sipNameNr_QIconEngine 36979
#define sipName_QIconEngine &sipStrings_QtGui[36979]
#define sipNameNr_QInputEvent 36991
#define sipName_QInputEvent &sipStrings_QtGui[36991]
#define sipNameNr_QMouseEvent 37003
#define sipName_QMouseEvent &sipStrings_QtGui[37003]
#define sipNameNr_QPageLayout 37015
#define sipName_QPageLayout &sipStrings_QtGui[37015]
#define sipNameNr_QPageRanges 37027
#define sipName_QPageRanges &sipStrings_QtGui[37027]
#define sipNameNr_QPaintEvent 37039
#define sipName_QPaintEvent &sipStrings_QtGui[37039]
#define sipNameNr_QQuaternion 37051
#define sipName_QQuaternion &sipStrings_QtGui[37051]
#define sipNameNr_QStaticText 37063
#define sipName_QStaticText &sipStrings_QtGui[37063]
#define sipNameNr_QStyleHints 37075
#define sipName_QStyleHints &sipStrings_QtGui[37075]
#define sipNameNr_QTextCursor 37087
#define sipName_QTextCursor &sipStrings_QtGui[37087]
#define sipNameNr_QTextFormat 37099
#define sipName_QTextFormat &sipStrings_QtGui[37099]
#define sipNameNr_QTextLayout 37111
#define sipName_QTextLayout &sipStrings_QtGui[37111]
#define sipNameNr_QTextLength 37123
#define sipName_QTextLength &sipStrings_QtGui[37123]
#define sipNameNr_QTextObject 37135
#define sipName_QTextObject &sipStrings_QtGui[37135]
#define sipNameNr_QTextOption 37147
#define sipName_QTextOption &sipStrings_QtGui[37147]
#define sipNameNr_QTouchEvent 37159
#define sipName_QTouchEvent &sipStrings_QtGui[37159]
#define sipNameNr_QWheelEvent 37171
#define sipName_QWheelEvent &sipStrings_QtGui[37171]
#define sipNameNr_RestartHint 3785
#define sipName_RestartHint &sipStrings_QtGui[3785]
#define sipNameNr_RetrieveAll 37183
#define sipName_RetrieveAll &sipStrings_QtGui[37183]
#define sipNameNr_RightToLeft 28058
#define sipName_RightToLeft &sipStrings_QtGui[28058]
#define sipNameNr_RipeMalinka 37195
#define sipName_RipeMalinka &sipStrings_QtGui[37195]
#define sipNameNr_RoyalGarden 37207
#define sipName_RoyalGarden &sipStrings_QtGui[37207]
#define sipNameNr_ScrollState 5533
#define sipName_ScrollState &sipStrings_QtGui[5533]
#define sipNameNr_SecurityLow 37219
#define sipName_SecurityLow &sipStrings_QtGui[37219]
#define sipNameNr_SmartIndigo 37231
#define sipName_SmartIndigo &sipStrings_QtGui[37231]
#define sipNameNr_SmilingRain 37243
#define sipName_SmilingRain &sipStrings_QtGui[37243]
#define sipNameNr_SoftCherish 37255
#define sipName_SoftCherish &sipStrings_QtGui[37255]
#define sipNameNr_SpacingType 6152
#define sipName_SpacingType &sipStrings_QtGui[6152]
#define sipNameNr_StandardKey 5429
#define sipName_StandardKey &sipStrings_QtGui[5429]
#define sipNameNr_StartOfLine 16950
#define sipName_StartOfLine &sipStrings_QtGui[16950]
#define sipNameNr_StartOfWord 16518
#define sipName_StartOfWord &sipStrings_QtGui[16518]
#define sipNameNr_StrongBliss 37267
#define sipName_StrongBliss &sipStrings_QtGui[37267]
#define sipNameNr_StrongStick 37279
#define sipName_StrongStick &sipStrings_QtGui[37279]
#define sipNameNr_StyleItalic 37291
#define sipName_StyleItalic &sipStrings_QtGui[37291]
#define sipNameNr_StyleNormal 37303
#define sipName_StyleNormal &sipStrings_QtGui[37303]
#define sipNameNr_SummerGames 37315
#define sipName_SummerGames &sipStrings_QtGui[37315]
#define sipNameNr_SurfaceType 9431
#define sipName_SurfaceType &sipStrings_QtGui[9431]
#define sipNameNr_SweetPeriod 37327
#define sipName_SweetPeriod &sipStrings_QtGui[37327]
#define sipNameNr_TableObject 37339
#define sipName_TableObject &sipStrings_QtGui[37339]
#define sipNameNr_TextOutline 28088
#define sipName_TextOutline &sipStrings_QtGui[28088]
#define sipNameNr_TextToolTip 37351
#define sipName_TextToolTip &sipStrings_QtGui[37351]
#define sipNameNr_ToolTipBase 37363
#define sipName_ToolTipBase &sipStrings_QtGui[37363]
#define sipNameNr_ToolTipText 37375
#define sipName_ToolTipText &sipStrings_QtGui[37375]
#define sipNameNr_TouchScreen 37387
#define sipName_TouchScreen &sipStrings_QtGui[37387]
#define sipNameNr_Transparent 30502
#define sipName_Transparent &sipStrings_QtGui[30502]
#define sipNameNr_TxTranslate 37399
#define sipName_TxTranslate &sipStrings_QtGui[37399]
#define sipNameNr_Unstretched 37411
#define sipName_Unstretched &sipStrings_QtGui[37411]
#define sipNameNr_UserOffline 37423
#define sipName_UserOffline &sipStrings_QtGui[37423]
#define sipNameNr_ViewRefresh 37435
#define sipName_ViewRefresh &sipStrings_QtGui[37435]
#define sipNameNr_ViewRestore 37447
#define sipName_ViewRestore &sipStrings_QtGui[37447]
#define sipNameNr_WeatherSnow 37459
#define sipName_WeatherSnow &sipStrings_QtGui[37459]
#define sipNameNr_WindingMode 37471
#define sipName_WindingMode &sipStrings_QtGui[37471]
#define sipNameNr_WindowClose 37483
#define sipName_WindowClose &sipStrings_QtGui[37483]
#define sipNameNr_ZeusMiracle 37495
#define sipName_ZeusMiracle &sipStrings_QtGui[37495]
#define sipNameNr_ZoomFitBest 37507
#define sipName_ZoomFitBest &sipStrings_QtGui[37507]
#define sipNameNr___delitem__ 37519
#define sipName___delitem__ &sipStrings_QtGui[37519]
#define sipNameNr___getitem__ 37531
#define sipName___getitem__ &sipStrings_QtGui[37531]
#define sipNameNr___imatmul__ 37543
#define sipName___imatmul__ &sipStrings_QtGui[37543]
#define sipNameNr___setitem__ 37555
#define sipName___setitem__ &sipStrings_QtGui[37555]
#define sipNameNr___truediv__ 37567
#define sipName___truediv__ &sipStrings_QtGui[37567]
#define sipNameNr_actionGroup 37579
#define sipName_actionGroup &sipStrings_QtGui[37579]
#define sipNameNr_activeStack 37591
#define sipName_activeStack &sipStrings_QtGui[37591]
#define sipNameNr_addResource 37603
#define sipName_addResource &sipStrings_QtGui[37603]
#define sipNameNr_anchorNames 37615
#define sipName_anchorNames &sipStrings_QtGui[37615]
#define sipNameNr_beginLayout 37627
#define sipName_beginLayout &sipStrings_QtGui[37627]
#define sipNameNr_blockFormat 37639
#define sipName_blockFormat &sipStrings_QtGui[37639]
#define sipNameNr_blockNumber 37651
#define sipName_blockNumber &sipStrings_QtGui[37651]
#define sipNameNr_borderBrush 37663
#define sipName_borderBrush &sipStrings_QtGui[37663]
#define sipNameNr_borderStyle 37675
#define sipName_borderStyle &sipStrings_QtGui[37675]
#define sipNameNr_brushOrigin 37687
#define sipName_brushOrigin &sipStrings_QtGui[37687]
#define sipNameNr_buttonCount 37699
#define sipName_buttonCount &sipStrings_QtGui[37699]
#define sipNameNr_cellPadding 37711
#define sipName_cellPadding &sipStrings_QtGui[37711]
#define sipNameNr_cellSpacing 37723
#define sipName_cellSpacing &sipStrings_QtGui[37723]
#define sipNameNr_characterAt 37735
#define sipName_characterAt &sipStrings_QtGui[37735]
#define sipNameNr_childFrames 37747
#define sipName_childFrames &sipStrings_QtGui[37747]
#define sipNameNr_cleanupInfo 37759
#define sipName_cleanupInfo &sipStrings_QtGui[37759]
#define sipNameNr_clearLayout 37771
#define sipName_clearLayout &sipStrings_QtGui[37771]
#define sipNameNr_colorScheme 37783
#define sipName_colorScheme &sipStrings_QtGui[37783]
#define sipNameNr_columnCount 37795
#define sipName_columnCount &sipStrings_QtGui[37795]
#define sipNameNr_compression 37807
#define sipName_compression &sipStrings_QtGui[37807]
#define sipNameNr_connectPath 37819
#define sipName_connectPath &sipStrings_QtGui[37819]
#define sipNameNr_convertedTo 37831
#define sipName_convertedTo &sipStrings_QtGui[37831]
#define sipNameNr_currentList 37843
#define sipName_currentList &sipStrings_QtGui[37843]
#define sipNameNr_customEvent 37855
#define sipName_customEvent &sipStrings_QtGui[37855]
#define sipNameNr_darkmagenta 37867
#define sipName_darkmagenta &sipStrings_QtGui[37867]
#define sipNameNr_dashPattern 37879
#define sipName_dashPattern &sipStrings_QtGui[37879]
#define sipNameNr_dataChanged 37891
#define sipName_dataChanged &sipStrings_QtGui[37891]
#define sipNameNr_deepskyblue 37903
#define sipName_deepskyblue &sipStrings_QtGui[37903]
#define sipNameNr_defaultFont 37915
#define sipName_defaultFont &sipStrings_QtGui[37915]
#define sipNameNr_description 37927
#define sipName_description &sipStrings_QtGui[37927]
#define sipNameNr_determinant 37939
#define sipName_determinant &sipStrings_QtGui[37939]
#define sipNameNr_doneCurrent 37951
#define sipName_doneCurrent &sipStrings_QtGui[37951]
#define sipNameNr_drawEllipse 37963
#define sipName_drawEllipse &sipStrings_QtGui[37963]
#define sipNameNr_drawPicture 37975
#define sipName_drawPicture &sipStrings_QtGui[37975]
#define sipNameNr_drawPolygon 37987
#define sipName_drawPolygon &sipStrings_QtGui[37987]
#define sipNameNr_errorString 37999
#define sipName_errorString &sipStrings_QtGui[37999]
#define sipNameNr_eventFilter 38011
#define sipName_eventFilter &sipStrings_QtGui[38011]
#define sipNameNr_exposeEvent 38023
#define sipName_exposeEvent &sipStrings_QtGui[38023]
#define sipNameNr_featureTags 38035
#define sipName_featureTags &sipStrings_QtGui[38035]
#define sipNameNr_fileRenamed 38047
#define sipName_fileRenamed &sipStrings_QtGui[38047]
#define sipNameNr_fingerCount 38059
#define sipName_fingerCount &sipStrings_QtGui[38059]
#define sipNameNr_floralwhite 38071
#define sipName_floralwhite &sipStrings_QtGui[38071]
#define sipNameNr_focalRadius 38083
#define sipName_focalRadius &sipStrings_QtGui[38083]
#define sipNameNr_focusObject 38095
#define sipName_focusObject &sipStrings_QtGui[38095]
#define sipNameNr_focusWindow 38107
#define sipName_focusWindow &sipStrings_QtGui[38107]
#define sipNameNr_fontKerning 38119
#define sipName_fontKerning &sipStrings_QtGui[38119]
#define sipNameNr_fontMetrics 38131
#define sipName_fontMetrics &sipStrings_QtGui[38131]
#define sipNameNr_fontStretch 38143
#define sipName_fontStretch &sipStrings_QtGui[38143]
#define sipNameNr_forestgreen 38155
#define sipName_forestgreen &sipStrings_QtGui[38155]
#define sipNameNr_formatIndex 38167
#define sipName_formatIndex &sipStrings_QtGui[38167]
#define sipNameNr_frameFormat 38179
#define sipName_frameFormat &sipStrings_QtGui[38179]
#define sipNameNr_gestureType 38191
#define sipName_gestureType &sipStrings_QtGui[38191]
#define sipNameNr_greenyellow 38203
#define sipName_greenyellow &sipStrings_QtGui[38203]
#define sipNameNr_hasChildren 38215
#define sipName_hasChildren &sipStrings_QtGui[38215]
#define sipNameNr_hasClipping 38227
#define sipName_hasClipping &sipStrings_QtGui[38227]
#define sipNameNr_hasProperty 38239
#define sipName_hasProperty &sipStrings_QtGui[38239]
#define sipNameNr_imageFormat 38251
#define sipName_imageFormat &sipStrings_QtGui[38251]
#define sipNameNr_indentWidth 38263
#define sipName_indentWidth &sipStrings_QtGui[38263]
#define sipNameNr_inputMethod 38275
#define sipName_inputMethod &sipStrings_QtGui[38275]
#define sipNameNr_insertBlock 38287
#define sipName_insertBlock &sipStrings_QtGui[38287]
#define sipNameNr_insertFrame 38299
#define sipName_insertFrame &sipStrings_QtGui[38299]
#define sipNameNr_insertImage 38311
#define sipName_insertImage &sipStrings_QtGui[38311]
#define sipNameNr_insertTable 38323
#define sipName_insertTable &sipStrings_QtGui[38323]
#define sipNameNr_intProperty 38335
#define sipName_intProperty &sipStrings_QtGui[38335]
#define sipNameNr_intersected 38347
#define sipName_intersected &sipStrings_QtGui[38347]
#define sipNameNr_isAmbiguous 38359
#define sipName_isAmbiguous &sipStrings_QtGui[38359]
#define sipNameNr_isAnimating 38371
#define sipName_isAnimating &sipStrings_QtGui[38371]
#define sipNameNr_isCheckable 38383
#define sipName_isCheckable &sipStrings_QtGui[38383]
#define sipNameNr_isExclusive 38395
#define sipName_isExclusive &sipStrings_QtGui[38395]
#define sipNameNr_isGrayscale 38407
#define sipName_isGrayscale &sipStrings_QtGui[38407]
#define sipNameNr_isLandscape 38419
#define sipName_isLandscape &sipStrings_QtGui[38419]
#define sipNameNr_isSeparator 38431
#define sipName_isSeparator &sipStrings_QtGui[38431]
#define sipNameNr_itemChanged 38443
#define sipName_itemChanged &sipStrings_QtGui[38443]
#define sipNameNr_jumpToFrame 38455
#define sipName_jumpToFrame &sipStrings_QtGui[38455]
#define sipNameNr_jumpToImage 38467
#define sipName_jumpToImage &sipStrings_QtGui[38467]
#define sipNameNr_keyBindings 38479
#define sipName_keyBindings &sipStrings_QtGui[38479]
#define sipNameNr_lastIndexOf 38491
#define sipName_lastIndexOf &sipStrings_QtGui[38491]
#define sipNameNr_leftBearing 38503
#define sipName_leftBearing &sipStrings_QtGui[38503]
#define sipNameNr_leftPadding 38515
#define sipName_leftPadding &sipStrings_QtGui[38515]
#define sipNameNr_lightsalmon 38527
#define sipName_lightsalmon &sipStrings_QtGui[38527]
#define sipNameNr_lightyellow 38539
#define sipName_lightyellow &sipStrings_QtGui[38539]
#define sipNameNr_lineSpacing 38551
#define sipName_lineSpacing &sipStrings_QtGui[38551]
#define sipNameNr_linkVisited 38563
#define sipName_linkVisited &sipStrings_QtGui[38563]
#define sipNameNr_logicalDpiX 38575
#define sipName_logicalDpiX &sipStrings_QtGui[38575]
#define sipNameNr_logicalDpiY 38587
#define sipName_logicalDpiY &sipStrings_QtGui[38587]
#define sipNameNr_magentaSize 38599
#define sipName_magentaSize &sipStrings_QtGui[38599]
#define sipNameNr_makeCurrent 38611
#define sipName_makeCurrent &sipStrings_QtGui[38611]
#define sipNameNr_mapToGlobal 38623
#define sipName_mapToGlobal &sipStrings_QtGui[38623]
#define sipNameNr_matchPolicy 38635
#define sipName_matchPolicy &sipStrings_QtGui[38635]
#define sipNameNr_maximumSize 38647
#define sipName_maximumSize &sipStrings_QtGui[38647]
#define sipNameNr_minimumSize 38659
#define sipName_minimumSize &sipStrings_QtGui[38659]
#define sipNameNr_modalWindow 38671
#define sipName_modalWindow &sipStrings_QtGui[38671]
#define sipNameNr_moveColumns 30978
#define sipName_moveColumns &sipStrings_QtGui[30978]
#define sipNameNr_nameFilters 38683
#define sipName_nameFilters &sipStrings_QtGui[38683]
#define sipNameNr_nativeEvent 38695
#define sipName_nativeEvent &sipStrings_QtGui[38695]
#define sipNameNr_navajowhite 38707
#define sipName_navajowhite &sipStrings_QtGui[38707]
#define sipNameNr_objectIndex 38719
#define sipName_objectIndex &sipStrings_QtGui[38719]
#define sipNameNr_orientation 38731
#define sipName_orientation &sipStrings_QtGui[38731]
#define sipNameNr_overlinePos 38743
#define sipName_overlinePos &sipStrings_QtGui[38743]
#define sipNameNr_paintDevice 38755
#define sipName_paintDevice &sipStrings_QtGui[38755]
#define sipNameNr_paintEngine 38767
#define sipName_paintEngine &sipStrings_QtGui[38767]
#define sipNameNr_paintdevice 38779
#define sipName_paintdevice &sipStrings_QtGui[38779]
#define sipNameNr_parentFrame 38791
#define sipName_parentFrame &sipStrings_QtGui[38791]
#define sipNameNr_penProperty 38803
#define sipName_penProperty &sipStrings_QtGui[38803]
#define sipNameNr_permissions 38815
#define sipName_permissions &sipStrings_QtGui[38815]
#define sipNameNr_perspective 38827
#define sipName_perspective &sipStrings_QtGui[38827]
#define sipNameNr_pixelFormat 38839
#define sipName_pixelFormat &sipStrings_QtGui[38839]
#define sipNameNr_pointerType 38851
#define sipName_pointerType &sipStrings_QtGui[38851]
#define sipNameNr_refreshRate 38863
#define sipName_refreshRate &sipStrings_QtGui[38863]
#define sipNameNr_rehighlight 38875
#define sipName_rehighlight &sipStrings_QtGui[38875]
#define sipNameNr_removeStack 38887
#define sipName_removeStack &sipStrings_QtGui[38887]
#define sipNameNr_renderFlags 38899
#define sipName_renderFlags &sipStrings_QtGui[38899]
#define sipNameNr_renderHints 38911
#define sipName_renderHints &sipStrings_QtGui[38911]
#define sipNameNr_resizeEvent 38923
#define sipName_resizeEvent &sipStrings_QtGui[38923]
#define sipNameNr_restartHint 38935
#define sipName_restartHint &sipStrings_QtGui[38935]
#define sipNameNr_rightBorder 38947
#define sipName_rightBorder &sipStrings_QtGui[38947]
#define sipNameNr_rightMargin 38959
#define sipName_rightMargin &sipStrings_QtGui[38959]
#define sipNameNr_saddlebrown 38971
#define sipName_saddlebrown &sipStrings_QtGui[38971]
#define sipNameNr_saturationF 38983
#define sipName_saturationF &sipStrings_QtGui[38983]
#define sipNameNr_screenAdded 38995
#define sipName_screenAdded &sipStrings_QtGui[38995]
#define sipNameNr_scrollState 39007
#define sipName_scrollState &sipStrings_QtGui[39007]
#define sipNameNr_setAccepted 39019
#define sipName_setAccepted &sipStrings_QtGui[39019]
#define sipNameNr_setBaseSize 39031
#define sipName_setBaseSize &sipStrings_QtGui[39031]
#define sipNameNr_setCapStyle 39043
#define sipName_setCapStyle &sipStrings_QtGui[39043]
#define sipNameNr_setClipPath 39055
#define sipName_setClipPath &sipStrings_QtGui[39055]
#define sipNameNr_setClipRect 39067
#define sipName_setClipRect &sipStrings_QtGui[39067]
#define sipNameNr_setClipping 39079
#define sipName_setClipping &sipStrings_QtGui[39079]
#define sipNameNr_setCosmetic 39091
#define sipName_setCosmetic &sipStrings_QtGui[39091]
#define sipNameNr_setDecimals 39103
#define sipName_setDecimals &sipStrings_QtGui[39103]
#define sipNameNr_setDisabled 39115
#define sipName_setDisabled &sipStrings_QtGui[39115]
#define sipNameNr_setDocument 39127
#define sipName_setDocument &sipStrings_QtGui[39127]
#define sipNameNr_setEditable 39139
#define sipName_setEditable &sipStrings_QtGui[39139]
#define sipNameNr_setFamilies 39151
#define sipName_setFamilies &sipStrings_QtGui[39151]
#define sipNameNr_setFileName 39163
#define sipName_setFileName &sipStrings_QtGui[39163]
#define sipNameNr_setFilePath 39175
#define sipName_setFilePath &sipStrings_QtGui[39175]
#define sipNameNr_setFillRule 39187
#define sipName_setFillRule &sipStrings_QtGui[39187]
#define sipNameNr_setGeometry 39199
#define sipName_setGeometry &sipStrings_QtGui[39199]
#define sipNameNr_setIconText 39211
#define sipName_setIconText &sipStrings_QtGui[39211]
#define sipNameNr_setItemData 39223
#define sipName_setItemData &sipStrings_QtGui[39223]
#define sipNameNr_setMarkdown 39235
#define sipName_setMarkdown &sipStrings_QtGui[39235]
#define sipNameNr_setMenuRole 39247
#define sipName_setMenuRole &sipStrings_QtGui[39247]
#define sipNameNr_setMimeData 39259
#define sipName_setMimeData &sipStrings_QtGui[39259]
#define sipNameNr_setModality 39271
#define sipName_setModality &sipStrings_QtGui[39271]
#define sipNameNr_setModified 39283
#define sipName_setModified &sipStrings_QtGui[39283]
#define sipNameNr_setNotation 39295
#define sipName_setNotation &sipStrings_QtGui[39295]
#define sipNameNr_setObsolete 39307
#define sipName_setObsolete &sipStrings_QtGui[39307]
#define sipNameNr_setOverline 39319
#define sipName_setOverline &sipStrings_QtGui[39319]
#define sipNameNr_setPageSize 39331
#define sipName_setPageSize &sipStrings_QtGui[39331]
#define sipNameNr_setPosition 39343
#define sipName_setPosition &sipStrings_QtGui[39343]
#define sipNameNr_setPriority 39355
#define sipName_setPriority &sipStrings_QtGui[39355]
#define sipNameNr_setProperty 39367
#define sipName_setProperty &sipStrings_QtGui[39367]
#define sipNameNr_setReadOnly 39379
#define sipName_setReadOnly &sipStrings_QtGui[39379]
#define sipNameNr_setRevision 39391
#define sipName_setRevision &sipStrings_QtGui[39391]
#define sipNameNr_setRootPath 39403
#define sipName_setRootPath &sipStrings_QtGui[39403]
#define sipNameNr_setRowCount 39415
#define sipName_setRowCount &sipStrings_QtGui[39415]
#define sipNameNr_setShortcut 39427
#define sipName_setShortcut &sipStrings_QtGui[39427]
#define sipNameNr_setSizeHint 39439
#define sipName_setSizeHint &sipStrings_QtGui[39439]
#define sipNameNr_setSortRole 39451
#define sipName_setSortRole &sipStrings_QtGui[39451]
#define sipNameNr_setTabArray 39463
#define sipName_setTabArray &sipStrings_QtGui[39463]
#define sipNameNr_setUserData 39475
#define sipName_setUserData &sipStrings_QtGui[39475]
#define sipNameNr_setViewport 39487
#define sipName_setViewport &sipStrings_QtGui[39487]
#define sipNameNr_setWrapMode 39499
#define sipName_setWrapMode &sipStrings_QtGui[39499]
#define sipNameNr_sizeInBytes 39511
#define sipName_sizeInBytes &sipStrings_QtGui[39511]
#define sipNameNr_smoothSizes 39523
#define sipName_smoothSizes &sipStrings_QtGui[39523]
#define sipNameNr_springgreen 18336
#define sipName_springgreen &sipStrings_QtGui[18336]
#define sipNameNr_styleString 39535
#define sipName_styleString &sipStrings_QtGui[39535]
#define sipNameNr_substitutes 39547
#define sipName_substitutes &sipStrings_QtGui[39547]
#define sipNameNr_surfaceType 39559
#define sipName_surfaceType &sipStrings_QtGui[39559]
#define sipNameNr_swapBuffers 39571
#define sipName_swapBuffers &sipStrings_QtGui[39571]
#define sipNameNr_tabletEvent 39583
#define sipName_tabletEvent &sipStrings_QtGui[39583]
#define sipNameNr_textFormats 39595
#define sipName_textFormats &sipStrings_QtGui[39595]
#define sipNameNr_textOutline 39607
#define sipName_textOutline &sipStrings_QtGui[39607]
#define sipNameNr_toPlainText 39619
#define sipName_toPlainText &sipStrings_QtGui[39619]
#define sipNameNr_toRangeList 39631
#define sipName_toRangeList &sipStrings_QtGui[39631]
#define sipNameNr_toTransform 21133
#define sipName_toTransform &sipStrings_QtGui[21133]
#define sipNameNr_toolTipBase 39643
#define sipName_toolTipBase &sipStrings_QtGui[39643]
#define sipNameNr_toolTipText 39655
#define sipName_toolTipText &sipStrings_QtGui[39655]
#define sipNameNr_touchPoints 39667
#define sipName_touchPoints &sipStrings_QtGui[39667]
#define sipNameNr_transformed 39679
#define sipName_transformed &sipStrings_QtGui[39679]
#define sipNameNr_unsetCursor 39691
#define sipName_unsetCursor &sipStrings_QtGui[39691]
#define sipNameNr_updateBlock 39703
#define sipName_updateBlock &sipStrings_QtGui[39703]
#define sipNameNr_updateState 39715
#define sipName_updateState &sipStrings_QtGui[39715]
#define sipNameNr_virtualSize 39727
#define sipName_virtualSize &sipStrings_QtGui[39727]
#define sipNameNr_windowState 39739
#define sipName_windowState &sipStrings_QtGui[39739]
#define sipNameNr_wordSpacing 39751
#define sipName_wordSpacing &sipStrings_QtGui[39751]
#define sipNameNr_yellowgreen 39763
#define sipName_yellowgreen &sipStrings_QtGui[39763]
#define sipNameNr_Acceptable 39775
#define sipName_Acceptable &sipStrings_QtGui[39775]
#define sipNameNr_AllDevices 39786
#define sipName_AllDevices &sipStrings_QtGui[39786]
#define sipNameNr_AlphaBlend 39797
#define sipName_AlphaBlend &sipStrings_QtGui[39797]
#define sipNameNr_AlphaUsage 6378
#define sipName_AlphaUsage &sipStrings_QtGui[6378]
#define sipNameNr_AmourAmour 39808
#define sipName_AmourAmour &sipStrings_QtGui[39808]
#define sipNameNr_AnchorHref 31119
#define sipName_AnchorHref &sipStrings_QtGui[31119]
#define sipNameNr_AnchorName 39819
#define sipName_AnchorName &sipStrings_QtGui[39819]
#define sipNameNr_AnyStretch 39830
#define sipName_AnyStretch &sipStrings_QtGui[39830]
#define sipNameNr_AquaSplash 39841
#define sipName_AquaSplash &sipStrings_QtGui[39841]
#define sipNameNr_BatteryLow 39852
#define sipName_BatteryLow &sipStrings_QtGui[39852]
#define sipNameNr_BlendModes 39863
#define sipName_BlendModes &sipStrings_QtGui[39863]
#define sipNameNr_BrightText 39874
#define sipName_BrightText &sipStrings_QtGui[39874]
#define sipNameNr_ButtonText 39885
#define sipName_ButtonText &sipStrings_QtGui[39885]
#define sipNameNr_Capability 6228
#define sipName_Capability &sipStrings_QtGui[6228]
#define sipNameNr_Capitalize 39896
#define sipName_Capitalize &sipStrings_QtGui[39896]
#define sipNameNr_CharFormat 11348
#define sipName_CharFormat &sipStrings_QtGui[11348]
#define sipNameNr_ColorGroup 10781
#define sipName_ColorGroup &sipStrings_QtGui[10781]
#define sipNameNr_ColorModel 6403
#define sipName_ColorModel &sipStrings_QtGui[6403]
#define sipNameNr_ContactNew 39907
#define sipName_ContactNew &sipStrings_QtGui[39907]
#define sipNameNr_ConvexMode 39918
#define sipName_ConvexMode &sipStrings_QtGui[39918]
#define sipNameNr_CursorMode 7285
#define sipName_CursorMode &sipStrings_QtGui[7285]
#define sipNameNr_DarkYellow 39929
#define sipName_DarkYellow &sipStrings_QtGui[39929]
#define sipNameNr_Decorative 39940
#define sipName_Decorative &sipStrings_QtGui[39940]
#define sipNameNr_DeepRelief 39951
#define sipName_DeepRelief &sipStrings_QtGui[39951]
#define sipNameNr_DenseWater 39962
#define sipName_DenseWater &sipStrings_QtGui[39962]
#define sipNameNr_DesertHump 39973
#define sipName_DesertHump &sipStrings_QtGui[39973]
#define sipNameNr_Devanagari 39984
#define sipName_Devanagari &sipStrings_QtGui[39984]
#define sipNameNr_DeviceType 6253
#define sipName_DeviceType &sipStrings_QtGui[6253]
#define sipNameNr_DirtyBrush 39995
#define sipName_DirtyBrush &sipStrings_QtGui[39995]
#define sipNameNr_DirtyHints 40006
#define sipName_DirtyHints &sipStrings_QtGui[40006]
#define sipNameNr_DustyGrass 40017
#define sipName_DustyGrass &sipStrings_QtGui[40017]
#define sipNameNr_EditDelete 40028
#define sipName_EditDelete &sipStrings_QtGui[40028]
#define sipNameNr_EndOfBlock 19842
#define sipName_EndOfBlock &sipStrings_QtGui[19842]
#define sipNameNr_Endianness 40039
#define sipName_Endianness &sipStrings_QtGui[40039]
#define sipNameNr_Envelope10 40050
#define sipName_Envelope10 &sipStrings_QtGui[40050]
#define sipNameNr_Envelope11 40061
#define sipName_Envelope11 &sipStrings_QtGui[40061]
#define sipNameNr_Envelope12 40072
#define sipName_Envelope12 &sipStrings_QtGui[40072]
#define sipNameNr_Envelope14 40083
#define sipName_Envelope14 &sipStrings_QtGui[40083]
#define sipNameNr_EnvelopeB4 40094
#define sipName_EnvelopeB4 &sipStrings_QtGui[40094]
#define sipNameNr_EnvelopeB5 40105
#define sipName_EnvelopeB5 &sipStrings_QtGui[40105]
#define sipNameNr_EnvelopeB6 40116
#define sipName_EnvelopeB6 &sipStrings_QtGui[40116]
#define sipNameNr_EnvelopeC0 40127
#define sipName_EnvelopeC0 &sipStrings_QtGui[40127]
#define sipNameNr_EnvelopeC1 40138
#define sipName_EnvelopeC1 &sipStrings_QtGui[40138]
#define sipNameNr_EnvelopeC2 40149
#define sipName_EnvelopeC2 &sipStrings_QtGui[40149]
#define sipNameNr_EnvelopeC3 40160
#define sipName_EnvelopeC3 &sipStrings_QtGui[40160]
#define sipNameNr_EnvelopeC4 40171
#define sipName_EnvelopeC4 &sipStrings_QtGui[40171]
#define sipNameNr_EnvelopeC5 40182
#define sipName_EnvelopeC5 &sipStrings_QtGui[40182]
#define sipNameNr_EnvelopeC6 40193
#define sipName_EnvelopeC6 &sipStrings_QtGui[40193]
#define sipNameNr_EnvelopeC7 40204
#define sipName_EnvelopeC7 &sipStrings_QtGui[40204]
#define sipNameNr_EnvelopeDL 40215
#define sipName_EnvelopeDL &sipStrings_QtGui[40215]
#define sipNameNr_ExactMatch 40226
#define sipName_ExactMatch &sipStrings_QtGui[40226]
#define sipNameNr_ExtraLight 40237
#define sipName_ExtraLight &sipStrings_QtGui[40237]
#define sipNameNr_FindBuffer 16225
#define sipName_FindBuffer &sipStrings_QtGui[16225]
#define sipNameNr_FloatRight 40248
#define sipName_FloatRight &sipStrings_QtGui[40248]
#define sipNameNr_FolderOpen 40259
#define sipName_FolderOpen &sipStrings_QtGui[40259]
#define sipNameNr_FontItalic 31399
#define sipName_FontItalic &sipStrings_QtGui[31399]
#define sipNameNr_FontWeight 31413
#define sipName_FontWeight &sipStrings_QtGui[31413]
#define sipNameNr_ForestInei 40270
#define sipName_ForestInei &sipStrings_QtGui[40270]
#define sipNameNr_FormatType 7261
#define sipName_FormatType &sipStrings_QtGui[7261]
#define sipNameNr_FrameWidth 40281
#define sipName_FrameWidth &sipStrings_QtGui[40281]
#define sipNameNr_FreshOasis 40292
#define sipName_FreshOasis &sipStrings_QtGui[40292]
#define sipNameNr_FrozenHeat 40303
#define sipName_FrozenHeat &sipStrings_QtGui[40303]
#define sipNameNr_FruitBlend 40314
#define sipName_FruitBlend &sipStrings_QtGui[40314]
#define sipNameNr_FullScreen 21559
#define sipName_FullScreen &sipStrings_QtGui[21559]
#define sipNameNr_FuzzyMatch 40325
#define sipName_FuzzyMatch &sipStrings_QtGui[40325]
#define sipNameNr_GentleCare 40336
#define sipName_GentleCare &sipStrings_QtGui[40336]
#define sipNameNr_GlassWater 40347
#define sipName_GlassWater &sipStrings_QtGui[40347]
#define sipNameNr_GoPrevious 40358
#define sipName_GoPrevious &sipStrings_QtGui[40358]
#define sipNameNr_GreatWhale 40369
#define sipName_GreatWhale &sipStrings_QtGui[40369]
#define sipNameNr_GrownEarly 40380
#define sipName_GrownEarly &sipStrings_QtGui[40380]
#define sipNameNr_HighFlight 40391
#define sipName_HighFlight &sipStrings_QtGui[40391]
#define sipNameNr_ImageTitle 40402
#define sipName_ImageTitle &sipStrings_QtGui[40402]
#define sipNameNr_ImageWidth 40413
#define sipName_ImageWidth &sipStrings_QtGui[40413]
#define sipNameNr_InputMouse 40424
#define sipName_InputMouse &sipStrings_QtGui[40424]
#define sipNameNr_InsertLink 40435
#define sipName_InsertLink &sipStrings_QtGui[40435]
#define sipNameNr_InsertText 40446
#define sipName_InsertText &sipStrings_QtGui[40446]
#define sipNameNr_InvertMode 14306
#define sipName_InvertMode &sipStrings_QtGui[14306]
#define sipNameNr_InvertRgba 40457
#define sipName_InvertRgba &sipStrings_QtGui[40457]
#define sipNameNr_IsNullHook 40468
#define sipName_IsNullHook &sipStrings_QtGui[40468]
#define sipNameNr_JapanBlush 40479
#define sipName_JapanBlush &sipStrings_QtGui[40479]
#define sipNameNr_JuicyPeach 40490
#define sipName_JuicyPeach &sipStrings_QtGui[40490]
#define sipNameNr_KeepAnchor 40501
#define sipName_KeepAnchor &sipStrings_QtGui[40501]
#define sipNameNr_LayoutFlag 10802
#define sipName_LayoutFlag &sipStrings_QtGui[10802]
#define sipNameNr_LeCocktail 40512
#define sipName_LeCocktail &sipStrings_QtGui[40512]
#define sipNameNr_LegalExtra 40523
#define sipName_LegalExtra &sipStrings_QtGui[40523]
#define sipNameNr_LetterPlus 40534
#define sipName_LetterPlus &sipStrings_QtGui[40534]
#define sipNameNr_LilyMeadow 40545
#define sipName_LilyMeadow &sipStrings_QtGui[40545]
#define sipNameNr_LineHeight 31483
#define sipName_LineHeight &sipStrings_QtGui[31483]
#define sipNameNr_ListCircle 40556
#define sipName_ListCircle &sipStrings_QtGui[40556]
#define sipNameNr_ListFormat 22859
#define sipName_ListFormat &sipStrings_QtGui[22859]
#define sipNameNr_ListIndent 40567
#define sipName_ListIndent &sipStrings_QtGui[40567]
#define sipNameNr_ListRemove 40578
#define sipName_ListRemove &sipStrings_QtGui[40578]
#define sipNameNr_ListSquare 40589
#define sipName_ListSquare &sipStrings_QtGui[40589]
#define sipNameNr_MacPrinter 40600
#define sipName_MacPrinter &sipStrings_QtGui[40600]
#define sipNameNr_MailUnread 40611
#define sipName_MailUnread &sipStrings_QtGui[40611]
#define sipNameNr_ManualWrap 40622
#define sipName_ManualWrap &sipStrings_QtGui[40622]
#define sipNameNr_MarbleWall 40633
#define sipName_MarbleWall &sipStrings_QtGui[40633]
#define sipNameNr_MarkerType 3902
#define sipName_MarkerType &sipStrings_QtGui[3902]
#define sipNameNr_MediaEject 40644
#define sipName_MediaEject &sipStrings_QtGui[40644]
#define sipNameNr_MediaFlash 40655
#define sipName_MediaFlash &sipStrings_QtGui[40655]
#define sipNameNr_Millimeter 40666
#define sipName_Millimeter &sipStrings_QtGui[40666]
#define sipNameNr_MixedHopes 40677
#define sipName_MixedHopes &sipStrings_QtGui[40677]
#define sipNameNr_MoveAnchor 40688
#define sipName_MoveAnchor &sipStrings_QtGui[40688]
#define sipNameNr_MovieState 14420
#define sipName_MovieState &sipStrings_QtGui[14420]
#define sipNameNr_NameFormat 14249
#define sipName_NameFormat &sipStrings_QtGui[14249]
#define sipNameNr_NativeText 40699
#define sipName_NativeText &sipStrings_QtGui[40699]
#define sipNameNr_NightParty 40710
#define sipName_NightParty &sipStrings_QtGui[40710]
#define sipNameNr_NoGradient 40721
#define sipName_NoGradient &sipStrings_QtGui[40721]
#define sipNameNr_NotRunning 40732
#define sipName_NotRunning &sipStrings_QtGui[40732]
#define sipNameNr_NumPresets 40743
#define sipName_NumPresets &sipStrings_QtGui[40743]
#define sipNameNr_ObjectMode 40754
#define sipName_ObjectMode &sipStrings_QtGui[40754]
#define sipNameNr_ObjectType 31539
#define sipName_ObjectType &sipStrings_QtGui[31539]
#define sipNameNr_OldEnglish 40765
#define sipName_OldEnglish &sipStrings_QtGui[40765]
#define sipNameNr_OpaqueHint 40776
#define sipName_OpaqueHint &sipStrings_QtGui[40776]
#define sipNameNr_OutlinePen 40787
#define sipName_OutlinePen &sipStrings_QtGui[40787]
#define sipNameNr_PageSizeId 9366
#define sipName_PageSizeId &sipStrings_QtGui[9366]
#define sipNameNr_PartyBliss 40798
#define sipName_PartyBliss &sipStrings_QtGui[40798]
#define sipNameNr_PdfVersion 3168
#define sipName_PdfVersion &sipStrings_QtGui[3168]
#define sipNameNr_PdmWidthMM 40809
#define sipName_PdmWidthMM &sipStrings_QtGui[40809]
#define sipNameNr_PorterDuff 40820
#define sipName_PorterDuff &sipStrings_QtGui[40820]
#define sipNameNr_QClipboard 40831
#define sipName_QClipboard &sipStrings_QtGui[40831]
#define sipNameNr_QDropEvent 40842
#define sipName_QDropEvent &sipStrings_QtGui[40842]
#define sipNameNr_QFont__Tag 40853
#define sipName_QFont__Tag &sipStrings_QtGui[40853]
#define sipNameNr_QHelpEvent 40864
#define sipName_QHelpEvent &sipStrings_QtGui[40864]
#define sipNameNr_QHideEvent 40875
#define sipName_QHideEvent &sipStrings_QtGui[40875]
#define sipNameNr_QMatrix2x2 40886
#define sipName_QMatrix2x2 &sipStrings_QtGui[40886]
#define sipNameNr_QMatrix2x3 40897
#define sipName_QMatrix2x3 &sipStrings_QtGui[40897]
#define sipNameNr_QMatrix2x4 40908
#define sipName_QMatrix2x4 &sipStrings_QtGui[40908]
#define sipNameNr_QMatrix3x2 40919
#define sipName_QMatrix3x2 &sipStrings_QtGui[40919]
#define sipNameNr_QMatrix3x3 40930
#define sipName_QMatrix3x3 &sipStrings_QtGui[40930]
#define sipNameNr_QMatrix3x4 40941
#define sipName_QMatrix3x4 &sipStrings_QtGui[40941]
#define sipNameNr_QMatrix4x2 40952
#define sipName_QMatrix4x2 &sipStrings_QtGui[40952]
#define sipNameNr_QMatrix4x3 40963
#define sipName_QMatrix4x3 &sipStrings_QtGui[40963]
#define sipNameNr_QMatrix4x4 40974
#define sipName_QMatrix4x4 &sipStrings_QtGui[40974]
#define sipNameNr_QMoveEvent 40985
#define sipName_QMoveEvent &sipStrings_QtGui[40985]
#define sipNameNr_QPdfWriter 40996
#define sipName_QPdfWriter &sipStrings_QtGui[40996]
#define sipNameNr_QShowEvent 41007
#define sipName_QShowEvent &sipStrings_QtGui[41007]
#define sipNameNr_QTextBlock 41018
#define sipName_QTextBlock &sipStrings_QtGui[41018]
#define sipNameNr_QTextFrame 41029
#define sipName_QTextFrame &sipStrings_QtGui[41029]
#define sipNameNr_QTextTable 41040
#define sipName_QTextTable &sipStrings_QtGui[41040]
#define sipNameNr_QTransform 41051
#define sipName_QTransform &sipStrings_QtGui[41051]
#define sipNameNr_QUndoGroup 41062
#define sipName_QUndoGroup &sipStrings_QtGui[41062]
#define sipNameNr_QUndoStack 41073
#define sipName_QUndoStack &sipStrings_QtGui[41073]
#define sipNameNr_QValidator 41084
#define sipName_QValidator &sipStrings_QtGui[41084]
#define sipNameNr_RegionType 12560
#define sipName_RegionType &sipStrings_QtGui[12560]
#define sipNameNr_RenderFlag 9542
#define sipName_RenderFlag &sipStrings_QtGui[9542]
#define sipNameNr_RenderHint 10760
#define sipName_RenderHint &sipStrings_QtGui[10760]
#define sipNameNr_SRgbLinear 41095
#define sipName_SRgbLinear &sipStrings_QtGui[41095]
#define sipNameNr_SandStrike 41106
#define sipName_SandStrike &sipStrings_QtGui[41106]
#define sipNameNr_ScaledSize 31651
#define sipName_ScaledSize &sipStrings_QtGui[31651]
#define sipNameNr_ShadyWater 41117
#define sipName_ShadyWater &sipStrings_QtGui[41117]
#define sipNameNr_SharpBlues 41128
#define sipName_SharpBlues &sipStrings_QtGui[41128]
#define sipNameNr_ShyRainbow 41139
#define sipName_ShyRainbow &sipStrings_QtGui[41139]
#define sipNameNr_SolidStone 41150
#define sipName_SolidStone &sipStrings_QtGui[41150]
#define sipNameNr_SpaceShift 41161
#define sipName_SpaceShift &sipStrings_QtGui[41161]
#define sipNameNr_Stationary 41172
#define sipName_Stationary &sipStrings_QtGui[41172]
#define sipNameNr_SupremeSky 41183
#define sipName_SupremeSky &sipStrings_QtGui[41183]
#define sipNameNr_SystemFont 5378
#define sipName_SystemFont &sipStrings_QtGui[5378]
#define sipNameNr_TextFormat 31679
#define sipName_TextFormat &sipStrings_QtGui[31679]
#define sipNameNr_TextIndent 31693
#define sipName_TextIndent &sipStrings_QtGui[31693]
#define sipNameNr_TrueSunset 41194
#define sipName_TrueSunset &sipStrings_QtGui[41194]
#define sipNameNr_TypeWriter 41205
#define sipName_TypeWriter &sipStrings_QtGui[41205]
#define sipNameNr_UnknownKey 41216
#define sipName_UnknownKey &sipStrings_QtGui[41216]
#define sipNameNr_UserFormat 41227
#define sipName_UserFormat &sipStrings_QtGui[41227]
#define sipNameNr_UserObject 41238
#define sipName_UserObject &sipStrings_QtGui[41238]
#define sipNameNr_Vietnamese 41249
#define sipName_Vietnamese &sipStrings_QtGui[41249]
#define sipNameNr_Visibility 12040
#define sipName_Visibility &sipStrings_QtGui[12040]
#define sipNameNr_WeatherFog 41260
#define sipName_WeatherFog &sipStrings_QtGui[41260]
#define sipNameNr_WideMatrix 41271
#define sipName_WideMatrix &sipStrings_QtGui[41271]
#define sipNameNr_WindowText 41282
#define sipName_WindowText &sipStrings_QtGui[41282]
#define sipNameNr_WinterNeva 41293
#define sipName_WinterNeva &sipStrings_QtGui[41293]
#define sipNameNr_WitchDance 41304
#define sipName_WitchDance &sipStrings_QtGui[41304]
#define sipNameNr_YoungGrass 41315
#define sipName_YoungGrass &sipStrings_QtGui[41315]
#define sipNameNr___lshift__ 41326
#define sipName___lshift__ &sipStrings_QtGui[41326]
#define sipNameNr___matmul__ 41337
#define sipName___matmul__ &sipStrings_QtGui[41337]
#define sipNameNr___rshift__ 41348
#define sipName___rshift__ &sipStrings_QtGui[41348]
#define sipNameNr_actionText 41359
#define sipName_actionText &sipStrings_QtGui[41359]
#define sipNameNr_actualSize 41370
#define sipName_actualSize &sipStrings_QtGui[41370]
#define sipNameNr_addEllipse 41381
#define sipName_addEllipse &sipStrings_QtGui[41381]
#define sipNameNr_addPolygon 41392
#define sipName_addPolygon &sipStrings_QtGui[41392]
#define sipNameNr_adjustSize 41403
#define sipName_adjustSize &sipStrings_QtGui[41403]
#define sipNameNr_allFormats 41414
#define sipName_allFormats &sipStrings_QtGui[41414]
#define sipNameNr_allWindows 41425
#define sipName_allWindows &sipStrings_QtGui[41425]
#define sipNameNr_alphaUsage 41436
#define sipName_alphaUsage &sipStrings_QtGui[41436]
#define sipNameNr_anchorHref 41447
#define sipName_anchorHref &sipStrings_QtGui[41447]
#define sipNameNr_angleDelta 41458
#define sipName_angleDelta &sipStrings_QtGui[41458]
#define sipNameNr_answerRect 41469
#define sipName_answerRect &sipStrings_QtGui[41469]
#define sipNameNr_appendRows 41480
#define sipName_appendRows &sipStrings_QtGui[41480]
#define sipNameNr_aquamarine 20862
#define sipName_aquamarine &sipStrings_QtGui[20862]
#define sipNameNr_areSharing 41491
#define sipName_areSharing &sipStrings_QtGui[41491]
#define sipNameNr_atBlockEnd 41502
#define sipName_atBlockEnd &sipStrings_QtGui[41502]
#define sipNameNr_attributes 41513
#define sipName_attributes &sipStrings_QtGui[41513]
#define sipNameNr_autoRepeat 41524
#define sipName_autoRepeat &sipStrings_QtGui[41524]
#define sipNameNr_background 41535
#define sipName_background &sipStrings_QtGui[41535]
#define sipNameNr_beginMacro 41546
#define sipName_beginMacro &sipStrings_QtGui[41546]
#define sipNameNr_beginPaint 41557
#define sipName_beginPaint &sipStrings_QtGui[41557]
#define sipNameNr_blockCount 41568
#define sipName_blockCount &sipStrings_QtGui[41568]
#define sipNameNr_blueviolet 41579
#define sipName_blueviolet &sipStrings_QtGui[41579]
#define sipNameNr_brightText 41590
#define sipName_brightText &sipStrings_QtGui[41590]
#define sipNameNr_buttonText 41601
#define sipName_buttonText &sipStrings_QtGui[41601]
#define sipNameNr_cacheLimit 41612
#define sipName_cacheLimit &sipStrings_QtGui[41612]
#define sipNameNr_charFormat 41623
#define sipName_charFormat &sipStrings_QtGui[41623]
#define sipNameNr_chartreuse 41634
#define sipName_chartreuse &sipStrings_QtGui[41634]
#define sipNameNr_checkState 41645
#define sipName_checkState &sipStrings_QtGui[41645]
#define sipNameNr_childCount 41656
#define sipName_childCount &sipStrings_QtGui[41656]
#define sipNameNr_childEvent 41667
#define sipName_childEvent &sipStrings_QtGui[41667]
#define sipNameNr_cleanIndex 41678
#define sipName_cleanIndex &sipStrings_QtGui[41678]
#define sipNameNr_clipRegion 41689
#define sipName_clipRegion &sipStrings_QtGui[41689]
#define sipNameNr_closeEvent 41700
#define sipName_closeEvent &sipStrings_QtGui[41700]
#define sipNameNr_colorCount 41711
#define sipName_colorCount &sipStrings_QtGui[41711]
#define sipNameNr_colorModel 41722
#define sipName_colorModel &sipStrings_QtGui[41722]
#define sipNameNr_colorNames 41733
#define sipName_colorNames &sipStrings_QtGui[41733]
#define sipNameNr_colorSpace 41744
#define sipName_colorSpace &sipStrings_QtGui[41744]
#define sipNameNr_colorTable 41755
#define sipName_colorTable &sipStrings_QtGui[41755]
#define sipNameNr_columnSpan 41766
#define sipName_columnSpan &sipStrings_QtGui[41766]
#define sipNameNr_conjugated 41777
#define sipName_conjugated &sipStrings_QtGui[41777]
#define sipNameNr_connection 41788
#define sipName_connection &sipStrings_QtGui[41788]
#define sipNameNr_contentPos 41799
#define sipName_contentPos &sipStrings_QtGui[41799]
#define sipNameNr_copyDataTo 41810
#define sipName_copyDataTo &sipStrings_QtGui[41810]
#define sipNameNr_createLine 41821
#define sipName_createLine &sipStrings_QtGui[41821]
#define sipNameNr_createList 41832
#define sipName_createList &sipStrings_QtGui[41832]
#define sipNameNr_darkorange 41843
#define sipName_darkorange &sipStrings_QtGui[41843]
#define sipNameNr_darkorchid 41854
#define sipName_darkorchid &sipStrings_QtGui[41854]
#define sipNameNr_darksalmon 41865
#define sipName_darksalmon &sipStrings_QtGui[41865]
#define sipNameNr_darkviolet 41876
#define sipName_darkviolet &sipStrings_QtGui[41876]
#define sipNameNr_dashOffset 41887
#define sipName_dashOffset &sipStrings_QtGui[41887]
#define sipNameNr_deleteChar 41898
#define sipName_deleteChar &sipStrings_QtGui[41898]
#define sipNameNr_deviceType 41909
#define sipName_deviceType &sipStrings_QtGui[41909]
#define sipNameNr_documentId 41920
#define sipName_documentId &sipStrings_QtGui[41920]
#define sipNameNr_dodgerblue 41931
#define sipName_dodgerblue &sipStrings_QtGui[41931]
#define sipNameNr_dotProduct 41942
#define sipName_dotProduct &sipStrings_QtGui[41942]
#define sipNameNr_dragCursor 41953
#define sipName_dragCursor &sipStrings_QtGui[41953]
#define sipNameNr_drawCursor 41964
#define sipName_drawCursor &sipStrings_QtGui[41964]
#define sipNameNr_drawObject 41975
#define sipName_drawObject &sipStrings_QtGui[41975]
#define sipNameNr_drawPixmap 41986
#define sipName_drawPixmap &sipStrings_QtGui[41986]
#define sipNameNr_drawPoints 41997
#define sipName_drawPoints &sipStrings_QtGui[41997]
#define sipNameNr_dropAction 42008
#define sipName_dropAction &sipStrings_QtGui[42008]
#define sipNameNr_elidedText 42019
#define sipName_elidedText &sipStrings_QtGui[42019]
#define sipNameNr_exactMatch 42030
#define sipName_exactMatch &sipStrings_QtGui[42030]
#define sipNameNr_extensions 42041
#define sipName_extensions &sipStrings_QtGui[42041]
#define sipNameNr_familyName 42052
#define sipName_familyName &sipStrings_QtGui[42052]
#define sipNameNr_firstBlock 42063
#define sipName_firstBlock &sipStrings_QtGui[42063]
#define sipNameNr_fixedPitch 42074
#define sipName_fixedPitch &sipStrings_QtGui[42074]
#define sipNameNr_focalPoint 42085
#define sipName_focalPoint &sipStrings_QtGui[42085]
#define sipNameNr_fontFamily 42096
#define sipName_fontFamily &sipStrings_QtGui[42096]
#define sipNameNr_fontItalic 42107
#define sipName_fontItalic &sipStrings_QtGui[42107]
#define sipNameNr_fontWeight 42118
#define sipName_fontWeight &sipStrings_QtGui[42118]
#define sipNameNr_foreground 42129
#define sipName_foreground &sipStrings_QtGui[42129]
#define sipNameNr_frameCount 42140
#define sipName_frameCount &sipStrings_QtGui[42140]
#define sipNameNr_fromArgb32 42151
#define sipName_fromArgb32 &sipStrings_QtGui[42151]
#define sipNameNr_fromPixmap 42162
#define sipName_fromPixmap &sipStrings_QtGui[42162]
#define sipNameNr_fromRgba64 42173
#define sipName_fromRgba64 &sipStrings_QtGui[42173]
#define sipNameNr_fromString 42184
#define sipName_fromString &sipStrings_QtGui[42184]
#define sipNameNr_ghostwhite 42195
#define sipName_ghostwhite &sipStrings_QtGui[42195]
#define sipNameNr_glyphCount 42206
#define sipName_glyphCount &sipStrings_QtGui[42206]
#define sipNameNr_grabWindow 42217
#define sipName_grabWindow &sipStrings_QtGui[42217]
#define sipNameNr_hasFeature 42228
#define sipName_hasFeature &sipStrings_QtGui[42228]
#define sipNameNr_headerData 42239
#define sipName_headerData &sipStrings_QtGui[42239]
#define sipNameNr_horizontal 42250
#define sipName_horizontal &sipStrings_QtGui[42250]
#define sipNameNr_iccProfile 42261
#define sipName_iccProfile &sipStrings_QtGui[42261]
#define sipNameNr_idealWidth 42272
#define sipName_idealWidth &sipStrings_QtGui[42272]
#define sipNameNr_imageCount 42283
#define sipName_imageCount &sipStrings_QtGui[42283]
#define sipNameNr_inFontUcs4 42294
#define sipName_inFontUcs4 &sipStrings_QtGui[42294]
#define sipNameNr_initialize 42305
#define sipName_initialize &sipStrings_QtGui[42305]
#define sipNameNr_insertHtml 42316
#define sipName_insertHtml &sipStrings_QtGui[42316]
#define sipNameNr_insertList 42327
#define sipName_insertList &sipStrings_QtGui[42327]
#define sipNameNr_insertRows 42338
#define sipName_insertRows &sipStrings_QtGui[42338]
#define sipNameNr_insertText 42349
#define sipName_insertText &sipStrings_QtGui[42349]
#define sipNameNr_intersects 42360
#define sipName_intersects &sipStrings_QtGui[42360]
#define sipNameNr_invertible 42371
#define sipName_invertible &sipStrings_QtGui[42371]
#define sipNameNr_isAccepted 42382
#define sipName_isAccepted &sipStrings_QtGui[42382]
#define sipNameNr_isBrushSet 42393
#define sipName_isBrushSet &sipStrings_QtGui[42393]
#define sipNameNr_isCosmetic 42404
#define sipName_isCosmetic &sipStrings_QtGui[42404]
#define sipNameNr_isDetached 42415
#define sipName_isDetached &sipStrings_QtGui[42415]
#define sipNameNr_isEditable 42426
#define sipName_isEditable &sipStrings_QtGui[42426]
#define sipNameNr_isEndEvent 42437
#define sipName_isEndEvent &sipStrings_QtGui[42437]
#define sipNameNr_isIdentity 42448
#define sipName_isIdentity &sipStrings_QtGui[42448]
#define sipNameNr_isModified 42459
#define sipName_isModified &sipStrings_QtGui[42459]
#define sipNameNr_isObsolete 42470
#define sipName_isObsolete &sipStrings_QtGui[42470]
#define sipNameNr_isOpenGLES 42481
#define sipName_isOpenGLES &sipStrings_QtGui[42481]
#define sipNameNr_isPortrait 42492
#define sipName_isPortrait &sipStrings_QtGui[42492]
#define sipNameNr_isReadOnly 42503
#define sipName_isReadOnly &sipStrings_QtGui[42503]
#define sipNameNr_isRotating 42514
#define sipName_isRotating &sipStrings_QtGui[42514]
#define sipNameNr_isScalable 42525
#define sipName_isScalable &sipStrings_QtGui[42525]
#define sipNameNr_isTopLevel 42536
#define sipName_isTopLevel &sipStrings_QtGui[42536]
#define sipNameNr_itemNumber 42547
#define sipName_itemNumber &sipStrings_QtGui[42547]
#define sipNameNr_leftBorder 42558
#define sipName_leftBorder &sipStrings_QtGui[42558]
#define sipNameNr_leftMargin 42569
#define sipName_leftMargin &sipStrings_QtGui[42569]
#define sipNameNr_lightcoral 42580
#define sipName_lightcoral &sipStrings_QtGui[42580]
#define sipNameNr_lightgreen 42591
#define sipName_lightgreen &sipStrings_QtGui[42591]
#define sipNameNr_lightnessF 42602
#define sipName_lightnessF &sipStrings_QtGui[42602]
#define sipNameNr_lineHeight 42613
#define sipName_lineHeight &sipStrings_QtGui[42613]
#define sipNameNr_lineNumber 42624
#define sipName_lineNumber &sipStrings_QtGui[42624]
#define sipNameNr_mapBetween 42635
#define sipName_mapBetween &sipStrings_QtGui[42635]
#define sipNameNr_mediumblue 42646
#define sipName_mediumblue &sipStrings_QtGui[42646]
#define sipNameNr_mergeCells 42657
#define sipName_mergeCells &sipStrings_QtGui[42657]
#define sipNameNr_minMargins 42668
#define sipName_minMargins &sipStrings_QtGui[42668]
#define sipNameNr_miterLimit 42679
#define sipName_miterLimit &sipStrings_QtGui[42679]
#define sipNameNr_myComputer 42690
#define sipName_myComputer &sipStrings_QtGui[42690]
#define sipNameNr_normalized 42701
#define sipName_normalized &sipStrings_QtGui[42701]
#define sipNameNr_objectType 42712
#define sipName_objectType &sipStrings_QtGui[42712]
#define sipNameNr_pageLayout 42723
#define sipName_pageLayout &sipStrings_QtGui[42723]
#define sipNameNr_pageRanges 42734
#define sipName_pageRanges &sipStrings_QtGui[42734]
#define sipNameNr_paintEvent 42745
#define sipName_paintEvent &sipStrings_QtGui[42745]
#define sipNameNr_papayawhip 42756
#define sipName_papayawhip &sipStrings_QtGui[42756]
#define sipNameNr_pdfVersion 42767
#define sipName_pdfVersion &sipStrings_QtGui[42767]
#define sipNameNr_pixelColor 42778
#define sipName_pixelColor &sipStrings_QtGui[42778]
#define sipNameNr_pixelDelta 42789
#define sipName_pixelDelta &sipStrings_QtGui[42789]
#define sipNameNr_pixelIndex 42800
#define sipName_pixelIndex &sipStrings_QtGui[42800]
#define sipNameNr_pointCount 42811
#define sipName_pointCount &sipStrings_QtGui[42811]
#define sipNameNr_pointSizeF 42822
#define sipName_pointSizeF &sipStrings_QtGui[42822]
#define sipNameNr_pointSizes 42833
#define sipName_pointSizes &sipStrings_QtGui[42833]
#define sipNameNr_powderblue 42844
#define sipName_powderblue &sipStrings_QtGui[42844]
#define sipNameNr_properties 42855
#define sipName_properties &sipStrings_QtGui[42855]
#define sipNameNr_quadToQuad 42866
#define sipName_quadToQuad &sipStrings_QtGui[42866]
#define sipNameNr_rectPixels 42877
#define sipName_rectPixels &sipStrings_QtGui[42877]
#define sipNameNr_rectPoints 42888
#define sipName_rectPoints &sipStrings_QtGui[42888]
#define sipNameNr_removeItem 42899
#define sipName_removeItem &sipStrings_QtGui[42899]
#define sipNameNr_removeRows 42910
#define sipName_removeRows &sipStrings_QtGui[42910]
#define sipNameNr_resetClean 42921
#define sipName_resetClean &sipStrings_QtGui[42921]
#define sipNameNr_resolution 42932
#define sipName_resolution &sipStrings_QtGui[42932]
#define sipNameNr_rgbSwapped 42943
#define sipName_rgbSwapped &sipStrings_QtGui[42943]
#define sipNameNr_rotationTo 42954
#define sipName_rotationTo &sipStrings_QtGui[42954]
#define sipNameNr_sandybrown 42965
#define sipName_sandybrown &sipStrings_QtGui[42965]
#define sipNameNr_saturation 42976
#define sipName_saturation &sipStrings_QtGui[42976]
#define sipNameNr_scaledSize 42987
#define sipName_scaledSize &sipStrings_QtGui[42987]
#define sipNameNr_selections 42998
#define sipName_selections &sipStrings_QtGui[42998]
#define sipNameNr_sequenceId 43009
#define sipName_sequenceId &sipStrings_QtGui[43009]
#define sipNameNr_sessionKey 43020
#define sipName_sessionKey &sipStrings_QtGui[43020]
#define sipNameNr_setBaseUrl 43031
#define sipName_setBaseUrl &sipStrings_QtGui[43031]
#define sipNameNr_setChecked 43042
#define sipName_setChecked &sipStrings_QtGui[43042]
#define sipNameNr_setColorAt 43053
#define sipName_setColorAt &sipStrings_QtGui[43053]
#define sipNameNr_setColumns 43064
#define sipName_setColumns &sipStrings_QtGui[43064]
#define sipNameNr_setContext 43075
#define sipName_setContext &sipStrings_QtGui[43075]
#define sipNameNr_setCreator 43086
#define sipName_setCreator &sipStrings_QtGui[43086]
#define sipNameNr_setDescent 43097
#define sipName_setDescent &sipStrings_QtGui[43097]
#define sipNameNr_setEnabled 35283
#define sipName_setEnabled &sipStrings_QtGui[35283]
#define sipNameNr_setFeature 35920
#define sipName_setFeature &sipStrings_QtGui[35920]
#define sipNameNr_setFormats 43108
#define sipName_setFormats &sipStrings_QtGui[43108]
#define sipNameNr_setHotSpot 43119
#define sipName_setHotSpot &sipStrings_QtGui[43119]
#define sipNameNr_setKerning 43130
#define sipName_setKerning &sipStrings_QtGui[43130]
#define sipNameNr_setMargins 43141
#define sipName_setMargins &sipStrings_QtGui[43141]
#define sipNameNr_setOpacity 43152
#define sipName_setOpacity &sipStrings_QtGui[43152]
#define sipNameNr_setOptions 43163
#define sipName_setOptions &sipStrings_QtGui[43163]
#define sipNameNr_setPadding 43174
#define sipName_setPadding &sipStrings_QtGui[43174]
#define sipNameNr_setPalette 43185
#define sipName_setPalette &sipStrings_QtGui[43185]
#define sipNameNr_setProfile 43196
#define sipName_setProfile &sipStrings_QtGui[43196]
#define sipNameNr_setQuality 43207
#define sipName_setQuality &sipStrings_QtGui[43207]
#define sipNameNr_setRawFont 43218
#define sipName_setRawFont &sipStrings_QtGui[43218]
#define sipNameNr_setSamples 43229
#define sipName_setSamples &sipStrings_QtGui[43229]
#define sipNameNr_setStretch 43240
#define sipName_setStretch &sipStrings_QtGui[43240]
#define sipNameNr_setSubType 43251
#define sipName_setSubType &sipStrings_QtGui[43251]
#define sipNameNr_setTexture 43262
#define sipName_setTexture &sipStrings_QtGui[43262]
#define sipNameNr_setToolTip 43273
#define sipName_setToolTip &sipStrings_QtGui[43273]
#define sipNameNr_setVersion 43284
#define sipName_setVersion &sipStrings_QtGui[43284]
#define sipNameNr_setVisible 43295
#define sipName_setVisible &sipStrings_QtGui[43295]
#define sipNameNr_shareGroup 43306
#define sipName_shareGroup &sipStrings_QtGui[43306]
#define sipNameNr_shortcutId 43317
#define sipName_shortcutId &sipStrings_QtGui[43317]
#define sipNameNr_showNormal 43328
#define sipName_showNormal &sipStrings_QtGui[43328]
#define sipNameNr_simplified 43339
#define sipName_simplified &sipStrings_QtGui[43339]
#define sipNameNr_sizePixels 43350
#define sipName_sizePixels &sipStrings_QtGui[43350]
#define sipNameNr_sizePoints 43361
#define sipName_sizePoints &sipStrings_QtGui[43361]
#define sipNameNr_sourceLeft 43372
#define sipName_sourceLeft &sipStrings_QtGui[43372]
#define sipNameNr_strokePath 43383
#define sipName_strokePath &sipStrings_QtGui[43383]
#define sipNameNr_styleHints 43394
#define sipName_styleHints &sipStrings_QtGui[43394]
#define sipNameNr_substitute 43405
#define sipName_substitute &sipStrings_QtGui[43405]
#define sipNameNr_subtracted 43416
#define sipName_subtracted &sipStrings_QtGui[43416]
#define sipNameNr_systemFont 43427
#define sipName_systemFont &sipStrings_QtGui[43427]
#define sipNameNr_takeColumn 43438
#define sipName_takeColumn &sipStrings_QtGui[43438]
#define sipNameNr_testOption 43449
#define sipName_testOption &sipStrings_QtGui[43449]
#define sipNameNr_textFormat 43460
#define sipName_textFormat &sipStrings_QtGui[43460]
#define sipNameNr_textIndent 43471
#define sipName_textIndent &sipStrings_QtGui[43471]
#define sipNameNr_textLength 43482
#define sipName_textLength &sipStrings_QtGui[43482]
#define sipNameNr_textOption 43493
#define sipName_textOption &sipStrings_QtGui[43493]
#define sipNameNr_timerEvent 43504
#define sipName_timerEvent &sipStrings_QtGui[43504]
#define sipNameNr_toMarkdown 43515
#define sipName_toMarkdown &sipStrings_QtGui[43515]
#define sipNameNr_toPolygonF 43526
#define sipName_toPolygonF &sipStrings_QtGui[43526]
#define sipNameNr_toReversed 43537
#define sipName_toReversed &sipStrings_QtGui[43537]
#define sipNameNr_toVector2D 43548
#define sipName_toVector2D &sipStrings_QtGui[43548]
#define sipNameNr_toVector3D 43559
#define sipName_toVector3D &sipStrings_QtGui[43559]
#define sipNameNr_toVector4D 43570
#define sipName_toVector4D &sipStrings_QtGui[43570]
#define sipNameNr_topLevelAt 43581
#define sipName_topLevelAt &sipStrings_QtGui[43581]
#define sipNameNr_topPadding 43592
#define sipName_topPadding &sipStrings_QtGui[43592]
#define sipNameNr_touchEvent 43603
#define sipName_touchEvent &sipStrings_QtGui[43603]
#define sipNameNr_translated 43614
#define sipName_translated &sipStrings_QtGui[43614]
#define sipNameNr_transposed 43625
#define sipName_transposed &sipStrings_QtGui[43625]
#define sipNameNr_trueMatrix 43636
#define sipName_trueMatrix &sipStrings_QtGui[43636]
#define sipNameNr_unitsPerEm 43647
#define sipName_unitsPerEm &sipStrings_QtGui[43647]
#define sipNameNr_visibility 43658
#define sipName_visibility &sipStrings_QtGui[43658]
#define sipNameNr_wheelEvent 43669
#define sipName_wheelEvent &sipStrings_QtGui[43669]
#define sipNameNr_whitePoint 43680
#define sipName_whitePoint &sipStrings_QtGui[43680]
#define sipNameNr_whitesmoke 43691
#define sipName_whitesmoke &sipStrings_QtGui[43691]
#define sipNameNr_windowIcon 43702
#define sipName_windowIcon &sipStrings_QtGui[43702]
#define sipNameNr_windowText 43713
#define sipName_windowText &sipStrings_QtGui[43713]
#define sipNameNr_yellowSize 43724
#define sipName_yellowSize &sipStrings_QtGui[43724]
#define sipNameNr_AboutRole 43735
#define sipName_AboutRole &sipStrings_QtGui[43735]
#define sipNameNr_AngelCare 43745
#define sipName_AngelCare &sipStrings_QtGui[43745]
#define sipNameNr_Animation 19184
#define sipName_Animation &sipStrings_QtGui[19184]
#define sipNameNr_Attribute 3671
#define sipName_Attribute &sipStrings_QtGui[3671]
#define sipNameNr_AudioCard 43755
#define sipName_AudioCard &sipStrings_QtGui[43755]
#define sipNameNr_Backspace 43765
#define sipName_Backspace &sipStrings_QtGui[43765]
#define sipNameNr_BigEndian 43775
#define sipName_BigEndian &sipStrings_QtGui[43775]
#define sipNameNr_Bt2100Hlg 43785
#define sipName_Bt2100Hlg &sipStrings_QtGui[43785]
#define sipNameNr_ByteOrder 7142
#define sipName_ByteOrder &sipStrings_QtGui[7142]
#define sipNameNr_CacheMode 17222
#define sipName_CacheMode &sipStrings_QtGui[17222]
#define sipNameNr_CacheNone 43795
#define sipName_CacheNone &sipStrings_QtGui[43795]
#define sipNameNr_CallStart 43805
#define sipName_CallStart &sipStrings_QtGui[43805]
#define sipNameNr_CameraWeb 43815
#define sipName_CameraWeb &sipStrings_QtGui[43815]
#define sipNameNr_CenterTab 43825
#define sipName_CenterTab &sipStrings_QtGui[43825]
#define sipNameNr_ChildCare 43835
#define sipName_ChildCare &sipStrings_QtGui[43835]
#define sipNameNr_Clipboard 30798
#define sipName_Clipboard &sipStrings_QtGui[30798]
#define sipNameNr_ColorRole 12541
#define sipName_ColorRole &sipStrings_QtGui[12541]
#define sipNameNr_Condensed 25480
#define sipName_Condensed &sipStrings_QtGui[25480]
#define sipNameNr_DarkGreen 43845
#define sipName_DarkGreen &sipStrings_QtGui[43845]
#define sipNameNr_DirtyFlag 7118
#define sipName_DirtyFlag &sipStrings_QtGui[7118]
#define sipNameNr_DirtyFont 43855
#define sipName_DirtyFont &sipStrings_QtGui[43855]
#define sipNameNr_DisplayP3 43865
#define sipName_DisplayP3 &sipStrings_QtGui[43865]
#define sipNameNr_EditClear 43875
#define sipName_EditClear &sipStrings_QtGui[43875]
#define sipNameNr_EditPaste 43885
#define sipName_EditPaste &sipStrings_QtGui[43885]
#define sipNameNr_EndOfLine 22092
#define sipName_EndOfLine &sipStrings_QtGui[22092]
#define sipNameNr_EndOfWord 22108
#define sipName_EndOfWord &sipStrings_QtGui[22108]
#define sipNameNr_Envelope9 43895
#define sipName_Envelope9 &sipStrings_QtGui[43895]
#define sipNameNr_Exclusive 35414
#define sipName_Exclusive &sipStrings_QtGui[35414]
#define sipNameNr_Executive 43905
#define sipName_Executive &sipStrings_QtGui[43905]
#define sipNameNr_ExtraBold 43915
#define sipName_ExtraBold &sipStrings_QtGui[43915]
#define sipNameNr_FanFoldUS 43925
#define sipName_FanFoldUS &sipStrings_QtGui[43925]
#define sipNameNr_FixedFont 43935
#define sipName_FixedFont &sipStrings_QtGui[43935]
#define sipNameNr_FloatLeft 43945
#define sipName_FloatLeft &sipStrings_QtGui[43945]
#define sipNameNr_FolderNew 43955
#define sipName_FolderNew &sipStrings_QtGui[43955]
#define sipNameNr_FreshMilk 43965
#define sipName_FreshMilk &sipStrings_QtGui[43965]
#define sipNameNr_Grayscale 10203
#define sipName_Grayscale &sipStrings_QtGui[10203]
#define sipNameNr_HappyAcid 43975
#define sipName_HappyAcid &sipStrings_QtGui[43975]
#define sipNameNr_HeavyRain 43985
#define sipName_HeavyRain &sipStrings_QtGui[43985]
#define sipNameNr_HelpAbout 43995
#define sipName_HelpAbout &sipStrings_QtGui[43995]
#define sipNameNr_Helvetica 44005
#define sipName_Helvetica &sipStrings_QtGui[44005]
#define sipNameNr_Highlight 44015
#define sipName_Highlight &sipStrings_QtGui[44015]
#define sipNameNr_ImageName 44025
#define sipName_ImageName &sipStrings_QtGui[44025]
#define sipNameNr_InvertRgb 44035
#define sipName_InvertRgb &sipStrings_QtGui[44035]
#define sipNameNr_JuicyCake 44045
#define sipName_JuicyCake &sipStrings_QtGui[44045]
#define sipNameNr_JungleDay 44055
#define sipName_JungleDay &sipStrings_QtGui[44055]
#define sipNameNr_KindSteel 44065
#define sipName_KindSteel &sipStrings_QtGui[44065]
#define sipNameNr_Landscape 38421
#define sipName_Landscape &sipStrings_QtGui[38421]
#define sipNameNr_LemonGate 44075
#define sipName_LemonGate &sipStrings_QtGui[44075]
#define sipNameNr_LightBlue 44085
#define sipName_LightBlue &sipStrings_QtGui[44085]
#define sipNameNr_LightGray 44095
#define sipName_LightGray &sipStrings_QtGui[44095]
#define sipNameNr_ListStart 44105
#define sipName_ListStart &sipStrings_QtGui[44105]
#define sipNameNr_ListStyle 44115
#define sipName_ListStyle &sipStrings_QtGui[44115]
#define sipNameNr_MagicLake 44125
#define sipName_MagicLake &sipStrings_QtGui[44125]
#define sipNameNr_Malayalam 44135
#define sipName_Malayalam &sipStrings_QtGui[44135]
#define sipNameNr_MarsParty 44145
#define sipName_MarsParty &sipStrings_QtGui[44145]
#define sipNameNr_Maximized 25020
#define sipName_Maximized &sipStrings_QtGui[25020]
#define sipNameNr_MeanFruit 44155
#define sipName_MeanFruit &sipStrings_QtGui[44155]
#define sipNameNr_MediaTape 44165
#define sipName_MediaTape &sipStrings_QtGui[44165]
#define sipNameNr_MindCrawl 44175
#define sipName_MindCrawl &sipStrings_QtGui[44175]
#define sipNameNr_Minimized 31806
#define sipName_Minimized &sipStrings_QtGui[31806]
#define sipNameNr_MixedCase 44185
#define sipName_MixedCase &sipStrings_QtGui[44185]
#define sipNameNr_Monospace 44195
#define sipName_Monospace &sipStrings_QtGui[44195]
#define sipNameNr_NextBlock 44205
#define sipName_NextBlock &sipStrings_QtGui[44205]
#define sipNameNr_NextChild 44215
#define sipName_NextChild &sipStrings_QtGui[44215]
#define sipNameNr_NightCall 44225
#define sipName_NightCall &sipStrings_QtGui[44225]
#define sipNameNr_NightFade 44235
#define sipName_NightFade &sipStrings_QtGui[44235]
#define sipNameNr_NoProfile 44245
#define sipName_NoProfile &sipStrings_QtGui[44245]
#define sipNameNr_Offscreen 44255
#define sipName_Offscreen &sipStrings_QtGui[44255]
#define sipNameNr_PadSpread 44265
#define sipName_PadSpread &sipStrings_QtGui[44265]
#define sipNameNr_PdmHeight 44275
#define sipName_PdmHeight &sipStrings_QtGui[44275]
#define sipNameNr_PlumPlate 44285
#define sipName_PlumPlate &sipStrings_QtGui[44285]
#define sipNameNr_Prc32KBig 44295
#define sipName_Prc32KBig &sipStrings_QtGui[44295]
#define sipNameNr_Primaries 8163
#define sipName_Primaries &sipStrings_QtGui[8163]
#define sipNameNr_QFontInfo 44305
#define sipName_QFontInfo &sipStrings_QtGui[44305]
#define sipNameNr_QGlyphRun 44315
#define sipName_QGlyphRun &sipStrings_QtGui[44315]
#define sipNameNr_QGradient 44325
#define sipName_QGradient &sipStrings_QtGui[44325]
#define sipNameNr_QKeyEvent 44335
#define sipName_QKeyEvent &sipStrings_QtGui[44335]
#define sipNameNr_QPageSize 44345
#define sipName_QPageSize &sipStrings_QtGui[44345]
#define sipNameNr_QPolygonF 44355
#define sipName_QPolygonF &sipStrings_QtGui[44355]
#define sipNameNr_QShortcut 44365
#define sipName_QShortcut &sipStrings_QtGui[44365]
#define sipNameNr_QTextItem 44375
#define sipName_QTextItem &sipStrings_QtGui[44375]
#define sipNameNr_QTextLine 44385
#define sipName_QTextLine &sipStrings_QtGui[44385]
#define sipNameNr_QTextList 44395
#define sipName_QTextList &sipStrings_QtGui[44395]
#define sipNameNr_QVector2D 44405
#define sipName_QVector2D &sipStrings_QtGui[44405]
#define sipNameNr_QVector3D 44415
#define sipName_QVector3D &sipStrings_QtGui[44415]
#define sipNameNr_QVector4D 44425
#define sipName_QVector4D &sipStrings_QtGui[44425]
#define sipNameNr_QuickDraw 44435
#define sipName_QuickDraw &sipStrings_QtGui[44435]
#define sipNameNr_Rectangle 8646
#define sipName_Rectangle &sipStrings_QtGui[8646]
#define sipNameNr_RedoStack 44445
#define sipName_RedoStack &sipStrings_QtGui[44445]
#define sipNameNr_RichMetal 44455
#define sipName_RichMetal &sipStrings_QtGui[44455]
#define sipNameNr_RiverCity 44465
#define sipName_RiverCity &sipStrings_QtGui[44465]
#define sipNameNr_SansSerif 44475
#define sipName_SansSerif &sipStrings_QtGui[44475]
#define sipNameNr_SeaStrike 44485
#define sipName_SeaStrike &sipStrings_QtGui[44485]
#define sipNameNr_SelectAll 28544
#define sipName_SelectAll &sipStrings_QtGui[28544]
#define sipNameNr_Selection 374
#define sipName_Selection &sipStrings_QtGui[374]
#define sipNameNr_SkipWords 44495
#define sipName_SkipWords &sipStrings_QtGui[44495]
#define sipNameNr_SkyGlider 44505
#define sipName_SkyGlider &sipStrings_QtGui[44505]
#define sipNameNr_SmallCaps 44515
#define sipName_SmallCaps &sipStrings_QtGui[44515]
#define sipNameNr_SnowAgain 44525
#define sipName_SnowAgain &sipStrings_QtGui[44525]
#define sipNameNr_SoftGrass 44535
#define sipName_SoftGrass &sipStrings_QtGui[44535]
#define sipNameNr_SpikyNaga 44545
#define sipName_SpikyNaga &sipStrings_QtGui[44545]
#define sipNameNr_Statement 44555
#define sipName_Statement &sipStrings_QtGui[44555]
#define sipNameNr_StrikeOut 21237
#define sipName_StrikeOut &sipStrings_QtGui[21237]
#define sipNameNr_StyleHint 20047
#define sipName_StyleHint &sipStrings_QtGui[20047]
#define sipNameNr_SunVeggie 44565
#define sipName_SunVeggie &sipStrings_QtGui[44565]
#define sipNameNr_SyncError 44575
#define sipName_SyncError &sipStrings_QtGui[44575]
#define sipNameNr_TeenParty 44585
#define sipName_TeenParty &sipStrings_QtGui[44585]
#define sipNameNr_ThemeIcon 20064
#define sipName_ThemeIcon &sipStrings_QtGui[20064]
#define sipNameNr_TitleFont 44595
#define sipName_TitleFont &sipStrings_QtGui[44595]
#define sipNameNr_TxProject 44605
#define sipName_TxProject &sipStrings_QtGui[44605]
#define sipNameNr_Unchecked 44615
#define sipName_Unchecked &sipStrings_QtGui[44615]
#define sipNameNr_Undefined 44625
#define sipName_Undefined &sipStrings_QtGui[44625]
#define sipNameNr_Underline 12301
#define sipName_Underline &sipStrings_QtGui[12301]
#define sipNameNr_UndoStack 41074
#define sipName_UndoStack &sipStrings_QtGui[41074]
#define sipNameNr_UsesAlpha 44635
#define sipName_UsesAlpha &sipStrings_QtGui[44635]
#define sipNameNr_WarmFlame 44645
#define sipName_WarmFlame &sipStrings_QtGui[44645]
#define sipNameNr_WhatsThis 35713
#define sipName_WhatsThis &sipStrings_QtGui[35713]
#define sipNameNr_WildApple 44655
#define sipName_WildApple &sipStrings_QtGui[44655]
#define sipNameNr_WindowNew 44665
#define sipName_WindowNew &sipStrings_QtGui[44665]
#define sipNameNr_WordRight 44675
#define sipName_WordRight &sipStrings_QtGui[44675]
#define sipNameNr_YUVLayout 7166
#define sipName_YUVLayout &sipStrings_QtGui[7166]
#define sipNameNr_ZPosition 44685
#define sipName_ZPosition &sipStrings_QtGui[44685]
#define sipNameNr___enter__ 44695
#define sipName___enter__ &sipStrings_QtGui[44695]
#define sipNameNr_activated 44705
#define sipName_activated &sipStrings_QtGui[44705]
#define sipNameNr_addAction 44715
#define sipName_addAction &sipStrings_QtGui[44715]
#define sipNameNr_addPixmap 44725
#define sipName_addPixmap &sipStrings_QtGui[44725]
#define sipNameNr_addRegion 44735
#define sipName_addRegion &sipStrings_QtGui[44735]
#define sipNameNr_aliceblue 44745
#define sipName_aliceblue &sipStrings_QtGui[44745]
#define sipNameNr_alignment 44755
#define sipName_alignment &sipStrings_QtGui[44755]
#define sipNameNr_alphaSize 44765
#define sipName_alphaSize &sipStrings_QtGui[44765]
#define sipNameNr_ambiguous 44775
#define sipName_ambiguous &sipStrings_QtGui[44775]
#define sipNameNr_appendRow 44785
#define sipName_appendRow &sipStrings_QtGui[44785]
#define sipNameNr_arcMoveTo 44795
#define sipName_arcMoveTo &sipStrings_QtGui[44795]
#define sipNameNr_blackSize 44805
#define sipName_blackSize &sipStrings_QtGui[44805]
#define sipNameNr_blockList 44815
#define sipName_blockList &sipStrings_QtGui[44815]
#define sipNameNr_burlywood 44825
#define sipName_burlywood &sipStrings_QtGui[44825]
#define sipNameNr_byteOrder 44835
#define sipName_byteOrder &sipStrings_QtGui[44835]
#define sipNameNr_cacheMode 44845
#define sipName_cacheMode &sipStrings_QtGui[44845]
#define sipNameNr_cadetblue 44855
#define sipName_cadetblue &sipStrings_QtGui[44855]
#define sipNameNr_capHeight 44865
#define sipName_capHeight &sipStrings_QtGui[44865]
#define sipNameNr_chocolate 44875
#define sipName_chocolate &sipStrings_QtGui[44875]
#define sipNameNr_clearData 44885
#define sipName_clearData &sipStrings_QtGui[44885]
#define sipNameNr_clipTight 44895
#define sipName_clipTight &sipStrings_QtGui[44895]
#define sipNameNr_clipboard 44905
#define sipName_clipboard &sipStrings_QtGui[44905]
#define sipNameNr_component 44915
#define sipName_component &sipStrings_QtGui[44915]
#define sipNameNr_constBits 44925
#define sipName_constBits &sipStrings_QtGui[44925]
#define sipNameNr_convertTo 44935
#define sipName_convertTo &sipStrings_QtGui[44935]
#define sipNameNr_cursorToX 44945
#define sipName_cursorToX &sipStrings_QtGui[44945]
#define sipNameNr_darkgreen 44955
#define sipName_darkgreen &sipStrings_QtGui[44955]
#define sipNameNr_darkkhaki 44965
#define sipName_darkkhaki &sipStrings_QtGui[44965]
#define sipNameNr_delimiter 44975
#define sipName_delimiter &sipStrings_QtGui[44975]
#define sipNameNr_drawChord 44985
#define sipName_drawChord &sipStrings_QtGui[44985]
#define sipNameNr_drawImage 44995
#define sipName_drawImage &sipStrings_QtGui[44995]
#define sipNameNr_drawLines 45005
#define sipName_drawLines &sipStrings_QtGui[45005]
#define sipNameNr_drawPoint 45015
#define sipName_drawPoint &sipStrings_QtGui[45015]
#define sipNameNr_drawRects 45025
#define sipName_drawRects &sipStrings_QtGui[45025]
#define sipNameNr_elementAt 45035
#define sipName_elementAt &sipStrings_QtGui[45035]
#define sipNameNr_endLayout 45045
#define sipName_endLayout &sipStrings_QtGui[45045]
#define sipNameNr_eraseRect 45055
#define sipName_eraseRect &sipStrings_QtGui[45055]
#define sipNameNr_fetchMore 45065
#define sipName_fetchMore &sipStrings_QtGui[45065]
#define sipNameNr_finalStop 45075
#define sipName_finalStop &sipStrings_QtGui[45075]
#define sipNameNr_findBlock 45085
#define sipName_findBlock &sipStrings_QtGui[45085]
#define sipNameNr_findItems 45095
#define sipName_findItems &sipStrings_QtGui[45095]
#define sipNameNr_firebrick 45105
#define sipName_firebrick &sipStrings_QtGui[45105]
#define sipNameNr_firstPage 45115
#define sipName_firstPage &sipStrings_QtGui[45115]
#define sipNameNr_fontTable 45125
#define sipName_fontTable &sipStrings_QtGui[45125]
#define sipNameNr_frameRect 45135
#define sipName_frameRect &sipStrings_QtGui[45135]
#define sipNameNr_fromCmykF 45145
#define sipName_fromCmykF &sipStrings_QtGui[45145]
#define sipNameNr_fromImage 45155
#define sipName_fromImage &sipStrings_QtGui[45155]
#define sipNameNr_fromScale 45165
#define sipName_fromScale &sipStrings_QtGui[45165]
#define sipNameNr_fromTheme 45175
#define sipName_fromTheme &sipStrings_QtGui[45175]
#define sipNameNr_fromValue 45185
#define sipName_fromValue &sipStrings_QtGui[45185]
#define sipNameNr_fromWinId 45195
#define sipName_fromWinId &sipStrings_QtGui[45195]
#define sipNameNr_gainsboro 45205
#define sipName_gainsboro &sipStrings_QtGui[45205]
#define sipNameNr_globalPos 45215
#define sipName_globalPos &sipStrings_QtGui[45215]
#define sipNameNr_glyphName 45225
#define sipName_glyphName &sipStrings_QtGui[45225]
#define sipNameNr_glyphRuns 45235
#define sipName_glyphRuns &sipStrings_QtGui[45235]
#define sipNameNr_goldenrod 29916
#define sipName_goldenrod &sipStrings_QtGui[29916]
#define sipNameNr_greenSize 45245
#define sipName_greenSize &sipStrings_QtGui[45245]
#define sipNameNr_hideEvent 45255
#define sipName_hideEvent &sipStrings_QtGui[45255]
#define sipNameNr_highlight 38877
#define sipName_highlight &sipStrings_QtGui[38877]
#define sipNameNr_indianred 45265
#define sipName_indianred &sipStrings_QtGui[45265]
#define sipNameNr_insertRow 45275
#define sipName_insertRow &sipStrings_QtGui[45275]
#define sipNameNr_isChecked 45285
#define sipName_isChecked &sipStrings_QtGui[45285]
#define sipNameNr_isCurveTo 45295
#define sipName_isCurveTo &sipStrings_QtGui[45295]
#define sipNameNr_isEnabled 45305
#define sipName_isEnabled &sipStrings_QtGui[45305]
#define sipNameNr_isExposed 45315
#define sipName_isExposed &sipStrings_QtGui[45315]
#define sipNameNr_isQBitmap 45325
#define sipName_isQBitmap &sipStrings_QtGui[45325]
#define sipNameNr_isScaling 45335
#define sipName_isScaling &sipStrings_QtGui[45335]
#define sipNameNr_isVisible 45345
#define sipName_isVisible &sipStrings_QtGui[45345]
#define sipNameNr_joinStyle 45355
#define sipName_joinStyle &sipStrings_QtGui[45355]
#define sipNameNr_lastBlock 45365
#define sipName_lastBlock &sipStrings_QtGui[45365]
#define sipNameNr_lastError 45375
#define sipName_lastError &sipStrings_QtGui[45375]
#define sipNameNr_lawngreen 45385
#define sipName_lawngreen &sipStrings_QtGui[45385]
#define sipNameNr_lightblue 45395
#define sipName_lightblue &sipStrings_QtGui[45395]
#define sipNameNr_lightcyan 45405
#define sipName_lightcyan &sipStrings_QtGui[45405]
#define sipNameNr_lightgray 45415
#define sipName_lightgray &sipStrings_QtGui[45415]
#define sipNameNr_lightgrey 45425
#define sipName_lightgrey &sipStrings_QtGui[45425]
#define sipNameNr_lightness 45435
#define sipName_lightness &sipStrings_QtGui[45435]
#define sipNameNr_lightpink 45445
#define sipName_lightpink &sipStrings_QtGui[45445]
#define sipNameNr_limegreen 45455
#define sipName_limegreen &sipStrings_QtGui[45455]
#define sipNameNr_lineCount 45465
#define sipName_lineCount &sipStrings_QtGui[45465]
#define sipNameNr_lineWidth 45475
#define sipName_lineWidth &sipStrings_QtGui[45475]
#define sipNameNr_loopCount 45485
#define sipName_loopCount &sipStrings_QtGui[45485]
#define sipNameNr_lostFocus 45495
#define sipName_lostFocus &sipStrings_QtGui[45495]
#define sipNameNr_mapVector 45505
#define sipName_mapVector &sipStrings_QtGui[45505]
#define sipNameNr_mergeWith 45515
#define sipName_mergeWith &sipStrings_QtGui[45515]
#define sipNameNr_mimeTypes 45525
#define sipName_mimeTypes &sipStrings_QtGui[45525]
#define sipNameNr_mintcream 45535
#define sipName_mintcream &sipStrings_QtGui[45535]
#define sipNameNr_mistyrose 45545
#define sipName_mistyrose &sipStrings_QtGui[45545]
#define sipNameNr_modifiers 45555
#define sipName_modifiers &sipStrings_QtGui[45555]
#define sipNameNr_moveEvent 45565
#define sipName_moveEvent &sipStrings_QtGui[45565]
#define sipNameNr_multiData 45575
#define sipName_multiData &sipStrings_QtGui[45575]
#define sipNameNr_nearPlane 45585
#define sipName_nearPlane &sipStrings_QtGui[45585]
#define sipNameNr_normalize 45595
#define sipName_normalize &sipStrings_QtGui[45595]
#define sipNameNr_numericId 45605
#define sipName_numericId &sipStrings_QtGui[45605]
#define sipNameNr_olivedrab 45615
#define sipName_olivedrab &sipStrings_QtGui[45615]
#define sipNameNr_operation 45625
#define sipName_operation &sipStrings_QtGui[45625]
#define sipNameNr_orangered 45635
#define sipName_orangered &sipStrings_QtGui[45635]
#define sipNameNr_pageCount 45645
#define sipName_pageCount &sipStrings_QtGui[45645]
#define sipNameNr_paintRect 45655
#define sipName_paintRect &sipStrings_QtGui[45655]
#define sipNameNr_palegreen 45665
#define sipName_palegreen &sipStrings_QtGui[45665]
#define sipNameNr_peachpuff 45675
#define sipName_peachpuff &sipStrings_QtGui[45675]
#define sipNameNr_pixelSize 45685
#define sipName_pixelSize &sipStrings_QtGui[45685]
#define sipNameNr_pointById 45695
#define sipName_pointById &sipStrings_QtGui[45695]
#define sipNameNr_pointSize 45705
#define sipName_pointSize &sipStrings_QtGui[45705]
#define sipNameNr_positions 45715
#define sipName_positions &sipStrings_QtGui[45715]
#define sipNameNr_primaries 45725
#define sipName_primaries &sipStrings_QtGui[45725]
#define sipNameNr_putPoints 45735
#define sipName_putPoints &sipStrings_QtGui[45735]
#define sipNameNr_rectCount 45745
#define sipName_rectCount &sipStrings_QtGui[45745]
#define sipNameNr_removeRow 45755
#define sipName_removeRow &sipStrings_QtGui[45755]
#define sipNameNr_roleNames 45765
#define sipName_roleNames &sipStrings_QtGui[45765]
#define sipNameNr_rootFrame 45775
#define sipName_rootFrame &sipStrings_QtGui[45775]
#define sipNameNr_rosybrown 45785
#define sipName_rosybrown &sipStrings_QtGui[45785]
#define sipNameNr_royalblue 45795
#define sipName_royalblue &sipStrings_QtGui[45795]
#define sipNameNr_seatNames 45805
#define sipName_seatNames &sipStrings_QtGui[45805]
#define sipNameNr_selection 45815
#define sipName_selection &sipStrings_QtGui[45815]
#define sipNameNr_sessionId 45825
#define sipName_sessionId &sipStrings_QtGui[45825]
#define sipNameNr_setActive 45835
#define sipName_setActive &sipStrings_QtGui[45835]
#define sipNameNr_setAlphaF 45845
#define sipName_setAlphaF &sipStrings_QtGui[45845]
#define sipNameNr_setAnchor 45855
#define sipName_setAnchor &sipStrings_QtGui[45855]
#define sipNameNr_setAscent 45865
#define sipName_setAscent &sipStrings_QtGui[45865]
#define sipNameNr_setAuthor 45875
#define sipName_setAuthor &sipStrings_QtGui[45875]
#define sipNameNr_setBorder 45885
#define sipName_setBorder &sipStrings_QtGui[45885]
#define sipNameNr_setBottom 45895
#define sipName_setBottom &sipStrings_QtGui[45895]
#define sipNameNr_setCenter 45905
#define sipName_setCenter &sipStrings_QtGui[45905]
#define sipNameNr_setColumn 45915
#define sipName_setColumn &sipStrings_QtGui[45915]
#define sipNameNr_setCursor 39693
#define sipName_setCursor &sipStrings_QtGui[39693]
#define sipNameNr_setDevice 45925
#define sipName_setDevice &sipStrings_QtGui[45925]
#define sipNameNr_setFamily 45935
#define sipName_setFamily &sipStrings_QtGui[45935]
#define sipNameNr_setFilter 45945
#define sipName_setFilter &sipStrings_QtGui[45945]
#define sipNameNr_setFormat 45955
#define sipName_setFormat &sipStrings_QtGui[45955]
#define sipNameNr_setGreenF 45965
#define sipName_setGreenF &sipStrings_QtGui[45965]
#define sipNameNr_setHeight 45975
#define sipName_setHeight &sipStrings_QtGui[45975]
#define sipNameNr_setIndent 45985
#define sipName_setIndent &sipStrings_QtGui[45985]
#define sipNameNr_setIsMask 45995
#define sipName_setIsMask &sipStrings_QtGui[45995]
#define sipNameNr_setItalic 46005
#define sipName_setItalic &sipStrings_QtGui[46005]
#define sipNameNr_setLocale 46015
#define sipName_setLocale &sipStrings_QtGui[46015]
#define sipNameNr_setMargin 46025
#define sipName_setMargin &sipStrings_QtGui[46025]
#define sipNameNr_setMarker 46035
#define sipName_setMarker &sipStrings_QtGui[46035]
#define sipNameNr_setMatrix 46045
#define sipName_setMatrix &sipStrings_QtGui[46045]
#define sipNameNr_setOffset 46055
#define sipName_setOffset &sipStrings_QtGui[46055]
#define sipNameNr_setOption 46065
#define sipName_setOption &sipStrings_QtGui[46065]
#define sipNameNr_setParent 46075
#define sipName_setParent &sipStrings_QtGui[46075]
#define sipNameNr_setPaused 46085
#define sipName_setPaused &sipStrings_QtGui[46085]
#define sipNameNr_setPixmap 46095
#define sipName_setPixmap &sipStrings_QtGui[46095]
#define sipNameNr_setPoints 46105
#define sipName_setPoints &sipStrings_QtGui[46105]
#define sipNameNr_setRadius 46115
#define sipName_setRadius &sipStrings_QtGui[46115]
#define sipNameNr_setRgba64 46125
#define sipName_setRgba64 &sipStrings_QtGui[46125]
#define sipNameNr_setScalar 46135
#define sipName_setScalar &sipStrings_QtGui[46135]
#define sipNameNr_setScreen 46145
#define sipName_setScreen &sipStrings_QtGui[46145]
#define sipNameNr_setSpread 46155
#define sipName_setSpread &sipStrings_QtGui[46155]
#define sipNameNr_setStereo 46165
#define sipName_setStereo &sipStrings_QtGui[46165]
#define sipNameNr_setVector 46175
#define sipName_setVector &sipStrings_QtGui[46175]
#define sipNameNr_setWeight 46185
#define sipName_setWeight &sipStrings_QtGui[46185]
#define sipNameNr_setWidthF 46195
#define sipName_setWidthF &sipStrings_QtGui[46195]
#define sipNameNr_setWindow 46205
#define sipName_setWindow &sipStrings_QtGui[46205]
#define sipNameNr_shortcuts 46215
#define sipName_shortcuts &sipStrings_QtGui[46215]
#define sipNameNr_showEvent 46225
#define sipName_showEvent &sipStrings_QtGui[46225]
#define sipNameNr_slateblue 23916
#define sipName_slateblue &sipStrings_QtGui[23916]
#define sipNameNr_slategray 27085
#define sipName_slategray &sipStrings_QtGui[27085]
#define sipNameNr_slategrey 27100
#define sipName_slategrey &sipStrings_QtGui[27100]
#define sipNameNr_sourceTop 46235
#define sipName_sourceTop &sipStrings_QtGui[46235]
#define sipNameNr_splitCell 46245
#define sipName_splitCell &sipStrings_QtGui[46245]
#define sipNameNr_statusTip 46255
#define sipName_statusTip &sipStrings_QtGui[46255]
#define sipNameNr_steelblue 27115
#define sipName_steelblue &sipStrings_QtGui[27115]
#define sipNameNr_strikeOut 46265
#define sipName_strikeOut &sipStrings_QtGui[46265]
#define sipNameNr_styleHint 46275
#define sipName_styleHint &sipStrings_QtGui[46275]
#define sipNameNr_styleName 46285
#define sipName_styleName &sipStrings_QtGui[46285]
#define sipNameNr_takeChild 46295
#define sipName_takeChild &sipStrings_QtGui[46295]
#define sipNameNr_textStart 46305
#define sipName_textStart &sipStrings_QtGui[46305]
#define sipNameNr_textWidth 46315
#define sipName_textWidth &sipStrings_QtGui[46315]
#define sipNameNr_themeName 46325
#define sipName_themeName &sipStrings_QtGui[46325]
#define sipNameNr_timestamp 46335
#define sipName_timestamp &sipStrings_QtGui[46335]
#define sipNameNr_toPolygon 46345
#define sipName_toPolygon &sipStrings_QtGui[46345]
#define sipNameNr_toRawText 46355
#define sipName_toRawText &sipStrings_QtGui[46355]
#define sipNameNr_topBorder 46365
#define sipName_topBorder &sipStrings_QtGui[46365]
#define sipNameNr_topMargin 46375
#define sipName_topMargin &sipStrings_QtGui[46375]
#define sipNameNr_transform 46385
#define sipName_transform &sipStrings_QtGui[46385]
#define sipNameNr_translate 46395
#define sipName_translate &sipStrings_QtGui[46395]
#define sipNameNr_triggered 46405
#define sipName_triggered &sipStrings_QtGui[46405]
#define sipNameNr_turquoise 23932
#define sipName_turquoise &sipStrings_QtGui[23932]
#define sipNameNr_underline 46415
#define sipName_underline &sipStrings_QtGui[46415]
#define sipNameNr_undoLimit 46425
#define sipName_undoLimit &sipStrings_QtGui[46425]
#define sipNameNr_unproject 46435
#define sipName_unproject &sipStrings_QtGui[46435]
#define sipNameNr_userState 46445
#define sipName_userState &sipStrings_QtGui[46445]
#define sipNameNr_whatsThis 46455
#define sipName_whatsThis &sipStrings_QtGui[46455]
#define sipNameNr_windowsId 46465
#define sipName_windowsId &sipStrings_QtGui[46465]
#define sipNameNr_xToCursor 46475
#define sipName_xToCursor &sipStrings_QtGui[46475]
#define sipNameNr_yuvLayout 46485
#define sipName_yuvLayout &sipStrings_QtGui[46485]
#define sipNameNr_AdobeRgb 46495
#define sipName_AdobeRgb &sipStrings_QtGui[46495]
#define sipNameNr_Airbrush 46504
#define sipName_Airbrush &sipStrings_QtGui[46504]
#define sipNameNr_AlignTop 46513
#define sipName_AlignTop &sipStrings_QtGui[46513]
#define sipNameNr_AllDirty 46522
#define sipName_AllDirty &sipStrings_QtGui[46522]
#define sipNameNr_AmyCrisp 46531
#define sipName_AmyCrisp &sipStrings_QtGui[46531]
#define sipNameNr_AnyStyle 46540
#define sipName_AnyStyle &sipStrings_QtGui[46540]
#define sipNameNr_Armenian 46549
#define sipName_Armenian &sipStrings_QtGui[46549]
#define sipNameNr_BigMango 46558
#define sipName_BigMango &sipStrings_QtGui[46558]
#define sipNameNr_BlackSea 46567
#define sipName_BlackSea &sipStrings_QtGui[46567]
#define sipNameNr_Blessing 46576
#define sipName_Blessing &sipStrings_QtGui[46576]
#define sipNameNr_Bt2100Pq 46585
#define sipName_Bt2100Pq &sipStrings_QtGui[46585]
#define sipNameNr_CacheAll 46594
#define sipName_CacheAll &sipStrings_QtGui[46594]
#define sipNameNr_CallStop 46603
#define sipName_CallStop &sipStrings_QtGui[46603]
#define sipNameNr_ClipRect 18933
#define sipName_ClipRect &sipStrings_QtGui[18933]
#define sipNameNr_Computer 42692
#define sipName_Computer &sipStrings_QtGui[42692]
#define sipNameNr_CssFloat 46612
#define sipName_CssFloat &sipStrings_QtGui[46612]
#define sipNameNr_CssMedia 46621
#define sipName_CssMedia &sipStrings_QtGui[46621]
#define sipNameNr_Cyrillic 46630
#define sipName_Cyrillic &sipStrings_QtGui[46630]
#define sipNameNr_DarkBlue 46639
#define sipName_DarkBlue &sipStrings_QtGui[46639]
#define sipNameNr_DarkCyan 46648
#define sipName_DarkCyan &sipStrings_QtGui[46648]
#define sipNameNr_DarkGray 46657
#define sipName_DarkGray &sipStrings_QtGui[46657]
#define sipNameNr_DciP3D65 46666
#define sipName_DciP3D65 &sipStrings_QtGui[46666]
#define sipNameNr_DeepBlue 46675
#define sipName_DeepBlue &sipStrings_QtGui[46675]
#define sipNameNr_DemiBold 46684
#define sipName_DemiBold &sipStrings_QtGui[46684]
#define sipNameNr_Deselect 46693
#define sipName_Deselect &sipStrings_QtGui[46693]
#define sipNameNr_Direct2D 46702
#define sipName_Direct2D &sipStrings_QtGui[46702]
#define sipNameNr_Direct3D 46711
#define sipName_Direct3D &sipStrings_QtGui[46711]
#define sipNameNr_DirtyPen 46720
#define sipName_DirtyPen &sipStrings_QtGui[46720]
#define sipNameNr_Disabled 39118
#define sipName_Disabled &sipStrings_QtGui[39118]
#define sipNameNr_Document 9214
#define sipName_Document &sipStrings_QtGui[9214]
#define sipNameNr_EditCopy 46729
#define sipName_EditCopy &sipStrings_QtGui[46729]
#define sipNameNr_EditFind 46738
#define sipName_EditFind &sipStrings_QtGui[46738]
#define sipNameNr_EditRedo 46747
#define sipName_EditRedo &sipStrings_QtGui[46747]
#define sipNameNr_EditUndo 46756
#define sipName_EditUndo &sipStrings_QtGui[46756]
#define sipNameNr_Expanded 28629
#define sipName_Expanded &sipStrings_QtGui[28629]
#define sipNameNr_FindFlag 7239
#define sipName_FindFlag &sipStrings_QtGui[7239]
#define sipNameNr_FindNext 46765
#define sipName_FindNext &sipStrings_QtGui[46765]
#define sipNameNr_Georgian 46774
#define sipName_Georgian &sipStrings_QtGui[46774]
#define sipNameNr_Gujarati 46783
#define sipName_Gujarati &sipStrings_QtGui[46783]
#define sipNameNr_Gurmukhi 46792
#define sipName_Gurmukhi &sipStrings_QtGui[46792]
#define sipNameNr_IconType 674
#define sipName_IconType &sipStrings_QtGui[674]
#define sipNameNr_Inactive 46801
#define sipName_Inactive &sipStrings_QtGui[46801]
#define sipNameNr_IsAnchor 46810
#define sipName_IsAnchor &sipStrings_QtGui[46810]
#define sipNameNr_ItemType 7215
#define sipName_ItemType &sipStrings_QtGui[7215]
#define sipNameNr_Japanese 46819
#define sipName_Japanese &sipStrings_QtGui[46819]
#define sipNameNr_Keyboard 24285
#define sipName_Keyboard &sipStrings_QtGui[24285]
#define sipNameNr_LadyLips 46828
#define sipName_LadyLips &sipStrings_QtGui[46828]
#define sipNameNr_Language 16431
#define sipName_Language &sipStrings_QtGui[16431]
#define sipNameNr_ListDisc 46837
#define sipName_ListDisc &sipStrings_QtGui[46837]
#define sipNameNr_LoveKiss 46846
#define sipName_LoveKiss &sipStrings_QtGui[46846]
#define sipNameNr_MagicRay 46855
#define sipName_MagicRay &sipStrings_QtGui[46855]
#define sipNameNr_MailRead 46864
#define sipName_MailRead &sipStrings_QtGui[46864]
#define sipNameNr_MailSend 46873
#define sipName_MailSend &sipStrings_QtGui[46873]
#define sipNameNr_MenuRole 17043
#define sipName_MenuRole &sipStrings_QtGui[17043]
#define sipNameNr_Midlight 46882
#define sipName_Midlight &sipStrings_QtGui[46882]
#define sipNameNr_MimeData 23149
#define sipName_MimeData &sipStrings_QtGui[23149]
#define sipNameNr_MoleHall 46891
#define sipName_MoleHall &sipStrings_QtGui[46891]
#define sipNameNr_MoveMode 9456
#define sipName_MoveMode &sipStrings_QtGui[9456]
#define sipNameNr_NearMoon 46900
#define sipName_NearMoon &sipStrings_QtGui[46900]
#define sipNameNr_NextCell 46909
#define sipName_NextCell &sipStrings_QtGui[46909]
#define sipNameNr_NextWord 25811
#define sipName_NextWord &sipStrings_QtGui[25811]
#define sipNameNr_NightSky 46918
#define sipName_NightSky &sipStrings_QtGui[46918]
#define sipNameNr_NoMarker 46927
#define sipName_NoMarker &sipStrings_QtGui[46927]
#define sipNameNr_NoObject 46936
#define sipName_NoObject &sipStrings_QtGui[46936]
#define sipNameNr_Notation 4716
#define sipName_Notation &sipStrings_QtGui[4716]
#define sipNameNr_OpenGLES 42483
#define sipName_OpenGLES &sipStrings_QtGui[42483]
#define sipNameNr_Overline 24621
#define sipName_Overline &sipStrings_QtGui[24621]
#define sipNameNr_PaloAlto 46945
#define sipName_PaloAlto &sipStrings_QtGui[46945]
#define sipNameNr_PdmDepth 46954
#define sipName_PdmDepth &sipStrings_QtGui[46954]
#define sipNameNr_PdmWidth 46963
#define sipName_PdmWidth &sipStrings_QtGui[46963]
#define sipNameNr_PlumBath 46972
#define sipName_PlumBath &sipStrings_QtGui[46972]
#define sipNameNr_Portrait 42494
#define sipName_Portrait &sipStrings_QtGui[42494]
#define sipNameNr_Position 4386
#define sipName_Position &sipStrings_QtGui[4386]
#define sipNameNr_Postcard 25436
#define sipName_Postcard &sipStrings_QtGui[25436]
#define sipNameNr_Pressure 14783
#define sipName_Pressure &sipStrings_QtGui[14783]
#define sipNameNr_Priority 17061
#define sipName_Priority &sipStrings_QtGui[17061]
#define sipNameNr_Property 9522
#define sipName_Property &sipStrings_QtGui[9522]
#define sipNameNr_QPainter 46981
#define sipName_QPainter &sipStrings_QtGui[46981]
#define sipNameNr_QPalette 46990
#define sipName_QPalette &sipStrings_QtGui[46990]
#define sipNameNr_QPicture 46999
#define sipName_QPicture &sipStrings_QtGui[46999]
#define sipNameNr_QPolygon 47008
#define sipName_QPolygon &sipStrings_QtGui[47008]
#define sipNameNr_QRawFont 47017
#define sipName_QRawFont &sipStrings_QtGui[47017]
#define sipNameNr_QSurface 47026
#define sipName_QSurface &sipStrings_QtGui[47026]
#define sipNameNr_QuitRole 47035
#define sipName_QuitRole &sipStrings_QtGui[47035]
#define sipNameNr_RareWind 47044
#define sipName_RareWind &sipStrings_QtGui[47044]
#define sipNameNr_Released 47053
#define sipName_Released &sipStrings_QtGui[47053]
#define sipNameNr_RightTab 47062
#define sipName_RightTab &sipStrings_QtGui[47062]
#define sipNameNr_Rotation 47071
#define sipName_Rotation &sipStrings_QtGui[47071]
#define sipNameNr_Seashore 47080
#define sipName_Seashore &sipStrings_QtGui[47080]
#define sipNameNr_Selected 47089
#define sipName_Selected &sipStrings_QtGui[47089]
#define sipNameNr_StarWine 47098
#define sipName_StarWine &sipStrings_QtGui[47098]
#define sipNameNr_TouchPad 47107
#define sipName_TouchPad &sipStrings_QtGui[47107]
#define sipNameNr_Trailing 47116
#define sipName_Trailing &sipStrings_QtGui[47116]
#define sipNameNr_Trashcan 47125
#define sipName_Trashcan &sipStrings_QtGui[47125]
#define sipNameNr_TxRotate 47134
#define sipName_TxRotate &sipStrings_QtGui[47134]
#define sipNameNr_UserType 47143
#define sipName_UserType &sipStrings_QtGui[47143]
#define sipNameNr_Velocity 19095
#define sipName_Velocity &sipStrings_QtGui[19095]
#define sipNameNr_Windowed 47152
#define sipName_Windowed &sipStrings_QtGui[47152]
#define sipNameNr_WordLeft 47161
#define sipName_WordLeft &sipStrings_QtGui[47161]
#define sipNameNr_WordWrap 47170
#define sipName_WordWrap &sipStrings_QtGui[47170]
#define sipNameNr_WrapMode 9566
#define sipName_WrapMode &sipStrings_QtGui[9566]
#define sipNameNr_YUV420SP 47179
#define sipName_YUV420SP &sipStrings_QtGui[47179]
#define sipNameNr___bool__ 47188
#define sipName___bool__ &sipStrings_QtGui[47188]
#define sipNameNr___exit__ 47197
#define sipName___exit__ &sipStrings_QtGui[47197]
#define sipNameNr___hash__ 47206
#define sipName___hash__ &sipStrings_QtGui[47206]
#define sipNameNr___iadd__ 47215
#define sipName___iadd__ &sipStrings_QtGui[47215]
#define sipNameNr___iand__ 47224
#define sipName___iand__ &sipStrings_QtGui[47224]
#define sipNameNr___imul__ 47233
#define sipName___imul__ &sipStrings_QtGui[47233]
#define sipNameNr___isub__ 47242
#define sipName___isub__ &sipStrings_QtGui[47242]
#define sipNameNr___ixor__ 47251
#define sipName___ixor__ &sipStrings_QtGui[47251]
#define sipNameNr___repr__ 47260
#define sipName___repr__ &sipStrings_QtGui[47260]
#define sipNameNr_accepted 47269
#define sipName_accepted &sipStrings_QtGui[47269]
#define sipNameNr_activate 47278
#define sipName_activate &sipStrings_QtGui[47278]
#define sipNameNr_addRange 47287
#define sipName_addRange &sipStrings_QtGui[47287]
#define sipNameNr_addStack 47296
#define sipName_addStack &sipStrings_QtGui[47296]
#define sipNameNr_anchorAt 47305
#define sipName_anchorAt &sipStrings_QtGui[47305]
#define sipNameNr_baseSize 47314
#define sipName_baseSize &sipStrings_QtGui[47314]
#define sipNameNr_behavior 47323
#define sipName_behavior &sipStrings_QtGui[47323]
#define sipNameNr_blueSize 47332
#define sipName_blueSize &sipStrings_QtGui[47332]
#define sipNameNr_cacheKey 47341
#define sipName_cacheKey &sipStrings_QtGui[47341]
#define sipNameNr_canWrite 7791
#define sipName_canWrite &sipStrings_QtGui[7791]
#define sipNameNr_capStyle 47350
#define sipName_capStyle &sipStrings_QtGui[47350]
#define sipNameNr_capacity 47359
#define sipName_capacity &sipStrings_QtGui[47359]
#define sipNameNr_clipPath 47368
#define sipName_clipPath &sipStrings_QtGui[47368]
#define sipNameNr_clipRect 47377
#define sipName_clipRect &sipStrings_QtGui[47377]
#define sipNameNr_contains 47386
#define sipName_contains &sipStrings_QtGui[47386]
#define sipNameNr_cornsilk 47395
#define sipName_cornsilk &sipStrings_QtGui[47395]
#define sipNameNr_cyanSize 47404
#define sipName_cyanSize &sipStrings_QtGui[47404]
#define sipNameNr_darkblue 47413
#define sipName_darkblue &sipStrings_QtGui[47413]
#define sipNameNr_darkcyan 47422
#define sipName_darkcyan &sipStrings_QtGui[47422]
#define sipNameNr_darkgray 47431
#define sipName_darkgray &sipStrings_QtGui[47431]
#define sipNameNr_darkgrey 47440
#define sipName_darkgrey &sipStrings_QtGui[47440]
#define sipNameNr_decimals 47449
#define sipName_decimals &sipStrings_QtGui[47449]
#define sipNameNr_deeppink 47458
#define sipName_deeppink &sipStrings_QtGui[47458]
#define sipNameNr_document 47467
#define sipName_document &sipStrings_QtGui[47467]
#define sipNameNr_drawLine 47476
#define sipName_drawLine &sipStrings_QtGui[47476]
#define sipNameNr_drawPath 47485
#define sipName_drawPath &sipStrings_QtGui[47485]
#define sipNameNr_drawRect 47494
#define sipName_drawRect &sipStrings_QtGui[47494]
#define sipNameNr_drawText 47503
#define sipName_drawText &sipStrings_QtGui[47503]
#define sipNameNr_endMacro 47512
#define sipName_endMacro &sipStrings_QtGui[47512]
#define sipNameNr_endPaint 47521
#define sipName_endPaint &sipStrings_QtGui[47521]
#define sipNameNr_families 47530
#define sipName_families &sipStrings_QtGui[47530]
#define sipNameNr_farPlane 47539
#define sipName_farPlane &sipStrings_QtGui[47539]
#define sipNameNr_features 47548
#define sipName_features &sipStrings_QtGui[47548]
#define sipNameNr_fileIcon 47557
#define sipName_fileIcon &sipStrings_QtGui[47557]
#define sipNameNr_fileInfo 47566
#define sipName_fileInfo &sipStrings_QtGui[47566]
#define sipNameNr_fileName 47575
#define sipName_fileName &sipStrings_QtGui[47575]
#define sipNameNr_filePath 47584
#define sipName_filePath &sipStrings_QtGui[47584]
#define sipNameNr_fillPath 47593
#define sipName_fillPath &sipStrings_QtGui[47593]
#define sipNameNr_fillRect 47602
#define sipName_fillRect &sipStrings_QtGui[47602]
#define sipNameNr_fillRule 47611
#define sipName_fillRule &sipStrings_QtGui[47611]
#define sipNameNr_finished 47620
#define sipName_finished &sipStrings_QtGui[47620]
#define sipNameNr_fontInfo 47629
#define sipName_fontInfo &sipStrings_QtGui[47629]
#define sipNameNr_formatAt 47638
#define sipName_formatAt &sipStrings_QtGui[47638]
#define sipNameNr_fragment 47647
#define sipName_fragment &sipStrings_QtGui[47647]
#define sipNameNr_fromAxes 47656
#define sipName_fromAxes &sipStrings_QtGui[47656]
#define sipNameNr_fromCmyk 47665
#define sipName_fromCmyk &sipStrings_QtGui[47665]
#define sipNameNr_fromData 47674
#define sipName_fromData &sipStrings_QtGui[47674]
#define sipNameNr_fromFont 47683
#define sipName_fromFont &sipStrings_QtGui[47683]
#define sipNameNr_fromHslF 47692
#define sipName_fromHslF &sipStrings_QtGui[47692]
#define sipNameNr_fromHsvF 47701
#define sipName_fromHsvF &sipStrings_QtGui[47701]
#define sipNameNr_fromHtml 47710
#define sipName_fromHtml &sipStrings_QtGui[47710]
#define sipNameNr_fromRgbF 47719
#define sipName_fromRgbF &sipStrings_QtGui[47719]
#define sipNameNr_fromRgba 47728
#define sipName_fromRgba &sipStrings_QtGui[47728]
#define sipNameNr_fullRect 47737
#define sipName_fullRect &sipStrings_QtGui[47737]
#define sipNameNr_geometry 47746
#define sipName_geometry &sipStrings_QtGui[47746]
#define sipNameNr_getCmykF 47755
#define sipName_getCmykF &sipStrings_QtGui[47755]
#define sipNameNr_gotFocus 47764
#define sipName_gotFocus &sipStrings_QtGui[47764]
#define sipNameNr_gradient 47773
#define sipName_gradient &sipStrings_QtGui[47773]
#define sipNameNr_hasAlpha 47782
#define sipName_hasAlpha &sipStrings_QtGui[47782]
#define sipNameNr_heightMM 47791
#define sipName_heightMM &sipStrings_QtGui[47791]
#define sipNameNr_honeydew 47800
#define sipName_honeydew &sipStrings_QtGui[47800]
#define sipNameNr_iconName 47809
#define sipName_iconName &sipStrings_QtGui[47809]
#define sipNameNr_iconText 47818
#define sipName_iconText &sipStrings_QtGui[47818]
#define sipNameNr_inverted 47827
#define sipName_inverted &sipStrings_QtGui[47827]
#define sipNameNr_isActive 47836
#define sipName_isActive &sipStrings_QtGui[47836]
#define sipNameNr_isAffine 47845
#define sipName_isAffine &sipStrings_QtGui[47845]
#define sipNameNr_isAnchor 47854
#define sipName_isAnchor &sipStrings_QtGui[47854]
#define sipNameNr_isClosed 47863
#define sipName_isClosed &sipStrings_QtGui[47863]
#define sipNameNr_isCopyOf 47872
#define sipName_isCopyOf &sipStrings_QtGui[47872]
#define sipNameNr_isLineTo 47881
#define sipName_isLineTo &sipStrings_QtGui[47881]
#define sipNameNr_isMoveTo 47890
#define sipName_isMoveTo &sipStrings_QtGui[47890]
#define sipNameNr_isOpaque 47899
#define sipName_isOpaque &sipStrings_QtGui[47899]
#define sipNameNr_isPhase2 47908
#define sipName_isPhase2 &sipStrings_QtGui[47908]
#define sipNameNr_itemData 47917
#define sipName_itemData &sipStrings_QtGui[47917]
#define sipNameNr_itemText 47926
#define sipName_itemText &sipStrings_QtGui[47926]
#define sipNameNr_iterator 10825
#define sipName_iterator &sipStrings_QtGui[10825]
#define sipNameNr_lastPage 47935
#define sipName_lastPage &sipStrings_QtGui[47935]
#define sipNameNr_lavender 47944
#define sipName_lavender &sipStrings_QtGui[47944]
#define sipNameNr_magentaF 47953
#define sipName_magentaF &sipStrings_QtGui[47953]
#define sipNameNr_maxWidth 47962
#define sipName_maxWidth &sipStrings_QtGui[47962]
#define sipNameNr_menuRole 47971
#define sipName_menuRole &sipStrings_QtGui[47971]
#define sipNameNr_midlight 47980
#define sipName_midlight &sipStrings_QtGui[47980]
#define sipNameNr_mimeData 47989
#define sipName_mimeData &sipStrings_QtGui[47989]
#define sipNameNr_mimeType 47998
#define sipName_mimeType &sipStrings_QtGui[47998]
#define sipNameNr_mirrored 48007
#define sipName_mirrored &sipStrings_QtGui[48007]
#define sipNameNr_mnemonic 3440
#define sipName_mnemonic &sipStrings_QtGui[3440]
#define sipNameNr_moccasin 48016
#define sipName_moccasin &sipStrings_QtGui[48016]
#define sipNameNr_modality 48025
#define sipName_modality &sipStrings_QtGui[48025]
#define sipNameNr_moveRows 42912
#define sipName_moveRows &sipStrings_QtGui[42912]
#define sipNameNr_notation 48034
#define sipName_notation &sipStrings_QtGui[48034]
#define sipNameNr_oldState 48043
#define sipName_oldState &sipStrings_QtGui[48043]
#define sipNameNr_openFile 48052
#define sipName_openFile &sipStrings_QtGui[48052]
#define sipNameNr_optimize 48061
#define sipName_optimize &sipStrings_QtGui[48061]
#define sipNameNr_overline 48070
#define sipName_overline &sipStrings_QtGui[48070]
#define sipNameNr_pageSize 48079
#define sipName_pageSize &sipStrings_QtGui[48079]
#define sipNameNr_position 48088
#define sipName_position &sipStrings_QtGui[48088]
#define sipNameNr_pressure 48097
#define sipName_pressure &sipStrings_QtGui[48097]
#define sipNameNr_previous 48106
#define sipName_previous &sipStrings_QtGui[48106]
#define sipNameNr_priority 48115
#define sipName_priority &sipStrings_QtGui[48115]
#define sipNameNr_property 48124
#define sipName_property &sipStrings_QtGui[48124]
#define sipNameNr_rawValue 48133
#define sipName_rawValue &sipStrings_QtGui[48133]
#define sipNameNr_redoText 48142
#define sipName_redoText &sipStrings_QtGui[48142]
#define sipNameNr_resource 48151
#define sipName_resource &sipStrings_QtGui[48151]
#define sipNameNr_revision 48160
#define sipName_revision &sipStrings_QtGui[48160]
#define sipNameNr_rootPath 48169
#define sipName_rootPath &sipStrings_QtGui[48169]
#define sipNameNr_rotation 48178
#define sipName_rotation &sipStrings_QtGui[48178]
#define sipNameNr_rowCount 48187
#define sipName_rowCount &sipStrings_QtGui[48187]
#define sipNameNr_rowStart 48196
#define sipName_rowStart &sipStrings_QtGui[48196]
#define sipNameNr_scanLine 48205
#define sipName_scanLine &sipStrings_QtGui[48205]
#define sipNameNr_screenAt 48214
#define sipName_screenAt &sipStrings_QtGui[48214]
#define sipNameNr_seagreen 27176
#define sipName_seagreen &sipStrings_QtGui[27176]
#define sipNameNr_seashell 48223
#define sipName_seashell &sipStrings_QtGui[48223]
#define sipNameNr_seatName 48232
#define sipName_seatName &sipStrings_QtGui[48232]
#define sipNameNr_setAlpha 48241
#define sipName_setAlpha &sipStrings_QtGui[48241]
#define sipNameNr_setAngle 48250
#define sipName_setAngle &sipStrings_QtGui[48250]
#define sipNameNr_setBlueF 48259
#define sipName_setBlueF &sipStrings_QtGui[48259]
#define sipNameNr_setBrush 48268
#define sipName_setBrush &sipStrings_QtGui[48268]
#define sipNameNr_setChild 48277
#define sipName_setChild &sipStrings_QtGui[48277]
#define sipNameNr_setClean 42923
#define sipName_setClean &sipStrings_QtGui[42923]
#define sipNameNr_setCmykF 48286
#define sipName_setCmykF &sipStrings_QtGui[48286]
#define sipNameNr_setColor 48295
#define sipName_setColor &sipStrings_QtGui[48295]
#define sipNameNr_setFlags 48304
#define sipName_setFlags &sipStrings_QtGui[48304]
#define sipNameNr_setGreen 48313
#define sipName_setGreen &sipStrings_QtGui[48313]
#define sipNameNr_setImage 48322
#define sipName_setImage &sipStrings_QtGui[48322]
#define sipNameNr_setIndex 48331
#define sipName_setIndex &sipStrings_QtGui[48331]
#define sipNameNr_setPixel 48340
#define sipName_setPixel &sipStrings_QtGui[48340]
#define sipNameNr_setPoint 48349
#define sipName_setPoint &sipStrings_QtGui[48349]
#define sipNameNr_setRange 48358
#define sipName_setRange &sipStrings_QtGui[48358]
#define sipNameNr_setRects 48367
#define sipName_setRects &sipStrings_QtGui[48367]
#define sipNameNr_setShape 48376
#define sipName_setShape &sipStrings_QtGui[48376]
#define sipNameNr_setSpeed 48385
#define sipName_setSpeed &sipStrings_QtGui[48385]
#define sipNameNr_setStart 48394
#define sipName_setStart &sipStrings_QtGui[48394]
#define sipNameNr_setStops 48403
#define sipName_setStops &sipStrings_QtGui[48403]
#define sipNameNr_setStyle 48412
#define sipName_setStyle &sipStrings_QtGui[48412]
#define sipNameNr_setTitle 48421
#define sipName_setTitle &sipStrings_QtGui[48421]
#define sipNameNr_setUnits 48430
#define sipName_setUnits &sipStrings_QtGui[48430]
#define sipNameNr_setValue 48439
#define sipName_setValue &sipStrings_QtGui[48439]
#define sipNameNr_setWidth 48448
#define sipName_setWidth &sipStrings_QtGui[48448]
#define sipNameNr_shortcut 48457
#define sipName_shortcut &sipStrings_QtGui[48457]
#define sipNameNr_sizeHint 48466
#define sipName_sizeHint &sipStrings_QtGui[48466]
#define sipNameNr_sortRole 48475
#define sipName_sortRole &sipStrings_QtGui[48475]
#define sipNameNr_startPos 48484
#define sipName_startPos &sipStrings_QtGui[48484]
#define sipNameNr_strategy 48493
#define sipName_strategy &sipStrings_QtGui[48493]
#define sipNameNr_systemId 48502
#define sipName_systemId &sipStrings_QtGui[48502]
#define sipNameNr_tabArray 48511
#define sipName_tabArray &sipStrings_QtGui[48511]
#define sipNameNr_tabStops 48520
#define sipName_tabStops &sipStrings_QtGui[48520]
#define sipNameNr_takeItem 48529
#define sipName_takeItem &sipStrings_QtGui[48529]
#define sipNameNr_textKeys 48538
#define sipName_textKeys &sipStrings_QtGui[48538]
#define sipNameNr_textList 48547
#define sipName_textList &sipStrings_QtGui[48547]
#define sipNameNr_timeHeld 48556
#define sipName_timeHeld &sipStrings_QtGui[48556]
#define sipNameNr_toArgb32 48565
#define sipName_toArgb32 &sipStrings_QtGui[48565]
#define sipNameNr_toPointF 48574
#define sipName_toPointF &sipStrings_QtGui[48574]
#define sipNameNr_toString 48583
#define sipName_toString &sipStrings_QtGui[48583]
#define sipNameNr_undoText 48592
#define sipName_undoText &sipStrings_QtGui[48592]
#define sipNameNr_uniqueId 48601
#define sipName_uniqueId &sipStrings_QtGui[48601]
#define sipNameNr_userData 48610
#define sipName_userData &sipStrings_QtGui[48610]
#define sipNameNr_validate 48619
#define sipName_validate &sipStrings_QtGui[48619]
#define sipNameNr_velocity 48628
#define sipName_velocity &sipStrings_QtGui[48628]
#define sipNameNr_vertical 48637
#define sipName_vertical &sipStrings_QtGui[48637]
#define sipNameNr_viewport 48646
#define sipName_viewport &sipStrings_QtGui[48646]
#define sipNameNr_wrapMode 48655
#define sipName_wrapMode &sipStrings_QtGui[48655]
#define sipNameNr_xChanged 34635
#define sipName_xChanged &sipStrings_QtGui[34635]
#define sipNameNr_yChanged 2342
#define sipName_yChanged &sipStrings_QtGui[2342]
#define sipNameNr_A3Extra 48664
#define sipName_A3Extra &sipStrings_QtGui[48664]
#define sipNameNr_A4Extra 48672
#define sipName_A4Extra &sipStrings_QtGui[48672]
#define sipNameNr_A4Small 48680
#define sipName_A4Small &sipStrings_QtGui[48680]
#define sipNameNr_A5Extra 48688
#define sipName_A5Extra &sipStrings_QtGui[48688]
#define sipNameNr_B5Extra 48696
#define sipName_B5Extra &sipStrings_QtGui[48696]
#define sipNameNr_Battery 48704
#define sipName_Battery &sipStrings_QtGui[48704]
#define sipNameNr_Bengali 48712
#define sipName_Bengali &sipStrings_QtGui[48712]
#define sipNameNr_Blitter 48720
#define sipName_Blitter &sipStrings_QtGui[48720]
#define sipNameNr_Checked 43045
#define sipName_Checked &sipStrings_QtGui[43045]
#define sipNameNr_Comm10E 48728
#define sipName_Comm10E &sipStrings_QtGui[48728]
#define sipNameNr_Courier 48736
#define sipName_Courier &sipStrings_QtGui[48736]
#define sipNameNr_Current 37955
#define sipName_Current &sipStrings_QtGui[37955]
#define sipNameNr_Cursive 48744
#define sipName_Cursive &sipStrings_QtGui[48744]
#define sipNameNr_DarkRed 48752
#define sipName_DarkRed &sipStrings_QtGui[48752]
#define sipNameNr_Desktop 48760
#define sipName_Desktop &sipStrings_QtGui[48760]
#define sipNameNr_DotLine 25347
#define sipName_DotLine &sipStrings_QtGui[25347]
#define sipNameNr_EditCut 48768
#define sipName_EditCut &sipStrings_QtGui[48768]
#define sipNameNr_Element 9391
#define sipName_Element &sipStrings_QtGui[9391]
#define sipNameNr_Ellipse 37967
#define sipName_Ellipse &sipStrings_QtGui[37967]
#define sipNameNr_Fantasy 48776
#define sipName_Fantasy &sipStrings_QtGui[48776]
#define sipNameNr_FlyHigh 48784
#define sipName_FlyHigh &sipStrings_QtGui[48784]
#define sipNameNr_Forward 19811
#define sipName_Forward &sipStrings_QtGui[19811]
#define sipNameNr_Generic 48792
#define sipName_Generic &sipStrings_QtGui[48792]
#define sipNameNr_HelpFaq 48800
#define sipName_HelpFaq &sipStrings_QtGui[48800]
#define sipNameNr_HexArgb 48808
#define sipName_HexArgb &sipStrings_QtGui[48808]
#define sipNameNr_Indexed 48816
#define sipName_Indexed &sipStrings_QtGui[48816]
#define sipNameNr_Invalid 25542
#define sipName_Invalid &sipStrings_QtGui[25542]
#define sipNameNr_Kannada 48824
#define sipName_Kannada &sipStrings_QtGui[48824]
#define sipNameNr_Leading 48832
#define sipName_Leading &sipStrings_QtGui[48832]
#define sipNameNr_LeftTab 48840
#define sipName_LeftTab &sipStrings_QtGui[48840]
#define sipNameNr_LibGLES 48848
#define sipName_LibGLES &sipStrings_QtGui[48848]
#define sipNameNr_ListAdd 48856
#define sipName_ListAdd &sipStrings_QtGui[48856]
#define sipNameNr_Magenta 36215
#define sipName_Magenta &sipStrings_QtGui[36215]
#define sipNameNr_MaxUser 48864
#define sipName_MaxUser &sipStrings_QtGui[48864]
#define sipNameNr_Myanmar 48872
#define sipName_Myanmar &sipStrings_QtGui[48872]
#define sipNameNr_Network 48880
#define sipName_Network &sipStrings_QtGui[48880]
#define sipNameNr_NewLife 48888
#define sipName_NewLife &sipStrings_QtGui[48888]
#define sipNameNr_NewYork 48896
#define sipName_NewYork &sipStrings_QtGui[48896]
#define sipNameNr_NextRow 48904
#define sipName_NextRow &sipStrings_QtGui[48904]
#define sipNameNr_NoMatch 48912
#define sipName_NoMatch &sipStrings_QtGui[48912]
#define sipNameNr_OpenGL2 48920
#define sipName_OpenGL2 &sipStrings_QtGui[48920]
#define sipNameNr_OverSun 48928
#define sipName_OverSun &sipStrings_QtGui[48928]
#define sipNameNr_PdmDpiX 48936
#define sipName_PdmDpiX &sipStrings_QtGui[48936]
#define sipNameNr_PdmDpiY 48944
#define sipName_PdmDpiY &sipStrings_QtGui[48944]
#define sipNameNr_Picture 37979
#define sipName_Picture &sipStrings_QtGui[37979]
#define sipNameNr_Pressed 48952
#define sipName_Pressed &sipStrings_QtGui[48952]
#define sipNameNr_Printer 40603
#define sipName_Printer &sipStrings_QtGui[40603]
#define sipNameNr_QAction 48960
#define sipName_QAction &sipStrings_QtGui[48960]
#define sipNameNr_QBitmap 45327
#define sipName_QBitmap &sipStrings_QtGui[45327]
#define sipNameNr_QCursor 48968
#define sipName_QCursor &sipStrings_QtGui[48968]
#define sipNameNr_QPixmap 48976
#define sipName_QPixmap &sipStrings_QtGui[48976]
#define sipNameNr_QRegion 48984
#define sipName_QRegion &sipStrings_QtGui[48984]
#define sipNameNr_QRgba64 48992
#define sipName_QRgba64 &sipStrings_QtGui[48992]
#define sipNameNr_QScreen 49000
#define sipName_QScreen &sipStrings_QtGui[49000]
#define sipNameNr_QWindow 49008
#define sipName_QWindow &sipStrings_QtGui[49008]
#define sipNameNr_Quality 29134
#define sipName_Quality &sipStrings_QtGui[29134]
#define sipNameNr_Refresh 37439
#define sipName_Refresh &sipStrings_QtGui[37439]
#define sipNameNr_Replace 49016
#define sipName_Replace &sipStrings_QtGui[49016]
#define sipNameNr_Running 20253
#define sipName_Running &sipStrings_QtGui[20253]
#define sipNameNr_Scanner 49024
#define sipName_Scanner &sipStrings_QtGui[49024]
#define sipNameNr_SeaLord 49032
#define sipName_SeaLord &sipStrings_QtGui[49032]
#define sipNameNr_Sinhala 49040
#define sipName_Sinhala &sipStrings_QtGui[49040]
#define sipNameNr_Stretch 25872
#define sipName_Stretch &sipStrings_QtGui[25872]
#define sipNameNr_SubType 43254
#define sipName_SubType &sipStrings_QtGui[43254]
#define sipNameNr_TabType 10889
#define sipName_TabType &sipStrings_QtGui[10889]
#define sipNameNr_Tabloid 49048
#define sipName_Tabloid &sipStrings_QtGui[49048]
#define sipNameNr_Tibetan 49056
#define sipName_Tibetan &sipStrings_QtGui[49056]
#define sipNameNr_Trigger 10271
#define sipName_Trigger &sipStrings_QtGui[10271]
#define sipNameNr_TxScale 49064
#define sipName_TxScale &sipStrings_QtGui[49064]
#define sipNameNr_TxShear 49072
#define sipName_TxShear &sipStrings_QtGui[49072]
#define sipNameNr_Unknown 49080
#define sipName_Unknown &sipStrings_QtGui[49080]
#define sipNameNr_Updated 29442
#define sipName_Updated &sipStrings_QtGui[29442]
#define sipNameNr_Windows 25070
#define sipName_Windows &sipStrings_QtGui[25070]
#define sipNameNr_YUV420P 49088
#define sipName_YUV420P &sipStrings_QtGui[49088]
#define sipNameNr_ZoomOut 49096
#define sipName_ZoomOut &sipStrings_QtGui[49096]
#define sipNameNr___add__ 49104
#define sipName___add__ &sipStrings_QtGui[49104]
#define sipNameNr___and__ 49112
#define sipName___and__ &sipStrings_QtGui[49112]
#define sipNameNr___int__ 49120
#define sipName___int__ &sipStrings_QtGui[49120]
#define sipNameNr___ior__ 49128
#define sipName___ior__ &sipStrings_QtGui[49128]
#define sipNameNr___len__ 49136
#define sipName___len__ &sipStrings_QtGui[49136]
#define sipNameNr___mul__ 49144
#define sipName___mul__ &sipStrings_QtGui[49144]
#define sipNameNr___neg__ 49152
#define sipName___neg__ &sipStrings_QtGui[49152]
#define sipNameNr___sub__ 49160
#define sipName___sub__ &sipStrings_QtGui[49160]
#define sipNameNr___xor__ 49168
#define sipName___xor__ &sipStrings_QtGui[49168]
#define sipNameNr_actions 49176
#define sipName_actions &sipStrings_QtGui[49176]
#define sipNameNr_addFile 49184
#define sipName_addFile &sipStrings_QtGui[49184]
#define sipNameNr_addPage 49192
#define sipName_addPage &sipStrings_QtGui[49192]
#define sipNameNr_addPath 49200
#define sipName_addPath &sipStrings_QtGui[49200]
#define sipNameNr_addRect 49208
#define sipName_addRect &sipStrings_QtGui[49208]
#define sipNameNr_addText 49216
#define sipName_addText &sipStrings_QtGui[49216]
#define sipNameNr_adjoint 49224
#define sipName_adjoint &sipStrings_QtGui[49224]
#define sipNameNr_allGray 49232
#define sipName_allGray &sipStrings_QtGui[49232]
#define sipNameNr_atStart 49240
#define sipName_atStart &sipStrings_QtGui[49240]
#define sipNameNr_autorep 49248
#define sipName_autorep &sipStrings_QtGui[49248]
#define sipNameNr_baseUrl 49256
#define sipName_baseUrl &sipStrings_QtGui[49256]
#define sipNameNr_buttons 49264
#define sipName_buttons &sipStrings_QtGui[49264]
#define sipNameNr_canRead 49272
#define sipName_canRead &sipStrings_QtGui[49272]
#define sipNameNr_canRedo 49280
#define sipName_canRedo &sipStrings_QtGui[49280]
#define sipNameNr_canUndo 49288
#define sipName_canUndo &sipStrings_QtGui[49288]
#define sipNameNr_changed 49296
#define sipName_changed &sipStrings_QtGui[49296]
#define sipNameNr_checked 44617
#define sipName_checked &sipStrings_QtGui[44617]
#define sipNameNr_cleanup 49304
#define sipName_cleanup &sipStrings_QtGui[49304]
#define sipNameNr_columns 49312
#define sipName_columns &sipStrings_QtGui[49312]
#define sipNameNr_combine 49320
#define sipName_combine &sipStrings_QtGui[49320]
#define sipNameNr_command 49328
#define sipName_command &sipStrings_QtGui[49328]
#define sipNameNr_context 49336
#define sipName_context &sipStrings_QtGui[49336]
#define sipNameNr_creator 49344
#define sipName_creator &sipStrings_QtGui[49344]
#define sipNameNr_crimson 49352
#define sipName_crimson &sipStrings_QtGui[49352]
#define sipNameNr_cubicTo 49360
#define sipName_cubicTo &sipStrings_QtGui[49360]
#define sipNameNr_darkred 49368
#define sipName_darkred &sipStrings_QtGui[49368]
#define sipNameNr_descent 49376
#define sipName_descent &sipStrings_QtGui[49376]
#define sipNameNr_destroy 49384
#define sipName_destroy &sipStrings_QtGui[49384]
#define sipNameNr_devType 49392
#define sipName_devType &sipStrings_QtGui[49392]
#define sipNameNr_devices 49400
#define sipName_devices &sipStrings_QtGui[49400]
#define sipNameNr_dimgray 49408
#define sipName_dimgray &sipStrings_QtGui[49408]
#define sipNameNr_dimgrey 49416
#define sipName_dimgrey &sipStrings_QtGui[49416]
#define sipNameNr_display 49424
#define sipName_display &sipStrings_QtGui[49424]
#define sipNameNr_drawArc 49432
#define sipName_drawArc &sipStrings_QtGui[49432]
#define sipNameNr_drawPie 49440
#define sipName_drawPie &sipStrings_QtGui[49440]
#define sipNameNr_enabled 49448
#define sipName_enabled &sipStrings_QtGui[49448]
#define sipNameNr_exposed 49456
#define sipName_exposed &sipStrings_QtGui[49456]
#define sipNameNr_flipped 49464
#define sipName_flipped &sipStrings_QtGui[49464]
#define sipNameNr_fontDpi 49472
#define sipName_fontDpi &sipStrings_QtGui[49472]
#define sipNameNr_formats 49480
#define sipName_formats &sipStrings_QtGui[49480]
#define sipNameNr_fromHsl 49488
#define sipName_fromHsl &sipStrings_QtGui[49488]
#define sipNameNr_fromHsv 49496
#define sipName_fromHsv &sipStrings_QtGui[49496]
#define sipNameNr_fromRgb 49504
#define sipName_fromRgb &sipStrings_QtGui[49504]
#define sipNameNr_frustum 49512
#define sipName_frustum &sipStrings_QtGui[49512]
#define sipNameNr_fuchsia 49520
#define sipName_fuchsia &sipStrings_QtGui[49520]
#define sipNameNr_getAxes 49528
#define sipName_getAxes &sipStrings_QtGui[49528]
#define sipNameNr_getCmyk 49536
#define sipName_getCmyk &sipStrings_QtGui[49536]
#define sipNameNr_getHslF 49544
#define sipName_getHslF &sipStrings_QtGui[49544]
#define sipNameNr_getHsvF 49552
#define sipName_getHsvF &sipStrings_QtGui[49552]
#define sipNameNr_getRgbF 49560
#define sipName_getRgbF &sipStrings_QtGui[49560]
#define sipNameNr_globalX 49568
#define sipName_globalX &sipStrings_QtGui[49568]
#define sipNameNr_globalY 49576
#define sipName_globalY &sipStrings_QtGui[49576]
#define sipNameNr_hitTest 49584
#define sipName_hitTest &sipStrings_QtGui[49584]
#define sipNameNr_hotSpot 49592
#define sipName_hotSpot &sipStrings_QtGui[49592]
#define sipNameNr_hotpink 49600
#define sipName_hotpink &sipStrings_QtGui[49600]
#define sipNameNr_hovered 49608
#define sipName_hovered &sipStrings_QtGui[49608]
#define sipNameNr_hslHueF 49616
#define sipName_hslHueF &sipStrings_QtGui[49616]
#define sipNameNr_hsvHueF 49624
#define sipName_hsvHueF &sipStrings_QtGui[49624]
#define sipNameNr_hueSize 49632
#define sipName_hueSize &sipStrings_QtGui[49632]
#define sipNameNr_imageAt 49640
#define sipName_imageAt &sipStrings_QtGui[49640]
#define sipNameNr_indexOf 49648
#define sipName_indexOf &sipStrings_QtGui[49648]
#define sipNameNr_isClean 49656
#define sipName_isClean &sipStrings_QtGui[49656]
#define sipNameNr_isEmpty 49664
#define sipName_isEmpty &sipStrings_QtGui[49664]
#define sipNameNr_isEqual 49672
#define sipName_isEqual &sipStrings_QtGui[49672]
#define sipNameNr_isModal 49680
#define sipName_isModal &sipStrings_QtGui[49680]
#define sipNameNr_isSolid 49688
#define sipName_isSolid &sipStrings_QtGui[49688]
#define sipNameNr_isValid 49696
#define sipName_isValid &sipStrings_QtGui[49696]
#define sipNameNr_kerning 49704
#define sipName_kerning &sipStrings_QtGui[49704]
#define sipNameNr_leading 49712
#define sipName_leading &sipStrings_QtGui[49712]
#define sipNameNr_lighter 14537
#define sipName_lighter &sipStrings_QtGui[14537]
#define sipNameNr_magenta 37871
#define sipName_magenta &sipStrings_QtGui[37871]
#define sipNameNr_mapRect 49720
#define sipName_mapRect &sipStrings_QtGui[49720]
#define sipNameNr_margins 49728
#define sipName_margins &sipStrings_QtGui[49728]
#define sipNameNr_matches 49736
#define sipName_matches &sipStrings_QtGui[49736]
#define sipNameNr_newPage 49744
#define sipName_newPage &sipStrings_QtGui[49744]
#define sipNameNr_oldPosF 49752
#define sipName_oldPosF &sipStrings_QtGui[49752]
#define sipNameNr_oldSize 49760
#define sipName_oldSize &sipStrings_QtGui[49760]
#define sipNameNr_oldlace 49768
#define sipName_oldlace &sipStrings_QtGui[49768]
#define sipNameNr_opacity 49776
#define sipName_opacity &sipStrings_QtGui[49776]
#define sipNameNr_openUrl 49784
#define sipName_openUrl &sipStrings_QtGui[49784]
#define sipNameNr_options 49792
#define sipName_options &sipStrings_QtGui[49792]
#define sipNameNr_padding 49800
#define sipName_padding &sipStrings_QtGui[49800]
#define sipNameNr_painter 49808
#define sipName_painter &sipStrings_QtGui[49808]
#define sipNameNr_palette 49816
#define sipName_palette &sipStrings_QtGui[49816]
#define sipNameNr_prepare 49824
#define sipName_prepare &sipStrings_QtGui[49824]
#define sipNameNr_prepend 49832
#define sipName_prepend &sipStrings_QtGui[49832]
#define sipNameNr_profile 49840
#define sipName_profile &sipStrings_QtGui[49840]
#define sipNameNr_project 46437
#define sipName_project &sipStrings_QtGui[46437]
#define sipNameNr_qRgba64 49848
#define sipName_qRgba64 &sipStrings_QtGui[49848]
#define sipNameNr_quality 49856
#define sipName_quality &sipStrings_QtGui[49856]
#define sipNameNr_queries 49864
#define sipName_queries &sipStrings_QtGui[49864]
#define sipNameNr_rawFont 49872
#define sipName_rawFont &sipStrings_QtGui[49872]
#define sipNameNr_redSize 49880
#define sipName_redSize &sipStrings_QtGui[49880]
#define sipNameNr_release 49888
#define sipName_release &sipStrings_QtGui[49888]
#define sipNameNr_replace 49896
#define sipName_replace &sipStrings_QtGui[49896]
#define sipNameNr_reserve 49904
#define sipName_reserve &sipStrings_QtGui[49904]
#define sipNameNr_resized 49912
#define sipName_resized &sipStrings_QtGui[49912]
#define sipNameNr_resolve 49920
#define sipName_resolve &sipStrings_QtGui[49920]
#define sipNameNr_restore 49928
#define sipName_restore &sipStrings_QtGui[49928]
#define sipNameNr_rgbSwap 49936
#define sipName_rgbSwap &sipStrings_QtGui[49936]
#define sipNameNr_rowSpan 49944
#define sipName_rowSpan &sipStrings_QtGui[49944]
#define sipNameNr_samples 49952
#define sipName_samples &sipStrings_QtGui[49952]
#define sipNameNr_scaling 49960
#define sipName_scaling &sipStrings_QtGui[49960]
#define sipNameNr_screens 49968
#define sipName_screens &sipStrings_QtGui[49968]
#define sipNameNr_setBlue 49976
#define sipName_setBlue &sipStrings_QtGui[49976]
#define sipNameNr_setBold 49984
#define sipName_setBold &sipStrings_QtGui[49984]
#define sipNameNr_setCmyk 49992
#define sipName_setCmyk &sipStrings_QtGui[49992]
#define sipNameNr_setData 50000
#define sipName_setData &sipStrings_QtGui[50000]
#define sipNameNr_setFlag 50008
#define sipName_setFlag &sipStrings_QtGui[50008]
#define sipNameNr_setFont 50016
#define sipName_setFont &sipStrings_QtGui[50016]
#define sipNameNr_setHslF 50024
#define sipName_setHslF &sipStrings_QtGui[50024]
#define sipNameNr_setHsvF 50032
#define sipName_setHsvF &sipStrings_QtGui[50032]
#define sipNameNr_setHtml 50040
#define sipName_setHtml &sipStrings_QtGui[50040]
#define sipNameNr_setIcon 50048
#define sipName_setIcon &sipStrings_QtGui[50048]
#define sipNameNr_setItem 50056
#define sipName_setItem &sipStrings_QtGui[50056]
#define sipNameNr_setKeys 50064
#define sipName_setKeys &sipStrings_QtGui[50064]
#define sipNameNr_setMask 50072
#define sipName_setMask &sipStrings_QtGui[50072]
#define sipNameNr_setMenu 50080
#define sipName_setMenu &sipStrings_QtGui[50080]
#define sipNameNr_setMode 50088
#define sipName_setMode &sipStrings_QtGui[50088]
#define sipNameNr_setName 50096
#define sipName_setName &sipStrings_QtGui[50096]
#define sipNameNr_setRedF 50104
#define sipName_setRedF &sipStrings_QtGui[50104]
#define sipNameNr_setRgbF 50112
#define sipName_setRgbF &sipStrings_QtGui[50112]
#define sipNameNr_setRgba 50120
#define sipName_setRgba &sipStrings_QtGui[50120]
#define sipNameNr_setTabs 50128
#define sipName_setTabs &sipStrings_QtGui[50128]
#define sipNameNr_setText 50136
#define sipName_setText &sipStrings_QtGui[50136]
#define sipNameNr_sibling 50144
#define sipName_sibling &sipStrings_QtGui[50144]
#define sipNameNr_skyblue 34857
#define sipName_skyblue &sipStrings_QtGui[34857]
#define sipNameNr_started 50152
#define sipName_started &sipStrings_QtGui[50152]
#define sipNameNr_stretch 50160
#define sipName_stretch &sipStrings_QtGui[50160]
#define sipNameNr_subEnum 50168
#define sipName_subEnum &sipStrings_QtGui[50168]
#define sipNameNr_subType 50176
#define sipName_subType &sipStrings_QtGui[50176]
#define sipNameNr_surface 50184
#define sipName_surface &sipStrings_QtGui[50184]
#define sipNameNr_takeRow 50192
#define sipName_takeRow &sipStrings_QtGui[50192]
#define sipNameNr_texture 50200
#define sipName_texture &sipStrings_QtGui[50200]
#define sipNameNr_thistle 50208
#define sipName_thistle &sipStrings_QtGui[50208]
#define sipNameNr_toImage 50216
#define sipName_toImage &sipStrings_QtGui[50216]
#define sipNameNr_toPoint 50224
#define sipName_toPoint &sipStrings_QtGui[50224]
#define sipNameNr_toRgb16 50232
#define sipName_toRgb16 &sipStrings_QtGui[50232]
#define sipNameNr_toggled 50240
#define sipName_toggled &sipStrings_QtGui[50240]
#define sipNameNr_toolTip 50248
#define sipName_toolTip &sipStrings_QtGui[50248]
#define sipNameNr_trigger 50256
#define sipName_trigger &sipStrings_QtGui[50256]
#define sipNameNr_trimmed 50264
#define sipName_trimmed &sipStrings_QtGui[50264]
#define sipNameNr_updated 50272
#define sipName_updated &sipStrings_QtGui[50272]
#define sipNameNr_version 50280
#define sipName_version &sipStrings_QtGui[50280]
#define sipNameNr_widthMM 50288
#define sipName_widthMM &sipStrings_QtGui[50288]
#define sipNameNr_xHeight 50296
#define sipName_xHeight &sipStrings_QtGui[50296]
#define sipNameNr_yellowF 50304
#define sipName_yellowF &sipStrings_QtGui[50304]
#define sipNameNr_A4Plus 50312
#define sipName_A4Plus &sipStrings_QtGui[50312]
#define sipNameNr_Accent 50319
#define sipName_Accent &sipStrings_QtGui[50319]
#define sipNameNr_Action 10722
#define sipName_Action &sipStrings_QtGui[10722]
#define sipNameNr_Active 27343
#define sipName_Active &sipStrings_QtGui[27343]
#define sipNameNr_AddTab 50326
#define sipName_AddTab &sipStrings_QtGui[50326]
#define sipNameNr_Arabic 50333
#define sipName_Arabic &sipStrings_QtGui[50333]
#define sipNameNr_Bt2020 50340
#define sipName_Bt2020 &sipStrings_QtGui[50340]
#define sipNameNr_Button 50347
#define sipName_Button &sipStrings_QtGui[50347]
#define sipNameNr_Cancel 50354
#define sipName_Cancel &sipStrings_QtGui[50354]
#define sipNameNr_Cicero 50361
#define sipName_Cicero &sipStrings_QtGui[50361]
#define sipNameNr_Color0 50368
#define sipName_Color0 &sipStrings_QtGui[50368]
#define sipNameNr_Color1 50375
#define sipName_Color1 &sipStrings_QtGui[50375]
#define sipNameNr_Cursor 10250
#define sipName_Cursor &sipStrings_QtGui[10250]
#define sipNameNr_Custom 50382
#define sipName_Custom &sipStrings_QtGui[50382]
#define sipNameNr_Delete 40032
#define sipName_Delete &sipStrings_QtGui[40032]
#define sipNameNr_Eraser 50389
#define sipName_Eraser &sipStrings_QtGui[50389]
#define sipNameNr_Finger 50396
#define sipName_Finger &sipStrings_QtGui[50396]
#define sipNameNr_Folder 50403
#define sipName_Folder &sipStrings_QtGui[50403]
#define sipNameNr_Format 3703
#define sipName_Format &sipStrings_QtGui[3703]
#define sipNameNr_GoDown 50410
#define sipName_GoDown &sipStrings_QtGui[50410]
#define sipNameNr_GoHome 50417
#define sipName_GoHome &sipStrings_QtGui[50417]
#define sipNameNr_GoNext 50424
#define sipName_GoNext &sipStrings_QtGui[50424]
#define sipNameNr_Hebrew 50431
#define sipName_Hebrew &sipStrings_QtGui[50431]
#define sipNameNr_HexRgb 50438
#define sipName_HexRgb &sipStrings_QtGui[50438]
#define sipNameNr_Hidden 50445
#define sipName_Hidden &sipStrings_QtGui[50445]
#define sipNameNr_InFlow 50452
#define sipName_InFlow &sipStrings_QtGui[50452]
#define sipNameNr_Italic 19659
#define sipName_Italic &sipStrings_QtGui[19659]
#define sipNameNr_JisB10 50459
#define sipName_JisB10 &sipStrings_QtGui[50459]
#define sipNameNr_Korean 50466
#define sipName_Korean &sipStrings_QtGui[50466]
#define sipNameNr_Ledger 50473
#define sipName_Ledger &sipStrings_QtGui[50473]
#define sipNameNr_Letter 50480
#define sipName_Letter &sipStrings_QtGui[50480]
#define sipNameNr_Linear 41099
#define sipName_Linear &sipStrings_QtGui[41099]
#define sipNameNr_Medium 16397
#define sipName_Medium &sipStrings_QtGui[16397]
#define sipNameNr_NoMove 50487
#define sipName_NoMove &sipStrings_QtGui[50487]
#define sipNameNr_NoRole 50494
#define sipName_NoRole &sipStrings_QtGui[50494]
#define sipNameNr_NoSave 50501
#define sipName_NoSave &sipStrings_QtGui[50501]
#define sipNameNr_NoWrap 50508
#define sipName_NoWrap &sipStrings_QtGui[50508]
#define sipNameNr_Normal 36036
#define sipName_Normal &sipStrings_QtGui[36036]
#define sipNameNr_OldHat 50515
#define sipName_OldHat &sipStrings_QtGui[50515]
#define sipNameNr_OpenGL 8948
#define sipName_OpenGL &sipStrings_QtGui[8948]
#define sipNameNr_OpenVG 50522
#define sipName_OpenVG &sipStrings_QtGui[50522]
#define sipNameNr_Option 1170
#define sipName_Option &sipStrings_QtGui[1170]
#define sipNameNr_Paused 46088
#define sipName_Paused &sipStrings_QtGui[46088]
#define sipNameNr_Prc16K 50529
#define sipName_Prc16K &sipStrings_QtGui[50529]
#define sipNameNr_Prc32K 50536
#define sipName_Prc32K &sipStrings_QtGui[50536]
#define sipNameNr_Preset 17135
#define sipName_Preset &sipStrings_QtGui[17135]
#define sipNameNr_QBrush 50543
#define sipName_QBrush &sipStrings_QtGui[50543]
#define sipNameNr_QColor 50550
#define sipName_QColor &sipStrings_QtGui[50550]
#define sipNameNr_QImage 50557
#define sipName_QImage &sipStrings_QtGui[50557]
#define sipNameNr_QMovie 50564
#define sipName_QMovie &sipStrings_QtGui[50564]
#define sipNameNr_Quarto 50571
#define sipName_Quarto &sipStrings_QtGui[50571]
#define sipNameNr_Raster 50578
#define sipName_Raster &sipStrings_QtGui[50578]
#define sipNameNr_Reason 5330
#define sipName_Reason &sipStrings_QtGui[5330]
#define sipNameNr_Reject 50585
#define sipName_Reject &sipStrings_QtGui[50585]
#define sipNameNr_SaveAs 25423
#define sipName_SaveAs &sipStrings_QtGui[25423]
#define sipNameNr_Scroll 36804
#define sipName_Scroll &sipStrings_QtGui[36804]
#define sipNameNr_Shadow 50592
#define sipName_Shadow &sipStrings_QtGui[50592]
#define sipNameNr_Spread 17153
#define sipName_Spread &sipStrings_QtGui[17153]
#define sipNameNr_St2084 50599
#define sipName_St2084 &sipStrings_QtGui[50599]
#define sipNameNr_Stacks 9480
#define sipName_Stacks &sipStrings_QtGui[9480]
#define sipNameNr_Stylus 50606
#define sipName_Stylus &sipStrings_QtGui[50606]
#define sipNameNr_SuperA 50613
#define sipName_SuperA &sipStrings_QtGui[50613]
#define sipNameNr_SuperB 50620
#define sipName_SuperB &sipStrings_QtGui[50620]
#define sipNameNr_Symbol 50627
#define sipName_Symbol &sipStrings_QtGui[50627]
#define sipNameNr_Syriac 50634
#define sipName_Syriac &sipStrings_QtGui[50634]
#define sipNameNr_System 3616
#define sipName_System &sipStrings_QtGui[3616]
#define sipNameNr_Telugu 50641
#define sipName_Telugu &sipStrings_QtGui[50641]
#define sipNameNr_Thaana 50648
#define sipName_Thaana &sipStrings_QtGui[50648]
#define sipNameNr_TxNone 50655
#define sipName_TxNone &sipStrings_QtGui[50655]
#define sipNameNr_Weight 29191
#define sipName_Weight &sipStrings_QtGui[29191]
#define sipNameNr_Window 14462
#define sipName_Window &sipStrings_QtGui[14462]
#define sipNameNr_YUV411 50662
#define sipName_YUV411 &sipStrings_QtGui[50662]
#define sipNameNr_YUV422 50669
#define sipName_YUV422 &sipStrings_QtGui[50669]
#define sipNameNr_YUV444 50676
#define sipName_YUV444 &sipStrings_QtGui[50676]
#define sipNameNr_Yellow 39933
#define sipName_Yellow &sipStrings_QtGui[39933]
#define sipNameNr_ZoomIn 50683
#define sipName_ZoomIn &sipStrings_QtGui[50683]
#define sipNameNr___eq__ 50690
#define sipName___eq__ &sipStrings_QtGui[50690]
#define sipNameNr___ge__ 50697
#define sipName___ge__ &sipStrings_QtGui[50697]
#define sipNameNr___gt__ 50704
#define sipName___gt__ &sipStrings_QtGui[50704]
#define sipNameNr___le__ 50711
#define sipName___le__ &sipStrings_QtGui[50711]
#define sipNameNr___lt__ 50718
#define sipName___lt__ &sipStrings_QtGui[50718]
#define sipNameNr___ne__ 50725
#define sipName___ne__ &sipStrings_QtGui[50725]
#define sipNameNr___or__ 50732
#define sipName___or__ &sipStrings_QtGui[50732]
#define sipNameNr_accent 50739
#define sipName_accent &sipStrings_QtGui[50739]
#define sipNameNr_accept 50746
#define sipName_accept &sipStrings_QtGui[50746]
#define sipNameNr_action 8465
#define sipName_action &sipStrings_QtGui[8465]
#define sipNameNr_active 46803
#define sipName_active &sipStrings_QtGui[46803]
#define sipNameNr_alpha8 50753
#define sipName_alpha8 &sipStrings_QtGui[50753]
#define sipNameNr_alphaF 50760
#define sipName_alphaF &sipStrings_QtGui[50760]
#define sipNameNr_anchor 50767
#define sipName_anchor &sipStrings_QtGui[50767]
#define sipNameNr_append 50774
#define sipName_append &sipStrings_QtGui[50774]
#define sipNameNr_ascent 50781
#define sipName_ascent &sipStrings_QtGui[50781]
#define sipNameNr_author 50788
#define sipName_author &sipStrings_QtGui[50788]
#define sipNameNr_before 50795
#define sipName_before &sipStrings_QtGui[50795]
#define sipNameNr_bisque 50802
#define sipName_bisque &sipStrings_QtGui[50802]
#define sipNameNr_bitmap 50809
#define sipName_bitmap &sipStrings_QtGui[50809]
#define sipNameNr_blackF 50816
#define sipName_blackF &sipStrings_QtGui[50816]
#define sipNameNr_border 50823
#define sipName_border &sipStrings_QtGui[50823]
#define sipNameNr_bottom 50830
#define sipName_bottom &sipStrings_QtGui[50830]
#define sipNameNr_button 50837
#define sipName_button &sipStrings_QtGui[50837]
#define sipNameNr_cancel 50844
#define sipName_cancel &sipStrings_QtGui[50844]
#define sipNameNr_cellAt 50851
#define sipName_cellAt &sipStrings_QtGui[50851]
#define sipNameNr_center 50858
#define sipName_center &sipStrings_QtGui[50858]
#define sipNameNr_closed 50865
#define sipName_closed &sipStrings_QtGui[50865]
#define sipNameNr_column 50872
#define sipName_column &sipStrings_QtGui[50872]
#define sipNameNr_commit 50879
#define sipName_commit &sipStrings_QtGui[50879]
#define sipNameNr_create 50886
#define sipName_create &sipStrings_QtGui[50886]
#define sipNameNr_cursor 50893
#define sipName_cursor &sipStrings_QtGui[50893]
#define sipNameNr_darker 50900
#define sipName_darker &sipStrings_QtGui[50900]
#define sipNameNr_detach 50907
#define sipName_detach &sipStrings_QtGui[50907]
#define sipNameNr_device 38784
#define sipName_device &sipStrings_QtGui[38784]
#define sipNameNr_factor 50914
#define sipName_factor &sipStrings_QtGui[50914]
#define sipNameNr_family 50921
#define sipName_family &sipStrings_QtGui[50921]
#define sipNameNr_filter 50928
#define sipName_filter &sipStrings_QtGui[50928]
#define sipNameNr_format 50935
#define sipName_format &sipStrings_QtGui[50935]
#define sipNameNr_getHsl 50942
#define sipName_getHsl &sipStrings_QtGui[50942]
#define sipNameNr_getHsv 50949
#define sipName_getHsv &sipStrings_QtGui[50949]
#define sipNameNr_getRgb 50956
#define sipName_getRgb &sipStrings_QtGui[50956]
#define sipNameNr_green8 50963
#define sipName_green8 &sipStrings_QtGui[50963]
#define sipNameNr_greenF 50970
#define sipName_greenF &sipStrings_QtGui[50970]
#define sipNameNr_height 50977
#define sipName_height &sipStrings_QtGui[50977]
#define sipNameNr_hslHue 50984
#define sipName_hslHue &sipStrings_QtGui[50984]
#define sipNameNr_hsvHue 50991
#define sipName_hsvHue &sipStrings_QtGui[50991]
#define sipNameNr_ignore 50998
#define sipName_ignore &sipStrings_QtGui[50998]
#define sipNameNr_inFont 51005
#define sipName_inFont &sipStrings_QtGui[51005]
#define sipNameNr_indent 51012
#define sipName_indent &sipStrings_QtGui[51012]
#define sipNameNr_indigo 51019
#define sipName_indigo &sipStrings_QtGui[51019]
#define sipNameNr_insert 51026
#define sipName_insert &sipStrings_QtGui[51026]
#define sipNameNr_isMask 51033
#define sipName_isMask &sipStrings_QtGui[51033]
#define sipNameNr_isNull 51040
#define sipName_isNull &sipStrings_QtGui[51040]
#define sipNameNr_italic 51047
#define sipName_italic &sipStrings_QtGui[51047]
#define sipNameNr_layout 51054
#define sipName_layout &sipStrings_QtGui[51054]
#define sipNameNr_length 51061
#define sipName_length &sipStrings_QtGui[51061]
#define sipNameNr_lineAt 51068
#define sipName_lineAt &sipStrings_QtGui[51068]
#define sipNameNr_lineTo 51075
#define sipName_lineTo &sipStrings_QtGui[51075]
#define sipNameNr_locale 51082
#define sipName_locale &sipStrings_QtGui[51082]
#define sipNameNr_lookAt 51089
#define sipName_lookAt &sipStrings_QtGui[51089]
#define sipNameNr_margin 51096
#define sipName_margin &sipStrings_QtGui[51096]
#define sipNameNr_marker 51103
#define sipName_marker &sipStrings_QtGui[51103]
#define sipNameNr_maroon 51110
#define sipName_maroon &sipStrings_QtGui[51110]
#define sipNameNr_matrix 51117
#define sipName_matrix &sipStrings_QtGui[51117]
#define sipNameNr_member 51124
#define sipName_member &sipStrings_QtGui[51124]
#define sipNameNr_metric 51131
#define sipName_metric &sipStrings_QtGui[51131]
#define sipNameNr_mirror 51138
#define sipName_mirror &sipStrings_QtGui[51138]
#define sipNameNr_moveTo 51145
#define sipName_moveTo &sipStrings_QtGui[51145]
#define sipNameNr_normal 51152
#define sipName_normal &sipStrings_QtGui[51152]
#define sipNameNr_notify 51159
#define sipName_notify &sipStrings_QtGui[51159]
#define sipNameNr_object 51166
#define sipName_object &sipStrings_QtGui[51166]
#define sipNameNr_offset 51173
#define sipName_offset &sipStrings_QtGui[51173]
#define sipNameNr_oldPos 51180
#define sipName_oldPos &sipStrings_QtGui[51180]
#define sipNameNr_option 51187
#define sipName_option &sipStrings_QtGui[51187]
#define sipNameNr_orange 41847
#define sipName_orange &sipStrings_QtGui[41847]
#define sipNameNr_orchid 35001
#define sipName_orchid &sipStrings_QtGui[35001]
#define sipNameNr_orient 51194
#define sipName_orient &sipStrings_QtGui[51194]
#define sipNameNr_parent 30507
#define sipName_parent &sipStrings_QtGui[30507]
#define sipNameNr_pixmap 51201
#define sipName_pixmap &sipStrings_QtGui[51201]
#define sipNameNr_points 51208
#define sipName_points &sipStrings_QtGui[51208]
#define sipNameNr_prefix 51215
#define sipName_prefix &sipStrings_QtGui[51215]
#define sipNameNr_purple 35014
#define sipName_purple &sipStrings_QtGui[35014]
#define sipNameNr_qAlpha 51222
#define sipName_qAlpha &sipStrings_QtGui[51222]
#define sipNameNr_qGreen 51229
#define sipName_qGreen &sipStrings_QtGui[51229]
#define sipNameNr_quadTo 51236
#define sipName_quadTo &sipStrings_QtGui[51236]
#define sipNameNr_radius 51243
#define sipName_radius &sipStrings_QtGui[51243]
#define sipNameNr_raise_ 51250
#define sipName_raise_ &sipStrings_QtGui[51250]
#define sipNameNr_reason 51257
#define sipName_reason &sipStrings_QtGui[51257]
#define sipNameNr_region 51264
#define sipName_region &sipStrings_QtGui[51264]
#define sipNameNr_remove 51271
#define sipName_remove &sipStrings_QtGui[51271]
#define sipNameNr_resize 51278
#define sipName_resize &sipStrings_QtGui[51278]
#define sipNameNr_revert 51285
#define sipName_revert &sipStrings_QtGui[51285]
#define sipNameNr_rgba64 51292
#define sipName_rgba64 &sipStrings_QtGui[51292]
#define sipNameNr_rotate 51299
#define sipName_rotate &sipStrings_QtGui[51299]
#define sipNameNr_rowEnd 51306
#define sipName_rowEnd &sipStrings_QtGui[51306]
#define sipNameNr_salmon 38532
#define sipName_salmon &sipStrings_QtGui[38532]
#define sipNameNr_scalar 51313
#define sipName_scalar &sipStrings_QtGui[51313]
#define sipNameNr_scaleX 51320
#define sipName_scaleX &sipStrings_QtGui[51320]
#define sipNameNr_scaleY 51327
#define sipName_scaleY &sipStrings_QtGui[51327]
#define sipNameNr_scaled 51334
#define sipName_scaled &sipStrings_QtGui[51334]
#define sipNameNr_screen 26308
#define sipName_screen &sipStrings_QtGui[26308]
#define sipNameNr_scroll 51341
#define sipName_scroll &sipStrings_QtGui[51341]
#define sipNameNr_select 46695
#define sipName_select &sipStrings_QtGui[46695]
#define sipNameNr_setHsl 51348
#define sipName_setHsl &sipStrings_QtGui[51348]
#define sipNameNr_setHsv 51355
#define sipName_setHsv &sipStrings_QtGui[51355]
#define sipNameNr_setKey 51362
#define sipName_setKey &sipStrings_QtGui[51362]
#define sipNameNr_setPen 51369
#define sipName_setPen &sipStrings_QtGui[51369]
#define sipNameNr_setPos 51376
#define sipName_setPos &sipStrings_QtGui[51376]
#define sipNameNr_setRed 51383
#define sipName_setRed &sipStrings_QtGui[51383]
#define sipNameNr_setRgb 51390
#define sipName_setRgb &sipStrings_QtGui[51390]
#define sipNameNr_setRow 51397
#define sipName_setRow &sipStrings_QtGui[51397]
#define sipNameNr_setTag 51404
#define sipName_setTag &sipStrings_QtGui[51404]
#define sipNameNr_setTop 51411
#define sipName_setTop &sipStrings_QtGui[51411]
#define sipNameNr_shadow 51418
#define sipName_shadow &sipStrings_QtGui[51418]
#define sipNameNr_shares 51425
#define sipName_shares &sipStrings_QtGui[51425]
#define sipNameNr_sienna 51432
#define sipName_sienna &sipStrings_QtGui[51432]
#define sipNameNr_silver 51439
#define sipName_silver &sipStrings_QtGui[51439]
#define sipNameNr_source 14747
#define sipName_source &sipStrings_QtGui[14747]
#define sipNameNr_spread 51446
#define sipName_spread &sipStrings_QtGui[51446]
#define sipNameNr_stacks 51453
#define sipName_stacks &sipStrings_QtGui[51453]
#define sipNameNr_stereo 51460
#define sipName_stereo &sipStrings_QtGui[51460]
#define sipNameNr_styles 51467
#define sipName_styles &sipStrings_QtGui[51467]
#define sipNameNr_submit 51474
#define sipName_submit &sipStrings_QtGui[51474]
#define sipNameNr_target 51481
#define sipName_target &sipStrings_QtGui[51481]
#define sipNameNr_toAxes 51488
#define sipName_toAxes &sipStrings_QtGui[51488]
#define sipNameNr_toCmyk 51495
#define sipName_toCmyk &sipStrings_QtGui[51495]
#define sipNameNr_toHtml 51502
#define sipName_toHtml &sipStrings_QtGui[51502]
#define sipNameNr_toggle 51509
#define sipName_toggle &sipStrings_QtGui[51509]
#define sipNameNr_tomato 51516
#define sipName_tomato &sipStrings_QtGui[51516]
#define sipNameNr_united 51523
#define sipName_united &sipStrings_QtGui[51523]
#define sipNameNr_update 51530
#define sipName_update &sipStrings_QtGui[51530]
#define sipNameNr_valueF 51537
#define sipName_valueF &sipStrings_QtGui[51537]
#define sipNameNr_vector 51544
#define sipName_vector &sipStrings_QtGui[51544]
#define sipNameNr_violet 41583
#define sipName_violet &sipStrings_QtGui[41583]
#define sipNameNr_weight 51551
#define sipName_weight &sipStrings_QtGui[51551]
#define sipNameNr_widthF 51558
#define sipName_widthF &sipStrings_QtGui[51558]
#define sipNameNr_window 51565
#define sipName_window &sipStrings_QtGui[51565]
#define sipNameNr_yellow 11310
#define sipName_yellow &sipStrings_QtGui[11310]
#define sipNameNr_Alpha 18486
#define sipName_Alpha &sipStrings_QtGui[18486]
#define sipNameNr_AnsiA 51572
#define sipName_AnsiA &sipStrings_QtGui[51572]
#define sipNameNr_AnsiB 51578
#define sipName_AnsiB &sipStrings_QtGui[51578]
#define sipNameNr_AnsiC 51584
#define sipName_AnsiC &sipStrings_QtGui[51584]
#define sipNameNr_AnsiD 51590
#define sipName_AnsiD &sipStrings_QtGui[51590]
#define sipNameNr_AnsiE 51596
#define sipName_AnsiE &sipStrings_QtGui[51596]
#define sipNameNr_ArchA 51602
#define sipName_ArchA &sipStrings_QtGui[51602]
#define sipNameNr_ArchB 51608
#define sipName_ArchB &sipStrings_QtGui[51608]
#define sipNameNr_ArchC 51614
#define sipName_ArchC &sipStrings_QtGui[51614]
#define sipNameNr_ArchD 51620
#define sipName_ArchD &sipStrings_QtGui[51620]
#define sipNameNr_ArchE 51626
#define sipName_ArchE &sipStrings_QtGui[51626]
#define sipNameNr_AtEnd 51632
#define sipName_AtEnd &sipStrings_QtGui[51632]
#define sipNameNr_Black 51638
#define sipName_Black &sipStrings_QtGui[51638]
#define sipNameNr_Clamp 51644
#define sipName_Clamp &sipStrings_QtGui[51644]
#define sipNameNr_Click 51650
#define sipName_Click &sipStrings_QtGui[51650]
#define sipNameNr_Close 37489
#define sipName_Close &sipStrings_QtGui[37489]
#define sipNameNr_Didot 51656
#define sipName_Didot &sipStrings_QtGui[51656]
#define sipNameNr_Drive 51662
#define sipName_Drive &sipStrings_QtGui[51662]
#define sipNameNr_Folio 51668
#define sipName_Folio &sipStrings_QtGui[51668]
#define sipNameNr_Gamma 15223
#define sipName_Gamma &sipStrings_QtGui[15223]
#define sipNameNr_Greek 51674
#define sipName_Greek &sipStrings_QtGui[51674]
#define sipNameNr_Green 43849
#define sipName_Green &sipStrings_QtGui[43849]
#define sipNameNr_Hover 51680
#define sipName_Hover &sipStrings_QtGui[51680]
#define sipNameNr_JisB0 51686
#define sipName_JisB0 &sipStrings_QtGui[51686]
#define sipNameNr_JisB1 51692
#define sipName_JisB1 &sipStrings_QtGui[51692]
#define sipNameNr_JisB2 51698
#define sipName_JisB2 &sipStrings_QtGui[51698]
#define sipNameNr_JisB3 51704
#define sipName_JisB3 &sipStrings_QtGui[51704]
#define sipNameNr_JisB4 51710
#define sipName_JisB4 &sipStrings_QtGui[51710]
#define sipNameNr_JisB5 51716
#define sipName_JisB5 &sipStrings_QtGui[51716]
#define sipNameNr_JisB6 51722
#define sipName_JisB6 &sipStrings_QtGui[51722]
#define sipNameNr_JisB7 51728
#define sipName_JisB7 &sipStrings_QtGui[51728]
#define sipNameNr_JisB8 51734
#define sipName_JisB8 &sipStrings_QtGui[51734]
#define sipNameNr_JisB9 51740
#define sipName_JisB9 &sipStrings_QtGui[51740]
#define sipNameNr_Khmer 51746
#define sipName_Khmer &sipStrings_QtGui[51746]
#define sipNameNr_Latin 51752
#define sipName_Latin &sipStrings_QtGui[51752]
#define sipNameNr_Legal 13893
#define sipName_Legal &sipStrings_QtGui[13893]
#define sipNameNr_LibGL 51758
#define sipName_LibGL &sipStrings_QtGui[51758]
#define sipNameNr_Light 5175
#define sipName_Light &sipStrings_QtGui[5175]
#define sipNameNr_Mouse 40429
#define sipName_Mouse &sipStrings_QtGui[40429]
#define sipNameNr_None_ 51764
#define sipName_None_ &sipStrings_QtGui[51764]
#define sipNameNr_Ogham 51770
#define sipName_Ogham &sipStrings_QtGui[51770]
#define sipNameNr_Oriya 51776
#define sipName_Oriya &sipStrings_QtGui[51776]
#define sipNameNr_Other 51782
#define sipName_Other &sipStrings_QtGui[51782]
#define sipNameNr_Paste 43889
#define sipName_Paste &sipStrings_QtGui[43889]
#define sipNameNr_Phone 51788
#define sipName_Phone &sipStrings_QtGui[51788]
#define sipNameNr_Point 23472
#define sipName_Point &sipStrings_QtGui[23472]
#define sipNameNr_Print 28506
#define sipName_Print &sipStrings_QtGui[28506]
#define sipNameNr_QDrag 51794
#define sipName_QDrag &sipStrings_QtGui[51794]
#define sipNameNr_QFont 51800
#define sipName_QFont &sipStrings_QtGui[51800]
#define sipNameNr_QIcon 51806
#define sipName_QIcon &sipStrings_QtGui[51806]
#define sipNameNr_QMenu 51812
#define sipName_QMenu &sipStrings_QtGui[51812]
#define sipNameNr_Range 6458
#define sipName_Range &sipStrings_QtGui[6458]
#define sipNameNr_Right 13931
#define sipName_Right &sipStrings_QtGui[13931]
#define sipNameNr_Roles 7050
#define sipName_Roles &sipStrings_QtGui[7050]
#define sipNameNr_Runic 51818
#define sipName_Runic &sipStrings_QtGui[51818]
#define sipNameNr_Serif 44479
#define sipName_Serif &sipStrings_QtGui[44479]
#define sipNameNr_Start 14064
#define sipName_Start &sipStrings_QtGui[14064]
#define sipNameNr_State 1504
#define sipName_State &sipStrings_QtGui[1504]
#define sipNameNr_Style 2185
#define sipName_Style &sipStrings_QtGui[2185]
#define sipNameNr_Tamil 51824
#define sipName_Tamil &sipStrings_QtGui[51824]
#define sipNameNr_Times 51830
#define sipName_Times &sipStrings_QtGui[51830]
#define sipNameNr_White 33065
#define sipName_White &sipStrings_QtGui[33065]
#define sipNameNr_XTilt 51836
#define sipName_XTilt &sipStrings_QtGui[51836]
#define sipNameNr_YTilt 51842
#define sipName_YTilt &sipStrings_QtGui[51842]
#define sipNameNr_alert 51848
#define sipName_alert &sipStrings_QtGui[51848]
#define sipNameNr_alpha 51854
#define sipName_alpha &sipStrings_QtGui[51854]
#define sipNameNr_angle 8650
#define sipName_angle &sipStrings_QtGui[8650]
#define sipNameNr_arcTo 51860
#define sipName_arcTo &sipStrings_QtGui[51860]
#define sipNameNr_atEnd 51866
#define sipName_atEnd &sipStrings_QtGui[51866]
#define sipNameNr_azure 51872
#define sipName_azure &sipStrings_QtGui[51872]
#define sipNameNr_begin 51878
#define sipName_begin &sipStrings_QtGui[51878]
#define sipNameNr_beige 51884
#define sipName_beige &sipStrings_QtGui[51884]
#define sipNameNr_black 51890
#define sipName_black &sipStrings_QtGui[51890]
#define sipNameNr_block 51896
#define sipName_block &sipStrings_QtGui[51896]
#define sipNameNr_blue8 51902
#define sipName_blue8 &sipStrings_QtGui[51902]
#define sipNameNr_blueF 51908
#define sipName_blueF &sipStrings_QtGui[51908]
#define sipNameNr_brown 38977
#define sipName_brown &sipStrings_QtGui[38977]
#define sipNameNr_brush 46507
#define sipName_brush &sipStrings_QtGui[46507]
#define sipNameNr_buddy 51914
#define sipName_buddy &sipStrings_QtGui[51914]
#define sipNameNr_child 51920
#define sipName_child &sipStrings_QtGui[51920]
#define sipNameNr_clear 51926
#define sipName_clear &sipStrings_QtGui[51926]
#define sipNameNr_clone 51932
#define sipName_clone &sipStrings_QtGui[51932]
#define sipNameNr_close 51938
#define sipName_close &sipStrings_QtGui[51938]
#define sipNameNr_color 51944
#define sipName_color &sipStrings_QtGui[51944]
#define sipNameNr_coral 42585
#define sipName_coral &sipStrings_QtGui[42585]
#define sipNameNr_count 51950
#define sipName_count &sipStrings_QtGui[51950]
#define sipNameNr_cyanF 51956
#define sipName_cyanF &sipStrings_QtGui[51956]
#define sipNameNr_delim 51962
#define sipName_delim &sipStrings_QtGui[51962]
#define sipNameNr_delta 51968
#define sipName_delta &sipStrings_QtGui[51968]
#define sipNameNr_depth 51974
#define sipName_depth &sipStrings_QtGui[51974]
#define sipNameNr_error 51980
#define sipName_error &sipStrings_QtGui[51980]
#define sipNameNr_event 51986
#define sipName_event &sipStrings_QtGui[51986]
#define sipNameNr_first 51992
#define sipName_first &sipStrings_QtGui[51992]
#define sipNameNr_fixup 51998
#define sipName_fixup &sipStrings_QtGui[51998]
#define sipNameNr_flags 52004
#define sipName_flags &sipStrings_QtGui[52004]
#define sipNameNr_flush 52010
#define sipName_flush &sipStrings_QtGui[52010]
#define sipNameNr_from_ 52016
#define sipName_from_ &sipStrings_QtGui[52016]
#define sipNameNr_gamma 52022
#define sipName_gamma &sipStrings_QtGui[52022]
#define sipNameNr_green 18342
#define sipName_green &sipStrings_QtGui[18342]
#define sipNameNr_hints 52028
#define sipName_hints &sipStrings_QtGui[52028]
#define sipNameNr_hover 52034
#define sipName_hover &sipStrings_QtGui[52034]
#define sipNameNr_image 52040
#define sipName_image &sipStrings_QtGui[52040]
#define sipNameNr_index 52046
#define sipName_index &sipStrings_QtGui[52046]
#define sipNameNr_isDir 52052
#define sipName_isDir &sipStrings_QtGui[52052]
#define sipNameNr_ivory 52058
#define sipName_ivory &sipStrings_QtGui[52058]
#define sipNameNr_khaki 44969
#define sipName_khaki &sipStrings_QtGui[44969]
#define sipNameNr_light 38881
#define sipName_light &sipStrings_QtGui[38881]
#define sipNameNr_linen 52064
#define sipName_linen &sipStrings_QtGui[52064]
#define sipNameNr_lower 52070
#define sipName_lower &sipStrings_QtGui[52070]
#define sipNameNr_match 52076
#define sipName_match &sipStrings_QtGui[52076]
#define sipNameNr_merge 52082
#define sipName_merge &sipStrings_QtGui[52082]
#define sipNameNr_mkdir 52088
#define sipName_mkdir &sipStrings_QtGui[52088]
#define sipNameNr_model 52094
#define sipName_model &sipStrings_QtGui[52094]
#define sipNameNr_nlerp 52100
#define sipName_nlerp &sipStrings_QtGui[52100]
#define sipNameNr_olive 52106
#define sipName_olive &sipStrings_QtGui[52106]
#define sipNameNr_order 9701
#define sipName_order &sipStrings_QtGui[9701]
#define sipNameNr_ortho 52112
#define sipName_ortho &sipStrings_QtGui[52112]
#define sipNameNr_paint 52118
#define sipName_paint &sipStrings_QtGui[52118]
#define sipNameNr_phase 52124
#define sipName_phase &sipStrings_QtGui[52124]
#define sipNameNr_pixel 52130
#define sipName_pixel &sipStrings_QtGui[52130]
#define sipNameNr_point 52136
#define sipName_point &sipStrings_QtGui[52136]
#define sipNameNr_print 52142
#define sipName_print &sipStrings_QtGui[52142]
#define sipNameNr_qBlue 52148
#define sipName_qBlue &sipStrings_QtGui[52148]
#define sipNameNr_qGray 52154
#define sipName_qGray &sipStrings_QtGui[52154]
#define sipNameNr_qRgba 52160
#define sipName_qRgba &sipStrings_QtGui[52160]
#define sipNameNr_reset 17136
#define sipName_reset &sipStrings_QtGui[17136]
#define sipNameNr_rmdir 52166
#define sipName_rmdir &sipStrings_QtGui[52166]
#define sipNameNr_scale 10207
#define sipName_scale &sipStrings_QtGui[10207]
#define sipNameNr_shape 52172
#define sipName_shape &sipStrings_QtGui[52172]
#define sipNameNr_shear 52178
#define sipName_shear &sipStrings_QtGui[52178]
#define sipNameNr_slerp 52184
#define sipName_slerp &sipStrings_QtGui[52184]
#define sipNameNr_speed 52190
#define sipName_speed &sipStrings_QtGui[52190]
#define sipNameNr_start 52196
#define sipName_start &sipStrings_QtGui[52196]
#define sipNameNr_state 24464
#define sipName_state &sipStrings_QtGui[24464]
#define sipNameNr_stops 52202
#define sipName_stops &sipStrings_QtGui[52202]
#define sipNameNr_style 52208
#define sipName_style &sipStrings_QtGui[52208]
#define sipNameNr_title 52214
#define sipName_title &sipStrings_QtGui[52214]
#define sipNameNr_toHsl 52220
#define sipName_toHsl &sipStrings_QtGui[52220]
#define sipNameNr_toHsv 52226
#define sipName_toHsv &sipStrings_QtGui[52226]
#define sipNameNr_toRgb 36865
#define sipName_toRgb &sipStrings_QtGui[36865]
#define sipNameNr_units 52232
#define sipName_units &sipStrings_QtGui[52232]
#define sipNameNr_valid 25544
#define sipName_valid &sipStrings_QtGui[25544]
#define sipNameNr_value 52238
#define sipName_value &sipStrings_QtGui[52238]
#define sipNameNr_wheat 52244
#define sipName_wheat &sipStrings_QtGui[52244]
#define sipNameNr_white 33910
#define sipName_white &sipStrings_QtGui[33910]
#define sipNameNr_width 52250
#define sipName_width &sipStrings_QtGui[52250]
#define sipNameNr_winId 52256
#define sipName_winId &sipStrings_QtGui[52256]
#define sipNameNr_write 52262
#define sipName_write &sipStrings_QtGui[52262]
#define sipNameNr_xTilt 52268
#define sipName_xTilt &sipStrings_QtGui[52268]
#define sipNameNr_xored 52274
#define sipName_xored &sipStrings_QtGui[52274]
#define sipNameNr_yTilt 52280
#define sipName_yTilt &sipStrings_QtGui[52280]
#define sipNameNr_Area 27990
#define sipName_Area &sipStrings_QtGui[27990]
#define sipNameNr_Auto 25890
#define sipName_Auto &sipStrings_QtGui[25890]
#define sipNameNr_Axes 13426
#define sipName_Axes &sipStrings_QtGui[13426]
#define sipNameNr_Axis 17119
#define sipName_Axis &sipStrings_QtGui[17119]
#define sipNameNr_Back 52286
#define sipName_Back &sipStrings_QtGui[52286]
#define sipNameNr_Base 28423
#define sipName_Base &sipStrings_QtGui[28423]
#define sipNameNr_Blue 36794
#define sipName_Blue &sipStrings_QtGui[36794]
#define sipNameNr_Bold 25530
#define sipName_Bold &sipStrings_QtGui[25530]
#define sipNameNr_CMYK 52291
#define sipName_CMYK &sipStrings_QtGui[52291]
#define sipNameNr_Cmyk 20970
#define sipName_Cmyk &sipStrings_QtGui[20970]
#define sipNameNr_Copy 46733
#define sipName_Copy &sipStrings_QtGui[46733]
#define sipNameNr_Cyan 46652
#define sipName_Cyan &sipStrings_QtGui[46652]
#define sipNameNr_Dark 36842
#define sipName_Dark &sipStrings_QtGui[36842]
#define sipNameNr_Down 50412
#define sipName_Down &sipStrings_QtGui[50412]
#define sipNameNr_Edge 22849
#define sipName_Edge &sipStrings_QtGui[22849]
#define sipNameNr_File 34899
#define sipName_File &sipStrings_QtGui[34899]
#define sipNameNr_Find 46742
#define sipName_Find &sipStrings_QtGui[46742]
#define sipNameNr_Flag 999
#define sipName_Flag &sipStrings_QtGui[999]
#define sipNameNr_GoUp 52296
#define sipName_GoUp &sipStrings_QtGui[52296]
#define sipNameNr_Gray 44100
#define sipName_Gray &sipStrings_QtGui[44100]
#define sipNameNr_IMC1 52301
#define sipName_IMC1 &sipStrings_QtGui[52301]
#define sipNameNr_IMC2 52306
#define sipName_IMC2 &sipStrings_QtGui[52306]
#define sipNameNr_IMC3 52311
#define sipName_IMC3 &sipStrings_QtGui[52311]
#define sipNameNr_IMC4 52316
#define sipName_IMC4 &sipStrings_QtGui[52316]
#define sipNameNr_Inch 13286
#define sipName_Inch &sipStrings_QtGui[13286]
#define sipNameNr_Left 16723
#define sipName_Left &sipStrings_QtGui[16723]
#define sipNameNr_Link 40441
#define sipName_Link &sipStrings_QtGui[40441]
#define sipNameNr_Mode 3204
#define sipName_Mode &sipStrings_QtGui[3204]
#define sipNameNr_NV12 52321
#define sipName_NV12 &sipStrings_QtGui[52321]
#define sipNameNr_NV21 52326
#define sipName_NV21 &sipStrings_QtGui[52326]
#define sipNameNr_Name 5904
#define sipName_Name &sipStrings_QtGui[5904]
#define sipNameNr_Nega 52331
#define sipName_Nega &sipStrings_QtGui[52331]
#define sipNameNr_Note 52336
#define sipName_Note &sipStrings_QtGui[52336]
#define sipNameNr_Open 32234
#define sipName_Open &sipStrings_QtGui[32234]
#define sipNameNr_Pica 52341
#define sipName_Pica &sipStrings_QtGui[52341]
#define sipNameNr_Puck 52346
#define sipName_Puck &sipStrings_QtGui[52346]
#define sipNameNr_QPen 52351
#define sipName_QPen &sipStrings_QtGui[52351]
#define sipNameNr_Quit 52356
#define sipName_Quit &sipStrings_QtGui[52356]
#define sipNameNr_Redo 46751
#define sipName_Redo &sipStrings_QtGui[46751]
#define sipNameNr_Ruby 52361
#define sipName_Ruby &sipStrings_QtGui[52361]
#define sipNameNr_SRgb 52366
#define sipName_SRgb &sipStrings_QtGui[52366]
#define sipNameNr_Save 32247
#define sipName_Save &sipStrings_QtGui[32247]
#define sipNameNr_Size 9900
#define sipName_Size &sipStrings_QtGui[9900]
#define sipNameNr_Spec 33209
#define sipName_Spec &sipStrings_QtGui[33209]
#define sipNameNr_Text 11186
#define sipName_Text &sipStrings_QtGui[11186]
#define sipNameNr_Thai 52371
#define sipName_Thai &sipStrings_QtGui[52371]
#define sipNameNr_Thin 52376
#define sipName_Thin &sipStrings_QtGui[52376]
#define sipNameNr_Type 340
#define sipName_Type &sipStrings_QtGui[340]
#define sipNameNr_UYVY 52381
#define sipName_UYVY &sipStrings_QtGui[52381]
#define sipNameNr_Undo 46760
#define sipName_Undo &sipStrings_QtGui[46760]
#define sipNameNr_Unit 17281
#define sipName_Unit &sipStrings_QtGui[17281]
#define sipNameNr_User 48867
#define sipName_User &sipStrings_QtGui[48867]
#define sipNameNr_YUYV 52386
#define sipName_YUYV &sipStrings_QtGui[52386]
#define sipNameNr_YV12 52391
#define sipName_YV12 &sipStrings_QtGui[52391]
#define sipNameNr_aqua 52396
#define sipName_aqua &sipStrings_QtGui[52396]
#define sipNameNr_axis 52401
#define sipName_axis &sipStrings_QtGui[52401]
#define sipNameNr_base 29207
#define sipName_base &sipStrings_QtGui[29207]
#define sipNameNr_bits 52406
#define sipName_bits &sipStrings_QtGui[52406]
#define sipNameNr_blue 23921
#define sipName_blue &sipStrings_QtGui[23921]
#define sipNameNr_bold 52411
#define sipName_bold &sipStrings_QtGui[52411]
#define sipNameNr_clip 52416
#define sipName_clip &sipStrings_QtGui[52416]
#define sipNameNr_copy 52421
#define sipName_copy &sipStrings_QtGui[52421]
#define sipNameNr_cyan 45410
#define sipName_cyan &sipStrings_QtGui[45410]
#define sipNameNr_dark 52426
#define sipName_dark &sipStrings_QtGui[52426]
#define sipNameNr_data 8812
#define sipName_data &sipStrings_QtGui[8812]
#define sipNameNr_draw 52431
#define sipName_draw &sipStrings_QtGui[52431]
#define sipNameNr_edge 52436
#define sipName_edge &sipStrings_QtGui[52436]
#define sipNameNr_exec 52441
#define sipName_exec &sipStrings_QtGui[52441]
#define sipNameNr_file 642
#define sipName_file &sipStrings_QtGui[642]
#define sipNameNr_fill 52446
#define sipName_fill &sipStrings_QtGui[52446]
#define sipNameNr_find 52451
#define sipName_find &sipStrings_QtGui[52451]
#define sipNameNr_flip 52456
#define sipName_flip &sipStrings_QtGui[52456]
#define sipNameNr_font 52461
#define sipName_font &sipStrings_QtGui[52461]
#define sipNameNr_from 52466
#define sipName_from &sipStrings_QtGui[52466]
#define sipNameNr_gold 52471
#define sipName_gold &sipStrings_QtGui[52471]
#define sipNameNr_gray 27090
#define sipName_gray &sipStrings_QtGui[27090]
#define sipNameNr_grey 27105
#define sipName_grey &sipStrings_QtGui[27105]
#define sipNameNr_hide 52476
#define sipName_hide &sipStrings_QtGui[52476]
#define sipNameNr_hotX 52481
#define sipName_hotX &sipStrings_QtGui[52481]
#define sipNameNr_hotY 52486
#define sipName_hotY &sipStrings_QtGui[52486]
#define sipNameNr_href 52491
#define sipName_href &sipStrings_QtGui[52491]
#define sipNameNr_hueF 52496
#define sipName_hueF &sipStrings_QtGui[52496]
#define sipNameNr_icon 52501
#define sipName_icon &sipStrings_QtGui[52501]
#define sipNameNr_item 52506
#define sipName_item &sipStrings_QtGui[52506]
#define sipNameNr_join 52511
#define sipName_join &sipStrings_QtGui[52511]
#define sipNameNr_key2 52516
#define sipName_key2 &sipStrings_QtGui[52516]
#define sipNameNr_key3 52521
#define sipName_key3 &sipStrings_QtGui[52521]
#define sipNameNr_key4 52526
#define sipName_key4 &sipStrings_QtGui[52526]
#define sipNameNr_keys 52531
#define sipName_keys &sipStrings_QtGui[52531]
#define sipNameNr_last 52536
#define sipName_last &sipStrings_QtGui[52536]
#define sipNameNr_lime 52541
#define sipName_lime &sipStrings_QtGui[52541]
#define sipNameNr_link 52546
#define sipName_link &sipStrings_QtGui[52546]
#define sipNameNr_load 52551
#define sipName_load &sipStrings_QtGui[52551]
#define sipNameNr_mask 52556
#define sipName_mask &sipStrings_QtGui[52556]
#define sipNameNr_menu 52561
#define sipName_menu &sipStrings_QtGui[52561]
#define sipNameNr_mode 52566
#define sipName_mode &sipStrings_QtGui[52566]
#define sipNameNr_name 52571
#define sipName_name &sipStrings_QtGui[52571]
#define sipNameNr_navy 52576
#define sipName_navy &sipStrings_QtGui[52576]
#define sipNameNr_next 52581
#define sipName_next &sipStrings_QtGui[52581]
#define sipNameNr_peru 52586
#define sipName_peru &sipStrings_QtGui[52586]
#define sipNameNr_pink 45450
#define sipName_pink &sipStrings_QtGui[45450]
#define sipNameNr_play 33807
#define sipName_play &sipStrings_QtGui[33807]
#define sipNameNr_plum 52591
#define sipName_plum &sipStrings_QtGui[52591]
#define sipNameNr_push 52596
#define sipName_push &sipStrings_QtGui[52596]
#define sipNameNr_qRed 52601
#define sipName_qRed &sipStrings_QtGui[52601]
#define sipNameNr_qRgb 52606
#define sipName_qRgb &sipStrings_QtGui[52606]
#define sipNameNr_read 17155
#define sipName_read &sipStrings_QtGui[17155]
#define sipNameNr_rect 52611
#define sipName_rect &sipStrings_QtGui[52611]
#define sipNameNr_red8 52616
#define sipName_red8 &sipStrings_QtGui[52616]
#define sipNameNr_redF 52621
#define sipName_redF &sipStrings_QtGui[52621]
#define sipNameNr_redo 52626
#define sipName_redo &sipStrings_QtGui[52626]
#define sipNameNr_rgba 52631
#define sipName_rgba &sipStrings_QtGui[52631]
#define sipNameNr_role 52636
#define sipName_role &sipStrings_QtGui[52636]
#define sipNameNr_rows 52641
#define sipName_rows &sipStrings_QtGui[52641]
#define sipNameNr_save 52646
#define sipName_save &sipStrings_QtGui[52646]
#define sipNameNr_setW 52651
#define sipName_setW &sipStrings_QtGui[52651]
#define sipNameNr_setX 52656
#define sipName_setX &sipStrings_QtGui[52656]
#define sipNameNr_setY 52661
#define sipName_setY &sipStrings_QtGui[52661]
#define sipNameNr_setZ 52666
#define sipName_setZ &sipStrings_QtGui[52666]
#define sipNameNr_show 52671
#define sipName_show &sipStrings_QtGui[52671]
#define sipNameNr_size 19117
#define sipName_size &sipStrings_QtGui[19117]
#define sipNameNr_snow 52676
#define sipName_snow &sipStrings_QtGui[52676]
#define sipNameNr_sort 52681
#define sipName_sort &sipStrings_QtGui[52681]
#define sipNameNr_span 52686
#define sipName_span &sipStrings_QtGui[52686]
#define sipNameNr_spec 52691
#define sipName_spec &sipStrings_QtGui[52691]
#define sipNameNr_stop 52696
#define sipName_stop &sipStrings_QtGui[52696]
#define sipNameNr_swap 52701
#define sipName_swap &sipStrings_QtGui[52701]
#define sipNameNr_sync 52706
#define sipName_sync &sipStrings_QtGui[52706]
#define sipNameNr_tabs 52711
#define sipName_tabs &sipStrings_QtGui[52711]
#define sipNameNr_teal 52716
#define sipName_teal &sipStrings_QtGui[52716]
#define sipNameNr_text 177
#define sipName_text &sipStrings_QtGui[177]
#define sipNameNr_type 21327
#define sipName_type &sipStrings_QtGui[21327]
#define sipNameNr_undo 52721
#define sipName_undo &sipStrings_QtGui[52721]
#define sipNameNr_A10 52726
#define sipName_A10 &sipStrings_QtGui[52726]
#define sipNameNr_All 16670
#define sipName_All &sipStrings_QtGui[16670]
#define sipNameNr_Any 52730
#define sipName_Any &sipStrings_QtGui[52730]
#define sipNameNr_B10 50462
#define sipName_B10 &sipStrings_QtGui[50462]
#define sipNameNr_BGR 52734
#define sipName_BGR &sipStrings_QtGui[52734]
#define sipNameNr_C5E 52738
#define sipName_C5E &sipStrings_QtGui[52738]
#define sipNameNr_Cut 48772
#define sipName_Cut &sipStrings_QtGui[48772]
#define sipNameNr_DLE 52742
#define sipName_DLE &sipStrings_QtGui[52742]
#define sipNameNr_End 35355
#define sipName_End &sipStrings_QtGui[35355]
#define sipNameNr_HSL 52746
#define sipName_HSL &sipStrings_QtGui[52746]
#define sipNameNr_HSV 52750
#define sipName_HSV &sipStrings_QtGui[52750]
#define sipNameNr_Hlg 43791
#define sipName_Hlg &sipStrings_QtGui[43791]
#define sipNameNr_Hsl 24306
#define sipName_Hsl &sipStrings_QtGui[24306]
#define sipNameNr_Hsv 24322
#define sipName_Hsv &sipStrings_QtGui[24322]
#define sipNameNr_Key 5437
#define sipName_Key &sipStrings_QtGui[5437]
#define sipNameNr_Lao 52754
#define sipName_Lao &sipStrings_QtGui[52754]
#define sipNameNr_Mid 52758
#define sipName_Mid &sipStrings_QtGui[52758]
#define sipNameNr_New 25201
#define sipName_New &sipStrings_QtGui[25201]
#define sipNameNr_Nko 52762
#define sipName_Nko &sipStrings_QtGui[52762]
#define sipNameNr_Off 52766
#define sipName_Off &sipStrings_QtGui[52766]
#define sipNameNr_Pdf 52770
#define sipName_Pdf &sipStrings_QtGui[52770]
#define sipNameNr_Pen 40794
#define sipName_Pen &sipStrings_QtGui[40794]
#define sipNameNr_RGB 52774
#define sipName_RGB &sipStrings_QtGui[52774]
#define sipNameNr_Red 48756
#define sipName_Red &sipStrings_QtGui[48756]
#define sipNameNr_Rgb 31980
#define sipName_Rgb &sipStrings_QtGui[31980]
#define sipNameNr_SVG 52778
#define sipName_SVG &sipStrings_QtGui[52778]
#define sipNameNr_Svg 10683
#define sipName_Svg &sipStrings_QtGui[10683]
#define sipNameNr_Tab 20223
#define sipName_Tab &sipStrings_QtGui[20223]
#define sipNameNr_Tag 40860
#define sipName_Tag &sipStrings_QtGui[40860]
#define sipNameNr_X11 52782
#define sipName_X11 &sipStrings_QtGui[52782]
#define sipNameNr_Y16 52786
#define sipName_Y16 &sipStrings_QtGui[52786]
#define sipNameNr_YUV 52790
#define sipName_YUV &sipStrings_QtGui[52790]
#define sipNameNr_add 52794
#define sipName_add &sipStrings_QtGui[52794]
#define sipNameNr_cap 52798
#define sipName_cap &sipStrings_QtGui[52798]
#define sipNameNr_end 32261
#define sipName_end &sipStrings_QtGui[32261]
#define sipNameNr_hue 52802
#define sipName_hue &sipStrings_QtGui[52802]
#define sipNameNr_key 52806
#define sipName_key &sipStrings_QtGui[52806]
#define sipNameNr_m11 52810
#define sipName_m11 &sipStrings_QtGui[52810]
#define sipNameNr_m12 52814
#define sipName_m12 &sipStrings_QtGui[52814]
#define sipNameNr_m13 52818
#define sipName_m13 &sipStrings_QtGui[52818]
#define sipNameNr_m21 52822
#define sipName_m21 &sipStrings_QtGui[52822]
#define sipNameNr_m22 52826
#define sipName_m22 &sipStrings_QtGui[52826]
#define sipNameNr_m23 52830
#define sipName_m23 &sipStrings_QtGui[52830]
#define sipNameNr_m31 52834
#define sipName_m31 &sipStrings_QtGui[52834]
#define sipNameNr_m32 52838
#define sipName_m32 &sipStrings_QtGui[52838]
#define sipNameNr_m33 52842
#define sipName_m33 &sipStrings_QtGui[52842]
#define sipNameNr_map 23522
#define sipName_map &sipStrings_QtGui[23522]
#define sipNameNr_mid 52846
#define sipName_mid &sipStrings_QtGui[52846]
#define sipNameNr_pen 32235
#define sipName_pen &sipStrings_QtGui[32235]
#define sipNameNr_pos 52850
#define sipName_pos &sipStrings_QtGui[52850]
#define sipNameNr_red 18182
#define sipName_red &sipStrings_QtGui[18182]
#define sipNameNr_rgb 48812
#define sipName_rgb &sipStrings_QtGui[48812]
#define sipNameNr_row 52854
#define sipName_row &sipStrings_QtGui[52854]
#define sipNameNr_tag 52858
#define sipName_tag &sipStrings_QtGui[52858]
#define sipNameNr_tan 49060
#define sipName_tan &sipStrings_QtGui[49060]
#define sipNameNr_tip 52862
#define sipName_tip &sipStrings_QtGui[52862]
#define sipNameNr_top 1835
#define sipName_top &sipStrings_QtGui[1835]
#define sipNameNr_url 52866
#define sipName_url &sipStrings_QtGui[52866]
#define sipNameNr_A0 52870
#define sipName_A0 &sipStrings_QtGui[52870]
#define sipNameNr_A1 52873
#define sipName_A1 &sipStrings_QtGui[52873]
#define sipNameNr_A2 52876
#define sipName_A2 &sipStrings_QtGui[52876]
#define sipNameNr_A3 52879
#define sipName_A3 &sipStrings_QtGui[52879]
#define sipNameNr_A4 52882
#define sipName_A4 &sipStrings_QtGui[52882]
#define sipNameNr_A5 52885
#define sipName_A5 &sipStrings_QtGui[52885]
#define sipNameNr_A6 52888
#define sipName_A6 &sipStrings_QtGui[52888]
#define sipNameNr_A7 52891
#define sipName_A7 &sipStrings_QtGui[52891]
#define sipNameNr_A8 52894
#define sipName_A8 &sipStrings_QtGui[52894]
#define sipNameNr_A9 52897
#define sipName_A9 &sipStrings_QtGui[52897]
#define sipNameNr_B0 51689
#define sipName_B0 &sipStrings_QtGui[51689]
#define sipNameNr_B1 51695
#define sipName_B1 &sipStrings_QtGui[51695]
#define sipNameNr_B2 51701
#define sipName_B2 &sipStrings_QtGui[51701]
#define sipNameNr_B3 51707
#define sipName_B3 &sipStrings_QtGui[51707]
#define sipNameNr_B4 40102
#define sipName_B4 &sipStrings_QtGui[40102]
#define sipNameNr_B5 40113
#define sipName_B5 &sipStrings_QtGui[40113]
#define sipNameNr_B6 40124
#define sipName_B6 &sipStrings_QtGui[40124]
#define sipNameNr_B7 51731
#define sipName_B7 &sipStrings_QtGui[51731]
#define sipNameNr_B8 51737
#define sipName_B8 &sipStrings_QtGui[51737]
#define sipNameNr_B9 51743
#define sipName_B9 &sipStrings_QtGui[51743]
#define sipNameNr_On 52900
#define sipName_On &sipStrings_QtGui[52900]
#define sipNameNr_Qt 52903
#define sipName_Qt &sipStrings_QtGui[52903]
#define sipNameNr_Up 52298
#define sipName_Up &sipStrings_QtGui[52298]
#define sipNameNr_Y8 52906
#define sipName_Y8 &sipStrings_QtGui[52906]
#define sipNameNr_at 3707
#define sipName_at &sipStrings_QtGui[3707]
#define sipNameNr_dx 52909
#define sipName_dx &sipStrings_QtGui[52909]
#define sipNameNr_dy 51917
#define sipName_dy &sipStrings_QtGui[51917]
#define sipNameNr_id 16491
#define sipName_id &sipStrings_QtGui[16491]
#define sipNameNr_on 381
#define sipName_on &sipStrings_QtGui[381]
#define sipNameNr_sh 4938
#define sipName_sh &sipStrings_QtGui[4938]
#define sipNameNr_sw 52912
#define sipName_sw &sipStrings_QtGui[52912]
#define sipNameNr_sx 52915
#define sipName_sx &sipStrings_QtGui[52915]
#define sipNameNr_sy 48781
#define sipName_sy &sipStrings_QtGui[48781]
#define sipNameNr_to 25892
#define sipName_to &sipStrings_QtGui[25892]
#define sipNameNr_n 382
#define sipName_n &sipStrings_QtGui[382]
#define sipNameNr_w 10580
#define sipName_w &sipStrings_QtGui[10580]
#define sipNameNr_x 11063
#define sipName_x &sipStrings_QtGui[11063]
#define sipNameNr_y 861
#define sipName_y &sipStrings_QtGui[861]
#define sipNameNr_z 52918
#define sipName_z &sipStrings_QtGui[52918]

#define sipMalloc                   sipAPI_QtGui->api_malloc
#define sipFree                     sipAPI_QtGui->api_free
#define sipBuildResult              sipAPI_QtGui->api_build_result
#define sipCallMethod               sipAPI_QtGui->api_call_method
#define sipCallProcedureMethod      sipAPI_QtGui->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtGui->api_call_error_handler
#define sipParseResultEx            sipAPI_QtGui->api_parse_result_ex
#define sipParseResult              sipAPI_QtGui->api_parse_result
#define sipParseArgs                sipAPI_QtGui->api_parse_args
#define sipParseKwdArgs             sipAPI_QtGui->api_parse_kwd_args
#define sipParsePair                sipAPI_QtGui->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtGui->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtGui->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtGui->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtGui->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtGui->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtGui->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtGui->api_add_exception
#define sipNoFunction               sipAPI_QtGui->api_no_function
#define sipNoMethod                 sipAPI_QtGui->api_no_method
#define sipAbstractMethod           sipAPI_QtGui->api_abstract_method
#define sipBadClass                 sipAPI_QtGui->api_bad_class
#define sipBadCatcherResult         sipAPI_QtGui->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtGui->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtGui->api_bad_operator_arg
#define sipTrace                    sipAPI_QtGui->api_trace
#define sipTransferBack             sipAPI_QtGui->api_transfer_back
#define sipTransferTo               sipAPI_QtGui->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtGui->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtGui->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtGui->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtGui->api_voidptr_type
#define sipGetPyObject              sipAPI_QtGui->api_get_pyobject
#define sipGetAddress               sipAPI_QtGui->api_get_address
#define sipGetMixinAddress          sipAPI_QtGui->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtGui->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtGui->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtGui->api_call_hook
#define sipEndThread                sipAPI_QtGui->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtGui->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtGui->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtGui->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtGui->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtGui->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtGui->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtGui->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtGui->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtGui->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtGui->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtGui->api_convert_to_bool
#define sipReleaseType              sipAPI_QtGui->api_release_type
#define sipConvertFromType          sipAPI_QtGui->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtGui->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtGui->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtGui->api_convert_from_enum
#define sipGetState                 sipAPI_QtGui->api_get_state
#define sipExportSymbol             sipAPI_QtGui->api_export_symbol
#define sipImportSymbol             sipAPI_QtGui->api_import_symbol
#define sipFindType                 sipAPI_QtGui->api_find_type
#define sipBytes_AsChar             sipAPI_QtGui->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtGui->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtGui->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtGui->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtGui->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtGui->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtGui->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtGui->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtGui->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtGui->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtGui->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtGui->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtGui->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtGui->api_get_reference
#define sipKeepReference            sipAPI_QtGui->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtGui->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtGui->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtGui->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtGui->api_type_scope
#define sipResolveTypedef           sipAPI_QtGui->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtGui->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtGui->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtGui->api_init_mixin
#define sipExportModule             sipAPI_QtGui->api_export_module
#define sipInitModule               sipAPI_QtGui->api_init_module
#define sipGetInterpreter           sipAPI_QtGui->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtGui->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtGui->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtGui->api_py_type_dict
#define sipPyTypeName               sipAPI_QtGui->api_py_type_name
#define sipGetCFunction             sipAPI_QtGui->api_get_c_function
#define sipGetMethod                sipAPI_QtGui->api_get_method
#define sipFromMethod               sipAPI_QtGui->api_from_method
#define sipGetDate                  sipAPI_QtGui->api_get_date
#define sipFromDate                 sipAPI_QtGui->api_from_date
#define sipGetDateTime              sipAPI_QtGui->api_get_datetime
#define sipFromDateTime             sipAPI_QtGui->api_from_datetime
#define sipGetTime                  sipAPI_QtGui->api_get_time
#define sipFromTime                 sipAPI_QtGui->api_from_time
#define sipIsUserType               sipAPI_QtGui->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtGui->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtGui->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtGui->api_unicode_write
#define sipUnicodeData              sipAPI_QtGui->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtGui->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtGui->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtGui->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtGui->api_is_derived_class
#define sipGetUserObject            sipAPI_QtGui->api_get_user_object
#define sipSetUserObject            sipAPI_QtGui->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtGui->api_register_event_handler
#define sipConvertToArray           sipAPI_QtGui->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtGui->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtGui->api_enable_gc
#define sipPrintObject              sipAPI_QtGui->api_print_object
#define sipLong_AsChar              sipAPI_QtGui->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtGui->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtGui->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtGui->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtGui->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtGui->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtGui->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtGui->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtGui->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtGui->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtGui->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtGui->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtGui->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtGui->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtGui->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtGui->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtGui->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtGui->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtGui->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtGui->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtGui->api_release_type_us
#define sipIsPyMethod               sipAPI_QtGui->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtGui[];

#define sipType_QAbstractFileIconProvider sipExportedTypes_QtGui[0]

#define sipType_QAbstractFileIconProvider_Option sipExportedTypes_QtGui[2]

#define sipType_QAbstractFileIconProvider_IconType sipExportedTypes_QtGui[1]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractFileIconProvider;

#define sipType_QAbstractTextDocumentLayout sipExportedTypes_QtGui[3]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout;

#define sipType_QAbstractTextDocumentLayout_Selection sipExportedTypes_QtGui[5]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout_Selection;

#define sipType_QAbstractTextDocumentLayout_PaintContext sipExportedTypes_QtGui[4]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout_PaintContext;

#define sipType_QTextObjectInterface sipExportedTypes_QtGui[343]

extern sipClassTypeDef sipTypeDef_QtGui_QTextObjectInterface;

#define sipType_QAccessibilityHints sipExportedTypes_QtGui[6]

extern sipClassTypeDef sipTypeDef_QtGui_QAccessibilityHints;

#define sipType_QMenu sipExportedTypes_QtGui[176]

#define sipType_QAction sipExportedTypes_QtGui[7]

#define sipType_QAction_Priority sipExportedTypes_QtGui[10]

#define sipType_QAction_MenuRole sipExportedTypes_QtGui[9]

#define sipType_QAction_ActionEvent sipExportedTypes_QtGui[8]

extern sipClassTypeDef sipTypeDef_QtGui_QAction;

#define sipType_QActionGroup sipExportedTypes_QtGui[12]

#define sipType_QActionGroup_ExclusionPolicy sipExportedTypes_QtGui[13]

extern sipClassTypeDef sipTypeDef_QtGui_QActionGroup;

#define sipType_QBackingStore sipExportedTypes_QtGui[14]

extern sipClassTypeDef sipTypeDef_QtGui_QBackingStore;

#define sipType_QPaintDevice sipExportedTypes_QtGui[203]

#define sipType_QPaintDevice_PaintDeviceMetric sipExportedTypes_QtGui[204]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintDevice;

#define sipType_QPixmap sipExportedTypes_QtGui[240]

extern sipClassTypeDef sipTypeDef_QtGui_QPixmap;

#define sipType_QBitmap sipExportedTypes_QtGui[15]

extern sipClassTypeDef sipTypeDef_QtGui_QBitmap;

#define sipType_QColor sipExportedTypes_QtGui[21]

#define sipType_QColor_NameFormat sipExportedTypes_QtGui[22]

#define sipType_QColor_Spec sipExportedTypes_QtGui[23]

extern sipClassTypeDef sipTypeDef_QtGui_QColor;

#define sipType_QColorConstants sipExportedTypes_QtGui[24]

extern sipClassTypeDef sipTypeDef_QtGui_QColorConstants;

#define sipType_QColorConstants_Svg sipExportedTypes_QtGui[25]

extern sipClassTypeDef sipTypeDef_QtGui_QColorConstants_Svg;

#define sipType_QBrush sipExportedTypes_QtGui[16]

extern sipClassTypeDef sipTypeDef_QtGui_QBrush;

#define sipType_QGradient sipExportedTypes_QtGui[94]

#define sipType_QGradient_Preset sipExportedTypes_QtGui[96]

#define sipType_QGradient_Spread sipExportedTypes_QtGui[97]

#define sipType_QGradient_Type sipExportedTypes_QtGui[98]

#define sipType_QGradient_CoordinateMode sipExportedTypes_QtGui[95]

extern sipClassTypeDef sipTypeDef_QtGui_QGradient;

#define sipType_QLinearGradient sipExportedTypes_QtGui[137]

extern sipClassTypeDef sipTypeDef_QtGui_QLinearGradient;

#define sipType_QRadialGradient sipExportedTypes_QtGui[254]

extern sipClassTypeDef sipTypeDef_QtGui_QRadialGradient;

#define sipType_QConicalGradient sipExportedTypes_QtGui[34]

extern sipClassTypeDef sipTypeDef_QtGui_QConicalGradient;

#define sipType_QClipboard sipExportedTypes_QtGui[18]

#define sipType_QClipboard_Mode sipExportedTypes_QtGui[19]

extern sipClassTypeDef sipTypeDef_QtGui_QClipboard;

#define sipType_QColorSpace sipExportedTypes_QtGui[26]

#define sipType_QColorSpace_TransformModel sipExportedTypes_QtGui[32]

#define sipType_QColorSpace_TransferFunction sipExportedTypes_QtGui[31]

#define sipType_QColorSpace_Primaries sipExportedTypes_QtGui[29]

#define sipType_QColorSpace_NamedColorSpace sipExportedTypes_QtGui[28]

#define sipType_QColorSpace_ColorModel sipExportedTypes_QtGui[27]

extern sipClassTypeDef sipTypeDef_QtGui_QColorSpace;

#define sipType_QColorSpace_PrimaryPoints sipExportedTypes_QtGui[30]

extern sipClassTypeDef sipTypeDef_QtGui_QColorSpace_PrimaryPoints;

#define sipType_QColorTransform sipExportedTypes_QtGui[33]

extern sipClassTypeDef sipTypeDef_QtGui_QColorTransform;

#define sipType_QCursor sipExportedTypes_QtGui[37]

extern sipClassTypeDef sipTypeDef_QtGui_QCursor;

#define sipType_QDesktopServices sipExportedTypes_QtGui[38]

extern sipClassTypeDef sipTypeDef_QtGui_QDesktopServices;

#define sipType_QDrag sipExportedTypes_QtGui[41]

extern sipClassTypeDef sipTypeDef_QtGui_QDrag;

#define sipType_QInputEvent sipExportedTypes_QtGui[124]

extern sipClassTypeDef sipTypeDef_QtGui_QInputEvent;

#define sipType_QKeyEvent sipExportedTypes_QtGui[132]

extern sipClassTypeDef sipTypeDef_QtGui_QKeyEvent;

#define sipType_QFocusEvent sipExportedTypes_QtGui[74]

extern sipClassTypeDef sipTypeDef_QtGui_QFocusEvent;

#define sipType_QPaintEvent sipExportedTypes_QtGui[212]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEvent;

#define sipType_QMoveEvent sipExportedTypes_QtGui[178]

extern sipClassTypeDef sipTypeDef_QtGui_QMoveEvent;

#define sipType_QResizeEvent sipExportedTypes_QtGui[262]

extern sipClassTypeDef sipTypeDef_QtGui_QResizeEvent;

#define sipType_QCloseEvent sipExportedTypes_QtGui[20]

extern sipClassTypeDef sipTypeDef_QtGui_QCloseEvent;

#define sipType_QIconDragEvent sipExportedTypes_QtGui[107]

extern sipClassTypeDef sipTypeDef_QtGui_QIconDragEvent;

#define sipType_QShowEvent sipExportedTypes_QtGui[273]

extern sipClassTypeDef sipTypeDef_QtGui_QShowEvent;

#define sipType_QHideEvent sipExportedTypes_QtGui[101]

extern sipClassTypeDef sipTypeDef_QtGui_QHideEvent;

#define sipType_QContextMenuEvent sipExportedTypes_QtGui[35]

#define sipType_QContextMenuEvent_Reason sipExportedTypes_QtGui[36]

extern sipClassTypeDef sipTypeDef_QtGui_QContextMenuEvent;

#define sipType_QInputMethodEvent sipExportedTypes_QtGui[127]

#define sipType_QInputMethodEvent_AttributeType sipExportedTypes_QtGui[129]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodEvent;

#define sipType_QInputMethodEvent_Attribute sipExportedTypes_QtGui[128]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodEvent_Attribute;

#define sipType_QInputMethodQueryEvent sipExportedTypes_QtGui[130]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodQueryEvent;

#define sipType_QDropEvent sipExportedTypes_QtGui[45]

extern sipClassTypeDef sipTypeDef_QtGui_QDropEvent;

#define sipType_QDragMoveEvent sipExportedTypes_QtGui[44]

extern sipClassTypeDef sipTypeDef_QtGui_QDragMoveEvent;

#define sipType_QDragEnterEvent sipExportedTypes_QtGui[42]

extern sipClassTypeDef sipTypeDef_QtGui_QDragEnterEvent;

#define sipType_QDragLeaveEvent sipExportedTypes_QtGui[43]

extern sipClassTypeDef sipTypeDef_QtGui_QDragLeaveEvent;

#define sipType_QHelpEvent sipExportedTypes_QtGui[100]

extern sipClassTypeDef sipTypeDef_QtGui_QHelpEvent;

#define sipType_QStatusTipEvent sipExportedTypes_QtGui[280]

extern sipClassTypeDef sipTypeDef_QtGui_QStatusTipEvent;

#define sipType_QWhatsThisClickedEvent sipExportedTypes_QtGui[364]

extern sipClassTypeDef sipTypeDef_QtGui_QWhatsThisClickedEvent;

#define sipType_QActionEvent sipExportedTypes_QtGui[11]

extern sipClassTypeDef sipTypeDef_QtGui_QActionEvent;

#define sipType_QFileOpenEvent sipExportedTypes_QtGui[50]

extern sipClassTypeDef sipTypeDef_QtGui_QFileOpenEvent;

#define sipType_QShortcutEvent sipExportedTypes_QtGui[272]

extern sipClassTypeDef sipTypeDef_QtGui_QShortcutEvent;

#define sipType_QWindowStateChangeEvent sipExportedTypes_QtGui[369]

extern sipClassTypeDef sipTypeDef_QtGui_QWindowStateChangeEvent;

#define sipType_QExposeEvent sipExportedTypes_QtGui[49]

extern sipClassTypeDef sipTypeDef_QtGui_QExposeEvent;

#define sipType_QScrollPrepareEvent sipExportedTypes_QtGui[267]

extern sipClassTypeDef sipTypeDef_QtGui_QScrollPrepareEvent;

#define sipType_QScrollEvent sipExportedTypes_QtGui[265]

#define sipType_QScrollEvent_ScrollState sipExportedTypes_QtGui[266]

extern sipClassTypeDef sipTypeDef_QtGui_QScrollEvent;

#define sipType_QPlatformSurfaceEvent sipExportedTypes_QtGui[243]

#define sipType_QPlatformSurfaceEvent_SurfaceEventType sipExportedTypes_QtGui[244]

extern sipClassTypeDef sipTypeDef_QtGui_QPlatformSurfaceEvent;

#define sipType_QPointerEvent sipExportedTypes_QtGui[245]

extern sipClassTypeDef sipTypeDef_QtGui_QPointerEvent;

#define sipType_QSinglePointEvent sipExportedTypes_QtGui[274]

extern sipClassTypeDef sipTypeDef_QtGui_QSinglePointEvent;

#define sipType_QEnterEvent sipExportedTypes_QtGui[46]

extern sipClassTypeDef sipTypeDef_QtGui_QEnterEvent;

#define sipType_QMouseEvent sipExportedTypes_QtGui[177]

extern sipClassTypeDef sipTypeDef_QtGui_QMouseEvent;

#define sipType_QHoverEvent sipExportedTypes_QtGui[102]

extern sipClassTypeDef sipTypeDef_QtGui_QHoverEvent;

#define sipType_QWheelEvent sipExportedTypes_QtGui[365]

extern sipClassTypeDef sipTypeDef_QtGui_QWheelEvent;

#define sipType_QTabletEvent sipExportedTypes_QtGui[291]

extern sipClassTypeDef sipTypeDef_QtGui_QTabletEvent;

#define sipType_QNativeGestureEvent sipExportedTypes_QtGui[182]

extern sipClassTypeDef sipTypeDef_QtGui_QNativeGestureEvent;

#define sipType_QTouchEvent sipExportedTypes_QtGui[353]

extern sipClassTypeDef sipTypeDef_QtGui_QTouchEvent;

#define sipType_QChildWindowEvent sipExportedTypes_QtGui[17]

extern sipClassTypeDef sipTypeDef_QtGui_QChildWindowEvent;

#define sipType_QEventPoint sipExportedTypes_QtGui[47]

#define sipType_QEventPoint_State sipExportedTypes_QtGui[48]

extern sipClassTypeDef sipTypeDef_QtGui_QEventPoint;

#define sipType_QFileSystemModel sipExportedTypes_QtGui[51]

#define sipType_QFileSystemModel_Option sipExportedTypes_QtGui[52]

#define sipType_QFileSystemModel_Roles sipExportedTypes_QtGui[53]

extern sipClassTypeDef sipTypeDef_QtGui_QFileSystemModel;

#define sipType_QFont sipExportedTypes_QtGui[75]

#define sipType_QFont_HintingPreference sipExportedTypes_QtGui[77]

#define sipType_QFont_SpacingType sipExportedTypes_QtGui[78]

#define sipType_QFont_Capitalization sipExportedTypes_QtGui[76]

#define sipType_QFont_Stretch sipExportedTypes_QtGui[79]

#define sipType_QFont_Style sipExportedTypes_QtGui[80]

#define sipType_QFont_Weight sipExportedTypes_QtGui[84]

#define sipType_QFont_StyleStrategy sipExportedTypes_QtGui[82]

#define sipType_QFont_StyleHint sipExportedTypes_QtGui[81]

extern sipClassTypeDef sipTypeDef_QtGui_QFont;

#define sipType_QFont_Tag sipExportedTypes_QtGui[83]

extern sipClassTypeDef sipTypeDef_QtGui_QFont_Tag;

#define sipType_QFontDatabase sipExportedTypes_QtGui[85]

#define sipType_QFontDatabase_SystemFont sipExportedTypes_QtGui[86]

#define sipType_QFontDatabase_WritingSystem sipExportedTypes_QtGui[87]

extern sipClassTypeDef sipTypeDef_QtGui_QFontDatabase;

#define sipType_QFontInfo sipExportedTypes_QtGui[88]

extern sipClassTypeDef sipTypeDef_QtGui_QFontInfo;

#define sipType_QFontMetrics sipExportedTypes_QtGui[89]

extern sipClassTypeDef sipTypeDef_QtGui_QFontMetrics;

#define sipType_QFontMetricsF sipExportedTypes_QtGui[90]

extern sipClassTypeDef sipTypeDef_QtGui_QFontMetricsF;

#define sipType_QFontVariableAxis sipExportedTypes_QtGui[91]

extern sipClassTypeDef sipTypeDef_QtGui_QFontVariableAxis;

#define sipType_QMatrix4x3 sipExportedTypes_QtGui[174]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x3;

#define sipType_QMatrix4x2 sipExportedTypes_QtGui[173]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x2;

#define sipType_QMatrix3x4 sipExportedTypes_QtGui[172]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x4;

#define sipType_QMatrix3x3 sipExportedTypes_QtGui[171]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x3;

#define sipType_QMatrix3x2 sipExportedTypes_QtGui[170]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x2;

#define sipType_QMatrix2x4 sipExportedTypes_QtGui[169]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x4;

#define sipType_QMatrix2x3 sipExportedTypes_QtGui[168]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x3;

#define sipType_QMatrix2x2 sipExportedTypes_QtGui[167]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x2;

#define sipType_QGlyphRun sipExportedTypes_QtGui[92]

#define sipType_QGlyphRun_GlyphRunFlag sipExportedTypes_QtGui[93]

extern sipClassTypeDef sipTypeDef_QtGui_QGlyphRun;

#define sipType_QGuiApplication sipExportedTypes_QtGui[99]

extern sipClassTypeDef sipTypeDef_QtGui_QGuiApplication;

#define sipType_QIcon sipExportedTypes_QtGui[103]

#define sipType_QIcon_ThemeIcon sipExportedTypes_QtGui[106]

#define sipType_QIcon_State sipExportedTypes_QtGui[105]

#define sipType_QIcon_Mode sipExportedTypes_QtGui[104]

extern sipClassTypeDef sipTypeDef_QtGui_QIcon;

#define sipType_QIconEngine sipExportedTypes_QtGui[108]

#define sipType_QIconEngine_IconEngineHook sipExportedTypes_QtGui[109]

extern sipClassTypeDef sipTypeDef_QtGui_QIconEngine;

#define sipType_QIconEngine_ScaledPixmapArgument sipExportedTypes_QtGui[110]

extern sipClassTypeDef sipTypeDef_QtGui_QIconEngine_ScaledPixmapArgument;

#define sipType_QImage sipExportedTypes_QtGui[111]

#define sipType_QImage_Format sipExportedTypes_QtGui[112]

#define sipType_QImage_InvertMode sipExportedTypes_QtGui[113]

extern sipClassTypeDef sipTypeDef_QtGui_QImage;

#define sipType_QImageIOHandler sipExportedTypes_QtGui[114]

#define sipType_QImageIOHandler_Transformation sipExportedTypes_QtGui[116]

#define sipType_QImageIOHandler_ImageOption sipExportedTypes_QtGui[115]

extern sipClassTypeDef sipTypeDef_QtGui_QImageIOHandler;

#define sipType_QImageReader sipExportedTypes_QtGui[117]

#define sipType_QImageReader_ImageReaderError sipExportedTypes_QtGui[118]

extern sipClassTypeDef sipTypeDef_QtGui_QImageReader;

#define sipType_QImageWriter sipExportedTypes_QtGui[119]

#define sipType_QImageWriter_ImageWriterError sipExportedTypes_QtGui[120]

extern sipClassTypeDef sipTypeDef_QtGui_QImageWriter;

#define sipType_QInputDevice sipExportedTypes_QtGui[121]

#define sipType_QInputDevice_Capability sipExportedTypes_QtGui[122]

#define sipType_QInputDevice_DeviceType sipExportedTypes_QtGui[123]

extern sipClassTypeDef sipTypeDef_QtGui_QInputDevice;

#define sipType_QInputMethod sipExportedTypes_QtGui[125]

#define sipType_QInputMethod_Action sipExportedTypes_QtGui[126]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethod;

#define sipType_QKeySequence sipExportedTypes_QtGui[133]

#define sipType_QKeySequence_StandardKey sipExportedTypes_QtGui[136]

#define sipType_QKeySequence_SequenceMatch sipExportedTypes_QtGui[135]

#define sipType_QKeySequence_SequenceFormat sipExportedTypes_QtGui[134]

extern sipClassTypeDef sipTypeDef_QtGui_QKeySequence;

#define sipType_QMatrix4x4 sipExportedTypes_QtGui[175]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x4;

#define sipType_QMovie sipExportedTypes_QtGui[179]

#define sipType_QMovie_CacheMode sipExportedTypes_QtGui[180]

#define sipType_QMovie_MovieState sipExportedTypes_QtGui[181]

extern sipClassTypeDef sipTypeDef_QtGui_QMovie;

#define sipType_QSurface sipExportedTypes_QtGui[282]

#define sipType_QSurface_SurfaceType sipExportedTypes_QtGui[284]

#define sipType_QSurface_SurfaceClass sipExportedTypes_QtGui[283]

extern sipClassTypeDef sipTypeDef_QtGui_QSurface;

#define sipType_QOffscreenSurface sipExportedTypes_QtGui[186]

extern sipClassTypeDef sipTypeDef_QtGui_QOffscreenSurface;

#define sipType_QOpenGLContextGroup sipExportedTypes_QtGui[189]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLContextGroup;

#define sipType_QOpenGLContext sipExportedTypes_QtGui[187]

#define sipType_QOpenGLContext_OpenGLModuleType sipExportedTypes_QtGui[188]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLContext;

#define sipType_QPagedPaintDevice sipExportedTypes_QtGui[201]

#define sipType_QPagedPaintDevice_PdfVersion sipExportedTypes_QtGui[202]

extern sipClassTypeDef sipTypeDef_QtGui_QPagedPaintDevice;

#define sipType_QPageLayout sipExportedTypes_QtGui[190]

#define sipType_QPageLayout_OutOfBoundsPolicy sipExportedTypes_QtGui[193]

#define sipType_QPageLayout_Mode sipExportedTypes_QtGui[191]

#define sipType_QPageLayout_Orientation sipExportedTypes_QtGui[192]

#define sipType_QPageLayout_Unit sipExportedTypes_QtGui[194]

extern sipClassTypeDef sipTypeDef_QtGui_QPageLayout;

#define sipType_QPageRanges sipExportedTypes_QtGui[195]

extern sipClassTypeDef sipTypeDef_QtGui_QPageRanges;

#define sipType_QPageRanges_Range sipExportedTypes_QtGui[196]

extern sipClassTypeDef sipTypeDef_QtGui_QPageRanges_Range;

#define sipType_QPageSize sipExportedTypes_QtGui[197]

#define sipType_QPageSize_SizeMatchPolicy sipExportedTypes_QtGui[199]

#define sipType_QPageSize_Unit sipExportedTypes_QtGui[200]

#define sipType_QPageSize_PageSizeId sipExportedTypes_QtGui[198]

extern sipClassTypeDef sipTypeDef_QtGui_QPageSize;

#define sipType_QWindow sipExportedTypes_QtGui[366]

#define sipType_QWindow_Visibility sipExportedTypes_QtGui[368]

#define sipType_QWindow_AncestorMode sipExportedTypes_QtGui[367]

extern sipClassTypeDef sipTypeDef_QtGui_QWindow;

#define sipType_QPaintDeviceWindow sipExportedTypes_QtGui[205]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintDeviceWindow;

#define sipType_QTextItem sipExportedTypes_QtGui[328]

#define sipType_QTextItem_RenderFlag sipExportedTypes_QtGui[329]

extern sipClassTypeDef sipTypeDef_QtGui_QTextItem;

#define sipType_QPaintEngine sipExportedTypes_QtGui[206]

#define sipType_QPaintEngine_Type sipExportedTypes_QtGui[210]

#define sipType_QPaintEngine_PolygonDrawMode sipExportedTypes_QtGui[209]

#define sipType_QPaintEngine_DirtyFlag sipExportedTypes_QtGui[207]

#define sipType_QPaintEngine_PaintEngineFeature sipExportedTypes_QtGui[208]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngine;

#define sipType_QPaintEngineState sipExportedTypes_QtGui[211]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngineState;

#define sipType_QPainter sipExportedTypes_QtGui[213]

#define sipType_QPainter_PixmapFragmentHint sipExportedTypes_QtGui[216]

#define sipType_QPainter_CompositionMode sipExportedTypes_QtGui[214]

#define sipType_QPainter_RenderHint sipExportedTypes_QtGui[217]

extern sipClassTypeDef sipTypeDef_QtGui_QPainter;

#define sipType_QPainter_PixmapFragment sipExportedTypes_QtGui[215]

extern sipClassTypeDef sipTypeDef_QtGui_QPainter_PixmapFragment;

#define sipType_QPainterPath sipExportedTypes_QtGui[218]

#define sipType_QPainterPath_ElementType sipExportedTypes_QtGui[220]

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPath;

#define sipType_QPainterPath_Element sipExportedTypes_QtGui[219]

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPath_Element;

#define sipType_QPainterPathStroker sipExportedTypes_QtGui[221]

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPathStroker;

#define sipType_QPainterStateGuard sipExportedTypes_QtGui[222]

#define sipType_QPainterStateGuard_InitialState sipExportedTypes_QtGui[223]

extern sipClassTypeDef sipTypeDef_QtGui_QPainterStateGuard;

#define sipType_QPalette sipExportedTypes_QtGui[224]

#define sipType_QPalette_ColorRole sipExportedTypes_QtGui[226]

#define sipType_QPalette_ColorGroup sipExportedTypes_QtGui[225]

extern sipClassTypeDef sipTypeDef_QtGui_QPalette;

#define sipType_QPdfOutputIntent sipExportedTypes_QtGui[227]

extern sipClassTypeDef sipTypeDef_QtGui_QPdfOutputIntent;

#define sipType_QPdfWriter sipExportedTypes_QtGui[228]

#define sipType_QPdfWriter_ColorModel sipExportedTypes_QtGui[229]

extern sipClassTypeDef sipTypeDef_QtGui_QPdfWriter;

#define sipType_QPen sipExportedTypes_QtGui[230]

extern sipClassTypeDef sipTypeDef_QtGui_QPen;

#define sipType_QPicture sipExportedTypes_QtGui[231]

extern sipClassTypeDef sipTypeDef_QtGui_QPicture;

#define sipType_QPixelFormat sipExportedTypes_QtGui[232]

#define sipType_QPixelFormat_ByteOrder sipExportedTypes_QtGui[236]

#define sipType_QPixelFormat_YUVLayout sipExportedTypes_QtGui[239]

#define sipType_QPixelFormat_TypeInterpretation sipExportedTypes_QtGui[238]

#define sipType_QPixelFormat_AlphaPremultiplied sipExportedTypes_QtGui[234]

#define sipType_QPixelFormat_AlphaPosition sipExportedTypes_QtGui[233]

#define sipType_QPixelFormat_AlphaUsage sipExportedTypes_QtGui[235]

#define sipType_QPixelFormat_ColorModel sipExportedTypes_QtGui[237]

extern sipClassTypeDef sipTypeDef_QtGui_QPixelFormat;

#define sipType_QPixmapCache sipExportedTypes_QtGui[241]

extern sipClassTypeDef sipTypeDef_QtGui_QPixmapCache;

#define sipType_QPixmapCache_Key sipExportedTypes_QtGui[242]

extern sipClassTypeDef sipTypeDef_QtGui_QPixmapCache_Key;

#define sipType_QPointingDeviceUniqueId sipExportedTypes_QtGui[248]

extern sipClassTypeDef sipTypeDef_QtGui_QPointingDeviceUniqueId;

#define sipType_QPointingDevice sipExportedTypes_QtGui[246]

#define sipType_QPointingDevice_PointerType sipExportedTypes_QtGui[247]

extern sipClassTypeDef sipTypeDef_QtGui_QPointingDevice;

#define sipType_QPolygon sipExportedTypes_QtGui[249]

extern sipClassTypeDef sipTypeDef_QtGui_QPolygon;

#define sipType_QPolygonF sipExportedTypes_QtGui[250]

extern sipClassTypeDef sipTypeDef_QtGui_QPolygonF;

#define sipType_QQuaternion sipExportedTypes_QtGui[251]

extern sipClassTypeDef sipTypeDef_QtGui_QQuaternion;

#define sipType_QQuaternion_Axis sipExportedTypes_QtGui[253]

extern sipClassTypeDef sipTypeDef_QtGui_QQuaternion_Axis;

#define sipType_QQuaternion_Axes sipExportedTypes_QtGui[252]

extern sipClassTypeDef sipTypeDef_QtGui_QQuaternion_Axes;

#define sipType_QRasterWindow sipExportedTypes_QtGui[255]

extern sipClassTypeDef sipTypeDef_QtGui_QRasterWindow;

#define sipType_QRawFont sipExportedTypes_QtGui[256]

#define sipType_QRawFont_LayoutFlag sipExportedTypes_QtGui[258]

#define sipType_QRawFont_AntialiasingType sipExportedTypes_QtGui[257]

extern sipClassTypeDef sipTypeDef_QtGui_QRawFont;

#define sipType_QRegion sipExportedTypes_QtGui[259]

#define sipType_QRegion_RegionType sipExportedTypes_QtGui[260]

extern sipClassTypeDef sipTypeDef_QtGui_QRegion;

#define sipType_QRgba64 sipExportedTypes_QtGui[263]

extern sipClassTypeDef sipTypeDef_QtGui_QRgba64;

#define sipType_QScreen sipExportedTypes_QtGui[264]

extern sipClassTypeDef sipTypeDef_QtGui_QScreen;

#define sipType_QSessionManager sipExportedTypes_QtGui[268]

#define sipType_QSessionManager_RestartHint sipExportedTypes_QtGui[269]

extern sipClassTypeDef sipTypeDef_QtGui_QSessionManager;

#define sipType_QShortcut sipExportedTypes_QtGui[271]

extern sipClassTypeDef sipTypeDef_QtGui_QShortcut;

#define sipType_QStandardItemModel sipExportedTypes_QtGui[277]

extern sipClassTypeDef sipTypeDef_QtGui_QStandardItemModel;

#define sipType_QStandardItem sipExportedTypes_QtGui[275]

#define sipType_QStandardItem_ItemType sipExportedTypes_QtGui[276]

extern sipClassTypeDef sipTypeDef_QtGui_QStandardItem;

#define sipType_QStaticText sipExportedTypes_QtGui[278]

#define sipType_QStaticText_PerformanceHint sipExportedTypes_QtGui[279]

extern sipClassTypeDef sipTypeDef_QtGui_QStaticText;

#define sipType_QStyleHints sipExportedTypes_QtGui[281]

extern sipClassTypeDef sipTypeDef_QtGui_QStyleHints;

#define sipType_QSurfaceFormat sipExportedTypes_QtGui[285]

#define sipType_QSurfaceFormat_OpenGLContextProfile sipExportedTypes_QtGui[287]

#define sipType_QSurfaceFormat_RenderableType sipExportedTypes_QtGui[288]

#define sipType_QSurfaceFormat_SwapBehavior sipExportedTypes_QtGui[289]

#define sipType_QSurfaceFormat_FormatOption sipExportedTypes_QtGui[286]

extern sipClassTypeDef sipTypeDef_QtGui_QSurfaceFormat;

#define sipType_QSyntaxHighlighter sipExportedTypes_QtGui[290]

extern sipClassTypeDef sipTypeDef_QtGui_QSyntaxHighlighter;

#define sipType_QTextCursor sipExportedTypes_QtGui[303]

#define sipType_QTextCursor_SelectionType sipExportedTypes_QtGui[306]

#define sipType_QTextCursor_MoveOperation sipExportedTypes_QtGui[305]

#define sipType_QTextCursor_MoveMode sipExportedTypes_QtGui[304]

extern sipClassTypeDef sipTypeDef_QtGui_QTextCursor;


extern sipClassTypeDef sipTypeDef_QtGui_Qt;

#define sipType_QTextDocument sipExportedTypes_QtGui[307]

#define sipType_QTextDocument_MarkdownFeature sipExportedTypes_QtGui[309]

#define sipType_QTextDocument_Stacks sipExportedTypes_QtGui[312]

#define sipType_QTextDocument_ResourceType sipExportedTypes_QtGui[311]

#define sipType_QTextDocument_FindFlag sipExportedTypes_QtGui[308]

#define sipType_QTextDocument_MetaInformation sipExportedTypes_QtGui[310]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocument;

#define sipType_QTextDocumentFragment sipExportedTypes_QtGui[313]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocumentFragment;

#define sipType_QTextDocumentWriter sipExportedTypes_QtGui[314]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocumentWriter;

#define sipType_QTextLength sipExportedTypes_QtGui[334]

#define sipType_QTextLength_Type sipExportedTypes_QtGui[335]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLength;

#define sipType_QTextFormat sipExportedTypes_QtGui[315]

#define sipType_QTextFormat_Property sipExportedTypes_QtGui[319]

#define sipType_QTextFormat_PageBreakFlag sipExportedTypes_QtGui[318]

#define sipType_QTextFormat_ObjectTypes sipExportedTypes_QtGui[317]

#define sipType_QTextFormat_FormatType sipExportedTypes_QtGui[316]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFormat;

#define sipType_QTextCharFormat sipExportedTypes_QtGui[299]

#define sipType_QTextCharFormat_FontPropertiesInheritanceBehavior sipExportedTypes_QtGui[300]

#define sipType_QTextCharFormat_UnderlineStyle sipExportedTypes_QtGui[301]

#define sipType_QTextCharFormat_VerticalAlignment sipExportedTypes_QtGui[302]

extern sipClassTypeDef sipTypeDef_QtGui_QTextCharFormat;

#define sipType_QTextBlockFormat sipExportedTypes_QtGui[294]

#define sipType_QTextBlockFormat_MarkerType sipExportedTypes_QtGui[296]

#define sipType_QTextBlockFormat_LineHeightTypes sipExportedTypes_QtGui[295]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockFormat;

#define sipType_QTextListFormat sipExportedTypes_QtGui[340]

#define sipType_QTextListFormat_Style sipExportedTypes_QtGui[341]

extern sipClassTypeDef sipTypeDef_QtGui_QTextListFormat;

#define sipType_QTextImageFormat sipExportedTypes_QtGui[326]

extern sipClassTypeDef sipTypeDef_QtGui_QTextImageFormat;

#define sipType_QTextFrameFormat sipExportedTypes_QtGui[323]

#define sipType_QTextFrameFormat_BorderStyle sipExportedTypes_QtGui[324]

#define sipType_QTextFrameFormat_Position sipExportedTypes_QtGui[325]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrameFormat;

#define sipType_QTextTableFormat sipExportedTypes_QtGui[352]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableFormat;

#define sipType_QTextTableCellFormat sipExportedTypes_QtGui[351]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableCellFormat;

#define sipType_QTextInlineObject sipExportedTypes_QtGui[327]

extern sipClassTypeDef sipTypeDef_QtGui_QTextInlineObject;

#define sipType_QTextLayout sipExportedTypes_QtGui[330]

#define sipType_QTextLayout_GlyphRunRetrievalFlag sipExportedTypes_QtGui[333]

#define sipType_QTextLayout_CursorMode sipExportedTypes_QtGui[331]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLayout;

#define sipType_QTextLayout_FormatRange sipExportedTypes_QtGui[332]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLayout_FormatRange;

#define sipType_QTextLine sipExportedTypes_QtGui[336]

#define sipType_QTextLine_CursorPosition sipExportedTypes_QtGui[337]

#define sipType_QTextLine_Edge sipExportedTypes_QtGui[338]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLine;

#define sipType_QTextObject sipExportedTypes_QtGui[342]

extern sipClassTypeDef sipTypeDef_QtGui_QTextObject;

#define sipType_QTextBlockGroup sipExportedTypes_QtGui[297]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockGroup;

#define sipType_QTextList sipExportedTypes_QtGui[339]

extern sipClassTypeDef sipTypeDef_QtGui_QTextList;

#define sipType_QTextFrame sipExportedTypes_QtGui[321]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrame;

#define sipType_QTextFrame_iterator sipExportedTypes_QtGui[322]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrame_iterator;

#define sipType_QTextBlock sipExportedTypes_QtGui[292]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlock;

#define sipType_QTextBlock_iterator sipExportedTypes_QtGui[293]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlock_iterator;

#define sipType_QTextFragment sipExportedTypes_QtGui[320]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFragment;

#define sipType_QTextBlockUserData sipExportedTypes_QtGui[298]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockUserData;

#define sipType_QTextOption sipExportedTypes_QtGui[344]

#define sipType_QTextOption_TabType sipExportedTypes_QtGui[347]

#define sipType_QTextOption_Flag sipExportedTypes_QtGui[345]

#define sipType_QTextOption_WrapMode sipExportedTypes_QtGui[348]

extern sipClassTypeDef sipTypeDef_QtGui_QTextOption;

#define sipType_QTextOption_Tab sipExportedTypes_QtGui[346]

extern sipClassTypeDef sipTypeDef_QtGui_QTextOption_Tab;

#define sipType_QTextTableCell sipExportedTypes_QtGui[350]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableCell;

#define sipType_QTextTable sipExportedTypes_QtGui[349]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTable;

#define sipType_QTransform sipExportedTypes_QtGui[354]

#define sipType_QTransform_TransformationType sipExportedTypes_QtGui[355]

extern sipClassTypeDef sipTypeDef_QtGui_QTransform;

#define sipType_QUndoGroup sipExportedTypes_QtGui[357]

extern sipClassTypeDef sipTypeDef_QtGui_QUndoGroup;

#define sipType_QUndoCommand sipExportedTypes_QtGui[356]

extern sipClassTypeDef sipTypeDef_QtGui_QUndoCommand;

#define sipType_QUndoStack sipExportedTypes_QtGui[358]

extern sipClassTypeDef sipTypeDef_QtGui_QUndoStack;

#define sipType_QValidator sipExportedTypes_QtGui[359]

#define sipType_QValidator_State sipExportedTypes_QtGui[360]

extern sipClassTypeDef sipTypeDef_QtGui_QValidator;

#define sipType_QIntValidator sipExportedTypes_QtGui[131]

extern sipClassTypeDef sipTypeDef_QtGui_QIntValidator;

#define sipType_QDoubleValidator sipExportedTypes_QtGui[39]

#define sipType_QDoubleValidator_Notation sipExportedTypes_QtGui[40]

extern sipClassTypeDef sipTypeDef_QtGui_QDoubleValidator;

#define sipType_QRegularExpressionValidator sipExportedTypes_QtGui[261]

extern sipClassTypeDef sipTypeDef_QtGui_QRegularExpressionValidator;

#define sipType_QVector2D sipExportedTypes_QtGui[361]

extern sipClassTypeDef sipTypeDef_QtGui_QVector2D;

#define sipType_QVector3D sipExportedTypes_QtGui[362]

extern sipClassTypeDef sipTypeDef_QtGui_QVector3D;

#define sipType_QVector4D sipExportedTypes_QtGui[363]

extern sipClassTypeDef sipTypeDef_QtGui_QVector4D;


extern sipClassTypeDef sipTypeDef_QtGui_QNativeInterface;

#define sipType_QNativeInterface_QX11Application sipExportedTypes_QtGui[185]

extern sipClassTypeDef sipTypeDef_QtGui_QNativeInterface_QX11Application;

#define sipType_QNativeInterface_QWaylandApplication sipExportedTypes_QtGui[184]

extern sipClassTypeDef sipTypeDef_QtGui_QNativeInterface_QWaylandApplication;

#define sipType_QList_0101QUndoStack sipExportedTypes_QtGui[162]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QUndoStack;

#define sipType_QList_0101QTextFrame sipExportedTypes_QtGui[158]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QTextFrame;

#define sipType_QList_0100QTextBlock sipExportedTypes_QtGui[156]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextBlock;

#define sipType_QList_0100QGlyphRun sipExportedTypes_QtGui[144]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QGlyphRun;

#define sipType_QList_0100QTextLayout_FormatRange sipExportedTypes_QtGui[159]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextLayout_FormatRange;

#define sipType_QList_0100QTextOption_Tab sipExportedTypes_QtGui[161]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextOption_Tab;

#define sipType_QMap_0100QFont_Tag_2200 sipExportedTypes_QtGui[165]

extern sipMappedTypeDef sipTypeDef_QtGui_QMap_0100QFont_Tag_2200;

#define sipType_QMap_0100QFont_Tag_1900 sipExportedTypes_QtGui[166]

extern sipMappedTypeDef sipTypeDef_QtGui_QMap_0100QFont_Tag_1900;

#define sipType_QList_0100QTextLength sipExportedTypes_QtGui[160]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextLength;

#define sipType_QList_0100QTextFormat sipExportedTypes_QtGui[157]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextFormat;

#define sipType_QList_0101QStandardItem sipExportedTypes_QtGui[155]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QStandardItem;

#define sipType_QList_0100QRect sipExportedTypes_QtGui[152]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QRect;

#define sipType_QList_0100QPoint sipExportedTypes_QtGui[150]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QPoint;

#define sipType_QList_0100QPolygonF sipExportedTypes_QtGui[151]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QPolygonF;

#define sipType_QList_0100QPageRanges_Range sipExportedTypes_QtGui[149]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QPageRanges_Range;

#define sipType_QSet_0100QByteArray sipExportedTypes_QtGui[270]

extern sipMappedTypeDef sipTypeDef_QtGui_QSet_0100QByteArray;

#define sipType_QList_0101QOpenGLContext sipExportedTypes_QtGui[148]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QOpenGLContext;

#define sipType_QList_0111QInputDevice sipExportedTypes_QtGui[145]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0111QInputDevice;

#define sipType_QList_0100QSize sipExportedTypes_QtGui[154]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QSize;

#define sipType_QList_0101QScreen sipExportedTypes_QtGui[153]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QScreen;

#define sipType_QList_0100QFontVariableAxis sipExportedTypes_QtGui[143]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QFontVariableAxis;

#define sipType_std_optional_0100QFont_Tag sipExportedTypes_QtGui[371]

extern sipMappedTypeDef sipTypeDef_QtGui_std_optional_0100QFont_Tag;

#define sipType_QList_0100QFont_Tag sipExportedTypes_QtGui[141]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QFont_Tag;

#define sipType_QList_0100QEventPoint sipExportedTypes_QtGui[140]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QEventPoint;

#define sipType_QList_0100QInputMethodEvent_Attribute sipExportedTypes_QtGui[146]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QInputMethodEvent_Attribute;

#define sipType_QList_0101QAction sipExportedTypes_QtGui[139]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QAction;

#define sipType_QList_0100QKeySequence sipExportedTypes_QtGui[147]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QKeySequence;

#define sipType_QList_0100QAbstractTextDocumentLayout_Selection sipExportedTypes_QtGui[138]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QAbstractTextDocumentLayout_Selection;

#define sipType_QList_0101QWindow sipExportedTypes_QtGui[163]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QWindow;

#define sipType_QFlags_0100QTextOption_Flag sipExportedTypes_QtGui[73]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QTextOption_Flag;

#define sipType_QFlags_0100QTextLayout_GlyphRunRetrievalFlag sipExportedTypes_QtGui[72]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QTextLayout_GlyphRunRetrievalFlag;

#define sipType_QFlags_0100QTextItem_RenderFlag sipExportedTypes_QtGui[71]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QTextItem_RenderFlag;

#define sipType_QFlags_0100QTextFormat_PageBreakFlag sipExportedTypes_QtGui[70]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QTextFormat_PageBreakFlag;

#define sipType_QFlags_0100QTextDocument_MarkdownFeature sipExportedTypes_QtGui[69]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QTextDocument_MarkdownFeature;

#define sipType_QFlags_0100QTextDocument_FindFlag sipExportedTypes_QtGui[68]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QTextDocument_FindFlag;

#define sipType_QFlags_0100QSurfaceFormat_FormatOption sipExportedTypes_QtGui[67]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QSurfaceFormat_FormatOption;

#define sipType_QFlags_0100QRawFont_LayoutFlag sipExportedTypes_QtGui[66]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QRawFont_LayoutFlag;

#define sipType_QFlags_0100QPointingDevice_PointerType sipExportedTypes_QtGui[65]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QPointingDevice_PointerType;

#define sipType_QFlags_0100QPainter_RenderHint sipExportedTypes_QtGui[64]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QPainter_RenderHint;

#define sipType_QFlags_0100QPainter_PixmapFragmentHint sipExportedTypes_QtGui[63]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QPainter_PixmapFragmentHint;

#define sipType_QFlags_0100QPaintEngine_PaintEngineFeature sipExportedTypes_QtGui[62]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QPaintEngine_PaintEngineFeature;

#define sipType_QFlags_0100QPaintEngine_DirtyFlag sipExportedTypes_QtGui[61]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QPaintEngine_DirtyFlag;

#define sipType_QFlags_0100QInputDevice_DeviceType sipExportedTypes_QtGui[60]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QInputDevice_DeviceType;

#define sipType_QFlags_0100QInputDevice_Capability sipExportedTypes_QtGui[59]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QInputDevice_Capability;

#define sipType_QFlags_0100QImageIOHandler_Transformation sipExportedTypes_QtGui[58]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QImageIOHandler_Transformation;

#define sipType_QList_0600std_pair_2400_0100QColor sipExportedTypes_QtGui[164]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0600std_pair_2400_0100QColor;

#define sipType_QFlags_0100QGlyphRun_GlyphRunFlag sipExportedTypes_QtGui[57]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QGlyphRun_GlyphRunFlag;

#define sipType_QFlags_0100QFileSystemModel_Option sipExportedTypes_QtGui[56]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QFileSystemModel_Option;

#define sipType_QFlags_0100QEventPoint_State sipExportedTypes_QtGui[55]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QEventPoint_State;

#define sipType_QFlags_0100QAbstractFileIconProvider_Option sipExportedTypes_QtGui[54]

extern sipMappedTypeDef sipTypeDef_QtGui_QFlags_0100QAbstractFileIconProvider_Option;

#define sipType_QList_0100QFontDatabase_WritingSystem sipExportedTypes_QtGui[142]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QFontDatabase_WritingSystem;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtGui;
extern sipExportedModuleDef sipModuleAPI_QtGui;
extern sipTypeDef *sipExportedTypes_QtGui[];

#if !defined(sipType_Qt)
#define sipType_Qt sipImportedTypes_QtGui_QtCore[69].it_td
#endif

#define sipType_Qt_ContrastPreference sipImportedTypes_QtGui_QtCore[79].it_td

#define sipType_Qt_ContextMenuTrigger sipImportedTypes_QtGui_QtCore[78].it_td

#define sipType_Qt_ColorScheme sipImportedTypes_QtGui_QtCore[77].it_td

#define sipType_Qt_HighDpiScaleFactorRoundingPolicy sipImportedTypes_QtGui_QtCore[86].it_td

#define sipType_Qt_TabFocusBehavior sipImportedTypes_QtGui_QtCore[103].it_td

#define sipType_Qt_MouseEventSource sipImportedTypes_QtGui_QtCore[92].it_td

#define sipType_Qt_ScrollPhase sipImportedTypes_QtGui_QtCore[99].it_td

#define sipType_Qt_NativeGestureType sipImportedTypes_QtGui_QtCore[93].it_td

#define sipType_Qt_ApplicationState sipImportedTypes_QtGui_QtCore[70].it_td

#define sipType_Qt_HitTestAccuracy sipImportedTypes_QtGui_QtCore[87].it_td

#define sipType_Qt_WhiteSpaceMode sipImportedTypes_QtGui_QtCore[107].it_td

#define sipType_Qt_ScreenOrientation sipImportedTypes_QtGui_QtCore[98].it_td

#define sipType_Qt_CursorMoveStyle sipImportedTypes_QtGui_QtCore[80].it_td

#define sipType_Qt_SizeMode sipImportedTypes_QtGui_QtCore[101].it_td

#define sipType_Qt_Axis sipImportedTypes_QtGui_QtCore[72].it_td

#define sipType_Qt_MaskMode sipImportedTypes_QtGui_QtCore[90].it_td

#define sipType_Qt_WindowModality sipImportedTypes_QtGui_QtCore[108].it_td

#define sipType_Qt_CheckState sipImportedTypes_QtGui_QtCore[75].it_td

#define sipType_Qt_DropAction sipImportedTypes_QtGui_QtCore[82].it_td

#define sipType_Qt_LayoutDirection sipImportedTypes_QtGui_QtCore[89].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtGui_QtCore[88].it_td

#define sipType_Qt_FocusReason sipImportedTypes_QtGui_QtCore[84].it_td

#define sipType_Qt_TransformationMode sipImportedTypes_QtGui_QtCore[106].it_td

#define sipType_Qt_ClipOperation sipImportedTypes_QtGui_QtCore[76].it_td

#define sipType_Qt_FillRule sipImportedTypes_QtGui_QtCore[83].it_td

#define sipType_Qt_ShortcutContext sipImportedTypes_QtGui_QtCore[100].it_td

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtGui_QtCore[71].it_td

#define sipType_Qt_TextFormat sipImportedTypes_QtGui_QtCore[105].it_td

#define sipType_Qt_CursorShape sipImportedTypes_QtGui_QtCore[81].it_td

#define sipType_Qt_BrushStyle sipImportedTypes_QtGui_QtCore[74].it_td

#define sipType_Qt_PenJoinStyle sipImportedTypes_QtGui_QtCore[96].it_td

#define sipType_Qt_PenCapStyle sipImportedTypes_QtGui_QtCore[95].it_td

#define sipType_Qt_PenStyle sipImportedTypes_QtGui_QtCore[97].it_td

#define sipType_Qt_BGMode sipImportedTypes_QtGui_QtCore[73].it_td

#define sipType_Qt_WindowState sipImportedTypes_QtGui_QtCore[109].it_td

#define sipType_Qt_WindowType sipImportedTypes_QtGui_QtCore[110].it_td

#define sipType_Qt_TextElideMode sipImportedTypes_QtGui_QtCore[104].it_td

#define sipType_Qt_SortOrder sipImportedTypes_QtGui_QtCore[102].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtGui_QtCore[94].it_td

#define sipType_Qt_MouseButton sipImportedTypes_QtGui_QtCore[91].it_td

#define sipType_Qt_GlobalColor sipImportedTypes_QtGui_QtCore[85].it_td

#define sipType_QKeyCombination sipImportedTypes_QtGui_QtCore[32].it_td

#define sipType_QObject sipImportedTypes_QtGui_QtCore[53].it_td

#define sipType_QModelIndex sipImportedTypes_QtGui_QtCore[50].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtGui_QtCore[0].it_td

#define sipType_QModelRoleDataSpan sipImportedTypes_QtGui_QtCore[51].it_td

#define sipType_QIODevice sipImportedTypes_QtGui_QtCore[31].it_td

#define sipType_QByteArray sipImportedTypes_QtGui_QtCore[2].it_td

#define sipType_QChar sipImportedTypes_QtGui_QtCore[3].it_td

#define sipType_QChar_Script sipImportedTypes_QtGui_QtCore[4].it_td

#define sipType_QCoreApplication sipImportedTypes_QtGui_QtCore[6].it_td

#define sipType_QEvent sipImportedTypes_QtGui_QtCore[10].it_td

#define sipType_QEvent_Type sipImportedTypes_QtGui_QtCore[11].it_td

#define sipType_QTimerEvent sipImportedTypes_QtGui_QtCore[65].it_td

#define sipType_QChildEvent sipImportedTypes_QtGui_QtCore[5].it_td

#define sipType_QDataStream sipImportedTypes_QtGui_QtCore[7].it_td

#define sipType_QDateTime sipImportedTypes_QtGui_QtCore[8].it_td

#define sipType_QDir sipImportedTypes_QtGui_QtCore[9].it_td

#define sipType_QFile sipImportedTypes_QtGui_QtCore[12].it_td

#define sipType_QFileInfo sipImportedTypes_QtGui_QtCore[13].it_td

#define sipType_QLine sipImportedTypes_QtGui_QtCore[33].it_td

#define sipType_QLineF sipImportedTypes_QtGui_QtCore[34].it_td

#define sipType_QLocale sipImportedTypes_QtGui_QtCore[44].it_td

#define sipType_QMargins sipImportedTypes_QtGui_QtCore[46].it_td

#define sipType_QMarginsF sipImportedTypes_QtGui_QtCore[47].it_td

#define sipType_QMetaMethod sipImportedTypes_QtGui_QtCore[48].it_td

#define sipType_QMimeData sipImportedTypes_QtGui_QtCore[49].it_td

#define sipType_QPoint sipImportedTypes_QtGui_QtCore[54].it_td

#define sipType_QPointF sipImportedTypes_QtGui_QtCore[55].it_td

#define sipType_QRect sipImportedTypes_QtGui_QtCore[56].it_td

#define sipType_QRectF sipImportedTypes_QtGui_QtCore[57].it_td

#define sipType_QRegularExpression sipImportedTypes_QtGui_QtCore[58].it_td

#define sipType_QSize sipImportedTypes_QtGui_QtCore[59].it_td

#define sipType_QSizeF sipImportedTypes_QtGui_QtCore[60].it_td

#define sipType_QTimeZone sipImportedTypes_QtGui_QtCore[64].it_td

#define sipType_QUrl sipImportedTypes_QtGui_QtCore[66].it_td

#define sipType_QUuid sipImportedTypes_QtGui_QtCore[67].it_td

#define sipType_QVariant sipImportedTypes_QtGui_QtCore[68].it_td

#if !defined(sipType_QNativeInterface)
#define sipType_QNativeInterface sipImportedTypes_QtGui_QtCore[52].it_td
#endif

#define sipType_QList_0100QPointF sipImportedTypes_QtGui_QtCore[38].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtGui_QtCore[30].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtGui_QtCore[45].it_td

#define sipType_QList_0100QByteArray sipImportedTypes_QtGui_QtCore[35].it_td

#define sipType_QFlags_0100Qt_WindowState sipImportedTypes_QtGui_QtCore[28].it_td

#define sipType_QFlags_0100Qt_WindowType sipImportedTypes_QtGui_QtCore[29].it_td

#define sipType_QFlags_0100Qt_Orientation sipImportedTypes_QtGui_QtCore[27].it_td

#define sipType_QFlags_0100Qt_MouseEventFlag sipImportedTypes_QtGui_QtCore[26].it_td

#define sipType_QFlags_0100Qt_MouseButton sipImportedTypes_QtGui_QtCore[25].it_td

#define sipType_QFlags_0100Qt_MatchFlag sipImportedTypes_QtGui_QtCore[24].it_td

#define sipType_QFlags_0100Qt_KeyboardModifier sipImportedTypes_QtGui_QtCore[23].it_td

#define sipType_QFlags_0100Qt_ItemFlag sipImportedTypes_QtGui_QtCore[22].it_td

#define sipType_QFlags_0100Qt_InputMethodQuery sipImportedTypes_QtGui_QtCore[21].it_td

#define sipType_QFlags_0100Qt_ImageConversionFlag sipImportedTypes_QtGui_QtCore[20].it_td

#define sipType_QFlags_0100Qt_Edge sipImportedTypes_QtGui_QtCore[19].it_td

#define sipType_QFlags_0100Qt_DropAction sipImportedTypes_QtGui_QtCore[18].it_td

#define sipType_QFlags_0100Qt_AlignmentFlag sipImportedTypes_QtGui_QtCore[17].it_td

#define sipType_QList_0101QObject sipImportedTypes_QtGui_QtCore[37].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtGui_QtCore[36].it_td

#define sipType_QFlags_0100QIODeviceBase_OpenModeFlag sipImportedTypes_QtGui_QtCore[16].it_td

#define sipType_QFlags_0100QFileDevice_Permission sipImportedTypes_QtGui_QtCore[15].it_td

#define sipType_QFlags_0100QDir_Filter sipImportedTypes_QtGui_QtCore[14].it_td

#define sipType_QStringList sipImportedTypes_QtGui_QtCore[62].it_td

#define sipType_QList_2400 sipImportedTypes_QtGui_QtCore[40].it_td

#define sipType_QList_3800 sipImportedTypes_QtGui_QtCore[41].it_td

#define sipType_QList_1600 sipImportedTypes_QtGui_QtCore[43].it_td

#define sipType_QList_1900 sipImportedTypes_QtGui_QtCore[42].it_td

#define sipType_QList_1800 sipImportedTypes_QtGui_QtCore[39].it_td

#define sipType_QStringView sipImportedTypes_QtGui_QtCore[63].it_td

#define sipType_std_pair_1800_1800 sipImportedTypes_QtGui_QtCore[113].it_td

#define sipType_QString sipImportedTypes_QtGui_QtCore[61].it_td

#define sipType_QAnyStringView sipImportedTypes_QtGui_QtCore[1].it_td

#define sipType_quintptr sipImportedTypes_QtGui_QtCore[112].it_td

#define sipType_qintptr sipImportedTypes_QtGui_QtCore[111].it_td
extern sipImportedTypeDef sipImportedTypes_QtGui_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtGui_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtGui_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtGui_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtGui_qt_metacast;
#line 175 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
// Used by QFontMetrics and QFontMetricsF.
int *qtgui_tabarray(PyObject *l);
#line 266 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qguiapplication.sip"
// Imports from QtCore.
typedef void (*pyqt6_qtgui_cleanup_qobjects_t)();
extern pyqt6_qtgui_cleanup_qobjects_t pyqt6_qtgui_cleanup_qobjects;

typedef char **(*pyqt6_qtgui_from_argv_list_t)(PyObject *, int &);
extern pyqt6_qtgui_from_argv_list_t pyqt6_qtgui_from_argv_list;

typedef void (*pyqt6_qtgui_update_argv_list_t)(PyObject *, int, char **);
extern pyqt6_qtgui_update_argv_list_t pyqt6_qtgui_update_argv_list;
#line 357 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qimage.sip"
// Helpers for QImage and QPixmap ctors.
const char **QtGui_ListToArray(PyObject *lst);
void QtGui_DeleteArray(const char **arr);

// Imports from QtCore.
typedef void (*pyqt6_qtgui_err_print_t)();
extern pyqt6_qtgui_err_print_t pyqt6_qtgui_err_print;
#line 192 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qmatrix4x4.sip"
// Helpers for the matrix classes.
typedef float PYQT_FLOAT;

sipErrorState qtgui_matrixParseIndex(PyObject *tup, int nr_rows,
        int nr_columns, int *row, int *column);
sipErrorState qtgui_matrixDataFromSequence(PyObject *seq, int nr_values,
        PYQT_FLOAT *values);
sipErrorState qtgui_matrixDataAsList(int nr_values, const PYQT_FLOAT *values,
        PyObject **list);
#line 157 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qshortcut.sip"
// Imports from QtCore.
typedef sipErrorState (*pyqt6_qtgui_get_connection_parts_t)(PyObject *, QObject *, const char *, bool, QObject **, QByteArray &);
extern pyqt6_qtgui_get_connection_parts_t pyqt6_qtgui_get_connection_parts;
#line 252 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextobject.sip"
PyObject *qtgui_wrap_ancestors(QObject *obj, const sipTypeDef *td);
#line 10190 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipAPIQtGui.h"

#endif
