/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtOpenGL.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
#include <qopenglfunctions_4_1_core.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"



class sipQOpenGLFunctions_4_1_Core : public ::QOpenGLFunctions_4_1_Core
{
public:
    sipQOpenGLFunctions_4_1_Core();
    virtual ~sipQOpenGLFunctions_4_1_Core();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool initializeOpenGLFunctions() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQOpenGLFunctions_4_1_Core(const sipQOpenGLFunctions_4_1_Core &);
    sipQOpenGLFunctions_4_1_Core &operator = (const sipQOpenGLFunctions_4_1_Core &);

    char sipPyMethods[1];
};

sipQOpenGLFunctions_4_1_Core::sipQOpenGLFunctions_4_1_Core(): ::QOpenGLFunctions_4_1_Core(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQOpenGLFunctions_4_1_Core::~sipQOpenGLFunctions_4_1_Core()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

bool sipQOpenGLFunctions_4_1_Core::initializeOpenGLFunctions()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_initializeOpenGLFunctions);

    if (!sipMeth)
        return ::QOpenGLFunctions_4_1_Core::initializeOpenGLFunctions();

    extern bool sipVH_QtOpenGL_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtOpenGL_9(sipGILState, sipImportedVirtErrorHandlers_QtOpenGL_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_initializeOpenGLFunctions, "initializeOpenGLFunctions(self) -> bool");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_initializeOpenGLFunctions(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_initializeOpenGLFunctions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QOpenGLFunctions_4_1_Core)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QOpenGLFunctions_4_1_Core::initializeOpenGLFunctions() : sipCpp->initializeOpenGLFunctions());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_initializeOpenGLFunctions, doc_QOpenGLFunctions_4_1_Core_initializeOpenGLFunctions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glViewport, "glViewport(self, x: int, y: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glViewport(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glViewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLsizei a2;
        ::GLsizei a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glViewport(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glViewport, doc_QOpenGLFunctions_4_1_Core_glViewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDepthRange, "glDepthRange(self, nearVal: float, farVal: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDepthRange(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDepthRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glDepthRange(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDepthRange, doc_QOpenGLFunctions_4_1_Core_glDepthRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsEnabled, "glIsEnabled(self, cap: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsEnabled(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsEnabled(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsEnabled, doc_QOpenGLFunctions_4_1_Core_glIsEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetTexLevelParameteriv, "glGetTexLevelParameteriv(self, target: int, level: int, pname: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetTexLevelParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetTexLevelParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        PyObject * a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            int sipIsErr = 0;

#line 40 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLint params[1];
        
        sipCpp->glGetTexLevelParameteriv(a0, a1, a2, params);
        
        a3 = qpyopengl_from_GLint(&sipIsErr, params, 1);
#line 216 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a3;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetTexLevelParameteriv, doc_QOpenGLFunctions_4_1_Core_glGetTexLevelParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetTexLevelParameterfv, "glGetTexLevelParameterfv(self, target: int, level: int, pname: int) -> float");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetTexLevelParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetTexLevelParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        PyObject * a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            int sipIsErr = 0;

#line 49 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLfloat params[1];
        
        sipCpp->glGetTexLevelParameterfv(a0, a1, a2, params);
        
        a3 = qpyopengl_from_GLfloat(&sipIsErr, params, 1);
#line 255 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a3;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetTexLevelParameterfv, doc_QOpenGLFunctions_4_1_Core_glGetTexLevelParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetTexParameteriv, "glGetTexParameteriv(self, target: int, pname: int) -> int|tuple[int, int, int, int]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetTexParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetTexParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 58 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLint params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        #if defined(GL_TEXTURE_SWIZZLE_RGBA) || defined(GL_TEXTURE_BORDER_COLOR)
        #if defined(GL_TEXTURE_SWIZZLE_RGBA)
        case GL_TEXTURE_SWIZZLE_RGBA:
        #endif
        #if defined(GL_TEXTURE_BORDER_COLOR)
        case GL_TEXTURE_BORDER_COLOR:
        #endif
            nr_params = 4;
            break;
        #endif
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetTexParameteriv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 311 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetTexParameteriv, doc_QOpenGLFunctions_4_1_Core_glGetTexParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetTexParameterfv, "glGetTexParameterfv(self, target: int, pname: int) -> float|tuple[float, float, float, float]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetTexParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetTexParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 85 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLfloat params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        #if defined(GL_TEXTURE_SWIZZLE_RGBA) || defined(GL_TEXTURE_BORDER_COLOR)
        #if defined(GL_TEXTURE_SWIZZLE_RGBA)
        case GL_TEXTURE_SWIZZLE_RGBA:
        #endif
        #if defined(GL_TEXTURE_BORDER_COLOR)
        case GL_TEXTURE_BORDER_COLOR:
        #endif
            nr_params = 4;
            break;
        #endif
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetTexParameterfv(a0, a1, params);
        
        a2 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
#line 367 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetTexParameterfv, doc_QOpenGLFunctions_4_1_Core_glGetTexParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetString, "glGetString(self, name: int) -> str");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetString(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            const char*sipRes = 0;

#line 112 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        sipRes = reinterpret_cast<const char *>(sipCpp->glGetString(a0));
#line 399 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipRes == SIP_NULLPTR)
            {
                Py_INCREF(Py_None);
                return Py_None;
            }

            return PyUnicode_DecodeASCII(sipRes, strlen(sipRes), SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetString, doc_QOpenGLFunctions_4_1_Core_glGetString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetIntegerv, "glGetIntegerv(self, pname: int) -> int|tuple[int, ...]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetIntegerv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetIntegerv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 117 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLint fixed_params[16], *params;
        GLint nr_params;
        GLenum query;
        
        nr_params = qpyopengl_get(a0, &query);
        
        if (nr_params == 0)
        {
            sipCpp->glGetIntegerv(query, &nr_params);
            params = new GLint[nr_params];
        }
        else
        {
            params = fixed_params;
        }
        
        sipCpp->glGetIntegerv(a0, params);
        a1 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
        
        if (params != fixed_params)
            delete[] params;
#line 455 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetIntegerv, doc_QOpenGLFunctions_4_1_Core_glGetIntegerv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetFloatv, "glGetFloatv(self, pname: int) -> float|tuple[float, ...]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetFloatv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetFloatv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 142 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLfloat fixed_params[16], *params;
        GLint nr_params;
        GLenum query;
        
        nr_params = qpyopengl_get(a0, &query);
        
        if (nr_params == 0)
        {
            sipCpp->glGetIntegerv(query, &nr_params);
            params = new GLfloat[nr_params];
        }
        else
        {
            params = fixed_params;
        }
        
        sipCpp->glGetFloatv(a0, params);
        a1 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
        
        if (params != fixed_params)
            delete[] params;
#line 508 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetFloatv, doc_QOpenGLFunctions_4_1_Core_glGetFloatv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetError, "glGetError(self) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetError(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp))
        {
            ::GLenum sipRes;

            sipRes = sipCpp->glGetError();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetError, doc_QOpenGLFunctions_4_1_Core_glGetError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetDoublev, "glGetDoublev(self, pname: int) -> float|tuple[float, ...]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetDoublev(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetDoublev(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 168 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLdouble fixed_params[16], *params;
        GLint nr_params;
        GLenum query;
        
        nr_params = qpyopengl_get(a0, &query);
        
        if (nr_params == 0)
        {
            sipCpp->glGetIntegerv(query, &nr_params);
            params = new GLdouble[nr_params];
        }
        else
        {
            params = fixed_params;
        }
        
        sipCpp->glGetDoublev(a0, params);
        a1 = qpyopengl_from_GLdouble(&sipIsErr, params, nr_params);
        
        if (params != fixed_params)
            delete[] params;
#line 587 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetDoublev, doc_QOpenGLFunctions_4_1_Core_glGetDoublev);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetBooleanv, "glGetBooleanv(self, pname: int) -> bool|tuple[bool, ...]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetBooleanv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetBooleanv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 193 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLboolean fixed_params[16], *params;
        GLint nr_params;
        GLenum query;
        
        nr_params = qpyopengl_get(a0, &query);
        
        if (nr_params == 0)
        {
            sipCpp->glGetIntegerv(query, &nr_params);
            params = new GLboolean[nr_params];
        }
        else
        {
            params = fixed_params;
        }
        
        sipCpp->glGetBooleanv(a0, params);
        a1 = qpyopengl_from_GLboolean(&sipIsErr, params, nr_params);
        
        if (params != fixed_params)
            delete[] params;
#line 640 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetBooleanv, doc_QOpenGLFunctions_4_1_Core_glGetBooleanv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glReadPixels, "glReadPixels(self, x: int, y: int, width: int, height: int, format: int, type: int) -> tuple[float, ...]|tuple[int, ...]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glReadPixels(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glReadPixels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLsizei a2;
        ::GLsizei a3;
        ::GLenum a4;
        ::GLenum a5;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiiiuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 218 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        int components;
        
        switch (a4)
        {
            case GL_BGR:
            case GL_RGB:
            {
                components = 3;
                break;
            }
        
            case GL_BGRA:
            case GL_RGBA:
            {
                components = 4;
                break;
            }
        
            case GL_RED:
            case GL_GREEN:
            case GL_BLUE:
            case GL_ALPHA:
            case GL_DEPTH_COMPONENT:
            case GL_STENCIL_INDEX:
            case GL_DEPTH_STENCIL:
            {
                components = 1;
                break;
            }
        
            default:
                components = 0;
        }
        
        Py_ssize_t length = components * a2 * a3;
        
        switch (a5)
        {
            case GL_FLOAT:
            {
                GLfloat *data = new GLfloat[length];
        
                sipCpp->glReadPixels(a0, a1, a2, a3, a4, a5, data);
                sipRes = qpyopengl_from_GLfloat(&sipIsErr, data, length);
                delete [] data;
        
                break;
            }
        
            case GL_INT:
            {
                GLint *data = new GLint[length];
        
                sipCpp->glReadPixels(a0, a1, a2, a3, a4, a5, data);
                sipRes = qpyopengl_from_GLint(&sipIsErr, data, length);
                delete [] data;
        
                break;
            }
        
            case GL_UNSIGNED_INT:
            case GL_UNSIGNED_INT_8_8_8_8:
            case GL_UNSIGNED_INT_8_8_8_8_REV:
            case GL_UNSIGNED_INT_10_10_10_2:
            case GL_UNSIGNED_INT_2_10_10_10_REV:
            case GL_UNSIGNED_INT_24_8:
            case GL_UNSIGNED_INT_10F_11F_11F_REV:
            case GL_UNSIGNED_INT_5_9_9_9_REV:
            {
                GLuint *data = new GLuint[length];
        
                sipCpp->glReadPixels(a0, a1, a2, a3, a4, a5, data);
                sipRes = qpyopengl_from_GLuint(&sipIsErr, data, length);
                delete [] data;
        
                break;
            }
        
            case GL_SHORT:
            case GL_UNSIGNED_SHORT:
            case GL_UNSIGNED_SHORT_5_6_5:
            case GL_UNSIGNED_SHORT_5_6_5_REV:
            case GL_UNSIGNED_SHORT_4_4_4_4:
            case GL_UNSIGNED_SHORT_4_4_4_4_REV:
            case GL_UNSIGNED_SHORT_5_5_5_1:
            case GL_UNSIGNED_SHORT_1_5_5_5_REV:
            case GL_BYTE:
            case GL_UNSIGNED_BYTE:
            case GL_UNSIGNED_BYTE_3_3_2:
            case GL_UNSIGNED_BYTE_2_3_3_REV:
            case GL_HALF_FLOAT:
            case GL_FLOAT_32_UNSIGNED_INT_24_8_REV:
            default:
                sipIsErr = 1;
                PyErr_SetString(PyExc_ValueError, "pixel data format not supported");
        }
#line 773 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glReadPixels, doc_QOpenGLFunctions_4_1_Core_glReadPixels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glReadBuffer, "glReadBuffer(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glReadBuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glReadBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glReadBuffer(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glReadBuffer, doc_QOpenGLFunctions_4_1_Core_glReadBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPixelStorei, "glPixelStorei(self, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPixelStorei(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPixelStorei(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bui", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glPixelStorei(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPixelStorei, doc_QOpenGLFunctions_4_1_Core_glPixelStorei);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPixelStoref, "glPixelStoref(self, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPixelStoref(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPixelStoref(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buf", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glPixelStoref(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPixelStoref, doc_QOpenGLFunctions_4_1_Core_glPixelStoref);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDepthFunc, "glDepthFunc(self, func: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDepthFunc(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDepthFunc(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glDepthFunc(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDepthFunc, doc_QOpenGLFunctions_4_1_Core_glDepthFunc);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glStencilOp, "glStencilOp(self, fail: int, zfail: int, zpass: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilOp(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilOp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLenum a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glStencilOp(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glStencilOp, doc_QOpenGLFunctions_4_1_Core_glStencilOp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glStencilFunc, "glStencilFunc(self, func: int, ref: int, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilFunc(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilFunc(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLuint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glStencilFunc(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glStencilFunc, doc_QOpenGLFunctions_4_1_Core_glStencilFunc);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glLogicOp, "glLogicOp(self, opcode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glLogicOp(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glLogicOp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glLogicOp(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glLogicOp, doc_QOpenGLFunctions_4_1_Core_glLogicOp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBlendFunc, "glBlendFunc(self, sfactor: int, dfactor: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendFunc(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendFunc(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glBlendFunc(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBlendFunc, doc_QOpenGLFunctions_4_1_Core_glBlendFunc);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glFlush, "glFlush(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glFlush(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glFlush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp))
        {
            sipCpp->glFlush();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glFlush, doc_QOpenGLFunctions_4_1_Core_glFlush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glFinish, "glFinish(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glFinish(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glFinish(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp))
        {
            sipCpp->glFinish();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glFinish, doc_QOpenGLFunctions_4_1_Core_glFinish);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glEnable, "glEnable(self, cap: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glEnable(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glEnable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glEnable(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glEnable, doc_QOpenGLFunctions_4_1_Core_glEnable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDisable, "glDisable(self, cap: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDisable(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDisable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glDisable(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDisable, doc_QOpenGLFunctions_4_1_Core_glDisable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDepthMask, "glDepthMask(self, flag: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDepthMask(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDepthMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLboolean a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BM", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glDepthMask(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDepthMask, doc_QOpenGLFunctions_4_1_Core_glDepthMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glColorMask, "glColorMask(self, red: int, green: int, blue: int, alpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glColorMask(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glColorMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLboolean a0;
        ::GLboolean a1;
        ::GLboolean a2;
        ::GLboolean a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BMMMM", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glColorMask(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glColorMask, doc_QOpenGLFunctions_4_1_Core_glColorMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glStencilMask, "glStencilMask(self, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilMask(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glStencilMask(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glStencilMask, doc_QOpenGLFunctions_4_1_Core_glStencilMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glClearDepth, "glClearDepth(self, depth: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glClearDepth(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glClearDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glClearDepth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glClearDepth, doc_QOpenGLFunctions_4_1_Core_glClearDepth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glClearStencil, "glClearStencil(self, s: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glClearStencil(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glClearStencil(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glClearStencil(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glClearStencil, doc_QOpenGLFunctions_4_1_Core_glClearStencil);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glClearColor, "glClearColor(self, red: float, green: float, blue: float, alpha: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glClearColor(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glClearColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glClearColor(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glClearColor, doc_QOpenGLFunctions_4_1_Core_glClearColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glClear, "glClear(self, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glClear(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glClear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLbitfield a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glClear(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glClear, doc_QOpenGLFunctions_4_1_Core_glClear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDrawBuffer, "glDrawBuffer(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawBuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glDrawBuffer(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDrawBuffer, doc_QOpenGLFunctions_4_1_Core_glDrawBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexImage2D, "glTexImage2D(self, target: int, level: int, internalformat: int, width: int, height: int, border: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::GLint a5;
        ::GLenum a6;
        ::GLenum a7;
        PyObject * a8;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8))
        {
            sipErrorState sipError = sipErrorNone;

#line 338 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a8, a7, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexImage2D(a0, a1, a2, a3, a4, a5, a6, a7, array);
#line 1347 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexImage2D, doc_QOpenGLFunctions_4_1_Core_glTexImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexImage1D, "glTexImage1D(self, target: int, level: int, internalformat: int, width: int, border: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLint a4;
        ::GLenum a5;
        ::GLenum a6;
        PyObject * a7;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7))
        {
            sipErrorState sipError = sipErrorNone;

#line 346 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a7, a6, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexImage1D(a0, a1, a2, a3, a4, a5, a6, array);
#line 1395 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexImage1D, doc_QOpenGLFunctions_4_1_Core_glTexImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexParameteriv, "glTexParameteriv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 354 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexParameteriv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 1438 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexParameteriv, doc_QOpenGLFunctions_4_1_Core_glTexParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexParameteri, "glTexParameteri(self, target: int, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexParameteri(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexParameteri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buui", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexParameteri(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexParameteri, doc_QOpenGLFunctions_4_1_Core_glTexParameteri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexParameterfv, "glTexParameterfv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 363 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexParameterfv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 1509 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexParameterfv, doc_QOpenGLFunctions_4_1_Core_glTexParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexParameterf, "glTexParameterf(self, target: int, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexParameterf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexParameterf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuf", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexParameterf(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexParameterf, doc_QOpenGLFunctions_4_1_Core_glTexParameterf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glScissor, "glScissor(self, x: int, y: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glScissor(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glScissor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLsizei a2;
        ::GLsizei a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glScissor(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glScissor, doc_QOpenGLFunctions_4_1_Core_glScissor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPolygonMode, "glPolygonMode(self, face: int, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPolygonMode(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPolygonMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glPolygonMode(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPolygonMode, doc_QOpenGLFunctions_4_1_Core_glPolygonMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPointSize, "glPointSize(self, size: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPointSize(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPointSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glPointSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPointSize, doc_QOpenGLFunctions_4_1_Core_glPointSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glLineWidth, "glLineWidth(self, width: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glLineWidth(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glLineWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glLineWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glLineWidth, doc_QOpenGLFunctions_4_1_Core_glLineWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glHint, "glHint(self, target: int, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glHint(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glHint(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glHint, doc_QOpenGLFunctions_4_1_Core_glHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glFrontFace, "glFrontFace(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glFrontFace(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glFrontFace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glFrontFace(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glFrontFace, doc_QOpenGLFunctions_4_1_Core_glFrontFace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCullFace, "glCullFace(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCullFace(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCullFace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glCullFace(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCullFace, doc_QOpenGLFunctions_4_1_Core_glCullFace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsTexture, "glIsTexture(self, texture: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsTexture(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsTexture(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsTexture, doc_QOpenGLFunctions_4_1_Core_glIsTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGenTextures, "glGenTextures(self, n: int) -> int|tuple[int, ...]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGenTextures(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGenTextures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLuint *params = new GLuint[a0];
        
        sipCpp->glGenTextures(a0, params);
        
        a1 = qpyopengl_from_GLuint(&sipIsErr, params, a0);
        
        delete[] params;
#line 1796 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGenTextures, doc_QOpenGLFunctions_4_1_Core_glGenTextures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDeleteTextures, "glDeleteTextures(self, n: int, textures: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDeleteTextures(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDeleteTextures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 391 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDeleteTextures(a0, reinterpret_cast<const GLuint *>(array));
#line 1833 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDeleteTextures, doc_QOpenGLFunctions_4_1_Core_glDeleteTextures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBindTexture, "glBindTexture(self, target: int, texture: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindTexture(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glBindTexture(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBindTexture, doc_QOpenGLFunctions_4_1_Core_glBindTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexSubImage2D, "glTexSubImage2D(self, target: int, level: int, xoffset: int, yoffset: int, width: int, height: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexSubImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexSubImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLsizei a4;
        ::GLsizei a5;
        ::GLenum a6;
        ::GLenum a7;
        PyObject * a8;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8))
        {
            sipErrorState sipError = sipErrorNone;

#line 401 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a8, a7, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexSubImage2D(a0, a1, a2, a3, a4, a5, a6, a7, array);
#line 1909 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexSubImage2D, doc_QOpenGLFunctions_4_1_Core_glTexSubImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexSubImage1D, "glTexSubImage1D(self, target: int, level: int, xoffset: int, width: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexSubImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexSubImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLenum a4;
        ::GLenum a5;
        PyObject * a6;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6))
        {
            sipErrorState sipError = sipErrorNone;

#line 409 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a6, a5, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexSubImage1D(a0, a1, a2, a3, a4, a5, array);
#line 1956 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexSubImage1D, doc_QOpenGLFunctions_4_1_Core_glTexSubImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCopyTexSubImage2D, "glCopyTexSubImage2D(self, target: int, level: int, xoffset: int, yoffset: int, x: int, y: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCopyTexSubImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCopyTexSubImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLint a5;
        ::GLsizei a6;
        ::GLsizei a7;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiiiiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7))
        {
            sipCpp->glCopyTexSubImage2D(a0, a1, a2, a3, a4, a5, a6, a7);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCopyTexSubImage2D, doc_QOpenGLFunctions_4_1_Core_glCopyTexSubImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCopyTexSubImage1D, "glCopyTexSubImage1D(self, target: int, level: int, xoffset: int, x: int, y: int, width: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCopyTexSubImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCopyTexSubImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLsizei a5;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glCopyTexSubImage1D(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCopyTexSubImage1D, doc_QOpenGLFunctions_4_1_Core_glCopyTexSubImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCopyTexImage2D, "glCopyTexImage2D(self, target: int, level: int, internalformat: int, x: int, y: int, width: int, height: int, border: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCopyTexImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCopyTexImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLint a3;
        ::GLint a4;
        ::GLsizei a5;
        ::GLsizei a6;
        ::GLint a7;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiuiiiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7))
        {
            sipCpp->glCopyTexImage2D(a0, a1, a2, a3, a4, a5, a6, a7);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCopyTexImage2D, doc_QOpenGLFunctions_4_1_Core_glCopyTexImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCopyTexImage1D, "glCopyTexImage1D(self, target: int, level: int, internalformat: int, x: int, y: int, width: int, border: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCopyTexImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCopyTexImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLint a3;
        ::GLint a4;
        ::GLsizei a5;
        ::GLint a6;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiuiiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6))
        {
            sipCpp->glCopyTexImage1D(a0, a1, a2, a3, a4, a5, a6);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCopyTexImage1D, doc_QOpenGLFunctions_4_1_Core_glCopyTexImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPolygonOffset, "glPolygonOffset(self, factor: float, units: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPolygonOffset(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPolygonOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bff", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glPolygonOffset(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPolygonOffset, doc_QOpenGLFunctions_4_1_Core_glPolygonOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDrawElements, "glDrawElements(self, mode: int, count: int, type: int, indices: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawElements(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawElements(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizei a1;
        ::GLenum a2;
        PyObject * a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 422 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a3, a2, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDrawElements(a0, a1, a2, array);
#line 2156 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDrawElements, doc_QOpenGLFunctions_4_1_Core_glDrawElements);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDrawArrays, "glDrawArrays(self, mode: int, first: int, count: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawArrays(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawArrays(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLsizei a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glDrawArrays(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDrawArrays, doc_QOpenGLFunctions_4_1_Core_glDrawArrays);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCopyTexSubImage3D, "glCopyTexSubImage3D(self, target: int, level: int, xoffset: int, yoffset: int, zoffset: int, x: int, y: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCopyTexSubImage3D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCopyTexSubImage3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLint a5;
        ::GLint a6;
        ::GLsizei a7;
        ::GLsizei a8;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiiiiiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8))
        {
            sipCpp->glCopyTexSubImage3D(a0, a1, a2, a3, a4, a5, a6, a7, a8);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCopyTexSubImage3D, doc_QOpenGLFunctions_4_1_Core_glCopyTexSubImage3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexSubImage3D, "glTexSubImage3D(self, target: int, level: int, xoffset: int, yoffset: int, zoffset: int, width: int, height: int, depth: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexSubImage3D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexSubImage3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLsizei a5;
        ::GLsizei a6;
        ::GLsizei a7;
        ::GLenum a8;
        ::GLenum a9;
        PyObject * a10;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8, &a9, &a10))
        {
            sipErrorState sipError = sipErrorNone;

#line 432 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a10, a9, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexSubImage3D(a0, a1, a2, a3, a4, a5, a6, a7, a8, a9, array);
#line 2269 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexSubImage3D, doc_QOpenGLFunctions_4_1_Core_glTexSubImage3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexImage3D, "glTexImage3D(self, target: int, level: int, internalformat: int, width: int, height: int, depth: int, border: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexImage3D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexImage3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::GLsizei a5;
        ::GLint a6;
        ::GLenum a7;
        ::GLenum a8;
        PyObject * a9;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8, &a9))
        {
            sipErrorState sipError = sipErrorNone;

#line 440 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a9, a8, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexImage3D(a0, a1, a2, a3, a4, a5, a6, a7, a8, array);
#line 2319 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexImage3D, doc_QOpenGLFunctions_4_1_Core_glTexImage3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDrawRangeElements, "glDrawRangeElements(self, mode: int, start: int, end: int, count: int, type: int, indices: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawRangeElements(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawRangeElements(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::GLuint a2;
        ::GLsizei a3;
        ::GLenum a4;
        PyObject * a5;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuuiuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipErrorState sipError = sipErrorNone;

#line 448 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a5, a4, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDrawRangeElements(a0, a1, a2, a3, a4, array);
#line 2365 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDrawRangeElements, doc_QOpenGLFunctions_4_1_Core_glDrawRangeElements);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBlendEquation, "glBlendEquation(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendEquation(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendEquation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glBlendEquation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBlendEquation, doc_QOpenGLFunctions_4_1_Core_glBlendEquation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBlendColor, "glBlendColor(self, red: float, green: float, blue: float, alpha: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendColor(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glBlendColor(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBlendColor, doc_QOpenGLFunctions_4_1_Core_glBlendColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage1D, "glCompressedTexSubImage1D(self, target: int, level: int, xoffset: int, width: int, format: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLenum a4;
        ::GLsizei a5;
        PyObject * a6;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiuiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6))
        {
            sipErrorState sipError = sipErrorNone;

#line 458 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a6, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexSubImage1D(a0, a1, a2, a3, a4, a5, array);
#line 2468 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCompressedTexSubImage1D, doc_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage2D, "glCompressedTexSubImage2D(self, target: int, level: int, xoffset: int, yoffset: int, width: int, height: int, format: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLsizei a4;
        ::GLsizei a5;
        ::GLenum a6;
        ::GLsizei a7;
        PyObject * a8;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiuiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8))
        {
            sipErrorState sipError = sipErrorNone;

#line 467 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a8, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexSubImage2D(a0, a1, a2, a3, a4, a5, a6, a7, array);
#line 2518 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCompressedTexSubImage2D, doc_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage3D, "glCompressedTexSubImage3D(self, target: int, level: int, xoffset: int, yoffset: int, zoffset: int, width: int, height: int, depth: int, format: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage3D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLsizei a5;
        ::GLsizei a6;
        ::GLsizei a7;
        ::GLenum a8;
        ::GLsizei a9;
        PyObject * a10;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiiiuiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8, &a9, &a10))
        {
            sipErrorState sipError = sipErrorNone;

#line 476 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a10, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexSubImage3D(a0, a1, a2, a3, a4, a5, a6, a7, a8, a9,
                array);
#line 2571 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCompressedTexSubImage3D, doc_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCompressedTexImage1D, "glCompressedTexImage1D(self, target: int, level: int, internalformat: int, width: int, border: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLsizei a3;
        ::GLint a4;
        ::GLsizei a5;
        PyObject * a6;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiuiiiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6))
        {
            sipErrorState sipError = sipErrorNone;

#line 486 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a6, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexImage1D(a0, a1, a2, a3, a4, a5, array);
#line 2619 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCompressedTexImage1D, doc_QOpenGLFunctions_4_1_Core_glCompressedTexImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCompressedTexImage2D, "glCompressedTexImage2D(self, target: int, level: int, internalformat: int, width: int, height: int, border: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::GLint a5;
        ::GLsizei a6;
        PyObject * a7;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiuiiiiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7))
        {
            sipErrorState sipError = sipErrorNone;

#line 495 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a7, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexImage2D(a0, a1, a2, a3, a4, a5, a6, array);
#line 2668 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCompressedTexImage2D, doc_QOpenGLFunctions_4_1_Core_glCompressedTexImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCompressedTexImage3D, "glCompressedTexImage3D(self, target: int, level: int, internalformat: int, width: int, height: int, depth: int, border: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexImage3D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompressedTexImage3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::GLsizei a5;
        ::GLint a6;
        ::GLsizei a7;
        PyObject * a8;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiuiiiiiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8))
        {
            sipErrorState sipError = sipErrorNone;

#line 504 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a8, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexImage3D(a0, a1, a2, a3, a4, a5, a6, a7, array);
#line 2718 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCompressedTexImage3D, doc_QOpenGLFunctions_4_1_Core_glCompressedTexImage3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glSampleCoverage, "glSampleCoverage(self, value: float, invert: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glSampleCoverage(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glSampleCoverage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLboolean a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BfM", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glSampleCoverage(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glSampleCoverage, doc_QOpenGLFunctions_4_1_Core_glSampleCoverage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glActiveTexture, "glActiveTexture(self, texture: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glActiveTexture(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glActiveTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glActiveTexture(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glActiveTexture, doc_QOpenGLFunctions_4_1_Core_glActiveTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPointParameteriv, "glPointParameteriv(self, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPointParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPointParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 515 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glPointParameteriv(a0, reinterpret_cast<const GLint *>(array));
#line 2813 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPointParameteriv, doc_QOpenGLFunctions_4_1_Core_glPointParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPointParameteri, "glPointParameteri(self, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPointParameteri(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPointParameteri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bui", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glPointParameteri(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPointParameteri, doc_QOpenGLFunctions_4_1_Core_glPointParameteri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPointParameterfv, "glPointParameterfv(self, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPointParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPointParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 524 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glPointParameterfv(a0, reinterpret_cast<const GLfloat *>(array));
#line 2882 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPointParameterfv, doc_QOpenGLFunctions_4_1_Core_glPointParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPointParameterf, "glPointParameterf(self, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPointParameterf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPointParameterf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buf", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glPointParameterf(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPointParameterf, doc_QOpenGLFunctions_4_1_Core_glPointParameterf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBlendFuncSeparate, "glBlendFuncSeparate(self, sfactorRGB: int, dfactorRGB: int, sfactorAlpha: int, dfactorAlpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendFuncSeparate(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendFuncSeparate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLenum a2;
        ::GLenum a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glBlendFuncSeparate(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBlendFuncSeparate, doc_QOpenGLFunctions_4_1_Core_glBlendFuncSeparate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetBufferParameteriv, "glGetBufferParameteriv(self, target: int, pname: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetBufferParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetBufferParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glGetBufferParameteriv(a0, a1, &a2);

            return PyLong_FromLong(a2);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetBufferParameteriv, doc_QOpenGLFunctions_4_1_Core_glGetBufferParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUnmapBuffer, "glUnmapBuffer(self, target: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUnmapBuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUnmapBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glUnmapBuffer(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUnmapBuffer, doc_QOpenGLFunctions_4_1_Core_glUnmapBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBufferSubData, "glBufferSubData(self, target: int, offset: int, size: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBufferSubData(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBufferSubData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLintptr a1;
        ::GLsizeiptr a2;
        PyObject * a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BullP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 536 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array;
        
        if (a3 == Py_None)
            array = 0;
        else
            array = qpyopengl_value_array(&sipError, a3, GL_UNSIGNED_BYTE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glBufferSubData(a0, a1, a2, array);
#line 3041 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBufferSubData, doc_QOpenGLFunctions_4_1_Core_glBufferSubData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBufferData, "glBufferData(self, target: int, size: int, data: PYQT_OPENGL_ARRAY, usage: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBufferData(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBufferData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizeiptr a1;
        PyObject * a2;
        ::GLenum a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BulP0u", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 549 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array;
        
        if (a2 == Py_None)
            array = 0;
        else
            array = qpyopengl_value_array(&sipError, a2, GL_UNSIGNED_BYTE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glBufferData(a0, a1, array, a3);
#line 3090 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBufferData, doc_QOpenGLFunctions_4_1_Core_glBufferData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsBuffer, "glIsBuffer(self, buffer: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsBuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsBuffer(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsBuffer, doc_QOpenGLFunctions_4_1_Core_glIsBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGenBuffers, "glGenBuffers(self, n: int) -> int|tuple[int, ...]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGenBuffers(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGenBuffers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 563 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLuint *params = new GLuint[a0];
        
        sipCpp->glGenBuffers(a0, params);
        
        a1 = qpyopengl_from_GLuint(&sipIsErr, params, a0);
        
        delete[] params;
#line 3162 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGenBuffers, doc_QOpenGLFunctions_4_1_Core_glGenBuffers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDeleteBuffers, "glDeleteBuffers(self, n: int, buffers: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDeleteBuffers(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDeleteBuffers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 574 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDeleteBuffers(a0, reinterpret_cast<const GLuint *>(array));
#line 3199 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDeleteBuffers, doc_QOpenGLFunctions_4_1_Core_glDeleteBuffers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBindBuffer, "glBindBuffer(self, target: int, buffer: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindBuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glBindBuffer(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBindBuffer, doc_QOpenGLFunctions_4_1_Core_glBindBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetQueryiv, "glGetQueryiv(self, target: int, pname: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetQueryiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetQueryiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glGetQueryiv(a0, a1, &a2);

            return PyLong_FromLong(a2);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetQueryiv, doc_QOpenGLFunctions_4_1_Core_glGetQueryiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glEndQuery, "glEndQuery(self, target: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glEndQuery(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glEndQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glEndQuery(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glEndQuery, doc_QOpenGLFunctions_4_1_Core_glEndQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBeginQuery, "glBeginQuery(self, target: int, id: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBeginQuery(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBeginQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glBeginQuery(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBeginQuery, doc_QOpenGLFunctions_4_1_Core_glBeginQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsQuery, "glIsQuery(self, id: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsQuery(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsQuery(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsQuery, doc_QOpenGLFunctions_4_1_Core_glIsQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDeleteQueries, "glDeleteQueries(self, n: int, ids: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDeleteQueries(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDeleteQueries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 588 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDeleteQueries(a0, reinterpret_cast<const GLuint *>(array));
#line 3376 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDeleteQueries, doc_QOpenGLFunctions_4_1_Core_glDeleteQueries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGenQueries, "glGenQueries(self, n: int) -> int|tuple[int, ...]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGenQueries(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGenQueries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 597 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLuint *params = new GLuint[a0];
        
        sipCpp->glGenQueries(a0, params);
        
        a1 = qpyopengl_from_GLuint(&sipIsErr, params, a0);
        
        delete[] params;
#line 3421 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGenQueries, doc_QOpenGLFunctions_4_1_Core_glGenQueries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glVertexAttribPointer, "glVertexAttribPointer(self, index: int, size: int, type: int, normalized: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribPointer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribPointer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLboolean a3;
        ::GLsizei a4;
        PyObject * a5;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiuMiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipErrorState sipError = sipErrorNone;

#line 608 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array_cached(&sipError, a5, a2, sipSelf,
                "VertexAttribPointer", a0);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttribPointer(a0, a1, a2, a3, a4, array);
#line 3462 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glVertexAttribPointer, doc_QOpenGLFunctions_4_1_Core_glVertexAttribPointer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glValidateProgram, "glValidateProgram(self, program: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glValidateProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glValidateProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glValidateProgram(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glValidateProgram, doc_QOpenGLFunctions_4_1_Core_glValidateProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniformMatrix4fv, "glUniformMatrix4fv(self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniformMatrix4fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniformMatrix4fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        ::GLboolean a2;
        PyObject * a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiMP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 618 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a3, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniformMatrix4fv(a0, a1, a2,
                    reinterpret_cast<const GLfloat *>(array));
#line 3533 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniformMatrix4fv, doc_QOpenGLFunctions_4_1_Core_glUniformMatrix4fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniformMatrix3fv, "glUniformMatrix3fv(self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniformMatrix3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniformMatrix3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        ::GLboolean a2;
        PyObject * a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiMP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 627 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a3, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniformMatrix3fv(a0, a1, a2,
                    reinterpret_cast<const GLfloat *>(array));
#line 3578 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniformMatrix3fv, doc_QOpenGLFunctions_4_1_Core_glUniformMatrix3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniformMatrix2fv, "glUniformMatrix2fv(self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniformMatrix2fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniformMatrix2fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        ::GLboolean a2;
        PyObject * a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiMP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 636 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a3, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniformMatrix2fv(a0, a1, a2,
                    reinterpret_cast<const GLfloat *>(array));
#line 3623 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniformMatrix2fv, doc_QOpenGLFunctions_4_1_Core_glUniformMatrix2fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform4iv, "glUniform4iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 645 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform4iv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 3666 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform4iv, doc_QOpenGLFunctions_4_1_Core_glUniform4iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform3iv, "glUniform3iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 653 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform3iv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 3709 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform3iv, doc_QOpenGLFunctions_4_1_Core_glUniform3iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform2iv, "glUniform2iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 661 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform2iv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 3752 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform2iv, doc_QOpenGLFunctions_4_1_Core_glUniform2iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform1iv, "glUniform1iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 669 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform1iv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 3795 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform1iv, doc_QOpenGLFunctions_4_1_Core_glUniform1iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform4fv, "glUniform4fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 677 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform4fv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 3838 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform4fv, doc_QOpenGLFunctions_4_1_Core_glUniform4fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform3fv, "glUniform3fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 685 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform3fv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 3881 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform3fv, doc_QOpenGLFunctions_4_1_Core_glUniform3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform2fv, "glUniform2fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 693 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform2fv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 3924 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform2fv, doc_QOpenGLFunctions_4_1_Core_glUniform2fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform1fv, "glUniform1fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 701 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform1fv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 3967 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform1fv, doc_QOpenGLFunctions_4_1_Core_glUniform1fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform4i, "glUniform4i(self, location: int, v0: int, v1: int, v2: int, v3: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glUniform4i(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform4i, doc_QOpenGLFunctions_4_1_Core_glUniform4i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform3i, "glUniform3i(self, location: int, v0: int, v1: int, v2: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glUniform3i(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform3i, doc_QOpenGLFunctions_4_1_Core_glUniform3i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform2i, "glUniform2i(self, location: int, v0: int, v1: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glUniform2i(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform2i, doc_QOpenGLFunctions_4_1_Core_glUniform2i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform1i, "glUniform1i(self, location: int, v0: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glUniform1i(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform1i, doc_QOpenGLFunctions_4_1_Core_glUniform1i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform4f, "glUniform4f(self, location: int, v0: float, v1: float, v2: float, v3: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::GLfloat a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biffff", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glUniform4f(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform4f, doc_QOpenGLFunctions_4_1_Core_glUniform4f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform3f, "glUniform3f(self, location: int, v0: float, v1: float, v2: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bifff", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glUniform3f(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform3f, doc_QOpenGLFunctions_4_1_Core_glUniform3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform2f, "glUniform2f(self, location: int, v0: float, v1: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biff", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glUniform2f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform2f, doc_QOpenGLFunctions_4_1_Core_glUniform2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform1f, "glUniform1f(self, location: int, v0: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bif", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glUniform1f(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform1f, doc_QOpenGLFunctions_4_1_Core_glUniform1f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUseProgram, "glUseProgram(self, program: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUseProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUseProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glUseProgram(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUseProgram, doc_QOpenGLFunctions_4_1_Core_glUseProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glLinkProgram, "glLinkProgram(self, program: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glLinkProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glLinkProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glLinkProgram(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glLinkProgram, doc_QOpenGLFunctions_4_1_Core_glLinkProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsShader, "glIsShader(self, shader: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsShader(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsShader, doc_QOpenGLFunctions_4_1_Core_glIsShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsProgram, "glIsProgram(self, program: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsProgram(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsProgram, doc_QOpenGLFunctions_4_1_Core_glIsProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetVertexAttribiv, "glGetVertexAttribiv(self, index: int, pname: int) -> int|tuple[int, int, int, int]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetVertexAttribiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetVertexAttribiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 721 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLint params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_CURRENT_VERTEX_ATTRIB:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetVertexAttribiv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 4356 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetVertexAttribiv, doc_QOpenGLFunctions_4_1_Core_glGetVertexAttribiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetVertexAttribfv, "glGetVertexAttribfv(self, index: int, pname: int) -> float|tuple[float, float, float, float]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetVertexAttribfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetVertexAttribfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 741 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLfloat params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_CURRENT_VERTEX_ATTRIB:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetVertexAttribfv(a0, a1, params);
        
        a2 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
#line 4405 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetVertexAttribfv, doc_QOpenGLFunctions_4_1_Core_glGetVertexAttribfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetVertexAttribdv, "glGetVertexAttribdv(self, index: int, pname: int) -> float|tuple[float, float, float, float]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetVertexAttribdv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetVertexAttribdv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 761 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLdouble params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_CURRENT_VERTEX_ATTRIB:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetVertexAttribdv(a0, a1, params);
        
        a2 = qpyopengl_from_GLdouble(&sipIsErr, params, nr_params);
#line 4454 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetVertexAttribdv, doc_QOpenGLFunctions_4_1_Core_glGetVertexAttribdv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetUniformLocation, "glGetUniformLocation(self, program: int, name: str) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetUniformLocation(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetUniformLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        const ::GLchar* a1;
        PyObject *a1Keep;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuAA", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1Keep, &a1))
        {
            ::GLint sipRes;

            sipRes = sipCpp->glGetUniformLocation(a0, a1);
            Py_DECREF(a1Keep);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetUniformLocation, doc_QOpenGLFunctions_4_1_Core_glGetUniformLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetShaderSource, "glGetShaderSource(self, shader: int) -> bytes");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetShaderSource(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetShaderSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 782 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLint bufsize;
        
        sipCpp->glGetShaderiv(a0, GL_SHADER_SOURCE_LENGTH, &bufsize);
        
        if (bufsize > 0)
        {
            GLchar *source = new GLchar[bufsize];
        
            sipCpp->glGetShaderSource(a0, bufsize, 0, source);
            sipRes = PyBytes_FromString(source);
        
            delete[] source;
        }
        else
        {
            sipRes = PyBytes_FromString("");
        }
#line 4532 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetShaderSource, doc_QOpenGLFunctions_4_1_Core_glGetShaderSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetShaderInfoLog, "glGetShaderInfoLog(self, shader: int) -> bytes");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetShaderInfoLog(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetShaderInfoLog(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 803 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLint bufsize;
        
        sipCpp->glGetShaderiv(a0, GL_INFO_LOG_LENGTH, &bufsize);
        
        if (bufsize > 0)
        {
            GLchar *log = new GLchar[bufsize];
        
            sipCpp->glGetShaderInfoLog(a0, bufsize, 0, log);
            sipRes = PyBytes_FromString(log);
        
            delete[] log;
        }
        else
        {
            sipRes = PyBytes_FromString("");
        }
#line 4577 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetShaderInfoLog, doc_QOpenGLFunctions_4_1_Core_glGetShaderInfoLog);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetShaderiv, "glGetShaderiv(self, shader: int, pname: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetShaderiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetShaderiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glGetShaderiv(a0, a1, &a2);

            return PyLong_FromLong(a2);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetShaderiv, doc_QOpenGLFunctions_4_1_Core_glGetShaderiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetProgramInfoLog, "glGetProgramInfoLog(self, program: int) -> bytes");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetProgramInfoLog(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetProgramInfoLog(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 825 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLint bufsize;
        
        sipCpp->glGetProgramiv(a0, GL_INFO_LOG_LENGTH, &bufsize);
        
        if (bufsize > 0)
        {
            GLchar *log = new GLchar[bufsize];
        
            sipCpp->glGetProgramInfoLog(a0, bufsize, 0, log);
            sipRes = PyBytes_FromString(log);
        
            delete[] log;
        }
        else
        {
            sipRes = PyBytes_FromString("");
        }
#line 4649 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetProgramInfoLog, doc_QOpenGLFunctions_4_1_Core_glGetProgramInfoLog);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetProgramiv, "glGetProgramiv(self, program: int, pname: int) -> int|tuple[int, int, int]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetProgramiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetProgramiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 846 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLint params[3];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        #if defined(GL_COMPUTE_LOCAL_WORK_SIZE)
        case GL_COMPUTE_LOCAL_WORK_SIZE:
            nr_params = 3;
            break;
        #endif
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetProgramiv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 4697 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetProgramiv, doc_QOpenGLFunctions_4_1_Core_glGetProgramiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetAttribLocation, "glGetAttribLocation(self, program: int, name: str) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetAttribLocation(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetAttribLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        const ::GLchar* a1;
        PyObject *a1Keep;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuAA", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1Keep, &a1))
        {
            ::GLint sipRes;

            sipRes = sipCpp->glGetAttribLocation(a0, a1);
            Py_DECREF(a1Keep);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetAttribLocation, doc_QOpenGLFunctions_4_1_Core_glGetAttribLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetAttachedShaders, "glGetAttachedShaders(self, program: int) -> tuple[int, ...]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetAttachedShaders(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetAttachedShaders(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 869 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLint nr_shaders;
        
        sipCpp->glGetProgramiv(a0, GL_ATTACHED_SHADERS, &nr_shaders);
        
        if (nr_shaders < 1)
        {
            sipRes = PyTuple_New(0);
        }
        else
        {
            GLuint *shaders = new GLuint[nr_shaders];
        
            sipCpp->glGetAttachedShaders(a0, nr_shaders, 0, shaders);
        
            sipRes = PyTuple_New(nr_shaders);
        
            if (sipRes)
            {
                for (GLint i = 0; i < nr_shaders; ++i)
                {
                    PyObject *itm = PyLong_FromLong(shaders[i]);
                    
                    if (!itm)
                    {
                        Py_DECREF(sipRes);
                        sipRes = 0;
                        break;
                    }
                    
                    PyTuple_SetItem(sipRes, i, itm);
                }
            }
        
            delete[] shaders;
        }
        
        if (!sipRes)
            sipIsErr = 1;
#line 4797 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetAttachedShaders, doc_QOpenGLFunctions_4_1_Core_glGetAttachedShaders);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetActiveUniform, "glGetActiveUniform(self, program: int, index: int) -> tuple[str, int, int]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetActiveUniform(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetActiveUniform(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 911 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLint bufsize;
        
        sipCpp->glGetProgramiv(a0, GL_ACTIVE_UNIFORM_MAX_LENGTH, &bufsize);
        
        GLchar *name = new GLchar[bufsize];
        GLint size;
        GLenum type;
        
        sipCpp->glGetActiveUniform(a0, a1, bufsize, 0, &size, &type, name);
        
        sipRes = Py_BuildValue("siI", name, size, type);
        
        if (!sipRes)
            sipIsErr = 1;
        
        delete[] name;
#line 4846 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetActiveUniform, doc_QOpenGLFunctions_4_1_Core_glGetActiveUniform);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGetActiveAttrib, "glGetActiveAttrib(self, program: int, index: int) -> tuple[str, int, int]");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetActiveAttrib(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGetActiveAttrib(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 931 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        GLint bufsize;
        
        sipCpp->glGetProgramiv(a0, GL_ACTIVE_ATTRIBUTE_MAX_LENGTH, &bufsize);
        
        GLchar *name = new GLchar[bufsize];
        GLint size;
        GLenum type;
        
        sipCpp->glGetActiveAttrib(a0, a1, bufsize, 0, &size, &type, name);
        
        sipRes = Py_BuildValue("siI", name, size, type);
        
        if (!sipRes)
            sipIsErr = 1;
        
        delete[] name;
#line 4895 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGetActiveAttrib, doc_QOpenGLFunctions_4_1_Core_glGetActiveAttrib);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glEnableVertexAttribArray, "glEnableVertexAttribArray(self, index: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glEnableVertexAttribArray(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glEnableVertexAttribArray(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glEnableVertexAttribArray(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glEnableVertexAttribArray, doc_QOpenGLFunctions_4_1_Core_glEnableVertexAttribArray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDisableVertexAttribArray, "glDisableVertexAttribArray(self, index: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDisableVertexAttribArray(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDisableVertexAttribArray(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glDisableVertexAttribArray(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDisableVertexAttribArray, doc_QOpenGLFunctions_4_1_Core_glDisableVertexAttribArray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDetachShader, "glDetachShader(self, program: int, shader: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDetachShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDetachShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glDetachShader(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDetachShader, doc_QOpenGLFunctions_4_1_Core_glDetachShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDeleteShader, "glDeleteShader(self, shader: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDeleteShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDeleteShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glDeleteShader(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDeleteShader, doc_QOpenGLFunctions_4_1_Core_glDeleteShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDeleteProgram, "glDeleteProgram(self, program: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDeleteProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDeleteProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glDeleteProgram(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDeleteProgram, doc_QOpenGLFunctions_4_1_Core_glDeleteProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCreateShader, "glCreateShader(self, type: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCreateShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCreateShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLuint sipRes;

            sipRes = sipCpp->glCreateShader(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCreateShader, doc_QOpenGLFunctions_4_1_Core_glCreateShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCreateProgram, "glCreateProgram(self) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCreateProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCreateProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp))
        {
            ::GLuint sipRes;

            sipRes = sipCpp->glCreateProgram();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCreateProgram, doc_QOpenGLFunctions_4_1_Core_glCreateProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCompileShader, "glCompileShader(self, shader: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompileShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCompileShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glCompileShader(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCompileShader, doc_QOpenGLFunctions_4_1_Core_glCompileShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBindAttribLocation, "glBindAttribLocation(self, program: int, index: int, name: str)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindAttribLocation(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindAttribLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        const ::GLchar* a2;
        PyObject *a2Keep;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuAA", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2Keep, &a2))
        {
            sipCpp->glBindAttribLocation(a0, a1, a2);
            Py_DECREF(a2Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBindAttribLocation, doc_QOpenGLFunctions_4_1_Core_glBindAttribLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glAttachShader, "glAttachShader(self, program: int, shader: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glAttachShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glAttachShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glAttachShader(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glAttachShader, doc_QOpenGLFunctions_4_1_Core_glAttachShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glStencilMaskSeparate, "glStencilMaskSeparate(self, face: int, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilMaskSeparate(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilMaskSeparate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glStencilMaskSeparate(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glStencilMaskSeparate, doc_QOpenGLFunctions_4_1_Core_glStencilMaskSeparate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glStencilFuncSeparate, "glStencilFuncSeparate(self, face: int, func: int, ref: int, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilFuncSeparate(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilFuncSeparate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::GLuint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuiu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glStencilFuncSeparate(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glStencilFuncSeparate, doc_QOpenGLFunctions_4_1_Core_glStencilFuncSeparate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glStencilOpSeparate, "glStencilOpSeparate(self, face: int, sfail: int, dpfail: int, dppass: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilOpSeparate(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glStencilOpSeparate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLenum a2;
        ::GLenum a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glStencilOpSeparate(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glStencilOpSeparate, doc_QOpenGLFunctions_4_1_Core_glStencilOpSeparate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDrawBuffers, "glDrawBuffers(self, n: int, bufs: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawBuffers(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawBuffers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiP0", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 964 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglfunctions_4_1_core.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDrawBuffers(a0, reinterpret_cast<const GLenum *>(array));
#line 5284 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipQtOpenGLQOpenGLFunctions_4_1_Core.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDrawBuffers, doc_QOpenGLFunctions_4_1_Core_glDrawBuffers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBlendEquationSeparate, "glBlendEquationSeparate(self, modeRGB: int, modeAlpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendEquationSeparate(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendEquationSeparate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glBlendEquationSeparate(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBlendEquationSeparate, doc_QOpenGLFunctions_4_1_Core_glBlendEquationSeparate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsVertexArray, "glIsVertexArray(self, array: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsVertexArray(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsVertexArray(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsVertexArray(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsVertexArray, doc_QOpenGLFunctions_4_1_Core_glIsVertexArray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBindVertexArray, "glBindVertexArray(self, array: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindVertexArray(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindVertexArray(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glBindVertexArray(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBindVertexArray, doc_QOpenGLFunctions_4_1_Core_glBindVertexArray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glFramebufferTextureLayer, "glFramebufferTextureLayer(self, target: int, attachment: int, texture: int, level: int, layer: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferTextureLayer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferTextureLayer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLuint a2;
        ::GLint a3;
        ::GLint a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuuii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glFramebufferTextureLayer(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glFramebufferTextureLayer, doc_QOpenGLFunctions_4_1_Core_glFramebufferTextureLayer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glRenderbufferStorageMultisample, "glRenderbufferStorageMultisample(self, target: int, samples: int, internalformat: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glRenderbufferStorageMultisample(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glRenderbufferStorageMultisample(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizei a1;
        ::GLenum a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiuii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glRenderbufferStorageMultisample(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glRenderbufferStorageMultisample, doc_QOpenGLFunctions_4_1_Core_glRenderbufferStorageMultisample);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBlitFramebuffer, "glBlitFramebuffer(self, srcX0: int, srcY0: int, srcX1: int, srcY1: int, dstX0: int, dstY0: int, dstX1: int, dstY1: int, mask: int, filter: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlitFramebuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlitFramebuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLint a5;
        ::GLint a6;
        ::GLint a7;
        ::GLbitfield a8;
        ::GLenum a9;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiiiiiiiuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8, &a9))
        {
            sipCpp->glBlitFramebuffer(a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBlitFramebuffer, doc_QOpenGLFunctions_4_1_Core_glBlitFramebuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glGenerateMipmap, "glGenerateMipmap(self, target: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glGenerateMipmap(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glGenerateMipmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glGenerateMipmap(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glGenerateMipmap, doc_QOpenGLFunctions_4_1_Core_glGenerateMipmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glFramebufferRenderbuffer, "glFramebufferRenderbuffer(self, target: int, attachment: int, renderbuffertarget: int, renderbuffer: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferRenderbuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferRenderbuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLenum a2;
        ::GLuint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glFramebufferRenderbuffer(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glFramebufferRenderbuffer, doc_QOpenGLFunctions_4_1_Core_glFramebufferRenderbuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture3D, "glFramebufferTexture3D(self, target: int, attachment: int, textarget: int, texture: int, level: int, zoffset: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture3D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLenum a2;
        ::GLuint a3;
        ::GLint a4;
        ::GLint a5;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuuuii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glFramebufferTexture3D(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glFramebufferTexture3D, doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture2D, "glFramebufferTexture2D(self, target: int, attachment: int, textarget: int, texture: int, level: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLenum a2;
        ::GLuint a3;
        ::GLint a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuuui", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glFramebufferTexture2D(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glFramebufferTexture2D, doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture1D, "glFramebufferTexture1D(self, target: int, attachment: int, textarget: int, texture: int, level: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLenum a2;
        ::GLuint a3;
        ::GLint a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuuui", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glFramebufferTexture1D(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glFramebufferTexture1D, doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glCheckFramebufferStatus, "glCheckFramebufferStatus(self, target: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glCheckFramebufferStatus(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glCheckFramebufferStatus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLenum sipRes;

            sipRes = sipCpp->glCheckFramebufferStatus(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glCheckFramebufferStatus, doc_QOpenGLFunctions_4_1_Core_glCheckFramebufferStatus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBindFramebuffer, "glBindFramebuffer(self, target: int, framebuffer: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindFramebuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindFramebuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glBindFramebuffer(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBindFramebuffer, doc_QOpenGLFunctions_4_1_Core_glBindFramebuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsFramebuffer, "glIsFramebuffer(self, framebuffer: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsFramebuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsFramebuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsFramebuffer(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsFramebuffer, doc_QOpenGLFunctions_4_1_Core_glIsFramebuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glRenderbufferStorage, "glRenderbufferStorage(self, target: int, internalformat: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glRenderbufferStorage(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glRenderbufferStorage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLsizei a2;
        ::GLsizei a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glRenderbufferStorage(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glRenderbufferStorage, doc_QOpenGLFunctions_4_1_Core_glRenderbufferStorage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBindRenderbuffer, "glBindRenderbuffer(self, target: int, renderbuffer: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindRenderbuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindRenderbuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glBindRenderbuffer(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBindRenderbuffer, doc_QOpenGLFunctions_4_1_Core_glBindRenderbuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsRenderbuffer, "glIsRenderbuffer(self, renderbuffer: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsRenderbuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsRenderbuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsRenderbuffer(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsRenderbuffer, doc_QOpenGLFunctions_4_1_Core_glIsRenderbuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glClearBufferfi, "glClearBufferfi(self, buffer: int, drawbuffer: int, depth: float, stencil: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glClearBufferfi(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glClearBufferfi(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLfloat a2;
        ::GLint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buifi", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glClearBufferfi(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glClearBufferfi, doc_QOpenGLFunctions_4_1_Core_glClearBufferfi);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform4ui, "glUniform4ui(self, location: int, v0: int, v1: int, v2: int, v3: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLuint a1;
        ::GLuint a2;
        ::GLuint a3;
        ::GLuint a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biuuuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glUniform4ui(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform4ui, doc_QOpenGLFunctions_4_1_Core_glUniform4ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform3ui, "glUniform3ui(self, location: int, v0: int, v1: int, v2: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLuint a1;
        ::GLuint a2;
        ::GLuint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biuuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glUniform3ui(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform3ui, doc_QOpenGLFunctions_4_1_Core_glUniform3ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform2ui, "glUniform2ui(self, location: int, v0: int, v1: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLuint a1;
        ::GLuint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glUniform2ui(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform2ui, doc_QOpenGLFunctions_4_1_Core_glUniform2ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform1ui, "glUniform1ui(self, location: int, v0: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glUniform1ui(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform1ui, doc_QOpenGLFunctions_4_1_Core_glUniform1ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glEndConditionalRender, "glEndConditionalRender(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glEndConditionalRender(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glEndConditionalRender(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp))
        {
            sipCpp->glEndConditionalRender();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glEndConditionalRender, doc_QOpenGLFunctions_4_1_Core_glEndConditionalRender);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBeginConditionalRender, "glBeginConditionalRender(self, id: int, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBeginConditionalRender(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBeginConditionalRender(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glBeginConditionalRender(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBeginConditionalRender, doc_QOpenGLFunctions_4_1_Core_glBeginConditionalRender);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glClampColor, "glClampColor(self, target: int, clamp: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glClampColor(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glClampColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glClampColor(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glClampColor, doc_QOpenGLFunctions_4_1_Core_glClampColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBindBufferBase, "glBindBufferBase(self, target: int, index: int, buffer: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindBufferBase(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindBufferBase(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::GLuint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glBindBufferBase(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBindBufferBase, doc_QOpenGLFunctions_4_1_Core_glBindBufferBase);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glEndTransformFeedback, "glEndTransformFeedback(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glEndTransformFeedback(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glEndTransformFeedback(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp))
        {
            sipCpp->glEndTransformFeedback();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glEndTransformFeedback, doc_QOpenGLFunctions_4_1_Core_glEndTransformFeedback);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBeginTransformFeedback, "glBeginTransformFeedback(self, primitiveMode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBeginTransformFeedback(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBeginTransformFeedback(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glBeginTransformFeedback(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBeginTransformFeedback, doc_QOpenGLFunctions_4_1_Core_glBeginTransformFeedback);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsEnabledi, "glIsEnabledi(self, target: int, index: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsEnabledi(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsEnabledi(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsEnabledi(a0, a1);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsEnabledi, doc_QOpenGLFunctions_4_1_Core_glIsEnabledi);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDisablei, "glDisablei(self, target: int, index: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDisablei(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDisablei(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glDisablei(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDisablei, doc_QOpenGLFunctions_4_1_Core_glDisablei);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glEnablei, "glEnablei(self, target: int, index: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glEnablei(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glEnablei(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glEnablei(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glEnablei, doc_QOpenGLFunctions_4_1_Core_glEnablei);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glColorMaski, "glColorMaski(self, index: int, r: int, g: int, b: int, a: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glColorMaski(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glColorMaski(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLboolean a1;
        ::GLboolean a2;
        ::GLboolean a3;
        ::GLboolean a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuMMMM", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glColorMaski(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glColorMaski, doc_QOpenGLFunctions_4_1_Core_glColorMaski);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniformBlockBinding, "glUniformBlockBinding(self, program: int, uniformBlockIndex: int, uniformBlockBinding: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniformBlockBinding(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniformBlockBinding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::GLuint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glUniformBlockBinding(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniformBlockBinding, doc_QOpenGLFunctions_4_1_Core_glUniformBlockBinding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPrimitiveRestartIndex, "glPrimitiveRestartIndex(self, index: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPrimitiveRestartIndex(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPrimitiveRestartIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glPrimitiveRestartIndex(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPrimitiveRestartIndex, doc_QOpenGLFunctions_4_1_Core_glPrimitiveRestartIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexBuffer, "glTexBuffer(self, target: int, internalformat: int, buffer: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexBuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLuint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexBuffer(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexBuffer, doc_QOpenGLFunctions_4_1_Core_glTexBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDrawArraysInstanced, "glDrawArraysInstanced(self, mode: int, first: int, count: int, instancecount: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawArraysInstanced(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawArraysInstanced(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLsizei a2;
        ::GLsizei a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glDrawArraysInstanced(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDrawArraysInstanced, doc_QOpenGLFunctions_4_1_Core_glDrawArraysInstanced);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glSampleMaski, "glSampleMaski(self, index: int, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glSampleMaski(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glSampleMaski(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLbitfield a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glSampleMaski(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glSampleMaski, doc_QOpenGLFunctions_4_1_Core_glSampleMaski);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexImage3DMultisample, "glTexImage3DMultisample(self, target: int, samples: int, internalformat: int, width: int, height: int, depth: int, fixedsamplelocations: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexImage3DMultisample(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexImage3DMultisample(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizei a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::GLsizei a5;
        ::GLboolean a6;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiM", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6))
        {
            sipCpp->glTexImage3DMultisample(a0, a1, a2, a3, a4, a5, a6);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexImage3DMultisample, doc_QOpenGLFunctions_4_1_Core_glTexImage3DMultisample);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glTexImage2DMultisample, "glTexImage2DMultisample(self, target: int, samples: int, internalformat: int, width: int, height: int, fixedsamplelocations: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexImage2DMultisample(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glTexImage2DMultisample(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizei a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::GLboolean a5;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiM", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glTexImage2DMultisample(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glTexImage2DMultisample, doc_QOpenGLFunctions_4_1_Core_glTexImage2DMultisample);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProvokingVertex, "glProvokingVertex(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProvokingVertex(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProvokingVertex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glProvokingVertex(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProvokingVertex, doc_QOpenGLFunctions_4_1_Core_glProvokingVertex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture, "glFramebufferTexture(self, target: int, attachment: int, texture: int, level: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLuint a2;
        ::GLint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuui", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glFramebufferTexture(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glFramebufferTexture, doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glVertexAttribP4ui, "glVertexAttribP4ui(self, index: int, type: int, normalized: int, value: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribP4ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribP4ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLboolean a2;
        ::GLuint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuMu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertexAttribP4ui(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glVertexAttribP4ui, doc_QOpenGLFunctions_4_1_Core_glVertexAttribP4ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glVertexAttribP3ui, "glVertexAttribP3ui(self, index: int, type: int, normalized: int, value: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribP3ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribP3ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLboolean a2;
        ::GLuint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuMu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertexAttribP3ui(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glVertexAttribP3ui, doc_QOpenGLFunctions_4_1_Core_glVertexAttribP3ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glVertexAttribP2ui, "glVertexAttribP2ui(self, index: int, type: int, normalized: int, value: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribP2ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribP2ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLboolean a2;
        ::GLuint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuMu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertexAttribP2ui(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glVertexAttribP2ui, doc_QOpenGLFunctions_4_1_Core_glVertexAttribP2ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glVertexAttribP1ui, "glVertexAttribP1ui(self, index: int, type: int, normalized: int, value: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribP1ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribP1ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLboolean a2;
        ::GLuint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuMu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertexAttribP1ui(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glVertexAttribP1ui, doc_QOpenGLFunctions_4_1_Core_glVertexAttribP1ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glQueryCounter, "glQueryCounter(self, id: int, target: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glQueryCounter(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glQueryCounter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glQueryCounter(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glQueryCounter, doc_QOpenGLFunctions_4_1_Core_glQueryCounter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glSamplerParameterf, "glSamplerParameterf(self, sampler: int, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glSamplerParameterf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glSamplerParameterf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuf", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glSamplerParameterf(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glSamplerParameterf, doc_QOpenGLFunctions_4_1_Core_glSamplerParameterf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glSamplerParameteri, "glSamplerParameteri(self, sampler: int, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glSamplerParameteri(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glSamplerParameteri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buui", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glSamplerParameteri(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glSamplerParameteri, doc_QOpenGLFunctions_4_1_Core_glSamplerParameteri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBindSampler, "glBindSampler(self, unit: int, sampler: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindSampler(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindSampler(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glBindSampler(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBindSampler, doc_QOpenGLFunctions_4_1_Core_glBindSampler);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsSampler, "glIsSampler(self, sampler: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsSampler(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsSampler(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsSampler(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsSampler, doc_QOpenGLFunctions_4_1_Core_glIsSampler);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glVertexAttribDivisor, "glVertexAttribDivisor(self, index: int, divisor: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribDivisor(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribDivisor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glVertexAttribDivisor(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glVertexAttribDivisor, doc_QOpenGLFunctions_4_1_Core_glVertexAttribDivisor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glEndQueryIndexed, "glEndQueryIndexed(self, target: int, index: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glEndQueryIndexed(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glEndQueryIndexed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glEndQueryIndexed(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glEndQueryIndexed, doc_QOpenGLFunctions_4_1_Core_glEndQueryIndexed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBeginQueryIndexed, "glBeginQueryIndexed(self, target: int, index: int, id: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBeginQueryIndexed(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBeginQueryIndexed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::GLuint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glBeginQueryIndexed(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBeginQueryIndexed, doc_QOpenGLFunctions_4_1_Core_glBeginQueryIndexed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDrawTransformFeedbackStream, "glDrawTransformFeedbackStream(self, mode: int, id: int, stream: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawTransformFeedbackStream(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawTransformFeedbackStream(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::GLuint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glDrawTransformFeedbackStream(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDrawTransformFeedbackStream, doc_QOpenGLFunctions_4_1_Core_glDrawTransformFeedbackStream);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDrawTransformFeedback, "glDrawTransformFeedback(self, mode: int, id: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawTransformFeedback(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDrawTransformFeedback(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glDrawTransformFeedback(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDrawTransformFeedback, doc_QOpenGLFunctions_4_1_Core_glDrawTransformFeedback);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glResumeTransformFeedback, "glResumeTransformFeedback(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glResumeTransformFeedback(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glResumeTransformFeedback(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp))
        {
            sipCpp->glResumeTransformFeedback();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glResumeTransformFeedback, doc_QOpenGLFunctions_4_1_Core_glResumeTransformFeedback);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPauseTransformFeedback, "glPauseTransformFeedback(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPauseTransformFeedback(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPauseTransformFeedback(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp))
        {
            sipCpp->glPauseTransformFeedback();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPauseTransformFeedback, doc_QOpenGLFunctions_4_1_Core_glPauseTransformFeedback);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsTransformFeedback, "glIsTransformFeedback(self, id: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsTransformFeedback(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsTransformFeedback(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsTransformFeedback(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsTransformFeedback, doc_QOpenGLFunctions_4_1_Core_glIsTransformFeedback);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBindTransformFeedback, "glBindTransformFeedback(self, target: int, id: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindTransformFeedback(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindTransformFeedback(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glBindTransformFeedback(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBindTransformFeedback, doc_QOpenGLFunctions_4_1_Core_glBindTransformFeedback);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glPatchParameteri, "glPatchParameteri(self, pname: int, value: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glPatchParameteri(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glPatchParameteri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bui", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glPatchParameteri(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glPatchParameteri, doc_QOpenGLFunctions_4_1_Core_glPatchParameteri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform4d, "glUniform4d(self, location: int, x: float, y: float, z: float, w: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform4d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::GLdouble a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bidddd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glUniform4d(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform4d, doc_QOpenGLFunctions_4_1_Core_glUniform4d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform3d, "glUniform3d(self, location: int, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biddd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glUniform3d(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform3d, doc_QOpenGLFunctions_4_1_Core_glUniform3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform2d, "glUniform2d(self, location: int, x: float, y: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bidd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glUniform2d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform2d, doc_QOpenGLFunctions_4_1_Core_glUniform2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUniform1d, "glUniform1d(self, location: int, x: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUniform1d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLdouble a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bid", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glUniform1d(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUniform1d, doc_QOpenGLFunctions_4_1_Core_glUniform1d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBlendFuncSeparatei, "glBlendFuncSeparatei(self, buf: int, srcRGB: int, dstRGB: int, srcAlpha: int, dstAlpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendFuncSeparatei(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendFuncSeparatei(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLenum a2;
        ::GLenum a3;
        ::GLenum a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuuuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glBlendFuncSeparatei(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBlendFuncSeparatei, doc_QOpenGLFunctions_4_1_Core_glBlendFuncSeparatei);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBlendFunci, "glBlendFunci(self, buf: int, src: int, dst: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendFunci(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendFunci(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLenum a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glBlendFunci(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBlendFunci, doc_QOpenGLFunctions_4_1_Core_glBlendFunci);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBlendEquationSeparatei, "glBlendEquationSeparatei(self, buf: int, modeRGB: int, modeAlpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendEquationSeparatei(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendEquationSeparatei(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLenum a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glBlendEquationSeparatei(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBlendEquationSeparatei, doc_QOpenGLFunctions_4_1_Core_glBlendEquationSeparatei);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBlendEquationi, "glBlendEquationi(self, buf: int, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendEquationi(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBlendEquationi(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glBlendEquationi(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBlendEquationi, doc_QOpenGLFunctions_4_1_Core_glBlendEquationi);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glMinSampleShading, "glMinSampleShading(self, value: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glMinSampleShading(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glMinSampleShading(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glMinSampleShading(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glMinSampleShading, doc_QOpenGLFunctions_4_1_Core_glMinSampleShading);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDepthRangeIndexed, "glDepthRangeIndexed(self, index: int, n: float, f: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDepthRangeIndexed(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDepthRangeIndexed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Budd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glDepthRangeIndexed(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDepthRangeIndexed, doc_QOpenGLFunctions_4_1_Core_glDepthRangeIndexed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glScissorIndexed, "glScissorIndexed(self, index: int, left: int, bottom: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glScissorIndexed(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glScissorIndexed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glScissorIndexed(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glScissorIndexed, doc_QOpenGLFunctions_4_1_Core_glScissorIndexed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glViewportIndexedf, "glViewportIndexedf(self, index: int, x: float, y: float, w: float, h: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glViewportIndexedf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glViewportIndexedf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::GLfloat a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buffff", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glViewportIndexedf(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glViewportIndexedf, doc_QOpenGLFunctions_4_1_Core_glViewportIndexedf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glVertexAttribL4d, "glVertexAttribL4d(self, index: int, x: float, y: float, z: float, w: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribL4d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribL4d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::GLdouble a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Budddd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glVertexAttribL4d(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glVertexAttribL4d, doc_QOpenGLFunctions_4_1_Core_glVertexAttribL4d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glVertexAttribL3d, "glVertexAttribL3d(self, index: int, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribL3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribL3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buddd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertexAttribL3d(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glVertexAttribL3d, doc_QOpenGLFunctions_4_1_Core_glVertexAttribL3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glVertexAttribL2d, "glVertexAttribL2d(self, index: int, x: float, y: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribL2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribL2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Budd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glVertexAttribL2d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glVertexAttribL2d, doc_QOpenGLFunctions_4_1_Core_glVertexAttribL2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glVertexAttribL1d, "glVertexAttribL1d(self, index: int, x: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribL1d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glVertexAttribL1d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLdouble a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bud", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glVertexAttribL1d(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glVertexAttribL1d, doc_QOpenGLFunctions_4_1_Core_glVertexAttribL1d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glValidateProgramPipeline, "glValidateProgramPipeline(self, pipeline: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glValidateProgramPipeline(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glValidateProgramPipeline(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glValidateProgramPipeline(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glValidateProgramPipeline, doc_QOpenGLFunctions_4_1_Core_glValidateProgramPipeline);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform4ui, "glProgramUniform4ui(self, program: int, location: int, v0: int, v1: int, v2: int, v3: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform4ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform4ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLuint a2;
        ::GLuint a3;
        ::GLuint a4;
        ::GLuint a5;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiuuuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glProgramUniform4ui(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform4ui, doc_QOpenGLFunctions_4_1_Core_glProgramUniform4ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform4d, "glProgramUniform4d(self, program: int, location: int, v0: float, v1: float, v2: float, v3: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform4d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform4d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::GLdouble a4;
        ::GLdouble a5;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buidddd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glProgramUniform4d(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform4d, doc_QOpenGLFunctions_4_1_Core_glProgramUniform4d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform4f, "glProgramUniform4f(self, program: int, location: int, v0: float, v1: float, v2: float, v3: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform4f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform4f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::GLfloat a4;
        ::GLfloat a5;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiffff", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glProgramUniform4f(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform4f, doc_QOpenGLFunctions_4_1_Core_glProgramUniform4f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform4i, "glProgramUniform4i(self, program: int, location: int, v0: int, v1: int, v2: int, v3: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform4i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform4i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLint a5;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glProgramUniform4i(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform4i, doc_QOpenGLFunctions_4_1_Core_glProgramUniform4i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform3ui, "glProgramUniform3ui(self, program: int, location: int, v0: int, v1: int, v2: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform3ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform3ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLuint a2;
        ::GLuint a3;
        ::GLuint a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiuuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glProgramUniform3ui(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform3ui, doc_QOpenGLFunctions_4_1_Core_glProgramUniform3ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform3d, "glProgramUniform3d(self, program: int, location: int, v0: float, v1: float, v2: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::GLdouble a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiddd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glProgramUniform3d(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform3d, doc_QOpenGLFunctions_4_1_Core_glProgramUniform3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform3f, "glProgramUniform3f(self, program: int, location: int, v0: float, v1: float, v2: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::GLfloat a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buifff", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glProgramUniform3f(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform3f, doc_QOpenGLFunctions_4_1_Core_glProgramUniform3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform3i, "glProgramUniform3i(self, program: int, location: int, v0: int, v1: int, v2: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform3i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform3i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glProgramUniform3i(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform3i, doc_QOpenGLFunctions_4_1_Core_glProgramUniform3i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform2ui, "glProgramUniform2ui(self, program: int, location: int, v0: int, v1: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform2ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform2ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLuint a2;
        ::GLuint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glProgramUniform2ui(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform2ui, doc_QOpenGLFunctions_4_1_Core_glProgramUniform2ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform2d, "glProgramUniform2d(self, program: int, location: int, v0: float, v1: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buidd", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glProgramUniform2d(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform2d, doc_QOpenGLFunctions_4_1_Core_glProgramUniform2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform2f, "glProgramUniform2f(self, program: int, location: int, v0: float, v1: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiff", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glProgramUniform2f(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform2f, doc_QOpenGLFunctions_4_1_Core_glProgramUniform2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform2i, "glProgramUniform2i(self, program: int, location: int, v0: int, v1: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform2i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform2i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glProgramUniform2i(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform2i, doc_QOpenGLFunctions_4_1_Core_glProgramUniform2i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform1ui, "glProgramUniform1ui(self, program: int, location: int, v0: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform1ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform1ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLuint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glProgramUniform1ui(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform1ui, doc_QOpenGLFunctions_4_1_Core_glProgramUniform1ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform1d, "glProgramUniform1d(self, program: int, location: int, v0: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform1d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform1d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buid", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glProgramUniform1d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform1d, doc_QOpenGLFunctions_4_1_Core_glProgramUniform1d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform1f, "glProgramUniform1f(self, program: int, location: int, v0: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform1f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform1f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buif", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glProgramUniform1f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform1f, doc_QOpenGLFunctions_4_1_Core_glProgramUniform1f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramUniform1i, "glProgramUniform1i(self, program: int, location: int, v0: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform1i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramUniform1i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buii", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glProgramUniform1i(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramUniform1i, doc_QOpenGLFunctions_4_1_Core_glProgramUniform1i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glIsProgramPipeline, "glIsProgramPipeline(self, pipeline: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsProgramPipeline(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glIsProgramPipeline(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsProgramPipeline(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glIsProgramPipeline, doc_QOpenGLFunctions_4_1_Core_glIsProgramPipeline);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glBindProgramPipeline, "glBindProgramPipeline(self, pipeline: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindProgramPipeline(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glBindProgramPipeline(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glBindProgramPipeline(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glBindProgramPipeline, doc_QOpenGLFunctions_4_1_Core_glBindProgramPipeline);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glActiveShaderProgram, "glActiveShaderProgram(self, pipeline: int, program: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glActiveShaderProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glActiveShaderProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glActiveShaderProgram(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glActiveShaderProgram, doc_QOpenGLFunctions_4_1_Core_glActiveShaderProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glUseProgramStages, "glUseProgramStages(self, pipeline: int, stages: int, program: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glUseProgramStages(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glUseProgramStages(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLbitfield a1;
        ::GLuint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glUseProgramStages(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glUseProgramStages, doc_QOpenGLFunctions_4_1_Core_glUseProgramStages);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glProgramParameteri, "glProgramParameteri(self, program: int, pname: int, value: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramParameteri(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glProgramParameteri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buui", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glProgramParameteri(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glProgramParameteri, doc_QOpenGLFunctions_4_1_Core_glProgramParameteri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glClearDepthf, "glClearDepthf(self, dd: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glClearDepthf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glClearDepthf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0))
        {
            sipCpp->glClearDepthf(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glClearDepthf, doc_QOpenGLFunctions_4_1_Core_glClearDepthf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glDepthRangef, "glDepthRangef(self, n: float, f: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glDepthRangef(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glDepthRangef(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bff", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp, &a0, &a1))
        {
            sipCpp->glDepthRangef(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glDepthRangef, doc_QOpenGLFunctions_4_1_Core_glDepthRangef);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core_glReleaseShaderCompiler, "glReleaseShaderCompiler(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_4_1_Core_glReleaseShaderCompiler(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_4_1_Core_glReleaseShaderCompiler(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_4_1_Core *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_4_1_Core, &sipCpp))
        {
            sipCpp->glReleaseShaderCompiler();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_4_1_Core, sipName_glReleaseShaderCompiler, doc_QOpenGLFunctions_4_1_Core_glReleaseShaderCompiler);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QOpenGLFunctions_4_1_Core(void *, const sipTypeDef *);}
static void *cast_QOpenGLFunctions_4_1_Core(void *sipCppV, const sipTypeDef *targetType)
{
    ::QOpenGLFunctions_4_1_Core *sipCpp = reinterpret_cast< ::QOpenGLFunctions_4_1_Core *>(sipCppV);

    if (targetType == sipType_QOpenGLFunctions_4_1_Core)
        return sipCppV;

    if (targetType == sipType_QAbstractOpenGLFunctions)
        return static_cast< ::QAbstractOpenGLFunctions *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QOpenGLFunctions_4_1_Core(void *, int);}
static void release_QOpenGLFunctions_4_1_Core(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQOpenGLFunctions_4_1_Core *>(sipCppV);
    else
        delete reinterpret_cast< ::QOpenGLFunctions_4_1_Core *>(sipCppV);
}


extern "C" {static void *array_QOpenGLFunctions_4_1_Core(Py_ssize_t);}
static void *array_QOpenGLFunctions_4_1_Core(Py_ssize_t sipNrElem)
{
    return new ::QOpenGLFunctions_4_1_Core[sipNrElem];
}


extern "C" {static void array_delete_QOpenGLFunctions_4_1_Core(void *);}
static void array_delete_QOpenGLFunctions_4_1_Core(void *sipCpp)
{
    delete[] reinterpret_cast< ::QOpenGLFunctions_4_1_Core *>(sipCpp);
}


extern "C" {static void dealloc_QOpenGLFunctions_4_1_Core(sipSimpleWrapper *);}
static void dealloc_QOpenGLFunctions_4_1_Core(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQOpenGLFunctions_4_1_Core *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QOpenGLFunctions_4_1_Core(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QOpenGLFunctions_4_1_Core(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QOpenGLFunctions_4_1_Core(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQOpenGLFunctions_4_1_Core *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQOpenGLFunctions_4_1_Core();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QOpenGLFunctions_4_1_Core[] = {{0, 255, 1}};


static PyMethodDef methods_QOpenGLFunctions_4_1_Core[] = {
    {sipName_glActiveShaderProgram, meth_QOpenGLFunctions_4_1_Core_glActiveShaderProgram, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glActiveShaderProgram},
    {sipName_glActiveTexture, meth_QOpenGLFunctions_4_1_Core_glActiveTexture, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glActiveTexture},
    {sipName_glAttachShader, meth_QOpenGLFunctions_4_1_Core_glAttachShader, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glAttachShader},
    {sipName_glBeginConditionalRender, meth_QOpenGLFunctions_4_1_Core_glBeginConditionalRender, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBeginConditionalRender},
    {sipName_glBeginQuery, meth_QOpenGLFunctions_4_1_Core_glBeginQuery, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBeginQuery},
    {sipName_glBeginQueryIndexed, meth_QOpenGLFunctions_4_1_Core_glBeginQueryIndexed, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBeginQueryIndexed},
    {sipName_glBeginTransformFeedback, meth_QOpenGLFunctions_4_1_Core_glBeginTransformFeedback, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBeginTransformFeedback},
    {sipName_glBindAttribLocation, meth_QOpenGLFunctions_4_1_Core_glBindAttribLocation, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBindAttribLocation},
    {sipName_glBindBuffer, meth_QOpenGLFunctions_4_1_Core_glBindBuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBindBuffer},
    {sipName_glBindBufferBase, meth_QOpenGLFunctions_4_1_Core_glBindBufferBase, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBindBufferBase},
    {sipName_glBindFramebuffer, meth_QOpenGLFunctions_4_1_Core_glBindFramebuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBindFramebuffer},
    {sipName_glBindProgramPipeline, meth_QOpenGLFunctions_4_1_Core_glBindProgramPipeline, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBindProgramPipeline},
    {sipName_glBindRenderbuffer, meth_QOpenGLFunctions_4_1_Core_glBindRenderbuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBindRenderbuffer},
    {sipName_glBindSampler, meth_QOpenGLFunctions_4_1_Core_glBindSampler, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBindSampler},
    {sipName_glBindTexture, meth_QOpenGLFunctions_4_1_Core_glBindTexture, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBindTexture},
    {sipName_glBindTransformFeedback, meth_QOpenGLFunctions_4_1_Core_glBindTransformFeedback, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBindTransformFeedback},
    {sipName_glBindVertexArray, meth_QOpenGLFunctions_4_1_Core_glBindVertexArray, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBindVertexArray},
    {sipName_glBlendColor, meth_QOpenGLFunctions_4_1_Core_glBlendColor, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBlendColor},
    {sipName_glBlendEquation, meth_QOpenGLFunctions_4_1_Core_glBlendEquation, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBlendEquation},
    {sipName_glBlendEquationSeparate, meth_QOpenGLFunctions_4_1_Core_glBlendEquationSeparate, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBlendEquationSeparate},
    {sipName_glBlendEquationSeparatei, meth_QOpenGLFunctions_4_1_Core_glBlendEquationSeparatei, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBlendEquationSeparatei},
    {sipName_glBlendEquationi, meth_QOpenGLFunctions_4_1_Core_glBlendEquationi, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBlendEquationi},
    {sipName_glBlendFunc, meth_QOpenGLFunctions_4_1_Core_glBlendFunc, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBlendFunc},
    {sipName_glBlendFuncSeparate, meth_QOpenGLFunctions_4_1_Core_glBlendFuncSeparate, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBlendFuncSeparate},
    {sipName_glBlendFuncSeparatei, meth_QOpenGLFunctions_4_1_Core_glBlendFuncSeparatei, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBlendFuncSeparatei},
    {sipName_glBlendFunci, meth_QOpenGLFunctions_4_1_Core_glBlendFunci, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBlendFunci},
    {sipName_glBlitFramebuffer, meth_QOpenGLFunctions_4_1_Core_glBlitFramebuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBlitFramebuffer},
    {sipName_glBufferData, meth_QOpenGLFunctions_4_1_Core_glBufferData, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBufferData},
    {sipName_glBufferSubData, meth_QOpenGLFunctions_4_1_Core_glBufferSubData, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glBufferSubData},
    {sipName_glCheckFramebufferStatus, meth_QOpenGLFunctions_4_1_Core_glCheckFramebufferStatus, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCheckFramebufferStatus},
    {sipName_glClampColor, meth_QOpenGLFunctions_4_1_Core_glClampColor, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glClampColor},
    {sipName_glClear, meth_QOpenGLFunctions_4_1_Core_glClear, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glClear},
    {sipName_glClearBufferfi, meth_QOpenGLFunctions_4_1_Core_glClearBufferfi, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glClearBufferfi},
    {sipName_glClearColor, meth_QOpenGLFunctions_4_1_Core_glClearColor, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glClearColor},
    {sipName_glClearDepth, meth_QOpenGLFunctions_4_1_Core_glClearDepth, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glClearDepth},
    {sipName_glClearDepthf, meth_QOpenGLFunctions_4_1_Core_glClearDepthf, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glClearDepthf},
    {sipName_glClearStencil, meth_QOpenGLFunctions_4_1_Core_glClearStencil, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glClearStencil},
    {sipName_glColorMask, meth_QOpenGLFunctions_4_1_Core_glColorMask, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glColorMask},
    {sipName_glColorMaski, meth_QOpenGLFunctions_4_1_Core_glColorMaski, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glColorMaski},
    {sipName_glCompileShader, meth_QOpenGLFunctions_4_1_Core_glCompileShader, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCompileShader},
    {sipName_glCompressedTexImage1D, meth_QOpenGLFunctions_4_1_Core_glCompressedTexImage1D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCompressedTexImage1D},
    {sipName_glCompressedTexImage2D, meth_QOpenGLFunctions_4_1_Core_glCompressedTexImage2D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCompressedTexImage2D},
    {sipName_glCompressedTexImage3D, meth_QOpenGLFunctions_4_1_Core_glCompressedTexImage3D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCompressedTexImage3D},
    {sipName_glCompressedTexSubImage1D, meth_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage1D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage1D},
    {sipName_glCompressedTexSubImage2D, meth_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage2D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage2D},
    {sipName_glCompressedTexSubImage3D, meth_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage3D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCompressedTexSubImage3D},
    {sipName_glCopyTexImage1D, meth_QOpenGLFunctions_4_1_Core_glCopyTexImage1D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCopyTexImage1D},
    {sipName_glCopyTexImage2D, meth_QOpenGLFunctions_4_1_Core_glCopyTexImage2D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCopyTexImage2D},
    {sipName_glCopyTexSubImage1D, meth_QOpenGLFunctions_4_1_Core_glCopyTexSubImage1D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCopyTexSubImage1D},
    {sipName_glCopyTexSubImage2D, meth_QOpenGLFunctions_4_1_Core_glCopyTexSubImage2D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCopyTexSubImage2D},
    {sipName_glCopyTexSubImage3D, meth_QOpenGLFunctions_4_1_Core_glCopyTexSubImage3D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCopyTexSubImage3D},
    {sipName_glCreateProgram, meth_QOpenGLFunctions_4_1_Core_glCreateProgram, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCreateProgram},
    {sipName_glCreateShader, meth_QOpenGLFunctions_4_1_Core_glCreateShader, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCreateShader},
    {sipName_glCullFace, meth_QOpenGLFunctions_4_1_Core_glCullFace, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glCullFace},
    {sipName_glDeleteBuffers, meth_QOpenGLFunctions_4_1_Core_glDeleteBuffers, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDeleteBuffers},
    {sipName_glDeleteProgram, meth_QOpenGLFunctions_4_1_Core_glDeleteProgram, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDeleteProgram},
    {sipName_glDeleteQueries, meth_QOpenGLFunctions_4_1_Core_glDeleteQueries, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDeleteQueries},
    {sipName_glDeleteShader, meth_QOpenGLFunctions_4_1_Core_glDeleteShader, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDeleteShader},
    {sipName_glDeleteTextures, meth_QOpenGLFunctions_4_1_Core_glDeleteTextures, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDeleteTextures},
    {sipName_glDepthFunc, meth_QOpenGLFunctions_4_1_Core_glDepthFunc, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDepthFunc},
    {sipName_glDepthMask, meth_QOpenGLFunctions_4_1_Core_glDepthMask, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDepthMask},
    {sipName_glDepthRange, meth_QOpenGLFunctions_4_1_Core_glDepthRange, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDepthRange},
    {sipName_glDepthRangeIndexed, meth_QOpenGLFunctions_4_1_Core_glDepthRangeIndexed, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDepthRangeIndexed},
    {sipName_glDepthRangef, meth_QOpenGLFunctions_4_1_Core_glDepthRangef, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDepthRangef},
    {sipName_glDetachShader, meth_QOpenGLFunctions_4_1_Core_glDetachShader, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDetachShader},
    {sipName_glDisable, meth_QOpenGLFunctions_4_1_Core_glDisable, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDisable},
    {sipName_glDisableVertexAttribArray, meth_QOpenGLFunctions_4_1_Core_glDisableVertexAttribArray, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDisableVertexAttribArray},
    {sipName_glDisablei, meth_QOpenGLFunctions_4_1_Core_glDisablei, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDisablei},
    {sipName_glDrawArrays, meth_QOpenGLFunctions_4_1_Core_glDrawArrays, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDrawArrays},
    {sipName_glDrawArraysInstanced, meth_QOpenGLFunctions_4_1_Core_glDrawArraysInstanced, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDrawArraysInstanced},
    {sipName_glDrawBuffer, meth_QOpenGLFunctions_4_1_Core_glDrawBuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDrawBuffer},
    {sipName_glDrawBuffers, meth_QOpenGLFunctions_4_1_Core_glDrawBuffers, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDrawBuffers},
    {sipName_glDrawElements, meth_QOpenGLFunctions_4_1_Core_glDrawElements, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDrawElements},
    {sipName_glDrawRangeElements, meth_QOpenGLFunctions_4_1_Core_glDrawRangeElements, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDrawRangeElements},
    {sipName_glDrawTransformFeedback, meth_QOpenGLFunctions_4_1_Core_glDrawTransformFeedback, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDrawTransformFeedback},
    {sipName_glDrawTransformFeedbackStream, meth_QOpenGLFunctions_4_1_Core_glDrawTransformFeedbackStream, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glDrawTransformFeedbackStream},
    {sipName_glEnable, meth_QOpenGLFunctions_4_1_Core_glEnable, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glEnable},
    {sipName_glEnableVertexAttribArray, meth_QOpenGLFunctions_4_1_Core_glEnableVertexAttribArray, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glEnableVertexAttribArray},
    {sipName_glEnablei, meth_QOpenGLFunctions_4_1_Core_glEnablei, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glEnablei},
    {sipName_glEndConditionalRender, meth_QOpenGLFunctions_4_1_Core_glEndConditionalRender, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glEndConditionalRender},
    {sipName_glEndQuery, meth_QOpenGLFunctions_4_1_Core_glEndQuery, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glEndQuery},
    {sipName_glEndQueryIndexed, meth_QOpenGLFunctions_4_1_Core_glEndQueryIndexed, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glEndQueryIndexed},
    {sipName_glEndTransformFeedback, meth_QOpenGLFunctions_4_1_Core_glEndTransformFeedback, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glEndTransformFeedback},
    {sipName_glFinish, meth_QOpenGLFunctions_4_1_Core_glFinish, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glFinish},
    {sipName_glFlush, meth_QOpenGLFunctions_4_1_Core_glFlush, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glFlush},
    {sipName_glFramebufferRenderbuffer, meth_QOpenGLFunctions_4_1_Core_glFramebufferRenderbuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glFramebufferRenderbuffer},
    {sipName_glFramebufferTexture, meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture},
    {sipName_glFramebufferTexture1D, meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture1D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture1D},
    {sipName_glFramebufferTexture2D, meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture2D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture2D},
    {sipName_glFramebufferTexture3D, meth_QOpenGLFunctions_4_1_Core_glFramebufferTexture3D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glFramebufferTexture3D},
    {sipName_glFramebufferTextureLayer, meth_QOpenGLFunctions_4_1_Core_glFramebufferTextureLayer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glFramebufferTextureLayer},
    {sipName_glFrontFace, meth_QOpenGLFunctions_4_1_Core_glFrontFace, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glFrontFace},
    {sipName_glGenBuffers, meth_QOpenGLFunctions_4_1_Core_glGenBuffers, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGenBuffers},
    {sipName_glGenQueries, meth_QOpenGLFunctions_4_1_Core_glGenQueries, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGenQueries},
    {sipName_glGenTextures, meth_QOpenGLFunctions_4_1_Core_glGenTextures, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGenTextures},
    {sipName_glGenerateMipmap, meth_QOpenGLFunctions_4_1_Core_glGenerateMipmap, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGenerateMipmap},
    {sipName_glGetActiveAttrib, meth_QOpenGLFunctions_4_1_Core_glGetActiveAttrib, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetActiveAttrib},
    {sipName_glGetActiveUniform, meth_QOpenGLFunctions_4_1_Core_glGetActiveUniform, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetActiveUniform},
    {sipName_glGetAttachedShaders, meth_QOpenGLFunctions_4_1_Core_glGetAttachedShaders, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetAttachedShaders},
    {sipName_glGetAttribLocation, meth_QOpenGLFunctions_4_1_Core_glGetAttribLocation, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetAttribLocation},
    {sipName_glGetBooleanv, meth_QOpenGLFunctions_4_1_Core_glGetBooleanv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetBooleanv},
    {sipName_glGetBufferParameteriv, meth_QOpenGLFunctions_4_1_Core_glGetBufferParameteriv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetBufferParameteriv},
    {sipName_glGetDoublev, meth_QOpenGLFunctions_4_1_Core_glGetDoublev, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetDoublev},
    {sipName_glGetError, meth_QOpenGLFunctions_4_1_Core_glGetError, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetError},
    {sipName_glGetFloatv, meth_QOpenGLFunctions_4_1_Core_glGetFloatv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetFloatv},
    {sipName_glGetIntegerv, meth_QOpenGLFunctions_4_1_Core_glGetIntegerv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetIntegerv},
    {sipName_glGetProgramInfoLog, meth_QOpenGLFunctions_4_1_Core_glGetProgramInfoLog, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetProgramInfoLog},
    {sipName_glGetProgramiv, meth_QOpenGLFunctions_4_1_Core_glGetProgramiv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetProgramiv},
    {sipName_glGetQueryiv, meth_QOpenGLFunctions_4_1_Core_glGetQueryiv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetQueryiv},
    {sipName_glGetShaderInfoLog, meth_QOpenGLFunctions_4_1_Core_glGetShaderInfoLog, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetShaderInfoLog},
    {sipName_glGetShaderSource, meth_QOpenGLFunctions_4_1_Core_glGetShaderSource, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetShaderSource},
    {sipName_glGetShaderiv, meth_QOpenGLFunctions_4_1_Core_glGetShaderiv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetShaderiv},
    {sipName_glGetString, meth_QOpenGLFunctions_4_1_Core_glGetString, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetString},
    {sipName_glGetTexLevelParameterfv, meth_QOpenGLFunctions_4_1_Core_glGetTexLevelParameterfv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetTexLevelParameterfv},
    {sipName_glGetTexLevelParameteriv, meth_QOpenGLFunctions_4_1_Core_glGetTexLevelParameteriv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetTexLevelParameteriv},
    {sipName_glGetTexParameterfv, meth_QOpenGLFunctions_4_1_Core_glGetTexParameterfv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetTexParameterfv},
    {sipName_glGetTexParameteriv, meth_QOpenGLFunctions_4_1_Core_glGetTexParameteriv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetTexParameteriv},
    {sipName_glGetUniformLocation, meth_QOpenGLFunctions_4_1_Core_glGetUniformLocation, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetUniformLocation},
    {sipName_glGetVertexAttribdv, meth_QOpenGLFunctions_4_1_Core_glGetVertexAttribdv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetVertexAttribdv},
    {sipName_glGetVertexAttribfv, meth_QOpenGLFunctions_4_1_Core_glGetVertexAttribfv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetVertexAttribfv},
    {sipName_glGetVertexAttribiv, meth_QOpenGLFunctions_4_1_Core_glGetVertexAttribiv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glGetVertexAttribiv},
    {sipName_glHint, meth_QOpenGLFunctions_4_1_Core_glHint, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glHint},
    {sipName_glIsBuffer, meth_QOpenGLFunctions_4_1_Core_glIsBuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsBuffer},
    {sipName_glIsEnabled, meth_QOpenGLFunctions_4_1_Core_glIsEnabled, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsEnabled},
    {sipName_glIsEnabledi, meth_QOpenGLFunctions_4_1_Core_glIsEnabledi, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsEnabledi},
    {sipName_glIsFramebuffer, meth_QOpenGLFunctions_4_1_Core_glIsFramebuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsFramebuffer},
    {sipName_glIsProgram, meth_QOpenGLFunctions_4_1_Core_glIsProgram, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsProgram},
    {sipName_glIsProgramPipeline, meth_QOpenGLFunctions_4_1_Core_glIsProgramPipeline, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsProgramPipeline},
    {sipName_glIsQuery, meth_QOpenGLFunctions_4_1_Core_glIsQuery, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsQuery},
    {sipName_glIsRenderbuffer, meth_QOpenGLFunctions_4_1_Core_glIsRenderbuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsRenderbuffer},
    {sipName_glIsSampler, meth_QOpenGLFunctions_4_1_Core_glIsSampler, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsSampler},
    {sipName_glIsShader, meth_QOpenGLFunctions_4_1_Core_glIsShader, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsShader},
    {sipName_glIsTexture, meth_QOpenGLFunctions_4_1_Core_glIsTexture, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsTexture},
    {sipName_glIsTransformFeedback, meth_QOpenGLFunctions_4_1_Core_glIsTransformFeedback, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsTransformFeedback},
    {sipName_glIsVertexArray, meth_QOpenGLFunctions_4_1_Core_glIsVertexArray, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glIsVertexArray},
    {sipName_glLineWidth, meth_QOpenGLFunctions_4_1_Core_glLineWidth, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glLineWidth},
    {sipName_glLinkProgram, meth_QOpenGLFunctions_4_1_Core_glLinkProgram, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glLinkProgram},
    {sipName_glLogicOp, meth_QOpenGLFunctions_4_1_Core_glLogicOp, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glLogicOp},
    {sipName_glMinSampleShading, meth_QOpenGLFunctions_4_1_Core_glMinSampleShading, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glMinSampleShading},
    {sipName_glPatchParameteri, meth_QOpenGLFunctions_4_1_Core_glPatchParameteri, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPatchParameteri},
    {sipName_glPauseTransformFeedback, meth_QOpenGLFunctions_4_1_Core_glPauseTransformFeedback, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPauseTransformFeedback},
    {sipName_glPixelStoref, meth_QOpenGLFunctions_4_1_Core_glPixelStoref, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPixelStoref},
    {sipName_glPixelStorei, meth_QOpenGLFunctions_4_1_Core_glPixelStorei, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPixelStorei},
    {sipName_glPointParameterf, meth_QOpenGLFunctions_4_1_Core_glPointParameterf, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPointParameterf},
    {sipName_glPointParameterfv, meth_QOpenGLFunctions_4_1_Core_glPointParameterfv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPointParameterfv},
    {sipName_glPointParameteri, meth_QOpenGLFunctions_4_1_Core_glPointParameteri, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPointParameteri},
    {sipName_glPointParameteriv, meth_QOpenGLFunctions_4_1_Core_glPointParameteriv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPointParameteriv},
    {sipName_glPointSize, meth_QOpenGLFunctions_4_1_Core_glPointSize, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPointSize},
    {sipName_glPolygonMode, meth_QOpenGLFunctions_4_1_Core_glPolygonMode, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPolygonMode},
    {sipName_glPolygonOffset, meth_QOpenGLFunctions_4_1_Core_glPolygonOffset, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPolygonOffset},
    {sipName_glPrimitiveRestartIndex, meth_QOpenGLFunctions_4_1_Core_glPrimitiveRestartIndex, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glPrimitiveRestartIndex},
    {sipName_glProgramParameteri, meth_QOpenGLFunctions_4_1_Core_glProgramParameteri, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramParameteri},
    {sipName_glProgramUniform1d, meth_QOpenGLFunctions_4_1_Core_glProgramUniform1d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform1d},
    {sipName_glProgramUniform1f, meth_QOpenGLFunctions_4_1_Core_glProgramUniform1f, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform1f},
    {sipName_glProgramUniform1i, meth_QOpenGLFunctions_4_1_Core_glProgramUniform1i, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform1i},
    {sipName_glProgramUniform1ui, meth_QOpenGLFunctions_4_1_Core_glProgramUniform1ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform1ui},
    {sipName_glProgramUniform2d, meth_QOpenGLFunctions_4_1_Core_glProgramUniform2d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform2d},
    {sipName_glProgramUniform2f, meth_QOpenGLFunctions_4_1_Core_glProgramUniform2f, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform2f},
    {sipName_glProgramUniform2i, meth_QOpenGLFunctions_4_1_Core_glProgramUniform2i, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform2i},
    {sipName_glProgramUniform2ui, meth_QOpenGLFunctions_4_1_Core_glProgramUniform2ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform2ui},
    {sipName_glProgramUniform3d, meth_QOpenGLFunctions_4_1_Core_glProgramUniform3d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform3d},
    {sipName_glProgramUniform3f, meth_QOpenGLFunctions_4_1_Core_glProgramUniform3f, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform3f},
    {sipName_glProgramUniform3i, meth_QOpenGLFunctions_4_1_Core_glProgramUniform3i, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform3i},
    {sipName_glProgramUniform3ui, meth_QOpenGLFunctions_4_1_Core_glProgramUniform3ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform3ui},
    {sipName_glProgramUniform4d, meth_QOpenGLFunctions_4_1_Core_glProgramUniform4d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform4d},
    {sipName_glProgramUniform4f, meth_QOpenGLFunctions_4_1_Core_glProgramUniform4f, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform4f},
    {sipName_glProgramUniform4i, meth_QOpenGLFunctions_4_1_Core_glProgramUniform4i, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform4i},
    {sipName_glProgramUniform4ui, meth_QOpenGLFunctions_4_1_Core_glProgramUniform4ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProgramUniform4ui},
    {sipName_glProvokingVertex, meth_QOpenGLFunctions_4_1_Core_glProvokingVertex, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glProvokingVertex},
    {sipName_glQueryCounter, meth_QOpenGLFunctions_4_1_Core_glQueryCounter, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glQueryCounter},
    {sipName_glReadBuffer, meth_QOpenGLFunctions_4_1_Core_glReadBuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glReadBuffer},
    {sipName_glReadPixels, meth_QOpenGLFunctions_4_1_Core_glReadPixels, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glReadPixels},
    {sipName_glReleaseShaderCompiler, meth_QOpenGLFunctions_4_1_Core_glReleaseShaderCompiler, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glReleaseShaderCompiler},
    {sipName_glRenderbufferStorage, meth_QOpenGLFunctions_4_1_Core_glRenderbufferStorage, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glRenderbufferStorage},
    {sipName_glRenderbufferStorageMultisample, meth_QOpenGLFunctions_4_1_Core_glRenderbufferStorageMultisample, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glRenderbufferStorageMultisample},
    {sipName_glResumeTransformFeedback, meth_QOpenGLFunctions_4_1_Core_glResumeTransformFeedback, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glResumeTransformFeedback},
    {sipName_glSampleCoverage, meth_QOpenGLFunctions_4_1_Core_glSampleCoverage, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glSampleCoverage},
    {sipName_glSampleMaski, meth_QOpenGLFunctions_4_1_Core_glSampleMaski, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glSampleMaski},
    {sipName_glSamplerParameterf, meth_QOpenGLFunctions_4_1_Core_glSamplerParameterf, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glSamplerParameterf},
    {sipName_glSamplerParameteri, meth_QOpenGLFunctions_4_1_Core_glSamplerParameteri, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glSamplerParameteri},
    {sipName_glScissor, meth_QOpenGLFunctions_4_1_Core_glScissor, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glScissor},
    {sipName_glScissorIndexed, meth_QOpenGLFunctions_4_1_Core_glScissorIndexed, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glScissorIndexed},
    {sipName_glStencilFunc, meth_QOpenGLFunctions_4_1_Core_glStencilFunc, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glStencilFunc},
    {sipName_glStencilFuncSeparate, meth_QOpenGLFunctions_4_1_Core_glStencilFuncSeparate, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glStencilFuncSeparate},
    {sipName_glStencilMask, meth_QOpenGLFunctions_4_1_Core_glStencilMask, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glStencilMask},
    {sipName_glStencilMaskSeparate, meth_QOpenGLFunctions_4_1_Core_glStencilMaskSeparate, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glStencilMaskSeparate},
    {sipName_glStencilOp, meth_QOpenGLFunctions_4_1_Core_glStencilOp, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glStencilOp},
    {sipName_glStencilOpSeparate, meth_QOpenGLFunctions_4_1_Core_glStencilOpSeparate, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glStencilOpSeparate},
    {sipName_glTexBuffer, meth_QOpenGLFunctions_4_1_Core_glTexBuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexBuffer},
    {sipName_glTexImage1D, meth_QOpenGLFunctions_4_1_Core_glTexImage1D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexImage1D},
    {sipName_glTexImage2D, meth_QOpenGLFunctions_4_1_Core_glTexImage2D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexImage2D},
    {sipName_glTexImage2DMultisample, meth_QOpenGLFunctions_4_1_Core_glTexImage2DMultisample, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexImage2DMultisample},
    {sipName_glTexImage3D, meth_QOpenGLFunctions_4_1_Core_glTexImage3D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexImage3D},
    {sipName_glTexImage3DMultisample, meth_QOpenGLFunctions_4_1_Core_glTexImage3DMultisample, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexImage3DMultisample},
    {sipName_glTexParameterf, meth_QOpenGLFunctions_4_1_Core_glTexParameterf, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexParameterf},
    {sipName_glTexParameterfv, meth_QOpenGLFunctions_4_1_Core_glTexParameterfv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexParameterfv},
    {sipName_glTexParameteri, meth_QOpenGLFunctions_4_1_Core_glTexParameteri, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexParameteri},
    {sipName_glTexParameteriv, meth_QOpenGLFunctions_4_1_Core_glTexParameteriv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexParameteriv},
    {sipName_glTexSubImage1D, meth_QOpenGLFunctions_4_1_Core_glTexSubImage1D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexSubImage1D},
    {sipName_glTexSubImage2D, meth_QOpenGLFunctions_4_1_Core_glTexSubImage2D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexSubImage2D},
    {sipName_glTexSubImage3D, meth_QOpenGLFunctions_4_1_Core_glTexSubImage3D, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glTexSubImage3D},
    {sipName_glUniform1d, meth_QOpenGLFunctions_4_1_Core_glUniform1d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform1d},
    {sipName_glUniform1f, meth_QOpenGLFunctions_4_1_Core_glUniform1f, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform1f},
    {sipName_glUniform1fv, meth_QOpenGLFunctions_4_1_Core_glUniform1fv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform1fv},
    {sipName_glUniform1i, meth_QOpenGLFunctions_4_1_Core_glUniform1i, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform1i},
    {sipName_glUniform1iv, meth_QOpenGLFunctions_4_1_Core_glUniform1iv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform1iv},
    {sipName_glUniform1ui, meth_QOpenGLFunctions_4_1_Core_glUniform1ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform1ui},
    {sipName_glUniform2d, meth_QOpenGLFunctions_4_1_Core_glUniform2d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform2d},
    {sipName_glUniform2f, meth_QOpenGLFunctions_4_1_Core_glUniform2f, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform2f},
    {sipName_glUniform2fv, meth_QOpenGLFunctions_4_1_Core_glUniform2fv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform2fv},
    {sipName_glUniform2i, meth_QOpenGLFunctions_4_1_Core_glUniform2i, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform2i},
    {sipName_glUniform2iv, meth_QOpenGLFunctions_4_1_Core_glUniform2iv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform2iv},
    {sipName_glUniform2ui, meth_QOpenGLFunctions_4_1_Core_glUniform2ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform2ui},
    {sipName_glUniform3d, meth_QOpenGLFunctions_4_1_Core_glUniform3d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform3d},
    {sipName_glUniform3f, meth_QOpenGLFunctions_4_1_Core_glUniform3f, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform3f},
    {sipName_glUniform3fv, meth_QOpenGLFunctions_4_1_Core_glUniform3fv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform3fv},
    {sipName_glUniform3i, meth_QOpenGLFunctions_4_1_Core_glUniform3i, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform3i},
    {sipName_glUniform3iv, meth_QOpenGLFunctions_4_1_Core_glUniform3iv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform3iv},
    {sipName_glUniform3ui, meth_QOpenGLFunctions_4_1_Core_glUniform3ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform3ui},
    {sipName_glUniform4d, meth_QOpenGLFunctions_4_1_Core_glUniform4d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform4d},
    {sipName_glUniform4f, meth_QOpenGLFunctions_4_1_Core_glUniform4f, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform4f},
    {sipName_glUniform4fv, meth_QOpenGLFunctions_4_1_Core_glUniform4fv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform4fv},
    {sipName_glUniform4i, meth_QOpenGLFunctions_4_1_Core_glUniform4i, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform4i},
    {sipName_glUniform4iv, meth_QOpenGLFunctions_4_1_Core_glUniform4iv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform4iv},
    {sipName_glUniform4ui, meth_QOpenGLFunctions_4_1_Core_glUniform4ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniform4ui},
    {sipName_glUniformBlockBinding, meth_QOpenGLFunctions_4_1_Core_glUniformBlockBinding, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniformBlockBinding},
    {sipName_glUniformMatrix2fv, meth_QOpenGLFunctions_4_1_Core_glUniformMatrix2fv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniformMatrix2fv},
    {sipName_glUniformMatrix3fv, meth_QOpenGLFunctions_4_1_Core_glUniformMatrix3fv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniformMatrix3fv},
    {sipName_glUniformMatrix4fv, meth_QOpenGLFunctions_4_1_Core_glUniformMatrix4fv, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUniformMatrix4fv},
    {sipName_glUnmapBuffer, meth_QOpenGLFunctions_4_1_Core_glUnmapBuffer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUnmapBuffer},
    {sipName_glUseProgram, meth_QOpenGLFunctions_4_1_Core_glUseProgram, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUseProgram},
    {sipName_glUseProgramStages, meth_QOpenGLFunctions_4_1_Core_glUseProgramStages, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glUseProgramStages},
    {sipName_glValidateProgram, meth_QOpenGLFunctions_4_1_Core_glValidateProgram, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glValidateProgram},
    {sipName_glValidateProgramPipeline, meth_QOpenGLFunctions_4_1_Core_glValidateProgramPipeline, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glValidateProgramPipeline},
    {sipName_glVertexAttribDivisor, meth_QOpenGLFunctions_4_1_Core_glVertexAttribDivisor, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glVertexAttribDivisor},
    {sipName_glVertexAttribL1d, meth_QOpenGLFunctions_4_1_Core_glVertexAttribL1d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glVertexAttribL1d},
    {sipName_glVertexAttribL2d, meth_QOpenGLFunctions_4_1_Core_glVertexAttribL2d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glVertexAttribL2d},
    {sipName_glVertexAttribL3d, meth_QOpenGLFunctions_4_1_Core_glVertexAttribL3d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glVertexAttribL3d},
    {sipName_glVertexAttribL4d, meth_QOpenGLFunctions_4_1_Core_glVertexAttribL4d, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glVertexAttribL4d},
    {sipName_glVertexAttribP1ui, meth_QOpenGLFunctions_4_1_Core_glVertexAttribP1ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glVertexAttribP1ui},
    {sipName_glVertexAttribP2ui, meth_QOpenGLFunctions_4_1_Core_glVertexAttribP2ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glVertexAttribP2ui},
    {sipName_glVertexAttribP3ui, meth_QOpenGLFunctions_4_1_Core_glVertexAttribP3ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glVertexAttribP3ui},
    {sipName_glVertexAttribP4ui, meth_QOpenGLFunctions_4_1_Core_glVertexAttribP4ui, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glVertexAttribP4ui},
    {sipName_glVertexAttribPointer, meth_QOpenGLFunctions_4_1_Core_glVertexAttribPointer, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glVertexAttribPointer},
    {sipName_glViewport, meth_QOpenGLFunctions_4_1_Core_glViewport, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glViewport},
    {sipName_glViewportIndexedf, meth_QOpenGLFunctions_4_1_Core_glViewportIndexedf, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_glViewportIndexedf},
    {sipName_initializeOpenGLFunctions, meth_QOpenGLFunctions_4_1_Core_initializeOpenGLFunctions, METH_VARARGS, doc_QOpenGLFunctions_4_1_Core_initializeOpenGLFunctions}
};

PyDoc_STRVAR(doc_QOpenGLFunctions_4_1_Core, "\1QOpenGLFunctions_4_1_Core()");


sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLFunctions_4_1_Core = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QOpenGLFunctions_4_1_Core,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QOpenGLFunctions_4_1_Core,
        {0, 0, 1},
        247, methods_QOpenGLFunctions_4_1_Core,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QOpenGLFunctions_4_1_Core,
    -1,
    -1,
    supers_QOpenGLFunctions_4_1_Core,
    SIP_NULLPTR,
    init_type_QOpenGLFunctions_4_1_Core,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QOpenGLFunctions_4_1_Core,
    SIP_NULLPTR,
    array_QOpenGLFunctions_4_1_Core,
    SIP_NULLPTR,
    release_QOpenGLFunctions_4_1_Core,
    cast_QOpenGLFunctions_4_1_Core,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QOpenGLFunctions_4_1_Core,
    sizeof (::QOpenGLFunctions_4_1_Core),
};
