/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtCoreAPI_H
#define _QtCoreAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#define PY_SSIZE_T_CLEAN

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QCommandLineParser__OptionsAfterPositionalArgumentsMode 0
#define sipName_QCommandLineParser__OptionsAfterPositionalArgumentsMode &sipStrings_QtCore[0]
#define sipNameNr_56 56
#define sipName_56 &sipStrings_QtCore[56]
#define sipNameNr_109 109
#define sipName_109 &sipStrings_QtCore[109]
#define sipNameNr_QCommandLineParser__SingleDashWordOptionMode 157
#define sipName_QCommandLineParser__SingleDashWordOptionMode &sipStrings_QtCore[157]
#define sipNameNr_202 202
#define sipName_202 &sipStrings_QtCore[202]
#define sipNameNr_QRegularExpression__WildcardConversionOption 247
#define sipName_QRegularExpression__WildcardConversionOption &sipStrings_QtCore[247]
#define sipNameNr_292 292
#define sipName_292 &sipStrings_QtCore[292]
#define sipNameNr_AA_SynthesizeMouseForUnhandledTabletEvents 336
#define sipName_AA_SynthesizeMouseForUnhandledTabletEvents &sipStrings_QtCore[336]
#define sipNameNr_379 379
#define sipName_379 &sipStrings_QtCore[379]
#define sipNameNr_422 422
#define sipName_422 &sipStrings_QtCore[422]
#define sipNameNr_QXmlStreamReader__ReadElementTextBehaviour 465
#define sipName_QXmlStreamReader__ReadElementTextBehaviour &sipStrings_QtCore[465]
#define sipNameNr_AA_SynthesizeMouseForUnhandledTouchEvents 508
#define sipName_AA_SynthesizeMouseForUnhandledTouchEvents &sipStrings_QtCore[508]
#define sipNameNr_AA_SynthesizeTouchForUnhandledMouseEvents 550
#define sipName_AA_SynthesizeTouchForUnhandledMouseEvents &sipStrings_QtCore[550]
#define sipNameNr_AA_UseStyleSheetPropagationInWidgetStyles 592
#define sipName_AA_UseStyleSheetPropagationInWidgetStyles &sipStrings_QtCore[592]
#define sipNameNr_634 634
#define sipName_634 &sipStrings_QtCore[634]
#define sipNameNr_676 676
#define sipName_676 &sipStrings_QtCore[676]
#define sipNameNr_AA_DontCheckOpenGLContextThreadAffinity 717
#define sipName_AA_DontCheckOpenGLContextThreadAffinity &sipStrings_QtCore[717]
#define sipNameNr_QBluetoothPermission__CommunicationMode 757
#define sipName_QBluetoothPermission__CommunicationMode &sipStrings_QtCore[757]
#define sipNameNr_797 797
#define sipName_797 &sipStrings_QtCore[797]
#define sipNameNr_837 837
#define sipName_837 &sipStrings_QtCore[837]
#define sipNameNr_877 877
#define sipName_877 &sipStrings_QtCore[877]
#define sipNameNr_QSystemSemaphore__SystemSemaphoreError 917
#define sipName_QSystemSemaphore__SystemSemaphoreError &sipStrings_QtCore[917]
#define sipNameNr_SouthGeorgiaAndTheSouthSandwichIslands 956
#define sipName_SouthGeorgiaAndTheSouthSandwichIslands &sipStrings_QtCore[956]
#define sipNameNr_setOptionsAfterPositionalArgumentsMode 995
#define sipName_setOptionsAfterPositionalArgumentsMode &sipStrings_QtCore[995]
#define sipNameNr_1034 1034
#define sipName_1034 &sipStrings_QtCore[1034]
#define sipNameNr_1072 1072
#define sipName_1072 &sipStrings_QtCore[1072]
#define sipNameNr_QLocale__FloatingPointPrecisionOption 1110
#define sipName_QLocale__FloatingPointPrecisionOption &sipStrings_QtCore[1110]
#define sipNameNr_QStringConverter__FinalizeResultError 1148
#define sipName_QStringConverter__FinalizeResultError &sipStrings_QtCore[1148]
#define sipNameNr_QAbstractItemModel__CheckIndexOption 1186
#define sipName_QAbstractItemModel__CheckIndexOption &sipStrings_QtCore[1186]
#define sipNameNr_QAbstractItemModel__LayoutChangeHint 1223
#define sipName_QAbstractItemModel__LayoutChangeHint &sipStrings_QtCore[1223]
#define sipNameNr_1260 1260
#define sipName_1260 &sipStrings_QtCore[1260]
#define sipNameNr_1297 1297
#define sipName_1297 &sipStrings_QtCore[1297]
#define sipNameNr_Qt__HighDpiScaleFactorRoundingPolicy 1334
#define sipName_Qt__HighDpiScaleFactorRoundingPolicy &sipStrings_QtCore[1334]
#define sipNameNr_MaximizeUsingFullscreenGeometryHint 1371
#define sipName_MaximizeUsingFullscreenGeometryHint &sipStrings_QtCore[1371]
#define sipNameNr_OptionsAfterPositionalArgumentsMode 20
#define sipName_OptionsAfterPositionalArgumentsMode &sipStrings_QtCore[20]
#define sipNameNr_QAbstractEventDispatcher__TimerInfo 1407
#define sipName_QAbstractEventDispatcher__TimerInfo &sipStrings_QtCore[1407]
#define sipNameNr_QCborStreamReader__StringResultCode 1443
#define sipName_QCborStreamReader__StringResultCode &sipStrings_QtCore[1443]
#define sipNameNr_QDataStream__FloatingPointPrecision 1479
#define sipName_QDataStream__FloatingPointPrecision &sipStrings_QtCore[1479]
#define sipNameNr_1515 1515
#define sipName_1515 &sipStrings_QtCore[1515]
#define sipNameNr_1551 1551
#define sipName_1551 &sipStrings_QtCore[1551]
#define sipNameNr_QProcessEnvironment__Initialization 1587
#define sipName_QProcessEnvironment__Initialization &sipStrings_QtCore[1587]
#define sipNameNr_QTextBoundaryFinder__BoundaryReason 1623
#define sipName_QTextBoundaryFinder__BoundaryReason &sipStrings_QtCore[1623]
#define sipNameNr_SouthGeorgiaAndSouthSandwichIslands 1659
#define sipName_SouthGeorgiaAndSouthSandwichIslands &sipStrings_QtCore[1659]
#define sipNameNr_AA_DontShowShortcutsInContextMenus 1695
#define sipName_AA_DontShowShortcutsInContextMenus &sipStrings_QtCore[1695]
#define sipNameNr_MouseEventSynthesizedByApplication 1730
#define sipName_MouseEventSynthesizedByApplication &sipStrings_QtCore[1730]
#define sipNameNr_QAbstractAnimation__DeletionPolicy 1765
#define sipName_QAbstractAnimation__DeletionPolicy &sipStrings_QtCore[1765]
#define sipNameNr_1800 1800
#define sipName_1800 &sipStrings_QtCore[1800]
#define sipNameNr_1835 1835
#define sipName_1835 &sipStrings_QtCore[1835]
#define sipNameNr_1870 1870
#define sipName_1870 &sipStrings_QtCore[1870]
#define sipNameNr_QItemSelectionModel__SelectionFlag 1905
#define sipName_QItemSelectionModel__SelectionFlag &sipStrings_QtCore[1905]
#define sipNameNr_1940 1940
#define sipName_1940 &sipStrings_QtCore[1940]
#define sipNameNr_1975 1975
#define sipName_1975 &sipStrings_QtCore[1975]
#define sipNameNr_WA_ContentsMarginsRespectsSafeArea 2010
#define sipName_WA_ContentsMarginsRespectsSafeArea &sipStrings_QtCore[2010]
#define sipNameNr_WA_TouchPadAcceptSingleTouchEvents 2045
#define sipName_WA_TouchPadAcceptSingleTouchEvents &sipStrings_QtCore[2045]
#define sipNameNr_AA_DontCreateNativeWidgetSiblings 2080
#define sipName_AA_DontCreateNativeWidgetSiblings &sipStrings_QtCore[2080]
#define sipNameNr_DontCheckSubjectStringMatchOption 2114
#define sipName_DontCheckSubjectStringMatchOption &sipStrings_QtCore[2114]
#define sipNameNr_2148 2148
#define sipName_2148 &sipStrings_QtCore[2148]
#define sipNameNr_2182 2182
#define sipName_2182 &sipStrings_QtCore[2182]
#define sipNameNr_2216 2216
#define sipName_2216 &sipStrings_QtCore[2216]
#define sipNameNr_2250 2250
#define sipName_2250 &sipStrings_QtCore[2250]
#define sipNameNr_2284 2284
#define sipName_2284 &sipStrings_QtCore[2284]
#define sipNameNr_QLocationPermission__Availability 2318
#define sipName_QLocationPermission__Availability &sipStrings_QtCore[2318]
#define sipNameNr_QRegularExpression__PatternOption 2352
#define sipName_QRegularExpression__PatternOption &sipStrings_QtCore[2352]
#define sipNameNr_QTextBoundaryFinder__BoundaryType 2386
#define sipName_QTextBoundaryFinder__BoundaryType &sipStrings_QtCore[2386]
#define sipNameNr_WA_X11NetWmWindowTypeDropDownMenu 2420
#define sipName_WA_X11NetWmWindowTypeDropDownMenu &sipStrings_QtCore[2420]
#define sipNameNr_WA_X11NetWmWindowTypeNotification 2454
#define sipName_WA_X11NetWmWindowTypeNotification &sipStrings_QtCore[2454]
#define sipNameNr_ApplicationLayoutDirectionChange 2488
#define sipName_ApplicationLayoutDirectionChange &sipStrings_QtCore[2488]
#define sipNameNr_HighDpiScaleFactorRoundingPolicy 1338
#define sipName_HighDpiScaleFactorRoundingPolicy &sipStrings_QtCore[1338]
#define sipNameNr_IgnoredGesturesPropagateToParent 2521
#define sipName_IgnoredGesturesPropagateToParent &sipStrings_QtCore[2521]
#define sipNameNr_NavigationModeCursorForceVisible 2554
#define sipName_NavigationModeCursorForceVisible &sipStrings_QtCore[2554]
#define sipNameNr_NonClientAreaMouseButtonDblClick 2587
#define sipName_NonClientAreaMouseButtonDblClick &sipStrings_QtCore[2587]
#define sipNameNr_QByteArray__Base64DecodingStatus 2620
#define sipName_QByteArray__Base64DecodingStatus &sipStrings_QtCore[2620]
#define sipNameNr_2653 2653
#define sipName_2653 &sipStrings_QtCore[2653]
#define sipNameNr_2686 2686
#define sipName_2686 &sipStrings_QtCore[2686]
#define sipNameNr_QSharedMemory__SharedMemoryError 2719
#define sipName_QSharedMemory__SharedMemoryError &sipStrings_QtCore[2719]
#define sipNameNr_QSortFilterProxyModel__Direction 2752
#define sipName_QSortFilterProxyModel__Direction &sipStrings_QtCore[2752]
#define sipNameNr_QStandardPaths__StandardLocation 2785
#define sipName_QStandardPaths__StandardLocation &sipStrings_QtCore[2785]
#define sipNameNr_UnitedStatesMinorOutlyingIslands 2818
#define sipName_UnitedStatesMinorOutlyingIslands &sipStrings_QtCore[2818]
#define sipNameNr_hasRegisteredDataStreamOperators 2851
#define sipName_hasRegisteredDataStreamOperators &sipStrings_QtCore[2851]
#define sipNameNr_hasRegisteredDebugStreamOperator 2884
#define sipName_hasRegisteredDebugStreamOperator &sipStrings_QtCore[2884]
#define sipNameNr_qEnvironmentVariableIntegerValue 2917
#define sipName_qEnvironmentVariableIntegerValue &sipStrings_QtCore[2917]
#define sipNameNr_recursiveFilteringEnabledChanged 2950
#define sipName_recursiveFilteringEnabledChanged &sipStrings_QtCore[2950]
#define sipNameNr_AA_DisableNativeVirtualKeyboard 2983
#define sipName_AA_DisableNativeVirtualKeyboard &sipStrings_QtCore[2983]
#define sipNameNr_NavigationModeKeypadDirectional 3015
#define sipName_NavigationModeKeypadDirectional &sipStrings_QtCore[3015]
#define sipNameNr_NonClientAreaMouseButtonRelease 3047
#define sipName_NonClientAreaMouseButtonRelease &sipStrings_QtCore[3047]
#define sipNameNr_QCalendarPermission__AccessMode 3079
#define sipName_QCalendarPermission__AccessMode &sipStrings_QtCore[3079]
#define sipNameNr_QCommandLineParser__MessageType 3111
#define sipName_QCommandLineParser__MessageType &sipStrings_QtCore[3111]
#define sipNameNr_QContactsPermission__AccessMode 3143
#define sipName_QContactsPermission__AccessMode &sipStrings_QtCore[3143]
#define sipNameNr_QDateTime__TransitionResolution 3175
#define sipName_QDateTime__TransitionResolution &sipStrings_QtCore[3175]
#define sipNameNr_QDeadlineTimer__ForeverConstant 3207
#define sipName_QDeadlineTimer__ForeverConstant &sipStrings_QtCore[3207]
#define sipNameNr_3239 3239
#define sipName_3239 &sipStrings_QtCore[3239]
#define sipNameNr_3271 3271
#define sipName_3271 &sipStrings_QtCore[3271]
#define sipNameNr_3303 3303
#define sipName_3303 &sipStrings_QtCore[3303]
#define sipNameNr_3335 3335
#define sipName_3335 &sipStrings_QtCore[3335]
#define sipNameNr_3367 3367
#define sipName_3367 &sipStrings_QtCore[3367]
#define sipNameNr_QOperatingSystemVersion__OSType 3399
#define sipName_QOperatingSystemVersion__OSType &sipStrings_QtCore[3399]
#define sipNameNr_QProcess__UnixProcessParameters 3431
#define sipName_QProcess__UnixProcessParameters &sipStrings_QtCore[3431]
#define sipNameNr_QRegularExpression__MatchOption 3463
#define sipName_QRegularExpression__MatchOption &sipStrings_QtCore[3463]
#define sipNameNr_QRegularExpressionMatchIterator 3495
#define sipName_QRegularExpressionMatchIterator &sipStrings_QtCore[3495]
#define sipNameNr_QTextStream__RealNumberNotation 3527
#define sipName_QTextStream__RealNumberNotation &sipStrings_QtCore[3527]
#define sipNameNr_QUrl__ComponentFormattingOption 3559
#define sipName_QUrl__ComponentFormattingOption &sipStrings_QtCore[3559]
#define sipNameNr_QUrl__UserInputResolutionOption 3591
#define sipName_QUrl__UserInputResolutionOption &sipStrings_QtCore[3591]
#define sipNameNr_AA_CompressHighFrequencyEvents 3623
#define sipName_AA_CompressHighFrequencyEvents &sipStrings_QtCore[3623]
#define sipNameNr_AA_QtQuickUseDefaultSizePolicy 3654
#define sipName_AA_QtQuickUseDefaultSizePolicy &sipStrings_QtCore[3654]
#define sipNameNr_QRangeModel__AutoConnectPolicy 3685
#define sipName_QRangeModel__AutoConnectPolicy &sipStrings_QtCore[3685]
#define sipNameNr_QXmlStreamNamespaceDeclaration 3716
#define sipName_QXmlStreamNamespaceDeclaration &sipStrings_QtCore[3716]
#define sipNameNr_WA_X11NetWmWindowTypePopupMenu 3747
#define sipName_WA_X11NetWmWindowTypePopupMenu &sipStrings_QtCore[3747]
#define sipNameNr_DisconnectControllingTerminal 3778
#define sipName_DisconnectControllingTerminal &sipStrings_QtCore[3778]
#define sipNameNr_GraphicsSceneMouseDoubleClick 3808
#define sipName_GraphicsSceneMouseDoubleClick &sipStrings_QtCore[3808]
#define sipNameNr_IncludeTrailingZeroesAfterDot 3838
#define sipName_IncludeTrailingZeroesAfterDot &sipStrings_QtCore[3838]
#define sipNameNr_MouseEventSynthesizedBySystem 3868
#define sipName_MouseEventSynthesizedBySystem &sipStrings_QtCore[3868]
#define sipNameNr_NonClientAreaMouseButtonPress 3898
#define sipName_NonClientAreaMouseButtonPress &sipStrings_QtCore[3898]
#define sipNameNr_QAbstractAnimation__Direction 3928
#define sipName_QAbstractAnimation__Direction &sipStrings_QtCore[3928]
#define sipNameNr_QCryptographicHash__Algorithm 3958
#define sipName_QCryptographicHash__Algorithm &sipStrings_QtCore[3958]
#define sipNameNr_QEventLoop__ProcessEventsFlag 3988
#define sipName_QEventLoop__ProcessEventsFlag &sipStrings_QtCore[3988]
#define sipNameNr_4018 4018
#define sipName_4018 &sipStrings_QtCore[4018]
#define sipNameNr_4048 4048
#define sipName_4048 &sipStrings_QtCore[4048]
#define sipNameNr_QLocale__CurrencySymbolFormat 4078
#define sipName_QLocale__CurrencySymbolFormat &sipStrings_QtCore[4078]
#define sipNameNr_QLocationPermission__Accuracy 4108
#define sipName_QLocationPermission__Accuracy &sipStrings_QtCore[4108]
#define sipNameNr_QReadWriteLock__RecursionMode 4138
#define sipName_QReadWriteLock__RecursionMode &sipStrings_QtCore[4138]
#define sipNameNr_QRegularExpression__MatchType 4168
#define sipName_QRegularExpression__MatchType &sipStrings_QtCore[4168]
#define sipNameNr_QXmlStreamNotationDeclaration 4198
#define sipName_QXmlStreamNotationDeclaration &sipStrings_QtCore[4198]
#define sipNameNr_WindowOverridesSystemGestures 4228
#define sipName_WindowOverridesSystemGestures &sipStrings_QtCore[4228]
#define sipNameNr_addExtraNamespaceDeclarations 4258
#define sipName_addExtraNamespaceDeclarations &sipStrings_QtCore[4258]
#define sipNameNr_4288 4288
#define sipName_4288 &sipStrings_QtCore[4288]
#define sipNameNr_FloatingPointPrecisionOption 1119
#define sipName_FloatingPointPrecisionOption &sipStrings_QtCore[1119]
#define sipNameNr_InvertedLandscapeOrientation 4318
#define sipName_InvertedLandscapeOrientation &sipStrings_QtCore[4318]
#define sipNameNr_MSWindowsFixedSizeDialogHint 4347
#define sipName_MSWindowsFixedSizeDialogHint &sipStrings_QtCore[4347]
#define sipNameNr_MouseEventCreatedDoubleClick 4376
#define sipName_MouseEventCreatedDoubleClick &sipStrings_QtCore[4376]
#define sipNameNr_NavigationModeKeypadTabOrder 4405
#define sipName_NavigationModeKeypadTabOrder &sipStrings_QtCore[4405]
#define sipNameNr_ParseAsCompactedShortOptions 4434
#define sipName_ParseAsCompactedShortOptions &sipStrings_QtCore[4434]
#define sipNameNr_QByteArray__FromBase64Result 4463
#define sipName_QByteArray__FromBase64Result &sipStrings_QtCore[4463]
#define sipNameNr_QConcatenateTablesProxyModel 4492
#define sipName_QConcatenateTablesProxyModel &sipStrings_QtCore[4492]
#define sipNameNr_4521 4521
#define sipName_4521 &sipStrings_QtCore[4521]
#define sipNameNr_4550 4550
#define sipName_4550 &sipStrings_QtCore[4550]
#define sipNameNr_4579 4579
#define sipName_4579 &sipStrings_QtCore[4579]
#define sipNameNr_4608 4608
#define sipName_4608 &sipStrings_QtCore[4608]
#define sipNameNr_4637 4637
#define sipName_4637 &sipStrings_QtCore[4637]
#define sipNameNr_QProcess__ProcessChannelMode 4666
#define sipName_QProcess__ProcessChannelMode &sipStrings_QtCore[4666]
#define sipNameNr_QStandardPaths__LocateOption 4695
#define sipName_QStandardPaths__LocateOption &sipStrings_QtCore[4695]
#define sipNameNr_QSystemSemaphore__AccessMode 4724
#define sipName_QSystemSemaphore__AccessMode &sipStrings_QtCore[4724]
#define sipNameNr_RejectTrailingZeroesAfterDot 4753
#define sipName_RejectTrailingZeroesAfterDot &sipStrings_QtCore[4753]
#define sipNameNr_SaintVincentAndTheGrenadines 4782
#define sipName_SaintVincentAndTheGrenadines &sipStrings_QtCore[4782]
#define sipNameNr_Script_InscriptionalParthian 4811
#define sipName_Script_InscriptionalParthian &sipStrings_QtCore[4811]
#define sipNameNr_UnanchoredWildcardConversion 4840
#define sipName_UnanchoredWildcardConversion &sipStrings_QtCore[4840]
#define sipNameNr_WA_DontCreateNativeAncestors 4869
#define sipName_WA_DontCreateNativeAncestors &sipStrings_QtCore[4869]
#define sipNameNr_WA_NoChildEventsFromChildren 4898
#define sipName_WA_NoChildEventsFromChildren &sipStrings_QtCore[4898]
#define sipNameNr_WA_TransparentForMouseEvents 4927
#define sipName_WA_TransparentForMouseEvents &sipStrings_QtCore[4927]
#define sipNameNr_WA_X11NetWmWindowTypeDesktop 4956
#define sipName_WA_X11NetWmWindowTypeDesktop &sipStrings_QtCore[4956]
#define sipNameNr_WA_X11NetWmWindowTypeToolBar 4985
#define sipName_WA_X11NetWmWindowTypeToolBar &sipStrings_QtCore[4985]
#define sipNameNr_WA_X11NetWmWindowTypeToolTip 5014
#define sipName_WA_X11NetWmWindowTypeToolTip &sipStrings_QtCore[5014]
#define sipNameNr_WA_X11NetWmWindowTypeUtility 5043
#define sipName_WA_X11NetWmWindowTypeUtility &sipStrings_QtCore[5043]
#define sipNameNr_addExtraNamespaceDeclaration 5072
#define sipName_addExtraNamespaceDeclaration &sipStrings_QtCore[5072]
#define sipNameNr_filterCaseSensitivityChanged 5101
#define sipName_filterCaseSensitivityChanged &sipStrings_QtCore[5101]
#define sipNameNr_qEnvironmentVariableIntValue 5130
#define sipName_qEnvironmentVariableIntValue &sipStrings_QtCore[5130]
#define sipNameNr_setHandleSourceLayoutChanges 5159
#define sipName_setHandleSourceLayoutChanges &sipStrings_QtCore[5159]
#define sipNameNr_setRecursiveFilteringEnabled 5188
#define sipName_setRecursiveFilteringEnabled &sipStrings_QtCore[5188]
#define sipNameNr_5217 5217
#define sipName_5217 &sipStrings_QtCore[5217]
#define sipNameNr_AA_DontUseNativeMenuWindows 5246
#define sipName_AA_DontUseNativeMenuWindows &sipStrings_QtCore[5246]
#define sipNameNr_AbortOnBase64DecodingErrors 5274
#define sipName_AbortOnBase64DecodingErrors &sipStrings_QtCore[5274]
#define sipNameNr_ApplicationWindowIconChange 5302
#define sipName_ApplicationWindowIconChange &sipStrings_QtCore[5302]
#define sipNameNr_BritishIndianOceanTerritory 5330
#define sipName_BritishIndianOceanTerritory &sipStrings_QtCore[5330]
#define sipNameNr_ExtendedPatternSyntaxOption 5358
#define sipName_ExtendedPatternSyntaxOption &sipStrings_QtCore[5358]
#define sipNameNr_InscriptionalParthianScript 5386
#define sipName_InscriptionalParthianScript &sipStrings_QtCore[5386]
#define sipNameNr_InvertedPortraitOrientation 5414
#define sipName_InvertedPortraitOrientation &sipStrings_QtCore[5414]
#define sipNameNr_Key_Dead_Abovereversedcomma 5442
#define sipName_Key_Dead_Abovereversedcomma &sipStrings_QtCore[5442]
#define sipNameNr_Key_Dead_Longsolidusoverlay 5470
#define sipName_Key_Dead_Longsolidusoverlay &sipStrings_QtCore[5470]
#define sipNameNr_LatinAmericaAndTheCaribbean 5498
#define sipName_LatinAmericaAndTheCaribbean &sipStrings_QtCore[5498]
#define sipNameNr_PrematureEndOfDocumentError 5526
#define sipName_PrematureEndOfDocumentError &sipStrings_QtCore[5526]
#define sipNameNr_QDynamicPropertyChangeEvent 5554
#define sipName_QDynamicPropertyChangeEvent &sipStrings_QtCore[5554]
#define sipNameNr_QFileDevice__FileHandleFlag 5582
#define sipName_QFileDevice__FileHandleFlag &sipStrings_QtCore[5582]
#define sipNameNr_5610 5610
#define sipName_5610 &sipStrings_QtCore[5610]
#define sipNameNr_5638 5638
#define sipName_5638 &sipStrings_QtCore[5638]
#define sipNameNr_5666 5666
#define sipName_5666 &sipStrings_QtCore[5666]
#define sipNameNr_5694 5694
#define sipName_5694 &sipStrings_QtCore[5694]
#define sipNameNr_QIODeviceBase__OpenModeFlag 5722
#define sipName_QIODeviceBase__OpenModeFlag &sipStrings_QtCore[5722]
#define sipNameNr_QJsonParseError__ParseError 5750
#define sipName_QJsonParseError__ParseError &sipStrings_QtCore[5750]
#define sipNameNr_QOperatingSystemVersionBase 5778
#define sipName_QOperatingSystemVersionBase &sipStrings_QtCore[5778]
#define sipNameNr_QTextStream__FieldAlignment 5806
#define sipName_QTextStream__FieldAlignment &sipStrings_QtCore[5806]
#define sipNameNr_QXmlStreamEntityDeclaration 5834
#define sipName_QXmlStreamEntityDeclaration &sipStrings_QtCore[5834]
#define sipNameNr_QXmlStreamReader__TokenType 5862
#define sipName_QXmlStreamReader__TokenType &sipStrings_QtCore[5862]
#define sipNameNr_RejectLeadingZeroInExponent 5890
#define sipName_RejectLeadingZeroInExponent &sipStrings_QtCore[5890]
#define sipNameNr_Script_AnatolianHieroglyphs 5918
#define sipName_Script_AnatolianHieroglyphs &sipStrings_QtCore[5918]
#define sipNameNr_Script_InscriptionalPahlavi 5946
#define sipName_Script_InscriptionalPahlavi &sipStrings_QtCore[5946]
#define sipNameNr_Script_NyiakengPuachueHmong 5974
#define sipName_Script_NyiakengPuachueHmong &sipStrings_QtCore[5974]
#define sipNameNr_UnitedStatesOutlyingIslands 6002
#define sipName_UnitedStatesOutlyingIslands &sipStrings_QtCore[6002]
#define sipNameNr_WA_X11NetWmWindowTypeDialog 6030
#define sipName_WA_X11NetWmWindowTypeDialog &sipStrings_QtCore[6030]
#define sipNameNr_WA_X11NetWmWindowTypeSplash 6058
#define sipName_WA_X11NetWmWindowTypeSplash &sipStrings_QtCore[6058]
#define sipNameNr_WindowContextHelpButtonHint 6086
#define sipName_WindowContextHelpButtonHint &sipStrings_QtCore[6086]
#define sipNameNr_isRecursiveFilteringEnabled 6114
#define sipName_isRecursiveFilteringEnabled &sipStrings_QtCore[6114]
#define sipNameNr_lowestFileDescriptorToClose 6142
#define sipName_lowestFileDescriptorToClose &sipStrings_QtCore[6142]
#define sipNameNr_processingInstructionTarget 6170
#define sipName_processingInstructionTarget &sipStrings_QtCore[6170]
#define sipNameNr_qEnvironmentVariableIsEmpty 6198
#define sipName_qEnvironmentVariableIsEmpty &sipStrings_QtCore[6198]
#define sipNameNr_setSingleDashWordOptionMode 6226
#define sipName_setSingleDashWordOptionMode &sipStrings_QtCore[6226]
#define sipNameNr_wildcardToRegularExpression 6254
#define sipName_wildcardToRegularExpression &sipStrings_QtCore[6254]
#define sipNameNr_AnatolianHieroglyphsScript 6282
#define sipName_AnatolianHieroglyphsScript &sipStrings_QtCore[6282]
#define sipNameNr_DontStartGestureOnChildren 6309
#define sipName_DontStartGestureOnChildren &sipStrings_QtCore[6309]
#define sipNameNr_DotMatchesEverythingOption 6336
#define sipName_DotMatchesEverythingOption &sipStrings_QtCore[6336]
#define sipNameNr_IgnoreBase64DecodingErrors 6363
#define sipName_IgnoreBase64DecodingErrors &sipStrings_QtCore[6363]
#define sipNameNr_InscriptionalPahlaviScript 6390
#define sipName_InscriptionalPahlaviScript &sipStrings_QtCore[6390]
#define sipNameNr_IntersectsItemBoundingRect 6417
#define sipName_IntersectsItemBoundingRect &sipStrings_QtCore[6417]
#define sipNameNr_KeepAspectRatioByExpanding 6444
#define sipName_KeepAspectRatioByExpanding &sipStrings_QtCore[6444]
#define sipNameNr_Key_Dead_Aboveverticalline 6471
#define sipName_Key_Dead_Aboveverticalline &sipStrings_QtCore[6471]
#define sipNameNr_Key_Dead_Belowverticalline 6498
#define sipName_Key_Dead_Belowverticalline &sipStrings_QtCore[6498]
#define sipNameNr_Key_KeyboardBrightnessDown 6525
#define sipName_Key_KeyboardBrightnessDown &sipStrings_QtCore[6525]
#define sipNameNr_MacWindowToolBarButtonHint 6552
#define sipName_MacWindowToolBarButtonHint &sipStrings_QtCore[6552]
#define sipNameNr_ParseAsPositionalArguments 6579
#define sipName_ParseAsPositionalArguments &sipStrings_QtCore[6579]
#define sipNameNr_PartialPreferCompleteMatch 6606
#define sipName_PartialPreferCompleteMatch &sipStrings_QtCore[6606]
#define sipNameNr_QAbstractNativeEventFilter 6633
#define sipName_QAbstractNativeEventFilter &sipStrings_QtCore[6633]
#define sipNameNr_QDirIterator__IteratorFlag 6660
#define sipName_QDirIterator__IteratorFlag &sipStrings_QtCore[6660]
#define sipNameNr_QFileDevice__MemoryMapFlag 6687
#define sipName_QFileDevice__MemoryMapFlag &sipStrings_QtCore[6687]
#define sipNameNr_6714 6714
#define sipName_6714 &sipStrings_QtCore[6714]
#define sipNameNr_6741 6741
#define sipName_6741 &sipStrings_QtCore[6741]
#define sipNameNr_6768 6768
#define sipName_6768 &sipStrings_QtCore[6768]
#define sipNameNr_6795 6795
#define sipName_6795 &sipStrings_QtCore[6795]
#define sipNameNr_6822 6822
#define sipName_6822 &sipStrings_QtCore[6822]
#define sipNameNr_QLocale__MeasurementSystem 6849
#define sipName_QLocale__MeasurementSystem &sipStrings_QtCore[6849]
#define sipNameNr_QMessageAuthenticationCode 6876
#define sipName_QMessageAuthenticationCode &sipStrings_QtCore[6876]
#define sipNameNr_QProcess__InputChannelMode 6903
#define sipName_QProcess__InputChannelMode &sipStrings_QtCore[6903]
#define sipNameNr_QStringConverter__Encoding 6930
#define sipName_QStringConverter__Encoding &sipStrings_QtCore[6930]
#define sipNameNr_QStringConverterBase__Flag 6957
#define sipName_QStringConverterBase__Flag &sipStrings_QtCore[6957]
#define sipNameNr_Qt__ItemSelectionOperation 6984
#define sipName_Qt__ItemSelectionOperation &sipStrings_QtCore[6984]
#define sipNameNr_Script_EgyptianHieroglyphs 7011
#define sipName_Script_EgyptianHieroglyphs &sipStrings_QtCore[7011]
#define sipNameNr_Script_MeroiticHieroglyphs 7038
#define sipName_Script_MeroiticHieroglyphs &sipStrings_QtCore[7038]
#define sipNameNr_SvalbardAndJanMayenIslands 7065
#define sipName_SvalbardAndJanMayenIslands &sipStrings_QtCore[7065]
#define sipNameNr_UseUnicodePropertiesOption 7092
#define sipName_UseUnicodePropertiesOption &sipStrings_QtCore[7092]
#define sipNameNr_WA_MacAlwaysShowToolWindow 7119
#define sipName_WA_MacAlwaysShowToolWindow &sipStrings_QtCore[7119]
#define sipNameNr_WA_WState_ExplicitShowHide 7146
#define sipName_WA_WState_ExplicitShowHide &sipStrings_QtCore[7146]
#define sipNameNr_WA_X11NetWmWindowTypeCombo 7173
#define sipName_WA_X11NetWmWindowTypeCombo &sipStrings_QtCore[7173]
#define sipNameNr_WidgetWithChildrenShortcut 7200
#define sipName_WidgetWithChildrenShortcut &sipStrings_QtCore[7200]
#define sipNameNr_WindowFullscreenButtonHint 7227
#define sipName_WindowFullscreenButtonHint &sipStrings_QtCore[7227]
#define sipNameNr_X11BypassWindowManagerHint 7254
#define sipName_X11BypassWindowManagerHint &sipStrings_QtCore[7254]
#define sipNameNr_autoAcceptChildRowsChanged 7281
#define sipName_autoAcceptChildRowsChanged &sipStrings_QtCore[7281]
#define sipNameNr_defaultQueryValueDelimiter 7308
#define sipName_defaultQueryValueDelimiter &sipStrings_QtCore[7308]
#define sipNameNr_mimeTypeForFileNameAndData 7335
#define sipName_mimeTypeForFileNameAndData &sipStrings_QtCore[7335]
#define sipNameNr_setFilterRegularExpression 7362
#define sipName_setFilterRegularExpression &sipStrings_QtCore[7362]
#define sipNameNr_setHandleSourceDataChanges 7389
#define sipName_setHandleSourceDataChanges &sipStrings_QtCore[7389]
#define sipNameNr_sortCaseSensitivityChanged 7416
#define sipName_sortCaseSensitivityChanged &sipStrings_QtCore[7416]
#define sipNameNr_writeProcessingInstruction 7443
#define sipName_writeProcessingInstruction &sipStrings_QtCore[7443]
#define sipNameNr_AA_DisableShaderDiskCache 7470
#define sipName_AA_DisableShaderDiskCache &sipStrings_QtCore[7470]
#define sipNameNr_AA_MacDontSwapCtrlAndMeta 7496
#define sipName_AA_MacDontSwapCtrlAndMeta &sipStrings_QtCore[7496]
#define sipNameNr_AccessibleDescriptionRole 7522
#define sipName_AccessibleDescriptionRole &sipStrings_QtCore[7522]
#define sipNameNr_AceTransitionalProcessing 7548
#define sipName_AceTransitionalProcessing &sipStrings_QtCore[7548]
#define sipNameNr_AnchorAtOffsetMatchOption 7574
#define sipName_AnchorAtOffsetMatchOption &sipStrings_QtCore[7574]
#define sipNameNr_BypassGraphicsProxyWidget 7600
#define sipName_BypassGraphicsProxyWidget &sipStrings_QtCore[7600]
#define sipNameNr_ComponentFormattingOption 3565
#define sipName_ComponentFormattingOption &sipStrings_QtCore[3565]
#define sipNameNr_DataSizeTraditionalFormat 7626
#define sipName_DataSizeTraditionalFormat &sipStrings_QtCore[7626]
#define sipNameNr_DefaultWildcardConversion 7652
#define sipName_DefaultWildcardConversion &sipStrings_QtCore[7652]
#define sipNameNr_DemocraticRepublicOfCongo 7678
#define sipName_DemocraticRepublicOfCongo &sipStrings_QtCore[7678]
#define sipNameNr_DemocraticRepublicOfKorea 7704
#define sipName_DemocraticRepublicOfKorea &sipStrings_QtCore[7704]
#define sipNameNr_EgyptianHieroglyphsScript 7730
#define sipName_EgyptianHieroglyphsScript &sipStrings_QtCore[7730]
#define sipNameNr_ExportExternalSymbolsHint 7756
#define sipName_ExportExternalSymbolsHint &sipStrings_QtCore[7756]
#define sipNameNr_FrenchSouthernTerritories 7782
#define sipName_FrenchSouthernTerritories &sipStrings_QtCore[7782]
#define sipNameNr_GraphicsSceneMouseRelease 7808
#define sipName_GraphicsSceneMouseRelease &sipStrings_QtCore[7808]
#define sipNameNr_ImhDialableCharactersOnly 7834
#define sipName_ImhDialableCharactersOnly &sipStrings_QtCore[7834]
#define sipNameNr_Key_Dead_Semivoiced_Sound 7860
#define sipName_Key_Dead_Semivoiced_Sound &sipStrings_QtCore[7860]
#define sipNameNr_LinksAccessibleByKeyboard 7886
#define sipName_LinksAccessibleByKeyboard &sipStrings_QtCore[7886]
#define sipNameNr_MouseEventSynthesizedByQt 7912
#define sipName_MouseEventSynthesizedByQt &sipStrings_QtCore[7912]
#define sipNameNr_NonPathWildcardConversion 7938
#define sipName_NonPathWildcardConversion &sipStrings_QtCore[7938]
#define sipNameNr_OmitLeadingZeroInExponent 7964
#define sipName_OmitLeadingZeroInExponent &sipStrings_QtCore[7964]
#define sipNameNr_ParentWindowAboutToChange 7990
#define sipName_ParentWindowAboutToChange &sipStrings_QtCore[7990]
#define sipNameNr_QAbstractAnimation__State 8016
#define sipName_QAbstractAnimation__State &sipStrings_QtCore[8016]
#define sipNameNr_8042 8042
#define sipName_8042 &sipStrings_QtCore[8042]
#define sipNameNr_QJsonDocument__JsonFormat 8068
#define sipName_QJsonDocument__JsonFormat &sipStrings_QtCore[8068]
#define sipNameNr_QLibraryInfo__LibraryPath 8094
#define sipName_QLibraryInfo__LibraryPath &sipStrings_QtCore[8094]
#define sipNameNr_8120 8120
#define sipName_8120 &sipStrings_QtCore[8120]
#define sipNameNr_QLocale__LanguageCodeType 8146
#define sipName_QLocale__LanguageCodeType &sipStrings_QtCore[8146]
#define sipNameNr_QProcess__UnixProcessFlag 8172
#define sipName_QProcess__UnixProcessFlag &sipStrings_QtCore[8172]
#define sipNameNr_QSequentialAnimationGroup 8198
#define sipName_QSequentialAnimationGroup &sipStrings_QtCore[8198]
#define sipNameNr_QSharedMemory__AccessMode 8224
#define sipName_QSharedMemory__AccessMode &sipStrings_QtCore[8224]
#define sipNameNr_QThread__QualityOfService 8250
#define sipName_QThread__QualityOfService &sipStrings_QtCore[8250]
#define sipNameNr_QTimeZone__Initialization 8276
#define sipName_QTimeZone__Initialization &sipStrings_QtCore[8276]
#define sipNameNr_QUrl__AceProcessingOption 8302
#define sipName_QUrl__AceProcessingOption &sipStrings_QtCore[8302]
#define sipNameNr_QUrl__UrlFormattingOption 8328
#define sipName_QUrl__UrlFormattingOption &sipStrings_QtCore[8328]
#define sipNameNr_RequestSoftwareInputPanel 8354
#define sipName_RequestSoftwareInputPanel &sipStrings_QtCore[8354]
#define sipNameNr_SaintVincentAndGrenadines 8380
#define sipName_SaintVincentAndGrenadines &sipStrings_QtCore[8380]
#define sipNameNr_Script_CanadianAboriginal 8406
#define sipName_Script_CanadianAboriginal &sipStrings_QtCore[8406]
#define sipNameNr_StandardMoroccanTamazight 8432
#define sipName_StandardMoroccanTamazight &sipStrings_QtCore[8432]
#define sipNameNr_TextIncludeTrailingSpaces 8458
#define sipName_TextIncludeTrailingSpaces &sipStrings_QtCore[8458]
#define sipNameNr_UnitedStatesVirginIslands 8484
#define sipName_UnitedStatesVirginIslands &sipStrings_QtCore[8484]
#define sipNameNr_UserInputResolutionOption 3597
#define sipName_UserInputResolutionOption &sipStrings_QtCore[3597]
#define sipNameNr_WA_InputMethodTransparent 8510
#define sipName_WA_InputMethodTransparent &sipStrings_QtCore[8510]
#define sipNameNr_WA_NoChildEventsForParent 8536
#define sipName_WA_NoChildEventsForParent &sipStrings_QtCore[8536]
#define sipNameNr_WA_X11NetWmWindowTypeDock 8562
#define sipName_WA_X11NetWmWindowTypeDock &sipStrings_QtCore[8562]
#define sipNameNr_WA_X11NetWmWindowTypeMenu 8588
#define sipName_WA_X11NetWmWindowTypeMenu &sipStrings_QtCore[8588]
#define sipNameNr_WindowTransparentForInput 8614
#define sipName_WindowTransparentForInput &sipStrings_QtCore[8614]
#define sipNameNr_changePersistentIndexList 8640
#define sipName_changePersistentIndexList &sipStrings_QtCore[8640]
#define sipNameNr_columnIntersectsSelection 8666
#define sipName_columnIntersectsSelection &sipStrings_QtCore[8666]
#define sipNameNr_defaultQueryPairDelimiter 8692
#define sipName_defaultQueryPairDelimiter &sipStrings_QtCore[8692]
#define sipNameNr_handleSourceLayoutChanges 8718
#define sipName_handleSourceLayoutChanges &sipStrings_QtCore[8718]
#define sipNameNr_processingInstructionData 8744
#define sipName_processingInstructionData &sipStrings_QtCore[8744]
#define sipNameNr_qEnvironmentVariableIsSet 8770
#define sipName_qEnvironmentVariableIsSet &sipStrings_QtCore[8770]
#define sipNameNr_readAndAppendToUtf8String 8796
#define sipName_readAndAppendToUtf8String &sipStrings_QtCore[8796]
#define sipNameNr_setApplicationDescription 8822
#define sipName_setApplicationDescription &sipStrings_QtCore[8822]
#define sipNameNr_setFloatingPointPrecision 8848
#define sipName_setFloatingPointPrecision &sipStrings_QtCore[8848]
#define sipNameNr_std__chrono__milliseconds 8874
#define sipName_std__chrono__milliseconds &sipStrings_QtCore[8874]
#define sipNameNr_AA_DisableSessionManager 8900
#define sipName_AA_DisableSessionManager &sipStrings_QtCore[8900]
#define sipNameNr_ApplicationPaletteChange 8925
#define sipName_ApplicationPaletteChange &sipStrings_QtCore[8925]
#define sipNameNr_BlockingQueuedConnection 8950
#define sipName_BlockingQueuedConnection &sipStrings_QtCore[8950]
#define sipNameNr_CanadianAboriginalScript 8975
#define sipName_CanadianAboriginalScript &sipStrings_QtCore[8975]
#define sipNameNr_ContainsItemBoundingRect 9000
#define sipName_ContainsItemBoundingRect &sipStrings_QtCore[9000]
#define sipNameNr_ErrorOnUnexpectedElement 9025
#define sipName_ErrorOnUnexpectedElement &sipStrings_QtCore[9025]
#define sipNameNr_GraphicsSceneContextMenu 9050
#define sipName_GraphicsSceneContextMenu &sipStrings_QtCore[9050]
#define sipNameNr_ImInputItemClipRectangle 9075
#define sipName_ImInputItemClipRectangle &sipStrings_QtCore[9075]
#define sipNameNr_InvertedGreedinessOption 9100
#define sipName_InvertedGreedinessOption &sipStrings_QtCore[9100]
#define sipNameNr_Key_Dead_Belowcircumflex 9125
#define sipName_Key_Dead_Belowcircumflex &sipStrings_QtCore[9125]
#define sipNameNr_Key_KeyboardBrightnessUp 9150
#define sipName_Key_KeyboardBrightnessUp &sipStrings_QtCore[9150]
#define sipNameNr_Key_MediaTogglePlayPause 9175
#define sipName_Key_MediaTogglePlayPause &sipStrings_QtCore[9175]
#define sipNameNr_MouseEventNotSynthesized 9200
#define sipName_MouseEventNotSynthesized &sipStrings_QtCore[9200]
#define sipNameNr_NavigationModeCursorAuto 9225
#define sipName_NavigationModeCursorAuto &sipStrings_QtCore[9225]
#define sipNameNr_NoTitleBarBackgroundHint 9250
#define sipName_NoTitleBarBackgroundHint &sipStrings_QtCore[9250]
#define sipNameNr_QAbstractEventDispatcher 9275
#define sipName_QAbstractEventDispatcher &sipStrings_QtCore[9275]
#define sipNameNr_QByteArray__Base64Option 9300
#define sipName_QByteArray__Base64Option &sipStrings_QtCore[9300]
#define sipNameNr_QCommandLineOption__Flag 9325
#define sipName_QCommandLineOption__Flag &sipStrings_QtCore[9325]
#define sipNameNr_QElapsedTimer__ClockType 9350
#define sipName_QElapsedTimer__ClockType &sipStrings_QtCore[9350]
#define sipNameNr_QLineF__IntersectionType 9375
#define sipName_QLineF__IntersectionType &sipStrings_QtCore[9375]
#define sipNameNr_QMimeDatabase__MatchMode 9400
#define sipName_QMimeDatabase__MatchMode &sipStrings_QtCore[9400]
#define sipNameNr_QProcess__ProcessChannel 9425
#define sipName_QProcess__ProcessChannel &sipStrings_QtCore[9425]
#define sipNameNr_QXmlStreamEntityResolver 9450
#define sipName_QXmlStreamEntityResolver &sipStrings_QtCore[9450]
#define sipNameNr_Qt__ApplicationAttribute 9475
#define sipName_Qt__ApplicationAttribute &sipStrings_QtCore[9475]
#define sipNameNr_ReadElementTextBehaviour 483
#define sipName_ReadElementTextBehaviour &sipStrings_QtCore[483]
#define sipNameNr_Script_CaucasianAlbanian 9500
#define sipName_Script_CaucasianAlbanian &sipStrings_QtCore[9500]
#define sipNameNr_Script_KhitanSmallScript 9525
#define sipName_Script_KhitanSmallScript &sipStrings_QtCore[9525]
#define sipNameNr_SingleDashWordOptionMode 177
#define sipName_SingleDashWordOptionMode &sipStrings_QtCore[177]
#define sipNameNr_TextSelectableByKeyboard 9550
#define sipName_TextSelectableByKeyboard &sipStrings_QtCore[9550]
#define sipNameNr_ToolButtonTextBesideIcon 9575
#define sipName_ToolButtonTextBesideIcon &sipStrings_QtCore[9575]
#define sipNameNr_TraditionalChineseScript 9600
#define sipName_TraditionalChineseScript &sipStrings_QtCore[9600]
#define sipNameNr_WA_NoX11EventCompression 9625
#define sipName_WA_NoX11EventCompression &sipStrings_QtCore[9625]
#define sipNameNr_WA_ShowWithoutActivating 9650
#define sipName_WA_ShowWithoutActivating &sipStrings_QtCore[9650]
#define sipNameNr_WA_TranslucentBackground 9675
#define sipName_WA_TranslucentBackground &sipStrings_QtCore[9675]
#define sipNameNr_WA_X11NetWmWindowTypeDND 9700
#define sipName_WA_X11NetWmWindowTypeDND &sipStrings_QtCore[9700]
#define sipNameNr_WildcardConversionOption 267
#define sipName_WildcardConversionOption &sipStrings_QtCore[267]
#define sipNameNr_WindowDoesNotAcceptFocus 9725
#define sipName_WindowDoesNotAcceptFocus &sipStrings_QtCore[9725]
#define sipNameNr_WindowMaximizeButtonHint 9750
#define sipName_WindowMaximizeButtonHint &sipStrings_QtCore[9750]
#define sipNameNr_WindowMinimizeButtonHint 9775
#define sipName_WindowMinimizeButtonHint &sipStrings_QtCore[9775]
#define sipNameNr_autoConnectPolicyChanged 9800
#define sipName_autoConnectPolicyChanged &sipStrings_QtCore[9800]
#define sipNameNr_clearPositionalArguments 9825
#define sipName_clearPositionalArguments &sipStrings_QtCore[9825]
#define sipNameNr_columnsAboutToBeInserted 9850
#define sipName_columnsAboutToBeInserted &sipStrings_QtCore[9850]
#define sipNameNr_dynamicSortFilterChanged 9875
#define sipName_dynamicSortFilterChanged &sipStrings_QtCore[9875]
#define sipNameNr_fromMSecsSinceStartOfDay 9900
#define sipName_fromMSecsSinceStartOfDay &sipStrings_QtCore[9900]
#define sipNameNr_hasStandaloneDeclaration 9925
#define sipName_hasStandaloneDeclaration &sipStrings_QtCore[9925]
#define sipNameNr_installNativeEventFilter 9950
#define sipName_installNativeEventFilter &sipStrings_QtCore[9950]
#define sipNameNr_readAndAppendToByteArray 9975
#define sipName_readAndAppendToByteArray &sipStrings_QtCore[9975]
#define sipNameNr_setFilterCaseSensitivity 10000
#define sipName_setFilterCaseSensitivity &sipStrings_QtCore[10000]
#define sipNameNr_setGenerateByteOrderMark 10025
#define sipName_setGenerateByteOrderMark &sipStrings_QtCore[10025]
#define sipNameNr_setStandardOutputProcess 10050
#define sipName_setStandardOutputProcess &sipStrings_QtCore[10050]
#define sipNameNr_setUnixProcessParameters 10075
#define sipName_setUnixProcessParameters &sipStrings_QtCore[10075]
#define sipNameNr_windowsIdToDefaultIanaId 10100
#define sipName_windowsIdToDefaultIanaId &sipStrings_QtCore[10100]
#define sipNameNr_AA_CompressTabletEvents 10125
#define sipName_AA_CompressTabletEvents &sipStrings_QtCore[10125]
#define sipNameNr_AA_DontShowIconsInMenus 10149
#define sipName_AA_DontShowIconsInMenus &sipStrings_QtCore[10149]
#define sipNameNr_AA_DontUseNativeDialogs 10173
#define sipName_AA_DontUseNativeDialogs &sipStrings_QtCore[10173]
#define sipNameNr_AA_DontUseNativeMenuBar 10197
#define sipName_AA_DontUseNativeMenuBar &sipStrings_QtCore[10197]
#define sipNameNr_ActiveWindowFocusReason 10221
#define sipName_ActiveWindowFocusReason &sipStrings_QtCore[10221]
#define sipNameNr_BypassWindowManagerHint 7257
#define sipName_BypassWindowManagerHint &sipStrings_QtCore[7257]
#define sipNameNr_CaucasianAlbanianScript 10245
#define sipName_CaucasianAlbanianScript &sipStrings_QtCore[10245]
#define sipNameNr_CentralMoroccoTamazight 10269
#define sipName_CentralMoroccoTamazight &sipStrings_QtCore[10269]
#define sipNameNr_CloseSoftwareInputPanel 10293
#define sipName_CloseSoftwareInputPanel &sipStrings_QtCore[10293]
#define sipNameNr_DefaultTwoDigitBaseYear 10317
#define sipName_DefaultTwoDigitBaseYear &sipStrings_QtCore[10317]
#define sipNameNr_FindChildrenRecursively 10341
#define sipName_FindChildrenRecursively &sipStrings_QtCore[10341]
#define sipNameNr_GraphicsSceneHoverEnter 10365
#define sipName_GraphicsSceneHoverEnter &sipStrings_QtCore[10365]
#define sipNameNr_GraphicsSceneHoverLeave 10389
#define sipName_GraphicsSceneHoverLeave &sipStrings_QtCore[10389]
#define sipNameNr_GraphicsSceneMousePress 10413
#define sipName_GraphicsSceneMousePress &sipStrings_QtCore[10413]
#define sipNameNr_HeardAndMcDonaldIslands 10437
#define sipName_HeardAndMcDonaldIslands &sipStrings_QtCore[10437]
#define sipNameNr_ImhFormattedNumbersOnly 10461
#define sipName_ImhFormattedNumbersOnly &sipStrings_QtCore[10461]
#define sipNameNr_Key_Dead_Belowdiaeresis 10485
#define sipName_Key_Dead_Belowdiaeresis &sipStrings_QtCore[10485]
#define sipNameNr_PartialPreferFirstMatch 10509
#define sipName_PartialPreferFirstMatch &sipStrings_QtCore[10509]
#define sipNameNr_PyQt6_sip_simplewrapper 10533
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtCore[10533]
#define sipNameNr_QCalendar__YearMonthDay 10557
#define sipName_QCalendar__YearMonthDay &sipStrings_QtCore[10557]
#define sipNameNr_QCborStreamReader__Type 10581
#define sipName_QCborStreamReader__Type &sipStrings_QtCore[10581]
#define sipNameNr_QFileDevice__Permission 10605
#define sipName_QFileDevice__Permission &sipStrings_QtCore[10605]
#define sipNameNr_10629 10629
#define sipName_10629 &sipStrings_QtCore[10629]
#define sipNameNr_10653 10653
#define sipName_10653 &sipStrings_QtCore[10653]
#define sipNameNr_10677 10677
#define sipName_10677 &sipStrings_QtCore[10677]
#define sipNameNr_10701 10701
#define sipName_10701 &sipStrings_QtCore[10701]
#define sipNameNr_10725 10725
#define sipName_10725 &sipStrings_QtCore[10725]
#define sipNameNr_10749 10749
#define sipName_10749 &sipStrings_QtCore[10749]
#define sipNameNr_QLocale__DataSizeFormat 10773
#define sipName_QLocale__DataSizeFormat &sipStrings_QtCore[10773]
#define sipNameNr_QLocale__QuotationStyle 10797
#define sipName_QLocale__QuotationStyle &sipStrings_QtCore[10797]
#define sipNameNr_QMetaMethod__MethodType 10821
#define sipName_QMetaMethod__MethodType &sipStrings_QtCore[10821]
#define sipNameNr_QMetaObject__Connection 10845
#define sipName_QMetaObject__Connection &sipStrings_QtCore[10845]
#define sipNameNr_QOperatingSystemVersion 10869
#define sipName_QOperatingSystemVersion &sipStrings_QtCore[10869]
#define sipNameNr_QParallelAnimationGroup 10893
#define sipName_QParallelAnimationGroup &sipStrings_QtCore[10893]
#define sipNameNr_QRegularExpressionMatch 10917
#define sipName_QRegularExpressionMatch &sipStrings_QtCore[10917]
#define sipNameNr_QTextStream__NumberFlag 10941
#define sipName_QTextStream__NumberFlag &sipStrings_QtCore[10941]
#define sipNameNr_QXmlStreamReader__Error 10965
#define sipName_QXmlStreamReader__Error &sipStrings_QtCore[10965]
#define sipNameNr_QXmlStreamWriter__Error 10989
#define sipName_QXmlStreamWriter__Error &sipStrings_QtCore[10989]
#define sipNameNr_Qt__ImageConversionFlag 11013
#define sipName_Qt__ImageConversionFlag &sipStrings_QtCore[11013]
#define sipNameNr_Qt__TextInteractionFlag 11037
#define sipName_Qt__TextInteractionFlag &sipStrings_QtCore[11037]
#define sipNameNr_SimplifiedChineseScript 11061
#define sipName_SimplifiedChineseScript &sipStrings_QtCore[11061]
#define sipNameNr_TextJustificationForced 11085
#define sipName_TextJustificationForced &sipStrings_QtCore[11085]
#define sipNameNr_ToolButtonTextUnderIcon 11109
#define sipName_ToolButtonTextUnderIcon &sipStrings_QtCore[11109]
#define sipNameNr_WA_ForceUpdatesDisabled 11133
#define sipName_WA_ForceUpdatesDisabled &sipStrings_QtCore[11133]
#define sipNameNr_WA_LayoutUsesWidgetRect 11157
#define sipName_WA_LayoutUsesWidgetRect &sipStrings_QtCore[11157]
#define sipNameNr_WA_WState_ConfigPending 11181
#define sipName_WA_WState_ConfigPending &sipStrings_QtCore[11181]
#define sipNameNr_WA_WState_OwnSizePolicy 11205
#define sipName_WA_WState_OwnSizePolicy &sipStrings_QtCore[11205]
#define sipNameNr_WhiteSpaceModeUndefined 11229
#define sipName_WhiteSpaceModeUndefined &sipStrings_QtCore[11229]
#define sipNameNr_WindowMinMaxButtonsHint 11253
#define sipName_WindowMinMaxButtonsHint &sipStrings_QtCore[11253]
#define sipNameNr_WindowStaysOnBottomHint 11277
#define sipName_WindowStaysOnBottomHint &sipStrings_QtCore[11277]
#define sipNameNr_columnsAboutToBeRemoved 11301
#define sipName_columnsAboutToBeRemoved &sipStrings_QtCore[11301]
#define sipNameNr_currentAnimationChanged 11325
#define sipName_currentAnimationChanged &sipStrings_QtCore[11325]
#define sipNameNr_filterRegularExpression 11349
#define sipName_filterRegularExpression &sipStrings_QtCore[11349]
#define sipNameNr_handleSourceDataChanges 11373
#define sipName_handleSourceDataChanges &sipStrings_QtCore[11373]
#define sipNameNr_invalidateColumnsFilter 11397
#define sipName_invalidateColumnsFilter &sipStrings_QtCore[11397]
#define sipNameNr_isInterruptionRequested 11421
#define sipName_isInterruptionRequested &sipStrings_QtCore[11421]
#define sipNameNr_isProcessingInstruction 11445
#define sipName_isProcessingInstruction &sipStrings_QtCore[11445]
#define sipNameNr_qSetRealNumberPrecision 11469
#define sipName_qSetRealNumberPrecision &sipStrings_QtCore[11469]
#define sipNameNr_qUnregisterResourceData 11493
#define sipName_qUnregisterResourceData &sipStrings_QtCore[11493]
#define sipNameNr_readyReadStandardOutput 11517
#define sipName_readyReadStandardOutput &sipStrings_QtCore[11517]
#define sipNameNr_removeNativeEventFilter 11541
#define sipName_removeNativeEventFilter &sipStrings_QtCore[11541]
#define sipNameNr_resolveUndeclaredEntity 11565
#define sipName_resolveUndeclaredEntity &sipStrings_QtCore[11565]
#define sipNameNr_setAutoFormattingIndent 11589
#define sipName_setAutoFormattingIndent &sipStrings_QtCore[11589]
#define sipNameNr_setEntityExpansionLimit 11613
#define sipName_setEntityExpansionLimit &sipStrings_QtCore[11613]
#define sipNameNr_setPreciseRemainingTime 11637
#define sipName_setPreciseRemainingTime &sipStrings_QtCore[11637]
#define sipNameNr_AA_ShareOpenGLContexts 11661
#define sipName_AA_ShareOpenGLContexts &sipStrings_QtCore[11661]
#define sipNameNr_AnchorHorizontalCenter 11684
#define sipName_AnchorHorizontalCenter &sipStrings_QtCore[11684]
#define sipNameNr_ApplicationDeactivated 11707
#define sipName_ApplicationDeactivated &sipStrings_QtCore[11707]
#define sipNameNr_ApplicationStateChange 11730
#define sipName_ApplicationStateChange &sipStrings_QtCore[11730]
#define sipNameNr_CentralAfricanRepublic 11753
#define sipName_CentralAfricanRepublic &sipStrings_QtCore[11753]
#define sipNameNr_ConicalGradientPattern 11776
#define sipName_ConicalGradientPattern &sipStrings_QtCore[11776]
#define sipNameNr_DevicePixelRatioChange 11799
#define sipName_DevicePixelRatioChange &sipStrings_QtCore[11799]
#define sipNameNr_ExcludeSocketNotifiers 11822
#define sipName_ExcludeSocketNotifiers &sipStrings_QtCore[11822]
#define sipNameNr_ExcludeUserInputEvents 11845
#define sipName_ExcludeUserInputEvents &sipStrings_QtCore[11845]
#define sipNameNr_ExpandedClientAreaHint 11868
#define sipName_ExpandedClientAreaHint &sipStrings_QtCore[11868]
#define sipNameNr_FileMetadataChangeTime 11891
#define sipName_FileMetadataChangeTime &sipStrings_QtCore[11891]
#define sipNameNr_FindDirectChildrenOnly 11914
#define sipName_FindDirectChildrenOnly &sipStrings_QtCore[11914]
#define sipNameNr_FloatingPointPrecision 1492
#define sipName_FloatingPointPrecision &sipStrings_QtCore[1492]
#define sipNameNr_ForwardedOutputChannel 11937
#define sipName_ForwardedOutputChannel &sipStrings_QtCore[11937]
#define sipNameNr_GraphicsSceneDragEnter 11960
#define sipName_GraphicsSceneDragEnter &sipStrings_QtCore[11960]
#define sipNameNr_GraphicsSceneDragLeave 11983
#define sipName_GraphicsSceneDragLeave &sipStrings_QtCore[11983]
#define sipNameNr_GraphicsSceneHoverMove 12006
#define sipName_GraphicsSceneHoverMove &sipStrings_QtCore[12006]
#define sipNameNr_GraphicsSceneMouseMove 12029
#define sipName_GraphicsSceneMouseMove &sipStrings_QtCore[12029]
#define sipNameNr_ImhEmailCharactersOnly 12052
#define sipName_ImhEmailCharactersOnly &sipStrings_QtCore[12052]
#define sipNameNr_ItemSelectionOperation 6988
#define sipName_ItemSelectionOperation &sipStrings_QtCore[6988]
#define sipNameNr_Key_Dead_Capital_Schwa 12075
#define sipName_Key_Dead_Capital_Schwa &sipStrings_QtCore[12075]
#define sipNameNr_Key_Dead_Invertedbreve 12098
#define sipName_Key_Dead_Invertedbreve &sipStrings_QtCore[12098]
#define sipNameNr_Key_KeyboardLightOnOff 12121
#define sipName_Key_KeyboardLightOnOff &sipStrings_QtCore[12121]
#define sipNameNr_LibraryExecutablesPath 12144
#define sipName_LibraryExecutablesPath &sipStrings_QtCore[12144]
#define sipNameNr_LinksAccessibleByMouse 12167
#define sipName_LinksAccessibleByMouse &sipStrings_QtCore[12167]
#define sipNameNr_MatchRegularExpression 12190
#define sipName_MatchRegularExpression &sipStrings_QtCore[12190]
#define sipNameNr_NoDropShadowWindowHint 12213
#define sipName_NoDropShadowWindowHint &sipStrings_QtCore[12213]
#define sipNameNr_NonClientAreaMouseMove 12236
#define sipName_NonClientAreaMouseMove &sipStrings_QtCore[12236]
#define sipNameNr_NorthernMarianaIslands 12259
#define sipName_NorthernMarianaIslands &sipStrings_QtCore[12259]
#define sipNameNr_PalestinianTerritories 12282
#define sipName_PalestinianTerritories &sipStrings_QtCore[12282]
#define sipNameNr_PeoplesRepublicOfCongo 12305
#define sipName_PeoplesRepublicOfCongo &sipStrings_QtCore[12305]
#define sipNameNr_QDataStream__ByteOrder 12328
#define sipName_QDataStream__ByteOrder &sipStrings_QtCore[12328]
#define sipNameNr_QFileDevice__FileError 12351
#define sipName_QFileDevice__FileError &sipStrings_QtCore[12351]
#define sipNameNr_12374 12374
#define sipName_12374 &sipStrings_QtCore[12374]
#define sipNameNr_12397 12397
#define sipName_12397 &sipStrings_QtCore[12397]
#define sipNameNr_12420 12420
#define sipName_12420 &sipStrings_QtCore[12420]
#define sipNameNr_QGenericReturnArgument 12443
#define sipName_QGenericReturnArgument &sipStrings_QtCore[12443]
#define sipNameNr_12466 12466
#define sipName_12466 &sipStrings_QtCore[12466]
#define sipNameNr_QProcess__ProcessError 12489
#define sipName_QProcess__ProcessError &sipStrings_QtCore[12489]
#define sipNameNr_QProcess__ProcessState 12512
#define sipName_QProcess__ProcessState &sipStrings_QtCore[12512]
#define sipNameNr_QResource__Compression 12535
#define sipName_QResource__Compression &sipStrings_QtCore[12535]
#define sipNameNr_QTextStreamManipulator 12558
#define sipName_QTextStreamManipulator &sipStrings_QtCore[12558]
#define sipNameNr_Qt__ContextMenuTrigger 12581
#define sipName_Qt__ContextMenuTrigger &sipStrings_QtCore[12581]
#define sipNameNr_Qt__ContrastPreference 12604
#define sipName_Qt__ContrastPreference &sipStrings_QtCore[12604]
#define sipNameNr_Qt__TransformationMode 12627
#define sipName_Qt__TransformationMode &sipStrings_QtCore[12627]
#define sipNameNr_Qt__WindowFrameSection 12650
#define sipName_Qt__WindowFrameSection &sipStrings_QtCore[12650]
#define sipNameNr_ReceivePartialGestures 12673
#define sipName_ReceivePartialGestures &sipStrings_QtCore[12673]
#define sipNameNr_SaintPierreAndMiquelon 12696
#define sipName_SaintPierreAndMiquelon &sipStrings_QtCore[12696]
#define sipNameNr_Script_ImperialAramaic 12719
#define sipName_Script_ImperialAramaic &sipStrings_QtCore[12719]
#define sipNameNr_Script_MeroiticCursive 12742
#define sipName_Script_MeroiticCursive &sipStrings_QtCore[12742]
#define sipNameNr_Script_OldNorthArabian 12765
#define sipName_Script_OldNorthArabian &sipStrings_QtCore[12765]
#define sipNameNr_Script_OldSouthArabian 12788
#define sipName_Script_OldSouthArabian &sipStrings_QtCore[12788]
#define sipNameNr_Script_ZanabazarSquare 12811
#define sipName_Script_ZanabazarSquare &sipStrings_QtCore[12811]
#define sipNameNr_SmartZoomNativeGesture 12834
#define sipName_SmartZoomNativeGesture &sipStrings_QtCore[12834]
#define sipNameNr_TextBrowserInteraction 12857
#define sipName_TextBrowserInteraction &sipStrings_QtCore[12857]
#define sipNameNr_TouchPointUnknownState 12880
#define sipName_TouchPointUnknownState &sipStrings_QtCore[12880]
#define sipNameNr_UnexpectedElementError 12903
#define sipName_UnexpectedElementError &sipStrings_QtCore[12903]
#define sipNameNr_WA_KeyboardFocusChange 12926
#define sipName_WA_KeyboardFocusChange &sipStrings_QtCore[12926]
#define sipNameNr_WA_WState_CompressKeys 12949
#define sipName_WA_WState_CompressKeys &sipStrings_QtCore[12949]
#define sipNameNr_WA_WState_InPaintEvent 12972
#define sipName_WA_WState_InPaintEvent &sipStrings_QtCore[12972]
#define sipNameNr_WA_X11DoNotAcceptFocus 12995
#define sipName_WA_X11DoNotAcceptFocus &sipStrings_QtCore[12995]
#define sipNameNr_WallisAndFutunaIslands 13018
#define sipName_WallisAndFutunaIslands &sipStrings_QtCore[13018]
#define sipNameNr_applicationDescription 13041
#define sipName_applicationDescription &sipStrings_QtCore[13041]
#define sipNameNr_currentCpuArchitecture 13064
#define sipName_currentCpuArchitecture &sipStrings_QtCore[13064]
#define sipNameNr_currentMSecsSinceEpoch 13087
#define sipName_currentMSecsSinceEpoch &sipStrings_QtCore[13087]
#define sipNameNr_fixedSecondsAheadOfUtc 13110
#define sipName_fixedSecondsAheadOfUtc &sipStrings_QtCore[13110]
#define sipNameNr_floatingPointPrecision 13133
#define sipName_floatingPointPrecision &sipStrings_QtCore[13133]
#define sipNameNr_isDefaultConstructible 13156
#define sipName_isDefaultConstructible &sipStrings_QtCore[13156]
#define sipNameNr_layoutAboutToBeChanged 13179
#define sipName_layoutAboutToBeChanged &sipStrings_QtCore[13179]
#define sipNameNr_legacyDefaultTypeForOs 13202
#define sipName_legacyDefaultTypeForOs &sipStrings_QtCore[13202]
#define sipNameNr_mapSelectionFromSource 13225
#define sipName_mapSelectionFromSource &sipStrings_QtCore[13225]
#define sipNameNr_qInstallMessageHandler 13248
#define sipName_qInstallMessageHandler &sipStrings_QtCore[13248]
#define sipNameNr_readyReadStandardError 13271
#define sipName_readyReadStandardError &sipStrings_QtCore[13271]
#define sipNameNr_rowIntersectsSelection 13294
#define sipName_rowIntersectsSelection &sipStrings_QtCore[13294]
#define sipNameNr_setAutoAcceptChildRows 13317
#define sipName_setAutoAcceptChildRows &sipStrings_QtCore[13317]
#define sipNameNr_setCurrentWriteChannel 13340
#define sipName_setCurrentWriteChannel &sipStrings_QtCore[13340]
#define sipNameNr_setDirectWriteFallback 13363
#define sipName_setDirectWriteFallback &sipStrings_QtCore[13363]
#define sipNameNr_setNamespaceProcessing 13386
#define sipName_setNamespaceProcessing &sipStrings_QtCore[13386]
#define sipNameNr_setRealNumberPrecision 13409
#define sipName_setRealNumberPrecision &sipStrings_QtCore[13409]
#define sipNameNr_setSortCaseSensitivity 13432
#define sipName_setSortCaseSensitivity &sipStrings_QtCore[13432]
#define sipNameNr_sortLocaleAwareChanged 13455
#define sipName_sortLocaleAwareChanged &sipStrings_QtCore[13455]
#define sipNameNr_13478 13478
#define sipName_13478 &sipStrings_QtCore[13478]
#define sipNameNr_13501 13501
#define sipName_13501 &sipStrings_QtCore[13501]
#define sipNameNr_unregisterResourceData 13524
#define sipName_unregisterResourceData &sipStrings_QtCore[13524]
#define sipNameNr_AA_ForceRasterWidgets 13547
#define sipName_AA_ForceRasterWidgets &sipStrings_QtCore[13547]
#define sipNameNr_ApplicationDeactivate 13569
#define sipName_ApplicationDeactivate &sipStrings_QtCore[13569]
#define sipNameNr_ApplicationFontChange 13591
#define sipName_ApplicationFontChange &sipStrings_QtCore[13591]
#define sipNameNr_CaseInsensitiveOption 13613
#define sipName_CaseInsensitiveOption &sipStrings_QtCore[13613]
#define sipNameNr_CentralAtlasTamazight 13635
#define sipName_CentralAtlasTamazight &sipStrings_QtCore[13635]
#define sipNameNr_DynamicPropertyChange 13657
#define sipName_DynamicPropertyChange &sipStrings_QtCore[13657]
#define sipNameNr_FloatingPointShortest 13679
#define sipName_FloatingPointShortest &sipStrings_QtCore[13679]
#define sipNameNr_ForwardedErrorChannel 13701
#define sipName_ForwardedErrorChannel &sipStrings_QtCore[13701]
#define sipNameNr_ForwardedInputChannel 13723
#define sipName_ForwardedInputChannel &sipStrings_QtCore[13723]
#define sipNameNr_GenericConfigLocation 13745
#define sipName_GenericConfigLocation &sipStrings_QtCore[13745]
#define sipNameNr_GraphicsSceneDragMove 13767
#define sipName_GraphicsSceneDragMove &sipStrings_QtCore[13767]
#define sipNameNr_HanWithBopomofoScript 13789
#define sipName_HanWithBopomofoScript &sipStrings_QtCore[13789]
#define sipNameNr_IllegalEscapeSequence 13811
#define sipName_IllegalEscapeSequence &sipStrings_QtCore[13811]
#define sipNameNr_ImhExclusiveInputMask 13833
#define sipName_ImhExclusiveInputMask &sipStrings_QtCore[13833]
#define sipNameNr_ImperialAramaicScript 13855
#define sipName_ImperialAramaicScript &sipStrings_QtCore[13855]
#define sipNameNr_IsUnsignedEnumeration 13877
#define sipName_IsUnsignedEnumeration &sipStrings_QtCore[13877]
#define sipNameNr_Key_Dead_Voiced_Sound 13899
#define sipName_Key_Dead_Voiced_Sound &sipStrings_QtCore[13899]
#define sipNameNr_Key_Hiragana_Katakana 13921
#define sipName_Key_Hiragana_Katakana &sipStrings_QtCore[13921]
#define sipNameNr_Key_MonBrightnessDown 13943
#define sipName_Key_MonBrightnessDown &sipStrings_QtCore[13943]
#define sipNameNr_Key_MultipleCandidate 13965
#define sipName_Key_MultipleCandidate &sipStrings_QtCore[13965]
#define sipNameNr_Key_PreviousCandidate 13987
#define sipName_Key_PreviousCandidate &sipStrings_QtCore[13987]
#define sipNameNr_LayoutDirectionChange 2499
#define sipName_LayoutDirectionChange &sipStrings_QtCore[2499]
#define sipNameNr_LinearGradientPattern 14009
#define sipName_LinearGradientPattern &sipStrings_QtCore[14009]
#define sipNameNr_LoadArchiveMemberHint 14031
#define sipName_LoadArchiveMemberHint &sipStrings_QtCore[14031]
#define sipNameNr_MeroiticCursiveScript 14053
#define sipName_MeroiticCursiveScript &sipStrings_QtCore[14053]
#define sipNameNr_MissingValueSeparator 14075
#define sipName_MissingValueSeparator &sipStrings_QtCore[14075]
#define sipNameNr_NeedsCopyConstruction 14097
#define sipName_NeedsCopyConstruction &sipStrings_QtCore[14097]
#define sipNameNr_NeedsMoveConstruction 14119
#define sipName_NeedsMoveConstruction &sipStrings_QtCore[14119]
#define sipNameNr_NormalizePathSegments 14141
#define sipName_NormalizePathSegments &sipStrings_QtCore[14141]
#define sipNameNr_OldNorthArabianScript 14163
#define sipName_OldNorthArabianScript &sipStrings_QtCore[14163]
#define sipNameNr_OldSouthArabianScript 14185
#define sipName_OldSouthArabianScript &sipStrings_QtCore[14185]
#define sipNameNr_PollardPhoneticScript 14207
#define sipName_PollardPhoneticScript &sipStrings_QtCore[14207]
#define sipNameNr_ProcessingInstruction 7448
#define sipName_ProcessingInstruction &sipStrings_QtCore[7448]
#define sipNameNr_QFileDevice__FileTime 14229
#define sipName_QFileDevice__FileTime &sipStrings_QtCore[14229]
#define sipNameNr_14251 14251
#define sipName_14251 &sipStrings_QtCore[14251]
#define sipNameNr_14273 14273
#define sipName_14273 &sipStrings_QtCore[14273]
#define sipNameNr_14295 14295
#define sipName_14295 &sipStrings_QtCore[14295]
#define sipNameNr_14317 14317
#define sipName_14317 &sipStrings_QtCore[14317]
#define sipNameNr_QLocale__NumberOption 14339
#define sipName_QLocale__NumberOption &sipStrings_QtCore[14339]
#define sipNameNr_QLocale__TagSeparator 14361
#define sipName_QLocale__TagSeparator &sipStrings_QtCore[14361]
#define sipNameNr_QMicrophonePermission 14383
#define sipName_QMicrophonePermission &sipStrings_QtCore[14383]
#define sipNameNr_QObjectCleanupHandler 14405
#define sipName_QObjectCleanupHandler &sipStrings_QtCore[14405]
#define sipNameNr_QPersistentModelIndex 14427
#define sipName_QPersistentModelIndex &sipStrings_QtCore[14427]
#define sipNameNr_QSocketNotifier__Type 14449
#define sipName_QSocketNotifier__Type &sipStrings_QtCore[14449]
#define sipNameNr_QSortFilterProxyModel 14471
#define sipName_QSortFilterProxyModel &sipStrings_QtCore[14471]
#define sipNameNr_QTimeZone__OffsetData 14493
#define sipName_QTimeZone__OffsetData &sipStrings_QtCore[14493]
#define sipNameNr_Qt__ContextMenuPolicy 14515
#define sipName_Qt__ContextMenuPolicy &sipStrings_QtCore[14515]
#define sipNameNr_Qt__ItemSelectionMode 14537
#define sipName_Qt__ItemSelectionMode &sipStrings_QtCore[14537]
#define sipNameNr_Qt__NativeGestureType 14559
#define sipName_Qt__NativeGestureType &sipStrings_QtCore[14559]
#define sipNameNr_Qt__ScreenOrientation 14581
#define sipName_Qt__ScreenOrientation &sipStrings_QtCore[14581]
#define sipNameNr_RadialGradientPattern 14603
#define sipName_RadialGradientPattern &sipStrings_QtCore[14603]
#define sipNameNr_RangeModelAdapterRole 14625
#define sipName_RangeModelAdapterRole &sipStrings_QtCore[14625]
#define sipNameNr_ResolveAllSymbolsHint 14647
#define sipName_ResolveAllSymbolsHint &sipStrings_QtCore[14647]
#define sipNameNr_SafeAreaMarginsChange 14669
#define sipName_SafeAreaMarginsChange &sipStrings_QtCore[14669]
#define sipNameNr_Script_HanifiRohingya 14691
#define sipName_Script_HanifiRohingya &sipStrings_QtCore[14691]
#define sipNameNr_Script_PsalterPahlavi 14713
#define sipName_Script_PsalterPahlavi &sipStrings_QtCore[14713]
#define sipNameNr_TextEditorInteraction 14735
#define sipName_TextEditorInteraction &sipStrings_QtCore[14735]
#define sipNameNr_TextSelectableByMouse 14757
#define sipName_TextSelectableByMouse &sipStrings_QtCore[14757]
#define sipNameNr_ToolButtonFollowStyle 14779
#define sipName_ToolButtonFollowStyle &sipStrings_QtCore[14779]
#define sipNameNr_TurksAndCaicosIslands 14801
#define sipName_TurksAndCaicosIslands &sipStrings_QtCore[14801]
#define sipNameNr_UnboundedIntersection 14823
#define sipName_UnboundedIntersection &sipStrings_QtCore[14823]
#define sipNameNr_UnixProcessParameters 3441
#define sipName_UnixProcessParameters &sipStrings_QtCore[3441]
#define sipNameNr_WA_AlwaysShowToolTips 14845
#define sipName_WA_AlwaysShowToolTips &sipStrings_QtCore[14845]
#define sipNameNr_WA_InputMethodEnabled 14867
#define sipName_WA_InputMethodEnabled &sipStrings_QtCore[14867]
#define sipNameNr_WA_LayoutOnEntireRect 14889
#define sipName_WA_LayoutOnEntireRect &sipStrings_QtCore[14889]
#define sipNameNr_WA_NoMousePropagation 14911
#define sipName_WA_NoMousePropagation &sipStrings_QtCore[14911]
#define sipNameNr_WA_NoSystemBackground 14933
#define sipName_WA_NoSystemBackground &sipStrings_QtCore[14933]
#define sipNameNr_WA_PendingResizeEvent 14955
#define sipName_WA_PendingResizeEvent &sipStrings_QtCore[14955]
#define sipNameNr_WA_SetLayoutDirection 14977
#define sipName_WA_SetLayoutDirection &sipStrings_QtCore[14977]
#define sipNameNr_WindowCloseButtonHint 14999
#define sipName_WindowCloseButtonHint &sipStrings_QtCore[14999]
#define sipNameNr_WindowShadeButtonHint 15021
#define sipName_WindowShadeButtonHint &sipStrings_QtCore[15021]
#define sipNameNr_addCubicBezierSegment 15043
#define sipName_addCubicBezierSegment &sipStrings_QtCore[15043]
#define sipNameNr_addPositionalArgument 15065
#define sipName_addPositionalArgument &sipStrings_QtCore[15065]
#define sipNameNr_changePersistentIndex 15087
#define sipName_changePersistentIndex &sipStrings_QtCore[15087]
#define sipNameNr_columnsAboutToBeMoved 15109
#define sipName_columnsAboutToBeMoved &sipStrings_QtCore[15109]
#define sipNameNr_currentSecsSinceEpoch 15131
#define sipName_currentSecsSinceEpoch &sipStrings_QtCore[15131]
#define sipNameNr_filterCaseSensitivity 15153
#define sipName_filterCaseSensitivity &sipStrings_QtCore[15153]
#define sipNameNr_fromSecondsAheadOfUtc 15175
#define sipName_fromSecondsAheadOfUtc &sipStrings_QtCore[15175]
#define sipNameNr_generateByteOrderMark 15197
#define sipName_generateByteOrderMark &sipStrings_QtCore[15197]
#define sipNameNr_isTimeZoneIdAvailable 15219
#define sipName_isTimeZoneIdAvailable &sipStrings_QtCore[15219]
#define sipNameNr_matchCenturyToWeekday 15241
#define sipName_matchCenturyToWeekday &sipStrings_QtCore[15241]
#define sipNameNr_nameFiltersFromString 15263
#define sipName_nameFiltersFromString &sipStrings_QtCore[15263]
#define sipNameNr_namespaceDeclarations 15285
#define sipName_namespaceDeclarations &sipStrings_QtCore[15285]
#define sipNameNr_pyqtSetPickleProtocol 15307
#define sipName_pyqtSetPickleProtocol &sipStrings_QtCore[15307]
#define sipNameNr_qRegisterResourceData 15329
#define sipName_qRegisterResourceData &sipStrings_QtCore[15329]
#define sipNameNr_readAllStandardOutput 15351
#define sipName_readAllStandardOutput &sipStrings_QtCore[15351]
#define sipNameNr_readAndAppendToString 15373
#define sipName_readAndAppendToString &sipStrings_QtCore[15373]
#define sipNameNr_relativePropertyIndex 15395
#define sipName_relativePropertyIndex &sipStrings_QtCore[15395]
#define sipNameNr_rowsAboutToBeInserted 15417
#define sipName_rowsAboutToBeInserted &sipStrings_QtCore[15417]
#define sipNameNr_setApplicationVersion 15439
#define sipName_setApplicationVersion &sipStrings_QtCore[15439]
#define sipNameNr_setAtomicSyncRequired 15461
#define sipName_setAtomicSyncRequired &sipStrings_QtCore[15461]
#define sipNameNr_setCommunicationModes 15483
#define sipName_setCommunicationModes &sipStrings_QtCore[15483]
#define sipNameNr_setCurrentReadChannel 15505
#define sipName_setCurrentReadChannel &sipStrings_QtCore[15505]
#define sipNameNr_setFileNameAndVersion 15527
#define sipName_setFileNameAndVersion &sipStrings_QtCore[15527]
#define sipNameNr_setOrganizationDomain 15549
#define sipName_setOrganizationDomain &sipStrings_QtCore[15549]
#define sipNameNr_setProcessChannelMode 15571
#define sipName_setProcessChannelMode &sipStrings_QtCore[15571]
#define sipNameNr_setProcessEnvironment 15593
#define sipName_setProcessEnvironment &sipStrings_QtCore[15593]
#define sipNameNr_setRealNumberNotation 15615
#define sipName_setRealNumberNotation &sipStrings_QtCore[15615]
#define sipNameNr_setStandardOutputFile 15637
#define sipName_setStandardOutputFile &sipStrings_QtCore[15637]
#define sipNameNr_setStopWritingOnError 15659
#define sipName_setStopWritingOnError &sipStrings_QtCore[15659]
#define sipNameNr_setTerminationEnabled 15681
#define sipName_setTerminationEnabled &sipStrings_QtCore[15681]
#define sipNameNr_standaloneWeekDayName 15703
#define sipName_standaloneWeekDayName &sipStrings_QtCore[15703]
#define sipNameNr_startOnReservedThread 15725
#define sipName_startOnReservedThread &sipStrings_QtCore[15725]
#define sipNameNr_15747 15747
#define sipName_15747 &sipStrings_QtCore[15747]
#define sipNameNr_unixProcessParameters 15769
#define sipName_unixProcessParameters &sipStrings_QtCore[15769]
#define sipNameNr_writeDefaultNamespace 15791
#define sipName_writeDefaultNamespace &sipStrings_QtCore[15791]
#define sipNameNr_AA_PluginApplication 15813
#define sipName_AA_PluginApplication &sipStrings_QtCore[15813]
#define sipNameNr_AA_UseSoftwareOpenGL 15834
#define sipName_AA_UseSoftwareOpenGL &sipStrings_QtCore[15834]
#define sipNameNr_AlignAccountingStyle 15855
#define sipName_AlignAccountingStyle &sipStrings_QtCore[15855]
#define sipNameNr_AlignHorizontal_Mask 15876
#define sipName_AlignHorizontal_Mask &sipStrings_QtCore[15876]
#define sipNameNr_AmericanSignLanguage 15897
#define sipName_AmericanSignLanguage &sipStrings_QtCore[15897]
#define sipNameNr_AnchorVerticalCenter 15918
#define sipName_AnchorVerticalCenter &sipStrings_QtCore[15918]
#define sipNameNr_AndroidJellyBean_MR1 15939
#define sipName_AndroidJellyBean_MR1 &sipStrings_QtCore[15939]
#define sipNameNr_AndroidJellyBean_MR2 15960
#define sipName_AndroidJellyBean_MR2 &sipStrings_QtCore[15960]
#define sipNameNr_AppLocalDataLocation 15981
#define sipName_AppLocalDataLocation &sipStrings_QtCore[15981]
#define sipNameNr_ApplicationActivated 16002
#define sipName_ApplicationActivated &sipStrings_QtCore[16002]
#define sipNameNr_ApplicationAttribute 9479
#define sipName_ApplicationAttribute &sipStrings_QtCore[9479]
#define sipNameNr_ApplicationSuspended 16023
#define sipName_ApplicationSuspended &sipStrings_QtCore[16023]
#define sipNameNr_ApplicationsLocation 16044
#define sipName_ApplicationsLocation &sipStrings_QtCore[16044]
#define sipNameNr_Base64DecodingStatus 2632
#define sipName_Base64DecodingStatus &sipStrings_QtCore[2632]
#define sipNameNr_BosniaAndHerzegovina 16065
#define sipName_BosniaAndHerzegovina &sipStrings_QtCore[16065]
#define sipNameNr_BosniaAndHerzegowina 16086
#define sipName_BosniaAndHerzegowina &sipStrings_QtCore[16086]
#define sipNameNr_BottomDockWidgetArea 16107
#define sipName_BottomDockWidgetArea &sipStrings_QtCore[16107]
#define sipNameNr_BritishVirginIslands 16128
#define sipName_BritishVirginIslands &sipStrings_QtCore[16128]
#define sipNameNr_CaribbeanNetherlands 16149
#define sipName_CaribbeanNetherlands &sipStrings_QtCore[16149]
#define sipNameNr_CloseFileDescriptors 16170
#define sipName_CloseFileDescriptors &sipStrings_QtCore[16170]
#define sipNameNr_ConvertInvalidToNull 16191
#define sipName_ConvertInvalidToNull &sipStrings_QtCore[16191]
#define sipNameNr_CurrencySymbolFormat 4087
#define sipName_CurrencySymbolFormat &sipStrings_QtCore[4087]
#define sipNameNr_DefaultNumberOptions 16212
#define sipName_DefaultNumberOptions &sipStrings_QtCore[16212]
#define sipNameNr_FileModificationTime 16233
#define sipName_FileModificationTime &sipStrings_QtCore[16233]
#define sipNameNr_GenericCacheLocation 16254
#define sipName_GenericCacheLocation &sipStrings_QtCore[16254]
#define sipNameNr_GenericStateLocation 16275
#define sipName_GenericStateLocation &sipStrings_QtCore[16275]
#define sipNameNr_ImhUrlCharactersOnly 16296
#define sipName_ImhUrlCharactersOnly &sipStrings_QtCore[16296]
#define sipNameNr_IncludeChildElements 16317
#define sipName_IncludeChildElements &sipStrings_QtCore[16317]
#define sipNameNr_InitialSortOrderRole 16338
#define sipName_InitialSortOrderRole &sipStrings_QtCore[16338]
#define sipNameNr_ItemNeverHasChildren 16359
#define sipName_ItemNeverHasChildren &sipStrings_QtCore[16359]
#define sipNameNr_Key_ApplicationRight 16380
#define sipName_Key_ApplicationRight &sipStrings_QtCore[16380]
#define sipNameNr_Key_BrightnessAdjust 16401
#define sipName_Key_BrightnessAdjust &sipStrings_QtCore[16401]
#define sipNameNr_Key_Dead_Belowmacron 16422
#define sipName_Key_Dead_Belowmacron &sipStrings_QtCore[16422]
#define sipNameNr_Key_Dead_Doubleacute 16443
#define sipName_Key_Dead_Doubleacute &sipStrings_QtCore[16443]
#define sipNameNr_Key_Dead_Doublegrave 16464
#define sipName_Key_Dead_Doublegrave &sipStrings_QtCore[16464]
#define sipNameNr_Key_Dead_Small_Schwa 16485
#define sipName_Key_Dead_Small_Schwa &sipStrings_QtCore[16485]
#define sipNameNr_Key_Hangul_PostHanja 16506
#define sipName_Key_Hangul_PostHanja &sipStrings_QtCore[16506]
#define sipNameNr_Key_LastNumberRedial 16527
#define sipName_Key_LastNumberRedial &sipStrings_QtCore[16527]
#define sipNameNr_Key_ToggleCallHangup 16548
#define sipName_Key_ToggleCallHangup &sipStrings_QtCore[16548]
#define sipNameNr_KeyboardLayoutChange 16569
#define sipName_KeyboardLayoutChange &sipStrings_QtCore[16569]
#define sipNameNr_KeyboardModifierMask 16590
#define sipName_KeyboardModifierMask &sipStrings_QtCore[16590]
#define sipNameNr_LandscapeOrientation 4326
#define sipName_LandscapeOrientation &sipStrings_QtCore[4326]
#define sipNameNr_MissingNameSeparator 16611
#define sipName_MissingNameSeparator &sipStrings_QtCore[16611]
#define sipNameNr_PreferDaylightSaving 16632
#define sipName_PreferDaylightSaving &sipStrings_QtCore[16632]
#define sipNameNr_PsalterPahlaviScript 16653
#define sipName_PsalterPahlaviScript &sipStrings_QtCore[16653]
#define sipNameNr_QBluetoothPermission 16674
#define sipName_QBluetoothPermission &sipStrings_QtCore[16674]
#define sipNameNr_QDataStream__Version 16695
#define sipName_QDataStream__Version &sipStrings_QtCore[16695]
#define sipNameNr_QDateTime__YearRange 16716
#define sipName_QDateTime__YearRange &sipStrings_QtCore[16716]
#define sipNameNr_16737 16737
#define sipName_16737 &sipStrings_QtCore[16737]
#define sipNameNr_16758 16758
#define sipName_16758 &sipStrings_QtCore[16758]
#define sipNameNr_16779 16779
#define sipName_16779 &sipStrings_QtCore[16779]
#define sipNameNr_16800 16800
#define sipName_16800 &sipStrings_QtCore[16800]
#define sipNameNr_QLockFile__LockError 16821
#define sipName_QLockFile__LockError &sipStrings_QtCore[16821]
#define sipNameNr_QProcess__ExitStatus 16842
#define sipName_QProcess__ExitStatus &sipStrings_QtCore[16842]
#define sipNameNr_QStringConverterBase 16863
#define sipName_QStringConverterBase &sipStrings_QtCore[16863]
#define sipNameNr_QTimeLine__Direction 16884
#define sipName_QTimeLine__Direction &sipStrings_QtCore[16884]
#define sipNameNr_QTransposeProxyModel 16905
#define sipName_QTransposeProxyModel &sipStrings_QtCore[16905]
#define sipNameNr_QXmlStreamAttributes 16926
#define sipName_QXmlStreamAttributes &sipStrings_QtCore[16926]
#define sipNameNr_Qt__ApplicationState 16947
#define sipName_Qt__ApplicationState &sipStrings_QtCore[16947]
#define sipNameNr_Qt__CoordinateSystem 16968
#define sipName_Qt__CoordinateSystem &sipStrings_QtCore[16968]
#define sipNameNr_Qt__InputMethodQuery 16989
#define sipName_Qt__InputMethodQuery &sipStrings_QtCore[16989]
#define sipNameNr_Qt__KeyboardModifier 17010
#define sipName_Qt__KeyboardModifier &sipStrings_QtCore[17010]
#define sipNameNr_Qt__MouseEventSource 17031
#define sipName_Qt__MouseEventSource &sipStrings_QtCore[17031]
#define sipNameNr_Qt__PermissionStatus 17052
#define sipName_Qt__PermissionStatus &sipStrings_QtCore[17052]
#define sipNameNr_Qt__TabFocusBehavior 17073
#define sipName_Qt__TabFocusBehavior &sipStrings_QtCore[17073]
#define sipNameNr_RejectGroupSeparator 17094
#define sipName_RejectGroupSeparator &sipStrings_QtCore[17094]
#define sipNameNr_SingleShotConnection 17115
#define sipName_SingleShotConnection &sipStrings_QtCore[17115]
#define sipNameNr_SmoothTransformation 17136
#define sipName_SmoothTransformation &sipStrings_QtCore[17136]
#define sipNameNr_SystemSemaphoreError 935
#define sipName_SystemSemaphoreError &sipStrings_QtCore[935]
#define sipNameNr_TabFocusListControls 17157
#define sipName_TabFocusListControls &sipStrings_QtCore[17157]
#define sipNameNr_TabFocusTextControls 17178
#define sipName_TabFocusTextControls &sipStrings_QtCore[17178]
#define sipNameNr_TabletEnterProximity 17199
#define sipName_TabletEnterProximity &sipStrings_QtCore[17199]
#define sipNameNr_TabletLeaveProximity 17220
#define sipName_TabletLeaveProximity &sipStrings_QtCore[17220]
#define sipNameNr_TabletTrackingChange 17241
#define sipName_TabletTrackingChange &sipStrings_QtCore[17241]
#define sipNameNr_ThresholdAlphaDither 17262
#define sipName_ThresholdAlphaDither &sipStrings_QtCore[17262]
#define sipNameNr_TimeCriticalPriority 17283
#define sipName_TimeCriticalPriority &sipStrings_QtCore[17283]
#define sipNameNr_TouchPointStationary 17304
#define sipName_TouchPointStationary &sipStrings_QtCore[17304]
#define sipNameNr_TraditionalHanScript 17325
#define sipName_TraditionalHanScript &sipStrings_QtCore[17325]
#define sipNameNr_TransitionResolution 3186
#define sipName_TransitionResolution &sipStrings_QtCore[3186]
#define sipNameNr_WA_AcceptTouchEvents 17346
#define sipName_WA_AcceptTouchEvents &sipStrings_QtCore[17346]
#define sipNameNr_WA_MacOpaqueSizeGrip 17367
#define sipName_WA_MacOpaqueSizeGrip &sipStrings_QtCore[17367]
#define sipNameNr_WA_WState_Reparented 17388
#define sipName_WA_WState_Reparented &sipStrings_QtCore[17388]
#define sipNameNr_WA_WindowPropagation 17409
#define sipName_WA_WindowPropagation &sipStrings_QtCore[17409]
#define sipNameNr_WindowStaysOnTopHint 17430
#define sipName_WindowStaysOnTopHint &sipStrings_QtCore[17430]
#define sipNameNr_WindowSystemMenuHint 17451
#define sipName_WindowSystemMenuHint &sipStrings_QtCore[17451]
#define sipNameNr_autoFormattingIndent 17472
#define sipName_autoFormattingIndent &sipStrings_QtCore[17472]
#define sipNameNr_availableTimeZoneIds 17493
#define sipName_availableTimeZoneIds &sipStrings_QtCore[17493]
#define sipNameNr_buildCpuArchitecture 17514
#define sipName_buildCpuArchitecture &sipStrings_QtCore[17514]
#define sipNameNr_compressionAlgorithm 17535
#define sipName_compressionAlgorithm &sipStrings_QtCore[17535]
#define sipNameNr_currentColumnChanged 17556
#define sipName_currentColumnChanged &sipStrings_QtCore[17556]
#define sipNameNr_dynamicPropertyNames 17577
#define sipName_dynamicPropertyNames &sipStrings_QtCore[17577]
#define sipNameNr_emitSelectionChanged 17598
#define sipName_emitSelectionChanged &sipStrings_QtCore[17598]
#define sipNameNr_entityExpansionLimit 17619
#define sipName_entityExpansionLimit &sipStrings_QtCore[17619]
#define sipNameNr_fromNativeSeparators 17640
#define sipName_fromNativeSeparators &sipStrings_QtCore[17640]
#define sipNameNr_invalidateRowsFilter 17661
#define sipName_invalidateRowsFilter &sipStrings_QtCore[17661]
#define sipNameNr_isAtomicSyncRequired 17682
#define sipName_isAtomicSyncRequired &sipStrings_QtCore[17682]
#define sipNameNr_isEqualityComparable 17703
#define sipName_isEqualityComparable &sipStrings_QtCore[17703]
#define sipNameNr_isStandaloneDocument 17724
#define sipName_isStandaloneDocument &sipStrings_QtCore[17724]
#define sipNameNr_isTransactionStarted 17745
#define sipName_isTransactionStarted &sipStrings_QtCore[17745]
#define sipNameNr_mapSelectionToSource 17766
#define sipName_mapSelectionToSource &sipStrings_QtCore[17766]
#define sipNameNr_mimeTypesForFileName 17787
#define sipName_mimeTypesForFileName &sipStrings_QtCore[17787]
#define sipNameNr_msecsSinceStartOfDay 17808
#define sipName_msecsSinceStartOfDay &sipStrings_QtCore[17808]
#define sipNameNr_notationDeclarations 17829
#define sipName_notationDeclarations &sipStrings_QtCore[17829]
#define sipNameNr_pyqtRestoreInputHook 17850
#define sipName_pyqtRestoreInputHook &sipStrings_QtCore[17850]
#define sipNameNr_qEnvironmentVariable 17871
#define sipName_qEnvironmentVariable &sipStrings_QtCore[17871]
#define sipNameNr_readAllStandardError 17892
#define sipName_readAllStandardError &sipStrings_QtCore[17892]
#define sipNameNr_readNextStartElement 17913
#define sipName_readNextStartElement &sipStrings_QtCore[17913]
#define sipNameNr_registerResourceData 11496
#define sipName_registerResourceData &sipStrings_QtCore[11496]
#define sipNameNr_rowsAboutToBeRemoved 17934
#define sipName_rowsAboutToBeRemoved &sipStrings_QtCore[17934]
#define sipNameNr_setAutoConnectPolicy 17955
#define sipName_setAutoConnectPolicy &sipStrings_QtCore[17955]
#define sipNameNr_setAutoDetectUnicode 17976
#define sipName_setAutoDetectUnicode &sipStrings_QtCore[17976]
#define sipNameNr_setDynamicSortFilter 17997
#define sipName_setDynamicSortFilter &sipStrings_QtCore[17997]
#define sipNameNr_setFilterFixedString 18018
#define sipName_setFilterFixedString &sipStrings_QtCore[18018]
#define sipNameNr_setIgnorePunctuation 18039
#define sipName_setIgnorePunctuation &sipStrings_QtCore[18039]
#define sipNameNr_setStandardErrorFile 18060
#define sipName_setStandardErrorFile &sipStrings_QtCore[18060]
#define sipNameNr_setStandardInputFile 18081
#define sipName_setStandardInputFile &sipStrings_QtCore[18081]
#define sipNameNr_std__chrono__seconds 18102
#define sipName_std__chrono__seconds &sipStrings_QtCore[18102]
#define sipNameNr_supportedDragActions 18123
#define sipName_supportedDragActions &sipStrings_QtCore[18123]
#define sipNameNr_supportedDropActions 18144
#define sipName_supportedDropActions &sipStrings_QtCore[18144]
#define sipNameNr_timeZoneAbbreviation 18165
#define sipName_timeZoneAbbreviation &sipStrings_QtCore[18165]
#define sipNameNr_writeEntityReference 18186
#define sipName_writeEntityReference &sipStrings_QtCore[18186]
#define sipNameNr_AA_UseDesktopOpenGL 18207
#define sipName_AA_UseDesktopOpenGL &sipStrings_QtCore[18207]
#define sipNameNr_AceProcessingOption 8308
#define sipName_AceProcessingOption &sipStrings_QtCore[8308]
#define sipNameNr_AndroidLollipop_MR1 18227
#define sipName_AndroidLollipop_MR1 &sipStrings_QtCore[18227]
#define sipNameNr_ApplicationActivate 18247
#define sipName_ApplicationActivate &sipStrings_QtCore[18247]
#define sipNameNr_ApplicationInactive 18267
#define sipName_ApplicationInactive &sipStrings_QtCore[18267]
#define sipNameNr_ApplicationShortcut 18287
#define sipName_ApplicationShortcut &sipStrings_QtCore[18287]
#define sipNameNr_BoundedIntersection 18307
#define sipName_BoundedIntersection &sipStrings_QtCore[18307]
#define sipNameNr_CurrencyDisplayName 18327
#define sipName_CurrencyDisplayName &sipStrings_QtCore[18327]
#define sipNameNr_CustomizeWindowHint 18347
#define sipName_CustomizeWindowHint &sipStrings_QtCore[18347]
#define sipNameNr_FinalizeResultError 1166
#define sipName_FinalizeResultError &sipStrings_QtCore[1166]
#define sipNameNr_FramelessWindowHint 18367
#define sipName_FramelessWindowHint &sipStrings_QtCore[18367]
#define sipNameNr_GenericDataLocation 18387
#define sipName_GenericDataLocation &sipStrings_QtCore[18387]
#define sipNameNr_GraphicsSceneResize 18407
#define sipName_GraphicsSceneResize &sipStrings_QtCore[18407]
#define sipNameNr_GroupSwitchModifier 18427
#define sipName_GroupSwitchModifier &sipStrings_QtCore[18427]
#define sipNameNr_ImMaximumTextLength 18447
#define sipName_ImMaximumTextLength &sipStrings_QtCore[18447]
#define sipNameNr_ImPreferredLanguage 18467
#define sipName_ImPreferredLanguage &sipStrings_QtCore[18467]
#define sipNameNr_ImageConversionFlag 11017
#define sipName_ImageConversionFlag &sipStrings_QtCore[11017]
#define sipNameNr_ImhNoPredictiveText 18487
#define sipName_ImhNoPredictiveText &sipStrings_QtCore[18487]
#define sipNameNr_IntersectsItemShape 18507
#define sipName_IntersectsItemShape &sipStrings_QtCore[18507]
#define sipNameNr_ItemIsUserCheckable 18527
#define sipName_ItemIsUserCheckable &sipStrings_QtCore[18527]
#define sipNameNr_Key_ApplicationLeft 18547
#define sipName_Key_ApplicationLeft &sipStrings_QtCore[18547]
#define sipNameNr_Key_AudioCycleTrack 18567
#define sipName_Key_AudioCycleTrack &sipStrings_QtCore[18567]
#define sipNameNr_Key_AudioRandomPlay 18587
#define sipName_Key_AudioRandomPlay &sipStrings_QtCore[18587]
#define sipNameNr_Key_Dead_Abovecomma 18607
#define sipName_Key_Dead_Abovecomma &sipStrings_QtCore[18607]
#define sipNameNr_Key_Dead_Belowbreve 18627
#define sipName_Key_Dead_Belowbreve &sipStrings_QtCore[18627]
#define sipNameNr_Key_Dead_Belowcomma 18647
#define sipName_Key_Dead_Belowcomma &sipStrings_QtCore[18647]
#define sipNameNr_Key_Dead_Belowtilde 18667
#define sipName_Key_Dead_Belowtilde &sipStrings_QtCore[18667]
#define sipNameNr_Key_Dead_Circumflex 18687
#define sipName_Key_Dead_Circumflex &sipStrings_QtCore[18687]
#define sipNameNr_Key_Hangul_PreHanja 18707
#define sipName_Key_Hangul_PreHanja &sipStrings_QtCore[18707]
#define sipNameNr_Key_MonBrightnessUp 18727
#define sipName_Key_MonBrightnessUp &sipStrings_QtCore[18727]
#define sipNameNr_Key_SingleCandidate 18747
#define sipName_Key_SingleCandidate &sipStrings_QtCore[18747]
#define sipNameNr_Key_Zenkaku_Hankaku 18767
#define sipName_Key_Zenkaku_Hankaku &sipStrings_QtCore[18767]
#define sipNameNr_LayoutDirectionAuto 18787
#define sipName_LayoutDirectionAuto &sipStrings_QtCore[18787]
#define sipNameNr_ManagedInputChannel 18807
#define sipName_ManagedInputChannel &sipStrings_QtCore[18807]
#define sipNameNr_MouseButtonDblClick 2600
#define sipName_MouseButtonDblClick &sipStrings_QtCore[2600]
#define sipNameNr_MouseTrackingChange 18827
#define sipName_MouseTrackingChange &sipStrings_QtCore[18827]
#define sipNameNr_NormalEventPriority 18847
#define sipName_NormalEventPriority &sipStrings_QtCore[18847]
#define sipNameNr_ParentAboutToChange 18867
#define sipName_ParentAboutToChange &sipStrings_QtCore[18867]
#define sipNameNr_PortraitOrientation 5422
#define sipName_PortraitOrientation &sipStrings_QtCore[5422]
#define sipNameNr_PublicShareLocation 18887
#define sipName_PublicShareLocation &sipStrings_QtCore[18887]
#define sipNameNr_QAbstractProxyModel 18907
#define sipName_QAbstractProxyModel &sipStrings_QtCore[18907]
#define sipNameNr_QAbstractTableModel 18927
#define sipName_QAbstractTableModel &sipStrings_QtCore[18927]
#define sipNameNr_QCalendarPermission 18947
#define sipName_QCalendarPermission &sipStrings_QtCore[18947]
#define sipNameNr_QContactsPermission 18967
#define sipName_QContactsPermission &sipStrings_QtCore[18967]
#define sipNameNr_QDataStream__Status 18987
#define sipName_QDataStream__Status &sipStrings_QtCore[18987]
#define sipNameNr_QIdentityProxyModel 19007
#define sipName_QIdentityProxyModel &sipStrings_QtCore[19007]
#define sipNameNr_QItemSelectionModel 19027
#define sipName_QItemSelectionModel &sipStrings_QtCore[19027]
#define sipNameNr_QItemSelectionRange 19047
#define sipName_QItemSelectionRange &sipStrings_QtCore[19047]
#define sipNameNr_19067 19067
#define sipName_19067 &sipStrings_QtCore[19067]
#define sipNameNr_QLocale__FormatType 19087
#define sipName_QLocale__FormatType &sipStrings_QtCore[19087]
#define sipNameNr_QLocationPermission 19107
#define sipName_QLocationPermission &sipStrings_QtCore[19107]
#define sipNameNr_QMetaMethod__Access 19127
#define sipName_QMetaMethod__Access &sipStrings_QtCore[19127]
#define sipNameNr_QMetaType__TypeFlag 19147
#define sipName_QMetaType__TypeFlag &sipStrings_QtCore[19147]
#define sipNameNr_QNativeIpcKey__Type 19167
#define sipName_QNativeIpcKey__Type &sipStrings_QtCore[19167]
#define sipNameNr_QProcessEnvironment 19187
#define sipName_QProcessEnvironment &sipStrings_QtCore[19187]
#define sipNameNr_QTextBoundaryFinder 19207
#define sipName_QTextBoundaryFinder &sipStrings_QtCore[19207]
#define sipNameNr_QTextStream__Status 19227
#define sipName_QTextStream__Status &sipStrings_QtCore[19227]
#define sipNameNr_QTimeZone__NameType 19247
#define sipName_QTimeZone__NameType &sipStrings_QtCore[19247]
#define sipNameNr_QTimeZone__TimeType 19267
#define sipName_QTimeZone__TimeType &sipStrings_QtCore[19267]
#define sipNameNr_QUuid__StringFormat 19287
#define sipName_QUuid__StringFormat &sipStrings_QtCore[19287]
#define sipNameNr_QXmlStreamAttribute 19307
#define sipName_QXmlStreamAttribute &sipStrings_QtCore[19307]
#define sipNameNr_Qt__AspectRatioMode 19327
#define sipName_Qt__AspectRatioMode &sipStrings_QtCore[19327]
#define sipNameNr_Qt__CaseSensitivity 19347
#define sipName_Qt__CaseSensitivity &sipStrings_QtCore[19347]
#define sipNameNr_Qt__CursorMoveStyle 19367
#define sipName_Qt__CursorMoveStyle &sipStrings_QtCore[19367]
#define sipNameNr_Qt__FindChildOption 19387
#define sipName_Qt__FindChildOption &sipStrings_QtCore[19387]
#define sipNameNr_Qt__HitTestAccuracy 19407
#define sipName_Qt__HitTestAccuracy &sipStrings_QtCore[19407]
#define sipNameNr_Qt__InputMethodHint 19427
#define sipName_Qt__InputMethodHint &sipStrings_QtCore[19427]
#define sipNameNr_Qt__LayoutDirection 19447
#define sipName_Qt__LayoutDirection &sipStrings_QtCore[19447]
#define sipNameNr_Qt__ScrollBarPolicy 19467
#define sipName_Qt__ScrollBarPolicy &sipStrings_QtCore[19467]
#define sipNameNr_Qt__ShortcutContext 19487
#define sipName_Qt__ShortcutContext &sipStrings_QtCore[19487]
#define sipNameNr_Qt__ToolButtonStyle 19507
#define sipName_Qt__ToolButtonStyle &sipStrings_QtCore[19507]
#define sipNameNr_Qt__TouchPointState 19527
#define sipName_Qt__TouchPointState &sipStrings_QtCore[19527]
#define sipNameNr_Qt__WidgetAttribute 19547
#define sipName_Qt__WidgetAttribute &sipStrings_QtCore[19547]
#define sipNameNr_ResetSignalHandlers 19567
#define sipName_ResetSignalHandlers &sipStrings_QtCore[19567]
#define sipNameNr_RightDockWidgetArea 19587
#define sipName_RightDockWidgetArea &sipStrings_QtCore[19587]
#define sipNameNr_RotateNativeGesture 19607
#define sipName_RotateNativeGesture &sipStrings_QtCore[19607]
#define sipNameNr_Script_GunjalaGondi 19627
#define sipName_Script_GunjalaGondi &sipStrings_QtCore[19627]
#define sipNameNr_Script_MasaramGondi 19647
#define sipName_Script_MasaramGondi &sipStrings_QtCore[19647]
#define sipNameNr_Script_MendeKikakui 19667
#define sipName_Script_MendeKikakui &sipStrings_QtCore[19667]
#define sipNameNr_Script_OldHungarian 19687
#define sipName_Script_OldHungarian &sipStrings_QtCore[19687]
#define sipNameNr_Script_TuluTigalari 19707
#define sipName_Script_TuluTigalari &sipStrings_QtCore[19707]
#define sipNameNr_ShortcutFocusReason 19727
#define sipName_ShortcutFocusReason &sipStrings_QtCore[19727]
#define sipNameNr_SimplifiedHanScript 19747
#define sipName_SimplifiedHanScript &sipStrings_QtCore[19747]
#define sipNameNr_StateMachineWrapped 19767
#define sipName_StateMachineWrapped &sipStrings_QtCore[19767]
#define sipNameNr_SvalbardAndJanMayen 19787
#define sipName_SvalbardAndJanMayen &sipStrings_QtCore[19787]
#define sipNameNr_TabFocusAllControls 19807
#define sipName_TabFocusAllControls &sipStrings_QtCore[19807]
#define sipNameNr_TerminationByNumber 19827
#define sipName_TerminationByNumber &sipStrings_QtCore[19827]
#define sipNameNr_TextInteractionFlag 11041
#define sipName_TextInteractionFlag &sipStrings_QtCore[11041]
#define sipNameNr_UrlFormattingOption 8334
#define sipName_UrlFormattingOption &sipStrings_QtCore[8334]
#define sipNameNr_WA_AlwaysStackOnTop 19847
#define sipName_WA_AlwaysStackOnTop &sipStrings_QtCore[19847]
#define sipNameNr_WA_DontShowOnScreen 19867
#define sipName_WA_DontShowOnScreen &sipStrings_QtCore[19867]
#define sipNameNr_WA_MacShowFocusRect 19887
#define sipName_WA_MacShowFocusRect &sipStrings_QtCore[19887]
#define sipNameNr_WA_OpaquePaintEvent 19907
#define sipName_WA_OpaquePaintEvent &sipStrings_QtCore[19907]
#define sipNameNr_WA_PendingMoveEvent 19927
#define sipName_WA_PendingMoveEvent &sipStrings_QtCore[19927]
#define sipNameNr_WA_StyleSheetTarget 19947
#define sipName_WA_StyleSheetTarget &sipStrings_QtCore[19947]
#define sipNameNr_WA_StyledBackground 19967
#define sipName_WA_StyledBackground &sipStrings_QtCore[19967]
#define sipNameNr_WA_TintedBackground 19987
#define sipName_WA_TintedBackground &sipStrings_QtCore[19987]
#define sipNameNr_WA_X11OpenGLOverlay 20007
#define sipName_WA_X11OpenGLOverlay &sipStrings_QtCore[20007]
#define sipNameNr_applicationFilePath 20027
#define sipName_applicationFilePath &sipStrings_QtCore[20027]
#define sipNameNr_autoAcceptChildRows 20047
#define sipName_autoAcceptChildRows &sipStrings_QtCore[20047]
#define sipNameNr_channelBytesWritten 20067
#define sipName_channelBytesWritten &sipStrings_QtCore[20067]
#define sipNameNr_createSeparatedList 20087
#define sipName_createSeparatedList &sipStrings_QtCore[20087]
#define sipNameNr_currentWriteChannel 20107
#define sipName_currentWriteChannel &sipStrings_QtCore[20107]
#define sipNameNr_directWriteFallback 20127
#define sipName_directWriteFallback &sipStrings_QtCore[20127]
#define sipNameNr_filterAcceptsColumn 20147
#define sipName_filterAcceptsColumn &sipStrings_QtCore[20147]
#define sipNameNr_fromMSecsSinceEpoch 20167
#define sipName_fromMSecsSinceEpoch &sipStrings_QtCore[20167]
#define sipNameNr_fromPercentEncoding 20187
#define sipName_fromPercentEncoding &sipStrings_QtCore[20187]
#define sipNameNr_isCopyConstructible 20207
#define sipName_isCopyConstructible &sipStrings_QtCore[20207]
#define sipNameNr_isMoveConstructible 20227
#define sipName_isMoveConstructible &sipStrings_QtCore[20227]
#define sipNameNr_maximumMonthsInYear 20247
#define sipName_maximumMonthsInYear &sipStrings_QtCore[20247]
#define sipNameNr_modelAboutToBeReset 20267
#define sipName_modelAboutToBeReset &sipStrings_QtCore[20267]
#define sipNameNr_msecsSinceReference 20287
#define sipName_msecsSinceReference &sipStrings_QtCore[20287]
#define sipNameNr_namespaceProcessing 20307
#define sipName_namespaceProcessing &sipStrings_QtCore[20307]
#define sipNameNr_nativeTerritoryName 20327
#define sipName_nativeTerritoryName &sipStrings_QtCore[20327]
#define sipNameNr_normalizedSignature 20347
#define sipName_normalizedSignature &sipStrings_QtCore[20347]
#define sipNameNr_parentContainerType 20367
#define sipName_parentContainerType &sipStrings_QtCore[20367]
#define sipNameNr_persistentIndexList 20387
#define sipName_persistentIndexList &sipStrings_QtCore[20387]
#define sipNameNr_positionalArguments 20407
#define sipName_positionalArguments &sipStrings_QtCore[20407]
#define sipNameNr_pyqtRemoveInputHook 20427
#define sipName_pyqtRemoveInputHook &sipStrings_QtCore[20427]
#define sipNameNr_queryValueDelimiter 20447
#define sipName_queryValueDelimiter &sipStrings_QtCore[20447]
#define sipNameNr_readChannelFinished 20467
#define sipName_readChannelFinished &sipStrings_QtCore[20467]
#define sipNameNr_realNumberPrecision 20487
#define sipName_realNumberPrecision &sipStrings_QtCore[20487]
#define sipNameNr_relativeMethodIndex 20507
#define sipName_relativeMethodIndex &sipStrings_QtCore[20507]
#define sipNameNr_removeAllQueryItems 20527
#define sipName_removeAllQueryItems &sipStrings_QtCore[20527]
#define sipNameNr_removeStaleLockFile 20547
#define sipName_removeStaleLockFile &sipStrings_QtCore[20547]
#define sipNameNr_requestInterruption 20567
#define sipName_requestInterruption &sipStrings_QtCore[20567]
#define sipNameNr_rollbackTransaction 20587
#define sipName_rollbackTransaction &sipStrings_QtCore[20587]
#define sipNameNr_setFallbacksEnabled 20607
#define sipName_setFallbacksEnabled &sipStrings_QtCore[20607]
#define sipNameNr_setInputChannelMode 20627
#define sipName_setInputChannelMode &sipStrings_QtCore[20627]
#define sipNameNr_setOrganizationName 20647
#define sipName_setOrganizationName &sipStrings_QtCore[20647]
#define sipNameNr_setWorkingDirectory 20667
#define sipName_setWorkingDirectory &sipStrings_QtCore[20667]
#define sipNameNr_sortCaseSensitivity 20687
#define sipName_sortCaseSensitivity &sipStrings_QtCore[20687]
#define sipNameNr_standaloneMonthName 20707
#define sipName_standaloneMonthName &sipStrings_QtCore[20707]
#define sipNameNr_supportsMoveToTrash 20727
#define sipName_supportsMoveToTrash &sipStrings_QtCore[20727]
#define sipNameNr_waitForBytesWritten 20747
#define sipName_waitForBytesWritten &sipStrings_QtCore[20747]
#define sipNameNr_AccessibleTextRole 20767
#define sipName_AccessibleTextRole &sipStrings_QtCore[20767]
#define sipNameNr_ActionsContextMenu 20786
#define sipName_ActionsContextMenu &sipStrings_QtCore[20786]
#define sipNameNr_AlignVertical_Mask 20805
#define sipName_AlignVertical_Mask &sipStrings_QtCore[20805]
#define sipNameNr_AllDockWidgetAreas 20824
#define sipName_AllDockWidgetAreas &sipStrings_QtCore[20824]
#define sipNameNr_AlternateQuotation 20843
#define sipName_AlternateQuotation &sipStrings_QtCore[20843]
#define sipNameNr_AndroidMarshmallow 20862
#define sipName_AndroidMarshmallow &sipStrings_QtCore[20862]
#define sipNameNr_BacktabFocusReason 20881
#define sipName_BacktabFocusReason &sipStrings_QtCore[20881]
#define sipNameNr_BeginNativeGesture 20900
#define sipName_BeginNativeGesture &sipStrings_QtCore[20900]
#define sipNameNr_BottomRightSection 20919
#define sipName_BottomRightSection &sipStrings_QtCore[20919]
#define sipNameNr_ChildWindowRemoved 20938
#define sipName_ChildWindowRemoved &sipStrings_QtCore[20938]
#define sipNameNr_ContentsRectChange 20957
#define sipName_ContentsRectChange &sipStrings_QtCore[20957]
#define sipNameNr_ContextMenuTrigger 12585
#define sipName_ContextMenuTrigger &sipStrings_QtCore[12585]
#define sipNameNr_ContrastPreference 12608
#define sipName_ContrastPreference &sipStrings_QtCore[12608]
#define sipNameNr_DefaultContextMenu 20976
#define sipName_DefaultContextMenu &sipStrings_QtCore[20976]
#define sipNameNr_DiffuseAlphaDither 20995
#define sipName_DiffuseAlphaDither &sipStrings_QtCore[20995]
#define sipNameNr_EnterWhatsThisMode 21014
#define sipName_EnterWhatsThisMode &sipStrings_QtCore[21014]
#define sipNameNr_FastTransformation 21033
#define sipName_FastTransformation &sipStrings_QtCore[21033]
#define sipNameNr_FocusAboutToChange 21052
#define sipName_FocusAboutToChange &sipStrings_QtCore[21052]
#define sipNameNr_GraphicsSceneLeave 21071
#define sipName_GraphicsSceneLeave &sipStrings_QtCore[21071]
#define sipNameNr_GraphicsSceneWheel 21090
#define sipName_GraphicsSceneWheel &sipStrings_QtCore[21090]
#define sipNameNr_HorizontalSortHint 21109
#define sipName_HorizontalSortHint &sipStrings_QtCore[21109]
#define sipNameNr_IgnoreIDNWhitelist 21128
#define sipName_IgnoreIDNWhitelist &sipStrings_QtCore[21128]
#define sipNameNr_IgnoreOptionsAfter 21147
#define sipName_IgnoreOptionsAfter &sipStrings_QtCore[21147]
#define sipNameNr_IllegalInputLength 21166
#define sipName_IllegalInputLength &sipStrings_QtCore[21166]
#define sipNameNr_ImAbsolutePosition 21185
#define sipName_ImAbsolutePosition &sipStrings_QtCore[21185]
#define sipNameNr_ImCurrentSelection 21204
#define sipName_ImCurrentSelection &sipStrings_QtCore[21204]
#define sipNameNr_ImTextBeforeCursor 21223
#define sipName_ImTextBeforeCursor &sipStrings_QtCore[21223]
#define sipNameNr_ImhNoAutoUppercase 21242
#define sipName_ImhNoAutoUppercase &sipStrings_QtCore[21242]
#define sipNameNr_ImhPreferLowercase 21261
#define sipName_ImhPreferLowercase &sipStrings_QtCore[21261]
#define sipNameNr_ImhPreferUppercase 21280
#define sipName_ImhPreferUppercase &sipStrings_QtCore[21280]
#define sipNameNr_ItemIsAutoTristate 21299
#define sipName_ItemIsAutoTristate &sipStrings_QtCore[21299]
#define sipNameNr_ItemIsUserTristate 21318
#define sipName_ItemIsUserTristate &sipStrings_QtCore[21318]
#define sipNameNr_KeepTrailingEquals 21337
#define sipName_KeepTrailingEquals &sipStrings_QtCore[21337]
#define sipNameNr_Key_ContrastAdjust 21356
#define sipName_Key_ContrastAdjust &sipStrings_QtCore[21356]
#define sipNameNr_Key_Dead_Abovering 21375
#define sipName_Key_Dead_Abovering &sipStrings_QtCore[21375]
#define sipNameNr_Key_Dead_Belowring 21394
#define sipName_Key_Dead_Belowring &sipStrings_QtCore[21394]
#define sipNameNr_Key_Dead_Diaeresis 21413
#define sipName_Key_Dead_Diaeresis &sipStrings_QtCore[21413]
#define sipNameNr_Key_Hangul_Special 21432
#define sipName_Key_Hangul_Special &sipStrings_QtCore[21432]
#define sipNameNr_Key_TouchpadToggle 21451
#define sipName_Key_TouchpadToggle &sipStrings_QtCore[21451]
#define sipNameNr_Key_guillemotright 21470
#define sipName_Key_guillemotright &sipStrings_QtCore[21470]
#define sipNameNr_Key_periodcentered 21489
#define sipName_Key_periodcentered &sipStrings_QtCore[21489]
#define sipNameNr_LeaveWhatsThisMode 21508
#define sipName_LeaveWhatsThisMode &sipStrings_QtCore[21508]
#define sipNameNr_LeftDockWidgetArea 21527
#define sipName_LeftDockWidgetArea &sipStrings_QtCore[21527]
#define sipNameNr_LegacyLanguageCode 21546
#define sipName_LegacyLanguageCode &sipStrings_QtCore[21546]
#define sipNameNr_LogicalCoordinates 21565
#define sipName_LogicalCoordinates &sipStrings_QtCore[21565]
#define sipNameNr_MatchCaseSensitive 21584
#define sipName_MatchCaseSensitive &sipStrings_QtCore[21584]
#define sipNameNr_MendeKikakuiScript 21603
#define sipName_MendeKikakuiScript &sipStrings_QtCore[21603]
#define sipNameNr_MenuBarFocusReason 21622
#define sipName_MenuBarFocusReason &sipStrings_QtCore[21622]
#define sipNameNr_MouseButtonRelease 3060
#define sipName_MouseButtonRelease &sipStrings_QtCore[3060]
#define sipNameNr_NavigationModeNone 21641
#define sipName_NavigationModeNone &sipStrings_QtCore[21641]
#define sipNameNr_NoFormatConversion 21660
#define sipName_NoFormatConversion &sipStrings_QtCore[21660]
#define sipNameNr_NoLayoutChangeHint 21679
#define sipName_NoLayoutChangeHint &sipStrings_QtCore[21679]
#define sipNameNr_NotWellFormedError 21698
#define sipName_NotWellFormedError &sipStrings_QtCore[21698]
#define sipNameNr_OldHungarianScript 21717
#define sipName_OldHungarianScript &sipStrings_QtCore[21717]
#define sipNameNr_OmitGroupSeparator 21736
#define sipName_OmitGroupSeparator &sipStrings_QtCore[21736]
#define sipNameNr_OmitTrailingEquals 21755
#define sipName_OmitTrailingEquals &sipStrings_QtCore[21755]
#define sipNameNr_OrderedAlphaDither 21774
#define sipName_OrderedAlphaDither &sipStrings_QtCore[21774]
#define sipNameNr_ParentWindowChange 21793
#define sipName_ParentWindowChange &sipStrings_QtCore[21793]
#define sipNameNr_ParseAsLongOptions 21812
#define sipName_ParseAsLongOptions &sipStrings_QtCore[21812]
#define sipNameNr_PerformanceCounter 21831
#define sipName_PerformanceCounter &sipStrings_QtCore[21831]
#define sipNameNr_PointingHandCursor 21850
#define sipName_PointingHandCursor &sipStrings_QtCore[21850]
#define sipNameNr_PreventContextMenu 21869
#define sipName_PreventContextMenu &sipStrings_QtCore[21869]
#define sipNameNr_PrimaryOrientation 21888
#define sipName_PrimaryOrientation &sipStrings_QtCore[21888]
#define sipNameNr_ProcessChannelMode 4676
#define sipName_ProcessChannelMode &sipStrings_QtCore[4676]
#define sipNameNr_QAbstractAnimation 21907
#define sipName_QAbstractAnimation &sipStrings_QtCore[21907]
#define sipNameNr_QAbstractItemModel 21926
#define sipName_QAbstractItemModel &sipStrings_QtCore[21926]
#define sipNameNr_QAbstractListModel 21945
#define sipName_QAbstractListModel &sipStrings_QtCore[21945]
#define sipNameNr_QCommandLineOption 21964
#define sipName_QCommandLineOption &sipStrings_QtCore[21964]
#define sipNameNr_QCommandLineParser 21983
#define sipName_QCommandLineParser &sipStrings_QtCore[21983]
#define sipNameNr_QCryptographicHash 22002
#define sipName_QCryptographicHash &sipStrings_QtCore[22002]
#define sipNameNr_QEasingCurve__Type 22021
#define sipName_QEasingCurve__Type &sipStrings_QtCore[22021]
#define sipNameNr_QFileSystemWatcher 22040
#define sipName_QFileSystemWatcher &sipStrings_QtCore[22040]
#define sipNameNr_QLibrary__LoadHint 22059
#define sipName_QLibrary__LoadHint &sipStrings_QtCore[22059]
#define sipNameNr_22078 22078
#define sipName_22078 &sipStrings_QtCore[22078]
#define sipNameNr_22097 22097
#define sipName_22097 &sipStrings_QtCore[22097]
#define sipNameNr_QMessageLogContext 22116
#define sipName_QMessageLogContext &sipStrings_QtCore[22116]
#define sipNameNr_QModelRoleDataSpan 22135
#define sipName_QModelRoleDataSpan &sipStrings_QtCore[22135]
#define sipNameNr_QPropertyAnimation 22154
#define sipName_QPropertyAnimation &sipStrings_QtCore[22154]
#define sipNameNr_QRegularExpression 22173
#define sipName_QRegularExpression &sipStrings_QtCore[22173]
#define sipNameNr_QSemaphoreReleaser 22192
#define sipName_QSemaphoreReleaser &sipStrings_QtCore[22192]
#define sipNameNr_Qt__ConnectionType 22211
#define sipName_Qt__ConnectionType &sipStrings_QtCore[22211]
#define sipNameNr_Qt__DockWidgetArea 22230
#define sipName_Qt__DockWidgetArea &sipStrings_QtCore[22230]
#define sipNameNr_Qt__MouseEventFlag 22249
#define sipName_Qt__MouseEventFlag &sipStrings_QtCore[22249]
#define sipNameNr_Qt__NavigationMode 22268
#define sipName_Qt__NavigationMode &sipStrings_QtCore[22268]
#define sipNameNr_Qt__WhiteSpaceMode 22287
#define sipName_Qt__WhiteSpaceMode &sipStrings_QtCore[22287]
#define sipNameNr_Qt__WindowModality 22306
#define sipName_Qt__WindowModality &sipStrings_QtCore[22306]
#define sipNameNr_RealNumberNotation 3540
#define sipName_RealNumberNotation &sipStrings_QtCore[3540]
#define sipNameNr_SaintKittsAndNevis 22325
#define sipName_SaintKittsAndNevis &sipStrings_QtCore[22325]
#define sipNameNr_SaoTomeAndPrincipe 22344
#define sipName_SaoTomeAndPrincipe &sipStrings_QtCore[22344]
#define sipNameNr_ScientificNotation 22363
#define sipName_ScientificNotation &sipStrings_QtCore[22363]
#define sipNameNr_Script_CyproMinoan 22382
#define sipName_Script_CyproMinoan &sipStrings_QtCore[22382]
#define sipNameNr_Script_GurungKhema 22401
#define sipName_Script_GurungKhema &sipStrings_QtCore[22401]
#define sipNameNr_Script_Medefaidrin 22420
#define sipName_Script_Medefaidrin &sipStrings_QtCore[22420]
#define sipNameNr_Script_MeeteiMayek 22439
#define sipName_Script_MeeteiMayek &sipStrings_QtCore[22439]
#define sipNameNr_Script_Nandinagari 22458
#define sipName_Script_Nandinagari &sipStrings_QtCore[22458]
#define sipNameNr_Script_PahawhHmong 22477
#define sipName_Script_PahawhHmong &sipStrings_QtCore[22477]
#define sipNameNr_Script_SignWriting 22496
#define sipName_Script_SignWriting &sipStrings_QtCore[22496]
#define sipNameNr_Script_SoraSompeng 22515
#define sipName_Script_SoraSompeng &sipStrings_QtCore[22515]
#define sipNameNr_Script_SylotiNagri 22534
#define sipName_Script_SylotiNagri &sipStrings_QtCore[22534]
#define sipNameNr_ScrollBarAlwaysOff 22553
#define sipName_ScrollBarAlwaysOff &sipStrings_QtCore[22553]
#define sipNameNr_StateMachineSignal 22572
#define sipName_StateMachineSignal &sipStrings_QtCore[22572]
#define sipNameNr_StripTrailingSlash 22591
#define sipName_StripTrailingSlash &sipStrings_QtCore[22591]
#define sipNameNr_SwipeNativeGesture 22610
#define sipName_SwipeNativeGesture &sipStrings_QtCore[22610]
#define sipNameNr_SyrianArabRepublic 22629
#define sipName_SyrianArabRepublic &sipStrings_QtCore[22629]
#define sipNameNr_ToolButtonIconOnly 22648
#define sipName_ToolButtonIconOnly &sipStrings_QtCore[22648]
#define sipNameNr_ToolButtonTextOnly 22667
#define sipName_ToolButtonTextOnly &sipStrings_QtCore[22667]
#define sipNameNr_TouchPointReleased 22686
#define sipName_TouchPointReleased &sipStrings_QtCore[22686]
#define sipNameNr_TransformationMode 12631
#define sipName_TransformationMode &sipStrings_QtCore[12631]
#define sipNameNr_UnitedArabEmirates 22705
#define sipName_UnitedArabEmirates &sipStrings_QtCore[22705]
#define sipNameNr_UnterminatedObject 22724
#define sipName_UnterminatedObject &sipStrings_QtCore[22724]
#define sipNameNr_UnterminatedString 22743
#define sipName_UnterminatedString &sipStrings_QtCore[22743]
#define sipNameNr_VarangKshitiScript 22762
#define sipName_VarangKshitiScript &sipStrings_QtCore[22762]
#define sipNameNr_WA_CustomWhatsThis 22781
#define sipName_WA_CustomWhatsThis &sipStrings_QtCore[22781]
#define sipNameNr_WA_GrabbedShortcut 22800
#define sipName_WA_GrabbedShortcut &sipStrings_QtCore[22800]
#define sipNameNr_WA_UpdatesDisabled 22819
#define sipName_WA_UpdatesDisabled &sipStrings_QtCore[22819]
#define sipNameNr_WA_WState_Polished 22838
#define sipName_WA_WState_Polished &sipStrings_QtCore[22838]
#define sipNameNr_WindowFrameSection 12654
#define sipName_WindowFrameSection &sipStrings_QtCore[12654]
#define sipNameNr_allQueryItemValues 22857
#define sipName_allQueryItemValues &sipStrings_QtCore[22857]
#define sipNameNr_applicationDirPath 22876
#define sipName_applicationDirPath &sipStrings_QtCore[22876]
#define sipNameNr_applicationVersion 22895
#define sipName_applicationVersion &sipStrings_QtCore[22895]
#define sipNameNr_availableCalendars 22914
#define sipName_availableCalendars &sipStrings_QtCore[22914]
#define sipNameNr_beginInsertColumns 22933
#define sipName_beginInsertColumns &sipStrings_QtCore[22933]
#define sipNameNr_beginRemoveColumns 22952
#define sipName_beginRemoveColumns &sipStrings_QtCore[22952]
#define sipNameNr_communicationModes 22971
#define sipName_communicationModes &sipStrings_QtCore[22971]
#define sipNameNr_connectSlotsByName 22990
#define sipName_connectSlotsByName &sipStrings_QtCore[22990]
#define sipNameNr_currentDateTimeUtc 23009
#define sipName_currentDateTimeUtc &sipStrings_QtCore[23009]
#define sipNameNr_currentLoopChanged 23028
#define sipName_currentLoopChanged &sipStrings_QtCore[23028]
#define sipNameNr_currentReadChannel 23047
#define sipName_currentReadChannel &sipStrings_QtCore[23047]
#define sipNameNr_daylightTimeOffset 23066
#define sipName_daylightTimeOffset &sipStrings_QtCore[23066]
#define sipNameNr_entityDeclarations 23085
#define sipName_entityDeclarations &sipStrings_QtCore[23085]
#define sipNameNr_fromBase64Encoding 23104
#define sipName_fromBase64Encoding &sipStrings_QtCore[23104]
#define sipNameNr_fromEncodedVersion 23123
#define sipName_fromEncodedVersion &sipStrings_QtCore[23123]
#define sipNameNr_fromSecsSinceEpoch 23142
#define sipName_fromSecsSinceEpoch &sipStrings_QtCore[23142]
#define sipNameNr_hasAlternativeName 23161
#define sipName_hasAlternativeName &sipStrings_QtCore[23161]
#define sipNameNr_indexOfConstructor 23180
#define sipName_indexOfConstructor &sipStrings_QtCore[23180]
#define sipNameNr_inheritsFromParent 23199
#define sipName_inheritsFromParent &sipStrings_QtCore[23199]
#define sipNameNr_installEventFilter 23218
#define sipName_installEventFilter &sipStrings_QtCore[23218]
#define sipNameNr_isKeyTypeSupported 23237
#define sipName_isKeyTypeSupported &sipStrings_QtCore[23237]
#define sipNameNr_isSinglePointEvent 23256
#define sipName_isSinglePointEvent &sipStrings_QtCore[23256]
#define sipNameNr_isUtcOrFixedOffset 23275
#define sipName_isUtcOrFixedOffset &sipStrings_QtCore[23275]
#define sipNameNr_maximumDaysInMonth 23294
#define sipName_maximumDaysInMonth &sipStrings_QtCore[23294]
#define sipNameNr_metadataChangeTime 23313
#define sipName_metadataChangeTime &sipStrings_QtCore[23313]
#define sipNameNr_minimumDaysInMonth 23332
#define sipName_minimumDaysInMonth &sipStrings_QtCore[23332]
#define sipNameNr_namedCaptureGroups 23351
#define sipName_namedCaptureGroups &sipStrings_QtCore[23351]
#define sipNameNr_nativeLanguageName 23370
#define sipName_nativeLanguageName &sipStrings_QtCore[23370]
#define sipNameNr_organizationDomain 23389
#define sipName_organizationDomain &sipStrings_QtCore[23389]
#define sipNameNr_patternErrorOffset 23408
#define sipName_patternErrorOffset &sipStrings_QtCore[23408]
#define sipNameNr_previousTransition 23427
#define sipName_previousTransition &sipStrings_QtCore[23427]
#define sipNameNr_processChannelMode 23446
#define sipName_processChannelMode &sipStrings_QtCore[23446]
#define sipNameNr_processEnvironment 23465
#define sipName_processEnvironment &sipStrings_QtCore[23465]
#define sipNameNr_pyqtPickleProtocol 23484
#define sipName_pyqtPickleProtocol &sipStrings_QtCore[23484]
#define sipNameNr_qRemovePostRoutine 23503
#define sipName_qRemovePostRoutine &sipStrings_QtCore[23503]
#define sipNameNr_qSetMessagePattern 23522
#define sipName_qSetMessagePattern &sipStrings_QtCore[23522]
#define sipNameNr_queryPairDelimiter 23541
#define sipName_queryPairDelimiter &sipStrings_QtCore[23541]
#define sipNameNr_realNumberNotation 23560
#define sipName_realNumberNotation &sipStrings_QtCore[23560]
#define sipNameNr_remainingTimeNSecs 23579
#define sipName_remainingTimeNSecs &sipStrings_QtCore[23579]
#define sipNameNr_removePostedEvents 23598
#define sipName_removePostedEvents &sipStrings_QtCore[23598]
#define sipNameNr_rowsAboutToBeMoved 23617
#define sipName_rowsAboutToBeMoved &sipStrings_QtCore[23617]
#define sipNameNr_setApplicationName 23636
#define sipName_setApplicationName &sipStrings_QtCore[23636]
#define sipNameNr_setCaseSensitivity 23655
#define sipName_setCaseSensitivity &sipStrings_QtCore[23655]
#define sipNameNr_setEventDispatcher 23674
#define sipName_setEventDispatcher &sipStrings_QtCore[23674]
#define sipNameNr_setFilterKeyColumn 23693
#define sipName_setFilterKeyColumn &sipStrings_QtCore[23693]
#define sipNameNr_setMSecsSinceEpoch 23712
#define sipName_setMSecsSinceEpoch &sipStrings_QtCore[23712]
#define sipNameNr_setPreciseDeadline 23731
#define sipName_setPreciseDeadline &sipStrings_QtCore[23731]
#define sipNameNr_setQueryDelimiters 23750
#define sipName_setQueryDelimiters &sipStrings_QtCore[23750]
#define sipNameNr_setQuitLockEnabled 23769
#define sipName_setQuitLockEnabled &sipStrings_QtCore[23769]
#define sipNameNr_setSortLocaleAware 23788
#define sipName_setSortLocaleAware &sipStrings_QtCore[23788]
#define sipNameNr_setTestModeEnabled 23807
#define sipName_setTestModeEnabled &sipStrings_QtCore[23807]
#define sipNameNr_setTextModeEnabled 23826
#define sipName_setTextModeEnabled &sipStrings_QtCore[23826]
#define sipNameNr_showMessageAndExit 23845
#define sipName_showMessageAndExit &sipStrings_QtCore[23845]
#define sipNameNr_skipCurrentElement 23864
#define sipName_skipCurrentElement &sipStrings_QtCore[23864]
#define sipNameNr_sourceModelChanged 23883
#define sipName_sourceModelChanged &sipStrings_QtCore[23883]
#define sipNameNr_standardTimeOffset 23902
#define sipName_standardTimeOffset &sipStrings_QtCore[23902]
#define sipNameNr_23921 23921
#define sipName_23921 &sipStrings_QtCore[23921]
#define sipNameNr_stopWritingOnError 23940
#define sipName_stopWritingOnError &sipStrings_QtCore[23940]
#define sipNameNr_timeRepresentation 23959
#define sipName_timeRepresentation &sipStrings_QtCore[23959]
#define sipNameNr_toNativeSeparators 23978
#define sipName_toNativeSeparators &sipStrings_QtCore[23978]
#define sipNameNr_toPreviousBoundary 23997
#define sipName_toPreviousBoundary &sipStrings_QtCore[23997]
#define sipNameNr_unknownOptionNames 24016
#define sipName_unknownOptionNames &sipStrings_QtCore[24016]
#define sipNameNr_unregisterResource 24035
#define sipName_unregisterResource &sipStrings_QtCore[24035]
#define sipNameNr_updateCurrentValue 24054
#define sipName_updateCurrentValue &sipStrings_QtCore[24054]
#define sipNameNr_windowsIdToIanaIds 24073
#define sipName_windowsIdToIanaIds &sipStrings_QtCore[24073]
#define sipNameNr_writeStartDocument 24092
#define sipName_writeStartDocument &sipStrings_QtCore[24092]
#define sipNameNr_yieldCurrentThread 24111
#define sipName_yieldCurrentThread &sipStrings_QtCore[24111]
#define sipNameNr_AndroidNougat_MR1 24130
#define sipName_AndroidNougat_MR1 &sipStrings_QtCore[24130]
#define sipNameNr_AntiguaAndBarbuda 24148
#define sipName_AntiguaAndBarbuda &sipStrings_QtCore[24148]
#define sipNameNr_AppConfigLocation 24166
#define sipName_AppConfigLocation &sipStrings_QtCore[24166]
#define sipNameNr_ApplicationActive 24184
#define sipName_ApplicationActive &sipStrings_QtCore[24184]
#define sipNameNr_ApplicationHidden 24202
#define sipName_ApplicationHidden &sipStrings_QtCore[24202]
#define sipNameNr_AutoConnectPolicy 3698
#define sipName_AutoConnectPolicy &sipStrings_QtCore[3698]
#define sipNameNr_Base64UrlEncoding 24220
#define sipName_Base64UrlEncoding &sipStrings_QtCore[24220]
#define sipNameNr_BottomLeftSection 24238
#define sipName_BottomLeftSection &sipStrings_QtCore[24238]
#define sipNameNr_BottomRightCorner 24256
#define sipName_BottomRightCorner &sipStrings_QtCore[24256]
#define sipNameNr_BottomToolBarArea 24274
#define sipName_BottomToolBarArea &sipStrings_QtCore[24274]
#define sipNameNr_CommunicationMode 779
#define sipName_CommunicationMode &sipStrings_QtCore[779]
#define sipNameNr_ContainsItemShape 24292
#define sipName_ContainsItemShape &sipStrings_QtCore[24292]
#define sipNameNr_ContextMenuPolicy 14519
#define sipName_ContextMenuPolicy &sipStrings_QtCore[14519]
#define sipNameNr_ConvertInitialBom 24310
#define sipName_ConvertInitialBom &sipStrings_QtCore[24310]
#define sipNameNr_CustomContextMenu 24328
#define sipName_CustomContextMenu &sipStrings_QtCore[24328]
#define sipNameNr_DataSizeIecFormat 24346
#define sipName_DataSizeIecFormat &sipStrings_QtCore[24346]
#define sipNameNr_DefaultResolution 24364
#define sipName_DefaultResolution &sipStrings_QtCore[24364]
#define sipNameNr_DeleteWhenStopped 24382
#define sipName_DeleteWhenStopped &sipStrings_QtCore[24382]
#define sipNameNr_DeviceCoordinates 24400
#define sipName_DeviceCoordinates &sipStrings_QtCore[24400]
#define sipNameNr_DocumentationPath 24418
#define sipName_DocumentationPath &sipStrings_QtCore[24418]
#define sipNameNr_DocumentsLocation 24436
#define sipName_DocumentsLocation &sipStrings_QtCore[24436]
#define sipNameNr_DominicanRepublic 24454
#define sipName_DominicanRepublic &sipStrings_QtCore[24454]
#define sipNameNr_DontCaptureOption 24472
#define sipName_DontCaptureOption &sipStrings_QtCore[24472]
#define sipNameNr_ExpectedBase64url 24490
#define sipName_ExpectedBase64url &sipStrings_QtCore[24490]
#define sipNameNr_ForwardedChannels 24508
#define sipName_ForwardedChannels &sipStrings_QtCore[24508]
#define sipNameNr_GraphicsSceneDrop 24526
#define sipName_GraphicsSceneDrop &sipStrings_QtCore[24526]
#define sipNameNr_GraphicsSceneHelp 24544
#define sipName_GraphicsSceneHelp &sipStrings_QtCore[24544]
#define sipNameNr_GraphicsSceneMove 24562
#define sipName_GraphicsSceneMove &sipStrings_QtCore[24562]
#define sipNameNr_HighEventPriority 24580
#define sipName_HighEventPriority &sipStrings_QtCore[24580]
#define sipNameNr_IgnoreAspectRatio 24598
#define sipName_IgnoreAspectRatio &sipStrings_QtCore[24598]
#define sipNameNr_IllegalSimpleType 24616
#define sipName_IllegalSimpleType &sipStrings_QtCore[24616]
#define sipNameNr_IllegalUTF8String 24634
#define sipName_IllegalUTF8String &sipStrings_QtCore[24634]
#define sipNameNr_ImAnchorRectangle 24652
#define sipName_ImAnchorRectangle &sipStrings_QtCore[24652]
#define sipNameNr_ImCursorRectangle 24670
#define sipName_ImCursorRectangle &sipStrings_QtCore[24670]
#define sipNameNr_ImSurroundingText 24688
#define sipName_ImSurroundingText &sipStrings_QtCore[24688]
#define sipNameNr_ImTextAfterCursor 24706
#define sipName_ImTextAfterCursor &sipStrings_QtCore[24706]
#define sipNameNr_InheritFromParent 24724
#define sipName_InheritFromParent &sipStrings_QtCore[24724]
#define sipNameNr_InvalidCharacters 24742
#define sipName_InvalidCharacters &sipStrings_QtCore[24742]
#define sipNameNr_InvalidUtf8String 24760
#define sipName_InvalidUtf8String &sipStrings_QtCore[24760]
#define sipNameNr_ItemIsDragEnabled 24778
#define sipName_ItemIsDragEnabled &sipStrings_QtCore[24778]
#define sipNameNr_ItemIsDropEnabled 24796
#define sipName_ItemIsDropEnabled &sipStrings_QtCore[24796]
#define sipNameNr_ItemSelectionMode 14541
#define sipName_ItemSelectionMode &sipStrings_QtCore[14541]
#define sipNameNr_Key_Dead_Abovedot 24814
#define sipName_Key_Dead_Abovedot &sipStrings_QtCore[24814]
#define sipNameNr_Key_Dead_Belowdot 24832
#define sipName_Key_Dead_Belowdot &sipStrings_QtCore[24832]
#define sipNameNr_Key_Dead_Currency 24850
#define sipName_Key_Dead_Currency &sipStrings_QtCore[24850]
#define sipNameNr_Key_Hangul_Jeonja 24868
#define sipName_Key_Hangul_Jeonja &sipStrings_QtCore[24868]
#define sipNameNr_Key_Hangul_Romaja 24886
#define sipName_Key_Hangul_Romaja &sipStrings_QtCore[24886]
#define sipNameNr_Key_MediaPrevious 24904
#define sipName_Key_MediaPrevious &sipStrings_QtCore[24904]
#define sipNameNr_Key_MicVolumeDown 24922
#define sipName_Key_MicVolumeDown &sipStrings_QtCore[24922]
#define sipNameNr_Key_RotateWindows 24940
#define sipName_Key_RotateWindows &sipStrings_QtCore[24940]
#define sipNameNr_Key_guillemotleft 24958
#define sipName_Key_guillemotleft &sipStrings_QtCore[24958]
#define sipNameNr_Key_threequarters 24976
#define sipName_Key_threequarters &sipStrings_QtCore[24976]
#define sipNameNr_Key_threesuperior 24994
#define sipName_Key_threesuperior &sipStrings_QtCore[24994]
#define sipNameNr_MeasurementSystem 6858
#define sipName_MeasurementSystem &sipStrings_QtCore[6858]
#define sipNameNr_MeiteiMayekScript 25012
#define sipName_MeiteiMayekScript &sipStrings_QtCore[25012]
#define sipNameNr_NativeGestureType 14563
#define sipName_NativeGestureType &sipStrings_QtCore[14563]
#define sipNameNr_NeedsConstruction 25030
#define sipName_NeedsConstruction &sipStrings_QtCore[25030]
#define sipNameNr_NoOpaqueDetection 25048
#define sipName_NoOpaqueDetection &sipStrings_QtCore[25048]
#define sipNameNr_NoTextInteraction 25066
#define sipName_NoTextInteraction &sipStrings_QtCore[25066]
#define sipNameNr_OrientationChange 25084
#define sipName_OrientationChange &sipStrings_QtCore[25084]
#define sipNameNr_PahawhHmongScript 25102
#define sipName_PahawhHmongScript &sipStrings_QtCore[25102]
#define sipNameNr_PreventUnloadHint 25120
#define sipName_PreventUnloadHint &sipStrings_QtCore[25120]
#define sipNameNr_ProcessEventsFlag 4000
#define sipName_ProcessEventsFlag &sipStrings_QtCore[4000]
#define sipNameNr_QByteArrayMatcher 25138
#define sipName_QByteArrayMatcher &sipStrings_QtCore[25138]
#define sipNameNr_QCalendar__System 25156
#define sipName_QCalendar__System &sipStrings_QtCore[25156]
#define sipNameNr_QCameraPermission 25174
#define sipName_QCameraPermission &sipStrings_QtCore[25174]
#define sipNameNr_QCborStreamReader 25192
#define sipName_QCborStreamReader &sipStrings_QtCore[25192]
#define sipNameNr_QCborStreamWriter 25210
#define sipName_QCborStreamWriter &sipStrings_QtCore[25210]
#define sipNameNr_25228 25228
#define sipName_25228 &sipStrings_QtCore[25228]
#define sipNameNr_QLocale__Language 25246
#define sipName_QLocale__Language &sipStrings_QtCore[25246]
#define sipNameNr_QSettings__Format 25264
#define sipName_QSettings__Format &sipStrings_QtCore[25264]
#define sipNameNr_QSettings__Status 25282
#define sipName_QSettings__Status &sipStrings_QtCore[25282]
#define sipNameNr_QT_TRANSLATE_NOOP 25300
#define sipName_QT_TRANSLATE_NOOP &sipStrings_QtCore[25300]
#define sipNameNr_QThread__Priority 25318
#define sipName_QThread__Priority &sipStrings_QtCore[25318]
#define sipNameNr_QUrl__ParsingMode 25336
#define sipName_QUrl__ParsingMode &sipStrings_QtCore[25336]
#define sipNameNr_QUuid__Id128Bytes 25354
#define sipName_QUuid__Id128Bytes &sipStrings_QtCore[25354]
#define sipNameNr_QVariantAnimation 25372
#define sipName_QVariantAnimation &sipStrings_QtCore[25372]
#define sipNameNr_Qt__AlignmentFlag 25390
#define sipName_Qt__AlignmentFlag &sipStrings_QtCore[25390]
#define sipNameNr_Qt__ClipOperation 25408
#define sipName_Qt__ClipOperation &sipStrings_QtCore[25408]
#define sipNameNr_Qt__EventPriority 25426
#define sipName_Qt__EventPriority &sipStrings_QtCore[25426]
#define sipNameNr_Qt__TextElideMode 25444
#define sipName_Qt__TextElideMode &sipStrings_QtCore[25444]
#define sipNameNr_RegularExpression 6264
#define sipName_RegularExpression &sipStrings_QtCore[6264]
#define sipNameNr_RussianFederation 25462
#define sipName_RussianFederation &sipStrings_QtCore[25462]
#define sipNameNr_ScreenOrientation 14585
#define sipName_ScreenOrientation &sipStrings_QtCore[14585]
#define sipNameNr_Script_Chorasmian 25480
#define sipName_Script_Chorasmian &sipStrings_QtCore[25480]
#define sipNameNr_Script_Devanagari 25498
#define sipName_Script_Devanagari &sipStrings_QtCore[25498]
#define sipNameNr_Script_DivesAkuru 25516
#define sipName_Script_DivesAkuru &sipStrings_QtCore[25516]
#define sipNameNr_Script_Glagolitic 25534
#define sipName_Script_Glagolitic &sipStrings_QtCore[25534]
#define sipNameNr_Script_Kharoshthi 25552
#define sipName_Script_Kharoshthi &sipStrings_QtCore[25552]
#define sipNameNr_Script_Manichaean 25570
#define sipName_Script_Manichaean &sipStrings_QtCore[25570]
#define sipNameNr_Script_NagMundari 25588
#define sipName_Script_NagMundari &sipStrings_QtCore[25588]
#define sipNameNr_Script_OldPersian 25606
#define sipName_Script_OldPersian &sipStrings_QtCore[25606]
#define sipNameNr_Script_OldSogdian 25624
#define sipName_Script_OldSogdian &sipStrings_QtCore[25624]
#define sipNameNr_Script_Phoenician 25642
#define sipName_Script_Phoenician &sipStrings_QtCore[25642]
#define sipNameNr_Script_Saurashtra 25660
#define sipName_Script_Saurashtra &sipStrings_QtCore[25660]
#define sipNameNr_Script_TolongSiki 25678
#define sipName_Script_TolongSiki &sipStrings_QtCore[25678]
#define sipNameNr_Script_WarangCiti 25696
#define sipName_Script_WarangCiti &sipStrings_QtCore[25696]
#define sipNameNr_ScrollBarAlwaysOn 25714
#define sipName_ScrollBarAlwaysOn &sipStrings_QtCore[25714]
#define sipNameNr_ScrollBarAsNeeded 25732
#define sipName_ScrollBarAsNeeded &sipStrings_QtCore[25732]
#define sipNameNr_SharedMemoryError 2734
#define sipName_SharedMemoryError &sipStrings_QtCore[2734]
#define sipNameNr_SignWritingScript 25750
#define sipName_SignWritingScript &sipStrings_QtCore[25750]
#define sipNameNr_SizeLimitExceeded 25768
#define sipName_SizeLimitExceeded &sipStrings_QtCore[25768]
#define sipNameNr_SkipChildElements 25786
#define sipName_SkipChildElements &sipStrings_QtCore[25786]
#define sipNameNr_SoraSompengScript 25804
#define sipName_SoraSompengScript &sipStrings_QtCore[25804]
#define sipNameNr_StandardQuotation 25822
#define sipName_StandardQuotation &sipStrings_QtCore[25822]
#define sipNameNr_SylotiNagriScript 25840
#define sipName_SylotiNagriScript &sipStrings_QtCore[25840]
#define sipNameNr_TapAndHoldGesture 25858
#define sipName_TapAndHoldGesture &sipStrings_QtCore[25858]
#define sipNameNr_TemplatesLocation 25876
#define sipName_TemplatesLocation &sipStrings_QtCore[25876]
#define sipNameNr_TextAlignmentRole 25894
#define sipName_TextAlignmentRole &sipStrings_QtCore[25894]
#define sipNameNr_TopDockWidgetArea 25912
#define sipName_TopDockWidgetArea &sipStrings_QtCore[25912]
#define sipNameNr_TouchPointPressed 25930
#define sipName_TouchPointPressed &sipStrings_QtCore[25930]
#define sipNameNr_TrinidadAndTobago 25948
#define sipName_TrinidadAndTobago &sipStrings_QtCore[25948]
#define sipNameNr_UI_AnimateToolBox 25966
#define sipName_UI_AnimateToolBox &sipStrings_QtCore[25966]
#define sipNameNr_UI_AnimateTooltip 25984
#define sipName_UI_AnimateTooltip &sipStrings_QtCore[25984]
#define sipNameNr_UnterminatedArray 26002
#define sipName_UnterminatedArray &sipStrings_QtCore[26002]
#define sipNameNr_WA_AttributeCount 26020
#define sipName_WA_AttributeCount &sipStrings_QtCore[26020]
#define sipNameNr_WA_KeyCompression 26038
#define sipName_WA_KeyCompression &sipStrings_QtCore[26038]
#define sipNameNr_WA_OutsideWSRange 26056
#define sipName_WA_OutsideWSRange &sipStrings_QtCore[26056]
#define sipNameNr_WA_PaintUnclipped 26074
#define sipName_WA_PaintUnclipped &sipStrings_QtCore[26074]
#define sipNameNr_WA_StaticContents 26092
#define sipName_WA_StaticContents &sipStrings_QtCore[26092]
#define sipNameNr_WA_TabletTracking 26110
#define sipName_WA_TabletTracking &sipStrings_QtCore[26110]
#define sipNameNr_WA_WState_Created 26128
#define sipName_WA_WState_Created &sipStrings_QtCore[26128]
#define sipNameNr_WA_WState_Visible 26146
#define sipName_WA_WState_Visible &sipStrings_QtCore[26146]
#define sipNameNr_WA_WindowModified 26164
#define sipName_WA_WindowModified &sipStrings_QtCore[26164]
#define sipNameNr_WaitForMoreEvents 26182
#define sipName_WaitForMoreEvents &sipStrings_QtCore[26182]
#define sipNameNr_WindowStateChange 26200
#define sipName_WindowStateChange &sipStrings_QtCore[26200]
#define sipNameNr_WindowTitleChange 26218
#define sipName_WindowTitleChange &sipStrings_QtCore[26218]
#define sipNameNr_ZoomNativeGesture 12839
#define sipName_ZoomNativeGesture &sipStrings_QtCore[12839]
#define sipNameNr_activeThreadCount 26236
#define sipName_activeThreadCount &sipStrings_QtCore[26236]
#define sipNameNr_autoConnectPolicy 26254
#define sipName_autoConnectPolicy &sipStrings_QtCore[26254]
#define sipNameNr_autoDetectUnicode 26272
#define sipName_autoDetectUnicode &sipStrings_QtCore[26272]
#define sipNameNr_beginFilterChange 26290
#define sipName_beginFilterChange &sipStrings_QtCore[26290]
#define sipNameNr_canonicalFilePath 26308
#define sipName_canonicalFilePath &sipStrings_QtCore[26308]
#define sipNameNr_clearCurrentIndex 26326
#define sipName_clearCurrentIndex &sipStrings_QtCore[26326]
#define sipNameNr_closeWriteChannel 26344
#define sipName_closeWriteChannel &sipStrings_QtCore[26344]
#define sipNameNr_commitTransaction 26362
#define sipName_commitTransaction &sipStrings_QtCore[26362]
#define sipNameNr_currentRowChanged 26380
#define sipName_currentRowChanged &sipStrings_QtCore[26380]
#define sipNameNr_dynamicSortFilter 26398
#define sipName_dynamicSortFilter &sipStrings_QtCore[26398]
#define sipNameNr_filterNativeEvent 26416
#define sipName_filterNativeEvent &sipStrings_QtCore[26416]
#define sipNameNr_filterRoleChanged 26434
#define sipName_filterRoleChanged &sipStrings_QtCore[26434]
#define sipNameNr_formattedDataSize 26452
#define sipName_formattedDataSize &sipStrings_QtCore[26452]
#define sipNameNr_headerDataChanged 26470
#define sipName_headerDataChanged &sipStrings_QtCore[26470]
#define sipNameNr_ianaIdToWindowsId 26488
#define sipName_ianaIdToWindowsId &sipStrings_QtCore[26488]
#define sipNameNr_ignorePunctuation 26506
#define sipName_ignorePunctuation &sipStrings_QtCore[26506]
#define sipNameNr_indexOfEnumerator 26524
#define sipName_indexOfEnumerator &sipStrings_QtCore[26524]
#define sipNameNr_installTranslator 26542
#define sipName_installTranslator &sipStrings_QtCore[26542]
#define sipNameNr_intersectionPoint 26560
#define sipName_intersectionPoint &sipStrings_QtCore[26560]
#define sipNameNr_isCriticalEnabled 26578
#define sipName_isCriticalEnabled &sipStrings_QtCore[26578]
#define sipNameNr_isEntityReference 26596
#define sipName_isEntityReference &sipStrings_QtCore[26596]
#define sipNameNr_isNegativeInteger 26614
#define sipName_isNegativeInteger &sipStrings_QtCore[26614]
#define sipNameNr_isQuitLockEnabled 26632
#define sipName_isQuitLockEnabled &sipStrings_QtCore[26632]
#define sipNameNr_isSignalConnected 26650
#define sipName_isSignalConnected &sipStrings_QtCore[26650]
#define sipNameNr_isSortLocaleAware 26668
#define sipName_isSortLocaleAware &sipStrings_QtCore[26668]
#define sipNameNr_isTextModeEnabled 26686
#define sipName_isTextModeEnabled &sipStrings_QtCore[26686]
#define sipNameNr_isUnsignedInteger 26704
#define sipName_isUnsignedInteger &sipStrings_QtCore[26704]
#define sipNameNr_keyboardModifiers 26722
#define sipName_keyboardModifiers &sipStrings_QtCore[26722]
#define sipNameNr_lastCapturedIndex 26740
#define sipName_lastCapturedIndex &sipStrings_QtCore[26740]
#define sipNameNr_measurementSystem 26758
#define sipName_measurementSystem &sipStrings_QtCore[26758]
#define sipNameNr_nativeCountryName 26776
#define sipName_nativeCountryName &sipStrings_QtCore[26776]
#define sipNameNr_nativeEventFilter 26794
#define sipName_nativeEventFilter &sipStrings_QtCore[26794]
#define sipNameNr_notifySignalIndex 26812
#define sipName_notifySignalIndex &sipStrings_QtCore[26812]
#define sipNameNr_objectNameChanged 26830
#define sipName_objectNameChanged &sipStrings_QtCore[26830]
#define sipNameNr_parameterMetaType 26848
#define sipName_parameterMetaType &sipStrings_QtCore[26848]
#define sipNameNr_parameterTypeName 26866
#define sipName_parameterTypeName &sipStrings_QtCore[26866]
#define sipNameNr_prettyProductName 26884
#define sipName_prettyProductName &sipStrings_QtCore[26884]
#define sipNameNr_qFormatLogMessage 26902
#define sipName_qFormatLogMessage &sipStrings_QtCore[26902]
#define sipNameNr_readAllUtf8String 26920
#define sipName_readAllUtf8String &sipStrings_QtCore[26920]
#define sipNameNr_registerEventType 26938
#define sipName_registerEventType &sipStrings_QtCore[26938]
#define sipNameNr_regularExpression 26956
#define sipName_regularExpression &sipStrings_QtCore[26956]
#define sipNameNr_removeEventFilter 26974
#define sipName_removeEventFilter &sipStrings_QtCore[26974]
#define sipNameNr_removeLibraryPath 26992
#define sipName_removeLibraryPath &sipStrings_QtCore[26992]
#define sipNameNr_removeRecursively 27010
#define sipName_removeRecursively &sipStrings_QtCore[27010]
#define sipNameNr_removeSourceModel 27028
#define sipName_removeSourceModel &sipStrings_QtCore[27028]
#define sipNameNr_requestPermission 27046
#define sipName_requestPermission &sipStrings_QtCore[27046]
#define sipNameNr_resetInternalData 27064
#define sipName_resetInternalData &sipStrings_QtCore[27064]
#define sipNameNr_senderSignalIndex 27082
#define sipName_senderSignalIndex &sipStrings_QtCore[27082]
#define sipNameNr_setAutoFormatting 27100
#define sipName_setAutoFormatting &sipStrings_QtCore[27100]
#define sipNameNr_setEntityResolver 27118
#define sipName_setEntityResolver &sipStrings_QtCore[27118]
#define sipNameNr_setExtraSelectors 27136
#define sipName_setExtraSelectors &sipStrings_QtCore[27136]
#define sipNameNr_setFieldAlignment 27154
#define sipName_setFieldAlignment &sipStrings_QtCore[27154]
#define sipNameNr_setFilterWildcard 27172
#define sipName_setFilterWildcard &sipStrings_QtCore[27172]
#define sipNameNr_setMaxThreadCount 27190
#define sipName_setMaxThreadCount &sipStrings_QtCore[27190]
#define sipNameNr_setPatternOptions 27208
#define sipName_setPatternOptions &sipStrings_QtCore[27208]
#define sipNameNr_setSecsSinceEpoch 27226
#define sipName_setSecsSinceEpoch &sipStrings_QtCore[27226]
#define sipNameNr_setThreadPriority 27244
#define sipName_setThreadPriority &sipStrings_QtCore[27244]
#define sipNameNr_setUpdateInterval 27262
#define sipName_setUpdateInterval &sipStrings_QtCore[27262]
#define sipNameNr_standaloneDayName 27280
#define sipName_standaloneDayName &sipStrings_QtCore[27280]
#define sipNameNr_standardLocations 27298
#define sipName_standardLocations &sipStrings_QtCore[27298]
#define sipNameNr_suffixForFileName 27316
#define sipName_suffixForFileName &sipStrings_QtCore[27316]
#define sipNameNr_supportsAlgorithm 27334
#define sipName_supportsAlgorithm &sipStrings_QtCore[27334]
#define sipNameNr_systemEnvironment 27352
#define sipName_systemEnvironment &sipStrings_QtCore[27352]
#define sipNameNr_territoryToString 27370
#define sipName_territoryToString &sipStrings_QtCore[27370]
#define sipNameNr_toMSecsSinceEpoch 27388
#define sipName_toMSecsSinceEpoch &sipStrings_QtCore[27388]
#define sipNameNr_toPercentEncoding 27406
#define sipName_toPercentEncoding &sipStrings_QtCore[27406]
#define sipNameNr_toUnsignedInteger 27424
#define sipName_toUnsignedInteger &sipStrings_QtCore[27424]
#define sipNameNr_updateCurrentTime 27442
#define sipName_updateCurrentTime &sipStrings_QtCore[27442]
#define sipNameNr_writeChannelCount 27460
#define sipName_writeChannelCount &sipStrings_QtCore[27460]
#define sipNameNr_writeCurrentToken 27478
#define sipName_writeCurrentToken &sipStrings_QtCore[27478]
#define sipNameNr_writeEmptyElement 27496
#define sipName_writeEmptyElement &sipStrings_QtCore[27496]
#define sipNameNr_writeQVariantHash 27514
#define sipName_writeQVariantHash &sipStrings_QtCore[27514]
#define sipNameNr_writeQVariantList 27532
#define sipName_writeQVariantList &sipStrings_QtCore[27532]
#define sipNameNr_writeStartElement 27550
#define sipName_writeStartElement &sipStrings_QtCore[27550]
#define sipNameNr_AA_NativeWindows 27568
#define sipName_AA_NativeWindows &sipStrings_QtCore[27568]
#define sipNameNr_ActivationChange 27585
#define sipName_ActivationChange &sipStrings_QtCore[27585]
#define sipNameNr_AndroidJellyBean 27602
#define sipName_AndroidJellyBean &sipStrings_QtCore[27602]
#define sipNameNr_ApplicationModal 27619
#define sipName_ApplicationModal &sipStrings_QtCore[27619]
#define sipNameNr_ApplicationState 16951
#define sipName_ApplicationState &sipStrings_QtCore[16951]
#define sipNameNr_BottomLeftCorner 27636
#define sipName_BottomLeftCorner &sipStrings_QtCore[27636]
#define sipNameNr_BreakOpportunity 27653
#define sipName_BreakOpportunity &sipStrings_QtCore[27653]
#define sipNameNr_CheckIndexOption 1206
#define sipName_CheckIndexOption &sipStrings_QtCore[1206]
#define sipNameNr_ChildWindowAdded 27670
#define sipName_ChildWindowAdded &sipStrings_QtCore[27670]
#define sipNameNr_ClippertonIsland 27687
#define sipName_ClippertonIsland &sipStrings_QtCore[27687]
#define sipNameNr_ClosedHandCursor 27704
#define sipName_ClosedHandCursor &sipStrings_QtCore[27704]
#define sipNameNr_CongoBrazzaville 27721
#define sipName_CongoBrazzaville &sipStrings_QtCore[27721]
#define sipNameNr_CoordinateSystem 16972
#define sipName_CoordinateSystem &sipStrings_QtCore[16972]
#define sipNameNr_CreateNewSession 27738
#define sipName_CreateNewSession &sipStrings_QtCore[27738]
#define sipNameNr_DataSizeSIFormat 27755
#define sipName_DataSizeSIFormat &sipStrings_QtCore[27755]
#define sipNameNr_DefaultTypeForOs 13208
#define sipName_DefaultTypeForOs &sipStrings_QtCore[13208]
#define sipNameNr_DevanagariScript 27772
#define sipName_DevanagariScript &sipStrings_QtCore[27772]
#define sipNameNr_DiagCrossPattern 27789
#define sipName_DiagCrossPattern &sipStrings_QtCore[27789]
#define sipNameNr_DirectConnection 27806
#define sipName_DirectConnection &sipStrings_QtCore[27806]
#define sipNameNr_DisableCoreDumps 27823
#define sipName_DisableCoreDumps &sipStrings_QtCore[27823]
#define sipNameNr_DocumentTooLarge 27840
#define sipName_DocumentTooLarge &sipStrings_QtCore[27840]
#define sipNameNr_DownloadLocation 27857
#define sipName_DownloadLocation &sipStrings_QtCore[27857]
#define sipNameNr_EncodeDelimiters 27874
#define sipName_EncodeDelimiters &sipStrings_QtCore[27874]
#define sipNameNr_EndNativeGesture 27891
#define sipName_EndNativeGesture &sipStrings_QtCore[27891]
#define sipNameNr_EnterKeyPrevious 27908
#define sipName_EnterKeyPrevious &sipStrings_QtCore[27908]
#define sipNameNr_EquatorialGuinea 27925
#define sipName_EquatorialGuinea &sipStrings_QtCore[27925]
#define sipNameNr_FromBase64Result 4475
#define sipName_FromBase64Result &sipStrings_QtCore[4475]
#define sipNameNr_GlagoliticScript 27942
#define sipName_GlagoliticScript &sipStrings_QtCore[27942]
#define sipNameNr_IllegalCharacter 27959
#define sipName_IllegalCharacter &sipStrings_QtCore[27959]
#define sipNameNr_ImAnchorPosition 27976
#define sipName_ImAnchorPosition &sipStrings_QtCore[27976]
#define sipNameNr_ImCursorPosition 27993
#define sipName_ImCursorPosition &sipStrings_QtCore[27993]
#define sipNameNr_ImhLowercaseOnly 28010
#define sipName_ImhLowercaseOnly &sipStrings_QtCore[28010]
#define sipNameNr_ImhNoTextHandles 28027
#define sipName_ImhNoTextHandles &sipStrings_QtCore[28027]
#define sipNameNr_ImhPreferNumbers 28044
#define sipName_ImhPreferNumbers &sipStrings_QtCore[28044]
#define sipNameNr_ImhSensitiveData 28061
#define sipName_ImhSensitiveData &sipStrings_QtCore[28061]
#define sipNameNr_ImhUppercaseOnly 28078
#define sipName_ImhUppercaseOnly &sipStrings_QtCore[28078]
#define sipNameNr_ImperialUKSystem 28095
#define sipName_ImperialUKSystem &sipStrings_QtCore[28095]
#define sipNameNr_ImperialUSSystem 28112
#define sipName_ImperialUSSystem &sipStrings_QtCore[28112]
#define sipNameNr_InputChannelMode 6913
#define sipName_InputChannelMode &sipStrings_QtCore[6913]
#define sipNameNr_InputMethodQuery 16993
#define sipName_InputMethodQuery &sipStrings_QtCore[16993]
#define sipNameNr_InputOutputError 28129
#define sipName_InputOutputError &sipStrings_QtCore[28129]
#define sipNameNr_IntersectionType 9383
#define sipName_IntersectionType &sipStrings_QtCore[9383]
#define sipNameNr_InvalidCharacter 28146
#define sipName_InvalidCharacter &sipStrings_QtCore[28146]
#define sipNameNr_ItemIsSelectable 28163
#define sipName_ItemIsSelectable &sipStrings_QtCore[28163]
#define sipNameNr_Key_AudioForward 28180
#define sipName_Key_AudioForward &sipStrings_QtCore[28180]
#define sipNameNr_Key_BracketRight 28197
#define sipName_Key_BracketRight &sipStrings_QtCore[28197]
#define sipNameNr_Key_Dead_Cedilla 28214
#define sipName_Key_Dead_Cedilla &sipStrings_QtCore[28214]
#define sipNameNr_Key_Dead_Lowline 28231
#define sipName_Key_Dead_Lowline &sipStrings_QtCore[28231]
#define sipNameNr_Key_Hangul_Banja 28248
#define sipName_Key_Hangul_Banja &sipStrings_QtCore[28248]
#define sipNameNr_Key_Hangul_Hanja 28265
#define sipName_Key_Hangul_Hanja &sipStrings_QtCore[28265]
#define sipNameNr_Key_Hangul_Start 28282
#define sipName_Key_Hangul_Start &sipStrings_QtCore[28282]
#define sipNameNr_Key_nobreakspace 28299
#define sipName_Key_nobreakspace &sipStrings_QtCore[28299]
#define sipNameNr_Key_questiondown 28316
#define sipName_Key_questiondown &sipStrings_QtCore[28316]
#define sipNameNr_KeyboardModifier 17014
#define sipName_KeyboardModifier &sipStrings_QtCore[17014]
#define sipNameNr_KharoshthiScript 28333
#define sipName_KharoshthiScript &sipStrings_QtCore[28333]
#define sipNameNr_LanguageCodeType 8155
#define sipName_LanguageCodeType &sipStrings_QtCore[8155]
#define sipNameNr_LayoutChangeHint 1243
#define sipName_LayoutChangeHint &sipStrings_QtCore[1243]
#define sipNameNr_LogicalMoveStyle 28350
#define sipName_LogicalMoveStyle &sipStrings_QtCore[28350]
#define sipNameNr_LowEventPriority 28367
#define sipName_LowEventPriority &sipStrings_QtCore[28367]
#define sipNameNr_MachAbsoluteTime 28384
#define sipName_MachAbsoluteTime &sipStrings_QtCore[28384]
#define sipNameNr_ManichaeanScript 28401
#define sipName_ManichaeanScript &sipStrings_QtCore[28401]
#define sipNameNr_MapPrivateOption 28418
#define sipName_MapPrivateOption &sipStrings_QtCore[28418]
#define sipNameNr_MatchFixedString 28435
#define sipName_MatchFixedString &sipStrings_QtCore[28435]
#define sipNameNr_MaxUtcOffsetSecs 28452
#define sipName_MaxUtcOffsetSecs &sipStrings_QtCore[28452]
#define sipNameNr_MinUtcOffsetSecs 28469
#define sipName_MinUtcOffsetSecs &sipStrings_QtCore[28469]
#define sipNameNr_MouseButtonPress 3911
#define sipName_MouseButtonPress &sipStrings_QtCore[3911]
#define sipNameNr_MouseEventSource 17035
#define sipName_MouseEventSource &sipStrings_QtCore[17035]
#define sipNameNr_MouseFocusReason 28486
#define sipName_MouseFocusReason &sipStrings_QtCore[28486]
#define sipNameNr_NeedsDestruction 28503
#define sipName_NeedsDestruction &sipStrings_QtCore[28503]
#define sipNameNr_NoDockWidgetArea 28520
#define sipName_NoDockWidgetArea &sipStrings_QtCore[28520]
#define sipNameNr_NorwegianNynorsk 28537
#define sipName_NorwegianNynorsk &sipStrings_QtCore[28537]
#define sipNameNr_OldPersianScript 28554
#define sipName_OldPersianScript &sipStrings_QtCore[28554]
#define sipNameNr_OtherFocusReason 28571
#define sipName_OtherFocusReason &sipStrings_QtCore[28571]
#define sipNameNr_PYQT_VERSION_STR 28588
#define sipName_PYQT_VERSION_STR &sipStrings_QtCore[28588]
#define sipNameNr_PanNativeGesture 28605
#define sipName_PanNativeGesture &sipStrings_QtCore[28605]
#define sipNameNr_PartiallyChecked 28622
#define sipName_PartiallyChecked &sipStrings_QtCore[28622]
#define sipNameNr_PermissionDenied 28639
#define sipName_PermissionDenied &sipStrings_QtCore[28639]
#define sipNameNr_PermissionStatus 17056
#define sipName_PermissionStatus &sipStrings_QtCore[17056]
#define sipNameNr_PermissionsError 28656
#define sipName_PermissionsError &sipStrings_QtCore[28656]
#define sipNameNr_PhoenicianScript 28673
#define sipName_PhoenicianScript &sipStrings_QtCore[28673]
#define sipNameNr_PicturesLocation 28690
#define sipName_PicturesLocation &sipStrings_QtCore[28690]
#define sipNameNr_PointerToQObject 28707
#define sipName_PointerToQObject &sipStrings_QtCore[28707]
#define sipNameNr_PopupFocusReason 28724
#define sipName_PopupFocusReason &sipStrings_QtCore[28724]
#define sipNameNr_QCborError__Code 28741
#define sipName_QCborError__Code &sipStrings_QtCore[28741]
#define sipNameNr_QCollatorSortKey 28758
#define sipName_QCollatorSortKey &sipStrings_QtCore[28758]
#define sipNameNr_QCoreApplication 28775
#define sipName_QCoreApplication &sipStrings_QtCore[28775]
#define sipNameNr_QEventLoopLocker 28792
#define sipName_QEventLoopLocker &sipStrings_QtCore[28792]
#define sipNameNr_28809 28809
#define sipName_28809 &sipStrings_QtCore[28809]
#define sipNameNr_QGenericArgument 28826
#define sipName_QGenericArgument &sipStrings_QtCore[28826]
#define sipNameNr_QJsonValue__Type 28843
#define sipName_QJsonValue__Type &sipStrings_QtCore[28843]
#define sipNameNr_28860 28860
#define sipName_28860 &sipStrings_QtCore[28860]
#define sipNameNr_28877 28877
#define sipName_28877 &sipStrings_QtCore[28877]
#define sipNameNr_28894 28894
#define sipName_28894 &sipStrings_QtCore[28894]
#define sipNameNr_QLocale__Country 28911
#define sipName_QLocale__Country &sipStrings_QtCore[28911]
#define sipNameNr_QLoggingCategory 28928
#define sipName_QLoggingCategory &sipStrings_QtCore[28928]
#define sipNameNr_QNativeInterface 28945
#define sipName_QNativeInterface &sipStrings_QtCore[28945]
#define sipNameNr_QPyAbstractRange 28962
#define sipName_QPyAbstractRange &sipStrings_QtCore[28962]
#define sipNameNr_QPySequenceRange 28979
#define sipName_QPySequenceRange &sipStrings_QtCore[28979]
#define sipNameNr_QRandomGenerator 28996
#define sipName_QRandomGenerator &sipStrings_QtCore[28996]
#define sipNameNr_QSettings__Scope 29013
#define sipName_QSettings__Scope &sipStrings_QtCore[29013]
#define sipNameNr_QStringConverter 29030
#define sipName_QStringConverter &sipStrings_QtCore[29030]
#define sipNameNr_QStringListModel 29047
#define sipName_QStringListModel &sipStrings_QtCore[29047]
#define sipNameNr_QSysInfo__Endian 29064
#define sipName_QSysInfo__Endian &sipStrings_QtCore[29064]
#define sipNameNr_QSystemSemaphore 29081
#define sipName_QSystemSemaphore &sipStrings_QtCore[29081]
#define sipNameNr_QTimeLine__State 29098
#define sipName_QTimeLine__State &sipStrings_QtCore[29098]
#define sipNameNr_QXmlStreamReader 29115
#define sipName_QXmlStreamReader &sipStrings_QtCore[29115]
#define sipNameNr_QXmlStreamWriter 29132
#define sipName_QXmlStreamWriter &sipStrings_QtCore[29132]
#define sipNameNr_Qt__ChecksumType 29149
#define sipName_Qt__ChecksumType &sipStrings_QtCore[29149]
#define sipNameNr_Qt__EnterKeyType 29166
#define sipName_Qt__EnterKeyType &sipStrings_QtCore[29166]
#define sipNameNr_Qt__GestureState 29183
#define sipName_Qt__GestureState &sipStrings_QtCore[29183]
#define sipNameNr_Qt__ItemDataRole 29200
#define sipName_Qt__ItemDataRole &sipStrings_QtCore[29200]
#define sipNameNr_Qt__PenJoinStyle 29217
#define sipName_Qt__PenJoinStyle &sipStrings_QtCore[29217]
#define sipNameNr_QualityOfService 8259
#define sipName_QualityOfService &sipStrings_QtCore[8259]
#define sipNameNr_QueuedConnection 8958
#define sipName_QueuedConnection &sipStrings_QtCore[8958]
#define sipNameNr_RelativeToBefore 29234
#define sipName_RelativeToBefore &sipStrings_QtCore[29234]
#define sipNameNr_ReplaceSelection 29251
#define sipName_ReplaceSelection &sipStrings_QtCore[29251]
#define sipNameNr_RightToolBarArea 29268
#define sipName_RightToolBarArea &sipStrings_QtCore[29268]
#define sipNameNr_RoundPreferFloor 29285
#define sipName_RoundPreferFloor &sipStrings_QtCore[29285]
#define sipNameNr_SaurashtraScript 29302
#define sipName_SaurashtraScript &sipStrings_QtCore[29302]
#define sipNameNr_Script_BeriaErfe 29319
#define sipName_Script_BeriaErfe &sipStrings_QtCore[29319]
#define sipNameNr_Script_Bhaiksuki 29336
#define sipName_Script_Bhaiksuki &sipStrings_QtCore[29336]
#define sipNameNr_Script_Cuneiform 29353
#define sipName_Script_Cuneiform &sipStrings_QtCore[29353]
#define sipNameNr_Script_Inherited 29370
#define sipName_Script_Inherited &sipStrings_QtCore[29370]
#define sipNameNr_Script_Khudawadi 29387
#define sipName_Script_Khudawadi &sipStrings_QtCore[29387]
#define sipNameNr_Script_Malayalam 29404
#define sipName_Script_Malayalam &sipStrings_QtCore[29404]
#define sipNameNr_Script_Mongolian 29421
#define sipName_Script_Mongolian &sipStrings_QtCore[29421]
#define sipNameNr_Script_Nabataean 29438
#define sipName_Script_Nabataean &sipStrings_QtCore[29438]
#define sipNameNr_Script_NewTaiLue 29455
#define sipName_Script_NewTaiLue &sipStrings_QtCore[29455]
#define sipNameNr_Script_OldItalic 29472
#define sipName_Script_OldItalic &sipStrings_QtCore[29472]
#define sipNameNr_Script_OldPermic 29489
#define sipName_Script_OldPermic &sipStrings_QtCore[29489]
#define sipNameNr_Script_OldTurkic 29506
#define sipName_Script_OldTurkic &sipStrings_QtCore[29506]
#define sipNameNr_Script_OldUyghur 29523
#define sipName_Script_OldUyghur &sipStrings_QtCore[29523]
#define sipNameNr_Script_Palmyrene 29540
#define sipName_Script_Palmyrene &sipStrings_QtCore[29540]
#define sipNameNr_Script_PauCinHau 29557
#define sipName_Script_PauCinHau &sipStrings_QtCore[29557]
#define sipNameNr_Script_Samaritan 29574
#define sipName_Script_Samaritan &sipStrings_QtCore[29574]
#define sipNameNr_Script_Sundanese 29591
#define sipName_Script_Sundanese &sipStrings_QtCore[29591]
#define sipNameNr_SeparateChannels 29608
#define sipName_SeparateChannels &sipStrings_QtCore[29608]
#define sipNameNr_ShortOptionStyle 29625
#define sipName_ShortOptionStyle &sipStrings_QtCore[29625]
#define sipNameNr_ShortcutOverride 29642
#define sipName_ShortcutOverride &sipStrings_QtCore[29642]
#define sipNameNr_StandardLocation 2801
#define sipName_StandardLocation &sipStrings_QtCore[2801]
#define sipNameNr_StringResultCode 1462
#define sipName_StringResultCode &sipStrings_QtCore[1462]
#define sipNameNr_TabFocusBehavior 17077
#define sipName_TabFocusBehavior &sipStrings_QtCore[17077]
#define sipNameNr_TargetMoveAction 29659
#define sipName_TargetMoveAction &sipStrings_QtCore[29659]
#define sipNameNr_TextHideMnemonic 29676
#define sipName_TextHideMnemonic &sipStrings_QtCore[29676]
#define sipNameNr_TextShowMnemonic 29693
#define sipName_TextShowMnemonic &sipStrings_QtCore[29693]
#define sipNameNr_TextWrapAnywhere 29710
#define sipName_TextWrapAnywhere &sipStrings_QtCore[29710]
#define sipNameNr_TokelauTerritory 29727
#define sipName_TokelauTerritory &sipStrings_QtCore[29727]
#define sipNameNr_TranslationsPath 29744
#define sipName_TranslationsPath &sipStrings_QtCore[29744]
#define sipNameNr_UniqueConnection 29761
#define sipName_UniqueConnection &sipStrings_QtCore[29761]
#define sipNameNr_UnspecifiedError 29778
#define sipName_UnspecifiedError &sipStrings_QtCore[29778]
#define sipNameNr_VaticanCityState 29795
#define sipName_VaticanCityState &sipStrings_QtCore[29795]
#define sipNameNr_VerticalSortHint 29812
#define sipName_VerticalSortHint &sipStrings_QtCore[29812]
#define sipNameNr_WA_DeleteOnClose 29829
#define sipName_WA_DeleteOnClose &sipStrings_QtCore[29829]
#define sipNameNr_WA_ForceDisabled 29846
#define sipName_WA_ForceDisabled &sipStrings_QtCore[29846]
#define sipNameNr_WA_MacNormalSize 29863
#define sipName_WA_MacNormalSize &sipStrings_QtCore[29863]
#define sipNameNr_WA_MouseTracking 29880
#define sipName_WA_MouseTracking &sipStrings_QtCore[29880]
#define sipNameNr_WA_NoMouseReplay 29897
#define sipName_WA_NoMouseReplay &sipStrings_QtCore[29897]
#define sipNameNr_WA_PaintOnScreen 29914
#define sipName_WA_PaintOnScreen &sipStrings_QtCore[29914]
#define sipNameNr_WA_PendingUpdate 29931
#define sipName_WA_PendingUpdate &sipStrings_QtCore[29931]
#define sipNameNr_WA_SetWindowIcon 29948
#define sipName_WA_SetWindowIcon &sipStrings_QtCore[29948]
#define sipNameNr_WA_WState_Hidden 29965
#define sipName_WA_WState_Hidden &sipStrings_QtCore[29965]
#define sipNameNr_WhatsThisClicked 29982
#define sipName_WhatsThisClicked &sipStrings_QtCore[29982]
#define sipNameNr_WhiteSpaceNoWrap 29999
#define sipName_WhiteSpaceNoWrap &sipStrings_QtCore[29999]
#define sipNameNr_WhiteSpaceNormal 30016
#define sipName_WhiteSpaceNormal &sipStrings_QtCore[30016]
#define sipNameNr_WindowDeactivate 30033
#define sipName_WindowDeactivate &sipStrings_QtCore[30033]
#define sipNameNr_WindowFullScreen 30050
#define sipName_WindowFullScreen &sipStrings_QtCore[30050]
#define sipNameNr_WindowIconChange 5313
#define sipName_WindowIconChange &sipStrings_QtCore[5313]
#define sipNameNr_abortTransaction 30067
#define sipName_abortTransaction &sipStrings_QtCore[30067]
#define sipNameNr_absoluteFilePath 30084
#define sipName_absoluteFilePath &sipStrings_QtCore[30084]
#define sipNameNr_addVersionOption 30101
#define sipName_addVersionOption &sipStrings_QtCore[30101]
#define sipNameNr_beginMoveColumns 30118
#define sipName_beginMoveColumns &sipStrings_QtCore[30118]
#define sipNameNr_channelReadyRead 30135
#define sipName_channelReadyRead &sipStrings_QtCore[30135]
#define sipNameNr_checkConnectArgs 30152
#define sipName_checkConnectArgs &sipStrings_QtCore[30152]
#define sipNameNr_closeReadChannel 30169
#define sipName_closeReadChannel &sipStrings_QtCore[30169]
#define sipNameNr_completeBaseName 30186
#define sipName_completeBaseName &sipStrings_QtCore[30186]
#define sipNameNr_compressionLevel 30203
#define sipName_compressionLevel &sipStrings_QtCore[30203]
#define sipNameNr_constructorCount 30220
#define sipName_constructorCount &sipStrings_QtCore[30220]
#define sipNameNr_createNativeFile 30237
#define sipName_createNativeFile &sipStrings_QtCore[30237]
#define sipNameNr_currentAnimation 30254
#define sipName_currentAnimation &sipStrings_QtCore[30254]
#define sipNameNr_dateTimeToString 30271
#define sipName_dateTimeToString &sipStrings_QtCore[30271]
#define sipNameNr_directionChanged 30288
#define sipName_directionChanged &sipStrings_QtCore[30288]
#define sipNameNr_directoryChanged 30305
#define sipName_directoryChanged &sipStrings_QtCore[30305]
#define sipNameNr_disconnectNotify 30322
#define sipName_disconnectNotify &sipStrings_QtCore[30322]
#define sipNameNr_documentEncoding 30339
#define sipName_documentEncoding &sipStrings_QtCore[30339]
#define sipNameNr_endInsertColumns 30356
#define sipName_endInsertColumns &sipStrings_QtCore[30356]
#define sipNameNr_endRemoveColumns 30373
#define sipName_endRemoveColumns &sipStrings_QtCore[30373]
#define sipNameNr_enumeratorOffset 30390
#define sipName_enumeratorOffset &sipStrings_QtCore[30390]
#define sipNameNr_fallbacksEnabled 30407
#define sipName_fallbacksEnabled &sipStrings_QtCore[30407]
#define sipNameNr_filterAcceptsRow 30424
#define sipName_filterAcceptsRow &sipStrings_QtCore[30424]
#define sipNameNr_idealThreadCount 30441
#define sipName_idealThreadCount &sipStrings_QtCore[30441]
#define sipNameNr_indexOfAnimation 30458
#define sipName_indexOfAnimation &sipStrings_QtCore[30458]
#define sipNameNr_indexOfClassInfo 30475
#define sipName_indexOfClassInfo &sipStrings_QtCore[30475]
#define sipNameNr_inputChannelMode 30492
#define sipName_inputChannelMode &sipStrings_QtCore[30492]
#define sipNameNr_invalidateFilter 30509
#define sipName_invalidateFilter &sipStrings_QtCore[30509]
#define sipNameNr_isColumnSelected 30526
#define sipName_isColumnSelected &sipStrings_QtCore[30526]
#define sipNameNr_isWarningEnabled 30543
#define sipName_isWarningEnabled &sipStrings_QtCore[30543]
#define sipNameNr_languageToString 30560
#define sipName_languageToString &sipStrings_QtCore[30560]
#define sipNameNr_organizationName 30577
#define sipName_organizationName &sipStrings_QtCore[30577]
#define sipNameNr_readAllByteArray 30594
#define sipName_readAllByteArray &sipStrings_QtCore[30594]
#define sipNameNr_readChannelCount 30611
#define sipName_readChannelCount &sipStrings_QtCore[30611]
#define sipNameNr_readQVariantHash 30628
#define sipName_readQVariantHash &sipStrings_QtCore[30628]
#define sipNameNr_readQVariantList 30645
#define sipName_readQVariantList &sipStrings_QtCore[30645]
#define sipNameNr_readRawInnerData 30662
#define sipName_readRawInnerData &sipStrings_QtCore[30662]
#define sipNameNr_registerResource 24037
#define sipName_registerResource &sipStrings_QtCore[24037]
#define sipNameNr_registeredTimers 30679
#define sipName_registeredTimers &sipStrings_QtCore[30679]
#define sipNameNr_relativeFilePath 30696
#define sipName_relativeFilePath &sipStrings_QtCore[30696]
#define sipNameNr_removeTranslator 30713
#define sipName_removeTranslator &sipStrings_QtCore[30713]
#define sipNameNr_roleNamesChanged 30730
#define sipName_roleNamesChanged &sipStrings_QtCore[30730]
#define sipNameNr_searchDelimiters 30747
#define sipName_searchDelimiters &sipStrings_QtCore[30747]
#define sipNameNr_selectionChanged 30764
#define sipName_selectionChanged &sipStrings_QtCore[30764]
#define sipNameNr_sendPostedEvents 30781
#define sipName_sendPostedEvents &sipStrings_QtCore[30781]
#define sipNameNr_setDefaultFormat 30798
#define sipName_setDefaultFormat &sipStrings_QtCore[30798]
#define sipNameNr_setDefaultValues 30815
#define sipName_setDefaultValues &sipStrings_QtCore[30815]
#define sipNameNr_setExpiryTimeout 30832
#define sipName_setExpiryTimeout &sipStrings_QtCore[30832]
#define sipNameNr_setNumberOptions 30849
#define sipName_setNumberOptions &sipStrings_QtCore[30849]
#define sipNameNr_setOffsetFromUtc 30866
#define sipName_setOffsetFromUtc &sipStrings_QtCore[30866]
#define sipNameNr_setRemainingTime 30883
#define sipName_setRemainingTime &sipStrings_QtCore[30883]
#define sipNameNr_setSetuidAllowed 30900
#define sipName_setSetuidAllowed &sipStrings_QtCore[30900]
#define sipNameNr_setStaleLockTime 30917
#define sipName_setStaleLockTime &sipStrings_QtCore[30917]
#define sipNameNr_startTransaction 30934
#define sipName_startTransaction &sipStrings_QtCore[30934]
#define sipNameNr_staticMetaObject 30951
#define sipName_staticMetaObject &sipStrings_QtCore[30951]
#define sipNameNr_systemTimeZoneId 30968
#define sipName_systemTimeZoneId &sipStrings_QtCore[30968]
#define sipNameNr_toCurrencyString 30985
#define sipName_toCurrencyString &sipStrings_QtCore[30985]
#define sipNameNr_toEncodedVersion 31002
#define sipName_toEncodedVersion &sipStrings_QtCore[31002]
#define sipNameNr_toSecsSinceEpoch 31019
#define sipName_toSecsSinceEpoch &sipStrings_QtCore[31019]
#define sipNameNr_uncompressedData 31036
#define sipName_uncompressedData &sipStrings_QtCore[31036]
#define sipNameNr_uncompressedSize 31053
#define sipName_uncompressedSize &sipStrings_QtCore[31053]
#define sipNameNr_unregisterTimers 31070
#define sipName_unregisterTimers &sipStrings_QtCore[31070]
#define sipNameNr_valueForProgress 31087
#define sipName_valueForProgress &sipStrings_QtCore[31087]
#define sipNameNr_waitForReadyRead 31104
#define sipName_waitForReadyRead &sipStrings_QtCore[31104]
#define sipNameNr_workingDirectory 31121
#define sipName_workingDirectory &sipStrings_QtCore[31121]
#define sipNameNr_writableLocation 31138
#define sipName_writableLocation &sipStrings_QtCore[31138]
#define sipNameNr_writeEndDocument 31155
#define sipName_writeEndDocument &sipStrings_QtCore[31155]
#define sipNameNr_writeQStringList 31172
#define sipName_writeQStringList &sipStrings_QtCore[31172]
#define sipNameNr_writeQVariantMap 31189
#define sipName_writeQVariantMap &sipStrings_QtCore[31189]
#define sipNameNr_writeTextElement 31206
#define sipName_writeTextElement &sipStrings_QtCore[31206]
#define sipNameNr_AllToolBarAreas 31223
#define sipName_AllToolBarAreas &sipStrings_QtCore[31223]
#define sipNameNr_AncientEgyptian 31239
#define sipName_AncientEgyptian &sipStrings_QtCore[31239]
#define sipNameNr_AndroidLollipop 31255
#define sipName_AndroidLollipop &sipStrings_QtCore[31255]
#define sipNameNr_AndroidOreo_MR1 31271
#define sipName_AndroidOreo_MR1 &sipStrings_QtCore[31271]
#define sipNameNr_AnyLanguageCode 31287
#define sipName_AnyLanguageCode &sipStrings_QtCore[31287]
#define sipNameNr_AppDataLocation 31303
#define sipName_AppDataLocation &sipStrings_QtCore[31303]
#define sipNameNr_AscensionIsland 31319
#define sipName_AscensionIsland &sipStrings_QtCore[31319]
#define sipNameNr_AspectRatioMode 19331
#define sipName_AspectRatioMode &sipStrings_QtCore[19331]
#define sipNameNr_AssumeLocalFile 31335
#define sipName_AssumeLocalFile &sipStrings_QtCore[31335]
#define sipNameNr_AutoCloseHandle 31351
#define sipName_AutoCloseHandle &sipStrings_QtCore[31351]
#define sipNameNr_BhaiksukiScript 31367
#define sipName_BhaiksukiScript &sipStrings_QtCore[31367]
#define sipNameNr_CaseInsensitive 31383
#define sipName_CaseInsensitive &sipStrings_QtCore[31383]
#define sipNameNr_CaseSensitivity 10009
#define sipName_CaseSensitivity &sipStrings_QtCore[10009]
#define sipNameNr_CeutaAndMelilla 31399
#define sipName_CeutaAndMelilla &sipStrings_QtCore[31399]
#define sipNameNr_ChecksumIso3309 31415
#define sipName_ChecksumIso3309 &sipStrings_QtCore[31415]
#define sipNameNr_ChristmasIsland 31431
#define sipName_ChristmasIsland &sipStrings_QtCore[31431]
#define sipNameNr_ControlModifier 31447
#define sipName_ControlModifier &sipStrings_QtCore[31447]
#define sipNameNr_CuneiformScript 31463
#define sipName_CuneiformScript &sipStrings_QtCore[31463]
#define sipNameNr_CurrencyIsoCode 31479
#define sipName_CurrencyIsoCode &sipStrings_QtCore[31479]
#define sipNameNr_CursorMoveStyle 19371
#define sipName_CursorMoveStyle &sipStrings_QtCore[19371]
#define sipNameNr_DescendingOrder 31495
#define sipName_DescendingOrder &sipStrings_QtCore[31495]
#define sipNameNr_DesktopLocation 31511
#define sipName_DesktopLocation &sipStrings_QtCore[31511]
#define sipNameNr_DontCloseHandle 31527
#define sipName_DontCloseHandle &sipStrings_QtCore[31527]
#define sipNameNr_DoublePrecision 31543
#define sipName_DoublePrecision &sipStrings_QtCore[31543]
#define sipNameNr_EnterKeyDefault 31559
#define sipName_EnterKeyDefault &sipStrings_QtCore[31559]
#define sipNameNr_EntityReference 18191
#define sipName_EntityReference &sipStrings_QtCore[18191]
#define sipNameNr_FalklandIslands 31575
#define sipName_FalklandIslands &sipStrings_QtCore[31575]
#define sipNameNr_FindChildOption 19391
#define sipName_FindChildOption &sipStrings_QtCore[19391]
#define sipNameNr_ForbiddenCursor 31591
#define sipName_ForbiddenCursor &sipStrings_QtCore[31591]
#define sipNameNr_ForeverConstant 3223
#define sipName_ForeverConstant &sipStrings_QtCore[3223]
#define sipNameNr_FrenchPolynesia 31607
#define sipName_FrenchPolynesia &sipStrings_QtCore[31607]
#define sipNameNr_GestureCanceled 31623
#define sipName_GestureCanceled &sipStrings_QtCore[31623]
#define sipNameNr_GestureFinished 31639
#define sipName_GestureFinished &sipStrings_QtCore[31639]
#define sipNameNr_GestureOverride 31655
#define sipName_GestureOverride &sipStrings_QtCore[31655]
#define sipNameNr_HighestPriority 31671
#define sipName_HighestPriority &sipStrings_QtCore[31671]
#define sipNameNr_HitTestAccuracy 19411
#define sipName_HitTestAccuracy &sipStrings_QtCore[19411]
#define sipNameNr_InheritPriority 31687
#define sipName_InheritPriority &sipStrings_QtCore[31687]
#define sipNameNr_InputMethodHint 19431
#define sipName_InputMethodHint &sipStrings_QtCore[19431]
#define sipNameNr_KeepAspectRatio 31703
#define sipName_KeepAspectRatio &sipStrings_QtCore[31703]
#define sipNameNr_KeepWhenStopped 31719
#define sipName_KeepWhenStopped &sipStrings_QtCore[31719]
#define sipNameNr_Key_Acircumflex 31735
#define sipName_Key_Acircumflex &sipStrings_QtCore[31735]
#define sipNameNr_Key_AddFavorite 31751
#define sipName_Key_AddFavorite &sipStrings_QtCore[31751]
#define sipNameNr_Key_AsciiCircum 31767
#define sipName_Key_AsciiCircum &sipStrings_QtCore[31767]
#define sipNameNr_Key_AudioRepeat 31783
#define sipName_Key_AudioRepeat &sipStrings_QtCore[31783]
#define sipNameNr_Key_AudioRewind 31799
#define sipName_Key_AudioRewind &sipStrings_QtCore[31799]
#define sipNameNr_Key_BackForward 31815
#define sipName_Key_BackForward &sipStrings_QtCore[31815]
#define sipNameNr_Key_BracketLeft 31831
#define sipName_Key_BracketLeft &sipStrings_QtCore[31831]
#define sipNameNr_Key_CameraFocus 31847
#define sipName_Key_CameraFocus &sipStrings_QtCore[31847]
#define sipNameNr_Key_ChannelDown 31863
#define sipName_Key_ChannelDown &sipStrings_QtCore[31863]
#define sipNameNr_Key_Dead_Macron 31879
#define sipName_Key_Dead_Macron &sipStrings_QtCore[31879]
#define sipNameNr_Key_Dead_Ogonek 31895
#define sipName_Key_Dead_Ogonek &sipStrings_QtCore[31895]
#define sipNameNr_Key_Dead_Stroke 31911
#define sipName_Key_Dead_Stroke &sipStrings_QtCore[31911]
#define sipNameNr_Key_Direction_L 31927
#define sipName_Key_Direction_L &sipStrings_QtCore[31927]
#define sipNameNr_Key_Direction_R 31943
#define sipName_Key_Direction_R &sipStrings_QtCore[31943]
#define sipNameNr_Key_Ecircumflex 31959
#define sipName_Key_Ecircumflex &sipStrings_QtCore[31959]
#define sipNameNr_Key_Eisu_toggle 31975
#define sipName_Key_Eisu_toggle &sipStrings_QtCore[31975]
#define sipNameNr_Key_Hangul_Jamo 31991
#define sipName_Key_Hangul_Jamo &sipStrings_QtCore[31991]
#define sipNameNr_Key_Icircumflex 32007
#define sipName_Key_Icircumflex &sipStrings_QtCore[32007]
#define sipNameNr_Key_LaunchMedia 32023
#define sipName_Key_LaunchMedia &sipStrings_QtCore[32023]
#define sipNameNr_Key_MailForward 32039
#define sipName_Key_MailForward &sipStrings_QtCore[32039]
#define sipNameNr_Key_MediaRecord 32055
#define sipName_Key_MediaRecord &sipStrings_QtCore[32055]
#define sipNameNr_Key_MicVolumeUp 32071
#define sipName_Key_MicVolumeUp &sipStrings_QtCore[32071]
#define sipNameNr_Key_Mode_switch 32087
#define sipName_Key_Mode_switch &sipStrings_QtCore[32087]
#define sipNameNr_Key_Ocircumflex 32103
#define sipName_Key_Ocircumflex &sipStrings_QtCore[32103]
#define sipNameNr_Key_ScreenSaver 32119
#define sipName_Key_ScreenSaver &sipStrings_QtCore[32119]
#define sipNameNr_Key_SplitScreen 32135
#define sipName_Key_SplitScreen &sipStrings_QtCore[32135]
#define sipNameNr_Key_TouchpadOff 32151
#define sipName_Key_TouchpadOff &sipStrings_QtCore[32151]
#define sipNameNr_Key_Ucircumflex 32167
#define sipName_Key_Ucircumflex &sipStrings_QtCore[32167]
#define sipNameNr_Key_onesuperior 32183
#define sipName_Key_onesuperior &sipStrings_QtCore[32183]
#define sipNameNr_Key_ordfeminine 32199
#define sipName_Key_ordfeminine &sipStrings_QtCore[32199]
#define sipNameNr_Key_twosuperior 32215
#define sipName_Key_twosuperior &sipStrings_QtCore[32215]
#define sipNameNr_KhudawadiScript 32231
#define sipName_KhudawadiScript &sipStrings_QtCore[32231]
#define sipNameNr_LayoutDirection 14983
#define sipName_LayoutDirection &sipStrings_QtCore[14983]
#define sipNameNr_LeftToolBarArea 32247
#define sipName_LeftToolBarArea &sipStrings_QtCore[32247]
#define sipNameNr_LiteraryChinese 32263
#define sipName_LiteraryChinese &sipStrings_QtCore[32263]
#define sipNameNr_LocateDirectory 32279
#define sipName_LocateDirectory &sipStrings_QtCore[32279]
#define sipNameNr_LockFailedError 32295
#define sipName_LockFailedError &sipStrings_QtCore[32295]
#define sipNameNr_MacOSHighSierra 32311
#define sipName_MacOSHighSierra &sipStrings_QtCore[32311]
#define sipNameNr_MalayalamScript 32327
#define sipName_MalayalamScript &sipStrings_QtCore[32327]
#define sipNameNr_MarshallIslands 32343
#define sipName_MarshallIslands &sipStrings_QtCore[32343]
#define sipNameNr_MatchStartsWith 32359
#define sipName_MatchStartsWith &sipStrings_QtCore[32359]
#define sipNameNr_MongolianScript 32375
#define sipName_MongolianScript &sipStrings_QtCore[32375]
#define sipNameNr_MultilineOption 32391
#define sipName_MultilineOption &sipStrings_QtCore[32391]
#define sipNameNr_NabataeanScript 32407
#define sipName_NabataeanScript &sipStrings_QtCore[32407]
#define sipNameNr_NegativeInteger 26616
#define sipName_NegativeInteger &sipStrings_QtCore[26616]
#define sipNameNr_NewTaiLueScript 32423
#define sipName_NewTaiLueScript &sipStrings_QtCore[32423]
#define sipNameNr_NoIteratorFlags 32439
#define sipName_NoIteratorFlags &sipStrings_QtCore[32439]
#define sipNameNr_NoPatternOption 32455
#define sipName_NoPatternOption &sipStrings_QtCore[32455]
#define sipNameNr_NorthernFrisian 32471
#define sipName_NorthernFrisian &sipStrings_QtCore[32471]
#define sipNameNr_NorwegianBokmal 32487
#define sipName_NorwegianBokmal &sipStrings_QtCore[32487]
#define sipNameNr_OldItalicScript 32503
#define sipName_OldItalicScript &sipStrings_QtCore[32503]
#define sipNameNr_OldPermicScript 32519
#define sipName_OldPermicScript &sipStrings_QtCore[32519]
#define sipNameNr_OutlyingOceania 32535
#define sipName_OutlyingOceania &sipStrings_QtCore[32535]
#define sipNameNr_PalmyreneScript 32551
#define sipName_PalmyreneScript &sipStrings_QtCore[32551]
#define sipNameNr_ParentIsInvalid 32567
#define sipName_ParentIsInvalid &sipStrings_QtCore[32567]
#define sipNameNr_PauCinHauScript 32583
#define sipName_PauCinHauScript &sipStrings_QtCore[32583]
#define sipNameNr_PermissionError 32599
#define sipName_PermissionError &sipStrings_QtCore[32599]
#define sipNameNr_PlatformSurface 32615
#define sipName_PlatformSurface &sipStrings_QtCore[32615]
#define sipNameNr_PreferLocalFile 32631
#define sipName_PreferLocalFile &sipStrings_QtCore[32631]
#define sipNameNr_PyQtMutexLocker 32647
#define sipName_PyQtMutexLocker &sipStrings_QtCore[32647]
#define sipNameNr_QAnimationGroup 32663
#define sipName_QAnimationGroup &sipStrings_QtCore[32663]
#define sipNameNr_QCborSimpleType 32679
#define sipName_QCborSimpleType &sipStrings_QtCore[32679]
#define sipNameNr_QJsonParseError 32695
#define sipName_QJsonParseError &sipStrings_QtCore[32695]
#define sipNameNr_QKeyCombination 32711
#define sipName_QKeyCombination &sipStrings_QtCore[32711]
#define sipNameNr_32727 32727
#define sipName_32727 &sipStrings_QtCore[32727]
#define sipNameNr_32743 32743
#define sipName_32743 &sipStrings_QtCore[32743]
#define sipNameNr_QLocale__Script 32759
#define sipName_QLocale__Script &sipStrings_QtCore[32759]
#define sipNameNr_QMetaType__Type 32775
#define sipName_QMetaType__Type &sipStrings_QtCore[32775]
#define sipNameNr_QPauseAnimation 32791
#define sipName_QPauseAnimation &sipStrings_QtCore[32791]
#define sipNameNr_QRecursiveMutex 32807
#define sipName_QRecursiveMutex &sipStrings_QtCore[32807]
#define sipNameNr_QSocketNotifier 32823
#define sipName_QSocketNotifier &sipStrings_QtCore[32823]
#define sipNameNr_QSysInfo__Sizes 32839
#define sipName_QSysInfo__Sizes &sipStrings_QtCore[32839]
#define sipNameNr_Qml2ImportsPath 32855
#define sipName_Qml2ImportsPath &sipStrings_QtCore[32855]
#define sipNameNr_Qt__AnchorPoint 32871
#define sipName_Qt__AnchorPoint &sipStrings_QtCore[32871]
#define sipNameNr_Qt__ColorScheme 32887
#define sipName_Qt__ColorScheme &sipStrings_QtCore[32887]
#define sipNameNr_Qt__CursorShape 32903
#define sipName_Qt__CursorShape &sipStrings_QtCore[32903]
#define sipNameNr_Qt__FocusPolicy 32919
#define sipName_Qt__FocusPolicy &sipStrings_QtCore[32919]
#define sipNameNr_Qt__FocusReason 32935
#define sipName_Qt__FocusReason &sipStrings_QtCore[32935]
#define sipNameNr_Qt__GestureFlag 32951
#define sipName_Qt__GestureFlag &sipStrings_QtCore[32951]
#define sipNameNr_Qt__GestureType 32967
#define sipName_Qt__GestureType &sipStrings_QtCore[32967]
#define sipNameNr_Qt__GlobalColor 32983
#define sipName_Qt__GlobalColor &sipStrings_QtCore[32983]
#define sipNameNr_Qt__MouseButton 32999
#define sipName_Qt__MouseButton &sipStrings_QtCore[32999]
#define sipNameNr_Qt__Orientation 33015
#define sipName_Qt__Orientation &sipStrings_QtCore[33015]
#define sipNameNr_Qt__PenCapStyle 33031
#define sipName_Qt__PenCapStyle &sipStrings_QtCore[33031]
#define sipNameNr_Qt__ScrollPhase 33047
#define sipName_Qt__ScrollPhase &sipStrings_QtCore[33047]
#define sipNameNr_Qt__ToolBarArea 33063
#define sipName_Qt__ToolBarArea &sipStrings_QtCore[33063]
#define sipNameNr_Qt__WindowState 33079
#define sipName_Qt__WindowState &sipStrings_QtCore[33079]
#define sipNameNr_ReadCorruptData 33095
#define sipName_ReadCorruptData &sipStrings_QtCore[33095]
#define sipNameNr_RelativeToAfter 33111
#define sipName_RelativeToAfter &sipStrings_QtCore[33111]
#define sipNameNr_RelocatableType 33127
#define sipName_RelocatableType &sipStrings_QtCore[33127]
#define sipNameNr_RemoveAuthority 33143
#define sipName_RemoveAuthority &sipStrings_QtCore[33143]
#define sipNameNr_RepublicOfKorea 7714
#define sipName_RepublicOfKorea &sipStrings_QtCore[7714]
#define sipNameNr_RuntimeLocation 33159
#define sipName_RuntimeLocation &sipStrings_QtCore[33159]
#define sipNameNr_SaintBarthelemy 33175
#define sipName_SaintBarthelemy &sipStrings_QtCore[33175]
#define sipNameNr_SamaritanScript 33191
#define sipName_SamaritanScript &sipStrings_QtCore[33191]
#define sipNameNr_Script_Armenian 33207
#define sipName_Script_Armenian &sipStrings_QtCore[33207]
#define sipNameNr_Script_Balinese 33223
#define sipName_Script_Balinese &sipStrings_QtCore[33223]
#define sipNameNr_Script_BassaVah 33239
#define sipName_Script_BassaVah &sipStrings_QtCore[33239]
#define sipNameNr_Script_Bopomofo 33255
#define sipName_Script_Bopomofo &sipStrings_QtCore[33255]
#define sipNameNr_Script_Buginese 33271
#define sipName_Script_Buginese &sipStrings_QtCore[33271]
#define sipNameNr_Script_Cherokee 33287
#define sipName_Script_Cherokee &sipStrings_QtCore[33287]
#define sipNameNr_Script_Cyrillic 33303
#define sipName_Script_Cyrillic &sipStrings_QtCore[33303]
#define sipNameNr_Script_Duployan 33319
#define sipName_Script_Duployan &sipStrings_QtCore[33319]
#define sipNameNr_Script_Ethiopic 33335
#define sipName_Script_Ethiopic &sipStrings_QtCore[33335]
#define sipNameNr_Script_Georgian 33351
#define sipName_Script_Georgian &sipStrings_QtCore[33351]
#define sipNameNr_Script_Gujarati 33367
#define sipName_Script_Gujarati &sipStrings_QtCore[33367]
#define sipNameNr_Script_Gurmukhi 33383
#define sipName_Script_Gurmukhi &sipStrings_QtCore[33383]
#define sipNameNr_Script_Hiragana 33399
#define sipName_Script_Hiragana &sipStrings_QtCore[33399]
#define sipNameNr_Script_Javanese 33415
#define sipName_Script_Javanese &sipStrings_QtCore[33415]
#define sipNameNr_Script_Katakana 33431
#define sipName_Script_Katakana &sipStrings_QtCore[33431]
#define sipNameNr_Script_KiratRai 33447
#define sipName_Script_KiratRai &sipStrings_QtCore[33447]
#define sipNameNr_Script_Mahajani 33463
#define sipName_Script_Mahajani &sipStrings_QtCore[33463]
#define sipNameNr_Script_Tagbanwa 33479
#define sipName_Script_Tagbanwa &sipStrings_QtCore[33479]
#define sipNameNr_Script_Tifinagh 33495
#define sipName_Script_Tifinagh &sipStrings_QtCore[33495]
#define sipNameNr_Script_Ugaritic 33511
#define sipName_Script_Ugaritic &sipStrings_QtCore[33511]
#define sipNameNr_Script_Vithkuqi 33527
#define sipName_Script_Vithkuqi &sipStrings_QtCore[33527]
#define sipNameNr_ScrollBarPolicy 19471
#define sipName_ScrollBarPolicy &sipStrings_QtCore[19471]
#define sipNameNr_ShortcutContext 19491
#define sipName_ShortcutContext &sipStrings_QtCore[19491]
#define sipNameNr_SinglePrecision 33543
#define sipName_SinglePrecision &sipStrings_QtCore[33543]
#define sipNameNr_SizeBDiagCursor 33559
#define sipName_SizeBDiagCursor &sipStrings_QtCore[33559]
#define sipNameNr_SizeFDiagCursor 33575
#define sipName_SizeFDiagCursor &sipStrings_QtCore[33575]
#define sipNameNr_SouthernKurdish 33591
#define sipName_SouthernKurdish &sipStrings_QtCore[33591]
#define sipNameNr_SundaneseScript 33607
#define sipName_SundaneseScript &sipStrings_QtCore[33607]
#define sipNameNr_ThresholdDither 33623
#define sipName_ThresholdDither &sipStrings_QtCore[33623]
#define sipNameNr_TokelauLanguage 33639
#define sipName_TokelauLanguage &sipStrings_QtCore[33639]
#define sipNameNr_ToolButtonStyle 19511
#define sipName_ToolButtonStyle &sipStrings_QtCore[19511]
#define sipNameNr_TopRightSection 33655
#define sipName_TopRightSection &sipStrings_QtCore[33655]
#define sipNameNr_TouchPointMoved 33671
#define sipName_TouchPointMoved &sipStrings_QtCore[33671]
#define sipNameNr_TouchPointState 19531
#define sipName_TouchPointState &sipStrings_QtCore[19531]
#define sipNameNr_TransparentMode 33687
#define sipName_TransparentMode &sipStrings_QtCore[33687]
#define sipNameNr_TuvaluTerritory 33703
#define sipName_TuvaluTerritory &sipStrings_QtCore[33703]
#define sipNameNr_UI_AnimateCombo 33719
#define sipName_UI_AnimateCombo &sipStrings_QtCore[33719]
#define sipNameNr_UnexpectedBreak 33735
#define sipName_UnexpectedBreak &sipStrings_QtCore[33735]
#define sipNameNr_UnixProcessFlag 8182
#define sipName_UnixProcessFlag &sipStrings_QtCore[8182]
#define sipNameNr_UnsignedInteger 26706
#define sipName_UnsignedInteger &sipStrings_QtCore[26706]
#define sipNameNr_UnsupportedType 33751
#define sipName_UnsupportedType &sipStrings_QtCore[33751]
#define sipNameNr_UppercaseDigits 33767
#define sipName_UppercaseDigits &sipStrings_QtCore[33767]
#define sipNameNr_VeryCoarseTimer 33783
#define sipName_VeryCoarseTimer &sipStrings_QtCore[33783]
#define sipNameNr_VisualMoveStyle 33799
#define sipName_VisualMoveStyle &sipStrings_QtCore[33799]
#define sipNameNr_WA_MacSmallSize 33815
#define sipName_WA_MacSmallSize &sipStrings_QtCore[33815]
#define sipNameNr_WA_NativeWindow 33831
#define sipName_WA_NativeWindow &sipStrings_QtCore[33831]
#define sipNameNr_WallisAndFutuna 33847
#define sipName_WallisAndFutuna &sipStrings_QtCore[33847]
#define sipNameNr_WhatsThisCursor 33863
#define sipName_WhatsThisCursor &sipStrings_QtCore[33863]
#define sipNameNr_WidgetAttribute 19551
#define sipName_WidgetAttribute &sipStrings_QtCore[19551]
#define sipNameNr_WindowMaximized 33879
#define sipName_WindowMaximized &sipStrings_QtCore[33879]
#define sipNameNr_WindowMinimized 33895
#define sipName_WindowMinimized &sipStrings_QtCore[33895]
#define sipNameNr_WindowTitleHint 33911
#define sipName_WindowTitleHint &sipStrings_QtCore[33911]
#define sipNameNr_WindowType_Mask 33927
#define sipName_WindowType_Mask &sipStrings_QtCore[33927]
#define sipNameNr_WindowUnblocked 33943
#define sipName_WindowUnblocked &sipStrings_QtCore[33943]
#define sipNameNr_ZlibCompression 33959
#define sipName_ZlibCompression &sipStrings_QtCore[33959]
#define sipNameNr_ZstdCompression 33975
#define sipName_ZstdCompression &sipStrings_QtCore[33975]
#define sipNameNr_anchoredPattern 33991
#define sipName_anchoredPattern &sipStrings_QtCore[33991]
#define sipNameNr_appendUndefined 34007
#define sipName_appendUndefined &sipStrings_QtCore[34007]
#define sipNameNr_applicationName 34023
#define sipName_applicationName &sipStrings_QtCore[34023]
#define sipNameNr_availableCodecs 34039
#define sipName_availableCodecs &sipStrings_QtCore[34039]
#define sipNameNr_beginInsertRows 34055
#define sipName_beginInsertRows &sipStrings_QtCore[34055]
#define sipNameNr_beginRemoveRows 34071
#define sipName_beginRemoveRows &sipStrings_QtCore[34071]
#define sipNameNr_beginResetModel 34087
#define sipName_beginResetModel &sipStrings_QtCore[34087]
#define sipNameNr_beginWriteArray 34103
#define sipName_beginWriteArray &sipStrings_QtCore[34103]
#define sipNameNr_boundaryReasons 34119
#define sipName_boundaryReasons &sipStrings_QtCore[34119]
#define sipNameNr_canDropMimeData 34135
#define sipName_canDropMimeData &sipStrings_QtCore[34135]
#define sipNameNr_caseSensitivity 34151
#define sipName_caseSensitivity &sipStrings_QtCore[34151]
#define sipNameNr_characterOffset 34167
#define sipName_characterOffset &sipStrings_QtCore[34167]
#define sipNameNr_checkPermission 34183
#define sipName_checkPermission &sipStrings_QtCore[34183]
#define sipNameNr_classInfoOffset 34199
#define sipName_classInfoOffset &sipStrings_QtCore[34199]
#define sipNameNr_codeToTerritory 34215
#define sipName_codeToTerritory &sipStrings_QtCore[34215]
#define sipNameNr_columnsInserted 34231
#define sipName_columnsInserted &sipStrings_QtCore[34231]
#define sipNameNr_countryToString 34247
#define sipName_countryToString &sipStrings_QtCore[34247]
#define sipNameNr_currentDateTime 34263
#define sipName_currentDateTime &sipStrings_QtCore[34263]
#define sipNameNr_currentLoopTime 34279
#define sipName_currentLoopTime &sipStrings_QtCore[34279]
#define sipNameNr_currentThreadId 34295
#define sipName_currentThreadId &sipStrings_QtCore[34295]
#define sipNameNr_defaultCategory 34311
#define sipName_defaultCategory &sipStrings_QtCore[34311]
#define sipNameNr_documentVersion 34327
#define sipName_documentVersion &sipStrings_QtCore[34327]
#define sipNameNr_endFilterChange 34343
#define sipName_endFilterChange &sipStrings_QtCore[34343]
#define sipNameNr_enumeratorCount 34359
#define sipName_enumeratorCount &sipStrings_QtCore[34359]
#define sipNameNr_eventDispatcher 34375
#define sipName_eventDispatcher &sipStrings_QtCore[34375]
#define sipNameNr_filterKeyColumn 34391
#define sipName_filterKeyColumn &sipStrings_QtCore[34391]
#define sipNameNr_genericIconName 34407
#define sipName_genericIconName &sipStrings_QtCore[34407]
#define sipNameNr_globalMatchView 34423
#define sipName_globalMatchView &sipStrings_QtCore[34423]
#define sipNameNr_hasDaylightTime 34439
#define sipName_hasDaylightTime &sipStrings_QtCore[34439]
#define sipNameNr_hasMajorVersion 34455
#define sipName_hasMajorVersion &sipStrings_QtCore[34455]
#define sipNameNr_hasMinorVersion 34471
#define sipName_hasMinorVersion &sipStrings_QtCore[34471]
#define sipNameNr_hasNotifySignal 34487
#define sipName_hasNotifySignal &sipStrings_QtCore[34487]
#define sipNameNr_hasPartialMatch 34503
#define sipName_hasPartialMatch &sipStrings_QtCore[34503]
#define sipNameNr_indexOfProperty 34519
#define sipName_indexOfProperty &sipStrings_QtCore[34519]
#define sipNameNr_insertAnimation 34535
#define sipName_insertAnimation &sipStrings_QtCore[34535]
#define sipNameNr_internalPointer 34551
#define sipName_internalPointer &sipStrings_QtCore[34551]
#define sipNameNr_isCurrentThread 34567
#define sipName_isCurrentThread &sipStrings_QtCore[34567]
#define sipNameNr_isQuickItemType 34583
#define sipName_isQuickItemType &sipStrings_QtCore[34583]
#define sipNameNr_isSetuidAllowed 34599
#define sipName_isSetuidAllowed &sipStrings_QtCore[34599]
#define sipNameNr_isStartDocument 34615
#define sipName_isStartDocument &sipStrings_QtCore[34615]
#define sipNameNr_legacyNativeKey 34631
#define sipName_legacyNativeKey &sipStrings_QtCore[34631]
#define sipNameNr_lowercasedigits 34647
#define sipName_lowercasedigits &sipStrings_QtCore[34647]
#define sipNameNr_machineHostName 34663
#define sipName_machineHostName &sipStrings_QtCore[34663]
#define sipNameNr_machineUniqueId 34679
#define sipName_machineUniqueId &sipStrings_QtCore[34679]
#define sipNameNr_manhattanLength 34695
#define sipName_manhattanLength &sipStrings_QtCore[34695]
#define sipNameNr_matchingLocales 34711
#define sipName_matchingLocales &sipStrings_QtCore[34711]
#define sipNameNr_methodSignature 34727
#define sipName_methodSignature &sipStrings_QtCore[34727]
#define sipNameNr_mimeTypeForData 34743
#define sipName_mimeTypeForData &sipStrings_QtCore[34743]
#define sipNameNr_mimeTypeForFile 34759
#define sipName_mimeTypeForFile &sipStrings_QtCore[34759]
#define sipNameNr_mimeTypeForName 34775
#define sipName_mimeTypeForName &sipStrings_QtCore[34775]
#define sipNameNr_moveBottomRight 34791
#define sipName_moveBottomRight &sipStrings_QtCore[34791]
#define sipNameNr_nameForEncoding 34807
#define sipName_nameForEncoding &sipStrings_QtCore[34807]
#define sipNameNr_parentMimeTypes 34823
#define sipName_parentMimeTypes &sipStrings_QtCore[34823]
#define sipNameNr_platformSafeKey 34839
#define sipName_platformSafeKey &sipStrings_QtCore[34839]
#define sipNameNr_preferredSuffix 34855
#define sipName_preferredSuffix &sipStrings_QtCore[34855]
#define sipNameNr_qAddPostRoutine 34871
#define sipName_qAddPostRoutine &sipStrings_QtCore[34871]
#define sipNameNr_readElementText 34887
#define sipName_readElementText &sipStrings_QtCore[34887]
#define sipNameNr_readQStringList 34903
#define sipName_readQStringList &sipStrings_QtCore[34903]
#define sipNameNr_readQVariantMap 34919
#define sipName_readQVariantMap &sipStrings_QtCore[34919]
#define sipNameNr_removeAnimation 34935
#define sipName_removeAnimation &sipStrings_QtCore[34935]
#define sipNameNr_removeQueryItem 34951
#define sipName_removeQueryItem &sipStrings_QtCore[34951]
#define sipNameNr_renameOverwrite 34967
#define sipName_renameOverwrite &sipStrings_QtCore[34967]
#define sipNameNr_selectedColumns 34983
#define sipName_selectedColumns &sipStrings_QtCore[34983]
#define sipNameNr_selectedIndexes 34999
#define sipName_selectedIndexes &sipStrings_QtCore[34999]
#define sipNameNr_setAvailability 35015
#define sipName_setAvailability &sipStrings_QtCore[35015]
#define sipNameNr_setCurrentIndex 35031
#define sipName_setCurrentIndex &sipStrings_QtCore[35031]
#define sipNameNr_setDefaultValue 35047
#define sipName_setDefaultValue &sipStrings_QtCore[35047]
#define sipNameNr_setFileTemplate 35063
#define sipName_setFileTemplate &sipStrings_QtCore[35063]
#define sipNameNr_setIdnWhitelist 35079
#define sipName_setIdnWhitelist &sipStrings_QtCore[35079]
#define sipNameNr_setLibraryPaths 35095
#define sipName_setLibraryPaths &sipStrings_QtCore[35095]
#define sipNameNr_setProcessState 35111
#define sipName_setProcessState &sipStrings_QtCore[35111]
#define sipNameNr_setPropertyName 35127
#define sipName_setPropertyName &sipStrings_QtCore[35127]
#define sipNameNr_setServiceLevel 35143
#define sipName_setServiceLevel &sipStrings_QtCore[35143]
#define sipNameNr_setTargetObject 35159
#define sipName_setTargetObject &sipStrings_QtCore[35159]
#define sipNameNr_siblingAtColumn 35175
#define sipName_siblingAtColumn &sipStrings_QtCore[35175]
#define sipNameNr_sortRoleChanged 35191
#define sipName_sortRoleChanged &sipStrings_QtCore[35191]
#define sipNameNr_staticInstances 35207
#define sipName_staticInstances &sipStrings_QtCore[35207]
#define sipNameNr_territoryToCode 35223
#define sipName_territoryToCode &sipStrings_QtCore[35223]
#define sipNameNr_toDisplayString 35239
#define sipName_toDisplayString &sipStrings_QtCore[35239]
#define sipNameNr_toOffsetFromUtc 35255
#define sipName_toOffsetFromUtc &sipStrings_QtCore[35255]
#define sipNameNr_toggleDirection 35271
#define sipName_toggleDirection &sipStrings_QtCore[35271]
#define sipNameNr_tryLockForWrite 35287
#define sipName_tryLockForWrite &sipStrings_QtCore[35287]
#define sipNameNr_unregisterTimer 35303
#define sipName_unregisterTimer &sipStrings_QtCore[35303]
#define sipNameNr_updateDirection 35319
#define sipName_updateDirection &sipStrings_QtCore[35319]
#define sipNameNr_uppercasedigits 35335
#define sipName_uppercasedigits &sipStrings_QtCore[35335]
#define sipNameNr_waitForFinished 35351
#define sipName_waitForFinished &sipStrings_QtCore[35351]
#define sipNameNr_writeAttributes 35367
#define sipName_writeAttributes &sipStrings_QtCore[35367]
#define sipNameNr_writeCharacters 35383
#define sipName_writeCharacters &sipStrings_QtCore[35383]
#define sipNameNr_writeEndElement 35399
#define sipName_writeEndElement &sipStrings_QtCore[35399]
#define sipNameNr_AA_UseOpenGLES 35415
#define sipName_AA_UseOpenGLES &sipStrings_QtCore[35415]
#define sipNameNr_AddToSelection 35430
#define sipName_AddToSelection &sipStrings_QtCore[35430]
#define sipNameNr_AdvancePastEnd 35445
#define sipName_AdvancePastEnd &sipStrings_QtCore[35445]
#define sipNameNr_ArmenianScript 35460
#define sipName_ArmenianScript &sipStrings_QtCore[35460]
#define sipNameNr_AscendingOrder 35475
#define sipName_AscendingOrder &sipStrings_QtCore[35475]
#define sipNameNr_AutoConnection 35490
#define sipName_AutoConnection &sipStrings_QtCore[35490]
#define sipNameNr_BackgroundRole 35505
#define sipName_BackgroundRole &sipStrings_QtCore[35505]
#define sipNameNr_BalineseScript 35520
#define sipName_BalineseScript &sipStrings_QtCore[35520]
#define sipNameNr_Base64Encoding 23108
#define sipName_Base64Encoding &sipStrings_QtCore[23108]
#define sipNameNr_BassaVahScript 35535
#define sipName_BassaVahScript &sipStrings_QtCore[35535]
#define sipNameNr_BopomofoScript 13796
#define sipName_BopomofoScript &sipStrings_QtCore[13796]
#define sipNameNr_BoundaryReason 1644
#define sipName_BoundaryReason &sipStrings_QtCore[1644]
#define sipNameNr_BugineseScript 35550
#define sipName_BugineseScript &sipStrings_QtCore[35550]
#define sipNameNr_CentralKurdish 35565
#define sipName_CentralKurdish &sipStrings_QtCore[35565]
#define sipNameNr_CheckStateRole 35580
#define sipName_CheckStateRole &sipStrings_QtCore[35580]
#define sipNameNr_ChecksumItuV41 35595
#define sipName_ChecksumItuV41 &sipStrings_QtCore[35595]
#define sipNameNr_CherokeeScript 35610
#define sipName_CherokeeScript &sipStrings_QtCore[35610]
#define sipNameNr_ClearAndSelect 35625
#define sipName_ClearAndSelect &sipStrings_QtCore[35625]
#define sipNameNr_ConfigLocation 13752
#define sipName_ConfigLocation &sipStrings_QtCore[13752]
#define sipNameNr_ConnectionType 22215
#define sipName_ConnectionType &sipStrings_QtCore[22215]
#define sipNameNr_CurrencySymbol 35640
#define sipName_CurrencySymbol &sipStrings_QtCore[35640]
#define sipNameNr_CurrentVersion 35655
#define sipName_CurrentVersion &sipStrings_QtCore[35655]
#define sipNameNr_CustomDashLine 35670
#define sipName_CustomDashLine &sipStrings_QtCore[35670]
#define sipNameNr_CyrillicScript 35685
#define sipName_CyrillicScript &sipStrings_QtCore[35685]
#define sipNameNr_DashDotDotLine 35700
#define sipName_DashDotDotLine &sipStrings_QtCore[35700]
#define sipNameNr_DataSizeFormat 10782
#define sipName_DataSizeFormat &sipStrings_QtCore[10782]
#define sipNameNr_DateTimeString 35715
#define sipName_DateTimeString &sipStrings_QtCore[35715]
#define sipNameNr_DecodeReserved 35730
#define sipName_DecodeReserved &sipStrings_QtCore[35730]
#define sipNameNr_DecorationRole 35745
#define sipName_DecorationRole &sipStrings_QtCore[35745]
#define sipNameNr_DeferredDelete 35760
#define sipName_DeferredDelete &sipStrings_QtCore[35760]
#define sipNameNr_DeletionPolicy 1785
#define sipName_DeletionPolicy &sipStrings_QtCore[1785]
#define sipNameNr_DoNotUseParent 35775
#define sipName_DoNotUseParent &sipStrings_QtCore[35775]
#define sipNameNr_DockWidgetArea 16113
#define sipName_DockWidgetArea &sipStrings_QtCore[16113]
#define sipNameNr_DragCopyCursor 35790
#define sipName_DragCopyCursor &sipStrings_QtCore[35790]
#define sipNameNr_DragLinkCursor 35805
#define sipName_DragLinkCursor &sipStrings_QtCore[35805]
#define sipNameNr_DragMoveCursor 35820
#define sipName_DragMoveCursor &sipStrings_QtCore[35820]
#define sipNameNr_DuployanScript 35835
#define sipName_DuployanScript &sipStrings_QtCore[35835]
#define sipNameNr_EncodeReserved 35850
#define sipName_EncodeReserved &sipStrings_QtCore[35850]
#define sipNameNr_EnterEditFocus 35865
#define sipName_EnterEditFocus &sipStrings_QtCore[35865]
#define sipNameNr_EnterKeyReturn 35880
#define sipName_EnterKeyReturn &sipStrings_QtCore[35880]
#define sipNameNr_EnterKeySearch 35895
#define sipName_EnterKeySearch &sipStrings_QtCore[35895]
#define sipNameNr_EthiopicScript 35910
#define sipName_EthiopicScript &sipStrings_QtCore[35910]
#define sipNameNr_ExpectedBase16 35925
#define sipName_ExpectedBase16 &sipStrings_QtCore[35925]
#define sipNameNr_ExpectedBase64 35940
#define sipName_ExpectedBase64 &sipStrings_QtCore[35940]
#define sipNameNr_FieldAlignment 5819
#define sipName_FieldAlignment &sipStrings_QtCore[5819]
#define sipNameNr_FileAccessTime 35955
#define sipName_FileAccessTime &sipStrings_QtCore[35955]
#define sipNameNr_FileHandleFlag 5595
#define sipName_FileHandleFlag &sipStrings_QtCore[5595]
#define sipNameNr_FollowSymlinks 35970
#define sipName_FollowSymlinks &sipStrings_QtCore[35970]
#define sipNameNr_ForegroundRole 35985
#define sipName_ForegroundRole &sipStrings_QtCore[35985]
#define sipNameNr_GeorgianScript 36000
#define sipName_GeorgianScript &sipStrings_QtCore[36000]
#define sipNameNr_GestureStarted 36015
#define sipName_GestureStarted &sipStrings_QtCore[36015]
#define sipNameNr_GestureUpdated 36030
#define sipName_GestureUpdated &sipStrings_QtCore[36030]
#define sipNameNr_GujaratiScript 36045
#define sipName_GujaratiScript &sipStrings_QtCore[36045]
#define sipNameNr_GurmukhiScript 36060
#define sipName_GurmukhiScript &sipStrings_QtCore[36060]
#define sipNameNr_HiddenFromHelp 36075
#define sipName_HiddenFromHelp &sipStrings_QtCore[36075]
#define sipNameNr_HiraganaScript 36090
#define sipName_HiraganaScript &sipStrings_QtCore[36090]
#define sipNameNr_IconTextChange 36105
#define sipName_IconTextChange &sipStrings_QtCore[36105]
#define sipNameNr_IllegalPadding 36120
#define sipName_IllegalPadding &sipStrings_QtCore[36120]
#define sipNameNr_ImEnterKeyType 36135
#define sipName_ImEnterKeyType &sipStrings_QtCore[36135]
#define sipNameNr_ImPlatformData 36150
#define sipName_ImPlatformData &sipStrings_QtCore[36150]
#define sipNameNr_ImhPreferLatin 36165
#define sipName_ImhPreferLatin &sipStrings_QtCore[36165]
#define sipNameNr_ImperialSystem 36180
#define sipName_ImperialSystem &sipStrings_QtCore[36180]
#define sipNameNr_Initialization 1608
#define sipName_Initialization &sipStrings_QtCore[1608]
#define sipNameNr_ItemIsEditable 36195
#define sipName_ItemIsEditable &sipStrings_QtCore[36195]
#define sipNameNr_JapaneseScript 36210
#define sipName_JapaneseScript &sipStrings_QtCore[36210]
#define sipNameNr_JavaneseScript 36225
#define sipName_JavaneseScript &sipStrings_QtCore[36225]
#define sipNameNr_KatakanaScript 36240
#define sipName_KatakanaScript &sipStrings_QtCore[36240]
#define sipNameNr_Key_Adiaeresis 36255
#define sipName_Key_Adiaeresis &sipStrings_QtCore[36255]
#define sipNameNr_Key_Apostrophe 36270
#define sipName_Key_Apostrophe &sipStrings_QtCore[36270]
#define sipNameNr_Key_AsciiTilde 36285
#define sipName_Key_AsciiTilde &sipStrings_QtCore[36285]
#define sipNameNr_Key_BraceRight 36300
#define sipName_Key_BraceRight &sipStrings_QtCore[36300]
#define sipNameNr_Key_Calculator 36315
#define sipName_Key_Calculator &sipStrings_QtCore[36315]
#define sipNameNr_Key_Dead_Acute 36330
#define sipName_Key_Dead_Acute &sipStrings_QtCore[36330]
#define sipNameNr_Key_Dead_Breve 36345
#define sipName_Key_Dead_Breve &sipStrings_QtCore[36345]
#define sipNameNr_Key_Dead_Caron 36360
#define sipName_Key_Dead_Caron &sipStrings_QtCore[36360]
#define sipNameNr_Key_Dead_Grave 36375
#define sipName_Key_Dead_Grave &sipStrings_QtCore[36375]
#define sipNameNr_Key_Dead_Greek 36390
#define sipName_Key_Dead_Greek &sipStrings_QtCore[36390]
#define sipNameNr_Key_Dead_Tilde 36405
#define sipName_Key_Dead_Tilde &sipStrings_QtCore[36405]
#define sipNameNr_Key_Ediaeresis 36420
#define sipName_Key_Ediaeresis &sipStrings_QtCore[36420]
#define sipNameNr_Key_Eisu_Shift 36435
#define sipName_Key_Eisu_Shift &sipStrings_QtCore[36435]
#define sipNameNr_Key_Hangul_End 36450
#define sipName_Key_Hangul_End &sipStrings_QtCore[36450]
#define sipNameNr_Key_Idiaeresis 36465
#define sipName_Key_Idiaeresis &sipStrings_QtCore[36465]
#define sipNameNr_Key_Kana_Shift 36480
#define sipName_Key_Kana_Shift &sipStrings_QtCore[36480]
#define sipNameNr_Key_LaunchMail 36495
#define sipName_Key_LaunchMail &sipStrings_QtCore[36495]
#define sipNameNr_Key_MediaPause 36510
#define sipName_Key_MediaPause &sipStrings_QtCore[36510]
#define sipNameNr_Key_NumberSign 36525
#define sipName_Key_NumberSign &sipStrings_QtCore[36525]
#define sipNameNr_Key_Odiaeresis 36540
#define sipName_Key_Odiaeresis &sipStrings_QtCore[36540]
#define sipNameNr_Key_OfficeHome 36555
#define sipName_Key_OfficeHome &sipStrings_QtCore[36555]
#define sipNameNr_Key_ParenRight 36570
#define sipName_Key_ParenRight &sipStrings_QtCore[36570]
#define sipNameNr_Key_RotationKB 36585
#define sipName_Key_RotationKB &sipStrings_QtCore[36585]
#define sipNameNr_Key_RotationPB 36600
#define sipName_Key_RotationPB &sipStrings_QtCore[36600]
#define sipNameNr_Key_ScrollLock 36615
#define sipName_Key_ScrollLock &sipStrings_QtCore[36615]
#define sipNameNr_Key_TouchpadOn 36630
#define sipName_Key_TouchpadOn &sipStrings_QtCore[36630]
#define sipNameNr_Key_TrebleDown 36645
#define sipName_Key_TrebleDown &sipStrings_QtCore[36645]
#define sipNameNr_Key_Udiaeresis 36660
#define sipName_Key_Udiaeresis &sipStrings_QtCore[36660]
#define sipNameNr_Key_Underscore 36675
#define sipName_Key_Underscore &sipStrings_QtCore[36675]
#define sipNameNr_Key_VolumeDown 36690
#define sipName_Key_VolumeDown &sipStrings_QtCore[36690]
#define sipNameNr_Key_VolumeMute 36705
#define sipName_Key_VolumeMute &sipStrings_QtCore[36705]
#define sipNameNr_Key_exclamdown 36720
#define sipName_Key_exclamdown &sipStrings_QtCore[36720]
#define sipNameNr_Key_onequarter 36735
#define sipName_Key_onequarter &sipStrings_QtCore[36735]
#define sipNameNr_Key_registered 36750
#define sipName_Key_registered &sipStrings_QtCore[36750]
#define sipNameNr_Key_ydiaeresis 36765
#define sipName_Key_ydiaeresis &sipStrings_QtCore[36765]
#define sipNameNr_KeypadModifier 36780
#define sipName_KeypadModifier &sipStrings_QtCore[36780]
#define sipNameNr_KoyraboroSenni 36795
#define sipName_KoyraboroSenni &sipStrings_QtCore[36795]
#define sipNameNr_LanguageChange 36810
#define sipName_LanguageChange &sipStrings_QtCore[36810]
#define sipNameNr_LeaveEditFocus 36825
#define sipName_LeaveEditFocus &sipStrings_QtCore[36825]
#define sipNameNr_LegacyBehavior 36840
#define sipName_LegacyBehavior &sipStrings_QtCore[36840]
#define sipNameNr_LowestPriority 36855
#define sipName_LowestPriority &sipStrings_QtCore[36855]
#define sipNameNr_MSWindowsOwnDC 36870
#define sipName_MSWindowsOwnDC &sipStrings_QtCore[36870]
#define sipNameNr_MahajaniScript 36885
#define sipName_MahajaniScript &sipStrings_QtCore[36885]
#define sipNameNr_MandaeanScript 36900
#define sipName_MandaeanScript &sipStrings_QtCore[36900]
#define sipNameNr_MandatoryBreak 36915
#define sipName_MandatoryBreak &sipStrings_QtCore[36915]
#define sipNameNr_MatchExtension 36930
#define sipName_MatchExtension &sipStrings_QtCore[36930]
#define sipNameNr_MatchRecursive 36945
#define sipName_MatchRecursive &sipStrings_QtCore[36945]
#define sipNameNr_MergedChannels 36960
#define sipName_MergedChannels &sipStrings_QtCore[36960]
#define sipNameNr_MeroiticScript 36975
#define sipName_MeroiticScript &sipStrings_QtCore[36975]
#define sipNameNr_MinimumDescent 36990
#define sipName_MinimumDescent &sipStrings_QtCore[36990]
#define sipNameNr_ModifiedChange 37005
#define sipName_ModifiedChange &sipStrings_QtCore[37005]
#define sipNameNr_MonotonicClock 37020
#define sipName_MonotonicClock &sipStrings_QtCore[37020]
#define sipNameNr_MouseEventFlag 22253
#define sipName_MouseEventFlag &sipStrings_QtCore[22253]
#define sipNameNr_MoviesLocation 37035
#define sipName_MoviesLocation &sipStrings_QtCore[37035]
#define sipNameNr_NauruTerritory 37050
#define sipName_NauruTerritory &sipStrings_QtCore[37050]
#define sipNameNr_NavigationMode 22272
#define sipName_NavigationMode &sipStrings_QtCore[22272]
#define sipNameNr_NegativeBignum 37065
#define sipName_NegativeBignum &sipStrings_QtCore[37065]
#define sipNameNr_NestingTooDeep 37080
#define sipName_NestingTooDeep &sipStrings_QtCore[37080]
#define sipNameNr_NigerianPidgin 37095
#define sipName_NigerianPidgin &sipStrings_QtCore[37095]
#define sipNameNr_NoDotAndDotDot 37110
#define sipName_NoDotAndDotDot &sipStrings_QtCore[37110]
#define sipNameNr_NoIntersection 37125
#define sipName_NoIntersection &sipStrings_QtCore[37125]
#define sipNameNr_NormalPriority 37140
#define sipName_NormalPriority &sipStrings_QtCore[37140]
#define sipNameNr_NotEnoughSpace 37155
#define sipName_NotEnoughSpace &sipStrings_QtCore[37155]
#define sipNameNr_OpenHandCursor 37170
#define sipName_OpenHandCursor &sipStrings_QtCore[37170]
#define sipNameNr_OutOfResources 37185
#define sipName_OutOfResources &sipStrings_QtCore[37185]
#define sipNameNr_PapuaNewGuinea 37200
#define sipName_PapuaNewGuinea &sipStrings_QtCore[37200]
#define sipNameNr_ParseAsOptions 37215
#define sipName_ParseAsOptions &sipStrings_QtCore[37215]
#define sipNameNr_PermissionMask 37230
#define sipName_PermissionMask &sipStrings_QtCore[37230]
#define sipNameNr_PositiveBignum 37245
#define sipName_PositiveBignum &sipStrings_QtCore[37245]
#define sipNameNr_PreferStandard 37260
#define sipName_PreferStandard &sipStrings_QtCore[37260]
#define sipNameNr_ProcessChannel 9435
#define sipName_ProcessChannel &sipStrings_QtCore[9435]
#define sipNameNr_QAnyStringView 37275
#define sipName_QAnyStringView &sipStrings_QtCore[37275]
#define sipNameNr_QByteArrayList 37290
#define sipName_QByteArrayList &sipStrings_QtCore[37290]
#define sipNameNr_QByteArrayView 37305
#define sipName_QByteArrayView &sipStrings_QtCore[37305]
#define sipNameNr_QCborKnownTags 37320
#define sipName_QCborKnownTags &sipStrings_QtCore[37320]
#define sipNameNr_QDeadlineTimer 37335
#define sipName_QDeadlineTimer &sipStrings_QtCore[37335]
#define sipNameNr_QDir__SortFlag 37350
#define sipName_QDir__SortFlag &sipStrings_QtCore[37350]
#define sipNameNr_QItemSelection 37365
#define sipName_QItemSelection &sipStrings_QtCore[37365]
#define sipNameNr_37380 37380
#define sipName_37380 &sipStrings_QtCore[37380]
#define sipNameNr_37395 37395
#define sipName_37395 &sipStrings_QtCore[37395]
#define sipNameNr_QMessageLogger 37410
#define sipName_QMessageLogger &sipStrings_QtCore[37410]
#define sipNameNr_QMetaClassInfo 37425
#define sipName_QMetaClassInfo &sipStrings_QtCore[37425]
#define sipNameNr_QModelRoleData 37440
#define sipName_QModelRoleData &sipStrings_QtCore[37440]
#define sipNameNr_QReadWriteLock 37455
#define sipName_QReadWriteLock &sipStrings_QtCore[37455]
#define sipNameNr_QSignalBlocker 37470
#define sipName_QSignalBlocker &sipStrings_QtCore[37470]
#define sipNameNr_QStandardPaths 37485
#define sipName_QStandardPaths &sipStrings_QtCore[37485]
#define sipNameNr_QStringDecoder 37500
#define sipName_QStringDecoder &sipStrings_QtCore[37500]
#define sipNameNr_QStringEncoder 37515
#define sipName_QStringEncoder &sipStrings_QtCore[37515]
#define sipNameNr_QT_VERSION_STR 28590
#define sipName_QT_VERSION_STR &sipStrings_QtCore[28590]
#define sipNameNr_QTemporaryFile 37530
#define sipName_QTemporaryFile &sipStrings_QtCore[37530]
#define sipNameNr_QUuid__Variant 37545
#define sipName_QUuid__Variant &sipStrings_QtCore[37545]
#define sipNameNr_QUuid__Version 37560
#define sipName_QUuid__Version &sipStrings_QtCore[37560]
#define sipNameNr_QVersionNumber 37575
#define sipName_QVersionNumber &sipStrings_QtCore[37575]
#define sipNameNr_QWaitCondition 37590
#define sipName_QWaitCondition &sipStrings_QtCore[37590]
#define sipNameNr_QmlImportsPath 37605
#define sipName_QmlImportsPath &sipStrings_QtCore[37605]
#define sipNameNr_Qt__BrushStyle 37620
#define sipName_Qt__BrushStyle &sipStrings_QtCore[37620]
#define sipNameNr_Qt__CheckState 37635
#define sipName_Qt__CheckState &sipStrings_QtCore[37635]
#define sipNameNr_Qt__DateFormat 37650
#define sipName_Qt__DateFormat &sipStrings_QtCore[37650]
#define sipNameNr_Qt__DropAction 37665
#define sipName_Qt__DropAction &sipStrings_QtCore[37665]
#define sipNameNr_Qt__TextFormat 37680
#define sipName_Qt__TextFormat &sipStrings_QtCore[37680]
#define sipNameNr_Qt__WindowType 37695
#define sipName_Qt__WindowType &sipStrings_QtCore[37695]
#define sipNameNr_QueryWhatsThis 37710
#define sipName_QueryWhatsThis &sipStrings_QtCore[37710]
#define sipNameNr_QuotationStyle 10806
#define sipName_QuotationStyle &sipStrings_QtCore[10806]
#define sipNameNr_ReadOnlyChange 37725
#define sipName_ReadOnlyChange &sipStrings_QtCore[37725]
#define sipNameNr_RemoveFilename 37740
#define sipName_RemoveFilename &sipStrings_QtCore[37740]
#define sipNameNr_RemoveFragment 37755
#define sipName_RemoveFragment &sipStrings_QtCore[37755]
#define sipNameNr_RemovePassword 37770
#define sipName_RemovePassword &sipStrings_QtCore[37770]
#define sipNameNr_RemoveUserInfo 37785
#define sipName_RemoveUserInfo &sipStrings_QtCore[37785]
#define sipNameNr_Script_Avestan 37800
#define sipName_Script_Avestan &sipStrings_QtCore[37800]
#define sipNameNr_Script_Bengali 37815
#define sipName_Script_Bengali &sipStrings_QtCore[37815]
#define sipNameNr_Script_Braille 37830
#define sipName_Script_Braille &sipStrings_QtCore[37830]
#define sipNameNr_Script_Cypriot 37845
#define sipName_Script_Cypriot &sipStrings_QtCore[37845]
#define sipNameNr_Script_Deseret 37860
#define sipName_Script_Deseret &sipStrings_QtCore[37860]
#define sipNameNr_Script_Elbasan 37875
#define sipName_Script_Elbasan &sipStrings_QtCore[37875]
#define sipNameNr_Script_Elymaic 37890
#define sipName_Script_Elymaic &sipStrings_QtCore[37890]
#define sipNameNr_Script_Grantha 37905
#define sipName_Script_Grantha &sipStrings_QtCore[37905]
#define sipNameNr_Script_Hanunoo 37920
#define sipName_Script_Hanunoo &sipStrings_QtCore[37920]
#define sipNameNr_Script_Kannada 37935
#define sipName_Script_Kannada &sipStrings_QtCore[37935]
#define sipNameNr_Script_KayahLi 37950
#define sipName_Script_KayahLi &sipStrings_QtCore[37950]
#define sipNameNr_Script_LinearA 37965
#define sipName_Script_LinearA &sipStrings_QtCore[37965]
#define sipNameNr_Script_LinearB 37980
#define sipName_Script_LinearB &sipStrings_QtCore[37980]
#define sipNameNr_Script_Makasar 37995
#define sipName_Script_Makasar &sipStrings_QtCore[37995]
#define sipNameNr_Script_Mandaic 38010
#define sipName_Script_Mandaic &sipStrings_QtCore[38010]
#define sipNameNr_Script_Marchen 38025
#define sipName_Script_Marchen &sipStrings_QtCore[38025]
#define sipNameNr_Script_Multani 38040
#define sipName_Script_Multani &sipStrings_QtCore[38040]
#define sipNameNr_Script_Myanmar 38055
#define sipName_Script_Myanmar &sipStrings_QtCore[38055]
#define sipNameNr_Script_OlChiki 38070
#define sipName_Script_OlChiki &sipStrings_QtCore[38070]
#define sipNameNr_Script_Osmanya 38085
#define sipName_Script_Osmanya &sipStrings_QtCore[38085]
#define sipNameNr_Script_PhagsPa 38100
#define sipName_Script_PhagsPa &sipStrings_QtCore[38100]
#define sipNameNr_Script_Sharada 38115
#define sipName_Script_Sharada &sipStrings_QtCore[38115]
#define sipNameNr_Script_Shavian 38130
#define sipName_Script_Shavian &sipStrings_QtCore[38130]
#define sipNameNr_Script_Siddham 38145
#define sipName_Script_Siddham &sipStrings_QtCore[38145]
#define sipNameNr_Script_Sidetic 38160
#define sipName_Script_Sidetic &sipStrings_QtCore[38160]
#define sipNameNr_Script_Sinhala 38175
#define sipName_Script_Sinhala &sipStrings_QtCore[38175]
#define sipNameNr_Script_Sogdian 38190
#define sipName_Script_Sogdian &sipStrings_QtCore[38190]
#define sipNameNr_Script_Soyombo 38205
#define sipName_Script_Soyombo &sipStrings_QtCore[38205]
#define sipNameNr_Script_Sunuwar 38220
#define sipName_Script_Sunuwar &sipStrings_QtCore[38220]
#define sipNameNr_Script_Tagalog 38235
#define sipName_Script_Tagalog &sipStrings_QtCore[38235]
#define sipNameNr_Script_TaiTham 38250
#define sipName_Script_TaiTham &sipStrings_QtCore[38250]
#define sipNameNr_Script_TaiViet 38265
#define sipName_Script_TaiViet &sipStrings_QtCore[38265]
#define sipNameNr_Script_Tibetan 38280
#define sipName_Script_Tibetan &sipStrings_QtCore[38280]
#define sipNameNr_Script_Tirhuta 38295
#define sipName_Script_Tirhuta &sipStrings_QtCore[38295]
#define sipNameNr_Script_Unknown 38310
#define sipName_Script_Unknown &sipStrings_QtCore[38310]
#define sipNameNr_ScrollMomentum 38325
#define sipName_ScrollMomentum &sipStrings_QtCore[38325]
#define sipNameNr_SolomonIslands 38340
#define sipName_SolomonIslands &sipStrings_QtCore[38340]
#define sipNameNr_StandardOutput 11526
#define sipName_StandardOutput &sipStrings_QtCore[11526]
#define sipNameNr_Subdirectories 38355
#define sipName_Subdirectories &sipStrings_QtCore[38355]
#define sipNameNr_TabFocusReason 38370
#define sipName_TabFocusReason &sipStrings_QtCore[38370]
#define sipNameNr_TagbanwaScript 38385
#define sipName_TagbanwaScript &sipStrings_QtCore[38385]
#define sipNameNr_TextExpandTabs 38400
#define sipName_TextExpandTabs &sipStrings_QtCore[38400]
#define sipNameNr_TextSingleLine 38415
#define sipName_TextSingleLine &sipStrings_QtCore[38415]
#define sipNameNr_TexturePattern 38430
#define sipName_TexturePattern &sipStrings_QtCore[38430]
#define sipNameNr_TifinaghScript 38445
#define sipName_TifinaghScript &sipStrings_QtCore[38445]
#define sipNameNr_TokelauCountry 38460
#define sipName_TokelauCountry &sipStrings_QtCore[38460]
#define sipNameNr_TopLeftSection 38475
#define sipName_TopLeftSection &sipStrings_QtCore[38475]
#define sipNameNr_TopRightCorner 38490
#define sipName_TopRightCorner &sipStrings_QtCore[38490]
#define sipNameNr_TopToolBarArea 38505
#define sipName_TopToolBarArea &sipStrings_QtCore[38505]
#define sipNameNr_TristanDaCunha 38520
#define sipName_TristanDaCunha &sipStrings_QtCore[38520]
#define sipNameNr_TuvaluLanguage 38535
#define sipName_TuvaluLanguage &sipStrings_QtCore[38535]
#define sipNameNr_UI_AnimateMenu 38550
#define sipName_UI_AnimateMenu &sipStrings_QtCore[38550]
#define sipNameNr_UI_FadeTooltip 38565
#define sipName_UI_FadeTooltip &sipStrings_QtCore[38565]
#define sipNameNr_UgariticScript 38580
#define sipName_UgariticScript &sipStrings_QtCore[38580]
#define sipNameNr_UngrabKeyboard 38595
#define sipName_UngrabKeyboard &sipStrings_QtCore[38595]
#define sipNameNr_WA_AcceptDrops 38610
#define sipName_WA_AcceptDrops &sipStrings_QtCore[38610]
#define sipNameNr_WA_InvalidSize 38625
#define sipName_WA_InvalidSize &sipStrings_QtCore[38625]
#define sipNameNr_WA_MacMiniSize 38640
#define sipName_WA_MacMiniSize &sipStrings_QtCore[38640]
#define sipNameNr_WA_MouseNoMask 38655
#define sipName_WA_MouseNoMask &sipStrings_QtCore[38655]
#define sipNameNr_WA_QuitOnClose 38670
#define sipName_WA_QuitOnClose &sipStrings_QtCore[38670]
#define sipNameNr_WA_RightToLeft 38685
#define sipName_WA_RightToLeft &sipStrings_QtCore[38685]
#define sipNameNr_WesternBalochi 38700
#define sipName_WesternBalochi &sipStrings_QtCore[38700]
#define sipNameNr_WesternFrisian 38715
#define sipName_WesternFrisian &sipStrings_QtCore[38715]
#define sipNameNr_WhiteSpaceMode 22291
#define sipName_WhiteSpaceMode &sipStrings_QtCore[22291]
#define sipNameNr_WidgetShortcut 38730
#define sipName_WidgetShortcut &sipStrings_QtCore[38730]
#define sipNameNr_WindowActivate 38745
#define sipName_WindowActivate &sipStrings_QtCore[38745]
#define sipNameNr_WindowModality 22310
#define sipName_WindowModality &sipStrings_QtCore[22310]
#define sipNameNr_WindowShortcut 38760
#define sipName_WindowShortcut &sipStrings_QtCore[38760]
#define sipNameNr_Windows10_1809 38775
#define sipName_Windows10_1809 &sipStrings_QtCore[38775]
#define sipNameNr_Windows10_1903 38790
#define sipName_Windows10_1903 &sipStrings_QtCore[38790]
#define sipNameNr_Windows10_1909 38805
#define sipName_Windows10_1909 &sipStrings_QtCore[38805]
#define sipNameNr_Windows10_2004 38820
#define sipName_Windows10_2004 &sipStrings_QtCore[38820]
#define sipNameNr_Windows10_20H2 38835
#define sipName_Windows10_20H2 &sipStrings_QtCore[38835]
#define sipNameNr_Windows10_21H1 38850
#define sipName_Windows10_21H1 &sipStrings_QtCore[38850]
#define sipNameNr_Windows10_21H2 38865
#define sipName_Windows10_21H2 &sipStrings_QtCore[38865]
#define sipNameNr_Windows10_22H2 38880
#define sipName_Windows10_22H2 &sipStrings_QtCore[38880]
#define sipNameNr_Windows11_21H2 38895
#define sipName_Windows11_21H2 &sipStrings_QtCore[38895]
#define sipNameNr_Windows11_22H2 38910
#define sipName_Windows11_22H2 &sipStrings_QtCore[38910]
#define sipNameNr_addLibraryPath 38925
#define sipName_addLibraryPath &sipStrings_QtCore[38925]
#define sipNameNr_addSourceModel 38940
#define sipName_addSourceModel &sipStrings_QtCore[38940]
#define sipNameNr_animationCount 38955
#define sipName_animationCount &sipStrings_QtCore[38955]
#define sipNameNr_applicationPid 38970
#define sipName_applicationPid &sipStrings_QtCore[38970]
#define sipNameNr_autoFormatting 38985
#define sipName_autoFormatting &sipStrings_QtCore[38985]
#define sipNameNr_beginReadArray 39000
#define sipName_beginReadArray &sipStrings_QtCore[39000]
#define sipNameNr_bytesAvailable 39015
#define sipName_bytesAvailable &sipStrings_QtCore[39015]
#define sipNameNr_capturedLength 39030
#define sipName_capturedLength &sipStrings_QtCore[39030]
#define sipNameNr_classInfoCount 39045
#define sipName_classInfoCount &sipStrings_QtCore[39045]
#define sipNameNr_clearSelection 39060
#define sipName_clearSelection &sipStrings_QtCore[39060]
#define sipNameNr_codeToLanguage 39075
#define sipName_codeToLanguage &sipStrings_QtCore[39075]
#define sipNameNr_columnsRemoved 39090
#define sipName_columnsRemoved &sipStrings_QtCore[39090]
#define sipNameNr_completeSuffix 39105
#define sipName_completeSuffix &sipStrings_QtCore[39105]
#define sipNameNr_containerDepth 39120
#define sipName_containerDepth &sipStrings_QtCore[39120]
#define sipNameNr_currencySymbol 39135
#define sipName_currencySymbol &sipStrings_QtCore[39135]
#define sipNameNr_currentChanged 39150
#define sipName_currentChanged &sipStrings_QtCore[39150]
#define sipNameNr_dateTimeFormat 39165
#define sipName_dateTimeFormat &sipStrings_QtCore[39165]
#define sipNameNr_decoderForHtml 39180
#define sipName_decoderForHtml &sipStrings_QtCore[39180]
#define sipNameNr_decodingStatus 39195
#define sipName_decodingStatus &sipStrings_QtCore[39195]
#define sipNameNr_defaultCompare 39210
#define sipName_defaultCompare &sipStrings_QtCore[39210]
#define sipNameNr_defaultSortKey 39225
#define sipName_defaultSortKey &sipStrings_QtCore[39225]
#define sipNameNr_disambiguation 39240
#define sipName_disambiguation &sipStrings_QtCore[39240]
#define sipNameNr_dumpObjectInfo 39255
#define sipName_dumpObjectInfo &sipStrings_QtCore[39255]
#define sipNameNr_dumpObjectTree 39270
#define sipName_dumpObjectTree &sipStrings_QtCore[39270]
#define sipNameNr_endMoveColumns 39285
#define sipName_endMoveColumns &sipStrings_QtCore[39285]
#define sipNameNr_enterContainer 39300
#define sipName_enterContainer &sipStrings_QtCore[39300]
#define sipNameNr_entityResolver 39315
#define sipName_entityResolver &sipStrings_QtCore[39315]
#define sipNameNr_extraSelectors 39330
#define sipName_extraSelectors &sipStrings_QtCore[39330]
#define sipNameNr_fieldAlignment 39345
#define sipName_fieldAlignment &sipStrings_QtCore[39345]
#define sipNameNr_fileSystemType 39360
#define sipName_fileSystemType &sipStrings_QtCore[39360]
#define sipNameNr_findExecutable 39375
#define sipName_findExecutable &sipStrings_QtCore[39375]
#define sipNameNr_firstDayOfWeek 39390
#define sipName_firstDayOfWeek &sipStrings_QtCore[39390]
#define sipNameNr_fromStringList 39405
#define sipName_fromStringList &sipStrings_QtCore[39405]
#define sipNameNr_generateDouble 39420
#define sipName_generateDouble &sipStrings_QtCore[39420]
#define sipNameNr_globalInstance 39435
#define sipName_globalInstance &sipStrings_QtCore[39435]
#define sipNameNr_groupSeparator 39450
#define sipName_groupSeparator &sipStrings_QtCore[39450]
#define sipNameNr_hasTransitions 39465
#define sipName_hasTransitions &sipStrings_QtCore[39465]
#define sipNameNr_isAbsolutePath 39480
#define sipName_isAbsolutePath &sipStrings_QtCore[39480]
#define sipNameNr_isDaylightTime 39495
#define sipName_isDaylightTime &sipStrings_QtCore[39495]
#define sipNameNr_isDebugEnabled 39510
#define sipName_isDebugEnabled &sipStrings_QtCore[39510]
#define sipNameNr_isDestructible 39525
#define sipName_isDestructible &sipStrings_QtCore[39525]
#define sipNameNr_isPointerEvent 39540
#define sipName_isPointerEvent &sipStrings_QtCore[39540]
#define sipNameNr_isRelativePath 39555
#define sipName_isRelativePath &sipStrings_QtCore[39555]
#define sipNameNr_isStartElement 39570
#define sipName_isStartElement &sipStrings_QtCore[39570]
#define sipNameNr_isSymbolicLink 39585
#define sipName_isSymbolicLink &sipStrings_QtCore[39585]
#define sipNameNr_junctionTarget 39600
#define sipName_junctionTarget &sipStrings_QtCore[39600]
#define sipNameNr_languageToCode 39615
#define sipName_languageToCode &sipStrings_QtCore[39615]
#define sipNameNr_leaveContainer 39630
#define sipName_leaveContainer &sipStrings_QtCore[39630]
#define sipNameNr_marginsRemoved 39645
#define sipName_marginsRemoved &sipStrings_QtCore[39645]
#define sipNameNr_maxThreadCount 39660
#define sipName_maxThreadCount &sipStrings_QtCore[39660]
#define sipNameNr_mimeTypeForUrl 39675
#define sipName_mimeTypeForUrl &sipStrings_QtCore[39675]
#define sipNameNr_mountedVolumes 39690
#define sipName_mountedVolumes &sipStrings_QtCore[39690]
#define sipNameNr_moveBottomLeft 39705
#define sipName_moveBottomLeft &sipStrings_QtCore[39705]
#define sipNameNr_nextTransition 39720
#define sipName_nextTransition &sipStrings_QtCore[39720]
#define sipNameNr_normalizedType 39735
#define sipName_normalizedType &sipStrings_QtCore[39735]
#define sipNameNr_nullTerminated 39750
#define sipName_nullTerminated &sipStrings_QtCore[39750]
#define sipNameNr_parameterCount 39765
#define sipName_parameterCount &sipStrings_QtCore[39765]
#define sipNameNr_parameterNames 39780
#define sipName_parameterNames &sipStrings_QtCore[39780]
#define sipNameNr_parameterTypes 39795
#define sipName_parameterTypes &sipStrings_QtCore[39795]
#define sipNameNr_patternOptions 39810
#define sipName_patternOptions &sipStrings_QtCore[39810]
#define sipNameNr_percentDecoded 39825
#define sipName_percentDecoded &sipStrings_QtCore[39825]
#define sipNameNr_productVersion 39840
#define sipName_productVersion &sipStrings_QtCore[39840]
#define sipNameNr_propertyOffset 39855
#define sipName_propertyOffset &sipStrings_QtCore[39855]
#define sipNameNr_qAddPreRoutine 39870
#define sipName_qAddPreRoutine &sipStrings_QtCore[39870]
#define sipNameNr_qFloatDistance 39885
#define sipName_qFloatDistance &sipStrings_QtCore[39885]
#define sipNameNr_qSetFieldWidth 39900
#define sipName_qSetFieldWidth &sipStrings_QtCore[39900]
#define sipNameNr_queryItemValue 39915
#define sipName_queryItemValue &sipStrings_QtCore[39915]
#define sipNameNr_readUtf8String 39930
#define sipName_readUtf8String &sipStrings_QtCore[39930]
#define sipNameNr_removeMappings 39945
#define sipName_removeMappings &sipStrings_QtCore[39945]
#define sipNameNr_resetRoleNames 39960
#define sipName_resetRoleNames &sipStrings_QtCore[39960]
#define sipNameNr_returnMetaType 39975
#define sipName_returnMetaType &sipStrings_QtCore[39975]
#define sipNameNr_rightJustified 39990
#define sipName_rightJustified &sipStrings_QtCore[39990]
#define sipNameNr_scriptToString 40005
#define sipName_scriptToString &sipStrings_QtCore[40005]
#define sipNameNr_securelySeeded 40020
#define sipName_securelySeeded &sipStrings_QtCore[40020]
#define sipNameNr_setBottomRight 40035
#define sipName_setBottomRight &sipStrings_QtCore[40035]
#define sipNameNr_setCurrentTime 40050
#define sipName_setCurrentTime &sipStrings_QtCore[40050]
#define sipNameNr_setDescription 40065
#define sipName_setDescription &sipStrings_QtCore[40065]
#define sipNameNr_setEasingCurve 40080
#define sipName_setEasingCurve &sipStrings_QtCore[40080]
#define sipNameNr_setErrorString 40095
#define sipName_setErrorString &sipStrings_QtCore[40095]
#define sipNameNr_setFilterRules 40110
#define sipName_setFilterRules &sipStrings_QtCore[40110]
#define sipNameNr_setIntegerBase 40125
#define sipName_setIntegerBase &sipStrings_QtCore[40125]
#define sipNameNr_setNameFilters 40140
#define sipName_setNameFilters &sipStrings_QtCore[40140]
#define sipNameNr_setNumberFlags 40155
#define sipName_setNumberFlags &sipStrings_QtCore[40155]
#define sipNameNr_setNumericMode 40170
#define sipName_setNumericMode &sipStrings_QtCore[40170]
#define sipNameNr_setPermissions 40185
#define sipName_setPermissions &sipStrings_QtCore[40185]
#define sipNameNr_setReadChannel 40200
#define sipName_setReadChannel &sipStrings_QtCore[40200]
#define sipNameNr_setSearchPaths 40215
#define sipName_setSearchPaths &sipStrings_QtCore[40215]
#define sipNameNr_setSourceModel 40230
#define sipName_setSourceModel &sipStrings_QtCore[40230]
#define sipNameNr_signalsBlocked 40245
#define sipName_signalsBlocked &sipStrings_QtCore[40245]
#define sipNameNr_skipWhiteSpace 40260
#define sipName_skipWhiteSpace &sipStrings_QtCore[40260]
#define sipNameNr_systemTimeZone 40275
#define sipName_systemTimeZone &sipStrings_QtCore[40275]
#define sipNameNr_threadPriority 40290
#define sipName_threadPriority &sipStrings_QtCore[40290]
#define sipNameNr_toNextBoundary 40305
#define sipName_toNextBoundary &sipStrings_QtCore[40305]
#define sipNameNr_tryLockForRead 40320
#define sipName_tryLockForRead &sipStrings_QtCore[40320]
#define sipNameNr_underlyingType 40335
#define sipName_underlyingType &sipStrings_QtCore[40335]
#define sipNameNr_updateInterval 40350
#define sipName_updateInterval &sipStrings_QtCore[40350]
#define sipNameNr_waitForStarted 40365
#define sipName_waitForStarted &sipStrings_QtCore[40365]
#define sipNameNr_writeAttribute 40380
#define sipName_writeAttribute &sipStrings_QtCore[40380]
#define sipNameNr_writeNamespace 40395
#define sipName_writeNamespace &sipStrings_QtCore[40395]
#define sipNameNr_AA_SetPalette 40410
#define sipName_AA_SetPalette &sipStrings_QtCore[40410]
#define sipNameNr_ActionChanged 40424
#define sipName_ActionChanged &sipStrings_QtCore[40424]
#define sipNameNr_ActionRemoved 40438
#define sipName_ActionRemoved &sipStrings_QtCore[40438]
#define sipNameNr_AlignAbsolute 40452
#define sipName_AlignAbsolute &sipStrings_QtCore[40452]
#define sipNameNr_AlignBaseline 40466
#define sipName_AlignBaseline &sipStrings_QtCore[40466]
#define sipNameNr_AlignTrailing 40480
#define sipName_AlignTrailing &sipStrings_QtCore[40480]
#define sipNameNr_AlignmentFlag 25394
#define sipName_AlignmentFlag &sipStrings_QtCore[25394]
#define sipNameNr_AlreadyExists 40494
#define sipName_AlreadyExists &sipStrings_QtCore[40494]
#define sipNameNr_AmericanSamoa 40508
#define sipName_AmericanSamoa &sipStrings_QtCore[40508]
#define sipNameNr_AndroidKitKat 40522
#define sipName_AndroidKitKat &sipStrings_QtCore[40522]
#define sipNameNr_AndroidNougat 40536
#define sipName_AndroidNougat &sipStrings_QtCore[40536]
#define sipNameNr_AvestanScript 40550
#define sipName_AvestanScript &sipStrings_QtCore[40550]
#define sipNameNr_BengaliScript 40564
#define sipName_BengaliScript &sipStrings_QtCore[40564]
#define sipNameNr_BottomSection 40578
#define sipName_BottomSection &sipStrings_QtCore[40578]
#define sipNameNr_BrailleScript 40592
#define sipName_BrailleScript &sipStrings_QtCore[40592]
#define sipNameNr_COSE_Encrypt0 40606
#define sipName_COSE_Encrypt0 &sipStrings_QtCore[40606]
#define sipNameNr_CacheLocation 16261
#define sipName_CacheLocation &sipStrings_QtCore[16261]
#define sipNameNr_CanaryIslands 40620
#define sipName_CanaryIslands &sipStrings_QtCore[40620]
#define sipNameNr_CaseSensitive 21589
#define sipName_CaseSensitive &sipStrings_QtCore[21589]
#define sipNameNr_CaymanIslands 40634
#define sipName_CaymanIslands &sipStrings_QtCore[40634]
#define sipNameNr_ChildPolished 40648
#define sipName_ChildPolished &sipStrings_QtCore[40648]
#define sipNameNr_ClipOperation 25412
#define sipName_ClipOperation &sipStrings_QtCore[25412]
#define sipNameNr_CongoKinshasa 40662
#define sipName_CongoKinshasa &sipStrings_QtCore[40662]
#define sipNameNr_CustomGesture 40676
#define sipName_CustomGesture &sipStrings_QtCore[40676]
#define sipNameNr_CypriotScript 40690
#define sipName_CypriotScript &sipStrings_QtCore[40690]
#define sipNameNr_CzechRepublic 40704
#define sipName_CzechRepublic &sipStrings_QtCore[40704]
#define sipNameNr_Dense1Pattern 40718
#define sipName_Dense1Pattern &sipStrings_QtCore[40718]
#define sipNameNr_Dense2Pattern 40732
#define sipName_Dense2Pattern &sipStrings_QtCore[40732]
#define sipNameNr_Dense3Pattern 40746
#define sipName_Dense3Pattern &sipStrings_QtCore[40746]
#define sipNameNr_Dense4Pattern 40760
#define sipName_Dense4Pattern &sipStrings_QtCore[40760]
#define sipNameNr_Dense5Pattern 40774
#define sipName_Dense5Pattern &sipStrings_QtCore[40774]
#define sipNameNr_Dense6Pattern 40788
#define sipName_Dense6Pattern &sipStrings_QtCore[40788]
#define sipNameNr_Dense7Pattern 40802
#define sipName_Dense7Pattern &sipStrings_QtCore[40802]
#define sipNameNr_DeseretScript 40816
#define sipName_DeseretScript &sipStrings_QtCore[40816]
#define sipNameNr_DiffuseDither 40830
#define sipName_DiffuseDither &sipStrings_QtCore[40830]
#define sipNameNr_ElbasanScript 40844
#define sipName_ElbasanScript &sipStrings_QtCore[40844]
#define sipNameNr_EmbeddedPOSIX 40858
#define sipName_EmbeddedPOSIX &sipStrings_QtCore[40858]
#define sipNameNr_EnabledChange 40872
#define sipName_EnabledChange &sipStrings_QtCore[40872]
#define sipNameNr_EncodeUnicode 40886
#define sipName_EncodeUnicode &sipStrings_QtCore[40886]
#define sipNameNr_EuropeanUnion 40900
#define sipName_EuropeanUnion &sipStrings_QtCore[40900]
#define sipNameNr_EventPriority 18853
#define sipName_EventPriority &sipStrings_QtCore[18853]
#define sipNameNr_ExtraButton10 40914
#define sipName_ExtraButton10 &sipStrings_QtCore[40914]
#define sipNameNr_ExtraButton11 40928
#define sipName_ExtraButton11 &sipStrings_QtCore[40928]
#define sipNameNr_ExtraButton12 40942
#define sipName_ExtraButton12 &sipStrings_QtCore[40942]
#define sipNameNr_ExtraButton13 40956
#define sipName_ExtraButton13 &sipStrings_QtCore[40956]
#define sipNameNr_ExtraButton14 40970
#define sipName_ExtraButton14 &sipStrings_QtCore[40970]
#define sipNameNr_ExtraButton15 40984
#define sipName_ExtraButton15 &sipStrings_QtCore[40984]
#define sipNameNr_ExtraButton16 40998
#define sipName_ExtraButton16 &sipStrings_QtCore[40998]
#define sipNameNr_ExtraButton17 41012
#define sipName_ExtraButton17 &sipStrings_QtCore[41012]
#define sipNameNr_ExtraButton18 41026
#define sipName_ExtraButton18 &sipStrings_QtCore[41026]
#define sipNameNr_ExtraButton19 41040
#define sipName_ExtraButton19 &sipStrings_QtCore[41040]
#define sipNameNr_ExtraButton20 41054
#define sipName_ExtraButton20 &sipStrings_QtCore[41054]
#define sipNameNr_ExtraButton21 41068
#define sipName_ExtraButton21 &sipStrings_QtCore[41068]
#define sipNameNr_ExtraButton22 41082
#define sipName_ExtraButton22 &sipStrings_QtCore[41082]
#define sipNameNr_ExtraButton23 41096
#define sipName_ExtraButton23 &sipStrings_QtCore[41096]
#define sipNameNr_ExtraButton24 41110
#define sipName_ExtraButton24 &sipStrings_QtCore[41110]
#define sipNameNr_FailedToStart 41124
#define sipName_FailedToStart &sipStrings_QtCore[41124]
#define sipNameNr_FileBirthTime 41138
#define sipName_FileBirthTime &sipStrings_QtCore[41138]
#define sipNameNr_FixedNotation 41152
#define sipName_FixedNotation &sipStrings_QtCore[41152]
#define sipNameNr_FontsLocation 41166
#define sipName_FontsLocation &sipStrings_QtCore[41166]
#define sipNameNr_ForeignWindow 41180
#define sipName_ForeignWindow &sipStrings_QtCore[41180]
#define sipNameNr_ForwardButton 41194
#define sipName_ForwardButton &sipStrings_QtCore[41194]
#define sipNameNr_GranthaScript 41208
#define sipName_GranthaScript &sipStrings_QtCore[41208]
#define sipNameNr_HanunooScript 41222
#define sipName_HanunooScript &sipStrings_QtCore[41222]
#define sipNameNr_ISODateWithMs 41236
#define sipName_ISODateWithMs &sipStrings_QtCore[41236]
#define sipNameNr_IgnoreSigPipe 41250
#define sipName_IgnoreSigPipe &sipStrings_QtCore[41250]
#define sipNameNr_IllegalNumber 41264
#define sipName_IllegalNumber &sipStrings_QtCore[41264]
#define sipNameNr_ImhDigitsOnly 41278
#define sipName_ImhDigitsOnly &sipStrings_QtCore[41278]
#define sipNameNr_ImhHiddenText 41292
#define sipName_ImhHiddenText &sipStrings_QtCore[41292]
#define sipNameNr_ImhNoEditMenu 41306
#define sipName_ImhNoEditMenu &sipStrings_QtCore[41306]
#define sipNameNr_IntersectClip 41320
#define sipName_IntersectClip &sipStrings_QtCore[41320]
#define sipNameNr_InvalidFormat 41334
#define sipName_InvalidFormat &sipStrings_QtCore[41334]
#define sipNameNr_IsEnumeration 41348
#define sipName_IsEnumeration &sipStrings_QtCore[41348]
#define sipNameNr_ItemIsEnabled 41362
#define sipName_ItemIsEnabled &sipStrings_QtCore[41362]
#define sipNameNr_KannadaScript 41376
#define sipName_KannadaScript &sipStrings_QtCore[41376]
#define sipNameNr_KayahLiScript 41390
#define sipName_KayahLiScript &sipStrings_QtCore[41390]
#define sipNameNr_Key_Ampersand 41404
#define sipName_Key_Ampersand &sipStrings_QtCore[41404]
#define sipNameNr_Key_Backslash 41418
#define sipName_Key_Backslash &sipStrings_QtCore[41418]
#define sipNameNr_Key_Backspace 41432
#define sipName_Key_Backspace &sipStrings_QtCore[41432]
#define sipNameNr_Key_BassBoost 41446
#define sipName_Key_BassBoost &sipStrings_QtCore[41446]
#define sipNameNr_Key_Bluetooth 41460
#define sipName_Key_Bluetooth &sipStrings_QtCore[41460]
#define sipNameNr_Key_BraceLeft 41474
#define sipName_Key_BraceLeft &sipStrings_QtCore[41474]
#define sipNameNr_Key_ChannelUp 41488
#define sipName_Key_ChannelUp &sipStrings_QtCore[41488]
#define sipNameNr_Key_ClearGrab 41502
#define sipName_Key_ClearGrab &sipStrings_QtCore[41502]
#define sipNameNr_Key_Codeinput 41516
#define sipName_Key_Codeinput &sipStrings_QtCore[41516]
#define sipNameNr_Key_Community 41530
#define sipName_Key_Community &sipStrings_QtCore[41530]
#define sipNameNr_Key_Dead_Hook 41544
#define sipName_Key_Dead_Hook &sipStrings_QtCore[41544]
#define sipNameNr_Key_Dead_Horn 41558
#define sipName_Key_Dead_Horn &sipStrings_QtCore[41558]
#define sipNameNr_Key_Dead_Iota 41572
#define sipName_Key_Dead_Iota &sipStrings_QtCore[41572]
#define sipNameNr_Key_Documents 41586
#define sipName_Key_Documents &sipStrings_QtCore[41586]
#define sipNameNr_Key_Favorites 41600
#define sipName_Key_Favorites &sipStrings_QtCore[41600]
#define sipNameNr_Key_Hibernate 41614
#define sipName_Key_Hibernate &sipStrings_QtCore[41614]
#define sipNameNr_Key_Kana_Lock 41628
#define sipName_Key_Kana_Lock &sipStrings_QtCore[41628]
#define sipNameNr_Key_LightBulb 41642
#define sipName_Key_LightBulb &sipStrings_QtCore[41642]
#define sipNameNr_Key_MediaLast 41656
#define sipName_Key_MediaLast &sipStrings_QtCore[41656]
#define sipNameNr_Key_MediaNext 41670
#define sipName_Key_MediaNext &sipStrings_QtCore[41670]
#define sipNameNr_Key_MediaPlay 41684
#define sipName_Key_MediaPlay &sipStrings_QtCore[41684]
#define sipNameNr_Key_MediaStop 41698
#define sipName_Key_MediaStop &sipStrings_QtCore[41698]
#define sipNameNr_Key_Messenger 41712
#define sipName_Key_Messenger &sipStrings_QtCore[41712]
#define sipNameNr_Key_Multi_key 41726
#define sipName_Key_Multi_key &sipStrings_QtCore[41726]
#define sipNameNr_Key_ParenLeft 41740
#define sipName_Key_ParenLeft &sipStrings_QtCore[41740]
#define sipNameNr_Key_PowerDown 41754
#define sipName_Key_PowerDown &sipStrings_QtCore[41754]
#define sipNameNr_Key_QuoteLeft 41768
#define sipName_Key_QuoteLeft &sipStrings_QtCore[41768]
#define sipNameNr_Key_Semicolon 41782
#define sipName_Key_Semicolon &sipStrings_QtCore[41782]
#define sipNameNr_Key_VoiceDial 41796
#define sipName_Key_VoiceDial &sipStrings_QtCore[41796]
#define sipNameNr_Key_brokenbar 41810
#define sipName_Key_brokenbar &sipStrings_QtCore[41810]
#define sipNameNr_Key_copyright 41824
#define sipName_Key_copyright &sipStrings_QtCore[41824]
#define sipNameNr_Key_diaeresis 41838
#define sipName_Key_diaeresis &sipStrings_QtCore[41838]
#define sipNameNr_Key_masculine 41852
#define sipName_Key_masculine &sipStrings_QtCore[41852]
#define sipNameNr_Key_paragraph 41866
#define sipName_Key_paragraph &sipStrings_QtCore[41866]
#define sipNameNr_Key_plusminus 41880
#define sipName_Key_plusminus &sipStrings_QtCore[41880]
#define sipNameNr_LayoutRequest 41894
#define sipName_LayoutRequest &sipStrings_QtCore[41894]
#define sipNameNr_LibrariesPath 41908
#define sipName_LibrariesPath &sipStrings_QtCore[41908]
#define sipNameNr_Liechtenstein 41922
#define sipName_Liechtenstein &sipStrings_QtCore[41922]
#define sipNameNr_LinearAScript 41936
#define sipName_LinearAScript &sipStrings_QtCore[41936]
#define sipNameNr_LinearBScript 41950
#define sipName_LinearBScript &sipStrings_QtCore[41950]
#define sipNameNr_Luxembourgish 41964
#define sipName_Luxembourgish &sipStrings_QtCore[41964]
#define sipNameNr_MODIFIER_MASK 41978
#define sipName_MODIFIER_MASK &sipStrings_QtCore[41978]
#define sipNameNr_MPenJoinStyle 41992
#define sipName_MPenJoinStyle &sipStrings_QtCore[41992]
#define sipNameNr_MacOSCatalina 42006
#define sipName_MacOSCatalina &sipStrings_QtCore[42006]
#define sipNameNr_MacOSMonterey 42020
#define sipName_MacOSMonterey &sipStrings_QtCore[42020]
#define sipNameNr_MacSizeChange 42034
#define sipName_MacSizeChange &sipStrings_QtCore[42034]
#define sipNameNr_MakhuwaMeetto 42048
#define sipName_MakhuwaMeetto &sipStrings_QtCore[42048]
#define sipNameNr_MarchenScript 42062
#define sipName_MarchenScript &sipStrings_QtCore[42062]
#define sipNameNr_MatchContains 42076
#define sipName_MatchContains &sipStrings_QtCore[42076]
#define sipNameNr_MatchEndsWith 42090
#define sipName_MatchEndsWith &sipStrings_QtCore[42090]
#define sipNameNr_MatchWildcard 42104
#define sipName_MatchWildcard &sipStrings_QtCore[42104]
#define sipNameNr_MemoryMapFlag 6700
#define sipName_MemoryMapFlag &sipStrings_QtCore[6700]
#define sipNameNr_MissingObject 42118
#define sipName_MissingObject &sipStrings_QtCore[42118]
#define sipNameNr_MultaniScript 42132
#define sipName_MultaniScript &sipStrings_QtCore[42132]
#define sipNameNr_MusicLocation 42146
#define sipName_MusicLocation &sipStrings_QtCore[42146]
#define sipNameNr_MyanmarScript 42160
#define sipName_MyanmarScript &sipStrings_QtCore[42160]
#define sipNameNr_NativeGesture 12843
#define sipName_NativeGesture &sipStrings_QtCore[12843]
#define sipNameNr_NauruLanguage 42174
#define sipName_NauruLanguage &sipStrings_QtCore[42174]
#define sipNameNr_NoCompression 42188
#define sipName_NoCompression &sipStrings_QtCore[42188]
#define sipNameNr_NoContextMenu 42202
#define sipName_NoContextMenu &sipStrings_QtCore[42202]
#define sipNameNr_NoFocusReason 42216
#define sipName_NoFocusReason &sipStrings_QtCore[42216]
#define sipNameNr_NoMatchOption 42230
#define sipName_NoMatchOption &sipStrings_QtCore[42230]
#define sipNameNr_NoScrollPhase 42244
#define sipName_NoScrollPhase &sipStrings_QtCore[42244]
#define sipNameNr_NoToolBarArea 42258
#define sipName_NoToolBarArea &sipStrings_QtCore[42258]
#define sipNameNr_NorfolkIsland 42272
#define sipName_NorfolkIsland &sipStrings_QtCore[42272]
#define sipNameNr_NorthernSotho 42286
#define sipName_NorthernSotho &sipStrings_QtCore[42286]
#define sipNameNr_NotAtBoundary 42300
#define sipName_NotAtBoundary &sipStrings_QtCore[42300]
#define sipNameNr_OffsetFromUTC 42314
#define sipName_OffsetFromUTC &sipStrings_QtCore[42314]
#define sipNameNr_OlChikiScript 42328
#define sipName_OlChikiScript &sipStrings_QtCore[42328]
#define sipNameNr_OrderedDither 42342
#define sipName_OrderedDither &sipStrings_QtCore[42342]
#define sipNameNr_OsmanyaScript 42356
#define sipName_OsmanyaScript &sipStrings_QtCore[42356]
#define sipNameNr_PaletteChange 8936
#define sipName_PaletteChange &sipStrings_QtCore[8936]
#define sipNameNr_PatternOption 2372
#define sipName_PatternOption &sipStrings_QtCore[2372]
#define sipNameNr_PhagsPaScript 42370
#define sipName_PhagsPaScript &sipStrings_QtCore[42370]
#define sipNameNr_PlatformPanel 42384
#define sipName_PlatformPanel &sipStrings_QtCore[42384]
#define sipNameNr_PolishRequest 42398
#define sipName_PolishRequest &sipStrings_QtCore[42398]
#define sipNameNr_PositionError 42412
#define sipName_PositionError &sipStrings_QtCore[42412]
#define sipNameNr_PosixRealtime 42426
#define sipName_PosixRealtime &sipStrings_QtCore[42426]
#define sipNameNr_PreferredSize 42440
#define sipName_PreferredSize &sipStrings_QtCore[42440]
#define sipNameNr_PrettyDecoded 42454
#define sipName_PrettyDecoded &sipStrings_QtCore[42454]
#define sipNameNr_QChar__Script 42468
#define sipName_QChar__Script &sipStrings_QtCore[42468]
#define sipNameNr_QElapsedTimer 42482
#define sipName_QElapsedTimer &sipStrings_QtCore[42482]
#define sipNameNr_QFileSelector 42496
#define sipName_QFileSelector &sipStrings_QtCore[42496]
#define sipNameNr_QIODeviceBase 42510
#define sipName_QIODeviceBase &sipStrings_QtCore[42510]
#define sipNameNr_QJsonDocument 42524
#define sipName_QJsonDocument &sipStrings_QtCore[42524]
#define sipNameNr_QMetaProperty 42538
#define sipName_QMetaProperty &sipStrings_QtCore[42538]
#define sipNameNr_QMimeDatabase 42552
#define sipName_QMimeDatabase &sipStrings_QtCore[42552]
#define sipNameNr_QNativeIpcKey 42566
#define sipName_QNativeIpcKey &sipStrings_QtCore[42566]
#define sipNameNr_QPluginLoader 42580
#define sipName_QPluginLoader &sipStrings_QtCore[42580]
#define sipNameNr_QPyTableRange 42594
#define sipName_QPyTableRange &sipStrings_QtCore[42594]
#define sipNameNr_QSharedMemory 42608
#define sipName_QSharedMemory &sipStrings_QtCore[42608]
#define sipNameNr_QSignalMapper 42622
#define sipName_QSignalMapper &sipStrings_QtCore[42622]
#define sipNameNr_QTemporaryDir 42636
#define sipName_QTemporaryDir &sipStrings_QtCore[42636]
#define sipNameNr_QTypeRevision 42650
#define sipName_QTypeRevision &sipStrings_QtCore[42650]
#define sipNameNr_Qt__ArrowType 42664
#define sipName_Qt__ArrowType &sipStrings_QtCore[42664]
#define sipNameNr_Qt__DayOfWeek 42678
#define sipName_Qt__DayOfWeek &sipStrings_QtCore[42678]
#define sipNameNr_Qt__MatchFlag 42692
#define sipName_Qt__MatchFlag &sipStrings_QtCore[42692]
#define sipNameNr_Qt__SortOrder 42706
#define sipName_Qt__SortOrder &sipStrings_QtCore[42706]
#define sipNameNr_Qt__TimerType 42720
#define sipName_Qt__TimerType &sipStrings_QtCore[42720]
#define sipNameNr_QtCriticalMsg 42734
#define sipName_QtCriticalMsg &sipStrings_QtCore[42734]
#define sipNameNr_RecursionMode 4154
#define sipName_RecursionMode &sipStrings_QtCore[4154]
#define sipNameNr_ResourceError 42748
#define sipName_ResourceError &sipStrings_QtCore[42748]
#define sipNameNr_RhaetoRomance 42762
#define sipName_RhaetoRomance &sipStrings_QtCore[42762]
#define sipNameNr_Script_Arabic 42776
#define sipName_Script_Arabic &sipStrings_QtCore[42776]
#define sipNameNr_Script_Brahmi 42790
#define sipName_Script_Brahmi &sipStrings_QtCore[42790]
#define sipNameNr_Script_Carian 42804
#define sipName_Script_Carian &sipStrings_QtCore[42804]
#define sipNameNr_Script_Chakma 42818
#define sipName_Script_Chakma &sipStrings_QtCore[42818]
#define sipNameNr_Script_Common 42832
#define sipName_Script_Common &sipStrings_QtCore[42832]
#define sipNameNr_Script_Coptic 42846
#define sipName_Script_Coptic &sipStrings_QtCore[42846]
#define sipNameNr_Script_Gothic 42860
#define sipName_Script_Gothic &sipStrings_QtCore[42860]
#define sipNameNr_Script_Hangul 42874
#define sipName_Script_Hangul &sipStrings_QtCore[42874]
#define sipNameNr_Script_Hatran 42888
#define sipName_Script_Hatran &sipStrings_QtCore[42888]
#define sipNameNr_Script_Hebrew 42902
#define sipName_Script_Hebrew &sipStrings_QtCore[42902]
#define sipNameNr_Script_Kaithi 42916
#define sipName_Script_Kaithi &sipStrings_QtCore[42916]
#define sipNameNr_Script_Khojki 42930
#define sipName_Script_Khojki &sipStrings_QtCore[42930]
#define sipNameNr_Script_Lepcha 42944
#define sipName_Script_Lepcha &sipStrings_QtCore[42944]
#define sipNameNr_Script_Lycian 42958
#define sipName_Script_Lycian &sipStrings_QtCore[42958]
#define sipNameNr_Script_Lydian 42972
#define sipName_Script_Lydian &sipStrings_QtCore[42972]
#define sipNameNr_Script_OlOnal 42986
#define sipName_Script_OlOnal &sipStrings_QtCore[42986]
#define sipNameNr_Script_Rejang 43000
#define sipName_Script_Rejang &sipStrings_QtCore[43000]
#define sipNameNr_Script_Syriac 43014
#define sipName_Script_Syriac &sipStrings_QtCore[43014]
#define sipNameNr_Script_Tangsa 43028
#define sipName_Script_Tangsa &sipStrings_QtCore[43028]
#define sipNameNr_Script_Tangut 43042
#define sipName_Script_Tangut &sipStrings_QtCore[43042]
#define sipNameNr_Script_Telugu 43056
#define sipName_Script_Telugu &sipStrings_QtCore[43056]
#define sipNameNr_Script_Thaana 43070
#define sipName_Script_Thaana &sipStrings_QtCore[43070]
#define sipNameNr_Script_Todhri 43084
#define sipName_Script_Todhri &sipStrings_QtCore[43084]
#define sipNameNr_Script_Wancho 43098
#define sipName_Script_Wancho &sipStrings_QtCore[43098]
#define sipNameNr_Script_Yezidi 43112
#define sipName_Script_Yezidi &sipStrings_QtCore[43112]
#define sipNameNr_ScrollPrepare 43126
#define sipName_ScrollPrepare &sipStrings_QtCore[43126]
#define sipNameNr_SelectCurrent 43140
#define sipName_SelectCurrent &sipStrings_QtCore[43140]
#define sipNameNr_SelectionFlag 1926
#define sipName_SelectionFlag &sipStrings_QtCore[1926]
#define sipNameNr_SharadaScript 43154
#define sipName_SharadaScript &sipStrings_QtCore[43154]
#define sipNameNr_ShavianScript 43168
#define sipName_ShavianScript &sipStrings_QtCore[43168]
#define sipNameNr_ShiftModifier 43182
#define sipName_ShiftModifier &sipStrings_QtCore[43182]
#define sipNameNr_SiddhamScript 43196
#define sipName_SiddhamScript &sipStrings_QtCore[43196]
#define sipNameNr_SinhalaScript 43210
#define sipName_SinhalaScript &sipStrings_QtCore[43210]
#define sipNameNr_SizeAllCursor 43224
#define sipName_SizeAllCursor &sipStrings_QtCore[43224]
#define sipNameNr_SizeHorCursor 43238
#define sipName_SizeHorCursor &sipStrings_QtCore[43238]
#define sipNameNr_SizeVerCursor 43252
#define sipName_SizeVerCursor &sipStrings_QtCore[43252]
#define sipNameNr_SmartNotation 43266
#define sipName_SmartNotation &sipStrings_QtCore[43266]
#define sipNameNr_SouthernSotho 43280
#define sipName_SouthernSotho &sipStrings_QtCore[43280]
#define sipNameNr_StandardError 13280
#define sipName_StandardError &sipStrings_QtCore[13280]
#define sipNameNr_StartDocument 24097
#define sipName_StartDocument &sipStrings_QtCore[24097]
#define sipNameNr_StateLocation 16282
#define sipName_StateLocation &sipStrings_QtCore[16282]
#define sipNameNr_StatusTipRole 43294
#define sipName_StatusTipRole &sipStrings_QtCore[43294]
#define sipNameNr_TabletRelease 43308
#define sipName_TabletRelease &sipStrings_QtCore[43308]
#define sipNameNr_TagalogScript 43322
#define sipName_TagalogScript &sipStrings_QtCore[43322]
#define sipNameNr_TaiVietScript 43336
#define sipName_TaiVietScript &sipStrings_QtCore[43336]
#define sipNameNr_TextDontPrint 43350
#define sipName_TextDontPrint &sipStrings_QtCore[43350]
#define sipNameNr_TextElideMode 25448
#define sipName_TextElideMode &sipStrings_QtCore[25448]
#define sipNameNr_TibetanScript 43364
#define sipName_TibetanScript &sipStrings_QtCore[43364]
#define sipNameNr_TirhutaScript 43378
#define sipName_TirhutaScript &sipStrings_QtCore[43378]
#define sipNameNr_ToggleCurrent 43392
#define sipName_ToggleCurrent &sipStrings_QtCore[43392]
#define sipNameNr_ToolBarChange 43406
#define sipName_ToolBarChange &sipStrings_QtCore[43406]
#define sipNameNr_ToolTipChange 43420
#define sipName_ToolTipChange &sipStrings_QtCore[43420]
#define sipNameNr_TopLeftCorner 43434
#define sipName_TopLeftCorner &sipStrings_QtCore[43434]
#define sipNameNr_TuvaluCountry 43448
#define sipName_TuvaluCountry &sipStrings_QtCore[43448]
#define sipNameNr_UnitedKingdom 43462
#define sipName_UnitedKingdom &sipStrings_QtCore[43462]
#define sipNameNr_UpArrowCursor 43476
#define sipName_UpArrowCursor &sipStrings_QtCore[43476]
#define sipNameNr_UpdateRequest 43490
#define sipName_UpdateRequest &sipStrings_QtCore[43490]
#define sipNameNr_UppercaseBase 43504
#define sipName_UppercaseBase &sipStrings_QtCore[43504]
#define sipNameNr_WA_SetPalette 43518
#define sipName_WA_SetPalette &sipStrings_QtCore[43518]
#define sipNameNr_WA_StyleSheet 43532
#define sipName_WA_StyleSheet &sipStrings_QtCore[43532]
#define sipNameNr_WA_UnderMouse 43546
#define sipName_WA_UnderMouse &sipStrings_QtCore[43546]
#define sipNameNr_WesternSahara 43560
#define sipName_WesternSahara &sipStrings_QtCore[43560]
#define sipNameNr_WhatsThisRole 43574
#define sipName_WhatsThisRole &sipStrings_QtCore[43574]
#define sipNameNr_WhiteSpacePre 43588
#define sipName_WhiteSpacePre &sipStrings_QtCore[43588]
#define sipNameNr_WindowBlocked 43602
#define sipName_WindowBlocked &sipStrings_QtCore[43602]
#define sipNameNr_WindowNoState 43616
#define sipName_WindowNoState &sipStrings_QtCore[43616]
#define sipNameNr_WithoutBraces 43630
#define sipName_WithoutBraces &sipStrings_QtCore[43630]
#define sipNameNr_addHelpOption 43644
#define sipName_addHelpOption &sipStrings_QtCore[43644]
#define sipNameNr_addSearchPath 43658
#define sipName_addSearchPath &sipStrings_QtCore[43658]
#define sipNameNr_addTCBSegment 43672
#define sipName_addTCBSegment &sipStrings_QtCore[43672]
#define sipNameNr_asBackendZone 43686
#define sipName_asBackendZone &sipStrings_QtCore[43686]
#define sipNameNr_beginMoveRows 43700
#define sipName_beginMoveRows &sipStrings_QtCore[43700]
#define sipNameNr_cancelWriting 43714
#define sipName_cancelWriting &sipStrings_QtCore[43714]
#define sipNameNr_canonicalPath 43728
#define sipName_canonicalPath &sipStrings_QtCore[43728]
#define sipNameNr_capturedStart 43742
#define sipName_capturedStart &sipStrings_QtCore[43742]
#define sipNameNr_capturedTexts 43756
#define sipName_capturedTexts &sipStrings_QtCore[43756]
#define sipNameNr_clearItemData 43770
#define sipName_clearItemData &sipStrings_QtCore[43770]
#define sipNameNr_codeToCountry 43784
#define sipName_codeToCountry &sipStrings_QtCore[43784]
#define sipNameNr_connectNotify 30325
#define sipName_connectNotify &sipStrings_QtCore[30325]
#define sipNameNr_countryToCode 43798
#define sipName_countryToCode &sipStrings_QtCore[43798]
#define sipNameNr_currentOffset 43812
#define sipName_currentOffset &sipStrings_QtCore[43812]
#define sipNameNr_currentThread 43826
#define sipName_currentThread &sipStrings_QtCore[43826]
#define sipNameNr_dateFromParts 43840
#define sipName_dateFromParts &sipStrings_QtCore[43840]
#define sipNameNr_deadlineNSecs 43854
#define sipName_deadlineNSecs &sipStrings_QtCore[43854]
#define sipNameNr_defaultFormat 43868
#define sipName_defaultFormat &sipStrings_QtCore[43868]
#define sipNameNr_defaultValues 43882
#define sipName_defaultValues &sipStrings_QtCore[43882]
#define sipNameNr_endInsertRows 43896
#define sipName_endInsertRows &sipStrings_QtCore[43896]
#define sipNameNr_endRemoveRows 43910
#define sipName_endRemoveRows &sipStrings_QtCore[43910]
#define sipNameNr_endResetModel 43924
#define sipName_endResetModel &sipStrings_QtCore[43924]
#define sipNameNr_entryInfoList 43938
#define sipName_entryInfoList &sipStrings_QtCore[43938]
#define sipNameNr_errorOccurred 43952
#define sipName_errorOccurred &sipStrings_QtCore[43952]
#define sipNameNr_expiryTimeout 43966
#define sipName_expiryTimeout &sipStrings_QtCore[43966]
#define sipNameNr_fromJulianDay 43980
#define sipName_fromJulianDay &sipStrings_QtCore[43980]
#define sipNameNr_fromLocalFile 43994
#define sipName_fromLocalFile &sipStrings_QtCore[43994]
#define sipNameNr_fromUserInput 44008
#define sipName_fromUserInput &sipStrings_QtCore[44008]
#define sipNameNr_indexOfMethod 44022
#define sipName_indexOfMethod &sipStrings_QtCore[44022]
#define sipNameNr_indexOfSignal 44036
#define sipName_indexOfSignal &sipStrings_QtCore[44036]
#define sipNameNr_insertColumns 44050
#define sipName_insertColumns &sipStrings_QtCore[44050]
#define sipNameNr_isEndDocument 44064
#define sipName_isEndDocument &sipStrings_QtCore[44064]
#define sipNameNr_isInfoEnabled 44078
#define sipName_isInfoEnabled &sipStrings_QtCore[44078]
#define sipNameNr_isLengthKnown 44092
#define sipName_isLengthKnown &sipStrings_QtCore[44092]
#define sipNameNr_isRowSelected 44106
#define sipName_isRowSelected &sipStrings_QtCore[44106]
#define sipNameNr_isSharedBuild 44120
#define sipName_isSharedBuild &sipStrings_QtCore[44120]
#define sipNameNr_kernelVersion 44134
#define sipName_kernelVersion &sipStrings_QtCore[44134]
#define sipNameNr_layoutChanged 44148
#define sipName_layoutChanged &sipStrings_QtCore[44148]
#define sipNameNr_leftJustified 44162
#define sipName_leftJustified &sipStrings_QtCore[44162]
#define sipNameNr_listSeparator 44176
#define sipName_listSeparator &sipStrings_QtCore[44176]
#define sipNameNr_lowercasebase 44190
#define sipName_lowercasebase &sipStrings_QtCore[44190]
#define sipNameNr_mapFromSource 44204
#define sipName_mapFromSource &sipStrings_QtCore[44204]
#define sipNameNr_nullTerminate 44218
#define sipName_nullTerminate &sipStrings_QtCore[44218]
#define sipNameNr_numberOptions 44232
#define sipName_numberOptions &sipStrings_QtCore[44232]
#define sipNameNr_offsetFromUtc 44246
#define sipName_offsetFromUtc &sipStrings_QtCore[44246]
#define sipNameNr_offsetSeconds 44260
#define sipName_offsetSeconds &sipStrings_QtCore[44260]
#define sipNameNr_parameterType 44274
#define sipName_parameterType &sipStrings_QtCore[44274]
#define sipNameNr_partsFromDate 44288
#define sipName_partsFromDate &sipStrings_QtCore[44288]
#define sipNameNr_processEvents 44302
#define sipName_processEvents &sipStrings_QtCore[44302]
#define sipNameNr_propertyCount 44316
#define sipName_propertyCount &sipStrings_QtCore[44316]
#define sipNameNr_propertyIndex 44330
#define sipName_propertyIndex &sipStrings_QtCore[44330]
#define sipNameNr_pyqtClassInfo 44344
#define sipName_pyqtClassInfo &sipStrings_QtCore[44344]
#define sipNameNr_pyqtConfigure 44358
#define sipName_pyqtConfigure &sipStrings_QtCore[44358]
#define sipNameNr_qFuzzyCompare 44372
#define sipName_qFuzzyCompare &sipStrings_QtCore[44372]
#define sipNameNr_qualifiedName 44386
#define sipName_qualifiedName &sipStrings_QtCore[44386]
#define sipNameNr_readAllString 44400
#define sipName_readAllString &sipStrings_QtCore[44400]
#define sipNameNr_readByteArray 44414
#define sipName_readByteArray &sipStrings_QtCore[44414]
#define sipNameNr_readWriteLock 44428
#define sipName_readWriteLock &sipStrings_QtCore[44428]
#define sipNameNr_recursionMode 44442
#define sipName_recursionMode &sipStrings_QtCore[44442]
#define sipNameNr_registerTimer 35305
#define sipName_registerTimer &sipStrings_QtCore[35305]
#define sipNameNr_releaseThread 44456
#define sipName_releaseThread &sipStrings_QtCore[44456]
#define sipNameNr_remainingTime 44470
#define sipName_remainingTime &sipStrings_QtCore[44470]
#define sipNameNr_removeColumns 44484
#define sipName_removeColumns &sipStrings_QtCore[44484]
#define sipNameNr_reserveThread 44498
#define sipName_reserveThread &sipStrings_QtCore[44498]
#define sipNameNr_setAccessMode 44512
#define sipName_setAccessMode &sipStrings_QtCore[44512]
#define sipNameNr_setArrayIndex 44526
#define sipName_setArrayIndex &sipStrings_QtCore[44526]
#define sipNameNr_setAutoDelete 44540
#define sipName_setAutoDelete &sipStrings_QtCore[44540]
#define sipNameNr_setAutoRemove 44554
#define sipName_setAutoRemove &sipStrings_QtCore[44554]
#define sipNameNr_setBottomLeft 44568
#define sipName_setBottomLeft &sipStrings_QtCore[44568]
#define sipNameNr_setCustomType 44582
#define sipName_setCustomType &sipStrings_QtCore[44582]
#define sipNameNr_setFieldWidth 44596
#define sipName_setFieldWidth &sipStrings_QtCore[44596]
#define sipNameNr_setFilterRole 44610
#define sipName_setFilterRole &sipStrings_QtCore[44610]
#define sipNameNr_setFrameRange 44624
#define sipName_setFrameRange &sipStrings_QtCore[44624]
#define sipNameNr_setHeaderData 44638
#define sipName_setHeaderData &sipStrings_QtCore[44638]
#define sipNameNr_setKeyValueAt 44652
#define sipName_setKeyValueAt &sipStrings_QtCore[44652]
#define sipNameNr_setObjectName 44666
#define sipName_setObjectName &sipStrings_QtCore[44666]
#define sipNameNr_setQueryItems 44680
#define sipName_setQueryItems &sipStrings_QtCore[44680]
#define sipNameNr_setSingleShot 44694
#define sipName_setSingleShot &sipStrings_QtCore[44694]
#define sipNameNr_setStartFrame 44708
#define sipName_setStartFrame &sipStrings_QtCore[44708]
#define sipNameNr_setStartValue 44722
#define sipName_setStartValue &sipStrings_QtCore[44722]
#define sipNameNr_setStringList 44736
#define sipName_setStringList &sipStrings_QtCore[44736]
#define sipNameNr_severityLevel 44750
#define sipName_severityLevel &sipStrings_QtCore[44750]
#define sipNameNr_staleLockTime 44764
#define sipName_staleLockTime &sipStrings_QtCore[44764]
#define sipNameNr_startDetached 44778
#define sipName_startDetached &sipStrings_QtCore[44778]
#define sipNameNr_symLinkTarget 44792
#define sipName_symLinkTarget &sipStrings_QtCore[44792]
#define sipNameNr_takeAnimation 44806
#define sipName_takeAnimation &sipStrings_QtCore[44806]
#define sipNameNr_testAttribute 44820
#define sipName_testAttribute &sipStrings_QtCore[44820]
#define sipNameNr_textDirection 44834
#define sipName_textDirection &sipStrings_QtCore[44834]
#define sipNameNr_toAlignedRect 44848
#define sipName_toAlignedRect &sipStrings_QtCore[44848]
#define sipNameNr_toCubicSpline 44862
#define sipName_toCubicSpline &sipStrings_QtCore[44862]
#define sipNameNr_totalDuration 44876
#define sipName_totalDuration &sipStrings_QtCore[44876]
#define sipNameNr_uppercasebase 44890
#define sipName_uppercasebase &sipStrings_QtCore[44890]
#define sipNameNr_writeQVariant 44904
#define sipName_writeQVariant &sipStrings_QtCore[44904]
#define sipNameNr_AbsoluteSize 44918
#define sipName_AbsoluteSize &sipStrings_QtCore[44918]
#define sipNameNr_AlandIslands 44931
#define sipName_AlandIslands &sipStrings_QtCore[44931]
#define sipNameNr_AlignHCenter 44944
#define sipName_AlignHCenter &sipStrings_QtCore[44944]
#define sipNameNr_AlignJustify 44957
#define sipName_AlignJustify &sipStrings_QtCore[44957]
#define sipNameNr_AlignLeading 44970
#define sipName_AlignLeading &sipStrings_QtCore[44970]
#define sipNameNr_AlignVCenter 44983
#define sipName_AlignVCenter &sipStrings_QtCore[44983]
#define sipNameNr_AnchorBottom 44996
#define sipName_AnchorBottom &sipStrings_QtCore[44996]
#define sipNameNr_AncientGreek 45009
#define sipName_AncientGreek &sipStrings_QtCore[45009]
#define sipNameNr_AnyTerritory 45022
#define sipName_AnyTerritory &sipStrings_QtCore[45022]
#define sipNameNr_ArabicScript 45035
#define sipName_ArabicScript &sipStrings_QtCore[45035]
#define sipNameNr_ArchDataPath 45048
#define sipName_ArchDataPath &sipStrings_QtCore[45048]
#define sipNameNr_Availability 2339
#define sipName_Availability &sipStrings_QtCore[2339]
#define sipNameNr_BDiagPattern 45061
#define sipName_BDiagPattern &sipStrings_QtCore[45061]
#define sipNameNr_BanglaScript 45074
#define sipName_BanglaScript &sipStrings_QtCore[45074]
#define sipNameNr_Base64Option 9312
#define sipName_Base64Option &sipStrings_QtCore[9312]
#define sipNameNr_BezierSpline 45087
#define sipName_BezierSpline &sipStrings_QtCore[45087]
#define sipNameNr_BinariesPath 45100
#define sipName_BinariesPath &sipStrings_QtCore[45100]
#define sipNameNr_BitmapCursor 45113
#define sipName_BitmapCursor &sipStrings_QtCore[45113]
#define sipNameNr_BoundaryType 2407
#define sipName_BoundaryType &sipStrings_QtCore[2407]
#define sipNameNr_BouvetIsland 45126
#define sipName_BouvetIsland &sipStrings_QtCore[45126]
#define sipNameNr_BrahmiScript 45139
#define sipName_BrahmiScript &sipStrings_QtCore[45139]
#define sipNameNr_Byelorussian 45152
#define sipName_Byelorussian &sipStrings_QtCore[45152]
#define sipNameNr_COSE_Encrypt 45165
#define sipName_COSE_Encrypt &sipStrings_QtCore[45165]
#define sipNameNr_CarianScript 45178
#define sipName_CarianScript &sipStrings_QtCore[45178]
#define sipNameNr_ChakmaScript 45191
#define sipName_ChakmaScript &sipStrings_QtCore[45191]
#define sipNameNr_ChecksumType 29153
#define sipName_ChecksumType &sipStrings_QtCore[29153]
#define sipNameNr_ChildRemoved 45204
#define sipName_ChildRemoved &sipStrings_QtCore[45204]
#define sipNameNr_CocosIslands 45217
#define sipName_CocosIslands &sipStrings_QtCore[45217]
#define sipNameNr_CopticScript 45230
#define sipName_CopticScript &sipStrings_QtCore[45230]
#define sipNameNr_CrossPattern 27793
#define sipName_CrossPattern &sipStrings_QtCore[27793]
#define sipNameNr_CursorChange 45243
#define sipName_CursorChange &sipStrings_QtCore[45243]
#define sipNameNr_CustomCursor 45256
#define sipName_CustomCursor &sipStrings_QtCore[45256]
#define sipNameNr_DataTooLarge 45269
#define sipName_DataTooLarge &sipStrings_QtCore[45269]
#define sipNameNr_DaylightTime 34442
#define sipName_DaylightTime &sipStrings_QtCore[34442]
#define sipNameNr_DeepBindHint 45282
#define sipName_DeepBindHint &sipStrings_QtCore[45282]
#define sipNameNr_EncodeSpaces 45295
#define sipName_EncodeSpaces &sipStrings_QtCore[45295]
#define sipNameNr_EnterKeyDone 45308
#define sipName_EnterKeyDone &sipStrings_QtCore[45308]
#define sipNameNr_EnterKeyNext 45321
#define sipName_EnterKeyNext &sipStrings_QtCore[45321]
#define sipNameNr_EnterKeySend 45334
#define sipName_EnterKeySend &sipStrings_QtCore[45334]
#define sipNameNr_EnterKeyType 29170
#define sipName_EnterKeyType &sipStrings_QtCore[29170]
#define sipNameNr_ExamplesPath 45347
#define sipName_ExamplesPath &sipStrings_QtCore[45347]
#define sipNameNr_ExistingOnly 45360
#define sipName_ExistingOnly &sipStrings_QtCore[45360]
#define sipNameNr_ExtraButton1 45373
#define sipName_ExtraButton1 &sipStrings_QtCore[45373]
#define sipNameNr_ExtraButton2 45386
#define sipName_ExtraButton2 &sipStrings_QtCore[45386]
#define sipNameNr_ExtraButton3 45399
#define sipName_ExtraButton3 &sipStrings_QtCore[45399]
#define sipNameNr_ExtraButton4 45412
#define sipName_ExtraButton4 &sipStrings_QtCore[45412]
#define sipNameNr_ExtraButton5 45425
#define sipName_ExtraButton5 &sipStrings_QtCore[45425]
#define sipNameNr_ExtraButton6 45438
#define sipName_ExtraButton6 &sipStrings_QtCore[45438]
#define sipNameNr_ExtraButton7 45451
#define sipName_ExtraButton7 &sipStrings_QtCore[45451]
#define sipNameNr_ExtraButton8 45464
#define sipName_ExtraButton8 &sipStrings_QtCore[45464]
#define sipNameNr_ExtraButton9 45477
#define sipName_ExtraButton9 &sipStrings_QtCore[45477]
#define sipNameNr_FDiagPattern 45490
#define sipName_FDiagPattern &sipStrings_QtCore[45490]
#define sipNameNr_FaroeIslands 45503
#define sipName_FaroeIslands &sipStrings_QtCore[45503]
#define sipNameNr_FirstGuiType 45516
#define sipName_FirstGuiType &sipStrings_QtCore[45516]
#define sipNameNr_FraserScript 45529
#define sipName_FraserScript &sipStrings_QtCore[45529]
#define sipNameNr_FrenchGuiana 45542
#define sipName_FrenchGuiana &sipStrings_QtCore[45542]
#define sipNameNr_FullyDecoded 45555
#define sipName_FullyDecoded &sipStrings_QtCore[45555]
#define sipNameNr_FullyEncoded 45568
#define sipName_FullyEncoded &sipStrings_QtCore[45568]
#define sipNameNr_GarbageAtEnd 45581
#define sipName_GarbageAtEnd &sipStrings_QtCore[45581]
#define sipNameNr_GestureState 29187
#define sipName_GestureState &sipStrings_QtCore[29187]
#define sipNameNr_GothicScript 45594
#define sipName_GothicScript &sipStrings_QtCore[45594]
#define sipNameNr_GrabKeyboard 45607
#define sipName_GrabKeyboard &sipStrings_QtCore[45607]
#define sipNameNr_GuineaBissau 45620
#define sipName_GuineaBissau &sipStrings_QtCore[45620]
#define sipNameNr_HangulScript 45633
#define sipName_HangulScript &sipStrings_QtCore[45633]
#define sipNameNr_HanifiScript 45646
#define sipName_HanifiScript &sipStrings_QtCore[45646]
#define sipNameNr_HatranScript 45659
#define sipName_HatranScript &sipStrings_QtCore[45659]
#define sipNameNr_HebrewScript 45672
#define sipName_HebrewScript &sipStrings_QtCore[45672]
#define sipNameNr_HideToParent 45685
#define sipName_HideToParent &sipStrings_QtCore[45685]
#define sipNameNr_HighContrast 45698
#define sipName_HighContrast &sipStrings_QtCore[45698]
#define sipNameNr_HighPriority 45711
#define sipName_HighPriority &sipStrings_QtCore[45711]
#define sipNameNr_HomeLocation 45724
#define sipName_HomeLocation &sipStrings_QtCore[45724]
#define sipNameNr_ISO639Alpha2 45737
#define sipName_ISO639Alpha2 &sipStrings_QtCore[45737]
#define sipNameNr_ISO639Alpha3 45750
#define sipName_ISO639Alpha3 &sipStrings_QtCore[45750]
#define sipNameNr_ISO639Part2B 45763
#define sipName_ISO639Part2B &sipStrings_QtCore[45763]
#define sipNameNr_ISO639Part2T 45776
#define sipName_ISO639Part2T &sipStrings_QtCore[45776]
#define sipNameNr_IdlePriority 45789
#define sipName_IdlePriority &sipStrings_QtCore[45789]
#define sipNameNr_IgnoreAction 45802
#define sipName_IgnoreAction &sipStrings_QtCore[45802]
#define sipNameNr_IllegalValue 45815
#define sipName_IllegalValue &sipStrings_QtCore[45815]
#define sipNameNr_ImQueryInput 45828
#define sipName_ImQueryInput &sipStrings_QtCore[45828]
#define sipNameNr_ImhLatinOnly 45841
#define sipName_ImhLatinOnly &sipStrings_QtCore[45841]
#define sipNameNr_ImhMultiLine 45854
#define sipName_ImhMultiLine &sipStrings_QtCore[45854]
#define sipNameNr_InOutElastic 45867
#define sipName_InOutElastic &sipStrings_QtCore[45867]
#define sipNameNr_IndexIsValid 45880
#define sipName_IndexIsValid &sipStrings_QtCore[45880]
#define sipNameNr_IslamicCivil 45893
#define sipName_IslamicCivil &sipStrings_QtCore[45893]
#define sipNameNr_ItemDataRole 29204
#define sipName_ItemDataRole &sipStrings_QtCore[29204]
#define sipNameNr_IteratorFlag 6674
#define sipName_IteratorFlag &sipStrings_QtCore[6674]
#define sipNameNr_Kabuverdianu 45906
#define sipName_Kabuverdianu &sipStrings_QtCore[45906]
#define sipNameNr_KaithiScript 45919
#define sipName_KaithiScript &sipStrings_QtCore[45919]
#define sipNameNr_Key_Asterisk 45932
#define sipName_Key_Asterisk &sipStrings_QtCore[45932]
#define sipNameNr_Key_BassDown 45945
#define sipName_Key_BassDown &sipStrings_QtCore[45945]
#define sipNameNr_Key_Calendar 45958
#define sipName_Key_Calendar &sipStrings_QtCore[45958]
#define sipNameNr_Key_CapsLock 45971
#define sipName_Key_CapsLock &sipStrings_QtCore[45971]
#define sipNameNr_Key_Ccedilla 45984
#define sipName_Key_Ccedilla &sipStrings_QtCore[45984]
#define sipNameNr_Key_Context1 45997
#define sipName_Key_Context1 &sipStrings_QtCore[45997]
#define sipNameNr_Key_Context2 46010
#define sipName_Key_Context2 &sipStrings_QtCore[46010]
#define sipNameNr_Key_Context3 46023
#define sipName_Key_Context3 &sipStrings_QtCore[46023]
#define sipNameNr_Key_Context4 46036
#define sipName_Key_Context4 &sipStrings_QtCore[46036]
#define sipNameNr_Key_Explorer 46049
#define sipName_Key_Explorer &sipStrings_QtCore[46049]
#define sipNameNr_Key_Hiragana 46062
#define sipName_Key_Hiragana &sipStrings_QtCore[46062]
#define sipNameNr_Key_HomePage 46075
#define sipName_Key_HomePage &sipStrings_QtCore[46075]
#define sipNameNr_Key_HotLinks 46088
#define sipName_Key_HotLinks &sipStrings_QtCore[46088]
#define sipNameNr_Key_Katakana 46101
#define sipName_Key_Katakana &sipStrings_QtCore[46101]
#define sipNameNr_Key_Keyboard 46114
#define sipName_Key_Keyboard &sipStrings_QtCore[46114]
#define sipNameNr_Key_Muhenkan 46127
#define sipName_Key_Muhenkan &sipStrings_QtCore[46127]
#define sipNameNr_Key_Ooblique 46140
#define sipName_Key_Ooblique &sipStrings_QtCore[46140]
#define sipNameNr_Key_PageDown 46153
#define sipName_Key_PageDown &sipStrings_QtCore[46153]
#define sipNameNr_Key_Pictures 46166
#define sipName_Key_Pictures &sipStrings_QtCore[46166]
#define sipNameNr_Key_PowerOff 46179
#define sipName_Key_PowerOff &sipStrings_QtCore[46179]
#define sipNameNr_Key_Question 46192
#define sipName_Key_Question &sipStrings_QtCore[46192]
#define sipNameNr_Key_QuoteDbl 46205
#define sipName_Key_QuoteDbl &sipStrings_QtCore[46205]
#define sipNameNr_Key_Settings 46218
#define sipName_Key_Settings &sipStrings_QtCore[46218]
#define sipNameNr_Key_Subtitle 46231
#define sipName_Key_Subtitle &sipStrings_QtCore[46231]
#define sipNameNr_Key_TaskPane 46244
#define sipName_Key_TaskPane &sipStrings_QtCore[46244]
#define sipNameNr_Key_Terminal 46257
#define sipName_Key_Terminal &sipStrings_QtCore[46257]
#define sipNameNr_Key_ToDoList 46270
#define sipName_Key_ToDoList &sipStrings_QtCore[46270]
#define sipNameNr_Key_TrebleUp 46283
#define sipName_Key_TrebleUp &sipStrings_QtCore[46283]
#define sipNameNr_Key_VolumeUp 46296
#define sipName_Key_VolumeUp &sipStrings_QtCore[46296]
#define sipNameNr_Key_currency 46309
#define sipName_Key_currency &sipStrings_QtCore[46309]
#define sipNameNr_Key_division 46322
#define sipName_Key_division &sipStrings_QtCore[46322]
#define sipNameNr_Key_multiply 46335
#define sipName_Key_multiply &sipStrings_QtCore[46335]
#define sipNameNr_Key_sterling 46348
#define sipName_Key_sterling &sipStrings_QtCore[46348]
#define sipNameNr_KhojkiScript 46361
#define sipName_KhojkiScript &sipStrings_QtCore[46361]
#define sipNameNr_KoreanScript 46374
#define sipName_KoreanScript &sipStrings_QtCore[46374]
#define sipNameNr_LastCoreType 46387
#define sipName_LastCoreType &sipStrings_QtCore[46387]
#define sipNameNr_LastLanguage 46400
#define sipName_LastLanguage &sipStrings_QtCore[46400]
#define sipNameNr_LatinAmerica 46413
#define sipName_LatinAmerica &sipStrings_QtCore[46413]
#define sipNameNr_LepchaScript 46426
#define sipName_LepchaScript &sipStrings_QtCore[46426]
#define sipNameNr_LittleEndian 46439
#define sipName_LittleEndian &sipStrings_QtCore[46439]
#define sipNameNr_LocaleChange 46452
#define sipName_LocaleChange &sipStrings_QtCore[46452]
#define sipNameNr_LocateOption 4711
#define sipName_LocateOption &sipStrings_QtCore[4711]
#define sipNameNr_LowerSorbian 46465
#define sipName_LowerSorbian &sipStrings_QtCore[46465]
#define sipNameNr_LycianScript 46478
#define sipName_LycianScript &sipStrings_QtCore[46478]
#define sipNameNr_LydianScript 46491
#define sipName_LydianScript &sipStrings_QtCore[46491]
#define sipNameNr_MacOSVentura 46504
#define sipName_MacOSVentura &sipStrings_QtCore[46504]
#define sipNameNr_MarkdownText 46517
#define sipName_MarkdownText &sipStrings_QtCore[46517]
#define sipNameNr_MaskOutColor 46530
#define sipName_MaskOutColor &sipStrings_QtCore[46530]
#define sipNameNr_MatchContent 46543
#define sipName_MatchContent &sipStrings_QtCore[46543]
#define sipNameNr_MatchDefault 46556
#define sipName_MatchDefault &sipStrings_QtCore[46556]
#define sipNameNr_MatchExactly 46569
#define sipName_MatchExactly &sipStrings_QtCore[46569]
#define sipNameNr_MetaModifier 46582
#define sipName_MetaModifier &sipStrings_QtCore[46582]
#define sipNameNr_MetricSystem 46595
#define sipName_MetricSystem &sipStrings_QtCore[46595]
#define sipNameNr_MiddleButton 46608
#define sipName_MiddleButton &sipStrings_QtCore[46608]
#define sipNameNr_NarrowFormat 46621
#define sipName_NarrowFormat &sipStrings_QtCore[46621]
#define sipNameNr_NativeFormat 46634
#define sipName_NativeFormat &sipStrings_QtCore[46634]
#define sipNameNr_NauruCountry 46647
#define sipName_NauruCountry &sipStrings_QtCore[46647]
#define sipNameNr_NewCaledonia 46660
#define sipName_NewCaledonia &sipStrings_QtCore[46660]
#define sipNameNr_NoPreference 46673
#define sipName_NoPreference &sipStrings_QtCore[46673]
#define sipNameNr_NonRecursive 46686
#define sipName_NonRecursive &sipStrings_QtCore[46686]
#define sipNameNr_NorthNdebele 46699
#define sipName_NorthNdebele &sipStrings_QtCore[46699]
#define sipNameNr_NorthernLuri 46712
#define sipName_NorthernLuri &sipStrings_QtCore[46712]
#define sipNameNr_NorthernSami 46725
#define sipName_NorthernSami &sipStrings_QtCore[46725]
#define sipNameNr_NumberOption 14348
#define sipName_NumberOption &sipStrings_QtCore[14348]
#define sipNameNr_OSXElCapitan 46738
#define sipName_OSXElCapitan &sipStrings_QtCore[46738]
#define sipNameNr_OSXMavericks 46751
#define sipName_OSXMavericks &sipStrings_QtCore[46751]
#define sipNameNr_OpenModeFlag 5737
#define sipName_OpenModeFlag &sipStrings_QtCore[5737]
#define sipNameNr_OrkhonScript 46764
#define sipName_OrkhonScript &sipStrings_QtCore[46764]
#define sipNameNr_OutInElastic 46777
#define sipName_OutInElastic &sipStrings_QtCore[46777]
#define sipNameNr_PYQT_VERSION 46790
#define sipName_PYQT_VERSION &sipStrings_QtCore[46790]
#define sipNameNr_ParentChange 46803
#define sipName_ParentChange &sipStrings_QtCore[46803]
#define sipNameNr_PenJoinStyle 29221
#define sipName_PenJoinStyle &sipStrings_QtCore[29221]
#define sipNameNr_PinchGesture 46816
#define sipName_PinchGesture &sipStrings_QtCore[46816]
#define sipNameNr_PreciseTimer 46829
#define sipName_PreciseTimer &sipStrings_QtCore[46829]
#define sipNameNr_PreferBefore 46842
#define sipName_PreferBefore &sipStrings_QtCore[46842]
#define sipNameNr_PreferDither 46855
#define sipName_PreferDither &sipStrings_QtCore[46855]
#define sipNameNr_ProcessError 12499
#define sipName_ProcessError &sipStrings_QtCore[12499]
#define sipNameNr_ProcessState 12522
#define sipName_ProcessState &sipStrings_QtCore[12522]
#define sipNameNr_PyQt6_QtCore 46868
#define sipName_PyQt6_QtCore &sipStrings_QtCore[46868]
#define sipNameNr_QDir__Filter 46881
#define sipName_QDir__Filter &sipStrings_QtCore[46881]
#define sipNameNr_QDirIterator 46894
#define sipName_QDirIterator &sipStrings_QtCore[46894]
#define sipNameNr_QEasingCurve 46907
#define sipName_QEasingCurve &sipStrings_QtCore[46907]
#define sipNameNr_QEvent__Type 46920
#define sipName_QEvent__Type &sipStrings_QtCore[46920]
#define sipNameNr_QKeySequence 46933
#define sipName_QKeySequence &sipStrings_QtCore[46933]
#define sipNameNr_QLibraryInfo 46946
#define sipName_QLibraryInfo &sipStrings_QtCore[46946]
#define sipNameNr_46959 46959
#define sipName_46959 &sipStrings_QtCore[46959]
#define sipNameNr_46972 46972
#define sipName_46972 &sipStrings_QtCore[46972]
#define sipNameNr_QMutexLocker 46985
#define sipName_QMutexLocker &sipStrings_QtCore[46985]
#define sipNameNr_QStorageInfo 46998
#define sipName_QStorageInfo &sipStrings_QtCore[46998]
#define sipNameNr_QVariantHash 27519
#define sipName_QVariantHash &sipStrings_QtCore[27519]
#define sipNameNr_QVariantList 27537
#define sipName_QVariantList &sipStrings_QtCore[27537]
#define sipNameNr_QVariantPair 47011
#define sipName_QVariantPair &sipStrings_QtCore[47011]
#define sipNameNr_QWriteLocker 47024
#define sipName_QWriteLocker &sipStrings_QtCore[47024]
#define sipNameNr_Q_RETURN_ARG 47037
#define sipName_Q_RETURN_ARG &sipStrings_QtCore[47037]
#define sipNameNr_Qt__FillRule 47050
#define sipName_Qt__FillRule &sipStrings_QtCore[47050]
#define sipNameNr_Qt__ItemFlag 47063
#define sipName_Qt__ItemFlag &sipStrings_QtCore[47063]
#define sipNameNr_Qt__MaskMode 47076
#define sipName_Qt__MaskMode &sipStrings_QtCore[47076]
#define sipNameNr_Qt__Modifier 47089
#define sipName_Qt__Modifier &sipStrings_QtCore[47089]
#define sipNameNr_Qt__PenStyle 47102
#define sipName_Qt__PenStyle &sipStrings_QtCore[47102]
#define sipNameNr_Qt__SizeHint 47115
#define sipName_Qt__SizeHint &sipStrings_QtCore[47115]
#define sipNameNr_Qt__SizeMode 47128
#define sipName_Qt__SizeMode &sipStrings_QtCore[47128]
#define sipNameNr_Qt__TextFlag 47141
#define sipName_Qt__TextFlag &sipStrings_QtCore[47141]
#define sipNameNr_Qt__TileRule 47154
#define sipName_Qt__TileRule &sipStrings_QtCore[47154]
#define sipNameNr_Qt__TimeSpec 47167
#define sipName_Qt__TimeSpec &sipStrings_QtCore[47167]
#define sipNameNr_Qt__UIEffect 47180
#define sipName_Qt__UIEffect &sipStrings_QtCore[47180]
#define sipNameNr_QtWarningMsg 47193
#define sipName_QtWarningMsg &sipStrings_QtCore[47193]
#define sipNameNr_RejangScript 47206
#define sipName_RejangScript &sipStrings_QtCore[47206]
#define sipNameNr_RelativeSize 47219
#define sipName_RelativeSize &sipStrings_QtCore[47219]
#define sipNameNr_RemoveScheme 47232
#define sipName_RemoveScheme &sipStrings_QtCore[47232]
#define sipNameNr_RightSection 20925
#define sipName_RightSection &sipStrings_QtCore[20925]
#define sipNameNr_Script_Adlam 47245
#define sipName_Script_Adlam &sipStrings_QtCore[47245]
#define sipNameNr_Script_Bamum 47258
#define sipName_Script_Bamum &sipStrings_QtCore[47258]
#define sipNameNr_Script_Batak 47271
#define sipName_Script_Batak &sipStrings_QtCore[47271]
#define sipNameNr_Script_Buhid 47284
#define sipName_Script_Buhid &sipStrings_QtCore[47284]
#define sipNameNr_Script_Dogra 47297
#define sipName_Script_Dogra &sipStrings_QtCore[47297]
#define sipNameNr_Script_Garay 47310
#define sipName_Script_Garay &sipStrings_QtCore[47310]
#define sipNameNr_Script_Greek 47323
#define sipName_Script_Greek &sipStrings_QtCore[47323]
#define sipNameNr_Script_Khmer 47336
#define sipName_Script_Khmer &sipStrings_QtCore[47336]
#define sipNameNr_Script_Latin 47349
#define sipName_Script_Latin &sipStrings_QtCore[47349]
#define sipNameNr_Script_Limbu 47362
#define sipName_Script_Limbu &sipStrings_QtCore[47362]
#define sipNameNr_Script_Nushu 47375
#define sipName_Script_Nushu &sipStrings_QtCore[47375]
#define sipNameNr_Script_Ogham 47388
#define sipName_Script_Ogham &sipStrings_QtCore[47388]
#define sipNameNr_Script_Oriya 47401
#define sipName_Script_Oriya &sipStrings_QtCore[47401]
#define sipNameNr_Script_Osage 47414
#define sipName_Script_Osage &sipStrings_QtCore[47414]
#define sipNameNr_Script_Runic 47427
#define sipName_Script_Runic &sipStrings_QtCore[47427]
#define sipNameNr_Script_TaiLe 47440
#define sipName_Script_TaiLe &sipStrings_QtCore[47440]
#define sipNameNr_Script_TaiYo 47453
#define sipName_Script_TaiYo &sipStrings_QtCore[47453]
#define sipNameNr_Script_Takri 47466
#define sipName_Script_Takri &sipStrings_QtCore[47466]
#define sipNameNr_Script_Tamil 47479
#define sipName_Script_Tamil &sipStrings_QtCore[47479]
#define sipNameNr_ScrollUpdate 47492
#define sipName_ScrollUpdate &sipStrings_QtCore[47492]
#define sipNameNr_SettingsPath 47505
#define sipName_SettingsPath &sipStrings_QtCore[47505]
#define sipNameNr_ShowToParent 47518
#define sipName_ShowToParent &sipStrings_QtCore[47518]
#define sipNameNr_SizeHintRole 47531
#define sipName_SizeHintRole &sipStrings_QtCore[47531]
#define sipNameNr_SolidPattern 47544
#define sipName_SolidPattern &sipStrings_QtCore[47544]
#define sipNameNr_SouthNdebele 47557
#define sipName_SouthNdebele &sipStrings_QtCore[47557]
#define sipNameNr_SouthernSami 47570
#define sipName_SouthernSami &sipStrings_QtCore[47570]
#define sipNameNr_SplashScreen 47583
#define sipName_SplashScreen &sipStrings_QtCore[47583]
#define sipNameNr_SplitHCursor 47596
#define sipName_SplitHCursor &sipStrings_QtCore[47596]
#define sipNameNr_SplitVCursor 47609
#define sipName_SplitVCursor &sipStrings_QtCore[47609]
#define sipNameNr_StandardTime 47622
#define sipName_StandardTime &sipStrings_QtCore[47622]
#define sipNameNr_StartElement 17921
#define sipName_StartElement &sipStrings_QtCore[17921]
#define sipNameNr_StringFormat 19294
#define sipName_StringFormat &sipStrings_QtCore[19294]
#define sipNameNr_SvgMiterJoin 47635
#define sipName_SvgMiterJoin &sipStrings_QtCore[47635]
#define sipNameNr_SwipeGesture 47648
#define sipName_SwipeGesture &sipStrings_QtCore[47648]
#define sipNameNr_SyriacScript 47661
#define sipName_SyriacScript &sipStrings_QtCore[47661]
#define sipNameNr_TagSeparator 14370
#define sipName_TagSeparator &sipStrings_QtCore[14370]
#define sipNameNr_TangutScript 47674
#define sipName_TangutScript &sipStrings_QtCore[47674]
#define sipNameNr_TeluguScript 47687
#define sipName_TeluguScript &sipStrings_QtCore[47687]
#define sipNameNr_TempLocation 47700
#define sipName_TempLocation &sipStrings_QtCore[47700]
#define sipNameNr_TextDontClip 47713
#define sipName_TextDontClip &sipStrings_QtCore[47713]
#define sipNameNr_TextEditable 47726
#define sipName_TextEditable &sipStrings_QtCore[47726]
#define sipNameNr_TextWordWrap 47739
#define sipName_TextWordWrap &sipStrings_QtCore[47739]
#define sipNameNr_ThaanaScript 47752
#define sipName_ThaanaScript &sipStrings_QtCore[47752]
#define sipNameNr_ThreadChange 47765
#define sipName_ThreadChange &sipStrings_QtCore[47765]
#define sipNameNr_TimeOutError 47778
#define sipName_TimeOutError &sipStrings_QtCore[47778]
#define sipNameNr_TitleBarArea 47791
#define sipName_TitleBarArea &sipStrings_QtCore[47791]
#define sipNameNr_TolerantMode 47804
#define sipName_TolerantMode &sipStrings_QtCore[47804]
#define sipNameNr_Turkmenistan 47817
#define sipName_Turkmenistan &sipStrings_QtCore[47817]
#define sipNameNr_Undetermined 47830
#define sipName_Undetermined &sipStrings_QtCore[47830]
#define sipNameNr_UnitedStates 47843
#define sipName_UnitedStates &sipStrings_QtCore[47843]
#define sipNameNr_UnknownError 47856
#define sipName_UnknownError &sipStrings_QtCore[47856]
#define sipNameNr_UpperSorbian 47869
#define sipName_UpperSorbian &sipStrings_QtCore[47869]
#define sipNameNr_WA_SetCursor 47882
#define sipName_WA_SetCursor &sipStrings_QtCore[47882]
#define sipNameNr_WA_SetLocale 47895
#define sipName_WA_SetLocale &sipStrings_QtCore[47895]
#define sipNameNr_WindowActive 47908
#define sipName_WindowActive &sipStrings_QtCore[47908]
#define sipNameNr_YearMonthDay 10568
#define sipName_YearMonthDay &sipStrings_QtCore[10568]
#define sipNameNr_ZOrderChange 47921
#define sipName_ZOrderChange &sipStrings_QtCore[47921]
#define sipNameNr___contains__ 47934
#define sipName___contains__ &sipStrings_QtCore[47934]
#define sipNameNr___itruediv__ 47947
#define sipName___itruediv__ &sipStrings_QtCore[47947]
#define sipNameNr_abbreviation 47960
#define sipName_abbreviation &sipStrings_QtCore[47960]
#define sipNameNr_aboutToBlock 47973
#define sipName_aboutToBlock &sipStrings_QtCore[47973]
#define sipNameNr_aboutToClose 47986
#define sipName_aboutToClose &sipStrings_QtCore[47986]
#define sipNameNr_absolutePath 47999
#define sipName_absolutePath &sipStrings_QtCore[47999]
#define sipNameNr_addAnimation 48012
#define sipName_addAnimation &sipStrings_QtCore[48012]
#define sipNameNr_addQueryItem 48025
#define sipName_addQueryItem &sipStrings_QtCore[48025]
#define sipNameNr_allAncestors 48038
#define sipName_allAncestors &sipStrings_QtCore[48038]
#define sipNameNr_allMimeTypes 48051
#define sipName_allMimeTypes &sipStrings_QtCore[48051]
#define sipNameNr_allSelectors 48064
#define sipName_allSelectors &sipStrings_QtCore[48064]
#define sipNameNr_availability 48077
#define sipName_availability &sipStrings_QtCore[48077]
#define sipNameNr_blockSignals 48090
#define sipName_blockSignals &sipStrings_QtCore[48090]
#define sipNameNr_bootUniqueId 48103
#define sipName_bootUniqueId &sipStrings_QtCore[48103]
#define sipNameNr_bytesToWrite 48116
#define sipName_bytesToWrite &sipStrings_QtCore[48116]
#define sipNameNr_bytesWritten 48129
#define sipName_bytesWritten &sipStrings_QtCore[48129]
#define sipNameNr_canFetchMore 48142
#define sipName_canFetchMore &sipStrings_QtCore[48142]
#define sipNameNr_captureCount 48155
#define sipName_captureCount &sipStrings_QtCore[48155]
#define sipNameNr_categoryName 48168
#define sipName_categoryName &sipStrings_QtCore[48168]
#define sipNameNr_codeToScript 48181
#define sipName_codeToScript &sipStrings_QtCore[48181]
#define sipNameNr_columnNumber 48194
#define sipName_columnNumber &sipStrings_QtCore[48194]
#define sipNameNr_columnsMoved 48207
#define sipName_columnsMoved &sipStrings_QtCore[48207]
#define sipNameNr_commonPrefix 48220
#define sipName_commonPrefix &sipStrings_QtCore[48220]
#define sipNameNr_createUuidV3 48233
#define sipName_createUuidV3 &sipStrings_QtCore[48233]
#define sipNameNr_createUuidV5 48246
#define sipName_createUuidV5 &sipStrings_QtCore[48246]
#define sipNameNr_createUuidV7 48259
#define sipName_createUuidV7 &sipStrings_QtCore[48259]
#define sipNameNr_currentFrame 48272
#define sipName_currentFrame &sipStrings_QtCore[48272]
#define sipNameNr_currentIndex 48285
#define sipName_currentIndex &sipStrings_QtCore[48285]
#define sipNameNr_currentValue 48298
#define sipName_currentValue &sipStrings_QtCore[48298]
#define sipNameNr_decimalPoint 48311
#define sipName_decimalPoint &sipStrings_QtCore[48311]
#define sipNameNr_defaultValue 48324
#define sipName_defaultValue &sipStrings_QtCore[48324]
#define sipNameNr_dropMimeData 48337
#define sipName_dropMimeData &sipStrings_QtCore[48337]
#define sipNameNr_fileTemplate 48350
#define sipName_fileTemplate &sipStrings_QtCore[48350]
#define sipNameNr_filterString 48363
#define sipName_filterString &sipStrings_QtCore[48363]
#define sipNameNr_findChildren 48376
#define sipName_findChildren &sipStrings_QtCore[48376]
#define sipNameNr_frameChanged 48389
#define sipName_frameChanged &sipStrings_QtCore[48389]
#define sipNameNr_frameForTime 48402
#define sipName_frameForTime &sipStrings_QtCore[48402]
#define sipNameNr_fromCombined 48415
#define sipName_fromCombined &sipStrings_QtCore[48415]
#define sipNameNr_fromWildcard 48428
#define sipName_fromWildcard &sipStrings_QtCore[48428]
#define sipNameNr_globPatterns 48441
#define sipName_globPatterns &sipStrings_QtCore[48441]
#define sipNameNr_hasAttribute 48454
#define sipName_hasAttribute &sipStrings_QtCore[48454]
#define sipNameNr_hasQueryItem 48467
#define sipName_hasQueryItem &sipStrings_QtCore[48467]
#define sipNameNr_hasSelection 48480
#define sipName_hasSelection &sipStrings_QtCore[48480]
#define sipNameNr_hasStdCppSet 48493
#define sipName_hasStdCppSet &sipStrings_QtCore[48493]
#define sipNameNr_idnWhitelist 48506
#define sipName_idnWhitelist &sipStrings_QtCore[48506]
#define sipNameNr_initialValue 48519
#define sipName_initialValue &sipStrings_QtCore[48519]
#define sipNameNr_insertColumn 48532
#define sipName_insertColumn &sipStrings_QtCore[48532]
#define sipNameNr_interpolated 48545
#define sipName_interpolated &sipStrings_QtCore[48545]
#define sipNameNr_invokeMethod 48558
#define sipName_invokeMethod &sipStrings_QtCore[48558]
#define sipNameNr_isAtBoundary 48571
#define sipName_isAtBoundary &sipStrings_QtCore[48571]
#define sipNameNr_isCharacters 48584
#define sipName_isCharacters &sipStrings_QtCore[48584]
#define sipNameNr_isDebugBuild 48597
#define sipName_isDebugBuild &sipStrings_QtCore[48597]
#define sipNameNr_isDesignable 48610
#define sipName_isDesignable &sipStrings_QtCore[48610]
#define sipNameNr_isEndElement 48623
#define sipName_isEndElement &sipStrings_QtCore[48623]
#define sipNameNr_isExecutable 48636
#define sipName_isExecutable &sipStrings_QtCore[48636]
#define sipNameNr_isInputEvent 48649
#define sipName_isInputEvent &sipStrings_QtCore[48649]
#define sipNameNr_isMainThread 48662
#define sipName_isMainThread &sipStrings_QtCore[48662]
#define sipNameNr_isNativePath 48675
#define sipName_isNativePath &sipStrings_QtCore[48675]
#define sipNameNr_isNormalized 48688
#define sipName_isNormalized &sipStrings_QtCore[48688]
#define sipNameNr_isQmlExposed 48701
#define sipName_isQmlExposed &sipStrings_QtCore[48701]
#define sipNameNr_isRegistered 48714
#define sipName_isRegistered &sipStrings_QtCore[48714]
#define sipNameNr_isResettable 48727
#define sipName_isResettable &sipStrings_QtCore[48727]
#define sipNameNr_isScriptable 48740
#define sipName_isScriptable &sipStrings_QtCore[48740]
#define sipNameNr_isSequential 48753
#define sipName_isSequential &sipStrings_QtCore[48753]
#define sipNameNr_isSimpleType 48766
#define sipName_isSimpleType &sipStrings_QtCore[48766]
#define sipNameNr_isSingleShot 48779
#define sipName_isSingleShot &sipStrings_QtCore[48779]
#define sipNameNr_isWhitespace 48792
#define sipName_isWhitespace &sipStrings_QtCore[48792]
#define sipNameNr_isWidgetType 48805
#define sipName_isWidgetType &sipStrings_QtCore[48805]
#define sipNameNr_isWindowType 48818
#define sipName_isWindowType &sipStrings_QtCore[48818]
#define sipNameNr_lastModified 48831
#define sipName_lastModified &sipStrings_QtCore[48831]
#define sipNameNr_libraryPaths 48844
#define sipName_libraryPaths &sipStrings_QtCore[48844]
#define sipNameNr_loadFromData 48857
#define sipName_loadFromData &sipStrings_QtCore[48857]
#define sipNameNr_lockForWrite 48870
#define sipName_lockForWrite &sipStrings_QtCore[48870]
#define sipNameNr_majorVersion 48883
#define sipName_majorVersion &sipStrings_QtCore[48883]
#define sipNameNr_makeAbsolute 48896
#define sipName_makeAbsolute &sipStrings_QtCore[48896]
#define sipNameNr_mappedObject 48909
#define sipName_mappedObject &sipStrings_QtCore[48909]
#define sipNameNr_mappedString 48922
#define sipName_mappedString &sipStrings_QtCore[48922]
#define sipNameNr_marginsAdded 48935
#define sipName_marginsAdded &sipStrings_QtCore[48935]
#define sipNameNr_matchOptions 48948
#define sipName_matchOptions &sipStrings_QtCore[48948]
#define sipNameNr_maxRecursion 48961
#define sipName_maxRecursion &sipStrings_QtCore[48961]
#define sipNameNr_methodOffset 48974
#define sipName_methodOffset &sipStrings_QtCore[48974]
#define sipNameNr_microVersion 48987
#define sipName_microVersion &sipStrings_QtCore[48987]
#define sipNameNr_milliseconds 8887
#define sipName_milliseconds &sipStrings_QtCore[8887]
#define sipNameNr_minorVersion 49000
#define sipName_minorVersion &sipStrings_QtCore[49000]
#define sipNameNr_modelChanged 49013
#define sipName_modelChanged &sipStrings_QtCore[49013]
#define sipNameNr_monthsInYear 49026
#define sipName_monthsInYear &sipStrings_QtCore[49026]
#define sipNameNr_moveToThread 49039
#define sipName_moveToThread &sipStrings_QtCore[49039]
#define sipNameNr_moveTopRight 49052
#define sipName_moveTopRight &sipStrings_QtCore[49052]
#define sipNameNr_namespaceUri 49065
#define sipName_namespaceUri &sipStrings_QtCore[49065]
#define sipNameNr_nativeIpcKey 49078
#define sipName_nativeIpcKey &sipStrings_QtCore[49078]
#define sipNameNr_negativeSign 49091
#define sipName_negativeSign &sipStrings_QtCore[49091]
#define sipNameNr_nextFileInfo 49104
#define sipName_nextFileInfo &sipStrings_QtCore[49104]
#define sipNameNr_noforcepoint 49117
#define sipName_noforcepoint &sipStrings_QtCore[49117]
#define sipNameNr_normalVector 49130
#define sipName_normalVector &sipStrings_QtCore[49130]
#define sipNameNr_notationName 49143
#define sipName_notationName &sipStrings_QtCore[49143]
#define sipNameNr_notifySignal 49156
#define sipName_notifySignal &sipStrings_QtCore[49156]
#define sipNameNr_nsecsElapsed 49169
#define sipName_nsecsElapsed &sipStrings_QtCore[49169]
#define sipNameNr_positiveSign 49182
#define sipName_positiveSign &sipStrings_QtCore[49182]
#define sipNameNr_propertyName 49195
#define sipName_propertyName &sipStrings_QtCore[49195]
#define sipNameNr_qFuzzyIsNull 49208
#define sipName_qFuzzyIsNull &sipStrings_QtCore[49208]
#define sipNameNr_readLineData 49221
#define sipName_readLineData &sipStrings_QtCore[49221]
#define sipNameNr_readLineInto 49234
#define sipName_readLineInto &sipStrings_QtCore[49234]
#define sipNameNr_readQVariant 49247
#define sipName_readQVariant &sipStrings_QtCore[49247]
#define sipNameNr_registerType 49260
#define sipName_registerType &sipStrings_QtCore[49260]
#define sipNameNr_removeColumn 49273
#define sipName_removeColumn &sipStrings_QtCore[49273]
#define sipNameNr_removeFormat 49286
#define sipName_removeFormat &sipStrings_QtCore[49286]
#define sipNameNr_retrieveData 49299
#define sipName_retrieveData &sipStrings_QtCore[49299]
#define sipNameNr_rowsInserted 49312
#define sipName_rowsInserted &sipStrings_QtCore[49312]
#define sipNameNr_scriptToCode 49325
#define sipName_scriptToCode &sipStrings_QtCore[49325]
#define sipNameNr_segmentCount 49338
#define sipName_segmentCount &sipStrings_QtCore[49338]
#define sipNameNr_selectedRows 49351
#define sipName_selectedRows &sipStrings_QtCore[49351]
#define sipNameNr_serviceLevel 49364
#define sipName_serviceLevel &sipStrings_QtCore[49364]
#define sipNameNr_setAmplitude 49377
#define sipName_setAmplitude &sipStrings_QtCore[49377]
#define sipNameNr_setArguments 49390
#define sipName_setArguments &sipStrings_QtCore[49390]
#define sipNameNr_setAttribute 49403
#define sipName_setAttribute &sipStrings_QtCore[49403]
#define sipNameNr_setAuthority 49416
#define sipName_setAuthority &sipStrings_QtCore[49416]
#define sipNameNr_setByteOrder 49429
#define sipName_setByteOrder &sipStrings_QtCore[49429]
#define sipNameNr_setColorData 49442
#define sipName_setColorData &sipStrings_QtCore[49442]
#define sipNameNr_setDirection 49455
#define sipName_setDirection &sipStrings_QtCore[49455]
#define sipNameNr_setImageData 49468
#define sipName_setImageData &sipStrings_QtCore[49468]
#define sipNameNr_setKeyValues 49481
#define sipName_setKeyValues &sipStrings_QtCore[49481]
#define sipNameNr_setLoadHints 49494
#define sipName_setLoadHints &sipStrings_QtCore[49494]
#define sipNameNr_setLoopCount 49507
#define sipName_setLoopCount &sipStrings_QtCore[49507]
#define sipNameNr_setNativeKey 49520
#define sipName_setNativeKey &sipStrings_QtCore[49520]
#define sipNameNr_setOvershoot 49533
#define sipName_setOvershoot &sipStrings_QtCore[49533]
#define sipNameNr_setRoleNames 39962
#define sipName_setRoleNames &sipStrings_QtCore[39962]
#define sipNameNr_setStackSize 49546
#define sipName_setStackSize &sipStrings_QtCore[49546]
#define sipNameNr_setTimerType 49559
#define sipName_setTimerType &sipStrings_QtCore[49559]
#define sipNameNr_setValueName 49572
#define sipName_setValueName &sipStrings_QtCore[49572]
#define sipNameNr_siblingAtRow 49585
#define sipName_siblingAtRow &sipStrings_QtCore[49585]
#define sipNameNr_sourceModels 49598
#define sipName_sourceModels &sipStrings_QtCore[49598]
#define sipNameNr_startCommand 49611
#define sipName_startCommand &sipStrings_QtCore[49611]
#define sipNameNr_stateChanged 49624
#define sipName_stateChanged &sipStrings_QtCore[49624]
#define sipNameNr_targetObject 49637
#define sipName_targetObject &sipStrings_QtCore[49637]
#define sipNameNr_toPyDateTime 49650
#define sipName_toPyDateTime &sipStrings_QtCore[49650]
#define sipNameNr_toSimpleType 49663
#define sipName_toSimpleType &sipStrings_QtCore[49663]
#define sipNameNr_toStringList 49676
#define sipName_toStringList &sipStrings_QtCore[49676]
#define sipNameNr_userProperty 49689
#define sipName_userProperty &sipStrings_QtCore[49689]
#define sipNameNr_valueChanged 49702
#define sipName_valueChanged &sipStrings_QtCore[49702]
#define sipNameNr_valueForTime 49715
#define sipName_valueForTime &sipStrings_QtCore[49715]
#define sipNameNr_writeComment 49728
#define sipName_writeComment &sipStrings_QtCore[49728]
#define sipNameNr_writeQString 49741
#define sipName_writeQString &sipStrings_QtCore[49741]
#define sipNameNr_writeRawData 49754
#define sipName_writeRawData &sipStrings_QtCore[49754]
#define sipNameNr_AA_Use96Dpi 49767
#define sipName_AA_Use96Dpi &sipStrings_QtCore[49767]
#define sipNameNr_AccessError 49779
#define sipName_AccessError &sipStrings_QtCore[49779]
#define sipNameNr_ActionAdded 49791
#define sipName_ActionAdded &sipStrings_QtCore[49791]
#define sipNameNr_AdlamScript 49803
#define sipName_AdlamScript &sipStrings_QtCore[49803]
#define sipNameNr_Afghanistan 49815
#define sipName_Afghanistan &sipStrings_QtCore[49815]
#define sipNameNr_AlignBottom 49827
#define sipName_AlignBottom &sipStrings_QtCore[49827]
#define sipNameNr_AlignCenter 49839
#define sipName_AlignCenter &sipStrings_QtCore[49839]
#define sipNameNr_AltModifier 49851
#define sipName_AltModifier &sipStrings_QtCore[49851]
#define sipNameNr_AnchorPoint 32875
#define sipName_AnchorPoint &sipStrings_QtCore[32875]
#define sipNameNr_AnchorRight 49863
#define sipName_AnchorRight &sipStrings_QtCore[49863]
#define sipNameNr_AndroidOreo 49875
#define sipName_AndroidOreo &sipStrings_QtCore[49875]
#define sipNameNr_AnyLanguage 49887
#define sipName_AnyLanguage &sipStrings_QtCore[49887]
#define sipNameNr_Approximate 49899
#define sipName_Approximate &sipStrings_QtCore[49899]
#define sipNameNr_ArrowCursor 43478
#define sipName_ArrowCursor &sipStrings_QtCore[43478]
#define sipNameNr_AvoidDither 49911
#define sipName_AvoidDither &sipStrings_QtCore[49911]
#define sipNameNr_Azerbaijani 49923
#define sipName_Azerbaijani &sipStrings_QtCore[49923]
#define sipNameNr_BamumScript 49935
#define sipName_BamumScript &sipStrings_QtCore[49935]
#define sipNameNr_BatakScript 49947
#define sipName_BatakScript &sipStrings_QtCore[49947]
#define sipNameNr_Blake2b_160 49959
#define sipName_Blake2b_160 &sipStrings_QtCore[49959]
#define sipNameNr_Blake2b_256 49971
#define sipName_Blake2b_256 &sipStrings_QtCore[49971]
#define sipNameNr_Blake2b_384 49983
#define sipName_Blake2b_384 &sipStrings_QtCore[49983]
#define sipNameNr_Blake2b_512 49995
#define sipName_Blake2b_512 &sipStrings_QtCore[49995]
#define sipNameNr_Blake2s_128 50007
#define sipName_Blake2s_128 &sipStrings_QtCore[50007]
#define sipNameNr_Blake2s_160 50019
#define sipName_Blake2s_160 &sipStrings_QtCore[50019]
#define sipNameNr_Blake2s_224 50031
#define sipName_Blake2s_224 &sipStrings_QtCore[50031]
#define sipNameNr_Blake2s_256 50043
#define sipName_Blake2s_256 &sipStrings_QtCore[50043]
#define sipNameNr_BlankCursor 50055
#define sipName_BlankCursor &sipStrings_QtCore[50055]
#define sipNameNr_BuhidScript 50067
#define sipName_BuhidScript &sipStrings_QtCore[50067]
#define sipNameNr_BurkinaFaso 50079
#define sipName_BurkinaFaso &sipStrings_QtCore[50079]
#define sipNameNr_CoarseTimer 33787
#define sipName_CoarseTimer &sipStrings_QtCore[33787]
#define sipNameNr_ColorScheme 32891
#define sipName_ColorScheme &sipStrings_QtCore[32891]
#define sipNameNr_Compression 9638
#define sipName_Compression &sipStrings_QtCore[9638]
#define sipNameNr_Constructor 23187
#define sipName_Constructor &sipStrings_QtCore[23187]
#define sipNameNr_ContextMenu 9063
#define sipName_ContextMenu &sipStrings_QtCore[9063]
#define sipNameNr_CookIslands 50091
#define sipName_CookIslands &sipStrings_QtCore[50091]
#define sipNameNr_CosineCurve 50103
#define sipName_CosineCurve &sipStrings_QtCore[50103]
#define sipNameNr_CoverWindow 50115
#define sipName_CoverWindow &sipStrings_QtCore[50115]
#define sipNameNr_CrossCursor 50127
#define sipName_CrossCursor &sipStrings_QtCore[50127]
#define sipNameNr_CursorShape 32907
#define sipName_CursorShape &sipStrings_QtCore[32907]
#define sipNameNr_CustomError 50139
#define sipName_CustomError &sipStrings_QtCore[50139]
#define sipNameNr_DashDotLine 50151
#define sipName_DashDotLine &sipStrings_QtCore[50151]
#define sipNameNr_DecodedMode 50163
#define sipName_DecodedMode &sipStrings_QtCore[50163]
#define sipNameNr_DeepNesting 50175
#define sipName_DeepNesting &sipStrings_QtCore[50175]
#define sipNameNr_DefaultName 50187
#define sipName_DefaultName &sipStrings_QtCore[50187]
#define sipNameNr_DiegoGarcia 50199
#define sipName_DiegoGarcia &sipStrings_QtCore[50199]
#define sipNameNr_DisplayRole 50211
#define sipName_DisplayRole &sipStrings_QtCore[50211]
#define sipNameNr_ElideMiddle 50223
#define sipName_ElideMiddle &sipStrings_QtCore[50223]
#define sipNameNr_EncodedCbor 50235
#define sipName_EncodedCbor &sipStrings_QtCore[50235]
#define sipNameNr_EndDocument 31160
#define sipName_EndDocument &sipStrings_QtCore[31160]
#define sipNameNr_EndOfString 50247
#define sipName_EndOfString &sipStrings_QtCore[50247]
#define sipNameNr_FocusPolicy 32923
#define sipName_FocusPolicy &sipStrings_QtCore[32923]
#define sipNameNr_FocusReason 10233
#define sipName_FocusReason &sipStrings_QtCore[10233]
#define sipNameNr_FormatError 50259
#define sipName_FormatError &sipStrings_QtCore[50259]
#define sipNameNr_GenericTime 50271
#define sipName_GenericTime &sipStrings_QtCore[50271]
#define sipNameNr_GestureFlag 32955
#define sipName_GestureFlag &sipStrings_QtCore[32955]
#define sipNameNr_GestureType 14569
#define sipName_GestureType &sipStrings_QtCore[14569]
#define sipNameNr_GlobalColor 32987
#define sipName_GlobalColor &sipStrings_QtCore[32987]
#define sipNameNr_GreekScript 50283
#define sipName_GreekScript &sipStrings_QtCore[50283]
#define sipNameNr_Greenlandic 50295
#define sipName_Greenlandic &sipStrings_QtCore[50295]
#define sipNameNr_HeadersPath 50307
#define sipName_HeadersPath &sipStrings_QtCore[50307]
#define sipNameNr_IBeamCursor 50319
#define sipName_IBeamCursor &sipStrings_QtCore[50319]
#define sipNameNr_ISO639Part1 50331
#define sipName_ISO639Part1 &sipStrings_QtCore[50331]
#define sipNameNr_ISO639Part2 50343
#define sipName_ISO639Part2 &sipStrings_QtCore[50343]
#define sipNameNr_ISO639Part3 50355
#define sipName_ISO639Part3 &sipStrings_QtCore[50355]
#define sipNameNr_IllegalType 50367
#define sipName_IllegalType &sipStrings_QtCore[50367]
#define sipNameNr_InOutBounce 50379
#define sipName_InOutBounce &sipStrings_QtCore[50379]
#define sipNameNr_Information 50391
#define sipName_Information &sipStrings_QtCore[50391]
#define sipNameNr_InputMethod 50403
#define sipName_InputMethod &sipStrings_QtCore[50403]
#define sipNameNr_Interlingua 50415
#define sipName_Interlingua &sipStrings_QtCore[50415]
#define sipNameNr_Interlingue 50427
#define sipName_Interlingue &sipStrings_QtCore[50427]
#define sipNameNr_InvalidSize 38628
#define sipName_InvalidSize &sipStrings_QtCore[38628]
#define sipNameNr_Kalaallisut 50439
#define sipName_Kalaallisut &sipStrings_QtCore[50439]
#define sipNameNr_Key_Backtab 50451
#define sipName_Key_Backtab &sipStrings_QtCore[50451]
#define sipNameNr_Key_Battery 50463
#define sipName_Key_Battery &sipStrings_QtCore[50463]
#define sipNameNr_Key_Control 50475
#define sipName_Key_Control &sipStrings_QtCore[50475]
#define sipNameNr_Key_Display 50487
#define sipName_Key_Display &sipStrings_QtCore[50487]
#define sipNameNr_Key_Execute 50499
#define sipName_Key_Execute &sipStrings_QtCore[50499]
#define sipNameNr_Key_Finance 50511
#define sipName_Key_Finance &sipStrings_QtCore[50511]
#define sipNameNr_Key_Forward 50523
#define sipName_Key_Forward &sipStrings_QtCore[50523]
#define sipNameNr_Key_Greater 50535
#define sipName_Key_Greater &sipStrings_QtCore[50535]
#define sipNameNr_Key_Hankaku 50547
#define sipName_Key_Hankaku &sipStrings_QtCore[50547]
#define sipNameNr_Key_History 50559
#define sipName_Key_History &sipStrings_QtCore[50559]
#define sipNameNr_Key_Hyper_L 50571
#define sipName_Key_Hyper_L &sipStrings_QtCore[50571]
#define sipNameNr_Key_Hyper_R 50583
#define sipName_Key_Hyper_R &sipStrings_QtCore[50583]
#define sipNameNr_Key_Launch0 50595
#define sipName_Key_Launch0 &sipStrings_QtCore[50595]
#define sipNameNr_Key_Launch1 50607
#define sipName_Key_Launch1 &sipStrings_QtCore[50607]
#define sipNameNr_Key_Launch2 50619
#define sipName_Key_Launch2 &sipStrings_QtCore[50619]
#define sipNameNr_Key_Launch3 50631
#define sipName_Key_Launch3 &sipStrings_QtCore[50631]
#define sipNameNr_Key_Launch4 50643
#define sipName_Key_Launch4 &sipStrings_QtCore[50643]
#define sipNameNr_Key_Launch5 50655
#define sipName_Key_Launch5 &sipStrings_QtCore[50655]
#define sipNameNr_Key_Launch6 50667
#define sipName_Key_Launch6 &sipStrings_QtCore[50667]
#define sipNameNr_Key_Launch7 50679
#define sipName_Key_Launch7 &sipStrings_QtCore[50679]
#define sipNameNr_Key_Launch8 50691
#define sipName_Key_Launch8 &sipStrings_QtCore[50691]
#define sipNameNr_Key_Launch9 50703
#define sipName_Key_Launch9 &sipStrings_QtCore[50703]
#define sipNameNr_Key_LaunchA 50715
#define sipName_Key_LaunchA &sipStrings_QtCore[50715]
#define sipNameNr_Key_LaunchB 50727
#define sipName_Key_LaunchB &sipStrings_QtCore[50727]
#define sipNameNr_Key_LaunchC 50739
#define sipName_Key_LaunchC &sipStrings_QtCore[50739]
#define sipNameNr_Key_LaunchD 50751
#define sipName_Key_LaunchD &sipStrings_QtCore[50751]
#define sipNameNr_Key_LaunchE 50763
#define sipName_Key_LaunchE &sipStrings_QtCore[50763]
#define sipNameNr_Key_LaunchF 50775
#define sipName_Key_LaunchF &sipStrings_QtCore[50775]
#define sipNameNr_Key_LaunchG 50787
#define sipName_Key_LaunchG &sipStrings_QtCore[50787]
#define sipNameNr_Key_LaunchH 50799
#define sipName_Key_LaunchH &sipStrings_QtCore[50799]
#define sipNameNr_Key_Meeting 50811
#define sipName_Key_Meeting &sipStrings_QtCore[50811]
#define sipNameNr_Key_MicMute 50823
#define sipName_Key_MicMute &sipStrings_QtCore[50823]
#define sipNameNr_Key_MySites 50835
#define sipName_Key_MySites &sipStrings_QtCore[50835]
#define sipNameNr_Key_NumLock 50847
#define sipName_Key_NumLock &sipStrings_QtCore[50847]
#define sipNameNr_Key_OpenUrl 50859
#define sipName_Key_OpenUrl &sipStrings_QtCore[50859]
#define sipNameNr_Key_Percent 50871
#define sipName_Key_Percent &sipStrings_QtCore[50871]
#define sipNameNr_Key_Printer 50883
#define sipName_Key_Printer &sipStrings_QtCore[50883]
#define sipNameNr_Key_Refresh 50895
#define sipName_Key_Refresh &sipStrings_QtCore[50895]
#define sipNameNr_Key_Standby 50907
#define sipName_Key_Standby &sipStrings_QtCore[50907]
#define sipNameNr_Key_Super_L 50919
#define sipName_Key_Super_L &sipStrings_QtCore[50919]
#define sipNameNr_Key_Super_R 50931
#define sipName_Key_Super_R &sipStrings_QtCore[50931]
#define sipNameNr_Key_Support 50943
#define sipName_Key_Support &sipStrings_QtCore[50943]
#define sipNameNr_Key_Suspend 50955
#define sipName_Key_Suspend &sipStrings_QtCore[50955]
#define sipNameNr_Key_TopMenu 50967
#define sipName_Key_TopMenu &sipStrings_QtCore[50967]
#define sipNameNr_Key_Touroku 50979
#define sipName_Key_Touroku &sipStrings_QtCore[50979]
#define sipNameNr_Key_Zenkaku 50991
#define sipName_Key_Zenkaku &sipStrings_QtCore[50991]
#define sipNameNr_Key_ZoomOut 51003
#define sipName_Key_ZoomOut &sipStrings_QtCore[51003]
#define sipNameNr_Key_cedilla 51015
#define sipName_Key_cedilla &sipStrings_QtCore[51015]
#define sipNameNr_Key_notsign 51027
#define sipName_Key_notsign &sipStrings_QtCore[51027]
#define sipNameNr_Key_onehalf 51039
#define sipName_Key_onehalf &sipStrings_QtCore[51039]
#define sipNameNr_Key_section 51051
#define sipName_Key_section &sipStrings_QtCore[51051]
#define sipNameNr_Key_unknown 51063
#define sipName_Key_unknown &sipStrings_QtCore[51063]
#define sipNameNr_KhmerScript 51075
#define sipName_KhmerScript &sipStrings_QtCore[51075]
#define sipNameNr_Kinyarwanda 51087
#define sipName_Kinyarwanda &sipStrings_QtCore[51087]
#define sipNameNr_KoyraChiini 51099
#define sipName_KoyraChiini &sipStrings_QtCore[51099]
#define sipNameNr_LannaScript 51111
#define sipName_LannaScript &sipStrings_QtCore[51111]
#define sipNameNr_LastCountry 51123
#define sipName_LastCountry &sipStrings_QtCore[51123]
#define sipNameNr_LatinScript 51135
#define sipName_LatinScript &sipStrings_QtCore[51135]
#define sipNameNr_LeftSection 24244
#define sipName_LeftSection &sipStrings_QtCore[24244]
#define sipNameNr_LeftToRight 51147
#define sipName_LeftToRight &sipStrings_QtCore[51147]
#define sipNameNr_LibraryPath 8108
#define sipName_LibraryPath &sipStrings_QtCore[8108]
#define sipNameNr_LimbuScript 51159
#define sipName_LimbuScript &sipStrings_QtCore[51159]
#define sipNameNr_LocaleAware 23795
#define sipName_LocaleAware &sipStrings_QtCore[23795]
#define sipNameNr_LowPriority 51171
#define sipName_LowPriority &sipStrings_QtCore[51171]
#define sipNameNr_LubaKatanga 51183
#define sipName_LubaKatanga &sipStrings_QtCore[51183]
#define sipNameNr_MacOSBigSur 51195
#define sipName_MacOSBigSur &sipStrings_QtCore[51195]
#define sipNameNr_MacOSMojave 51207
#define sipName_MacOSMojave &sipStrings_QtCore[51207]
#define sipNameNr_MacOSSierra 51219
#define sipName_MacOSSierra &sipStrings_QtCore[51219]
#define sipNameNr_MacOSSonoma 51231
#define sipName_MacOSSonoma &sipStrings_QtCore[51231]
#define sipNameNr_Marshallese 51243
#define sipName_Marshallese &sipStrings_QtCore[51243]
#define sipNameNr_MaskInColor 51255
#define sipName_MaskInColor &sipStrings_QtCore[51255]
#define sipNameNr_MatchOption 2136
#define sipName_MatchOption &sipStrings_QtCore[2136]
#define sipNameNr_MaximumSize 51267
#define sipName_MaximumSize &sipStrings_QtCore[51267]
#define sipNameNr_Mazanderani 51279
#define sipName_Mazanderani &sipStrings_QtCore[51279]
#define sipNameNr_MendeScript 51291
#define sipName_MendeScript &sipStrings_QtCore[51291]
#define sipNameNr_MessageType 3131
#define sipName_MessageType &sipStrings_QtCore[3131]
#define sipNameNr_MimeMessage 51303
#define sipName_MimeMessage &sipStrings_QtCore[51303]
#define sipNameNr_MinimumSize 51315
#define sipName_MinimumSize &sipStrings_QtCore[51315]
#define sipNameNr_MouseButton 33003
#define sipName_MouseButton &sipStrings_QtCore[33003]
#define sipNameNr_Netherlands 16158
#define sipName_Netherlands &sipStrings_QtCore[16158]
#define sipNameNr_NoItemFlags 51327
#define sipName_NoItemFlags &sipStrings_QtCore[51327]
#define sipNameNr_NormalMatch 51339
#define sipName_NormalMatch &sipStrings_QtCore[51339]
#define sipNameNr_OSXYosemite 51351
#define sipName_OSXYosemite &sipStrings_QtCore[51351]
#define sipNameNr_OddEvenFill 51363
#define sipName_OddEvenFill &sipStrings_QtCore[51363]
#define sipNameNr_OghamScript 51375
#define sipName_OghamScript &sipStrings_QtCore[51375]
#define sipNameNr_Orientation 4335
#define sipName_Orientation &sipStrings_QtCore[4335]
#define sipNameNr_OriyaScript 51387
#define sipName_OriyaScript &sipStrings_QtCore[51387]
#define sipNameNr_OsageScript 51399
#define sipName_OsageScript &sipStrings_QtCore[51399]
#define sipNameNr_OutInBounce 51411
#define sipName_OutInBounce &sipStrings_QtCore[51411]
#define sipNameNr_ParsingMode 25342
#define sipName_ParsingMode &sipStrings_QtCore[25342]
#define sipNameNr_PassThrough 51423
#define sipName_PassThrough &sipStrings_QtCore[51423]
#define sipNameNr_PenCapStyle 33035
#define sipName_PenCapStyle &sipStrings_QtCore[33035]
#define sipNameNr_Philippines 51435
#define sipName_Philippines &sipStrings_QtCore[51435]
#define sipNameNr_PluginsPath 51447
#define sipName_PluginsPath &sipStrings_QtCore[51447]
#define sipNameNr_PreferAfter 51459
#define sipName_PreferAfter &sipStrings_QtCore[51459]
#define sipNameNr_QBasicTimer 51471
#define sipName_QBasicTimer &sipStrings_QtCore[51471]
#define sipNameNr_QChildEvent 51483
#define sipName_QChildEvent &sipStrings_QtCore[51483]
#define sipNameNr_QColorSpace 51495
#define sipName_QColorSpace &sipStrings_QtCore[51495]
#define sipNameNr_QDataStream 51507
#define sipName_QDataStream &sipStrings_QtCore[51507]
#define sipNameNr_QFileDevice 51519
#define sipName_QFileDevice &sipStrings_QtCore[51519]
#define sipNameNr_QJsonObject 51531
#define sipName_QJsonObject &sipStrings_QtCore[51531]
#define sipNameNr_51543 51543
#define sipName_51543 &sipStrings_QtCore[51543]
#define sipNameNr_51555 51555
#define sipName_51555 &sipStrings_QtCore[51555]
#define sipNameNr_QMetaMethod 51567
#define sipName_QMetaMethod &sipStrings_QtCore[51567]
#define sipNameNr_QMetaObject 51579
#define sipName_QMetaObject &sipStrings_QtCore[51579]
#define sipNameNr_QModelIndex 51591
#define sipName_QModelIndex &sipStrings_QtCore[51591]
#define sipNameNr_QObjectStar 51603
#define sipName_QObjectStar &sipStrings_QtCore[51603]
#define sipNameNr_QPermission 51615
#define sipName_QPermission &sipStrings_QtCore[51615]
#define sipNameNr_QQuaternion 51627
#define sipName_QQuaternion &sipStrings_QtCore[51627]
#define sipNameNr_QRangeModel 51639
#define sipName_QRangeModel &sipStrings_QtCore[51639]
#define sipNameNr_QReadLocker 51651
#define sipName_QReadLocker &sipStrings_QtCore[51651]
#define sipNameNr_QSizePolicy 51663
#define sipName_QSizePolicy &sipStrings_QtCore[51663]
#define sipNameNr_QStringList 31177
#define sipName_QStringList &sipStrings_QtCore[31177]
#define sipNameNr_QStringView 51675
#define sipName_QStringView &sipStrings_QtCore[51675]
#define sipNameNr_QTextFormat 51687
#define sipName_QTextFormat &sipStrings_QtCore[51687]
#define sipNameNr_QTextLength 51699
#define sipName_QTextLength &sipStrings_QtCore[51699]
#define sipNameNr_QTextStream 51711
#define sipName_QTextStream &sipStrings_QtCore[51711]
#define sipNameNr_QThreadPool 51723
#define sipName_QThreadPool &sipStrings_QtCore[51723]
#define sipNameNr_QTimerEvent 51735
#define sipName_QTimerEvent &sipStrings_QtCore[51735]
#define sipNameNr_QTranslator 51747
#define sipName_QTranslator &sipStrings_QtCore[51747]
#define sipNameNr_QVariantMap 31194
#define sipName_QVariantMap &sipStrings_QtCore[31194]
#define sipNameNr_QtSystemMsg 51759
#define sipName_QtSystemMsg &sipStrings_QtCore[51759]
#define sipNameNr_RFC2822Date 51771
#define sipName_RFC2822Date &sipStrings_QtCore[51771]
#define sipNameNr_ReadPastEnd 51783
#define sipName_ReadPastEnd &sipStrings_QtCore[51783]
#define sipNameNr_RemoveError 51795
#define sipName_RemoveError &sipStrings_QtCore[51795]
#define sipNameNr_RemoveQuery 51807
#define sipName_RemoveQuery &sipStrings_QtCore[51807]
#define sipNameNr_RenameError 51819
#define sipName_RenameError &sipStrings_QtCore[51819]
#define sipNameNr_ReplaceClip 51831
#define sipName_ReplaceClip &sipStrings_QtCore[51831]
#define sipNameNr_ResizeError 51843
#define sipName_ResizeError &sipStrings_QtCore[51843]
#define sipNameNr_RightButton 51855
#define sipName_RightButton &sipStrings_QtCore[51855]
#define sipNameNr_RightToLeft 38688
#define sipName_RightToLeft &sipStrings_QtCore[38688]
#define sipNameNr_RunicScript 51867
#define sipName_RunicScript &sipStrings_QtCore[51867]
#define sipNameNr_SaintHelena 51879
#define sipName_SaintHelena &sipStrings_QtCore[51879]
#define sipNameNr_SaintMartin 51891
#define sipName_SaintMartin &sipStrings_QtCore[51891]
#define sipNameNr_SaudiArabia 51903
#define sipName_SaudiArabia &sipStrings_QtCore[51903]
#define sipNameNr_Script_Ahom 51915
#define sipName_Script_Ahom &sipStrings_QtCore[51915]
#define sipNameNr_Script_Cham 51927
#define sipName_Script_Cham &sipStrings_QtCore[51927]
#define sipNameNr_Script_Kawi 51939
#define sipName_Script_Kawi &sipStrings_QtCore[51939]
#define sipNameNr_Script_Lisu 51951
#define sipName_Script_Lisu &sipStrings_QtCore[51951]
#define sipNameNr_Script_Miao 51963
#define sipName_Script_Miao &sipStrings_QtCore[51963]
#define sipNameNr_Script_Modi 51975
#define sipName_Script_Modi &sipStrings_QtCore[51975]
#define sipNameNr_Script_Newa 51987
#define sipName_Script_Newa &sipStrings_QtCore[51987]
#define sipNameNr_Script_Thai 51999
#define sipName_Script_Thai &sipStrings_QtCore[51999]
#define sipNameNr_Script_Toto 52011
#define sipName_Script_Toto &sipStrings_QtCore[52011]
#define sipNameNr_ScrollBegin 52023
#define sipName_ScrollBegin &sipStrings_QtCore[52023]
#define sipNameNr_ScrollPhase 33051
#define sipName_ScrollPhase &sipStrings_QtCore[33051]
#define sipNameNr_ShortFormat 52035
#define sipName_ShortFormat &sipStrings_QtCore[52035]
#define sipNameNr_SierraLeone 52047
#define sipName_SierraLeone &sipStrings_QtCore[52047]
#define sipNameNr_SintMaarten 52059
#define sipName_SintMaarten &sipStrings_QtCore[52059]
#define sipNameNr_SouthAfrica 52071
#define sipName_SouthAfrica &sipStrings_QtCore[52071]
#define sipNameNr_StartOfItem 52083
#define sipName_StartOfItem &sipStrings_QtCore[52083]
#define sipNameNr_StretchTile 52095
#define sipName_StretchTile &sipStrings_QtCore[52095]
#define sipNameNr_StrongFocus 52107
#define sipName_StrongFocus &sipStrings_QtCore[52107]
#define sipNameNr_StyleChange 52119
#define sipName_StyleChange &sipStrings_QtCore[52119]
#define sipNameNr_SwissGerman 52131
#define sipName_SwissGerman &sipStrings_QtCore[52131]
#define sipNameNr_Switzerland 52143
#define sipName_Switzerland &sipStrings_QtCore[52143]
#define sipNameNr_SystemScope 52155
#define sipName_SystemScope &sipStrings_QtCore[52155]
#define sipNameNr_TabletPress 52167
#define sipName_TabletPress &sipStrings_QtCore[52167]
#define sipNameNr_TaiLeScript 52179
#define sipName_TaiLeScript &sipStrings_QtCore[52179]
#define sipNameNr_TakriScript 52191
#define sipName_TakriScript &sipStrings_QtCore[52191]
#define sipNameNr_TamilScript 52203
#define sipName_TamilScript &sipStrings_QtCore[52203]
#define sipNameNr_TickCounter 52215
#define sipName_TickCounter &sipStrings_QtCore[52215]
#define sipNameNr_ToolBarArea 24280
#define sipName_ToolBarArea &sipStrings_QtCore[24280]
#define sipNameNr_ToolTipRole 52227
#define sipName_ToolTipRole &sipStrings_QtCore[52227]
#define sipNameNr_TouchCancel 52239
#define sipName_TouchCancel &sipStrings_QtCore[52239]
#define sipNameNr_TouchUpdate 52251
#define sipName_TouchUpdate &sipStrings_QtCore[52251]
#define sipNameNr_UI_FadeMenu 52263
#define sipName_UI_FadeMenu &sipStrings_QtCore[52263]
#define sipNameNr_UngrabMouse 52275
#define sipName_UngrabMouse &sipStrings_QtCore[52275]
#define sipNameNr_UnknownType 52287
#define sipName_UnknownType &sipStrings_QtCore[52287]
#define sipNameNr_Unspecified 52299
#define sipName_Unspecified &sipStrings_QtCore[52299]
#define sipNameNr_UpdateLater 52311
#define sipName_UpdateLater &sipStrings_QtCore[52311]
#define sipNameNr_VaticanCity 52323
#define sipName_VaticanCity &sipStrings_QtCore[52323]
#define sipNameNr_WA_Disabled 52335
#define sipName_WA_Disabled &sipStrings_QtCore[52335]
#define sipNameNr_WA_SetStyle 52347
#define sipName_WA_SetStyle &sipStrings_QtCore[52347]
#define sipNameNr_WinEventAct 52359
#define sipName_WinEventAct &sipStrings_QtCore[52359]
#define sipNameNr_WinIdChange 52371
#define sipName_WinIdChange &sipStrings_QtCore[52371]
#define sipNameNr_WindingFill 52383
#define sipName_WindingFill &sipStrings_QtCore[52383]
#define sipNameNr_WindowModal 52395
#define sipName_WindowModal &sipStrings_QtCore[52395]
#define sipNameNr_WindowState 33083
#define sipName_WindowState &sipStrings_QtCore[33083]
#define sipNameNr_WriteFailed 52407
#define sipName_WriteFailed &sipStrings_QtCore[52407]
#define sipNameNr___delitem__ 52419
#define sipName___delitem__ &sipStrings_QtCore[52419]
#define sipNameNr___getattr__ 52431
#define sipName___getattr__ &sipStrings_QtCore[52431]
#define sipNameNr___getitem__ 52443
#define sipName___getitem__ &sipStrings_QtCore[52443]
#define sipNameNr___setitem__ 52455
#define sipName___setitem__ &sipStrings_QtCore[52455]
#define sipNameNr___truediv__ 52467
#define sipName___truediv__ &sipStrings_QtCore[52467]
#define sipNameNr_aboutToQuit 52479
#define sipName_aboutToQuit &sipStrings_QtCore[52479]
#define sipNameNr_absoluteDir 52491
#define sipName_absoluteDir &sipStrings_QtCore[52491]
#define sipNameNr_animationAt 52503
#define sipName_animationAt &sipStrings_QtCore[52503]
#define sipNameNr_application 52515
#define sipName_application &sipStrings_QtCore[52515]
#define sipNameNr_bottomRight 52527
#define sipName_bottomRight &sipStrings_QtCore[52527]
#define sipNameNr_canReadLine 52539
#define sipName_canReadLine &sipStrings_QtCore[52539]
#define sipNameNr_capturedEnd 52551
#define sipName_capturedEnd &sipStrings_QtCore[52551]
#define sipNameNr_childGroups 52563
#define sipName_childGroups &sipStrings_QtCore[52563]
#define sipNameNr_closingDown 52575
#define sipName_closingDown &sipStrings_QtCore[52575]
#define sipNameNr_columnCount 52587
#define sipName_columnCount &sipStrings_QtCore[52587]
#define sipNameNr_constructor 52599
#define sipName_constructor &sipStrings_QtCore[52599]
#define sipNameNr_createIndex 52611
#define sipName_createIndex &sipStrings_QtCore[52611]
#define sipNameNr_currentDate 52623
#define sipName_currentDate &sipStrings_QtCore[52623]
#define sipNameNr_currentLoop 52635
#define sipName_currentLoop &sipStrings_QtCore[52635]
#define sipNameNr_currentPath 52647
#define sipName_currentPath &sipStrings_QtCore[52647]
#define sipNameNr_currentTime 52659
#define sipName_currentTime &sipStrings_QtCore[52659]
#define sipNameNr_currentType 52671
#define sipName_currentType &sipStrings_QtCore[52671]
#define sipNameNr_customEvent 52683
#define sipName_customEvent &sipStrings_QtCore[52683]
#define sipNameNr_darkMagenta 52695
#define sipName_darkMagenta &sipStrings_QtCore[52695]
#define sipNameNr_dataChanged 52707
#define sipName_dataChanged &sipStrings_QtCore[52707]
#define sipNameNr_dataForRole 52719
#define sipName_dataForRole &sipStrings_QtCore[52719]
#define sipNameNr_daysInMonth 52731
#define sipName_daysInMonth &sipStrings_QtCore[52731]
#define sipNameNr_defaultPort 52743
#define sipName_defaultPort &sipStrings_QtCore[52743]
#define sipNameNr_deleteLater 52755
#define sipName_deleteLater &sipStrings_QtCore[52755]
#define sipNameNr_description 52767
#define sipName_description &sipStrings_QtCore[52767]
#define sipNameNr_directories 38358
#define sipName_directories &sipStrings_QtCore[38358]
#define sipNameNr_displayName 52779
#define sipName_displayName &sipStrings_QtCore[52779]
#define sipNameNr_dtdPublicId 52791
#define sipName_dtdPublicId &sipStrings_QtCore[52791]
#define sipNameNr_dtdSystemId 52803
#define sipName_dtdSystemId &sipStrings_QtCore[52803]
#define sipNameNr_easingCurve 52815
#define sipName_easingCurve &sipStrings_QtCore[52815]
#define sipNameNr_endMoveRows 52827
#define sipName_endMoveRows &sipStrings_QtCore[52827]
#define sipNameNr_errorString 52839
#define sipName_errorString &sipStrings_QtCore[52839]
#define sipNameNr_eventFilter 52851
#define sipName_eventFilter &sipStrings_QtCore[52851]
#define sipNameNr_exponential 52863
#define sipName_exponential &sipStrings_QtCore[52863]
#define sipNameNr_fileChanged 52875
#define sipName_fileChanged &sipStrings_QtCore[52875]
#define sipNameNr_fromEncoded 52887
#define sipName_fromEncoded &sipStrings_QtCore[52887]
#define sipNameNr_fromRfc4122 52899
#define sipName_fromRfc4122 &sipStrings_QtCore[52899]
#define sipNameNr_fromVariant 52911
#define sipName_fromVariant &sipStrings_QtCore[52911]
#define sipNameNr_getLockInfo 52923
#define sipName_getLockInfo &sipStrings_QtCore[52923]
#define sipNameNr_globalMatch 52935
#define sipName_globalMatch &sipStrings_QtCore[52935]
#define sipNameNr_handleFlags 52947
#define sipName_handleFlags &sipStrings_QtCore[52947]
#define sipNameNr_hasCaptured 52959
#define sipName_hasCaptured &sipStrings_QtCore[52959]
#define sipNameNr_hasChildren 52971
#define sipName_hasChildren &sipStrings_QtCore[52971]
#define sipNameNr_hasFragment 52983
#define sipName_hasFragment &sipStrings_QtCore[52983]
#define sipNameNr_hasYearZero 52995
#define sipName_hasYearZero &sipStrings_QtCore[52995]
#define sipNameNr_indexOfSlot 53007
#define sipName_indexOfSlot &sipStrings_QtCore[53007]
#define sipNameNr_insertPause 53019
#define sipName_insertPause &sipStrings_QtCore[53019]
#define sipNameNr_integerBase 53031
#define sipName_integerBase &sipStrings_QtCore[53031]
#define sipNameNr_intersected 53043
#define sipName_intersected &sipStrings_QtCore[53043]
#define sipNameNr_isByteArray 53055
#define sipName_isByteArray &sipStrings_QtCore[53055]
#define sipNameNr_isContainer 53067
#define sipName_isContainer &sipStrings_QtCore[53067]
#define sipNameNr_isDateValid 53079
#define sipName_isDateValid &sipStrings_QtCore[53079]
#define sipNameNr_isGregorian 53091
#define sipName_isGregorian &sipStrings_QtCore[53091]
#define sipNameNr_isLocalFile 53103
#define sipName_isLocalFile &sipStrings_QtCore[53103]
#define sipNameNr_isLuniSolar 53115
#define sipName_isLuniSolar &sipStrings_QtCore[53115]
#define sipNameNr_isMonotonic 53127
#define sipName_isMonotonic &sipStrings_QtCore[53127]
#define sipNameNr_isProleptic 53139
#define sipName_isProleptic &sipStrings_QtCore[53139]
#define sipNameNr_isUndefined 53151
#define sipName_isUndefined &sipStrings_QtCore[53151]
#define sipNameNr_isValidUtf8 53163
#define sipName_isValidUtf8 &sipStrings_QtCore[53163]
#define sipNameNr_keysToValue 53175
#define sipName_keysToValue &sipStrings_QtCore[53175]
#define sipNameNr_lastIndexOf 53187
#define sipName_lastIndexOf &sipStrings_QtCore[53187]
#define sipNameNr_lockForRead 53199
#define sipName_lockForRead &sipStrings_QtCore[53199]
#define sipNameNr_mapToSource 53211
#define sipName_mapToSource &sipStrings_QtCore[53211]
#define sipNameNr_methodCount 53223
#define sipName_methodCount &sipStrings_QtCore[53223]
#define sipNameNr_methodIndex 53235
#define sipName_methodIndex &sipStrings_QtCore[53235]
#define sipNameNr_moveColumns 22959
#define sipName_moveColumns &sipStrings_QtCore[22959]
#define sipNameNr_moveToTrash 53247
#define sipName_moveToTrash &sipStrings_QtCore[53247]
#define sipNameNr_moveTopLeft 53259
#define sipName_moveTopLeft &sipStrings_QtCore[53259]
#define sipNameNr_nameFilters 53271
#define sipName_nameFilters &sipStrings_QtCore[53271]
#define sipNameNr_newInstance 53283
#define sipName_newInstance &sipStrings_QtCore[53283]
#define sipNameNr_noforcesign 53295
#define sipName_noforcesign &sipStrings_QtCore[53295]
#define sipNameNr_numberFlags 53307
#define sipName_numberFlags &sipStrings_QtCore[53307]
#define sipNameNr_numericMode 53319
#define sipName_numericMode &sipStrings_QtCore[53319]
#define sipNameNr_optionNames 53331
#define sipName_optionNames &sipStrings_QtCore[53331]
#define sipNameNr_pathInTrash 53343
#define sipName_pathInTrash &sipStrings_QtCore[53343]
#define sipNameNr_permissions 53355
#define sipName_permissions &sipStrings_QtCore[53355]
#define sipNameNr_productType 53367
#define sipName_productType &sipStrings_QtCore[53367]
#define sipNameNr_qSetPadChar 53379
#define sipName_qSetPadChar &sipStrings_QtCore[53379]
#define sipNameNr_qUncompress 53391
#define sipName_qUncompress &sipStrings_QtCore[53391]
#define sipNameNr_quoteString 53403
#define sipName_quoteString &sipStrings_QtCore[53403]
#define sipNameNr_readChannel 53415
#define sipName_readChannel &sipStrings_QtCore[53415]
#define sipNameNr_readQString 53427
#define sipName_readQString &sipStrings_QtCore[53427]
#define sipNameNr_readRawData 53439
#define sipName_readRawData &sipStrings_QtCore[53439]
#define sipNameNr_readSymLink 53451
#define sipName_readSymLink &sipStrings_QtCore[53451]
#define sipNameNr_removeFirst 53463
#define sipName_removeFirst &sipStrings_QtCore[53463]
#define sipNameNr_removePaths 53475
#define sipName_removePaths &sipStrings_QtCore[53475]
#define sipNameNr_resetStatus 53487
#define sipName_resetStatus &sipStrings_QtCore[53487]
#define sipNameNr_rowsRemoved 53499
#define sipName_rowsRemoved &sipStrings_QtCore[53499]
#define sipNameNr_searchPaths 53511
#define sipName_searchPaths &sipStrings_QtCore[53511]
#define sipNameNr_setAccepted 53523
#define sipName_setAccepted &sipStrings_QtCore[53523]
#define sipNameNr_setAccuracy 53535
#define sipName_setAccuracy &sipStrings_QtCore[53535]
#define sipNameNr_setDeadline 53547
#define sipName_setDeadline &sipStrings_QtCore[53547]
#define sipNameNr_setDuration 53559
#define sipName_setDuration &sipStrings_QtCore[53559]
#define sipNameNr_setEncoding 53571
#define sipName_setEncoding &sipStrings_QtCore[53571]
#define sipNameNr_setEndFrame 53583
#define sipName_setEndFrame &sipStrings_QtCore[53583]
#define sipNameNr_setEndValue 53595
#define sipName_setEndValue &sipStrings_QtCore[53595]
#define sipNameNr_setFileName 53607
#define sipName_setFileName &sipStrings_QtCore[53607]
#define sipNameNr_setFileTime 53619
#define sipName_setFileTime &sipStrings_QtCore[53619]
#define sipNameNr_setFragment 53631
#define sipName_setFragment &sipStrings_QtCore[53631]
#define sipNameNr_setInterval 53643
#define sipName_setInterval &sipStrings_QtCore[53643]
#define sipNameNr_setItemData 53655
#define sipName_setItemData &sipStrings_QtCore[53655]
#define sipNameNr_setOpenMode 53667
#define sipName_setOpenMode &sipStrings_QtCore[53667]
#define sipNameNr_setPassword 53679
#define sipName_setPassword &sipStrings_QtCore[53679]
#define sipNameNr_setPosition 53691
#define sipName_setPosition &sipStrings_QtCore[53691]
#define sipNameNr_setPriority 53703
#define sipName_setPriority &sipStrings_QtCore[53703]
#define sipNameNr_setProperty 53715
#define sipName_setProperty &sipStrings_QtCore[53715]
#define sipNameNr_setSortRole 53727
#define sipName_setSortRole &sipStrings_QtCore[53727]
#define sipNameNr_setTimeSpec 53739
#define sipName_setTimeSpec &sipStrings_QtCore[53739]
#define sipNameNr_setTimeZone 53751
#define sipName_setTimeZone &sipStrings_QtCore[53751]
#define sipNameNr_setTopRight 53763
#define sipName_setTopRight &sipStrings_QtCore[53763]
#define sipNameNr_setUserInfo 53775
#define sipName_setUserInfo &sipStrings_QtCore[53775]
#define sipNameNr_setUserName 53787
#define sipName_setUserName &sipStrings_QtCore[53787]
#define sipNameNr_showVersion 53799
#define sipName_showVersion &sipStrings_QtCore[53799]
#define sipNameNr_skipRawData 53811
#define sipName_skipRawData &sipStrings_QtCore[53811]
#define sipNameNr_sourceModel 53823
#define sipName_sourceModel &sipStrings_QtCore[53823]
#define sipNameNr_spontaneous 53835
#define sipName_spontaneous &sipStrings_QtCore[53835]
#define sipNameNr_suffixIndex 53847
#define sipName_suffixIndex &sipStrings_QtCore[53847]
#define sipNameNr_toByteArray 53859
#define sipName_toByteArray &sipStrings_QtCore[53859]
#define sipNameNr_toJulianDay 53871
#define sipName_toJulianDay &sipStrings_QtCore[53871]
#define sipNameNr_toLocalFile 53883
#define sipName_toLocalFile &sipStrings_QtCore[53883]
#define sipNameNr_toLocalTime 53895
#define sipName_toLocalTime &sipStrings_QtCore[53895]
#define sipNameNr_toULongLong 53907
#define sipName_toULongLong &sipStrings_QtCore[53907]
#define sipNameNr_tokenString 53919
#define sipName_tokenString &sipStrings_QtCore[53919]
#define sipNameNr_transitions 53931
#define sipName_transitions &sipStrings_QtCore[53931]
#define sipNameNr_transparent 53943
#define sipName_transparent &sipStrings_QtCore[53943]
#define sipNameNr_uiLanguages 53955
#define sipName_uiLanguages &sipStrings_QtCore[53955]
#define sipNameNr_updateState 53967
#define sipName_updateState &sipStrings_QtCore[53967]
#define sipNameNr_valueToKeys 53979
#define sipName_valueToKeys &sipStrings_QtCore[53979]
#define sipNameNr_waitForDone 53991
#define sipName_waitForDone &sipStrings_QtCore[53991]
#define sipNameNr_weekDayName 54003
#define sipName_weekDayName &sipStrings_QtCore[54003]
#define sipNameNr_writeDouble 54015
#define sipName_writeDouble &sipStrings_QtCore[54015]
#define sipNameNr_writeString 54027
#define sipName_writeString &sipStrings_QtCore[54027]
#define sipNameNr_writeUInt16 54039
#define sipName_writeUInt16 &sipStrings_QtCore[54039]
#define sipNameNr_writeUInt32 54051
#define sipName_writeUInt32 &sipStrings_QtCore[54051]
#define sipNameNr_writeUInt64 54063
#define sipName_writeUInt64 &sipStrings_QtCore[54063]
#define sipNameNr_AbortError 54075
#define sipName_AbortError &sipStrings_QtCore[54075]
#define sipNameNr_AccessMask 54086
#define sipName_AccessMask &sipStrings_QtCore[54086]
#define sipNameNr_AccessMode 3100
#define sipName_AccessMode &sipStrings_QtCore[3100]
#define sipNameNr_ActionMask 54097
#define sipName_ActionMask &sipStrings_QtCore[54097]
#define sipNameNr_AhomScript 54108
#define sipName_AhomScript &sipStrings_QtCore[54108]
#define sipNameNr_AlignRight 54119
#define sipName_AlignRight &sipStrings_QtCore[54119]
#define sipNameNr_AllButtons 54130
#define sipName_AllButtons &sipStrings_QtCore[54130]
#define sipNameNr_AllEntries 54141
#define sipName_AllEntries &sipStrings_QtCore[54141]
#define sipNameNr_AnchorLeft 54152
#define sipName_AnchorLeft &sipStrings_QtCore[54152]
#define sipNameNr_Android12L 54163
#define sipName_Android12L &sipStrings_QtCore[54163]
#define sipNameNr_AndroidPie 54174
#define sipName_AndroidPie &sipStrings_QtCore[54174]
#define sipNameNr_Antarctica 54185
#define sipName_Antarctica &sipStrings_QtCore[54185]
#define sipNameNr_AnyCountry 54196
#define sipName_AnyCountry &sipStrings_QtCore[54196]
#define sipNameNr_AutoDither 54207
#define sipName_AutoDither &sipStrings_QtCore[54207]
#define sipNameNr_Azerbaijan 54218
#define sipName_Azerbaijan &sipStrings_QtCore[54218]
#define sipNameNr_BackButton 54229
#define sipName_BackButton &sipStrings_QtCore[54229]
#define sipNameNr_Bangladesh 54240
#define sipName_Bangladesh &sipStrings_QtCore[54240]
#define sipNameNr_Belarusian 54251
#define sipName_Belarusian &sipStrings_QtCore[54251]
#define sipNameNr_BottomEdge 54262
#define sipName_BottomEdge &sipStrings_QtCore[54262]
#define sipNameNr_BrushStyle 37624
#define sipName_BrushStyle &sipStrings_QtCore[37624]
#define sipNameNr_BusyCursor 54273
#define sipName_BusyCursor &sipStrings_QtCore[54273]
#define sipNameNr_ByteString 54284
#define sipName_ByteString &sipStrings_QtCore[54284]
#define sipNameNr_COSE_Sign1 54295
#define sipName_COSE_Sign1 &sipStrings_QtCore[54295]
#define sipNameNr_ChamScript 54306
#define sipName_ChamScript &sipStrings_QtCore[54306]
#define sipNameNr_Characters 24749
#define sipName_Characters &sipStrings_QtCore[24749]
#define sipNameNr_CheckState 37639
#define sipName_CheckState &sipStrings_QtCore[37639]
#define sipNameNr_ChildAdded 54317
#define sipName_ChildAdded &sipStrings_QtCore[54317]
#define sipNameNr_ClickFocus 54328
#define sipName_ClickFocus &sipStrings_QtCore[54328]
#define sipNameNr_Connection 8964
#define sipName_Connection &sipStrings_QtCore[8964]
#define sipNameNr_CopyAction 54339
#define sipName_CopyAction &sipStrings_QtCore[54339]
#define sipNameNr_DateFormat 37654
#define sipName_DateFormat &sipStrings_QtCore[37654]
#define sipNameNr_DropAction 37669
#define sipName_DropAction &sipStrings_QtCore[37669]
#define sipNameNr_ElSalvador 54350
#define sipName_ElSalvador &sipStrings_QtCore[54350]
#define sipNameNr_ElideRight 54361
#define sipName_ElideRight &sipStrings_QtCore[54361]
#define sipNameNr_EndElement 35404
#define sipName_EndElement &sipStrings_QtCore[35404]
#define sipNameNr_EnterKeyGo 54372
#define sipName_EnterKeyGo &sipStrings_QtCore[54372]
#define sipNameNr_Executable 39379
#define sipName_Executable &sipStrings_QtCore[39379]
#define sipNameNr_ExitStatus 16852
#define sipName_ExitStatus &sipStrings_QtCore[16852]
#define sipNameNr_FatalError 54383
#define sipName_FatalError &sipStrings_QtCore[54383]
#define sipNameNr_FontChange 13602
#define sipName_FontChange &sipStrings_QtCore[13602]
#define sipNameNr_ForcePoint 54394
#define sipName_ForcePoint &sipStrings_QtCore[54394]
#define sipNameNr_FormatType 19096
#define sipName_FormatType &sipStrings_QtCore[19096]
#define sipNameNr_Guadeloupe 54405
#define sipName_Guadeloupe &sipStrings_QtCore[54405]
#define sipNameNr_HorPattern 54416
#define sipName_HorPattern &sipStrings_QtCore[54416]
#define sipNameNr_Horizontal 54427
#define sipName_Horizontal &sipStrings_QtCore[54427]
#define sipNameNr_HoverEnter 10378
#define sipName_HoverEnter &sipStrings_QtCore[10378]
#define sipNameNr_HoverLeave 10402
#define sipName_HoverLeave &sipStrings_QtCore[10402]
#define sipNameNr_Id128Bytes 25361
#define sipName_Id128Bytes &sipStrings_QtCore[25361]
#define sipNameNr_IgnoreCase 54438
#define sipName_IgnoreCase &sipStrings_QtCore[54438]
#define sipNameNr_ImQueryAll 54449
#define sipName_ImQueryAll &sipStrings_QtCore[54449]
#define sipNameNr_ImReadOnly 54460
#define sipName_ImReadOnly &sipStrings_QtCore[54460]
#define sipNameNr_InOutCubic 54471
#define sipName_InOutCubic &sipStrings_QtCore[54471]
#define sipNameNr_InOutQuart 54482
#define sipName_InOutQuart &sipStrings_QtCore[54482]
#define sipNameNr_InOutQuint 54493
#define sipName_InOutQuint &sipStrings_QtCore[54493]
#define sipNameNr_Indonesian 54504
#define sipName_Indonesian &sipStrings_QtCore[54504]
#define sipNameNr_IvoryCoast 54515
#define sipName_IvoryCoast &sipStrings_QtCore[54515]
#define sipNameNr_JamoScript 54526
#define sipName_JamoScript &sipStrings_QtCore[54526]
#define sipNameNr_JsonFormat 8083
#define sipName_JsonFormat &sipStrings_QtCore[8083]
#define sipNameNr_KaraKalpak 54537
#define sipName_KaraKalpak &sipStrings_QtCore[54537]
#define sipNameNr_Kazakhstan 54548
#define sipName_Kazakhstan &sipStrings_QtCore[54548]
#define sipNameNr_Keccak_224 54559
#define sipName_Keccak_224 &sipStrings_QtCore[54559]
#define sipNameNr_Keccak_256 54570
#define sipName_Keccak_256 &sipStrings_QtCore[54570]
#define sipNameNr_Keccak_384 54581
#define sipName_Keccak_384 &sipStrings_QtCore[54581]
#define sipNameNr_Keccak_512 54592
#define sipName_Keccak_512 &sipStrings_QtCore[54592]
#define sipNameNr_KeyRelease 54603
#define sipName_KeyRelease &sipStrings_QtCore[54603]
#define sipNameNr_Key_Aacute 54614
#define sipName_Key_Aacute &sipStrings_QtCore[54614]
#define sipNameNr_Key_Agrave 54625
#define sipName_Key_Agrave &sipStrings_QtCore[54625]
#define sipNameNr_Key_Atilde 54636
#define sipName_Key_Atilde &sipStrings_QtCore[54636]
#define sipNameNr_Key_BassUp 54647
#define sipName_Key_BassUp &sipStrings_QtCore[54647]
#define sipNameNr_Key_Camera 54658
#define sipName_Key_Camera &sipStrings_QtCore[54658]
#define sipNameNr_Key_Cancel 54669
#define sipName_Key_Cancel &sipStrings_QtCore[54669]
#define sipNameNr_Key_Dead_A 54680
#define sipName_Key_Dead_A &sipStrings_QtCore[54680]
#define sipNameNr_Key_Dead_E 54691
#define sipName_Key_Dead_E &sipStrings_QtCore[54691]
#define sipNameNr_Key_Dead_I 54702
#define sipName_Key_Dead_I &sipStrings_QtCore[54702]
#define sipNameNr_Key_Dead_O 54713
#define sipName_Key_Dead_O &sipStrings_QtCore[54713]
#define sipNameNr_Key_Dead_U 54724
#define sipName_Key_Dead_U &sipStrings_QtCore[54724]
#define sipNameNr_Key_Dead_a 54735
#define sipName_Key_Dead_a &sipStrings_QtCore[54735]
#define sipNameNr_Key_Dead_e 54746
#define sipName_Key_Dead_e &sipStrings_QtCore[54746]
#define sipNameNr_Key_Dead_i 54757
#define sipName_Key_Dead_i &sipStrings_QtCore[54757]
#define sipNameNr_Key_Dead_o 54768
#define sipName_Key_Dead_o &sipStrings_QtCore[54768]
#define sipNameNr_Key_Dead_u 54779
#define sipName_Key_Dead_u &sipStrings_QtCore[54779]
#define sipNameNr_Key_Delete 54790
#define sipName_Key_Delete &sipStrings_QtCore[54790]
#define sipNameNr_Key_Dollar 54801
#define sipName_Key_Dollar &sipStrings_QtCore[54801]
#define sipNameNr_Key_Eacute 54812
#define sipName_Key_Eacute &sipStrings_QtCore[54812]
#define sipNameNr_Key_Egrave 54823
#define sipName_Key_Egrave &sipStrings_QtCore[54823]
#define sipNameNr_Key_Escape 54834
#define sipName_Key_Escape &sipStrings_QtCore[54834]
#define sipNameNr_Key_Exclam 54845
#define sipName_Key_Exclam &sipStrings_QtCore[54845]
#define sipNameNr_Key_Hangul 54856
#define sipName_Key_Hangul &sipStrings_QtCore[54856]
#define sipNameNr_Key_Hangup 54867
#define sipName_Key_Hangup &sipStrings_QtCore[54867]
#define sipNameNr_Key_Henkan 54878
#define sipName_Key_Henkan &sipStrings_QtCore[54878]
#define sipNameNr_Key_Iacute 54889
#define sipName_Key_Iacute &sipStrings_QtCore[54889]
#define sipNameNr_Key_Igrave 54900
#define sipName_Key_Igrave &sipStrings_QtCore[54900]
#define sipNameNr_Key_Insert 54911
#define sipName_Key_Insert &sipStrings_QtCore[54911]
#define sipNameNr_Key_LogOff 54922
#define sipName_Key_LogOff &sipStrings_QtCore[54922]
#define sipNameNr_Key_Market 54933
#define sipName_Key_Market &sipStrings_QtCore[54933]
#define sipNameNr_Key_Massyo 54944
#define sipName_Key_Massyo &sipStrings_QtCore[54944]
#define sipNameNr_Key_MenuKB 54955
#define sipName_Key_MenuKB &sipStrings_QtCore[54955]
#define sipNameNr_Key_MenuPB 54966
#define sipName_Key_MenuPB &sipStrings_QtCore[54966]
#define sipNameNr_Key_Ntilde 54977
#define sipName_Key_Ntilde &sipStrings_QtCore[54977]
#define sipNameNr_Key_Oacute 54988
#define sipName_Key_Oacute &sipStrings_QtCore[54988]
#define sipNameNr_Key_Ograve 54999
#define sipName_Key_Ograve &sipStrings_QtCore[54999]
#define sipNameNr_Key_Option 55010
#define sipName_Key_Option &sipStrings_QtCore[55010]
#define sipNameNr_Key_Otilde 55021
#define sipName_Key_Otilde &sipStrings_QtCore[55021]
#define sipNameNr_Key_PageUp 55032
#define sipName_Key_PageUp &sipStrings_QtCore[55032]
#define sipNameNr_Key_Period 55043
#define sipName_Key_Period &sipStrings_QtCore[55043]
#define sipNameNr_Key_Reload 55054
#define sipName_Key_Reload &sipStrings_QtCore[55054]
#define sipNameNr_Key_Return 55065
#define sipName_Key_Return &sipStrings_QtCore[55065]
#define sipNameNr_Key_Romaji 55076
#define sipName_Key_Romaji &sipStrings_QtCore[55076]
#define sipNameNr_Key_Search 55087
#define sipName_Key_Search &sipStrings_QtCore[55087]
#define sipNameNr_Key_Select 55098
#define sipName_Key_Select &sipStrings_QtCore[55098]
#define sipNameNr_Key_SysReq 55109
#define sipName_Key_SysReq &sipStrings_QtCore[55109]
#define sipNameNr_Key_Travel 55120
#define sipName_Key_Travel &sipStrings_QtCore[55120]
#define sipNameNr_Key_Uacute 55131
#define sipName_Key_Uacute &sipStrings_QtCore[55131]
#define sipNameNr_Key_Ugrave 55142
#define sipName_Key_Ugrave &sipStrings_QtCore[55142]
#define sipNameNr_Key_WakeUp 55153
#define sipName_Key_WakeUp &sipStrings_QtCore[55153]
#define sipNameNr_Key_WebCam 55164
#define sipName_Key_WebCam &sipStrings_QtCore[55164]
#define sipNameNr_Key_Yacute 55175
#define sipName_Key_Yacute &sipStrings_QtCore[55175]
#define sipNameNr_Key_Yellow 55186
#define sipName_Key_Yellow &sipStrings_QtCore[55186]
#define sipNameNr_Key_ZoomIn 55197
#define sipName_Key_ZoomIn &sipStrings_QtCore[55197]
#define sipNameNr_Key_degree 55208
#define sipName_Key_degree &sipStrings_QtCore[55208]
#define sipNameNr_Key_hyphen 55219
#define sipName_Key_hyphen &sipStrings_QtCore[55219]
#define sipNameNr_Key_iTouch 55230
#define sipName_Key_iTouch &sipStrings_QtCore[55230]
#define sipNameNr_Key_macron 55241
#define sipName_Key_macron &sipStrings_QtCore[55241]
#define sipNameNr_Key_ssharp 55252
#define sipName_Key_ssharp &sipStrings_QtCore[55252]
#define sipNameNr_Kyrgyzstan 55263
#define sipName_Kyrgyzstan &sipStrings_QtCore[55263]
#define sipNameNr_LastCursor 55274
#define sipName_LastCursor &sipStrings_QtCore[55274]
#define sipNameNr_LeftButton 55285
#define sipName_LeftButton &sipStrings_QtCore[55285]
#define sipNameNr_Limburgish 55296
#define sipName_Limburgish &sipStrings_QtCore[55296]
#define sipNameNr_LinkAction 55307
#define sipName_LinkAction &sipStrings_QtCore[55307]
#define sipNameNr_Lithuanian 55318
#define sipName_Lithuanian &sipStrings_QtCore[55318]
#define sipNameNr_LocateFile 55329
#define sipName_LocateFile &sipStrings_QtCore[55329]
#define sipNameNr_LongFormat 55340
#define sipName_LongFormat &sipStrings_QtCore[55340]
#define sipNameNr_Luxembourg 55351
#define sipName_Luxembourg &sipStrings_QtCore[55351]
#define sipNameNr_Macedonian 55362
#define sipName_Macedonian &sipStrings_QtCore[55362]
#define sipNameNr_Madagascar 55373
#define sipName_Madagascar &sipStrings_QtCore[55373]
#define sipNameNr_Martinique 55384
#define sipName_Martinique &sipStrings_QtCore[55384]
#define sipNameNr_Mauritania 55395
#define sipName_Mauritania &sipStrings_QtCore[55395]
#define sipNameNr_MethodType 10834
#define sipName_MethodType &sipStrings_QtCore[10834]
#define sipNameNr_Micronesia 55406
#define sipName_Micronesia &sipStrings_QtCore[55406]
#define sipNameNr_Milankovic 55417
#define sipName_Milankovic &sipStrings_QtCore[55417]
#define sipNameNr_ModiScript 55428
#define sipName_ModiScript &sipStrings_QtCore[55428]
#define sipNameNr_Montenegro 55439
#define sipName_Montenegro &sipStrings_QtCore[55439]
#define sipNameNr_Montserrat 55450
#define sipName_Montserrat &sipStrings_QtCore[55450]
#define sipNameNr_MoveAction 29665
#define sipName_MoveAction &sipStrings_QtCore[29665]
#define sipNameNr_Mozambique 55461
#define sipName_Mozambique &sipStrings_QtCore[55461]
#define sipNameNr_NewZealand 55472
#define sipName_NewZealand &sipStrings_QtCore[55472]
#define sipNameNr_NewaScript 55483
#define sipName_NewaScript &sipStrings_QtCore[55483]
#define sipNameNr_NoModifier 55494
#define sipName_NoModifier &sipStrings_QtCore[55494]
#define sipNameNr_NoSymLinks 55505
#define sipName_NoSymLinks &sipStrings_QtCore[55505]
#define sipNameNr_NoTabFocus 55516
#define sipName_NoTabFocus &sipStrings_QtCore[55516]
#define sipNameNr_NormalExit 55527
#define sipName_NormalExit &sipStrings_QtCore[55527]
#define sipNameNr_NorthKorea 55538
#define sipName_NorthKorea &sipStrings_QtCore[55538]
#define sipNameNr_NotRunning 55549
#define sipName_NotRunning &sipStrings_QtCore[55549]
#define sipNameNr_NumberFlag 10954
#define sipName_NumberFlag &sipStrings_QtCore[10954]
#define sipNameNr_OdiaScript 55560
#define sipName_OdiaScript &sipStrings_QtCore[55560]
#define sipNameNr_OffsetData 14504
#define sipName_OffsetData &sipStrings_QtCore[14504]
#define sipNameNr_OffsetName 55571
#define sipName_OffsetName &sipStrings_QtCore[55571]
#define sipNameNr_OldPersian 25613
#define sipName_OldPersian &sipStrings_QtCore[25613]
#define sipNameNr_OpaqueMode 55582
#define sipName_OpaqueMode &sipStrings_QtCore[55582]
#define sipNameNr_OutElastic 45869
#define sipName_OutElastic &sipStrings_QtCore[45869]
#define sipNameNr_OutInCubic 55593
#define sipName_OutInCubic &sipStrings_QtCore[55593]
#define sipNameNr_OutInQuart 55604
#define sipName_OutInQuart &sipStrings_QtCore[55604]
#define sipNameNr_OutInQuint 55615
#define sipName_OutInQuint &sipStrings_QtCore[55615]
#define sipNameNr_PanGesture 55626
#define sipName_PanGesture &sipStrings_QtCore[55626]
#define sipNameNr_Papiamento 55637
#define sipName_Papiamento &sipStrings_QtCore[55637]
#define sipNameNr_ParseError 5767
#define sipName_ParseError &sipStrings_QtCore[5767]
#define sipNameNr_Permission 10618
#define sipName_Permission &sipStrings_QtCore[10618]
#define sipNameNr_Phoenician 25649
#define sipName_Phoenician &sipStrings_QtCore[25649]
#define sipNameNr_Portuguese 55648
#define sipName_Portuguese &sipStrings_QtCore[55648]
#define sipNameNr_PrefixPath 55659
#define sipName_PrefixPath &sipStrings_QtCore[55659]
#define sipNameNr_PuertoRico 55670
#define sipName_PuertoRico &sipStrings_QtCore[55670]
#define sipNameNr_QByteArray 55681
#define sipName_QByteArray &sipStrings_QtCore[55681]
#define sipNameNr_QCborArray 55692
#define sipName_QCborArray &sipStrings_QtCore[55692]
#define sipNameNr_QCborError 55703
#define sipName_QCborError &sipStrings_QtCore[55703]
#define sipNameNr_QCborValue 55714
#define sipName_QCborValue &sipStrings_QtCore[55714]
#define sipNameNr_QEventLoop 55725
#define sipName_QEventLoop &sipStrings_QtCore[55725]
#define sipNameNr_QJsonArray 55736
#define sipName_QJsonArray &sipStrings_QtCore[55736]
#define sipNameNr_QJsonValue 55747
#define sipName_QJsonValue &sipStrings_QtCore[55747]
#define sipNameNr_55758 55758
#define sipName_55758 &sipStrings_QtCore[55758]
#define sipNameNr_QMatrix4x4 55769
#define sipName_QMatrix4x4 &sipStrings_QtCore[55769]
#define sipNameNr_QSemaphore 55780
#define sipName_QSemaphore &sipStrings_QtCore[55780]
#define sipNameNr_QT_TR_NOOP 55791
#define sipName_QT_TR_NOOP &sipStrings_QtCore[55791]
#define sipNameNr_QT_VERSION 46792
#define sipName_QT_VERSION &sipStrings_QtCore[46792]
#define sipNameNr_QTransform 55802
#define sipName_QTransform &sipStrings_QtCore[55802]
#define sipNameNr_Qt__BGMode 55813
#define sipName_Qt__BGMode &sipStrings_QtCore[55813]
#define sipNameNr_Qt__Corner 55824
#define sipName_Qt__Corner &sipStrings_QtCore[55824]
#define sipNameNr_QtDebugMsg 55835
#define sipName_QtDebugMsg &sipStrings_QtCore[55835]
#define sipNameNr_QtFatalMsg 55846
#define sipName_QtFatalMsg &sipStrings_QtCore[55846]
#define sipNameNr_Rajasthani 55857
#define sipName_Rajasthani &sipStrings_QtCore[55857]
#define sipNameNr_RemovePath 55868
#define sipName_RemovePath &sipStrings_QtCore[55868]
#define sipNameNr_RemovePort 55879
#define sipName_RemovePort &sipStrings_QtCore[55879]
#define sipNameNr_RepeatTile 55890
#define sipName_RepeatTile &sipStrings_QtCore[55890]
#define sipNameNr_RightArrow 55901
#define sipName_RightArrow &sipStrings_QtCore[55901]
#define sipNameNr_SaintLucia 55912
#define sipName_SaintLucia &sipStrings_QtCore[55912]
#define sipNameNr_Saurashtra 25667
#define sipName_Saurashtra &sipStrings_QtCore[25667]
#define sipNameNr_Script_Han 55923
#define sipName_Script_Han &sipStrings_QtCore[55923]
#define sipNameNr_Script_Lao 55934
#define sipName_Script_Lao &sipStrings_QtCore[55934]
#define sipNameNr_Script_Mro 55945
#define sipName_Script_Mro &sipStrings_QtCore[55945]
#define sipNameNr_Script_Nko 55956
#define sipName_Script_Nko &sipStrings_QtCore[55956]
#define sipNameNr_Script_Vai 55967
#define sipName_Script_Vai &sipStrings_QtCore[55967]
#define sipNameNr_Seychelles 55978
#define sipName_Seychelles &sipStrings_QtCore[55978]
#define sipNameNr_SimpleType 24623
#define sipName_SimpleType &sipStrings_QtCore[24623]
#define sipNameNr_SoftHyphen 55989
#define sipName_SoftHyphen &sipStrings_QtCore[55989]
#define sipNameNr_SortByMask 56000
#define sipName_SortByMask &sipStrings_QtCore[56000]
#define sipNameNr_SouthKorea 56011
#define sipName_SouthKorea &sipStrings_QtCore[56011]
#define sipNameNr_SouthSudan 56022
#define sipName_SouthSudan &sipStrings_QtCore[56022]
#define sipNameNr_StrictMode 56033
#define sipName_StrictMode &sipStrings_QtCore[56033]
#define sipNameNr_SwampyCree 56044
#define sipName_SwampyCree &sipStrings_QtCore[56044]
#define sipNameNr_SystemTime 56055
#define sipName_SystemTime &sipStrings_QtCore[56055]
#define sipNameNr_TabletMove 56066
#define sipName_TabletMove &sipStrings_QtCore[56066]
#define sipNameNr_Tajikistan 56077
#define sipName_Tajikistan &sipStrings_QtCore[56077]
#define sipNameNr_TapGesture 56088
#define sipName_TapGesture &sipStrings_QtCore[56088]
#define sipNameNr_TaskButton 56099
#define sipName_TaskButton &sipStrings_QtCore[56099]
#define sipNameNr_TextFormat 37684
#define sipName_TextFormat &sipStrings_QtCore[37684]
#define sipNameNr_TextString 56110
#define sipName_TextString &sipStrings_QtCore[56110]
#define sipNameNr_ThaiScript 56121
#define sipName_ThaiScript &sipStrings_QtCore[56121]
#define sipNameNr_TimorLeste 56132
#define sipName_TimorLeste &sipStrings_QtCore[56132]
#define sipNameNr_TopSection 56143
#define sipName_TopSection &sipStrings_QtCore[56143]
#define sipNameNr_TouchBegin 56154
#define sipName_TouchBegin &sipStrings_QtCore[56154]
#define sipNameNr_UI_General 56165
#define sipName_UI_General &sipStrings_QtCore[56165]
#define sipNameNr_Unbuffered 56176
#define sipName_Unbuffered &sipStrings_QtCore[56176]
#define sipNameNr_Underscore 36679
#define sipName_Underscore &sipStrings_QtCore[36679]
#define sipNameNr_UnixTime_t 56187
#define sipName_UnixTime_t &sipStrings_QtCore[56187]
#define sipNameNr_Uzbekistan 56198
#define sipName_Uzbekistan &sipStrings_QtCore[56198]
#define sipNameNr_VarUnknown 56209
#define sipName_VarUnknown &sipStrings_QtCore[56209]
#define sipNameNr_VerPattern 56220
#define sipName_VerPattern &sipStrings_QtCore[56220]
#define sipNameNr_VerUnknown 56231
#define sipName_VerUnknown &sipStrings_QtCore[56231]
#define sipNameNr_Vietnamese 56242
#define sipName_Vietnamese &sipStrings_QtCore[56242]
#define sipNameNr_WA_LaidOut 56253
#define sipName_WA_LaidOut &sipStrings_QtCore[56253]
#define sipNameNr_WA_Resized 56264
#define sipName_WA_Resized &sipStrings_QtCore[56264]
#define sipNameNr_WA_SetFont 56275
#define sipName_WA_SetFont &sipStrings_QtCore[56275]
#define sipNameNr_WaitCursor 56286
#define sipName_WaitCursor &sipStrings_QtCore[56286]
#define sipNameNr_WheelFocus 56297
#define sipName_WheelFocus &sipStrings_QtCore[56297]
#define sipNameNr_WindowType 37699
#define sipName_WindowType &sipStrings_QtCore[37699]
#define sipNameNr_Windows8_1 56308
#define sipName_Windows8_1 &sipStrings_QtCore[56308]
#define sipNameNr_WithBraces 56319
#define sipName_WithBraces &sipStrings_QtCore[56319]
#define sipNameNr_WriteError 56330
#define sipName_WriteError &sipStrings_QtCore[56330]
#define sipNameNr_WriteGroup 56341
#define sipName_WriteGroup &sipStrings_QtCore[56341]
#define sipNameNr_WriteOther 56352
#define sipName_WriteOther &sipStrings_QtCore[56352]
#define sipNameNr_WriteOwner 56363
#define sipName_WriteOwner &sipStrings_QtCore[56363]
#define sipNameNr___fspath__ 56374
#define sipName___fspath__ &sipStrings_QtCore[56374]
#define sipNameNr___lshift__ 56385
#define sipName___lshift__ &sipStrings_QtCore[56385]
#define sipNameNr___rshift__ 56396
#define sipName___rshift__ &sipStrings_QtCore[56396]
#define sipNameNr_accessMode 56407
#define sipName_accessMode &sipStrings_QtCore[56407]
#define sipNameNr_addOptions 56418
#define sipName_addOptions &sipStrings_QtCore[56418]
#define sipNameNr_appendNull 56429
#define sipName_appendNull &sipStrings_QtCore[56429]
#define sipNameNr_attributes 56440
#define sipName_attributes &sipStrings_QtCore[56440]
#define sipNameNr_autoDelete 56451
#define sipName_autoDelete &sipStrings_QtCore[56451]
#define sipNameNr_autoRemove 56462
#define sipName_autoRemove &sipStrings_QtCore[56462]
#define sipNameNr_beginGroup 56473
#define sipName_beginGroup &sipStrings_QtCore[56473]
#define sipNameNr_bottomLeft 56484
#define sipName_bottomLeft &sipStrings_QtCore[56484]
#define sipNameNr_bundleName 56495
#define sipName_bundleName &sipStrings_QtCore[56495]
#define sipNameNr_bytesTotal 56506
#define sipName_bytesTotal &sipStrings_QtCore[56506]
#define sipNameNr_canConvert 56517
#define sipName_canConvert &sipStrings_QtCore[56517]
#define sipNameNr_checkIndex 56528
#define sipName_checkIndex &sipStrings_QtCore[56528]
#define sipNameNr_childEvent 56539
#define sipName_childEvent &sipStrings_QtCore[56539]
#define sipNameNr_createUuid 56550
#define sipName_createUuid &sipStrings_QtCore[56550]
#define sipNameNr_customType 56561
#define sipName_customType &sipStrings_QtCore[56561]
#define sipNameNr_darkYellow 56572
#define sipName_darkYellow &sipStrings_QtCore[56572]
#define sipNameNr_dateFormat 56583
#define sipName_dateFormat &sipStrings_QtCore[56583]
#define sipNameNr_daysInYear 56594
#define sipName_daysInYear &sipStrings_QtCore[56594]
#define sipNameNr_decodeData 56605
#define sipName_decodeData &sipStrings_QtCore[56605]
#define sipNameNr_decodeName 56616
#define sipName_decodeName &sipStrings_QtCore[56616]
#define sipNameNr_directions 56627
#define sipName_directions &sipStrings_QtCore[56627]
#define sipNameNr_disconnect 56638
#define sipName_disconnect &sipStrings_QtCore[56638]
#define sipNameNr_dotProduct 56649
#define sipName_dotProduct &sipStrings_QtCore[56649]
#define sipNameNr_encodeData 56660
#define sipName_encodeData &sipStrings_QtCore[56660]
#define sipNameNr_encodeName 56671
#define sipName_encodeName &sipStrings_QtCore[56671]
#define sipNameNr_enumerator 56682
#define sipName_enumerator &sipStrings_QtCore[56682]
#define sipNameNr_exitStatus 56693
#define sipName_exitStatus &sipStrings_QtCore[56693]
#define sipNameNr_expandedTo 56704
#define sipName_expandedTo &sipStrings_QtCore[56704]
#define sipNameNr_fieldWidth 56715
#define sipName_fieldWidth &sipStrings_QtCore[56715]
#define sipNameNr_filterRole 56726
#define sipName_filterRole &sipStrings_QtCore[56726]
#define sipNameNr_forcepoint 49119
#define sipName_forcepoint &sipStrings_QtCore[49119]
#define sipNameNr_fromBase64 56737
#define sipName_fromBase64 &sipStrings_QtCore[56737]
#define sipNameNr_fromString 56748
#define sipName_fromString &sipStrings_QtCore[56748]
#define sipNameNr_generate64 56759
#define sipName_generate64 &sipStrings_QtCore[56759]
#define sipNameNr_hasExpired 56770
#define sipName_hasExpired &sipStrings_QtCore[56770]
#define sipNameNr_hashLength 56781
#define sipName_hashLength &sipStrings_QtCore[56781]
#define sipNameNr_headerData 56792
#define sipName_headerData &sipStrings_QtCore[56792]
#define sipNameNr_insertRows 56803
#define sipName_insertRows &sipStrings_QtCore[56803]
#define sipNameNr_internalId 56814
#define sipName_internalId &sipStrings_QtCore[56814]
#define sipNameNr_intersects 56825
#define sipName_intersects &sipStrings_QtCore[56825]
#define sipNameNr_invalidate 56836
#define sipName_invalidate &sipStrings_QtCore[56836]
#define sipNameNr_isAbsolute 56847
#define sipName_isAbsolute &sipStrings_QtCore[56847]
#define sipNameNr_isAccepted 56858
#define sipName_isAccepted &sipStrings_QtCore[56858]
#define sipNameNr_isAttached 56869
#define sipName_isAttached &sipStrings_QtCore[56869]
#define sipNameNr_isBindable 56880
#define sipName_isBindable &sipStrings_QtCore[56880]
#define sipNameNr_isConstant 56891
#define sipName_isConstant &sipStrings_QtCore[56891]
#define sipNameNr_isDetached 56902
#define sipName_isDetached &sipStrings_QtCore[56902]
#define sipNameNr_isEnumType 56913
#define sipName_isEnumType &sipStrings_QtCore[56913]
#define sipNameNr_isFinished 56924
#define sipName_isFinished &sipStrings_QtCore[56924]
#define sipNameNr_isFlagType 56935
#define sipName_isFlagType &sipStrings_QtCore[56935]
#define sipNameNr_isJunction 56946
#define sipName_isJunction &sipStrings_QtCore[56946]
#define sipNameNr_isLeapYear 56957
#define sipName_isLeapYear &sipStrings_QtCore[56957]
#define sipNameNr_isOverride 56968
#define sipName_isOverride &sipStrings_QtCore[56968]
#define sipNameNr_isParentOf 56979
#define sipName_isParentOf &sipStrings_QtCore[56979]
#define sipNameNr_isPrefixOf 56990
#define sipName_isPrefixOf &sipStrings_QtCore[56990]
#define sipNameNr_isReadOnly 57001
#define sipName_isReadOnly &sipStrings_QtCore[57001]
#define sipNameNr_isReadable 57012
#define sipName_isReadable &sipStrings_QtCore[57012]
#define sipNameNr_isRelative 57023
#define sipName_isRelative &sipStrings_QtCore[57023]
#define sipNameNr_isRequired 57034
#define sipName_isRequired &sipStrings_QtCore[57034]
#define sipNameNr_isSelected 57045
#define sipName_isSelected &sipStrings_QtCore[57045]
#define sipNameNr_isShortcut 57056
#define sipName_isShortcut &sipStrings_QtCore[57056]
#define sipNameNr_isWritable 57067
#define sipName_isWritable &sipStrings_QtCore[57067]
#define sipNameNr_kernelType 57078
#define sipName_kernelType &sipStrings_QtCore[57078]
#define sipNameNr_keyToValue 57089
#define sipName_keyToValue &sipStrings_QtCore[57089]
#define sipNameNr_keyValueAt 57100
#define sipName_keyValueAt &sipStrings_QtCore[57100]
#define sipNameNr_lineNumber 57111
#define sipName_lineNumber &sipStrings_QtCore[57111]
#define sipNameNr_metaObject 57122
#define sipName_metaObject &sipStrings_QtCore[57122]
#define sipNameNr_methodType 57133
#define sipName_methodType &sipStrings_QtCore[57133]
#define sipNameNr_modelReset 57144
#define sipName_modelReset &sipStrings_QtCore[57144]
#define sipNameNr_moveBottom 57155
#define sipName_moveBottom &sipStrings_QtCore[57155]
#define sipNameNr_moveCenter 57166
#define sipName_moveCenter &sipStrings_QtCore[57166]
#define sipNameNr_moveColumn 49275
#define sipName_moveColumn &sipStrings_QtCore[49275]
#define sipNameNr_normalized 57177
#define sipName_normalized &sipStrings_QtCore[57177]
#define sipNameNr_noshowbase 57188
#define sipName_noshowbase &sipStrings_QtCore[57188]
#define sipNameNr_nullDevice 57199
#define sipName_nullDevice &sipStrings_QtCore[57199]
#define sipNameNr_objectName 57210
#define sipName_objectName &sipStrings_QtCore[57210]
#define sipNameNr_offsetData 57221
#define sipName_offsetData &sipStrings_QtCore[57221]
#define sipNameNr_permission 57232
#define sipName_permission &sipStrings_QtCore[57232]
#define sipNameNr_push_front 57243
#define sipName_push_front &sipStrings_QtCore[57243]
#define sipNameNr_queryItems 57254
#define sipName_queryItems &sipStrings_QtCore[57254]
#define sipNameNr_raiseError 57265
#define sipName_raiseError &sipStrings_QtCore[57265]
#define sipNameNr_readDouble 57276
#define sipName_readDouble &sipStrings_QtCore[57276]
#define sipNameNr_readString 57287
#define sipName_readString &sipStrings_QtCore[57287]
#define sipNameNr_readUInt16 57298
#define sipName_readUInt16 &sipStrings_QtCore[57298]
#define sipNameNr_readUInt32 57309
#define sipName_readUInt32 &sipStrings_QtCore[57309]
#define sipNameNr_readUInt64 57320
#define sipName_readUInt64 &sipStrings_QtCore[57320]
#define sipNameNr_removeLast 57331
#define sipName_removeLast &sipStrings_QtCore[57331]
#define sipNameNr_removePath 57342
#define sipName_removePath &sipStrings_QtCore[57342]
#define sipNameNr_removeRows 57353
#define sipName_removeRows &sipStrings_QtCore[57353]
#define sipNameNr_resetState 57364
#define sipName_resetState &sipStrings_QtCore[57364]
#define sipNameNr_resultView 57375
#define sipName_resultView &sipStrings_QtCore[57375]
#define sipNameNr_returnCode 57386
#define sipName_returnCode &sipStrings_QtCore[57386]
#define sipNameNr_returnType 57397
#define sipName_returnType &sipStrings_QtCore[57397]
#define sipNameNr_scientific 57408
#define sipName_scientific &sipStrings_QtCore[57408]
#define sipNameNr_setCaching 57419
#define sipName_setCaching &sipStrings_QtCore[57419]
#define sipNameNr_setCurrent 57430
#define sipName_setCurrent &sipStrings_QtCore[57430]
#define sipNameNr_setDefault 57441
#define sipName_setDefault &sipStrings_QtCore[57441]
#define sipNameNr_setEnabled 57452
#define sipName_setEnabled &sipStrings_QtCore[57452]
#define sipNameNr_setMapping 57463
#define sipName_setMapping &sipStrings_QtCore[57463]
#define sipNameNr_setPadChar 57474
#define sipName_setPadChar &sipStrings_QtCore[57474]
#define sipNameNr_setPattern 57485
#define sipName_setPattern &sipStrings_QtCore[57485]
#define sipNameNr_setProgram 57496
#define sipName_setProgram &sipStrings_QtCore[57496]
#define sipNameNr_setSorting 57507
#define sipName_setSorting &sipStrings_QtCore[57507]
#define sipNameNr_setTopLeft 57518
#define sipName_setTopLeft &sipStrings_QtCore[57518]
#define sipNameNr_setVersion 57529
#define sipName_setVersion &sipStrings_QtCore[57529]
#define sipNameNr_simplified 57540
#define sipName_simplified &sipStrings_QtCore[57540]
#define sipNameNr_singleShot 57551
#define sipName_singleShot &sipStrings_QtCore[57551]
#define sipNameNr_sortColumn 57562
#define sipName_sortColumn &sipStrings_QtCore[57562]
#define sipNameNr_startArray 57573
#define sipName_startArray &sipStrings_QtCore[57573]
#define sipNameNr_startFrame 57584
#define sipName_startFrame &sipStrings_QtCore[57584]
#define sipNameNr_startOfDay 57595
#define sipName_startOfDay &sipStrings_QtCore[57595]
#define sipNameNr_startTimer 57606
#define sipName_startTimer &sipStrings_QtCore[57606]
#define sipNameNr_startValue 57617
#define sipName_startValue &sipStrings_QtCore[57617]
#define sipNameNr_startingUp 57628
#define sipName_startingUp &sipStrings_QtCore[57628]
#define sipNameNr_startsWith 57639
#define sipName_startsWith &sipStrings_QtCore[57639]
#define sipNameNr_stringList 57650
#define sipName_stringList &sipStrings_QtCore[57650]
#define sipNameNr_superClass 57661
#define sipName_superClass &sipStrings_QtCore[57661]
#define sipNameNr_timeFormat 57672
#define sipName_timeFormat &sipStrings_QtCore[57672]
#define sipNameNr_timerEvent 57683
#define sipName_timerEvent &sipStrings_QtCore[57683]
#define sipNameNr_toCombined 57694
#define sipName_toCombined &sipStrings_QtCore[57694]
#define sipNameNr_toDateTime 57705
#define sipName_toDateTime &sipStrings_QtCore[57705]
#define sipNameNr_toLongLong 57716
#define sipName_toLongLong &sipStrings_QtCore[57716]
#define sipNameNr_toMarginsF 57727
#define sipName_toMarginsF &sipStrings_QtCore[57727]
#define sipNameNr_toTimeSpec 57738
#define sipName_toTimeSpec &sipStrings_QtCore[57738]
#define sipNameNr_toTimeZone 57749
#define sipName_toTimeZone &sipStrings_QtCore[57749]
#define sipNameNr_translated 57760
#define sipName_translated &sipStrings_QtCore[57760]
#define sipNameNr_transposed 57771
#define sipName_transposed &sipStrings_QtCore[57771]
#define sipNameNr_tryAcquire 57782
#define sipName_tryAcquire &sipStrings_QtCore[57782]
#define sipNameNr_unitVector 57793
#define sipName_unitVector &sipStrings_QtCore[57793]
#define sipNameNr_unsetError 57804
#define sipName_unsetError &sipStrings_QtCore[57804]
#define sipNameNr_valueToKey 57815
#define sipName_valueToKey &sipStrings_QtCore[57815]
#define sipNameNr_weekNumber 57826
#define sipName_weekNumber &sipStrings_QtCore[57826]
#define sipNameNr_writeBytes 57837
#define sipName_writeBytes &sipStrings_QtCore[57837]
#define sipNameNr_writeCDATA 57848
#define sipName_writeCDATA &sipStrings_QtCore[57848]
#define sipNameNr_writeFloat 57859
#define sipName_writeFloat &sipStrings_QtCore[57859]
#define sipNameNr_writeInt16 57870
#define sipName_writeInt16 &sipStrings_QtCore[57870]
#define sipNameNr_writeInt32 57881
#define sipName_writeInt32 &sipStrings_QtCore[57881]
#define sipNameNr_writeInt64 57892
#define sipName_writeInt64 &sipStrings_QtCore[57892]
#define sipNameNr_writeUInt8 57903
#define sipName_writeUInt8 &sipStrings_QtCore[57903]
#define sipNameNr_yearNumber 57914
#define sipName_yearNumber &sipStrings_QtCore[57914]
#define sipNameNr_Abkhazian 57925
#define sipName_Abkhazian &sipStrings_QtCore[57925]
#define sipNameNr_Advertise 57935
#define sipName_Advertise &sipStrings_QtCore[57935]
#define sipNameNr_Afrikaans 57945
#define sipName_Afrikaans &sipStrings_QtCore[57945]
#define sipNameNr_Algorithm 3978
#define sipName_Algorithm &sipStrings_QtCore[3978]
#define sipNameNr_AlignLeft 57955
#define sipName_AlignLeft &sipStrings_QtCore[57955]
#define sipNameNr_AllEvents 57965
#define sipName_AllEvents &sipStrings_QtCore[57965]
#define sipNameNr_AnchorTop 57975
#define sipName_AnchorTop &sipStrings_QtCore[57975]
#define sipNameNr_Android10 57985
#define sipName_Android10 &sipStrings_QtCore[57985]
#define sipNameNr_Android11 57995
#define sipName_Android11 &sipStrings_QtCore[57995]
#define sipNameNr_Android12 58005
#define sipName_Android12 &sipStrings_QtCore[58005]
#define sipNameNr_Android13 58015
#define sipName_Android13 &sipStrings_QtCore[58015]
#define sipNameNr_AnyScript 58025
#define sipName_AnyScript &sipStrings_QtCore[58025]
#define sipNameNr_Aragonese 58035
#define sipName_Aragonese &sipStrings_QtCore[58035]
#define sipNameNr_Argentina 58045
#define sipName_Argentina &sipStrings_QtCore[58045]
#define sipNameNr_ArrowType 42668
#define sipName_ArrowType &sipStrings_QtCore[42668]
#define sipNameNr_Australia 58055
#define sipName_Australia &sipStrings_QtCore[58055]
#define sipNameNr_AutoColor 58065
#define sipName_AutoColor &sipStrings_QtCore[58065]
#define sipNameNr_Base64url 24498
#define sipName_Base64url &sipStrings_QtCore[24498]
#define sipNameNr_BatakToba 58075
#define sipName_BatakToba &sipStrings_QtCore[58075]
#define sipNameNr_BevelJoin 58085
#define sipName_BevelJoin &sipStrings_QtCore[58085]
#define sipNameNr_BigEndian 58095
#define sipName_BigEndian &sipStrings_QtCore[58095]
#define sipNameNr_Bulgarian 58105
#define sipName_Bulgarian &sipStrings_QtCore[58105]
#define sipNameNr_ByteArray 9990
#define sipName_ByteArray &sipStrings_QtCore[9990]
#define sipNameNr_ByteOrder 12341
#define sipName_ByteOrder &sipStrings_QtCore[12341]
#define sipNameNr_COSE_Mac0 58115
#define sipName_COSE_Mac0 &sipStrings_QtCore[58115]
#define sipNameNr_COSE_Sign 58125
#define sipName_COSE_Sign &sipStrings_QtCore[58125]
#define sipNameNr_Cambodian 58135
#define sipName_Cambodian &sipStrings_QtCore[58135]
#define sipNameNr_Cantonese 58145
#define sipName_Cantonese &sipStrings_QtCore[58145]
#define sipNameNr_CapeVerde 58155
#define sipName_CapeVerde &sipStrings_QtCore[58155]
#define sipNameNr_Chickasaw 58165
#define sipName_Chickasaw &sipStrings_QtCore[58165]
#define sipNameNr_Clipboard 58175
#define sipName_Clipboard &sipStrings_QtCore[58175]
#define sipNameNr_ClockType 9365
#define sipName_ClockType &sipStrings_QtCore[9365]
#define sipNameNr_Colognian 58185
#define sipName_Colognian &sipStrings_QtCore[58185]
#define sipNameNr_ColorOnly 58195
#define sipName_ColorOnly &sipStrings_QtCore[58195]
#define sipNameNr_CopyError 58205
#define sipName_CopyError &sipStrings_QtCore[58205]
#define sipNameNr_CostaRica 58215
#define sipName_CostaRica &sipStrings_QtCore[58215]
#define sipNameNr_CrashExit 58225
#define sipName_CrashExit &sipStrings_QtCore[58225]
#define sipNameNr_DayOfWeek 39395
#define sipName_DayOfWeek &sipStrings_QtCore[39395]
#define sipNameNr_Direction 2775
#define sipName_Direction &sipStrings_QtCore[2775]
#define sipNameNr_DirsFirst 58235
#define sipName_DirsFirst &sipStrings_QtCore[58235]
#define sipNameNr_DownArrow 58245
#define sipName_DownArrow &sipStrings_QtCore[58245]
#define sipNameNr_DragEnter 11973
#define sipName_DragEnter &sipStrings_QtCore[11973]
#define sipNameNr_DragLeave 11996
#define sipName_DragLeave &sipStrings_QtCore[11996]
#define sipNameNr_EastTimor 58255
#define sipName_EastTimor &sipStrings_QtCore[58255]
#define sipNameNr_ElideLeft 58265
#define sipName_ElideLeft &sipStrings_QtCore[58265]
#define sipNameNr_ElideNone 58275
#define sipName_ElideNone &sipStrings_QtCore[58275]
#define sipNameNr_EndOfFile 58285
#define sipName_EndOfFile &sipStrings_QtCore[58285]
#define sipNameNr_EndOfItem 58295
#define sipName_EndOfItem &sipStrings_QtCore[58295]
#define sipNameNr_Esperanto 58305
#define sipName_Esperanto &sipStrings_QtCore[58305]
#define sipNameNr_Exception 58315
#define sipName_Exception &sipStrings_QtCore[58315]
#define sipNameNr_FileError 12364
#define sipName_FileError &sipStrings_QtCore[12364]
#define sipNameNr_ForceSign 58325
#define sipName_ForceSign &sipStrings_QtCore[58325]
#define sipNameNr_Gibraltar 58335
#define sipName_Gibraltar &sipStrings_QtCore[58335]
#define sipNameNr_GrabMouse 58345
#define sipName_GrabMouse &sipStrings_QtCore[58345]
#define sipNameNr_Greenland 58355
#define sipName_Greenland &sipStrings_QtCore[58355]
#define sipNameNr_Gregorian 53093
#define sipName_Gregorian &sipStrings_QtCore[53093]
#define sipNameNr_Guatemala 58365
#define sipName_Guatemala &sipStrings_QtCore[58365]
#define sipNameNr_HalfFloat 58375
#define sipName_HalfFloat &sipStrings_QtCore[58375]
#define sipNameNr_HanScript 17336
#define sipName_HanScript &sipStrings_QtCore[17336]
#define sipNameNr_HoverMove 12019
#define sipName_HoverMove &sipStrings_QtCore[12019]
#define sipNameNr_Hungarian 19697
#define sipName_Hungarian &sipStrings_QtCore[19697]
#define sipNameNr_Icelandic 58385
#define sipName_Icelandic &sipStrings_QtCore[58385]
#define sipNameNr_ImEnabled 58395
#define sipName_ImEnabled &sipStrings_QtCore[58395]
#define sipNameNr_InElastic 46780
#define sipName_InElastic &sipStrings_QtCore[46780]
#define sipNameNr_InOutBack 58405
#define sipName_InOutBack &sipStrings_QtCore[58405]
#define sipNameNr_InOutCirc 58415
#define sipName_InOutCirc &sipStrings_QtCore[58415]
#define sipNameNr_InOutExpo 58425
#define sipName_InOutExpo &sipStrings_QtCore[58425]
#define sipNameNr_InOutQuad 58435
#define sipName_InOutQuad &sipStrings_QtCore[58435]
#define sipNameNr_InOutSine 58445
#define sipName_InOutSine &sipStrings_QtCore[58445]
#define sipNameNr_InariSami 58455
#define sipName_InariSami &sipStrings_QtCore[58455]
#define sipNameNr_Indonesia 58465
#define sipName_Indonesia &sipStrings_QtCore[58465]
#define sipNameNr_IniFormat 58475
#define sipName_IniFormat &sipStrings_QtCore[58475]
#define sipNameNr_Inuktitut 58485
#define sipName_Inuktitut &sipStrings_QtCore[58485]
#define sipNameNr_IsPointer 58495
#define sipName_IsPointer &sipStrings_QtCore[58495]
#define sipNameNr_IsQmlList 58505
#define sipName_IsQmlList &sipStrings_QtCore[58505]
#define sipNameNr_IsleOfMan 58515
#define sipName_IsleOfMan &sipStrings_QtCore[58515]
#define sipNameNr_JolaFonyi 58525
#define sipName_JolaFonyi &sipStrings_QtCore[58525]
#define sipNameNr_Key_AltGr 58535
#define sipName_Key_AltGr &sipStrings_QtCore[58535]
#define sipNameNr_Key_Aring 58545
#define sipName_Key_Aring &sipStrings_QtCore[58545]
#define sipNameNr_Key_Clear 58555
#define sipName_Key_Clear &sipStrings_QtCore[58555]
#define sipNameNr_Key_Close 58565
#define sipName_Key_Close &sipStrings_QtCore[58565]
#define sipNameNr_Key_Colon 58575
#define sipName_Key_Colon &sipStrings_QtCore[58575]
#define sipNameNr_Key_Comma 58585
#define sipName_Key_Comma &sipStrings_QtCore[58585]
#define sipNameNr_Key_Eject 58595
#define sipName_Key_Eject &sipStrings_QtCore[58595]
#define sipNameNr_Key_Enter 58605
#define sipName_Key_Enter &sipStrings_QtCore[58605]
#define sipNameNr_Key_Equal 58615
#define sipName_Key_Equal &sipStrings_QtCore[58615]
#define sipNameNr_Key_Excel 58625
#define sipName_Key_Excel &sipStrings_QtCore[58625]
#define sipNameNr_Key_Green 58635
#define sipName_Key_Green &sipStrings_QtCore[58635]
#define sipNameNr_Key_Guide 58645
#define sipName_Key_Guide &sipStrings_QtCore[58645]
#define sipNameNr_Key_Kanji 58655
#define sipName_Key_Kanji &sipStrings_QtCore[58655]
#define sipNameNr_Key_Minus 58665
#define sipName_Key_Minus &sipStrings_QtCore[58665]
#define sipNameNr_Key_Music 58675
#define sipName_Key_Music &sipStrings_QtCore[58675]
#define sipNameNr_Key_Paste 58685
#define sipName_Key_Paste &sipStrings_QtCore[58685]
#define sipNameNr_Key_Pause 58695
#define sipName_Key_Pause &sipStrings_QtCore[58695]
#define sipNameNr_Key_Phone 58705
#define sipName_Key_Phone &sipStrings_QtCore[58705]
#define sipNameNr_Key_Print 58715
#define sipName_Key_Print &sipStrings_QtCore[58715]
#define sipNameNr_Key_Reply 58725
#define sipName_Key_Reply &sipStrings_QtCore[58725]
#define sipNameNr_Key_Right 58735
#define sipName_Key_Right &sipStrings_QtCore[58735]
#define sipNameNr_Key_Shift 58745
#define sipName_Key_Shift &sipStrings_QtCore[58745]
#define sipNameNr_Key_Slash 58755
#define sipName_Key_Slash &sipStrings_QtCore[58755]
#define sipNameNr_Key_Sleep 58765
#define sipName_Key_Sleep &sipStrings_QtCore[58765]
#define sipNameNr_Key_Space 58775
#define sipName_Key_Space &sipStrings_QtCore[58775]
#define sipNameNr_Key_Spell 58785
#define sipName_Key_Spell &sipStrings_QtCore[58785]
#define sipNameNr_Key_THORN 58795
#define sipName_Key_THORN &sipStrings_QtCore[58795]
#define sipNameNr_Key_Tools 58805
#define sipName_Key_Tools &sipStrings_QtCore[58805]
#define sipNameNr_Key_Video 58815
#define sipName_Key_Video &sipStrings_QtCore[58815]
#define sipNameNr_Key_acute 58825
#define sipName_Key_acute &sipStrings_QtCore[58825]
#define sipNameNr_Key_micro 58835
#define sipName_Key_micro &sipStrings_QtCore[58835]
#define sipNameNr_LaoScript 58845
#define sipName_LaoScript &sipStrings_QtCore[58845]
#define sipNameNr_LeftArrow 58855
#define sipName_LeftArrow &sipStrings_QtCore[58855]
#define sipNameNr_Lithuania 58865
#define sipName_Lithuania &sipStrings_QtCore[58865]
#define sipNameNr_LocalTime 53897
#define sipName_LocalTime &sipStrings_QtCore[53897]
#define sipNameNr_LockError 16832
#define sipName_LockError &sipStrings_QtCore[16832]
#define sipNameNr_LowGerman 58875
#define sipName_LowGerman &sipStrings_QtCore[58875]
#define sipNameNr_Macedonia 58885
#define sipName_Macedonia &sipStrings_QtCore[58885]
#define sipNameNr_Malayalam 29411
#define sipName_Malayalam &sipStrings_QtCore[29411]
#define sipNameNr_MatchFlag 42696
#define sipName_MatchFlag &sipStrings_QtCore[42696]
#define sipNameNr_MatchMode 9415
#define sipName_MatchMode &sipStrings_QtCore[9415]
#define sipNameNr_MatchType 4188
#define sipName_MatchType &sipStrings_QtCore[4188]
#define sipNameNr_MatchWrap 58895
#define sipName_MatchWrap &sipStrings_QtCore[58895]
#define sipNameNr_Mauritius 58905
#define sipName_Mauritius &sipStrings_QtCore[58905]
#define sipNameNr_Microsoft 58915
#define sipName_Microsoft &sipStrings_QtCore[58915]
#define sipNameNr_MiterJoin 47638
#define sipName_MiterJoin &sipStrings_QtCore[47638]
#define sipNameNr_Mongolian 29428
#define sipName_Mongolian &sipStrings_QtCore[29428]
#define sipNameNr_MouseMove 12042
#define sipName_MouseMove &sipStrings_QtCore[12042]
#define sipNameNr_MroScript 58925
#define sipName_MroScript &sipStrings_QtCore[58925]
#define sipNameNr_Ngiemboon 58935
#define sipName_Ngiemboon &sipStrings_QtCore[58935]
#define sipNameNr_Nheengatu 58945
#define sipName_Nheengatu &sipStrings_QtCore[58945]
#define sipNameNr_Nicaragua 58955
#define sipName_Nicaragua &sipStrings_QtCore[58955]
#define sipNameNr_NkoScript 58965
#define sipName_NkoScript &sipStrings_QtCore[58965]
#define sipNameNr_NoOptions 58975
#define sipName_NoOptions &sipStrings_QtCore[58975]
#define sipNameNr_NoSection 58985
#define sipName_NoSection &sipStrings_QtCore[58985]
#define sipNameNr_OkRequest 58995
#define sipName_OkRequest &sipStrings_QtCore[58995]
#define sipNameNr_OpenError 59005
#define sipName_OpenError &sipStrings_QtCore[59005]
#define sipNameNr_OutBounce 50381
#define sipName_OutBounce &sipStrings_QtCore[50381]
#define sipNameNr_OutInBack 59015
#define sipName_OutInBack &sipStrings_QtCore[59015]
#define sipNameNr_OutInCirc 59025
#define sipName_OutInCirc &sipStrings_QtCore[59025]
#define sipNameNr_OutInExpo 59035
#define sipName_OutInExpo &sipStrings_QtCore[59035]
#define sipNameNr_OutInQuad 59045
#define sipName_OutInQuad &sipStrings_QtCore[59045]
#define sipNameNr_OutInSine 59055
#define sipName_OutInSine &sipStrings_QtCore[59055]
#define sipNameNr_PlainText 59065
#define sipName_PlainText &sipStrings_QtCore[59065]
#define sipNameNr_Protected 59075
#define sipName_Protected &sipStrings_QtCore[59075]
#define sipNameNr_QBitArray 59085
#define sipName_QBitArray &sipStrings_QtCore[59085]
#define sipNameNr_QCalendar 59095
#define sipName_QCalendar &sipStrings_QtCore[59095]
#define sipNameNr_QCollator 59105
#define sipName_QCollator &sipStrings_QtCore[59105]
#define sipNameNr_QDateTime 59115
#define sipName_QDateTime &sipStrings_QtCore[59115]
#define sipNameNr_QFileInfo 59125
#define sipName_QFileInfo &sipStrings_QtCore[59125]
#define sipNameNr_QIODevice 59135
#define sipName_QIODevice &sipStrings_QtCore[59135]
#define sipNameNr_QLockFile 59145
#define sipName_QLockFile &sipStrings_QtCore[59145]
#define sipNameNr_QMarginsF 59155
#define sipName_QMarginsF &sipStrings_QtCore[59155]
#define sipNameNr_QMetaEnum 59165
#define sipName_QMetaEnum &sipStrings_QtCore[59165]
#define sipNameNr_QMetaType 59175
#define sipName_QMetaType &sipStrings_QtCore[59175]
#define sipNameNr_QMimeData 59185
#define sipName_QMimeData &sipStrings_QtCore[59185]
#define sipNameNr_QMimeType 59195
#define sipName_QMimeType &sipStrings_QtCore[59195]
#define sipNameNr_QPolygonF 59205
#define sipName_QPolygonF &sipStrings_QtCore[59205]
#define sipNameNr_QResource 59215
#define sipName_QResource &sipStrings_QtCore[59215]
#define sipNameNr_QRunnable 59225
#define sipName_QRunnable &sipStrings_QtCore[59225]
#define sipNameNr_QSaveFile 59235
#define sipName_QSaveFile &sipStrings_QtCore[59235]
#define sipNameNr_QSettings 59245
#define sipName_QSettings &sipStrings_QtCore[59245]
#define sipNameNr_QTimeLine 59255
#define sipName_QTimeLine &sipStrings_QtCore[59255]
#define sipNameNr_QTimeZone 59265
#define sipName_QTimeZone &sipStrings_QtCore[59265]
#define sipNameNr_QUrlQuery 59275
#define sipName_QUrlQuery &sipStrings_QtCore[59275]
#define sipNameNr_QVector2D 59285
#define sipName_QVector2D &sipStrings_QtCore[59285]
#define sipNameNr_QVector3D 59295
#define sipName_QVector3D &sipStrings_QtCore[59295]
#define sipNameNr_QVector4D 59305
#define sipName_QVector4D &sipStrings_QtCore[59305]
#define sipNameNr_QtInfoMsg 59315
#define sipName_QtInfoMsg &sipStrings_QtCore[59315]
#define sipNameNr_QtMsgType 59325
#define sipName_QtMsgType &sipStrings_QtCore[59325]
#define sipNameNr_ReadError 59335
#define sipName_ReadError &sipStrings_QtCore[59335]
#define sipNameNr_ReadGroup 59345
#define sipName_ReadGroup &sipStrings_QtCore[59345]
#define sipNameNr_ReadOther 59355
#define sipName_ReadOther &sipStrings_QtCore[59355]
#define sipNameNr_ReadOwner 59365
#define sipName_ReadOwner &sipStrings_QtCore[59365]
#define sipNameNr_ReadWrite 59375
#define sipName_ReadWrite &sipStrings_QtCore[59375]
#define sipNameNr_Recursive 36950
#define sipName_Recursive &sipStrings_QtCore[36950]
#define sipNameNr_RightEdge 59385
#define sipName_RightEdge &sipStrings_QtCore[59385]
#define sipNameNr_RoundJoin 59395
#define sipName_RoundJoin &sipStrings_QtCore[59395]
#define sipNameNr_RoundTile 59405
#define sipName_RoundTile &sipStrings_QtCore[59405]
#define sipNameNr_SanMarino 59415
#define sipName_SanMarino &sipStrings_QtCore[59415]
#define sipNameNr_Sardinian 59425
#define sipName_Sardinian &sipStrings_QtCore[59425]
#define sipNameNr_Script_Yi 59435
#define sipName_Script_Yi &sipStrings_QtCore[59435]
#define sipNameNr_ScrollEnd 59445
#define sipName_ScrollEnd &sipStrings_QtCore[59445]
#define sipNameNr_ShortName 59455
#define sipName_ShortName &sipStrings_QtCore[59455]
#define sipNameNr_SichuanYi 59465
#define sipName_SichuanYi &sipStrings_QtCore[59465]
#define sipNameNr_Signature 20357
#define sipName_Signature &sipStrings_QtCore[20357]
#define sipNameNr_SineCurve 59475
#define sipName_SineCurve &sipStrings_QtCore[59475]
#define sipNameNr_Singapore 59485
#define sipName_Singapore &sipStrings_QtCore[59485]
#define sipNameNr_SkoltSami 59495
#define sipName_SkoltSami &sipStrings_QtCore[59495]
#define sipNameNr_Slovenian 59505
#define sipName_Slovenian &sipStrings_QtCore[59505]
#define sipNameNr_SolidLine 59515
#define sipName_SolidLine &sipStrings_QtCore[59515]
#define sipNameNr_SortOrder 42710
#define sipName_SortOrder &sipStrings_QtCore[42710]
#define sipNameNr_SquareCap 59525
#define sipName_SquareCap &sipStrings_QtCore[59525]
#define sipNameNr_Stateless 59535
#define sipName_Stateless &sipStrings_QtCore[59535]
#define sipNameNr_StatusTip 59545
#define sipName_StatusTip &sipStrings_QtCore[59545]
#define sipNameNr_SubWindow 59555
#define sipName_SubWindow &sipStrings_QtCore[59555]
#define sipNameNr_Sundanese 29598
#define sipName_Sundanese &sipStrings_QtCore[29598]
#define sipNameNr_Swaziland 59565
#define sipName_Swaziland &sipStrings_QtCore[59565]
#define sipNameNr_TCBSpline 59575
#define sipName_TCBSpline &sipStrings_QtCore[59575]
#define sipNameNr_Tachelhit 59585
#define sipName_Tachelhit &sipStrings_QtCore[59585]
#define sipNameNr_TestsPath 59595
#define sipName_TestsPath &sipStrings_QtCore[59595]
#define sipNameNr_TimerInfo 1433
#define sipName_TimerInfo &sipStrings_QtCore[1433]
#define sipNameNr_TimerType 42724
#define sipName_TimerType &sipStrings_QtCore[42724]
#define sipNameNr_TokenType 5880
#define sipName_TokenType &sipStrings_QtCore[5880]
#define sipNameNr_ULongLong 53909
#define sipName_ULongLong &sipStrings_QtCore[53909]
#define sipNameNr_Ukrainian 59605
#define sipName_Ukrainian &sipStrings_QtCore[59605]
#define sipNameNr_Unchecked 59615
#define sipName_Unchecked &sipStrings_QtCore[59615]
#define sipNameNr_Undefined 11243
#define sipName_Undefined &sipStrings_QtCore[11243]
#define sipNameNr_UnixEpoch 59625
#define sipName_UnixEpoch &sipStrings_QtCore[59625]
#define sipNameNr_UserScope 59635
#define sipName_UserScope &sipStrings_QtCore[59635]
#define sipNameNr_VaiScript 59645
#define sipName_VaiScript &sipStrings_QtCore[59645]
#define sipNameNr_Venezuela 59655
#define sipName_Venezuela &sipStrings_QtCore[59655]
#define sipNameNr_WA_Mapped 59665
#define sipName_WA_Mapped &sipStrings_QtCore[59665]
#define sipNameNr_Wednesday 59675
#define sipName_Wednesday &sipStrings_QtCore[59675]
#define sipNameNr_WhatsThis 22790
#define sipName_WhatsThis &sipStrings_QtCore[22790]
#define sipNameNr_WhenInUse 59685
#define sipName_WhenInUse &sipStrings_QtCore[59685]
#define sipNameNr_Windows10 59695
#define sipName_Windows10 &sipStrings_QtCore[59695]
#define sipNameNr_Windows11 59705
#define sipName_Windows11 &sipStrings_QtCore[59705]
#define sipNameNr_WriteOnly 59715
#define sipName_WriteOnly &sipStrings_QtCore[59715]
#define sipNameNr_WriteUser 59725
#define sipName_WriteUser &sipStrings_QtCore[59725]
#define sipNameNr_YearRange 16727
#define sipName_YearRange &sipStrings_QtCore[16727]
#define sipNameNr___enter__ 59735
#define sipName___enter__ &sipStrings_QtCore[59735]
#define sipNameNr_activated 11720
#define sipName_activated &sipStrings_QtCore[11720]
#define sipNameNr_addMonths 59745
#define sipName_addMonths &sipStrings_QtCore[59745]
#define sipNameNr_addOption 59755
#define sipName_addOption &sipStrings_QtCore[59755]
#define sipNameNr_algorithm 59765
#define sipName_algorithm &sipStrings_QtCore[59765]
#define sipNameNr_amplitude 59775
#define sipName_amplitude &sipStrings_QtCore[59775]
#define sipNameNr_arguments 59785
#define sipName_arguments &sipStrings_QtCore[59785]
#define sipNameNr_authority 59795
#define sipName_authority &sipStrings_QtCore[59795]
#define sipNameNr_available 59805
#define sipName_available &sipStrings_QtCore[59805]
#define sipNameNr_bcp47Name 59815
#define sipName_bcp47Name &sipStrings_QtCore[59815]
#define sipNameNr_behaviour 59825
#define sipName_behaviour &sipStrings_QtCore[59825]
#define sipNameNr_birthTime 59835
#define sipName_birthTime &sipStrings_QtCore[59835]
#define sipNameNr_blockSize 59845
#define sipName_blockSize &sipStrings_QtCore[59845]
#define sipNameNr_boundedTo 59855
#define sipName_boundedTo &sipStrings_QtCore[59855]
#define sipNameNr_byteOrder 59865
#define sipName_byteOrder &sipStrings_QtCore[59865]
#define sipNameNr_bytesFree 59875
#define sipName_bytesFree &sipStrings_QtCore[59875]
#define sipNameNr_childKeys 59885
#define sipName_childKeys &sipStrings_QtCore[59885]
#define sipNameNr_classInfo 59895
#define sipName_classInfo &sipStrings_QtCore[59895]
#define sipNameNr_className 59905
#define sipName_className &sipStrings_QtCore[59905]
#define sipNameNr_cleanPath 59915
#define sipName_cleanPath &sipStrings_QtCore[59915]
#define sipNameNr_clearData 59925
#define sipName_clearData &sipStrings_QtCore[59925]
#define sipNameNr_clockType 59935
#define sipName_clockType &sipStrings_QtCore[59935]
#define sipNameNr_codeTypes 59945
#define sipName_codeTypes &sipStrings_QtCore[59945]
#define sipNameNr_collation 59955
#define sipName_collation &sipStrings_QtCore[59955]
#define sipNameNr_colorData 59965
#define sipName_colorData &sipStrings_QtCore[59965]
#define sipNameNr_constData 59975
#define sipName_constData &sipStrings_QtCore[59975]
#define sipNameNr_darkGreen 59985
#define sipName_darkGreen &sipStrings_QtCore[59985]
#define sipNameNr_dayOfWeek 59995
#define sipName_dayOfWeek &sipStrings_QtCore[59995]
#define sipNameNr_dayOfYear 60005
#define sipName_dayOfYear &sipStrings_QtCore[60005]
#define sipNameNr_destroyed 60015
#define sipName_destroyed &sipStrings_QtCore[60015]
#define sipNameNr_direction 60025
#define sipName_direction &sipStrings_QtCore[60025]
#define sipNameNr_directory 60035
#define sipName_directory &sipStrings_QtCore[60035]
#define sipNameNr_entryList 60045
#define sipName_entryList &sipStrings_QtCore[60045]
#define sipNameNr_errorText 60055
#define sipName_errorText &sipStrings_QtCore[60055]
#define sipNameNr_eventType 60065
#define sipName_eventType &sipStrings_QtCore[60065]
#define sipNameNr_fetchMore 60075
#define sipName_fetchMore &sipStrings_QtCore[60075]
#define sipNameNr_findChild 60085
#define sipName_findChild &sipStrings_QtCore[60085]
#define sipNameNr_forcesign 53297
#define sipName_forcesign &sipStrings_QtCore[53297]
#define sipNameNr_fromPolar 60095
#define sipName_fromPolar &sipStrings_QtCore[60095]
#define sipNameNr_getCoords 60105
#define sipName_getCoords &sipStrings_QtCore[60105]
#define sipNameNr_hasFormat 60115
#define sipName_hasFormat &sipStrings_QtCore[60115]
#define sipNameNr_imageData 60125
#define sipName_imageData &sipStrings_QtCore[60125]
#define sipNameNr_insertRow 60135
#define sipName_insertRow &sipStrings_QtCore[60135]
#define sipNameNr_interrupt 60145
#define sipName_interrupt &sipStrings_QtCore[60145]
#define sipNameNr_isComment 60155
#define sipName_isComment &sipStrings_QtCore[60155]
#define sipNameNr_isDefault 60165
#define sipName_isDefault &sipStrings_QtCore[60165]
#define sipNameNr_isEnabled 60175
#define sipName_isEnabled &sipStrings_QtCore[60175]
#define sipNameNr_isFloat16 60185
#define sipName_isFloat16 &sipStrings_QtCore[60185]
#define sipNameNr_isForever 60195
#define sipName_isForever &sipStrings_QtCore[60195]
#define sipNameNr_isInteger 60205
#define sipName_isInteger &sipStrings_QtCore[60205]
#define sipNameNr_isInvalid 60215
#define sipName_isInvalid &sipStrings_QtCore[60215]
#define sipNameNr_isLibrary 60225
#define sipName_isLibrary &sipStrings_QtCore[60225]
#define sipNameNr_isOrdered 60235
#define sipName_isOrdered &sipStrings_QtCore[60235]
#define sipNameNr_isRunning 60245
#define sipName_isRunning &sipStrings_QtCore[60245]
#define sipNameNr_isSymLink 60255
#define sipName_isSymLink &sipStrings_QtCore[60255]
#define sipNameNr_isVirtual 60265
#define sipName_isVirtual &sipStrings_QtCore[60265]
#define sipNameNr_keyValues 60275
#define sipName_keyValues &sipStrings_QtCore[60275]
#define sipNameNr_killTimer 60285
#define sipName_killTimer &sipStrings_QtCore[60285]
#define sipNameNr_lastError 60295
#define sipName_lastError &sipStrings_QtCore[60295]
#define sipNameNr_lightGray 60305
#define sipName_lightGray &sipStrings_QtCore[60305]
#define sipNameNr_loadHints 60315
#define sipName_loadHints &sipStrings_QtCore[60315]
#define sipNameNr_locateAll 60325
#define sipName_locateAll &sipStrings_QtCore[60325]
#define sipNameNr_loopCount 60335
#define sipName_loopCount &sipStrings_QtCore[60335]
#define sipNameNr_loopLevel 60345
#define sipName_loopLevel &sipStrings_QtCore[60345]
#define sipNameNr_mappedInt 60355
#define sipName_mappedInt &sipStrings_QtCore[60355]
#define sipNameNr_matchType 60365
#define sipName_matchType &sipStrings_QtCore[60365]
#define sipNameNr_matchView 60375
#define sipName_matchView &sipStrings_QtCore[60375]
#define sipNameNr_maxLength 60385
#define sipName_maxLength &sipStrings_QtCore[60385]
#define sipNameNr_mimeTypes 60395
#define sipName_mimeTypes &sipStrings_QtCore[60395]
#define sipNameNr_monthName 60405
#define sipName_monthName &sipStrings_QtCore[60405]
#define sipNameNr_moveRight 60415
#define sipName_moveRight &sipStrings_QtCore[60415]
#define sipNameNr_multiData 60425
#define sipName_multiData &sipStrings_QtCore[60425]
#define sipNameNr_nativeKey 60435
#define sipName_nativeKey &sipStrings_QtCore[60435]
#define sipNameNr_overshoot 60445
#define sipName_overshoot &sipStrings_QtCore[60445]
#define sipNameNr_postEvent 60455
#define sipName_postEvent &sipStrings_QtCore[60455]
#define sipNameNr_precision 60465
#define sipName_precision &sipStrings_QtCore[60465]
#define sipNameNr_processId 60475
#define sipName_processId &sipStrings_QtCore[60475]
#define sipNameNr_push_back 60485
#define sipName_push_back &sipStrings_QtCore[60485]
#define sipNameNr_qChecksum 60495
#define sipName_qChecksum &sipStrings_QtCore[60495]
#define sipNameNr_qCompress 60505
#define sipName_qCompress &sipStrings_QtCore[60505]
#define sipNameNr_qCritical 60515
#define sipName_qCritical &sipStrings_QtCore[60515]
#define sipNameNr_qIsFinite 60525
#define sipName_qIsFinite &sipStrings_QtCore[60525]
#define sipNameNr_qYieldCpu 60535
#define sipName_qYieldCpu &sipStrings_QtCore[60535]
#define sipNameNr_readBytes 60545
#define sipName_readBytes &sipStrings_QtCore[60545]
#define sipNameNr_readFloat 60555
#define sipName_readFloat &sipStrings_QtCore[60555]
#define sipNameNr_readInt16 60565
#define sipName_readInt16 &sipStrings_QtCore[60565]
#define sipNameNr_readInt32 60575
#define sipName_readInt32 &sipStrings_QtCore[60575]
#define sipNameNr_readInt64 60585
#define sipName_readInt64 &sipStrings_QtCore[60585]
#define sipNameNr_readUInt8 60595
#define sipName_readUInt8 &sipStrings_QtCore[60595]
#define sipNameNr_readyRead 60605
#define sipName_readyRead &sipStrings_QtCore[60605]
#define sipNameNr_receivers 60615
#define sipName_receivers &sipStrings_QtCore[60615]
#define sipNameNr_removeAll 60625
#define sipName_removeAll &sipStrings_QtCore[60625]
#define sipNameNr_removeRow 60635
#define sipName_removeRow &sipStrings_QtCore[60635]
#define sipNameNr_roleNames 60645
#define sipName_roleNames &sipStrings_QtCore[60645]
#define sipNameNr_rowsMoved 60655
#define sipName_rowsMoved &sipStrings_QtCore[60655]
#define sipNameNr_segmentAt 60665
#define sipName_segmentAt &sipStrings_QtCore[60665]
#define sipNameNr_selection 60675
#define sipName_selection &sipStrings_QtCore[60675]
#define sipNameNr_semaphore 60685
#define sipName_semaphore &sipStrings_QtCore[60685]
#define sipNameNr_sendEvent 60695
#define sipName_sendEvent &sipStrings_QtCore[60695]
#define sipNameNr_separator 60705
#define sipName_separator &sipStrings_QtCore[60705]
#define sipNameNr_setBottom 60715
#define sipName_setBottom &sipStrings_QtCore[60715]
#define sipNameNr_setBuffer 60725
#define sipName_setBuffer &sipStrings_QtCore[60725]
#define sipNameNr_setCoords 60735
#define sipName_setCoords &sipStrings_QtCore[60735]
#define sipNameNr_setDevice 60745
#define sipName_setDevice &sipStrings_QtCore[60745]
#define sipNameNr_setFilter 60755
#define sipName_setFilter &sipStrings_QtCore[60755]
#define sipNameNr_setHeight 60765
#define sipName_setHeight &sipStrings_QtCore[60765]
#define sipNameNr_setLength 60775
#define sipName_setLength &sipStrings_QtCore[60775]
#define sipNameNr_setLocale 60785
#define sipName_setLocale &sipStrings_QtCore[60785]
#define sipNameNr_setObject 60795
#define sipName_setObject &sipStrings_QtCore[60795]
#define sipNameNr_setParent 60805
#define sipName_setParent &sipStrings_QtCore[60805]
#define sipNameNr_setPaused 60815
#define sipName_setPaused &sipStrings_QtCore[60815]
#define sipNameNr_setPeriod 60825
#define sipName_setPeriod &sipStrings_QtCore[60825]
#define sipNameNr_setPoints 60835
#define sipName_setPoints &sipStrings_QtCore[60835]
#define sipNameNr_setScheme 60845
#define sipName_setScheme &sipStrings_QtCore[60845]
#define sipNameNr_setSocket 60855
#define sipName_setSocket &sipStrings_QtCore[60855]
#define sipNameNr_setStatus 53489
#define sipName_setStatus &sipStrings_QtCore[53489]
#define sipNameNr_sortOrder 60865
#define sipName_sortOrder &sipStrings_QtCore[60865]
#define sipNameNr_stackSize 60875
#define sipName_stackSize &sipStrings_QtCore[60875]
#define sipNameNr_subvolume 60885
#define sipName_subvolume &sipStrings_QtCore[60885]
#define sipNameNr_takeFirst 60895
#define sipName_takeFirst &sipStrings_QtCore[60895]
#define sipNameNr_terminate 60905
#define sipName_terminate &sipStrings_QtCore[60905]
#define sipNameNr_territory 60915
#define sipName_territory &sipStrings_QtCore[60915]
#define sipNameNr_timerType 60925
#define sipName_timerType &sipStrings_QtCore[60925]
#define sipNameNr_toEncoded 60935
#define sipName_toEncoded &sipStrings_QtCore[60935]
#define sipNameNr_toInteger 60945
#define sipName_toInteger &sipStrings_QtCore[60945]
#define sipNameNr_toMargins 60955
#define sipName_toMargins &sipStrings_QtCore[60955]
#define sipNameNr_toRfc4122 60965
#define sipName_toRfc4122 &sipStrings_QtCore[60965]
#define sipNameNr_toVariant 60975
#define sipName_toVariant &sipStrings_QtCore[60975]
#define sipNameNr_toggleBit 60985
#define sipName_toggleBit &sipStrings_QtCore[60985]
#define sipNameNr_tokenType 60995
#define sipName_tokenType &sipStrings_QtCore[60995]
#define sipNameNr_translate 61005
#define sipName_translate &sipStrings_QtCore[61005]
#define sipNameNr_transpose 61015
#define sipName_transpose &sipStrings_QtCore[61015]
#define sipNameNr_ungetChar 61025
#define sipName_ungetChar &sipStrings_QtCore[61025]
#define sipNameNr_valueName 61035
#define sipName_valueName &sipStrings_QtCore[61035]
#define sipNameNr_writeBool 61045
#define sipName_writeBool &sipStrings_QtCore[61045]
#define sipNameNr_writeData 61055
#define sipName_writeData &sipStrings_QtCore[61055]
#define sipNameNr_writeInt8 61065
#define sipName_writeInt8 &sipStrings_QtCore[61065]
#define sipNameNr_zeroDigit 61075
#define sipName_zeroDigit &sipStrings_QtCore[61075]
#define sipNameNr_Accuracy 4129
#define sipName_Accuracy &sipStrings_QtCore[4129]
#define sipNameNr_Akkadian 61085
#define sipName_Akkadian &sipStrings_QtCore[61085]
#define sipNameNr_Albanian 9516
#define sipName_Albanian &sipStrings_QtCore[9516]
#define sipNameNr_AlignTop 61094
#define sipName_AlignTop &sipStrings_QtCore[61094]
#define sipNameNr_Anguilla 61103
#define sipName_Anguilla &sipStrings_QtCore[61103]
#define sipNameNr_Armenian 33214
#define sipName_Armenian &sipStrings_QtCore[33214]
#define sipNameNr_Assamese 61112
#define sipName_Assamese &sipStrings_QtCore[61112]
#define sipNameNr_Asturian 61121
#define sipName_Asturian &sipStrings_QtCore[61121]
#define sipNameNr_AutoText 61130
#define sipName_AutoText &sipStrings_QtCore[61130]
#define sipNameNr_Backward 61139
#define sipName_Backward &sipStrings_QtCore[61139]
#define sipNameNr_Balinese 33230
#define sipName_Balinese &sipStrings_QtCore[33230]
#define sipNameNr_Barbados 61148
#define sipName_Barbados &sipStrings_QtCore[61148]
#define sipNameNr_Bhojpuri 61157
#define sipName_Bhojpuri &sipStrings_QtCore[61157]
#define sipNameNr_Bigfloat 61166
#define sipName_Bigfloat &sipStrings_QtCore[61166]
#define sipNameNr_Botswana 61175
#define sipName_Botswana &sipStrings_QtCore[61175]
#define sipNameNr_Buginese 33278
#define sipName_Buginese &sipStrings_QtCore[33278]
#define sipNameNr_Bulgaria 61184
#define sipName_Bulgaria &sipStrings_QtCore[61184]
#define sipNameNr_COSE_Mac 61193
#define sipName_COSE_Mac &sipStrings_QtCore[61193]
#define sipNameNr_Cambodia 61202
#define sipName_Cambodia &sipStrings_QtCore[61202]
#define sipNameNr_Cameroon 61211
#define sipName_Cameroon &sipStrings_QtCore[61211]
#define sipNameNr_Chamorro 61220
#define sipName_Chamorro &sipStrings_QtCore[61220]
#define sipNameNr_Cherokee 33294
#define sipName_Cherokee &sipStrings_QtCore[33294]
#define sipNameNr_Colombia 61229
#define sipName_Colombia &sipStrings_QtCore[61229]
#define sipNameNr_Corsican 61238
#define sipName_Corsican &sipStrings_QtCore[61238]
#define sipNameNr_Croatian 61247
#define sipName_Croatian &sipStrings_QtCore[61247]
#define sipNameNr_DashLine 35676
#define sipName_DashLine &sipStrings_QtCore[35676]
#define sipNameNr_DataPath 45052
#define sipName_DataPath &sipStrings_QtCore[45052]
#define sipNameNr_Deselect 61256
#define sipName_Deselect &sipStrings_QtCore[61256]
#define sipNameNr_DirsLast 61265
#define sipName_DirsLast &sipStrings_QtCore[61265]
#define sipNameNr_Djibouti 61274
#define sipName_Djibouti &sipStrings_QtCore[61274]
#define sipNameNr_Dominica 61283
#define sipName_Dominica &sipStrings_QtCore[61283]
#define sipNameNr_DragMove 13780
#define sipName_DragMove &sipStrings_QtCore[13780]
#define sipNameNr_Dzongkha 61292
#define sipName_Dzongkha &sipStrings_QtCore[61292]
#define sipNameNr_EditRole 61301
#define sipName_EditRole &sipStrings_QtCore[61301]
#define sipNameNr_Encoding 6948
#define sipName_Encoding &sipStrings_QtCore[6948]
#define sipNameNr_Estonian 61310
#define sipName_Estonian &sipStrings_QtCore[61310]
#define sipNameNr_Eswatini 61319
#define sipName_Eswatini &sipStrings_QtCore[61319]
#define sipNameNr_Ethiopia 61328
#define sipName_Ethiopia &sipStrings_QtCore[61328]
#define sipNameNr_ExactHit 61337
#define sipName_ExactHit &sipStrings_QtCore[61337]
#define sipNameNr_ExeGroup 61346
#define sipName_ExeGroup &sipStrings_QtCore[61346]
#define sipNameNr_ExeOther 61355
#define sipName_ExeOther &sipStrings_QtCore[61355]
#define sipNameNr_ExeOwner 61364
#define sipName_ExeOwner &sipStrings_QtCore[61364]
#define sipNameNr_FileOpen 61373
#define sipName_FileOpen &sipStrings_QtCore[61373]
#define sipNameNr_FileTime 14242
#define sipName_FileTime &sipStrings_QtCore[14242]
#define sipNameNr_Filipino 61382
#define sipName_Filipino &sipStrings_QtCore[61382]
#define sipNameNr_FillRule 47054
#define sipName_FillRule &sipStrings_QtCore[47054]
#define sipNameNr_FocusOut 61391
#define sipName_FocusOut &sipStrings_QtCore[61391]
#define sipNameNr_FontRole 61400
#define sipName_FontRole &sipStrings_QtCore[61400]
#define sipNameNr_Friulian 61409
#define sipName_Friulian &sipStrings_QtCore[61409]
#define sipNameNr_FuzzyHit 61418
#define sipName_FuzzyHit &sipStrings_QtCore[61418]
#define sipNameNr_Galician 61427
#define sipName_Galician &sipStrings_QtCore[61427]
#define sipNameNr_Georgian 33358
#define sipName_Georgian &sipStrings_QtCore[33358]
#define sipNameNr_Grapheme 61436
#define sipName_Grapheme &sipStrings_QtCore[61436]
#define sipNameNr_Guernsey 61445
#define sipName_Guernsey &sipStrings_QtCore[61445]
#define sipNameNr_Gujarati 33374
#define sipName_Gujarati &sipStrings_QtCore[33374]
#define sipNameNr_Haryanvi 61454
#define sipName_Haryanvi &sipStrings_QtCore[61454]
#define sipNameNr_Hawaiian 61463
#define sipName_Hawaiian &sipStrings_QtCore[61463]
#define sipNameNr_HiriMotu 61472
#define sipName_HiriMotu &sipStrings_QtCore[61472]
#define sipNameNr_Honduras 61481
#define sipName_Honduras &sipStrings_QtCore[61481]
#define sipNameNr_HongKong 61490
#define sipName_HongKong &sipStrings_QtCore[61490]
#define sipNameNr_IconDrag 61499
#define sipName_IconDrag &sipStrings_QtCore[61499]
#define sipNameNr_InBounce 51414
#define sipName_InBounce &sipStrings_QtCore[51414]
#define sipNameNr_Indented 61508
#define sipName_Indented &sipStrings_QtCore[61508]
#define sipNameNr_ItemFlag 47067
#define sipName_ItemFlag &sipStrings_QtCore[47067]
#define sipNameNr_Japanese 61517
#define sipName_Japanese &sipStrings_QtCore[61517]
#define sipNameNr_Javanese 33422
#define sipName_Javanese &sipStrings_QtCore[33422]
#define sipNameNr_Kaingang 61526
#define sipName_Kaingang &sipStrings_QtCore[61526]
#define sipNameNr_Kalenjin 61535
#define sipName_Kalenjin &sipStrings_QtCore[61535]
#define sipNameNr_Kashmiri 61544
#define sipName_Kashmiri &sipStrings_QtCore[61544]
#define sipNameNr_KeyError 61553
#define sipName_KeyError &sipStrings_QtCore[61553]
#define sipNameNr_KeyPress 61562
#define sipName_KeyPress &sipStrings_QtCore[61562]
#define sipNameNr_Key_Away 61571
#define sipName_Key_Away &sipStrings_QtCore[61571]
#define sipNameNr_Key_Back 61580
#define sipName_Key_Back &sipStrings_QtCore[61580]
#define sipNameNr_Key_Blue 61589
#define sipName_Key_Blue &sipStrings_QtCore[61589]
#define sipNameNr_Key_Book 61598
#define sipName_Key_Book &sipStrings_QtCore[61598]
#define sipNameNr_Key_Call 61607
#define sipName_Key_Call &sipStrings_QtCore[61607]
#define sipNameNr_Key_Copy 61616
#define sipName_Key_Copy &sipStrings_QtCore[61616]
#define sipNameNr_Key_Down 61625
#define sipName_Key_Down &sipStrings_QtCore[61625]
#define sipNameNr_Key_Exit 61634
#define sipName_Key_Exit &sipStrings_QtCore[61634]
#define sipNameNr_Key_Find 61643
#define sipName_Key_Find &sipStrings_QtCore[61643]
#define sipNameNr_Key_Flip 61652
#define sipName_Key_Flip &sipStrings_QtCore[61652]
#define sipNameNr_Key_Game 61661
#define sipName_Key_Game &sipStrings_QtCore[61661]
#define sipNameNr_Key_Help 61670
#define sipName_Key_Help &sipStrings_QtCore[61670]
#define sipNameNr_Key_Home 61679
#define sipName_Key_Home &sipStrings_QtCore[61679]
#define sipNameNr_Key_Info 61688
#define sipName_Key_Info &sipStrings_QtCore[61688]
#define sipNameNr_Key_Left 61697
#define sipName_Key_Left &sipStrings_QtCore[61697]
#define sipNameNr_Key_Less 61706
#define sipName_Key_Less &sipStrings_QtCore[61706]
#define sipNameNr_Key_Memo 61715
#define sipName_Key_Memo &sipStrings_QtCore[61715]
#define sipNameNr_Key_Menu 61724
#define sipName_Key_Menu &sipStrings_QtCore[61724]
#define sipNameNr_Key_Meta 61733
#define sipName_Key_Meta &sipStrings_QtCore[61733]
#define sipNameNr_Key_News 61742
#define sipName_Key_News &sipStrings_QtCore[61742]
#define sipNameNr_Key_Open 61751
#define sipName_Key_Open &sipStrings_QtCore[61751]
#define sipNameNr_Key_Play 61760
#define sipName_Key_Play &sipStrings_QtCore[61760]
#define sipNameNr_Key_Plus 61769
#define sipName_Key_Plus &sipStrings_QtCore[61769]
#define sipNameNr_Key_Redo 61778
#define sipName_Key_Redo &sipStrings_QtCore[61778]
#define sipNameNr_Key_Save 61787
#define sipName_Key_Save &sipStrings_QtCore[61787]
#define sipNameNr_Key_Send 61796
#define sipName_Key_Send &sipStrings_QtCore[61796]
#define sipNameNr_Key_Shop 61805
#define sipName_Key_Shop &sipStrings_QtCore[61805]
#define sipNameNr_Key_Stop 61814
#define sipName_Key_Stop &sipStrings_QtCore[61814]
#define sipNameNr_Key_Time 61823
#define sipName_Key_Time &sipStrings_QtCore[61823]
#define sipNameNr_Key_Undo 61832
#define sipName_Key_Undo &sipStrings_QtCore[61832]
#define sipNameNr_Key_View 61841
#define sipName_Key_View &sipStrings_QtCore[61841]
#define sipNameNr_Key_WLAN 61850
#define sipName_Key_WLAN &sipStrings_QtCore[61850]
#define sipNameNr_Key_Word 61859
#define sipName_Key_Word &sipStrings_QtCore[61859]
#define sipNameNr_Key_Xfer 61868
#define sipName_Key_Xfer &sipStrings_QtCore[61868]
#define sipNameNr_Key_Zoom 61877
#define sipName_Key_Zoom &sipStrings_QtCore[61877]
#define sipNameNr_Key_cent 61886
#define sipName_Key_cent &sipStrings_QtCore[61886]
#define sipNameNr_Kiribati 61895
#define sipName_Kiribati &sipStrings_QtCore[61895]
#define sipNameNr_Kuanyama 61904
#define sipName_Kuanyama &sipStrings_QtCore[61904]
#define sipNameNr_Kwanyama 61913
#define sipName_Kwanyama &sipStrings_QtCore[61913]
#define sipNameNr_Language 15909
#define sipName_Language &sipStrings_QtCore[15909]
#define sipNameNr_LeftEdge 61922
#define sipName_LeftEdge &sipStrings_QtCore[61922]
#define sipNameNr_Lezghian 61931
#define sipName_Lezghian &sipStrings_QtCore[61931]
#define sipNameNr_Ligurian 61940
#define sipName_Ligurian &sipStrings_QtCore[61940]
#define sipNameNr_LoadHint 22069
#define sipName_LoadHint &sipStrings_QtCore[22069]
#define sipNameNr_LongLong 53910
#define sipName_LongLong &sipStrings_QtCore[53910]
#define sipNameNr_LongName 61949
#define sipName_LongName &sipStrings_QtCore[61949]
#define sipNameNr_LuleSami 61958
#define sipName_LuleSami &sipStrings_QtCore[61958]
#define sipNameNr_Maithili 61967
#define sipName_Maithili &sipStrings_QtCore[61967]
#define sipNameNr_Malagasy 61976
#define sipName_Malagasy &sipStrings_QtCore[61976]
#define sipNameNr_Malaysia 61985
#define sipName_Malaysia &sipStrings_QtCore[61985]
#define sipNameNr_Maldives 61994
#define sipName_Maldives &sipStrings_QtCore[61994]
#define sipNameNr_Mandingo 62003
#define sipName_Mandingo &sipStrings_QtCore[62003]
#define sipNameNr_Manipuri 62012
#define sipName_Manipuri &sipStrings_QtCore[62012]
#define sipNameNr_MaskMode 47080
#define sipName_MaskMode &sipStrings_QtCore[47080]
#define sipNameNr_MetaCall 62021
#define sipName_MetaCall &sipStrings_QtCore[62021]
#define sipNameNr_Modified 26173
#define sipName_Modified &sipStrings_QtCore[26173]
#define sipNameNr_Modifier 17022
#define sipName_Modifier &sipStrings_QtCore[17022]
#define sipNameNr_Mongolia 62030
#define sipName_Mongolia &sipStrings_QtCore[62030]
#define sipNameNr_MonoOnly 62039
#define sipName_MonoOnly &sipStrings_QtCore[62039]
#define sipNameNr_Morisyen 62048
#define sipName_Morisyen &sipStrings_QtCore[62048]
#define sipNameNr_Muscogee 62057
#define sipName_Muscogee &sipStrings_QtCore[62057]
#define sipNameNr_NameType 19258
#define sipName_NameType &sipStrings_QtCore[19258]
#define sipNameNr_NoButton 62066
#define sipName_NoButton &sipStrings_QtCore[62066]
#define sipNameNr_NoDotDot 62075
#define sipName_NoDotDot &sipStrings_QtCore[62075]
#define sipNameNr_NoFilter 62084
#define sipName_NoFilter &sipStrings_QtCore[62084]
#define sipNameNr_NoOption 62093
#define sipName_NoOption &sipStrings_QtCore[62093]
#define sipNameNr_NoUpdate 62102
#define sipName_NoUpdate &sipStrings_QtCore[62102]
#define sipNameNr_NonModal 62111
#define sipName_NonModal &sipStrings_QtCore[62111]
#define sipNameNr_NotFound 62120
#define sipName_NotFound &sipStrings_QtCore[62120]
#define sipNameNr_Nyankole 62129
#define sipName_Nyankole &sipStrings_QtCore[62129]
#define sipNameNr_OldIrish 62138
#define sipName_OldIrish &sipStrings_QtCore[62138]
#define sipNameNr_OldNorse 62147
#define sipName_OldNorse &sipStrings_QtCore[62147]
#define sipNameNr_OutCubic 54473
#define sipName_OutCubic &sipStrings_QtCore[54473]
#define sipNameNr_OutCurve 62156
#define sipName_OutCurve &sipStrings_QtCore[62156]
#define sipNameNr_OutQuart 54484
#define sipName_OutQuart &sipStrings_QtCore[54484]
#define sipNameNr_OutQuint 54495
#define sipName_OutQuint &sipStrings_QtCore[54495]
#define sipNameNr_Pakistan 62165
#define sipName_Pakistan &sipStrings_QtCore[62165]
#define sipNameNr_Paraguay 62174
#define sipName_Paraguay &sipStrings_QtCore[62174]
#define sipNameNr_PenStyle 47106
#define sipName_PenStyle &sipStrings_QtCore[47106]
#define sipNameNr_Pitcairn 62183
#define sipName_Pitcairn &sipStrings_QtCore[62183]
#define sipNameNr_Portugal 62192
#define sipName_Portugal &sipStrings_QtCore[62192]
#define sipNameNr_Priority 17295
#define sipName_Priority &sipStrings_QtCore[17295]
#define sipNameNr_Prussian 62201
#define sipName_Prussian &sipStrings_QtCore[62201]
#define sipNameNr_QCborMap 62210
#define sipName_QCborMap &sipStrings_QtCore[62210]
#define sipNameNr_QLibrary 62219
#define sipName_QLibrary &sipStrings_QtCore[62219]
#define sipNameNr_QMargins 62228
#define sipName_QMargins &sipStrings_QtCore[62228]
#define sipNameNr_QPalette 62237
#define sipName_QPalette &sipStrings_QtCore[62237]
#define sipNameNr_QPolygon 62246
#define sipName_QPolygon &sipStrings_QtCore[62246]
#define sipNameNr_QProcess 62255
#define sipName_QProcess &sipStrings_QtCore[62255]
#define sipNameNr_QSysInfo 62264
#define sipName_QSysInfo &sipStrings_QtCore[62264]
#define sipNameNr_QVariant 44909
#define sipName_QVariant &sipStrings_QtCore[44909]
#define sipNameNr_Qt__Axis 62273
#define sipName_Qt__Axis &sipStrings_QtCore[62273]
#define sipNameNr_Qt__Edge 62282
#define sipName_Qt__Edge &sipStrings_QtCore[62282]
#define sipNameNr_ReadOnly 54462
#define sipName_ReadOnly &sipStrings_QtCore[54462]
#define sipNameNr_ReadUser 62291
#define sipName_ReadUser &sipStrings_QtCore[62291]
#define sipNameNr_Readable 57014
#define sipName_Readable &sipStrings_QtCore[57014]
#define sipNameNr_Reserved 35736
#define sipName_Reserved &sipStrings_QtCore[35736]
#define sipNameNr_ResetIds 62300
#define sipName_ResetIds &sipStrings_QtCore[62300]
#define sipNameNr_Reversed 62309
#define sipName_Reversed &sipStrings_QtCore[62309]
#define sipNameNr_RichText 62318
#define sipName_RichText &sipStrings_QtCore[62318]
#define sipNameNr_Rohingya 14704
#define sipName_Rohingya &sipStrings_QtCore[14704]
#define sipNameNr_Romanian 62327
#define sipName_Romanian &sipStrings_QtCore[62327]
#define sipNameNr_RoundCap 62336
#define sipName_RoundCap &sipStrings_QtCore[62336]
#define sipNameNr_Sanskrit 62345
#define sipName_Sanskrit &sipStrings_QtCore[62345]
#define sipNameNr_Saturday 62354
#define sipName_Saturday &sipStrings_QtCore[62354]
#define sipNameNr_Sentence 62363
#define sipName_Sentence &sipStrings_QtCore[62363]
#define sipNameNr_Sha3_224 62372
#define sipName_Sha3_224 &sipStrings_QtCore[62372]
#define sipNameNr_Sha3_256 62381
#define sipName_Sha3_256 &sipStrings_QtCore[62381]
#define sipNameNr_Sha3_384 62390
#define sipName_Sha3_384 &sipStrings_QtCore[62390]
#define sipNameNr_Sha3_512 62399
#define sipName_Sha3_512 &sipStrings_QtCore[62399]
#define sipNameNr_Shambala 62408
#define sipName_Shambala &sipStrings_QtCore[62408]
#define sipNameNr_Shortcut 7218
#define sipName_Shortcut &sipStrings_QtCore[7218]
#define sipNameNr_ShowBase 62417
#define sipName_ShowBase &sipStrings_QtCore[62417]
#define sipNameNr_Sicilian 62426
#define sipName_Sicilian &sipStrings_QtCore[62426]
#define sipNameNr_Silesian 62435
#define sipName_Silesian &sipStrings_QtCore[62435]
#define sipNameNr_SizeHint 47119
#define sipName_SizeHint &sipStrings_QtCore[47119]
#define sipNameNr_SizeMode 47132
#define sipName_SizeMode &sipStrings_QtCore[47132]
#define sipNameNr_Slovakia 62444
#define sipName_Slovakia &sipStrings_QtCore[62444]
#define sipNameNr_Slovenia 62453
#define sipName_Slovenia &sipStrings_QtCore[62453]
#define sipNameNr_SortFlag 37356
#define sipName_SortFlag &sipStrings_QtCore[37356]
#define sipNameNr_SriLanka 62462
#define sipName_SriLanka &sipStrings_QtCore[62462]
#define sipNameNr_Starting 62471
#define sipName_Starting &sipStrings_QtCore[62471]
#define sipNameNr_Suriname 62480
#define sipName_Suriname &sipStrings_QtCore[62480]
#define sipNameNr_TabFocus 55518
#define sipName_TabFocus &sipStrings_QtCore[55518]
#define sipNameNr_Tahitian 62489
#define sipName_Tahitian &sipStrings_QtCore[62489]
#define sipNameNr_Tanzania 62498
#define sipName_Tanzania &sipStrings_QtCore[62498]
#define sipNameNr_TextDate 62507
#define sipName_TextDate &sipStrings_QtCore[62507]
#define sipNameNr_TextFlag 47145
#define sipName_TextFlag &sipStrings_QtCore[47145]
#define sipNameNr_Thailand 62516
#define sipName_Thailand &sipStrings_QtCore[62516]
#define sipNameNr_Thursday 62525
#define sipName_Thursday &sipStrings_QtCore[62525]
#define sipNameNr_Tigrinya 62534
#define sipName_Tigrinya &sipStrings_QtCore[62534]
#define sipNameNr_TileRule 47158
#define sipName_TileRule &sipStrings_QtCore[47158]
#define sipNameNr_TimeSpec 47171
#define sipName_TimeSpec &sipStrings_QtCore[47171]
#define sipNameNr_TimeType 19278
#define sipName_TimeType &sipStrings_QtCore[19278]
#define sipNameNr_TimeZone 40281
#define sipName_TimeZone &sipStrings_QtCore[40281]
#define sipNameNr_Timedout 62543
#define sipName_Timedout &sipStrings_QtCore[62543]
#define sipNameNr_TokPisin 62552
#define sipName_TokPisin &sipStrings_QtCore[62552]
#define sipNameNr_TokiPona 62561
#define sipName_TokiPona &sipStrings_QtCore[62561]
#define sipNameNr_TouchEnd 62570
#define sipName_TouchEnd &sipStrings_QtCore[62570]
#define sipNameNr_Truncate 62579
#define sipName_Truncate &sipStrings_QtCore[62579]
#define sipNameNr_TypeFlag 19158
#define sipName_TypeFlag &sipStrings_QtCore[19158]
#define sipNameNr_TypeMask 62588
#define sipName_TypeMask &sipStrings_QtCore[62588]
#define sipNameNr_UIEffect 47184
#define sipName_UIEffect &sipStrings_QtCore[47184]
#define sipNameNr_Ugaritic 33518
#define sipName_Ugaritic &sipStrings_QtCore[33518]
#define sipNameNr_Unsorted 62597
#define sipName_Unsorted &sipStrings_QtCore[62597]
#define sipNameNr_UseVFork 62606
#define sipName_UseVFork &sipStrings_QtCore[62606]
#define sipNameNr_UserRole 62615
#define sipName_UserRole &sipStrings_QtCore[62615]
#define sipNameNr_Venetian 62624
#define sipName_Venetian &sipStrings_QtCore[62624]
#define sipNameNr_Vertical 62633
#define sipName_Vertical &sipStrings_QtCore[62633]
#define sipNameNr_VoidStar 62642
#define sipName_VoidStar &sipStrings_QtCore[62642]
#define sipNameNr_WA_Hover 62651
#define sipName_WA_Hover &sipStrings_QtCore[62651]
#define sipNameNr_WA_Moved 62660
#define sipName_WA_Moved &sipStrings_QtCore[62660]
#define sipNameNr_Warlpiri 62669
#define sipName_Warlpiri &sipStrings_QtCore[62669]
#define sipNameNr_Windows7 62678
#define sipName_Windows7 &sipStrings_QtCore[62678]
#define sipNameNr_Windows8 62687
#define sipName_Windows8 &sipStrings_QtCore[62687]
#define sipNameNr_Wolaytta 62696
#define sipName_Wolaytta &sipStrings_QtCore[62696]
#define sipNameNr_WordSize 62705
#define sipName_WordSize &sipStrings_QtCore[62705]
#define sipNameNr_Writable 57069
#define sipName_Writable &sipStrings_QtCore[57069]
#define sipNameNr_WriteBom 62714
#define sipName_WriteBom &sipStrings_QtCore[62714]
#define sipNameNr_XButton1 62723
#define sipName_XButton1 &sipStrings_QtCore[62723]
#define sipNameNr_XButton2 62732
#define sipName_XButton2 &sipStrings_QtCore[62732]
#define sipNameNr_YiScript 62741
#define sipName_YiScript &sipStrings_QtCore[62741]
#define sipNameNr_Zimbabwe 62750
#define sipName_Zimbabwe &sipStrings_QtCore[62750]
#define sipNameNr___bool__ 62759
#define sipName___bool__ &sipStrings_QtCore[62759]
#define sipNameNr___call__ 62768
#define sipName___call__ &sipStrings_QtCore[62768]
#define sipNameNr___exit__ 62777
#define sipName___exit__ &sipStrings_QtCore[62777]
#define sipNameNr___hash__ 62786
#define sipName___hash__ &sipStrings_QtCore[62786]
#define sipNameNr___iadd__ 62795
#define sipName___iadd__ &sipStrings_QtCore[62795]
#define sipNameNr___iand__ 62804
#define sipName___iand__ &sipStrings_QtCore[62804]
#define sipNameNr___imul__ 62813
#define sipName___imul__ &sipStrings_QtCore[62813]
#define sipNameNr___isub__ 62822
#define sipName___isub__ &sipStrings_QtCore[62822]
#define sipNameNr___ixor__ 62831
#define sipName___ixor__ &sipStrings_QtCore[62831]
#define sipNameNr___repr__ 62840
#define sipName___repr__ &sipStrings_QtCore[62840]
#define sipNameNr_accuracy 62849
#define sipName_accuracy &sipStrings_QtCore[62849]
#define sipNameNr_addMSecs 62858
#define sipName_addMSecs &sipStrings_QtCore[62858]
#define sipNameNr_addNSecs 62867
#define sipName_addNSecs &sipStrings_QtCore[62867]
#define sipNameNr_addPaths 62876
#define sipName_addPaths &sipStrings_QtCore[62876]
#define sipNameNr_addPause 62885
#define sipName_addPause &sipStrings_QtCore[62885]
#define sipNameNr_addYears 62894
#define sipName_addYears &sipStrings_QtCore[62894]
#define sipNameNr_adjusted 62903
#define sipName_adjusted &sipStrings_QtCore[62903]
#define sipNameNr_baseName 62912
#define sipName_baseName &sipStrings_QtCore[62912]
#define sipNameNr_baseYear 62921
#define sipName_baseYear &sipStrings_QtCore[62921]
#define sipNameNr_buildAbi 62930
#define sipName_buildAbi &sipStrings_QtCore[62930]
#define sipNameNr_capacity 62939
#define sipName_capacity &sipStrings_QtCore[62939]
#define sipNameNr_captured 62948
#define sipName_captured &sipStrings_QtCore[62948]
#define sipNameNr_category 62957
#define sipName_category &sipStrings_QtCore[62957]
#define sipNameNr_children 62966
#define sipName_children &sipStrings_QtCore[62966]
#define sipNameNr_clearBit 62975
#define sipName_clearBit &sipStrings_QtCore[62975]
#define sipNameNr_contains 62984
#define sipName_contains &sipStrings_QtCore[62984]
#define sipNameNr_critical 62993
#define sipName_critical &sipStrings_QtCore[62993]
#define sipNameNr_darkBlue 63002
#define sipName_darkBlue &sipStrings_QtCore[63002]
#define sipNameNr_darkCyan 63011
#define sipName_darkCyan &sipStrings_QtCore[63011]
#define sipNameNr_darkGray 63020
#define sipName_darkGray &sipStrings_QtCore[63020]
#define sipNameNr_deadline 63029
#define sipName_deadline &sipStrings_QtCore[63029]
#define sipNameNr_duration 63038
#define sipName_duration &sipStrings_QtCore[63038]
#define sipNameNr_editable 63047
#define sipName_editable &sipStrings_QtCore[63047]
#define sipNameNr_encoding 63056
#define sipName_encoding &sipStrings_QtCore[63056]
#define sipNameNr_endArray 63065
#define sipName_endArray &sipStrings_QtCore[63065]
#define sipNameNr_endFrame 63074
#define sipName_endFrame &sipStrings_QtCore[63074]
#define sipNameNr_endGroup 63083
#define sipName_endGroup &sipStrings_QtCore[63083]
#define sipNameNr_endOfDay 63092
#define sipName_endOfDay &sipStrings_QtCore[63092]
#define sipNameNr_endValue 63101
#define sipName_endValue &sipStrings_QtCore[63101]
#define sipNameNr_endsWith 63110
#define sipName_endsWith &sipStrings_QtCore[63110]
#define sipNameNr_enumName 63119
#define sipName_enumName &sipStrings_QtCore[63119]
#define sipNameNr_exitCode 63128
#define sipName_exitCode &sipStrings_QtCore[63128]
#define sipNameNr_fileInfo 63137
#define sipName_fileInfo &sipStrings_QtCore[63137]
#define sipNameNr_fileName 63146
#define sipName_fileName &sipStrings_QtCore[63146]
#define sipNameNr_filePath 63155
#define sipName_filePath &sipStrings_QtCore[63155]
#define sipNameNr_fileTime 63164
#define sipName_fileTime &sipStrings_QtCore[63164]
#define sipNameNr_finished 63173
#define sipName_finished &sipStrings_QtCore[63173]
#define sipNameNr_fragment 63182
#define sipName_fragment &sipStrings_QtCore[63182]
#define sipNameNr_fromBits 63191
#define sipName_fromBits &sipStrings_QtCore[63191]
#define sipNameNr_fromJson 63200
#define sipName_fromJson &sipStrings_QtCore[63200]
#define sipNameNr_fromName 63209
#define sipName_fromName &sipStrings_QtCore[63209]
#define sipNameNr_function 63218
#define sipName_function &sipStrings_QtCore[63218]
#define sipNameNr_generate 63227
#define sipName_generate &sipStrings_QtCore[63227]
#define sipNameNr_hasColor 63236
#define sipName_hasColor &sipStrings_QtCore[63236]
#define sipNameNr_hasError 63245
#define sipName_hasError &sipStrings_QtCore[63245]
#define sipNameNr_hasImage 63254
#define sipName_hasImage &sipStrings_QtCore[63254]
#define sipNameNr_hasIndex 63263
#define sipName_hasIndex &sipStrings_QtCore[63263]
#define sipNameNr_hasMatch 63272
#define sipName_hasMatch &sipStrings_QtCore[63272]
#define sipNameNr_hasQuery 63281
#define sipName_hasQuery &sipStrings_QtCore[63281]
#define sipNameNr_helpText 63290
#define sipName_helpText &sipStrings_QtCore[63290]
#define sipNameNr_homePath 63299
#define sipName_homePath &sipStrings_QtCore[63299]
#define sipNameNr_iconName 63308
#define sipName_iconName &sipStrings_QtCore[63308]
#define sipNameNr_inherits 63317
#define sipName_inherits &sipStrings_QtCore[63317]
#define sipNameNr_instance 63326
#define sipName_instance &sipStrings_QtCore[63326]
#define sipNameNr_interval 63335
#define sipName_interval &sipStrings_QtCore[63335]
#define sipNameNr_isActive 63344
#define sipName_isActive &sipStrings_QtCore[63344]
#define sipNameNr_isBundle 63353
#define sipName_isBundle &sipStrings_QtCore[63353]
#define sipNameNr_isDouble 63362
#define sipName_isDouble &sipStrings_QtCore[63362]
#define sipNameNr_isHidden 63371
#define sipName_isHidden &sipStrings_QtCore[63371]
#define sipNameNr_isLoaded 63380
#define sipName_isLoaded &sipStrings_QtCore[63380]
#define sipNameNr_isLocked 63389
#define sipName_isLocked &sipStrings_QtCore[63389]
#define sipNameNr_isObject 63398
#define sipName_isObject &sipStrings_QtCore[63398]
#define sipNameNr_isScoped 63407
#define sipName_isScoped &sipStrings_QtCore[63407]
#define sipNameNr_isStored 63416
#define sipName_isStored &sipStrings_QtCore[63416]
#define sipNameNr_isString 63425
#define sipName_isString &sipStrings_QtCore[63425]
#define sipNameNr_itemData 63434
#define sipName_itemData &sipStrings_QtCore[63434]
#define sipNameNr_keyCount 63443
#define sipName_keyCount &sipStrings_QtCore[63443]
#define sipNameNr_language 63452
#define sipName_language &sipStrings_QtCore[63452]
#define sipNameNr_lastRead 63461
#define sipName_lastRead &sipStrings_QtCore[63461]
#define sipNameNr_lessThan 63470
#define sipName_lessThan &sipStrings_QtCore[63470]
#define sipNameNr_max_size 63479
#define sipName_max_size &sipStrings_QtCore[63479]
#define sipNameNr_metaType 63488
#define sipName_metaType &sipStrings_QtCore[63488]
#define sipNameNr_mimeData 63497
#define sipName_mimeData &sipStrings_QtCore[63497]
#define sipNameNr_moveLeft 63506
#define sipName_moveLeft &sipStrings_QtCore[63506]
#define sipNameNr_moveRows 34078
#define sipName_moveRows &sipStrings_QtCore[34078]
#define sipNameNr_nameType 63515
#define sipName_nameType &sipStrings_QtCore[63515]
#define sipNameNr_openMode 63524
#define sipName_openMode &sipStrings_QtCore[63524]
#define sipNameNr_optimize 63533
#define sipName_optimize &sipStrings_QtCore[63533]
#define sipNameNr_password 63542
#define sipName_password &sipStrings_QtCore[63542]
#define sipNameNr_peekNext 63551
#define sipName_peekNext &sipStrings_QtCore[63551]
#define sipNameNr_polished 63560
#define sipName_polished &sipStrings_QtCore[63560]
#define sipNameNr_position 63569
#define sipName_position &sipStrings_QtCore[63569]
#define sipNameNr_priority 63578
#define sipName_priority &sipStrings_QtCore[63578]
#define sipNameNr_property 63587
#define sipName_property &sipStrings_QtCore[63587]
#define sipNameNr_publicId 63596
#define sipName_publicId &sipStrings_QtCore[63596]
#define sipNameNr_pyqtEnum 63605
#define sipName_pyqtEnum &sipStrings_QtCore[63605]
#define sipNameNr_pyqtSlot 63614
#define sipName_pyqtSlot &sipStrings_QtCore[63614]
#define sipNameNr_qRound64 63623
#define sipName_qRound64 &sipStrings_QtCore[63623]
#define sipNameNr_qVersion 63632
#define sipName_qVersion &sipStrings_QtCore[63632]
#define sipNameNr_qWarning 63641
#define sipName_qWarning &sipStrings_QtCore[63641]
#define sipNameNr_quintptr 63650
#define sipName_quintptr &sipStrings_QtCore[63650]
#define sipNameNr_readBool 63659
#define sipName_readBool &sipStrings_QtCore[63659]
#define sipNameNr_readData 63668
#define sipName_readData &sipStrings_QtCore[63668]
#define sipNameNr_readInt8 63677
#define sipName_readInt8 &sipStrings_QtCore[63677]
#define sipNameNr_readLine 63686
#define sipName_readLine &sipStrings_QtCore[63686]
#define sipNameNr_readNext 63695
#define sipName_readNext &sipStrings_QtCore[63695]
#define sipNameNr_receiver 63704
#define sipName_receiver &sipStrings_QtCore[63704]
#define sipNameNr_removeAt 63713
#define sipName_removeAt &sipStrings_QtCore[63713]
#define sipNameNr_repeated 63722
#define sipName_repeated &sipStrings_QtCore[63722]
#define sipNameNr_resolved 63731
#define sipName_resolved &sipStrings_QtCore[63731]
#define sipNameNr_revision 63740
#define sipName_revision &sipStrings_QtCore[63740]
#define sipNameNr_rootPath 63749
#define sipName_rootPath &sipStrings_QtCore[63749]
#define sipNameNr_rowCount 63758
#define sipName_rowCount &sipStrings_QtCore[63758]
#define sipNameNr_segments 63767
#define sipName_segments &sipStrings_QtCore[63767]
#define sipNameNr_setAngle 63776
#define sipName_setAngle &sipStrings_QtCore[63776]
#define sipNameNr_setArray 63785
#define sipName_setArray &sipStrings_QtCore[63785]
#define sipNameNr_setFlags 63794
#define sipName_setFlags &sipStrings_QtCore[63794]
#define sipNameNr_setModel 34094
#define sipName_setModel &sipStrings_QtCore[34094]
#define sipNameNr_setQuery 63803
#define sipName_setQuery &sipStrings_QtCore[63803]
#define sipNameNr_setRight 63812
#define sipName_setRight &sipStrings_QtCore[63812]
#define sipNameNr_setValue 63821
#define sipName_setValue &sipStrings_QtCore[63821]
#define sipNameNr_setWidth 63830
#define sipName_setWidth &sipStrings_QtCore[63830]
#define sipNameNr_showHelp 63839
#define sipName_showHelp &sipStrings_QtCore[63839]
#define sipNameNr_showbase 57190
#define sipName_showbase &sipStrings_QtCore[57190]
#define sipNameNr_shrunkBy 63848
#define sipName_shrunkBy &sipStrings_QtCore[63848]
#define sipNameNr_skipData 63857
#define sipName_skipData &sipStrings_QtCore[63857]
#define sipNameNr_sortRole 63866
#define sipName_sortRole &sipStrings_QtCore[63866]
#define sipNameNr_standard 63875
#define sipName_standard &sipStrings_QtCore[63875]
#define sipNameNr_startMap 63884
#define sipName_startMap &sipStrings_QtCore[63884]
#define sipNameNr_suffixes 63893
#define sipName_suffixes &sipStrings_QtCore[63893]
#define sipNameNr_systemId 63902
#define sipName_systemId &sipStrings_QtCore[63902]
#define sipNameNr_takeLast 63911
#define sipName_takeLast &sipStrings_QtCore[63911]
#define sipNameNr_tempPath 63920
#define sipName_tempPath &sipStrings_QtCore[63920]
#define sipNameNr_timeSpec 63929
#define sipName_timeSpec &sipStrings_QtCore[63929]
#define sipNameNr_timeZone 63938
#define sipName_timeZone &sipStrings_QtCore[63938]
#define sipNameNr_toBase64 63947
#define sipName_toBase64 &sipStrings_QtCore[63947]
#define sipNameNr_toDouble 63956
#define sipName_toDouble &sipStrings_QtCore[63956]
#define sipNameNr_toObject 63965
#define sipName_toObject &sipStrings_QtCore[63965]
#define sipNameNr_toPointF 63974
#define sipName_toPointF &sipStrings_QtCore[63974]
#define sipNameNr_toPyDate 63983
#define sipName_toPyDate &sipStrings_QtCore[63983]
#define sipNameNr_toPyTime 63992
#define sipName_toPyTime &sipStrings_QtCore[63992]
#define sipNameNr_toString 64001
#define sipName_toString &sipStrings_QtCore[64001]
#define sipNameNr_toUInt32 64010
#define sipName_toUInt32 &sipStrings_QtCore[64010]
#define sipNameNr_toUShort 64019
#define sipName_toUShort &sipStrings_QtCore[64019]
#define sipNameNr_topRight 64028
#define sipName_topRight &sipStrings_QtCore[64028]
#define sipNameNr_truncate 64037
#define sipName_truncate &sipStrings_QtCore[64037]
#define sipNameNr_tryStart 64046
#define sipName_tryStart &sipStrings_QtCore[64046]
#define sipNameNr_typeName 64055
#define sipName_typeName &sipStrings_QtCore[64055]
#define sipNameNr_userInfo 64064
#define sipName_userInfo &sipStrings_QtCore[64064]
#define sipNameNr_userName 64073
#define sipName_userName &sipStrings_QtCore[64073]
#define sipNameNr_userType 64082
#define sipName_userType &sipStrings_QtCore[64082]
#define sipNameNr_weekdays 64091
#define sipName_weekdays &sipStrings_QtCore[64091]
#define sipNameNr_writeDTD 64100
#define sipName_writeDTD &sipStrings_QtCore[64100]
#define sipNameNr_writeInt 64109
#define sipName_writeInt &sipStrings_QtCore[64109]
#define sipNameNr_Albania 64118
#define sipName_Albania &sipStrings_QtCore[64118]
#define sipNameNr_Algeria 64126
#define sipName_Algeria &sipStrings_QtCore[64126]
#define sipNameNr_AllDirs 64134
#define sipName_AllDirs &sipStrings_QtCore[64134]
#define sipNameNr_Amharic 64142
#define sipName_Amharic &sipStrings_QtCore[64142]
#define sipNameNr_Andorra 64150
#define sipName_Andorra &sipStrings_QtCore[64150]
#define sipNameNr_Android 64158
#define sipName_Android &sipStrings_QtCore[64158]
#define sipNameNr_Aramaic 12734
#define sipName_Aramaic &sipStrings_QtCore[12734]
#define sipNameNr_Armenia 64166
#define sipName_Armenia &sipStrings_QtCore[64166]
#define sipNameNr_Austria 64174
#define sipName_Austria &sipStrings_QtCore[64174]
#define sipNameNr_Avestan 37807
#define sipName_Avestan &sipStrings_QtCore[37807]
#define sipNameNr_Bahamas 64182
#define sipName_Bahamas &sipStrings_QtCore[64182]
#define sipNameNr_Bahrain 64190
#define sipName_Bahrain &sipStrings_QtCore[64190]
#define sipNameNr_Baluchi 64198
#define sipName_Baluchi &sipStrings_QtCore[64198]
#define sipNameNr_Bambara 64206
#define sipName_Bambara &sipStrings_QtCore[64206]
#define sipNameNr_Bashkir 64214
#define sipName_Bashkir &sipStrings_QtCore[64214]
#define sipNameNr_Belarus 64222
#define sipName_Belarus &sipStrings_QtCore[64222]
#define sipNameNr_Belgium 64230
#define sipName_Belgium &sipStrings_QtCore[64230]
#define sipNameNr_Bengali 37822
#define sipName_Bengali &sipStrings_QtCore[37822]
#define sipNameNr_Bermuda 64238
#define sipName_Bermuda &sipStrings_QtCore[64238]
#define sipNameNr_Bhutani 64246
#define sipName_Bhutani &sipStrings_QtCore[64246]
#define sipNameNr_Bislama 64254
#define sipName_Bislama &sipStrings_QtCore[64254]
#define sipNameNr_Bolivia 64262
#define sipName_Bolivia &sipStrings_QtCore[64262]
#define sipNameNr_Bonaire 64270
#define sipName_Bonaire &sipStrings_QtCore[64270]
#define sipNameNr_Bosnian 64278
#define sipName_Bosnian &sipStrings_QtCore[64278]
#define sipNameNr_Burmese 64286
#define sipName_Burmese &sipStrings_QtCore[64286]
#define sipNameNr_Burundi 64294
#define sipName_Burundi &sipStrings_QtCore[64294]
#define sipNameNr_Catalan 64302
#define sipName_Catalan &sipStrings_QtCore[64302]
#define sipNameNr_Cebuano 64310
#define sipName_Cebuano &sipStrings_QtCore[64310]
#define sipNameNr_Chechen 64318
#define sipName_Chechen &sipStrings_QtCore[64318]
#define sipNameNr_Checked 28631
#define sipName_Checked &sipStrings_QtCore[28631]
#define sipNameNr_Chinese 32271
#define sipName_Chinese &sipStrings_QtCore[32271]
#define sipNameNr_Chuvash 64326
#define sipName_Chuvash &sipStrings_QtCore[64326]
#define sipNameNr_Columns 22944
#define sipName_Columns &sipStrings_QtCore[22944]
#define sipNameNr_Comment 49733
#define sipName_Comment &sipStrings_QtCore[49733]
#define sipNameNr_Comoros 64334
#define sipName_Comoros &sipStrings_QtCore[64334]
#define sipNameNr_Compact 64342
#define sipName_Compact &sipStrings_QtCore[64342]
#define sipNameNr_Cornish 64350
#define sipName_Cornish &sipStrings_QtCore[64350]
#define sipNameNr_Country 28920
#define sipName_Country &sipStrings_QtCore[28920]
#define sipNameNr_Crashed 64358
#define sipName_Crashed &sipStrings_QtCore[64358]
#define sipNameNr_Croatia 64366
#define sipName_Croatia &sipStrings_QtCore[64366]
#define sipNameNr_CuraSao 64374
#define sipName_CuraSao &sipStrings_QtCore[64374]
#define sipNameNr_Curacao 64382
#define sipName_Curacao &sipStrings_QtCore[64382]
#define sipNameNr_Current 43146
#define sipName_Current &sipStrings_QtCore[43146]
#define sipNameNr_Czechia 64390
#define sipName_Czechia &sipStrings_QtCore[64390]
#define sipNameNr_Decimal 64398
#define sipName_Decimal &sipStrings_QtCore[64398]
#define sipNameNr_Default 31567
#define sipName_Default &sipStrings_QtCore[31567]
#define sipNameNr_Denmark 64406
#define sipName_Denmark &sipStrings_QtCore[64406]
#define sipNameNr_Desktop 4977
#define sipName_Desktop &sipStrings_QtCore[4977]
#define sipNameNr_DotLine 35707
#define sipName_DotLine &sipStrings_QtCore[35707]
#define sipNameNr_Ecuador 64414
#define sipName_Ecuador &sipStrings_QtCore[64414]
#define sipNameNr_English 64422
#define sipName_English &sipStrings_QtCore[64422]
#define sipNameNr_Eritrea 64430
#define sipName_Eritrea &sipStrings_QtCore[64430]
#define sipNameNr_Estonia 64438
#define sipName_Estonia &sipStrings_QtCore[64438]
#define sipNameNr_ExeUser 64446
#define sipName_ExeUser &sipStrings_QtCore[64446]
#define sipNameNr_Faroese 64454
#define sipName_Faroese &sipStrings_QtCore[64454]
#define sipNameNr_Finland 64462
#define sipName_Finland &sipStrings_QtCore[64462]
#define sipNameNr_Finnish 64470
#define sipName_Finnish &sipStrings_QtCore[64470]
#define sipNameNr_FlatCap 64478
#define sipName_FlatCap &sipStrings_QtCore[64478]
#define sipNameNr_Float16 60187
#define sipName_Float16 &sipStrings_QtCore[60187]
#define sipNameNr_FocusIn 64486
#define sipName_FocusIn &sipStrings_QtCore[64486]
#define sipNameNr_Forever 60197
#define sipName_Forever &sipStrings_QtCore[60197]
#define sipNameNr_Forward 28189
#define sipName_Forward &sipStrings_QtCore[28189]
#define sipNameNr_Frisian 32479
#define sipName_Frisian &sipStrings_QtCore[32479]
#define sipNameNr_Georgia 64494
#define sipName_Georgia &sipStrings_QtCore[64494]
#define sipNameNr_Germany 64502
#define sipName_Germany &sipStrings_QtCore[64502]
#define sipNameNr_Gesture 12849
#define sipName_Gesture &sipStrings_QtCore[12849]
#define sipNameNr_Granted 64510
#define sipName_Granted &sipStrings_QtCore[64510]
#define sipNameNr_Grenada 64518
#define sipName_Grenada &sipStrings_QtCore[64518]
#define sipNameNr_Guarani 64526
#define sipName_Guarani &sipStrings_QtCore[64526]
#define sipNameNr_Haitian 64534
#define sipName_Haitian &sipStrings_QtCore[64534]
#define sipNameNr_Hungary 64542
#define sipName_Hungary &sipStrings_QtCore[64542]
#define sipNameNr_ISODate 64550
#define sipName_ISODate &sipStrings_QtCore[64550]
#define sipNameNr_Iceland 64558
#define sipName_Iceland &sipStrings_QtCore[64558]
#define sipNameNr_ImHints 64566
#define sipName_ImHints &sipStrings_QtCore[64566]
#define sipNameNr_ImhDate 64574
#define sipName_ImhDate &sipStrings_QtCore[64574]
#define sipNameNr_ImhNone 64582
#define sipName_ImhNone &sipStrings_QtCore[64582]
#define sipNameNr_ImhTime 64590
#define sipName_ImhTime &sipStrings_QtCore[64590]
#define sipNameNr_InCubic 55596
#define sipName_InCubic &sipStrings_QtCore[55596]
#define sipNameNr_InCurve 64598
#define sipName_InCurve &sipStrings_QtCore[64598]
#define sipNameNr_InQuart 55607
#define sipName_InQuart &sipStrings_QtCore[55607]
#define sipNameNr_InQuint 55618
#define sipName_InQuint &sipStrings_QtCore[55618]
#define sipNameNr_Inupiak 64606
#define sipName_Inupiak &sipStrings_QtCore[64606]
#define sipNameNr_Inupiaq 64614
#define sipName_Inupiaq &sipStrings_QtCore[64614]
#define sipNameNr_Invalid 32575
#define sipName_Invalid &sipStrings_QtCore[32575]
#define sipNameNr_Ireland 64622
#define sipName_Ireland &sipStrings_QtCore[64622]
#define sipNameNr_IsConst 64630
#define sipName_IsConst &sipStrings_QtCore[64630]
#define sipNameNr_Italian 64638
#define sipName_Italian &sipStrings_QtCore[64638]
#define sipNameNr_Jamaica 64646
#define sipName_Jamaica &sipStrings_QtCore[64646]
#define sipNameNr_Kannada 37942
#define sipName_Kannada &sipStrings_QtCore[37942]
#define sipNameNr_Kenyang 64654
#define sipName_Kenyang &sipStrings_QtCore[64654]
#define sipNameNr_Key_Alt 64662
#define sipName_Key_Alt &sipStrings_QtCore[64662]
#define sipNameNr_Key_Any 64670
#define sipName_Key_Any &sipStrings_QtCore[64670]
#define sipNameNr_Key_Bar 64678
#define sipName_Key_Bar &sipStrings_QtCore[64678]
#define sipNameNr_Key_Cut 64686
#define sipName_Key_Cut &sipStrings_QtCore[64686]
#define sipNameNr_Key_DOS 64694
#define sipName_Key_DOS &sipStrings_QtCore[64694]
#define sipNameNr_Key_ETH 64702
#define sipName_Key_ETH &sipStrings_QtCore[64702]
#define sipNameNr_Key_End 64710
#define sipName_Key_End &sipStrings_QtCore[64710]
#define sipNameNr_Key_F10 64718
#define sipName_Key_F10 &sipStrings_QtCore[64718]
#define sipNameNr_Key_F11 64726
#define sipName_Key_F11 &sipStrings_QtCore[64726]
#define sipNameNr_Key_F12 64734
#define sipName_Key_F12 &sipStrings_QtCore[64734]
#define sipNameNr_Key_F13 64742
#define sipName_Key_F13 &sipStrings_QtCore[64742]
#define sipNameNr_Key_F14 64750
#define sipName_Key_F14 &sipStrings_QtCore[64750]
#define sipNameNr_Key_F15 64758
#define sipName_Key_F15 &sipStrings_QtCore[64758]
#define sipNameNr_Key_F16 64766
#define sipName_Key_F16 &sipStrings_QtCore[64766]
#define sipNameNr_Key_F17 64774
#define sipName_Key_F17 &sipStrings_QtCore[64774]
#define sipNameNr_Key_F18 64782
#define sipName_Key_F18 &sipStrings_QtCore[64782]
#define sipNameNr_Key_F19 64790
#define sipName_Key_F19 &sipStrings_QtCore[64790]
#define sipNameNr_Key_F20 64798
#define sipName_Key_F20 &sipStrings_QtCore[64798]
#define sipNameNr_Key_F21 64806
#define sipName_Key_F21 &sipStrings_QtCore[64806]
#define sipNameNr_Key_F22 64814
#define sipName_Key_F22 &sipStrings_QtCore[64814]
#define sipNameNr_Key_F23 64822
#define sipName_Key_F23 &sipStrings_QtCore[64822]
#define sipNameNr_Key_F24 64830
#define sipName_Key_F24 &sipStrings_QtCore[64830]
#define sipNameNr_Key_F25 64838
#define sipName_Key_F25 &sipStrings_QtCore[64838]
#define sipNameNr_Key_F26 64846
#define sipName_Key_F26 &sipStrings_QtCore[64846]
#define sipNameNr_Key_F27 64854
#define sipName_Key_F27 &sipStrings_QtCore[64854]
#define sipNameNr_Key_F28 64862
#define sipName_Key_F28 &sipStrings_QtCore[64862]
#define sipNameNr_Key_F29 64870
#define sipName_Key_F29 &sipStrings_QtCore[64870]
#define sipNameNr_Key_F30 64878
#define sipName_Key_F30 &sipStrings_QtCore[64878]
#define sipNameNr_Key_F31 64886
#define sipName_Key_F31 &sipStrings_QtCore[64886]
#define sipNameNr_Key_F32 64894
#define sipName_Key_F32 &sipStrings_QtCore[64894]
#define sipNameNr_Key_F33 64902
#define sipName_Key_F33 &sipStrings_QtCore[64902]
#define sipNameNr_Key_F34 64910
#define sipName_Key_F34 &sipStrings_QtCore[64910]
#define sipNameNr_Key_F35 64918
#define sipName_Key_F35 &sipStrings_QtCore[64918]
#define sipNameNr_Key_New 64926
#define sipName_Key_New &sipStrings_QtCore[64926]
#define sipNameNr_Key_Red 64934
#define sipName_Key_Red &sipStrings_QtCore[64934]
#define sipNameNr_Key_Tab 64942
#define sipName_Key_Tab &sipStrings_QtCore[64942]
#define sipNameNr_Key_UWB 64950
#define sipName_Key_UWB &sipStrings_QtCore[64950]
#define sipNameNr_Key_WWW 64958
#define sipName_Key_WWW &sipStrings_QtCore[64958]
#define sipNameNr_Key_Yes 64966
#define sipName_Key_Yes &sipStrings_QtCore[64966]
#define sipNameNr_Key_yen 64974
#define sipName_Key_yen &sipStrings_QtCore[64974]
#define sipNameNr_Kirghiz 64982
#define sipName_Kirghiz &sipStrings_QtCore[64982]
#define sipNameNr_Konkani 64990
#define sipName_Konkani &sipStrings_QtCore[64990]
#define sipNameNr_Kurdish 33599
#define sipName_Kurdish &sipStrings_QtCore[33599]
#define sipNameNr_Kurundi 64998
#define sipName_Kurundi &sipStrings_QtCore[64998]
#define sipNameNr_Latvian 65006
#define sipName_Latvian &sipStrings_QtCore[65006]
#define sipNameNr_Lebanon 65014
#define sipName_Lebanon &sipStrings_QtCore[65014]
#define sipNameNr_Lesotho 65022
#define sipName_Lesotho &sipStrings_QtCore[65022]
#define sipNameNr_Liberia 65030
#define sipName_Liberia &sipStrings_QtCore[65030]
#define sipNameNr_Lingala 65038
#define sipName_Lingala &sipStrings_QtCore[65038]
#define sipNameNr_Machame 65046
#define sipName_Machame &sipStrings_QtCore[65046]
#define sipNameNr_Makonde 65054
#define sipName_Makonde &sipStrings_QtCore[65054]
#define sipNameNr_Maltese 65062
#define sipName_Maltese &sipStrings_QtCore[65062]
#define sipNameNr_Mapuche 65070
#define sipName_Mapuche &sipStrings_QtCore[65070]
#define sipNameNr_Marathi 65078
#define sipName_Marathi &sipStrings_QtCore[65078]
#define sipNameNr_MaxUser 65086
#define sipName_MaxUser &sipStrings_QtCore[65086]
#define sipNameNr_Mayotte 65094
#define sipName_Mayotte &sipStrings_QtCore[65094]
#define sipNameNr_Moldova 65102
#define sipName_Moldova &sipStrings_QtCore[65102]
#define sipNameNr_Morocco 65110
#define sipName_Morocco &sipStrings_QtCore[65110]
#define sipNameNr_Mundang 65118
#define sipName_Mundang &sipStrings_QtCore[65118]
#define sipNameNr_Myanmar 38062
#define sipName_Myanmar &sipStrings_QtCore[38062]
#define sipNameNr_Namibia 65126
#define sipName_Namibia &sipStrings_QtCore[65126]
#define sipNameNr_NewOnly 65134
#define sipName_NewOnly &sipStrings_QtCore[65134]
#define sipNameNr_Nigeria 65142
#define sipName_Nigeria &sipStrings_QtCore[65142]
#define sipNameNr_NoArrow 65150
#define sipName_NoArrow &sipStrings_QtCore[65150]
#define sipNameNr_NoBrush 65158
#define sipName_NoBrush &sipStrings_QtCore[65158]
#define sipNameNr_NoError 65166
#define sipName_NoError &sipStrings_QtCore[65166]
#define sipNameNr_NoFocus 65174
#define sipName_NoFocus &sipStrings_QtCore[65174]
#define sipNameNr_NoMatch 65182
#define sipName_NoMatch &sipStrings_QtCore[65182]
#define sipNameNr_NoToken 65190
#define sipName_NoToken &sipStrings_QtCore[65190]
#define sipNameNr_NotOpen 65198
#define sipName_NotOpen &sipStrings_QtCore[65198]
#define sipNameNr_Occitan 65206
#define sipName_Occitan &sipStrings_QtCore[65206]
#define sipNameNr_Ossetic 65214
#define sipName_Ossetic &sipStrings_QtCore[65214]
#define sipNameNr_OutBack 58407
#define sipName_OutBack &sipStrings_QtCore[58407]
#define sipNameNr_OutCirc 58417
#define sipName_OutCirc &sipStrings_QtCore[58417]
#define sipNameNr_OutExpo 58427
#define sipName_OutExpo &sipStrings_QtCore[58427]
#define sipNameNr_OutQuad 58437
#define sipName_OutQuad &sipStrings_QtCore[58437]
#define sipNameNr_OutSine 58447
#define sipName_OutSine &sipStrings_QtCore[58447]
#define sipNameNr_Pahlavi 5966
#define sipName_Pahlavi &sipStrings_QtCore[5966]
#define sipNameNr_Palauan 65222
#define sipName_Palauan &sipStrings_QtCore[65222]
#define sipNameNr_Persian 25616
#define sipName_Persian &sipStrings_QtCore[25616]
#define sipNameNr_Precise 65230
#define sipName_Precise &sipStrings_QtCore[65230]
#define sipNameNr_Private 65238
#define sipName_Private &sipStrings_QtCore[65238]
#define sipNameNr_Punjabi 65246
#define sipName_Punjabi &sipStrings_QtCore[65246]
#define sipNameNr_QBitmap 65254
#define sipName_QBitmap &sipStrings_QtCore[65254]
#define sipNameNr_QBuffer 65262
#define sipName_QBuffer &sipStrings_QtCore[65262]
#define sipNameNr_QCursor 65270
#define sipName_QCursor &sipStrings_QtCore[65270]
#define sipNameNr_QLocale 65278
#define sipName_QLocale &sipStrings_QtCore[65278]
#define sipNameNr_QObject 28716
#define sipName_QObject &sipStrings_QtCore[28716]
#define sipNameNr_QPixmap 65286
#define sipName_QPixmap &sipStrings_QtCore[65286]
#define sipNameNr_QPointF 65294
#define sipName_QPointF &sipStrings_QtCore[65294]
#define sipNameNr_QRegion 65302
#define sipName_QRegion &sipStrings_QtCore[65302]
#define sipNameNr_QString 49746
#define sipName_QString &sipStrings_QtCore[49746]
#define sipNameNr_QThread 65310
#define sipName_QThread &sipStrings_QtCore[65310]
#define sipNameNr_Qt__Key 65318
#define sipName_Qt__Key &sipStrings_QtCore[65318]
#define sipNameNr_Qt_5_10 65326
#define sipName_Qt_5_10 &sipStrings_QtCore[65326]
#define sipNameNr_Qt_5_11 65334
#define sipName_Qt_5_11 &sipStrings_QtCore[65334]
#define sipNameNr_Qt_5_12 65342
#define sipName_Qt_5_12 &sipStrings_QtCore[65342]
#define sipNameNr_Qt_5_13 65350
#define sipName_Qt_5_13 &sipStrings_QtCore[65350]
#define sipNameNr_Qt_5_14 65358
#define sipName_Qt_5_14 &sipStrings_QtCore[65358]
#define sipNameNr_Qt_5_15 65366
#define sipName_Qt_5_15 &sipStrings_QtCore[65366]
#define sipNameNr_Qt_6_10 65374
#define sipName_Qt_6_10 &sipStrings_QtCore[65374]
#define sipNameNr_Qt_6_11 65382
#define sipName_Qt_6_11 &sipStrings_QtCore[65382]
#define sipNameNr_Quechua 65390
#define sipName_Quechua &sipStrings_QtCore[65390]
#define sipNameNr_Release 3071
#define sipName_Release &sipStrings_QtCore[3071]
#define sipNameNr_Reunion 65398
#define sipName_Reunion &sipStrings_QtCore[65398]
#define sipNameNr_Romania 65406
#define sipName_Romania &sipStrings_QtCore[65406]
#define sipNameNr_Romansh 65414
#define sipName_Romansh &sipStrings_QtCore[65414]
#define sipNameNr_Running 55552
#define sipName_Running &sipStrings_QtCore[55552]
#define sipNameNr_Russian 65422
#define sipName_Russian &sipStrings_QtCore[65422]
#define sipNameNr_Samburu 65430
#define sipName_Samburu &sipStrings_QtCore[65430]
#define sipNameNr_Santali 65438
#define sipName_Santali &sipStrings_QtCore[65438]
#define sipNameNr_Senegal 65446
#define sipName_Senegal &sipStrings_QtCore[65446]
#define sipNameNr_Serbian 65454
#define sipName_Serbian &sipStrings_QtCore[65454]
#define sipNameNr_Sinhala 38182
#define sipName_Sinhala &sipStrings_QtCore[38182]
#define sipNameNr_SockAct 65462
#define sipName_SockAct &sipStrings_QtCore[65462]
#define sipNameNr_Somalia 65470
#define sipName_Somalia &sipStrings_QtCore[65470]
#define sipNameNr_Spanish 65478
#define sipName_Spanish &sipStrings_QtCore[65478]
#define sipNameNr_Stopped 24392
#define sipName_Stopped &sipStrings_QtCore[24392]
#define sipNameNr_Swahili 65486
#define sipName_Swahili &sipStrings_QtCore[65486]
#define sipNameNr_Swedish 65494
#define sipName_Swedish &sipStrings_QtCore[65494]
#define sipNameNr_SystemV 65502
#define sipName_SystemV &sipStrings_QtCore[65502]
#define sipNameNr_Tasawaq 65510
#define sipName_Tasawaq &sipStrings_QtCore[65510]
#define sipNameNr_Tibetan 38287
#define sipName_Tibetan &sipStrings_QtCore[38287]
#define sipNameNr_ToolTip 5035
#define sipName_ToolTip &sipStrings_QtCore[5035]
#define sipNameNr_TopEdge 65518
#define sipName_TopEdge &sipStrings_QtCore[65518]
#define sipNameNr_Torwali 65526
#define sipName_Torwali &sipStrings_QtCore[65526]
#define sipNameNr_Tuesday 65534
#define sipName_Tuesday &sipStrings_QtCore[65534]
#define sipNameNr_Tunisia 65542
#define sipName_Tunisia &sipStrings_QtCore[65542]
#define sipNameNr_Turkish 65550
#define sipName_Turkish &sipStrings_QtCore[65550]
#define sipNameNr_Turkmen 65558
#define sipName_Turkmen &sipStrings_QtCore[65558]
#define sipNameNr_Ukraine 65566
#define sipName_Ukraine &sipStrings_QtCore[65566]
#define sipNameNr_Unknown 38317
#define sipName_Unknown &sipStrings_QtCore[38317]
#define sipNameNr_UpArrow 65574
#define sipName_UpArrow &sipStrings_QtCore[65574]
#define sipNameNr_Uruguay 65582
#define sipName_Uruguay &sipStrings_QtCore[65582]
#define sipNameNr_UsesIcu 65590
#define sipName_UsesIcu &sipStrings_QtCore[65590]
#define sipNameNr_Utf16BE 65598
#define sipName_Utf16BE &sipStrings_QtCore[65598]
#define sipNameNr_Utf16LE 65606
#define sipName_Utf16LE &sipStrings_QtCore[65606]
#define sipNameNr_Utf32BE 65614
#define sipName_Utf32BE &sipStrings_QtCore[65614]
#define sipNameNr_Utf32LE 65622
#define sipName_Utf32LE &sipStrings_QtCore[65622]
#define sipNameNr_Vanuatu 65630
#define sipName_Vanuatu &sipStrings_QtCore[65630]
#define sipNameNr_Variant 37552
#define sipName_Variant &sipStrings_QtCore[37552]
#define sipNameNr_Version 10885
#define sipName_Version &sipStrings_QtCore[10885]
#define sipNameNr_Vietnam 65638
#define sipName_Vietnam &sipStrings_QtCore[65638]
#define sipNameNr_Volapuk 65646
#define sipName_Volapuk &sipStrings_QtCore[65646]
#define sipNameNr_Walloon 65654
#define sipName_Walloon &sipStrings_QtCore[65654]
#define sipNameNr_WatchOS 65662
#define sipName_WatchOS &sipStrings_QtCore[65662]
#define sipNameNr_Windows 5266
#define sipName_Windows &sipStrings_QtCore[5266]
#define sipNameNr_Yangben 65670
#define sipName_Yangben &sipStrings_QtCore[65670]
#define sipNameNr_Yiddish 65678
#define sipName_Yiddish &sipStrings_QtCore[65678]
#define sipNameNr___add__ 65686
#define sipName___add__ &sipStrings_QtCore[65686]
#define sipNameNr___and__ 65694
#define sipName___and__ &sipStrings_QtCore[65694]
#define sipNameNr___int__ 65702
#define sipName___int__ &sipStrings_QtCore[65702]
#define sipNameNr___ior__ 65710
#define sipName___ior__ &sipStrings_QtCore[65710]
#define sipNameNr___len__ 65718
#define sipName___len__ &sipStrings_QtCore[65718]
#define sipNameNr___mul__ 65726
#define sipName___mul__ &sipStrings_QtCore[65726]
#define sipNameNr___neg__ 65734
#define sipName___neg__ &sipStrings_QtCore[65734]
#define sipNameNr___pos__ 65742
#define sipName___pos__ &sipStrings_QtCore[65742]
#define sipNameNr___str__ 65750
#define sipName___str__ &sipStrings_QtCore[65750]
#define sipNameNr___sub__ 65758
#define sipName___sub__ &sipStrings_QtCore[65758]
#define sipNameNr___xor__ 65766
#define sipName___xor__ &sipStrings_QtCore[65766]
#define sipNameNr_acquire 65774
#define sipName_acquire &sipStrings_QtCore[65774]
#define sipNameNr_addData 65782
#define sipName_addData &sipStrings_QtCore[65782]
#define sipNameNr_addDays 65790
#define sipName_addDays &sipStrings_QtCore[65790]
#define sipNameNr_addPath 65798
#define sipName_addPath &sipStrings_QtCore[65798]
#define sipNameNr_addSecs 65806
#define sipName_addSecs &sipStrings_QtCore[65806]
#define sipNameNr_aliases 65814
#define sipName_aliases &sipStrings_QtCore[65814]
#define sipNameNr_alignOf 65822
#define sipName_alignOf &sipStrings_QtCore[65822]
#define sipNameNr_allKeys 65830
#define sipName_allKeys &sipStrings_QtCore[65830]
#define sipNameNr_angleTo 65838
#define sipName_angleTo &sipStrings_QtCore[65838]
#define sipNameNr_bounded 65846
#define sipName_bounded &sipStrings_QtCore[65846]
#define sipNameNr_caching 65854
#define sipName_caching &sipStrings_QtCore[65854]
#define sipNameNr_canView 65862
#define sipName_canView &sipStrings_QtCore[65862]
#define sipNameNr_chopped 65870
#define sipName_chopped &sipStrings_QtCore[65870]
#define sipNameNr_comment 65878
#define sipName_comment &sipStrings_QtCore[65878]
#define sipNameNr_compare 65886
#define sipName_compare &sipStrings_QtCore[65886]
#define sipNameNr_convert 65894
#define sipName_convert &sipStrings_QtCore[65894]
#define sipNameNr_country 65902
#define sipName_country &sipStrings_QtCore[65902]
#define sipNameNr_current 65910
#define sipName_current &sipStrings_QtCore[65910]
#define sipNameNr_darkRed 65918
#define sipName_darkRed &sipStrings_QtCore[65918]
#define sipNameNr_dayName 65926
#define sipName_dayName &sipStrings_QtCore[65926]
#define sipNameNr_decoded 65934
#define sipName_decoded &sipStrings_QtCore[65934]
#define sipNameNr_dirName 65942
#define sipName_dirName &sipStrings_QtCore[65942]
#define sipNameNr_discard 65950
#define sipName_discard &sipStrings_QtCore[65950]
#define sipNameNr_dismiss 65958
#define sipName_dismiss &sipStrings_QtCore[65958]
#define sipNameNr_dtdName 65966
#define sipName_dtdName &sipStrings_QtCore[65966]
#define sipNameNr_elapsed 65974
#define sipName_elapsed &sipStrings_QtCore[65974]
#define sipNameNr_enabled 65982
#define sipName_enabled &sipStrings_QtCore[65982]
#define sipNameNr_exclude 65990
#define sipName_exclude &sipStrings_QtCore[65990]
#define sipNameNr_execute 65998
#define sipName_execute &sipStrings_QtCore[65998]
#define sipNameNr_filters 66006
#define sipName_filters &sipStrings_QtCore[66006]
#define sipNameNr_formats 66014
#define sipName_formats &sipStrings_QtCore[66014]
#define sipNameNr_fromAce 66022
#define sipName_fromAce &sipStrings_QtCore[66022]
#define sipNameNr_fromHex 66030
#define sipName_fromHex &sipStrings_QtCore[66030]
#define sipNameNr_getChar 61027
#define sipName_getChar &sipStrings_QtCore[61027]
#define sipNameNr_getDate 66038
#define sipName_getDate &sipStrings_QtCore[66038]
#define sipNameNr_getRect 11173
#define sipName_getRect &sipStrings_QtCore[11173]
#define sipNameNr_global_ 66046
#define sipName_global_ &sipStrings_QtCore[66046]
#define sipNameNr_groupId 66054
#define sipName_groupId &sipStrings_QtCore[66054]
#define sipNameNr_grownBy 66062
#define sipName_grownBy &sipStrings_QtCore[66062]
#define sipNameNr_hasHtml 66070
#define sipName_hasHtml &sipStrings_QtCore[66070]
#define sipNameNr_hasNext 66078
#define sipName_hasNext &sipStrings_QtCore[66078]
#define sipNameNr_hasText 66086
#define sipName_hasText &sipStrings_QtCore[66086]
#define sipNameNr_hasUrls 66094
#define sipName_hasUrls &sipStrings_QtCore[66094]
#define sipNameNr_include 66102
#define sipName_include &sipStrings_QtCore[66102]
#define sipNameNr_indexIn 66110
#define sipName_indexIn &sipStrings_QtCore[66110]
#define sipNameNr_indexOf 66118
#define sipName_indexOf &sipStrings_QtCore[66118]
#define sipNameNr_indexes 66126
#define sipName_indexes &sipStrings_QtCore[66126]
#define sipNameNr_is64Bit 66134
#define sipName_is64Bit &sipStrings_QtCore[66134]
#define sipNameNr_isAlias 66142
#define sipName_isAlias &sipStrings_QtCore[66142]
#define sipNameNr_isArray 66150
#define sipName_isArray &sipStrings_QtCore[66150]
#define sipNameNr_isCDATA 66158
#define sipName_isCDATA &sipStrings_QtCore[66158]
#define sipNameNr_isConst 66166
#define sipName_isConst &sipStrings_QtCore[66166]
#define sipNameNr_isEmpty 66174
#define sipName_isEmpty &sipStrings_QtCore[66174]
#define sipNameNr_isFalse 66182
#define sipName_isFalse &sipStrings_QtCore[66182]
#define sipNameNr_isFinal 66190
#define sipName_isFinal &sipStrings_QtCore[66190]
#define sipNameNr_isFloat 66198
#define sipName_isFloat &sipStrings_QtCore[66198]
#define sipNameNr_isLower 66206
#define sipName_isLower &sipStrings_QtCore[66206]
#define sipNameNr_isLunar 66214
#define sipName_isLunar &sipStrings_QtCore[66214]
#define sipNameNr_isOther 66222
#define sipName_isOther &sipStrings_QtCore[66222]
#define sipNameNr_isReady 66230
#define sipName_isReady &sipStrings_QtCore[66230]
#define sipNameNr_isSolar 66238
#define sipName_isSolar &sipStrings_QtCore[66238]
#define sipNameNr_isUpper 66246
#define sipName_isUpper &sipStrings_QtCore[66246]
#define sipNameNr_isValid 66254
#define sipName_isValid &sipStrings_QtCore[66254]
#define sipNameNr_magenta 66262
#define sipName_magenta &sipStrings_QtCore[66262]
#define sipNameNr_mapRoot 66270
#define sipName_mapRoot &sipStrings_QtCore[66270]
#define sipNameNr_mapping 66278
#define sipName_mapping &sipStrings_QtCore[66278]
#define sipNameNr_matches 66286
#define sipName_matches &sipStrings_QtCore[66286]
#define sipNameNr_maxSize 66294
#define sipName_maxSize &sipStrings_QtCore[66294]
#define sipNameNr_message 66302
#define sipName_message &sipStrings_QtCore[66302]
#define sipNameNr_moveRow 60637
#define sipName_moveRow &sipStrings_QtCore[60637]
#define sipNameNr_moveTop 66310
#define sipName_moveTop &sipStrings_QtCore[66310]
#define sipNameNr_msecsTo 66318
#define sipName_msecsTo &sipStrings_QtCore[66318]
#define sipNameNr_options 66326
#define sipName_options &sipStrings_QtCore[66326]
#define sipNameNr_ownerId 66334
#define sipName_ownerId &sipStrings_QtCore[66334]
#define sipNameNr_padChar 66342
#define sipName_padChar &sipStrings_QtCore[66342]
#define sipNameNr_parents 66350
#define sipName_parents &sipStrings_QtCore[66350]
#define sipNameNr_pattern 66358
#define sipName_pattern &sipStrings_QtCore[66358]
#define sipNameNr_percent 66366
#define sipName_percent &sipStrings_QtCore[66366]
#define sipNameNr_pointAt 66374
#define sipName_pointAt &sipStrings_QtCore[66374]
#define sipNameNr_prepend 66382
#define sipName_prepend &sipStrings_QtCore[66382]
#define sipNameNr_process 66390
#define sipName_process &sipStrings_QtCore[66390]
#define sipNameNr_program 66398
#define sipName_program &sipStrings_QtCore[66398]
#define sipNameNr_putChar 66406
#define sipName_putChar &sipStrings_QtCore[66406]
#define sipNameNr_qintptr 66414
#define sipName_qintptr &sipStrings_QtCore[66414]
#define sipNameNr_readAll 66422
#define sipName_readAll &sipStrings_QtCore[66422]
#define sipNameNr_readInt 66430
#define sipName_readInt &sipStrings_QtCore[66430]
#define sipNameNr_reblock 66438
#define sipName_reblock &sipStrings_QtCore[66438]
#define sipNameNr_refresh 66446
#define sipName_refresh &sipStrings_QtCore[66446]
#define sipNameNr_release 66454
#define sipName_release &sipStrings_QtCore[66454]
#define sipNameNr_removed 66462
#define sipName_removed &sipStrings_QtCore[66462]
#define sipNameNr_reparse 66470
#define sipName_reparse &sipStrings_QtCore[66470]
#define sipNameNr_replace 66478
#define sipName_replace &sipStrings_QtCore[66478]
#define sipNameNr_reserve 66486
#define sipName_reserve &sipStrings_QtCore[66486]
#define sipNameNr_resolve 66494
#define sipName_resolve &sipStrings_QtCore[66494]
#define sipNameNr_restart 66502
#define sipName_restart &sipStrings_QtCore[66502]
#define sipNameNr_seconds 8892
#define sipName_seconds &sipStrings_QtCore[8892]
#define sipNameNr_setData 14507
#define sipName_setData &sipStrings_QtCore[14507]
#define sipNameNr_setDate 66510
#define sipName_setDate &sipStrings_QtCore[66510]
#define sipNameNr_setFile 66518
#define sipName_setFile &sipStrings_QtCore[66518]
#define sipNameNr_setHost 66526
#define sipName_setHost &sipStrings_QtCore[66526]
#define sipNameNr_setHtml 66534
#define sipName_setHtml &sipStrings_QtCore[66534]
#define sipNameNr_setLeft 66542
#define sipName_setLeft &sipStrings_QtCore[66542]
#define sipNameNr_setLine 66550
#define sipName_setLine &sipStrings_QtCore[66550]
#define sipNameNr_setPath 66558
#define sipName_setPath &sipStrings_QtCore[66558]
#define sipNameNr_setPort 66566
#define sipName_setPort &sipStrings_QtCore[66566]
#define sipNameNr_setRect 66574
#define sipName_setRect &sipStrings_QtCore[66574]
#define sipNameNr_setSize 66582
#define sipName_setSize &sipStrings_QtCore[66582]
#define sipNameNr_setText 66590
#define sipName_setText &sipStrings_QtCore[66590]
#define sipNameNr_setTime 66598
#define sipName_setTime &sipStrings_QtCore[66598]
#define sipNameNr_setType 66606
#define sipName_setType &sipStrings_QtCore[66606]
#define sipNameNr_setUrls 66614
#define sipName_setUrls &sipStrings_QtCore[66614]
#define sipNameNr_sibling 66622
#define sipName_sibling &sipStrings_QtCore[66622]
#define sipNameNr_sortKey 66630
#define sipName_sortKey &sipStrings_QtCore[66630]
#define sipNameNr_sorting 66638
#define sipName_sorting &sipStrings_QtCore[66638]
#define sipNameNr_squeeze 66646
#define sipName_squeeze &sipStrings_QtCore[66646]
#define sipNameNr_started 66654
#define sipName_started &sipStrings_QtCore[66654]
#define sipNameNr_testBit 66662
#define sipName_testBit &sipStrings_QtCore[66662]
#define sipNameNr_timeout 66670
#define sipName_timeout &sipStrings_QtCore[66670]
#define sipNameNr_timerId 66678
#define sipName_timerId &sipStrings_QtCore[66678]
#define sipNameNr_toArray 66686
#define sipName_toArray &sipStrings_QtCore[66686]
#define sipNameNr_toFloat 66694
#define sipName_toFloat &sipStrings_QtCore[66694]
#define sipNameNr_toLineF 66702
#define sipName_toLineF &sipStrings_QtCore[66702]
#define sipNameNr_toLower 66710
#define sipName_toLower &sipStrings_QtCore[66710]
#define sipNameNr_toPoint 66718
#define sipName_toPoint &sipStrings_QtCore[66718]
#define sipNameNr_toRectF 66726
#define sipName_toRectF &sipStrings_QtCore[66726]
#define sipNameNr_toShort 66734
#define sipName_toShort &sipStrings_QtCore[66734]
#define sipNameNr_toSizeF 66742
#define sipName_toSizeF &sipStrings_QtCore[66742]
#define sipNameNr_toStart 66750
#define sipName_toStart &sipStrings_QtCore[66750]
#define sipNameNr_toULong 66758
#define sipName_toULong &sipStrings_QtCore[66758]
#define sipNameNr_toUpper 66766
#define sipName_toUpper &sipStrings_QtCore[66766]
#define sipNameNr_topLeft 66774
#define sipName_topLeft &sipStrings_QtCore[66774]
#define sipNameNr_trimmed 66782
#define sipName_trimmed &sipStrings_QtCore[66782]
#define sipNameNr_tryLock 66790
#define sipName_tryLock &sipStrings_QtCore[66790]
#define sipNameNr_tryTake 66798
#define sipName_tryTake &sipStrings_QtCore[66798]
#define sipNameNr_unblock 66806
#define sipName_unblock &sipStrings_QtCore[66806]
#define sipNameNr_variant 66814
#define sipName_variant &sipStrings_QtCore[66814]
#define sipNameNr_version 4861
#define sipName_version &sipStrings_QtCore[4861]
#define sipNameNr_wakeAll 66822
#define sipName_wakeAll &sipStrings_QtCore[66822]
#define sipNameNr_wakeOne 66830
#define sipName_wakeOne &sipStrings_QtCore[66830]
#define sipNameNr_warning 66838
#define sipName_warning &sipStrings_QtCore[66838]
#define sipNameNr_Access 19140
#define sipName_Access &sipStrings_QtCore[19140]
#define sipNameNr_Akoose 66846
#define sipName_Akoose &sipStrings_QtCore[66846]
#define sipNameNr_Always 66853
#define sipName_Always &sipStrings_QtCore[66853]
#define sipNameNr_Angola 66860
#define sipName_Angola &sipStrings_QtCore[66860]
#define sipNameNr_Append 66867
#define sipName_Append &sipStrings_QtCore[66867]
#define sipNameNr_Arabic 42783
#define sipName_Arabic &sipStrings_QtCore[42783]
#define sipNameNr_Avaric 66874
#define sipName_Avaric &sipStrings_QtCore[66874]
#define sipNameNr_Aymara 66881
#define sipName_Aymara &sipStrings_QtCore[66881]
#define sipNameNr_BGMode 55817
#define sipName_BGMode &sipStrings_QtCore[55817]
#define sipNameNr_Bangla 66888
#define sipName_Bangla &sipStrings_QtCore[66888]
#define sipNameNr_Base64 35948
#define sipName_Base64 &sipStrings_QtCore[35948]
#define sipNameNr_Basque 66895
#define sipName_Basque &sipStrings_QtCore[66895]
#define sipNameNr_Belize 66902
#define sipName_Belize &sipStrings_QtCore[66902]
#define sipNameNr_Bhutan 66909
#define sipName_Bhutan &sipStrings_QtCore[66909]
#define sipNameNr_Brazil 66916
#define sipName_Brazil &sipStrings_QtCore[66916]
#define sipNameNr_Breton 66923
#define sipName_Breton &sipStrings_QtCore[66923]
#define sipNameNr_Brunei 66930
#define sipName_Brunei &sipStrings_QtCore[66930]
#define sipNameNr_Canada 66937
#define sipName_Canada &sipStrings_QtCore[66937]
#define sipNameNr_Chakma 42825
#define sipName_Chakma &sipStrings_QtCore[42825]
#define sipNameNr_Char16 66944
#define sipName_Char16 &sipStrings_QtCore[66944]
#define sipNameNr_Char32 66951
#define sipName_Char32 &sipStrings_QtCore[66951]
#define sipNameNr_Church 66958
#define sipName_Church &sipStrings_QtCore[66958]
#define sipNameNr_Coptic 42853
#define sipName_Coptic &sipStrings_QtCore[42853]
#define sipNameNr_Corner 24267
#define sipName_Corner &sipStrings_QtCore[24267]
#define sipNameNr_Create 66965
#define sipName_Create &sipStrings_QtCore[66965]
#define sipNameNr_Custom 66972
#define sipName_Custom &sipStrings_QtCore[66972]
#define sipNameNr_Cyprus 66979
#define sipName_Cyprus &sipStrings_QtCore[66979]
#define sipNameNr_Danish 66986
#define sipName_Danish &sipStrings_QtCore[66986]
#define sipNameNr_Denied 28649
#define sipName_Denied &sipStrings_QtCore[28649]
#define sipNameNr_Dialog 6051
#define sipName_Dialog &sipStrings_QtCore[6051]
#define sipNameNr_Divehi 66993
#define sipName_Divehi &sipStrings_QtCore[66993]
#define sipNameNr_Double 39428
#define sipName_Double &sipStrings_QtCore[39428]
#define sipNameNr_Drawer 67000
#define sipName_Drawer &sipStrings_QtCore[67000]
#define sipNameNr_Drives 67007
#define sipName_Drives &sipStrings_QtCore[67007]
#define sipNameNr_Endian 29074
#define sipName_Endian &sipStrings_QtCore[29074]
#define sipNameNr_Europe 67014
#define sipName_Europe &sipStrings_QtCore[67014]
#define sipNameNr_Ewondo 67021
#define sipName_Ewondo &sipStrings_QtCore[67021]
#define sipNameNr_Expose 67028
#define sipName_Expose &sipStrings_QtCore[67028]
#define sipNameNr_False_ 67035
#define sipName_False_ &sipStrings_QtCore[67035]
#define sipNameNr_Fijian 67042
#define sipName_Fijian &sipStrings_QtCore[67042]
#define sipNameNr_Filter 6653
#define sipName_Filter &sipStrings_QtCore[6653]
#define sipNameNr_Format 4101
#define sipName_Format &sipStrings_QtCore[4101]
#define sipNameNr_France 67049
#define sipName_France &sipStrings_QtCore[67049]
#define sipNameNr_French 67056
#define sipName_French &sipStrings_QtCore[67056]
#define sipNameNr_Friday 67063
#define sipName_Friday &sipStrings_QtCore[67063]
#define sipNameNr_Gaelic 67070
#define sipName_Gaelic &sipStrings_QtCore[67070]
#define sipNameNr_Gambia 67077
#define sipName_Gambia &sipStrings_QtCore[67077]
#define sipNameNr_German 52136
#define sipName_German &sipStrings_QtCore[52136]
#define sipNameNr_Gothic 42867
#define sipName_Gothic &sipStrings_QtCore[42867]
#define sipNameNr_Greece 67084
#define sipName_Greece &sipStrings_QtCore[67084]
#define sipNameNr_Guinea 27935
#define sipName_Guinea &sipStrings_QtCore[27935]
#define sipNameNr_Guyana 67091
#define sipName_Guyana &sipStrings_QtCore[67091]
#define sipNameNr_Hebrew 42909
#define sipName_Hebrew &sipStrings_QtCore[42909]
#define sipNameNr_Herero 67098
#define sipName_Herero &sipStrings_QtCore[67098]
#define sipNameNr_Hidden 24213
#define sipName_Hidden &sipStrings_QtCore[24213]
#define sipNameNr_ISO639 67105
#define sipName_ISO639 &sipStrings_QtCore[67105]
#define sipNameNr_ImFont 67112
#define sipName_ImFont &sipStrings_QtCore[67112]
#define sipNameNr_InBack 59018
#define sipName_InBack &sipStrings_QtCore[59018]
#define sipNameNr_InCirc 59028
#define sipName_InCirc &sipStrings_QtCore[59028]
#define sipNameNr_InExpo 59038
#define sipName_InExpo &sipStrings_QtCore[59038]
#define sipNameNr_InQuad 59048
#define sipName_InQuad &sipStrings_QtCore[59048]
#define sipNameNr_InSine 59058
#define sipName_InSine &sipStrings_QtCore[59058]
#define sipNameNr_Ingush 67119
#define sipName_Ingush &sipStrings_QtCore[67119]
#define sipNameNr_Israel 67126
#define sipName_Israel &sipStrings_QtCore[67126]
#define sipNameNr_Jalali 67133
#define sipName_Jalali &sipStrings_QtCore[67133]
#define sipNameNr_Jersey 67140
#define sipName_Jersey &sipStrings_QtCore[67140]
#define sipNameNr_Jordan 67147
#define sipName_Jordan &sipStrings_QtCore[67147]
#define sipNameNr_Julian 67154
#define sipName_Julian &sipStrings_QtCore[67154]
#define sipNameNr_Kabyle 67161
#define sipName_Kabyle &sipStrings_QtCore[67161]
#define sipNameNr_Kangri 67168
#define sipName_Kangri &sipStrings_QtCore[67168]
#define sipNameNr_Kanuri 67175
#define sipName_Kanuri &sipStrings_QtCore[67175]
#define sipNameNr_Kazakh 67182
#define sipName_Kazakh &sipStrings_QtCore[67182]
#define sipNameNr_Key_AE 67189
#define sipName_Key_AE &sipStrings_QtCore[67189]
#define sipNameNr_Key_At 67196
#define sipName_Key_At &sipStrings_QtCore[67196]
#define sipNameNr_Key_CD 67203
#define sipName_Key_CD &sipStrings_QtCore[67203]
#define sipNameNr_Key_F1 67210
#define sipName_Key_F1 &sipStrings_QtCore[67210]
#define sipNameNr_Key_F2 67217
#define sipName_Key_F2 &sipStrings_QtCore[67217]
#define sipNameNr_Key_F3 67224
#define sipName_Key_F3 &sipStrings_QtCore[67224]
#define sipNameNr_Key_F4 67231
#define sipName_Key_F4 &sipStrings_QtCore[67231]
#define sipNameNr_Key_F5 67238
#define sipName_Key_F5 &sipStrings_QtCore[67238]
#define sipNameNr_Key_F6 67245
#define sipName_Key_F6 &sipStrings_QtCore[67245]
#define sipNameNr_Key_F7 67252
#define sipName_Key_F7 &sipStrings_QtCore[67252]
#define sipNameNr_Key_F8 67259
#define sipName_Key_F8 &sipStrings_QtCore[67259]
#define sipNameNr_Key_F9 67266
#define sipName_Key_F9 &sipStrings_QtCore[67266]
#define sipNameNr_Key_Go 67273
#define sipName_Key_Go &sipStrings_QtCore[67273]
#define sipNameNr_Key_No 67280
#define sipName_Key_No &sipStrings_QtCore[67280]
#define sipNameNr_Key_Up 67287
#define sipName_Key_Up &sipStrings_QtCore[67287]
#define sipNameNr_Key_mu 67294
#define sipName_Key_mu &sipStrings_QtCore[67294]
#define sipNameNr_Kikuyu 67301
#define sipName_Kikuyu &sipStrings_QtCore[67301]
#define sipNameNr_Korean 67308
#define sipName_Korean &sipStrings_QtCore[67308]
#define sipNameNr_Kosovo 67315
#define sipName_Kosovo &sipStrings_QtCore[67315]
#define sipNameNr_Kpelle 67322
#define sipName_Kpelle &sipStrings_QtCore[67322]
#define sipNameNr_Kuwait 67329
#define sipName_Kuwait &sipStrings_QtCore[67329]
#define sipNameNr_Kwasio 67336
#define sipName_Kwasio &sipStrings_QtCore[67336]
#define sipNameNr_Kyrgyz 67343
#define sipName_Kyrgyz &sipStrings_QtCore[67343]
#define sipNameNr_Lakota 67350
#define sipName_Lakota &sipStrings_QtCore[67350]
#define sipNameNr_Latin1 67357
#define sipName_Latin1 &sipStrings_QtCore[67357]
#define sipNameNr_Latvia 67364
#define sipName_Latvia &sipStrings_QtCore[67364]
#define sipNameNr_Linear 67371
#define sipName_Linear &sipStrings_QtCore[67371]
#define sipNameNr_Lojban 67378
#define sipName_Lojban &sipStrings_QtCore[67378]
#define sipNameNr_Malawi 67385
#define sipName_Malawi &sipStrings_QtCore[67385]
#define sipNameNr_Method 44029
#define sipName_Method &sipStrings_QtCore[44029]
#define sipNameNr_Mexico 67392
#define sipName_Mexico &sipStrings_QtCore[67392]
#define sipNameNr_Mohawk 67399
#define sipName_Mohawk &sipStrings_QtCore[67399]
#define sipNameNr_Moksha 67406
#define sipName_Moksha &sipStrings_QtCore[67406]
#define sipNameNr_Monaco 67413
#define sipName_Monaco &sipStrings_QtCore[67413]
#define sipNameNr_Monday 67420
#define sipName_Monday &sipStrings_QtCore[67420]
#define sipNameNr_Navaho 67427
#define sipName_Navaho &sipStrings_QtCore[67427]
#define sipNameNr_Navajo 67434
#define sipName_Navajo &sipStrings_QtCore[67434]
#define sipNameNr_Ndonga 67441
#define sipName_Ndonga &sipStrings_QtCore[67441]
#define sipNameNr_Nepali 67448
#define sipName_Nepali &sipStrings_QtCore[67448]
#define sipNameNr_Newari 67455
#define sipName_Newari &sipStrings_QtCore[67455]
#define sipNameNr_Ngomba 67462
#define sipName_Ngomba &sipStrings_QtCore[67462]
#define sipNameNr_NoClip 67469
#define sipName_NoClip &sipStrings_QtCore[67469]
#define sipNameNr_NoSort 67476
#define sipName_NoSort &sipStrings_QtCore[67476]
#define sipNameNr_Norway 67483
#define sipName_Norway &sipStrings_QtCore[67483]
#define sipNameNr_Nyanja 67490
#define sipName_Nyanja &sipStrings_QtCore[67490]
#define sipNameNr_OSType 3424
#define sipName_OSType &sipStrings_QtCore[3424]
#define sipNameNr_Object 22736
#define sipName_Object &sipStrings_QtCore[22736]
#define sipNameNr_Ojibwa 67497
#define sipName_Ojibwa &sipStrings_QtCore[67497]
#define sipNameNr_OnRead 67504
#define sipName_OnRead &sipStrings_QtCore[67504]
#define sipNameNr_Panama 67511
#define sipName_Panama &sipStrings_QtCore[67511]
#define sipNameNr_Pashto 67518
#define sipName_Pashto &sipStrings_QtCore[67518]
#define sipNameNr_Paused 60818
#define sipName_Paused &sipStrings_QtCore[60818]
#define sipNameNr_Poland 67525
#define sipName_Poland &sipStrings_QtCore[67525]
#define sipNameNr_Polish 67532
#define sipName_Polish &sipStrings_QtCore[67532]
#define sipNameNr_Public 67539
#define sipName_Public &sipStrings_QtCore[67539]
#define sipNameNr_QBrush 67546
#define sipName_QBrush &sipStrings_QtCore[67546]
#define sipNameNr_QColor 67553
#define sipName_QColor &sipStrings_QtCore[67553]
#define sipNameNr_QEvent 67560
#define sipName_QEvent &sipStrings_QtCore[67560]
#define sipNameNr_QImage 67567
#define sipName_QImage &sipStrings_QtCore[67567]
#define sipNameNr_QLineF 67574
#define sipName_QLineF &sipStrings_QtCore[67574]
#define sipNameNr_QMutex 67581
#define sipName_QMutex &sipStrings_QtCore[67581]
#define sipNameNr_QPoint 67588
#define sipName_QPoint &sipStrings_QtCore[67588]
#define sipNameNr_QRectF 67595
#define sipName_QRectF &sipStrings_QtCore[67595]
#define sipNameNr_QSizeF 67602
#define sipName_QSizeF &sipStrings_QtCore[67602]
#define sipNameNr_QTimer 67609
#define sipName_QTimer &sipStrings_QtCore[67609]
#define sipNameNr_Qt_1_0 67616
#define sipName_Qt_1_0 &sipStrings_QtCore[67616]
#define sipNameNr_Qt_2_0 67623
#define sipName_Qt_2_0 &sipStrings_QtCore[67623]
#define sipNameNr_Qt_2_1 67630
#define sipName_Qt_2_1 &sipStrings_QtCore[67630]
#define sipNameNr_Qt_3_0 67637
#define sipName_Qt_3_0 &sipStrings_QtCore[67637]
#define sipNameNr_Qt_3_1 67644
#define sipName_Qt_3_1 &sipStrings_QtCore[67644]
#define sipNameNr_Qt_3_3 67651
#define sipName_Qt_3_3 &sipStrings_QtCore[67651]
#define sipNameNr_Qt_4_0 67658
#define sipName_Qt_4_0 &sipStrings_QtCore[67658]
#define sipNameNr_Qt_4_1 67665
#define sipName_Qt_4_1 &sipStrings_QtCore[67665]
#define sipNameNr_Qt_4_2 67672
#define sipName_Qt_4_2 &sipStrings_QtCore[67672]
#define sipNameNr_Qt_4_3 67679
#define sipName_Qt_4_3 &sipStrings_QtCore[67679]
#define sipNameNr_Qt_4_4 67686
#define sipName_Qt_4_4 &sipStrings_QtCore[67686]
#define sipNameNr_Qt_4_5 67693
#define sipName_Qt_4_5 &sipStrings_QtCore[67693]
#define sipNameNr_Qt_4_6 67700
#define sipName_Qt_4_6 &sipStrings_QtCore[67700]
#define sipNameNr_Qt_4_7 67707
#define sipName_Qt_4_7 &sipStrings_QtCore[67707]
#define sipNameNr_Qt_4_8 67714
#define sipName_Qt_4_8 &sipStrings_QtCore[67714]
#define sipNameNr_Qt_4_9 67721
#define sipName_Qt_4_9 &sipStrings_QtCore[67721]
#define sipNameNr_Qt_5_0 67728
#define sipName_Qt_5_0 &sipStrings_QtCore[67728]
#define sipNameNr_Qt_5_1 67735
#define sipName_Qt_5_1 &sipStrings_QtCore[67735]
#define sipNameNr_Qt_5_2 67742
#define sipName_Qt_5_2 &sipStrings_QtCore[67742]
#define sipNameNr_Qt_5_3 67749
#define sipName_Qt_5_3 &sipStrings_QtCore[67749]
#define sipNameNr_Qt_5_4 67756
#define sipName_Qt_5_4 &sipStrings_QtCore[67756]
#define sipNameNr_Qt_5_5 67763
#define sipName_Qt_5_5 &sipStrings_QtCore[67763]
#define sipNameNr_Qt_5_6 67770
#define sipName_Qt_5_6 &sipStrings_QtCore[67770]
#define sipNameNr_Qt_5_7 67777
#define sipName_Qt_5_7 &sipStrings_QtCore[67777]
#define sipNameNr_Qt_5_8 67784
#define sipName_Qt_5_8 &sipStrings_QtCore[67784]
#define sipNameNr_Qt_5_9 67791
#define sipName_Qt_5_9 &sipStrings_QtCore[67791]
#define sipNameNr_Qt_6_0 67798
#define sipName_Qt_6_0 &sipStrings_QtCore[67798]
#define sipNameNr_Qt_6_1 67805
#define sipName_Qt_6_1 &sipStrings_QtCore[67805]
#define sipNameNr_Qt_6_2 67812
#define sipName_Qt_6_2 &sipStrings_QtCore[67812]
#define sipNameNr_Qt_6_3 67819
#define sipName_Qt_6_3 &sipStrings_QtCore[67819]
#define sipNameNr_Qt_6_4 67826
#define sipName_Qt_6_4 &sipStrings_QtCore[67826]
#define sipNameNr_Qt_6_5 67833
#define sipName_Qt_6_5 &sipStrings_QtCore[67833]
#define sipNameNr_Qt_6_6 67840
#define sipName_Qt_6_6 &sipStrings_QtCore[67840]
#define sipNameNr_Qt_6_7 67847
#define sipName_Qt_6_7 &sipStrings_QtCore[67847]
#define sipNameNr_Qt_6_8 67854
#define sipName_Qt_6_8 &sipStrings_QtCore[67854]
#define sipNameNr_Qt_6_9 67861
#define sipName_Qt_6_9 &sipStrings_QtCore[67861]
#define sipNameNr_Random 67868
#define sipName_Random &sipStrings_QtCore[67868]
#define sipNameNr_Reject 67875
#define sipName_Reject &sipStrings_QtCore[67875]
#define sipNameNr_Resize 18420
#define sipName_Resize &sipStrings_QtCore[18420]
#define sipNameNr_Russia 67882
#define sipName_Russia &sipStrings_QtCore[67882]
#define sipNameNr_Rwanda 67889
#define sipName_Rwanda &sipStrings_QtCore[67889]
#define sipNameNr_Samoan 67896
#define sipName_Samoan &sipStrings_QtCore[67896]
#define sipNameNr_Script 5407
#define sipName_Script &sipStrings_QtCore[5407]
#define sipNameNr_Scroll 67903
#define sipName_Scroll &sipStrings_QtCore[67903]
#define sipNameNr_Select 35633
#define sipName_Select &sipStrings_QtCore[35633]
#define sipNameNr_Serbia 67910
#define sipName_Serbia &sipStrings_QtCore[67910]
#define sipNameNr_Sha224 67917
#define sipName_Sha224 &sipStrings_QtCore[67917]
#define sipNameNr_Sha256 67924
#define sipName_Sha256 &sipStrings_QtCore[67924]
#define sipNameNr_Sha384 67931
#define sipName_Sha384 &sipStrings_QtCore[67931]
#define sipNameNr_Sha512 67938
#define sipName_Sha512 &sipStrings_QtCore[67938]
#define sipNameNr_Sidamo 67945
#define sipName_Sidamo &sipStrings_QtCore[67945]
#define sipNameNr_Signal 22584
#define sipName_Signal &sipStrings_QtCore[22584]
#define sipNameNr_Sindhi 67952
#define sipName_Sindhi &sipStrings_QtCore[67952]
#define sipNameNr_Slovak 67959
#define sipName_Slovak &sipStrings_QtCore[67959]
#define sipNameNr_Somali 67966
#define sipName_Somali &sipStrings_QtCore[67966]
#define sipNameNr_Status 2646
#define sipName_Status &sipStrings_QtCore[2646]
#define sipNameNr_String 8815
#define sipName_String &sipStrings_QtCore[8815]
#define sipNameNr_Sunday 67973
#define sipName_Sunday &sipStrings_QtCore[67973]
#define sipNameNr_Sweden 67980
#define sipName_Sweden &sipStrings_QtCore[67980]
#define sipNameNr_Syriac 43021
#define sipName_Syriac &sipStrings_QtCore[43021]
#define sipNameNr_System 3891
#define sipName_System &sipStrings_QtCore[3891]
#define sipNameNr_TaiDam 67987
#define sipName_TaiDam &sipStrings_QtCore[67987]
#define sipNameNr_Taiwan 67994
#define sipName_Taiwan &sipStrings_QtCore[67994]
#define sipNameNr_Taroko 68001
#define sipName_Taroko &sipStrings_QtCore[68001]
#define sipNameNr_Telugu 43063
#define sipName_Telugu &sipStrings_QtCore[43063]
#define sipNameNr_Toggle 21463
#define sipName_Toggle &sipStrings_QtCore[21463]
#define sipNameNr_Tongan 68008
#define sipName_Tongan &sipStrings_QtCore[68008]
#define sipNameNr_Tsonga 68015
#define sipName_Tsonga &sipStrings_QtCore[68015]
#define sipNameNr_Tswana 68022
#define sipName_Tswana &sipStrings_QtCore[68022]
#define sipNameNr_Turkey 68029
#define sipName_Turkey &sipStrings_QtCore[68029]
#define sipNameNr_UShort 64021
#define sipName_UShort &sipStrings_QtCore[64021]
#define sipNameNr_Uganda 68036
#define sipName_Uganda &sipStrings_QtCore[68036]
#define sipNameNr_Uighur 68043
#define sipName_Uighur &sipStrings_QtCore[68043]
#define sipNameNr_Uyghur 29533
#define sipName_Uyghur &sipStrings_QtCore[29533]
#define sipNameNr_Walamo 68050
#define sipName_Walamo &sipStrings_QtCore[68050]
#define sipNameNr_Walser 68057
#define sipName_Walser &sipStrings_QtCore[68057]
#define sipNameNr_Widget 7619
#define sipName_Widget &sipStrings_QtCore[7619]
#define sipNameNr_Window 7139
#define sipName_Window &sipStrings_QtCore[7139]
#define sipNameNr_Yoruba 68064
#define sipName_Yoruba &sipStrings_QtCore[68064]
#define sipNameNr_Zambia 68071
#define sipName_Zambia &sipStrings_QtCore[68071]
#define sipNameNr_Zhuang 68078
#define sipName_Zhuang &sipStrings_QtCore[68078]
#define sipNameNr___eq__ 68085
#define sipName___eq__ &sipStrings_QtCore[68085]
#define sipNameNr___ge__ 68092
#define sipName___ge__ &sipStrings_QtCore[68092]
#define sipNameNr___gt__ 68099
#define sipName___gt__ &sipStrings_QtCore[68099]
#define sipNameNr___le__ 68106
#define sipName___le__ &sipStrings_QtCore[68106]
#define sipNameNr___lt__ 68113
#define sipName___lt__ &sipStrings_QtCore[68113]
#define sipNameNr___ne__ 68120
#define sipName___ne__ &sipStrings_QtCore[68120]
#define sipNameNr___or__ 68127
#define sipName___or__ &sipStrings_QtCore[68127]
#define sipNameNr_accept 68134
#define sipName_accept &sipStrings_QtCore[68134]
#define sipNameNr_access 68141
#define sipName_access &sipStrings_QtCore[68141]
#define sipNameNr_adjust 68148
#define sipName_adjust &sipStrings_QtCore[68148]
#define sipNameNr_amText 68155
#define sipName_amText &sipStrings_QtCore[68155]
#define sipNameNr_append 68162
#define sipName_append &sipStrings_QtCore[68162]
#define sipNameNr_assign 68169
#define sipName_assign &sipStrings_QtCore[68169]
#define sipNameNr_attach 68176
#define sipName_attach &sipStrings_QtCore[68176]
#define sipNameNr_bottom 68183
#define sipName_bottom &sipStrings_QtCore[68183]
#define sipNameNr_buffer 68190
#define sipName_buffer &sipStrings_QtCore[68190]
#define sipNameNr_cancel 68197
#define sipName_cancel &sipStrings_QtCore[68197]
#define sipNameNr_center 68204
#define sipName_center &sipStrings_QtCore[68204]
#define sipNameNr_color0 68211
#define sipName_color0 &sipStrings_QtCore[68211]
#define sipNameNr_color1 68218
#define sipName_color1 &sipStrings_QtCore[68218]
#define sipNameNr_column 68225
#define sipName_column &sipStrings_QtCore[68225]
#define sipNameNr_commit 68232
#define sipName_commit &sipStrings_QtCore[68232]
#define sipNameNr_create 68239
#define sipName_create &sipStrings_QtCore[68239]
#define sipNameNr_daysTo 68246
#define sipName_daysTo &sipStrings_QtCore[68246]
#define sipNameNr_decode 68253
#define sipName_decode &sipStrings_QtCore[68253]
#define sipNameNr_detach 68260
#define sipName_detach &sipStrings_QtCore[68260]
#define sipNameNr_device 68267
#define sipName_device &sipStrings_QtCore[68267]
#define sipNameNr_drives 68274
#define sipName_drives &sipStrings_QtCore[68274]
#define sipNameNr_encode 68281
#define sipName_encode &sipStrings_QtCore[68281]
#define sipNameNr_endMap 68288
#define sipName_endMap &sipStrings_QtCore[68288]
#define sipNameNr_escape 68295
#define sipName_escape &sipStrings_QtCore[68295]
#define sipNameNr_exists 68302
#define sipName_exists &sipStrings_QtCore[68302]
#define sipNameNr_filter 68309
#define sipName_filter &sipStrings_QtCore[68309]
#define sipNameNr_format 68316
#define sipName_format &sipStrings_QtCore[68316]
#define sipNameNr_handle 68323
#define sipName_handle &sipStrings_QtCore[68323]
#define sipNameNr_height 68330
#define sipName_height &sipStrings_QtCore[68330]
#define sipNameNr_ignore 68337
#define sipName_ignore &sipStrings_QtCore[68337]
#define sipNameNr_insert 68344
#define sipName_insert &sipStrings_QtCore[68344]
#define sipNameNr_invoke 68351
#define sipName_invoke &sipStrings_QtCore[68351]
#define sipNameNr_isBool 68358
#define sipName_isBool &sipStrings_QtCore[68358]
#define sipNameNr_isFile 68365
#define sipName_isFile &sipStrings_QtCore[68365]
#define sipNameNr_isFlag 68372
#define sipName_isFlag &sipStrings_QtCore[68372]
#define sipNameNr_isNull 68379
#define sipName_isNull &sipStrings_QtCore[68379]
#define sipNameNr_isOpen 68386
#define sipName_isOpen &sipStrings_QtCore[68386]
#define sipNameNr_isRoot 68393
#define sipName_isRoot &sipStrings_QtCore[68393]
#define sipNameNr_isTrue 68400
#define sipName_isTrue &sipStrings_QtCore[68400]
#define sipNameNr_isUser 68407
#define sipName_isUser &sipStrings_QtCore[68407]
#define sipNameNr_length 68414
#define sipName_length &sipStrings_QtCore[68414]
#define sipNameNr_locale 68421
#define sipName_locale &sipStrings_QtCore[68421]
#define sipNameNr_locate 68428
#define sipName_locate &sipStrings_QtCore[68428]
#define sipNameNr_method 68435
#define sipName_method &sipStrings_QtCore[68435]
#define sipNameNr_minute 68442
#define sipName_minute &sipStrings_QtCore[68442]
#define sipNameNr_mkpath 68449
#define sipName_mkpath &sipStrings_QtCore[68449]
#define sipNameNr_moveTo 68456
#define sipName_moveTo &sipStrings_QtCore[68456]
#define sipNameNr_msleep 68463
#define sipName_msleep &sipStrings_QtCore[68463]
#define sipNameNr_notify 68470
#define sipName_notify &sipStrings_QtCore[68470]
#define sipNameNr_number 68477
#define sipName_number &sipStrings_QtCore[68477]
#define sipNameNr_object 68484
#define sipName_object &sipStrings_QtCore[68484]
#define sipNameNr_offset 68491
#define sipName_offset &sipStrings_QtCore[68491]
#define sipNameNr_parent 8529
#define sipName_parent &sipStrings_QtCore[8529]
#define sipNameNr_period 68498
#define sipName_period &sipStrings_QtCore[68498]
#define sipNameNr_pmText 68505
#define sipName_pmText &sipStrings_QtCore[68505]
#define sipNameNr_policy 68512
#define sipName_policy &sipStrings_QtCore[68512]
#define sipNameNr_prefix 68519
#define sipName_prefix &sipStrings_QtCore[68519]
#define sipNameNr_proper 68526
#define sipName_proper &sipStrings_QtCore[68526]
#define sipNameNr_qDebug 68533
#define sipName_qDebug &sipStrings_QtCore[68533]
#define sipNameNr_qFatal 68540
#define sipName_qFatal &sipStrings_QtCore[68540]
#define sipNameNr_qIsInf 68547
#define sipName_qIsInf &sipStrings_QtCore[68547]
#define sipNameNr_qIsNaN 68554
#define sipName_qIsNaN &sipStrings_QtCore[68554]
#define sipNameNr_qRound 68561
#define sipName_qRound &sipStrings_QtCore[68561]
#define sipNameNr_relock 68568
#define sipName_relock &sipStrings_QtCore[68568]
#define sipNameNr_remove 68575
#define sipName_remove &sipStrings_QtCore[68575]
#define sipNameNr_rename 68582
#define sipName_rename &sipStrings_QtCore[68582]
#define sipNameNr_resize 68589
#define sipName_resize &sipStrings_QtCore[68589]
#define sipNameNr_result 68596
#define sipName_result &sipStrings_QtCore[68596]
#define sipNameNr_resume 68603
#define sipName_resume &sipStrings_QtCore[68603]
#define sipNameNr_revert 68610
#define sipName_revert &sipStrings_QtCore[68610]
#define sipNameNr_rmpath 68617
#define sipName_rmpath &sipStrings_QtCore[68617]
#define sipNameNr_scaled 68624
#define sipName_scaled &sipStrings_QtCore[68624]
#define sipNameNr_scheme 68631
#define sipName_scheme &sipStrings_QtCore[68631]
#define sipNameNr_script 68638
#define sipName_script &sipStrings_QtCore[68638]
#define sipNameNr_second 68645
#define sipName_second &sipStrings_QtCore[68645]
#define sipNameNr_secsTo 66319
#define sipName_secsTo &sipStrings_QtCore[66319]
#define sipNameNr_select 61258
#define sipName_select &sipStrings_QtCore[61258]
#define sipNameNr_sender 68652
#define sipName_sender &sipStrings_QtCore[68652]
#define sipNameNr_setBit 68659
#define sipName_setBit &sipStrings_QtCore[68659]
#define sipNameNr_setHMS 68666
#define sipName_setHMS &sipStrings_QtCore[68666]
#define sipNameNr_setKey 68673
#define sipName_setKey &sipStrings_QtCore[68673]
#define sipNameNr_setNum 68680
#define sipName_setNum &sipStrings_QtCore[68680]
#define sipNameNr_setTop 68687
#define sipName_setTop &sipStrings_QtCore[68687]
#define sipNameNr_setUrl 68694
#define sipName_setUrl &sipStrings_QtCore[68694]
#define sipNameNr_sizeOf 68701
#define sipName_sizeOf &sipStrings_QtCore[68701]
#define sipNameNr_sliced 68708
#define sipName_sliced &sipStrings_QtCore[68708]
#define sipNameNr_socket 68715
#define sipName_socket &sipStrings_QtCore[68715]
#define sipNameNr_status 68722
#define sipName_status &sipStrings_QtCore[68722]
#define sipNameNr_string 68729
#define sipName_string &sipStrings_QtCore[68729]
#define sipNameNr_submit 68736
#define sipName_submit &sipStrings_QtCore[68736]
#define sipNameNr_suffix 68743
#define sipName_suffix &sipStrings_QtCore[68743]
#define sipNameNr_symbol 68750
#define sipName_symbol &sipStrings_QtCore[68750]
#define sipNameNr_syntax 68757
#define sipName_syntax &sipStrings_QtCore[68757]
#define sipNameNr_system 68764
#define sipName_system &sipStrings_QtCore[68764]
#define sipNameNr_takeAt 68771
#define sipName_takeAt &sipStrings_QtCore[68771]
#define sipNameNr_thread 68778
#define sipName_thread &sipStrings_QtCore[68778]
#define sipNameNr_toBool 68785
#define sipName_toBool &sipStrings_QtCore[68785]
#define sipNameNr_toDate 68792
#define sipName_toDate &sipStrings_QtCore[68792]
#define sipNameNr_toJson 68799
#define sipName_toJson &sipStrings_QtCore[68799]
#define sipNameNr_toLine 68806
#define sipName_toLine &sipStrings_QtCore[68806]
#define sipNameNr_toLong 68813
#define sipName_toLong &sipStrings_QtCore[68813]
#define sipNameNr_toRect 68820
#define sipName_toRect &sipStrings_QtCore[68820]
#define sipNameNr_toSize 68827
#define sipName_toSize &sipStrings_QtCore[68827]
#define sipNameNr_toTime 68834
#define sipName_toTime &sipStrings_QtCore[68834]
#define sipNameNr_toUInt 68841
#define sipName_toUInt &sipStrings_QtCore[68841]
#define sipNameNr_typeId 68848
#define sipName_typeId &sipStrings_QtCore[68848]
#define sipNameNr_united 68855
#define sipName_united &sipStrings_QtCore[68855]
#define sipNameNr_unload 68862
#define sipName_unload &sipStrings_QtCore[68862]
#define sipNameNr_unlock 68869
#define sipName_unlock &sipStrings_QtCore[68869]
#define sipNameNr_usleep 68876
#define sipName_usleep &sipStrings_QtCore[68876]
#define sipNameNr_value0 68883
#define sipName_value0 &sipStrings_QtCore[68883]
#define sipNameNr_value1 68890
#define sipName_value1 &sipStrings_QtCore[68890]
#define sipNameNr_value2 68897
#define sipName_value2 &sipStrings_QtCore[68897]
#define sipNameNr_value3 68904
#define sipName_value3 &sipStrings_QtCore[68904]
#define sipNameNr_value4 68911
#define sipName_value4 &sipStrings_QtCore[68911]
#define sipNameNr_value5 68918
#define sipName_value5 &sipStrings_QtCore[68918]
#define sipNameNr_value6 68925
#define sipName_value6 &sipStrings_QtCore[68925]
#define sipNameNr_value7 68932
#define sipName_value7 &sipStrings_QtCore[68932]
#define sipNameNr_value8 68939
#define sipName_value8 &sipStrings_QtCore[68939]
#define sipNameNr_value9 68946
#define sipName_value9 &sipStrings_QtCore[68946]
#define sipNameNr_values 68953
#define sipName_values &sipStrings_QtCore[68953]
#define sipNameNr_vmicro 68960
#define sipName_vmicro &sipStrings_QtCore[68960]
#define sipNameNr_vminor 68967
#define sipName_vminor &sipStrings_QtCore[68967]
#define sipNameNr_wakeUp 68974
#define sipName_wakeUp &sipStrings_QtCore[68974]
#define sipNameNr_yellow 68981
#define sipName_yellow &sipStrings_QtCore[68981]
#define sipNameNr_Aghem 68988
#define sipName_Aghem &sipStrings_QtCore[68988]
#define sipNameNr_Array 9994
#define sipName_Array &sipStrings_QtCore[9994]
#define sipNameNr_Aruba 68994
#define sipName_Aruba &sipStrings_QtCore[68994]
#define sipNameNr_Atsam 69000
#define sipName_Atsam &sipStrings_QtCore[69000]
#define sipNameNr_Bafia 69006
#define sipName_Bafia &sipStrings_QtCore[69006]
#define sipNameNr_Bamun 69012
#define sipName_Bamun &sipStrings_QtCore[69012]
#define sipNameNr_Basaa 69018
#define sipName_Basaa &sipStrings_QtCore[69018]
#define sipNameNr_Bemba 69024
#define sipName_Bemba &sipStrings_QtCore[69024]
#define sipNameNr_Benin 69030
#define sipName_Benin &sipStrings_QtCore[69030]
#define sipNameNr_Chewa 69036
#define sipName_Chewa &sipStrings_QtCore[69036]
#define sipNameNr_Chiga 69042
#define sipName_Chiga &sipStrings_QtCore[69042]
#define sipNameNr_Chile 69048
#define sipName_Chile &sipStrings_QtCore[69048]
#define sipNameNr_China 69054
#define sipName_China &sipStrings_QtCore[69054]
#define sipNameNr_Clear 58559
#define sipName_Clear &sipStrings_QtCore[58559]
#define sipNameNr_Close 6164
#define sipName_Close &sipStrings_QtCore[6164]
#define sipNameNr_Czech 69060
#define sipName_Czech &sipStrings_QtCore[69060]
#define sipNameNr_Dogri 69066
#define sipName_Dogri &sipStrings_QtCore[69066]
#define sipNameNr_Duala 69072
#define sipName_Duala &sipStrings_QtCore[69072]
#define sipNameNr_Dutch 69078
#define sipName_Dutch &sipStrings_QtCore[69078]
#define sipNameNr_Egypt 69084
#define sipName_Egypt &sipStrings_QtCore[69084]
#define sipNameNr_Enter 10383
#define sipName_Enter &sipStrings_QtCore[10383]
#define sipNameNr_Error 950
#define sipName_Error &sipStrings_QtCore[950]
#define sipNameNr_Erzya 69090
#define sipName_Erzya &sipStrings_QtCore[69090]
#define sipNameNr_Files 69096
#define sipName_Files &sipStrings_QtCore[69096]
#define sipNameNr_First 53469
#define sipName_First &sipStrings_QtCore[53469]
#define sipNameNr_Float 57864
#define sipName_Float &sipStrings_QtCore[57864]
#define sipNameNr_Floor 29296
#define sipName_Floor &sipStrings_QtCore[29296]
#define sipNameNr_Fulah 69102
#define sipName_Fulah &sipStrings_QtCore[69102]
#define sipNameNr_Gabon 69108
#define sipName_Gabon &sipStrings_QtCore[69108]
#define sipNameNr_Ganda 69114
#define sipName_Ganda &sipStrings_QtCore[69114]
#define sipNameNr_Ghana 69120
#define sipName_Ghana &sipStrings_QtCore[69120]
#define sipNameNr_Greek 36399
#define sipName_Greek &sipStrings_QtCore[36399]
#define sipNameNr_Gusii 69126
#define sipName_Gusii &sipStrings_QtCore[69126]
#define sipNameNr_Haiti 69132
#define sipName_Haiti &sipStrings_QtCore[69132]
#define sipNameNr_Hausa 69138
#define sipName_Hausa &sipStrings_QtCore[69138]
#define sipNameNr_Hindi 69144
#define sipName_Hindi &sipStrings_QtCore[69144]
#define sipNameNr_Id128 69150
#define sipName_Id128 &sipStrings_QtCore[69150]
#define sipNameNr_India 69156
#define sipName_India &sipStrings_QtCore[69156]
#define sipNameNr_Irish 62141
#define sipName_Irish &sipStrings_QtCore[62141]
#define sipNameNr_Italy 69162
#define sipName_Italy &sipStrings_QtCore[69162]
#define sipNameNr_Japan 69168
#define sipName_Japan &sipStrings_QtCore[69168]
#define sipNameNr_Kamba 69174
#define sipName_Kamba &sipStrings_QtCore[69174]
#define sipNameNr_Kenya 69180
#define sipName_Kenya &sipStrings_QtCore[69180]
#define sipNameNr_Key_0 69186
#define sipName_Key_0 &sipStrings_QtCore[69186]
#define sipNameNr_Key_1 69192
#define sipName_Key_1 &sipStrings_QtCore[69192]
#define sipNameNr_Key_2 69198
#define sipName_Key_2 &sipStrings_QtCore[69198]
#define sipNameNr_Key_3 69204
#define sipName_Key_3 &sipStrings_QtCore[69204]
#define sipNameNr_Key_4 69210
#define sipName_Key_4 &sipStrings_QtCore[69210]
#define sipNameNr_Key_5 69216
#define sipName_Key_5 &sipStrings_QtCore[69216]
#define sipNameNr_Key_6 69222
#define sipName_Key_6 &sipStrings_QtCore[69222]
#define sipNameNr_Key_7 69228
#define sipName_Key_7 &sipStrings_QtCore[69228]
#define sipNameNr_Key_8 69234
#define sipName_Key_8 &sipStrings_QtCore[69234]
#define sipNameNr_Key_9 69240
#define sipName_Key_9 &sipStrings_QtCore[69240]
#define sipNameNr_Key_A 69246
#define sipName_Key_A &sipStrings_QtCore[69246]
#define sipNameNr_Key_B 69252
#define sipName_Key_B &sipStrings_QtCore[69252]
#define sipNameNr_Key_C 69258
#define sipName_Key_C &sipStrings_QtCore[69258]
#define sipNameNr_Key_D 69264
#define sipName_Key_D &sipStrings_QtCore[69264]
#define sipNameNr_Key_E 69270
#define sipName_Key_E &sipStrings_QtCore[69270]
#define sipNameNr_Key_F 69276
#define sipName_Key_F &sipStrings_QtCore[69276]
#define sipNameNr_Key_G 69282
#define sipName_Key_G &sipStrings_QtCore[69282]
#define sipNameNr_Key_H 69288
#define sipName_Key_H &sipStrings_QtCore[69288]
#define sipNameNr_Key_I 69294
#define sipName_Key_I &sipStrings_QtCore[69294]
#define sipNameNr_Key_J 69300
#define sipName_Key_J &sipStrings_QtCore[69300]
#define sipNameNr_Key_K 69306
#define sipName_Key_K &sipStrings_QtCore[69306]
#define sipNameNr_Key_L 69312
#define sipName_Key_L &sipStrings_QtCore[69312]
#define sipNameNr_Key_M 69318
#define sipName_Key_M &sipStrings_QtCore[69318]
#define sipNameNr_Key_N 69324
#define sipName_Key_N &sipStrings_QtCore[69324]
#define sipNameNr_Key_O 69330
#define sipName_Key_O &sipStrings_QtCore[69330]
#define sipNameNr_Key_P 69336
#define sipName_Key_P &sipStrings_QtCore[69336]
#define sipNameNr_Key_Q 69342
#define sipName_Key_Q &sipStrings_QtCore[69342]
#define sipNameNr_Key_R 69348
#define sipName_Key_R &sipStrings_QtCore[69348]
#define sipNameNr_Key_S 69354
#define sipName_Key_S &sipStrings_QtCore[69354]
#define sipNameNr_Key_T 69360
#define sipName_Key_T &sipStrings_QtCore[69360]
#define sipNameNr_Key_U 69366
#define sipName_Key_U &sipStrings_QtCore[69366]
#define sipNameNr_Key_V 69372
#define sipName_Key_V &sipStrings_QtCore[69372]
#define sipNameNr_Key_W 69378
#define sipName_Key_W &sipStrings_QtCore[69378]
#define sipNameNr_Key_X 69384
#define sipName_Key_X &sipStrings_QtCore[69384]
#define sipNameNr_Key_Y 69390
#define sipName_Key_Y &sipStrings_QtCore[69390]
#define sipNameNr_Key_Z 69396
#define sipName_Key_Z &sipStrings_QtCore[69396]
#define sipNameNr_Khmer 47343
#define sipName_Khmer &sipStrings_QtCore[47343]
#define sipNameNr_Kiche 69402
#define sipName_Kiche &sipStrings_QtCore[69402]
#define sipNameNr_Kongo 69408
#define sipName_Kongo &sipStrings_QtCore[69408]
#define sipNameNr_Ladin 69414
#define sipName_Ladin &sipStrings_QtCore[69414]
#define sipNameNr_Langi 69420
#define sipName_Langi &sipStrings_QtCore[69420]
#define sipNameNr_Latin 36174
#define sipName_Latin &sipStrings_QtCore[36174]
#define sipNameNr_Leave 10407
#define sipName_Leave &sipStrings_QtCore[10407]
#define sipNameNr_Libya 69426
#define sipName_Libya &sipStrings_QtCore[69426]
#define sipNameNr_Light 69432
#define sipName_Light &sipStrings_QtCore[69432]
#define sipNameNr_Luyia 69438
#define sipName_Luyia &sipStrings_QtCore[69438]
#define sipNameNr_MacOS 69444
#define sipName_MacOS &sipStrings_QtCore[69444]
#define sipNameNr_Macao 69450
#define sipName_Macao &sipStrings_QtCore[69450]
#define sipNameNr_Macau 69456
#define sipName_Macau &sipStrings_QtCore[69456]
#define sipNameNr_Malay 69462
#define sipName_Malay &sipStrings_QtCore[69462]
#define sipNameNr_Malta 69468
#define sipName_Malta &sipStrings_QtCore[69468]
#define sipNameNr_Maori 69474
#define sipName_Maori &sipStrings_QtCore[69474]
#define sipNameNr_Masai 69480
#define sipName_Masai &sipStrings_QtCore[69480]
#define sipNameNr_Mende 69486
#define sipName_Mende &sipStrings_QtCore[69486]
#define sipNameNr_Nepal 69492
#define sipName_Nepal &sipStrings_QtCore[69492]
#define sipNameNr_Niger 69498
#define sipName_Niger &sipStrings_QtCore[69498]
#define sipNameNr_NoDot 69504
#define sipName_NoDot &sipStrings_QtCore[69504]
#define sipNameNr_NoPen 69510
#define sipName_NoPen &sipStrings_QtCore[69510]
#define sipNameNr_None_ 69516
#define sipName_None_ &sipStrings_QtCore[69516]
#define sipNameNr_Obolo 69522
#define sipName_Obolo &sipStrings_QtCore[69522]
#define sipNameNr_Oriya 47408
#define sipName_Oriya &sipStrings_QtCore[47408]
#define sipNameNr_Oromo 69528
#define sipName_Oromo &sipStrings_QtCore[69528]
#define sipNameNr_Osage 47421
#define sipName_Osage &sipStrings_QtCore[47421]
#define sipNameNr_Paint 69534
#define sipName_Paint &sipStrings_QtCore[69534]
#define sipNameNr_Palau 69540
#define sipName_Palau &sipStrings_QtCore[69540]
#define sipNameNr_Pijin 69546
#define sipName_Pijin &sipStrings_QtCore[69546]
#define sipNameNr_Popup 69552
#define sipName_Popup &sipStrings_QtCore[69552]
#define sipNameNr_Press 3922
#define sipName_Press &sipStrings_QtCore[3922]
#define sipNameNr_QChar 69558
#define sipName_QChar &sipStrings_QtCore[69558]
#define sipNameNr_QDate 69564
#define sipName_QDate &sipStrings_QtCore[69564]
#define sipNameNr_QFile 69570
#define sipName_QFile &sipStrings_QtCore[69570]
#define sipNameNr_QFont 69576
#define sipName_QFont &sipStrings_QtCore[69576]
#define sipNameNr_QIcon 69582
#define sipName_QIcon &sipStrings_QtCore[69582]
#define sipNameNr_QLine 69588
#define sipName_QLine &sipStrings_QtCore[69588]
#define sipNameNr_QRect 69594
#define sipName_QRect &sipStrings_QtCore[69594]
#define sipNameNr_QSize 69600
#define sipName_QSize &sipStrings_QtCore[69600]
#define sipNameNr_QTime 69606
#define sipName_QTime &sipStrings_QtCore[69606]
#define sipNameNr_QUuid 69612
#define sipName_QUuid &sipStrings_QtCore[69612]
#define sipNameNr_Q_ARG 69618
#define sipName_Q_ARG &sipStrings_QtCore[69618]
#define sipNameNr_Qatar 69624
#define sipName_Qatar &sipStrings_QtCore[69624]
#define sipNameNr_Rombo 69630
#define sipName_Rombo &sipStrings_QtCore[69630]
#define sipNameNr_Round 68562
#define sipName_Round &sipStrings_QtCore[68562]
#define sipNameNr_Rundi 69636
#define sipName_Rundi &sipStrings_QtCore[69636]
#define sipNameNr_SChar 69642
#define sipName_SChar &sipStrings_QtCore[69642]
#define sipNameNr_SHIFT 69648
#define sipName_SHIFT &sipStrings_QtCore[69648]
#define sipNameNr_Sakha 69654
#define sipName_Sakha &sipStrings_QtCore[69654]
#define sipNameNr_Samoa 40516
#define sipName_Samoa &sipStrings_QtCore[40516]
#define sipNameNr_Sango 69660
#define sipName_Sango &sipStrings_QtCore[69660]
#define sipNameNr_Sangu 69666
#define sipName_Sangu &sipStrings_QtCore[69666]
#define sipNameNr_Scope 29024
#define sipName_Scope &sipStrings_QtCore[29024]
#define sipNameNr_Sheet 43540
#define sipName_Sheet &sipStrings_QtCore[43540]
#define sipNameNr_Shona 69672
#define sipName_Shona &sipStrings_QtCore[69672]
#define sipNameNr_Short 64022
#define sipName_Short &sipStrings_QtCore[64022]
#define sipNameNr_Sizes 32849
#define sipName_Sizes &sipStrings_QtCore[32849]
#define sipNameNr_Spain 69678
#define sipName_Spain &sipStrings_QtCore[69678]
#define sipNameNr_State 8036
#define sipName_State &sipStrings_QtCore[8036]
#define sipNameNr_Sudan 56027
#define sipName_Sudan &sipStrings_QtCore[56027]
#define sipNameNr_Swati 69684
#define sipName_Swati &sipStrings_QtCore[69684]
#define sipNameNr_Syria 69690
#define sipName_Syria &sipStrings_QtCore[69690]
#define sipNameNr_Taita 69696
#define sipName_Taita &sipStrings_QtCore[69696]
#define sipNameNr_Tajik 69702
#define sipName_Tajik &sipStrings_QtCore[69702]
#define sipNameNr_Tamil 47486
#define sipName_Tamil &sipStrings_QtCore[47486]
#define sipNameNr_Tatar 69708
#define sipName_Tatar &sipStrings_QtCore[69708]
#define sipNameNr_Tigre 69714
#define sipName_Tigre &sipStrings_QtCore[69714]
#define sipNameNr_Timer 33793
#define sipName_Timer &sipStrings_QtCore[33793]
#define sipNameNr_Tonga 69720
#define sipName_Tonga &sipStrings_QtCore[69720]
#define sipNameNr_True_ 69726
#define sipName_True_ &sipStrings_QtCore[69726]
#define sipNameNr_UChar 69732
#define sipName_UChar &sipStrings_QtCore[69732]
#define sipNameNr_ULong 66760
#define sipName_ULong &sipStrings_QtCore[66760]
#define sipNameNr_Uigur 69738
#define sipName_Uigur &sipStrings_QtCore[69738]
#define sipNameNr_Utf16 69744
#define sipName_Utf16 &sipStrings_QtCore[69744]
#define sipNameNr_Utf32 69750
#define sipName_Utf32 &sipStrings_QtCore[69750]
#define sipNameNr_Uzbek 69756
#define sipName_Uzbek &sipStrings_QtCore[69756]
#define sipNameNr_Venda 69762
#define sipName_Venda &sipStrings_QtCore[69762]
#define sipNameNr_Vunjo 69768
#define sipName_Vunjo &sipStrings_QtCore[69768]
#define sipNameNr_Welsh 69774
#define sipName_Welsh &sipStrings_QtCore[69774]
#define sipNameNr_Wheel 21103
#define sipName_Wheel &sipStrings_QtCore[21103]
#define sipNameNr_Wolof 69780
#define sipName_Wolof &sipStrings_QtCore[69780]
#define sipNameNr_World 69786
#define sipName_World &sipStrings_QtCore[69786]
#define sipNameNr_Write 35297
#define sipName_Write &sipStrings_QtCore[35297]
#define sipNameNr_XAxis 69792
#define sipName_XAxis &sipStrings_QtCore[69792]
#define sipNameNr_Xhosa 69798
#define sipName_Xhosa &sipStrings_QtCore[69798]
#define sipNameNr_YAxis 69804
#define sipName_YAxis &sipStrings_QtCore[69804]
#define sipNameNr_Yemen 69810
#define sipName_Yemen &sipStrings_QtCore[69810]
#define sipNameNr_ZAxis 69816
#define sipName_ZAxis &sipStrings_QtCore[69816]
#define sipNameNr_Zarma 69822
#define sipName_Zarma &sipStrings_QtCore[69822]
#define sipNameNr_added 69828
#define sipName_added &sipStrings_QtCore[69828]
#define sipNameNr_angle 9094
#define sipName_angle &sipStrings_QtCore[9094]
#define sipNameNr_array 69834
#define sipName_array &sipStrings_QtCore[69834]
#define sipNameNr_atEnd 69840
#define sipName_atEnd &sipStrings_QtCore[69840]
#define sipNameNr_atUtc 69846
#define sipName_atUtc &sipStrings_QtCore[69846]
#define sipNameNr_awake 69852
#define sipName_awake &sipStrings_QtCore[69852]
#define sipNameNr_begin 69858
#define sipName_begin &sipStrings_QtCore[69858]
#define sipNameNr_black 69864
#define sipName_black &sipStrings_QtCore[69864]
#define sipNameNr_buddy 69870
#define sipName_buddy &sipStrings_QtCore[69870]
#define sipNameNr_child 69876
#define sipName_child &sipStrings_QtCore[69876]
#define sipNameNr_clear 69882
#define sipName_clear &sipStrings_QtCore[69882]
#define sipNameNr_clone 69888
#define sipName_clone &sipStrings_QtCore[69888]
#define sipNameNr_close 69894
#define sipName_close &sipStrings_QtCore[69894]
#define sipNameNr_count 69900
#define sipName_count &sipStrings_QtCore[69900]
#define sipNameNr_debug 69906
#define sipName_debug &sipStrings_QtCore[69906]
#define sipNameNr_error 69912
#define sipName_error &sipStrings_QtCore[69912]
#define sipNameNr_event 69918
#define sipName_event &sipStrings_QtCore[69918]
#define sipNameNr_fatal 69924
#define sipName_fatal &sipStrings_QtCore[69924]
#define sipNameNr_files 69930
#define sipName_files &sipStrings_QtCore[69930]
#define sipNameNr_first 69936
#define sipName_first &sipStrings_QtCore[69936]
#define sipNameNr_fixed 69942
#define sipName_fixed &sipStrings_QtCore[69942]
#define sipNameNr_flags 69948
#define sipName_flags &sipStrings_QtCore[69948]
#define sipNameNr_flush 69954
#define sipName_flush &sipStrings_QtCore[69954]
#define sipNameNr_green 69960
#define sipName_green &sipStrings_QtCore[69960]
#define sipNameNr_group 69966
#define sipName_group &sipStrings_QtCore[69966]
#define sipNameNr_index 69972
#define sipName_index &sipStrings_QtCore[69972]
#define sipNameNr_isDTD 69978
#define sipName_isDTD &sipStrings_QtCore[69978]
#define sipNameNr_isDir 69984
#define sipName_isDir &sipStrings_QtCore[69984]
#define sipNameNr_isMap 69990
#define sipName_isMap &sipStrings_QtCore[69990]
#define sipNameNr_isSet 69996
#define sipName_isSet &sipStrings_QtCore[69996]
#define sipNameNr_isTag 70002
#define sipName_isTag &sipStrings_QtCore[70002]
#define sipNameNr_match 70008
#define sipName_match &sipStrings_QtCore[70008]
#define sipNameNr_merge 70014
#define sipName_merge &sipStrings_QtCore[70014]
#define sipNameNr_mkdir 70020
#define sipName_mkdir &sipStrings_QtCore[70020]
#define sipNameNr_model 70026
#define sipName_model &sipStrings_QtCore[70026]
#define sipNameNr_month 70032
#define sipName_month &sipStrings_QtCore[70032]
#define sipNameNr_msecs 70038
#define sipName_msecs &sipStrings_QtCore[70038]
#define sipNameNr_mutex 70044
#define sipName_mutex &sipStrings_QtCore[70044]
#define sipNameNr_names 70050
#define sipName_names &sipStrings_QtCore[70050]
#define sipNameNr_nsecs 70056
#define sipName_nsecs &sipStrings_QtCore[70056]
#define sipNameNr_order 70062
#define sipName_order &sipStrings_QtCore[70062]
#define sipNameNr_owner 70068
#define sipName_owner &sipStrings_QtCore[70068]
#define sipNameNr_parse 66472
#define sipName_parse &sipStrings_QtCore[66472]
#define sipNameNr_paths 70074
#define sipName_paths &sipStrings_QtCore[70074]
#define sipNameNr_pause 70080
#define sipName_pause &sipStrings_QtCore[70080]
#define sipNameNr_qInfo 70086
#define sipName_qInfo &sipStrings_QtCore[70086]
#define sipNameNr_qQNaN 70092
#define sipName_qQNaN &sipStrings_QtCore[70092]
#define sipNameNr_qSNaN 70098
#define sipName_qSNaN &sipStrings_QtCore[70098]
#define sipNameNr_query 70104
#define sipName_query &sipStrings_QtCore[70104]
#define sipNameNr_reset 70110
#define sipName_reset &sipStrings_QtCore[70110]
#define sipNameNr_right 21483
#define sipName_right &sipStrings_QtCore[21483]
#define sipNameNr_rmdir 70116
#define sipName_rmdir &sipStrings_QtCore[70116]
#define sipNameNr_roles 70122
#define sipName_roles &sipStrings_QtCore[70122]
#define sipNameNr_scale 70128
#define sipName_scale &sipStrings_QtCore[70128]
#define sipNameNr_scope 70134
#define sipName_scope &sipStrings_QtCore[70134]
#define sipNameNr_setP1 70140
#define sipName_setP1 &sipStrings_QtCore[70140]
#define sipNameNr_setP2 70146
#define sipName_setP2 &sipStrings_QtCore[70146]
#define sipNameNr_sleep 68464
#define sipName_sleep &sipStrings_QtCore[68464]
#define sipNameNr_slice 70152
#define sipName_slice &sipStrings_QtCore[70152]
#define sipNameNr_split 70158
#define sipName_split &sipStrings_QtCore[70158]
#define sipNameNr_start 66504
#define sipName_start &sipStrings_QtCore[66504]
#define sipNameNr_state 21312
#define sipName_state &sipStrings_QtCore[21312]
#define sipNameNr_style 70164
#define sipName_style &sipStrings_QtCore[70164]
#define sipNameNr_toAce 70170
#define sipName_toAce &sipStrings_QtCore[70170]
#define sipNameNr_toEnd 70176
#define sipName_toEnd &sipStrings_QtCore[70176]
#define sipNameNr_toHex 70182
#define sipName_toHex &sipStrings_QtCore[70182]
#define sipNameNr_toInt 70188
#define sipName_toInt &sipStrings_QtCore[70188]
#define sipNameNr_toUTC 70194
#define sipName_toUTC &sipStrings_QtCore[70194]
#define sipNameNr_unmap 70200
#define sipName_unmap &sipStrings_QtCore[70200]
#define sipNameNr_value 70206
#define sipName_value &sipStrings_QtCore[70206]
#define sipNameNr_white 70212
#define sipName_white &sipStrings_QtCore[70212]
#define sipNameNr_width 70218
#define sipName_width &sipStrings_QtCore[70218]
#define sipNameNr_write 34977
#define sipName_write &sipStrings_QtCore[34977]
#define sipNameNr_Afan 70224
#define sipName_Afan &sipStrings_QtCore[70224]
#define sipNameNr_Afar 70229
#define sipName_Afar &sipStrings_QtCore[70229]
#define sipNameNr_Akan 70234
#define sipName_Akan &sipStrings_QtCore[70234]
#define sipNameNr_Anii 70239
#define sipName_Anii &sipStrings_QtCore[70239]
#define sipNameNr_Auto 9245
#define sipName_Auto &sipStrings_QtCore[9245]
#define sipNameNr_Axis 62277
#define sipName_Axis &sipStrings_QtCore[62277]
#define sipNameNr_Bena 70244
#define sipName_Bena &sipStrings_QtCore[70244]
#define sipNameNr_Blin 70249
#define sipName_Blin &sipStrings_QtCore[70249]
#define sipNameNr_Bodo 70254
#define sipName_Bodo &sipStrings_QtCore[70254]
#define sipNameNr_Bool 61050
#define sipName_Bool &sipStrings_QtCore[61050]
#define sipNameNr_Both 70259
#define sipName_Both &sipStrings_QtCore[70259]
#define sipNameNr_CTRL 70264
#define sipName_CTRL &sipStrings_QtCore[70264]
#define sipNameNr_Ceil 70269
#define sipName_Ceil &sipStrings_QtCore[70269]
#define sipNameNr_Chad 70274
#define sipName_Chad &sipStrings_QtCore[70274]
#define sipNameNr_Char 53386
#define sipName_Char &sipStrings_QtCore[53386]
#define sipNameNr_Code 1474
#define sipName_Code &sipStrings_QtCore[1474]
#define sipNameNr_Cree 56050
#define sipName_Cree &sipStrings_QtCore[56050]
#define sipNameNr_Cuba 70279
#define sipName_Cuba &sipStrings_QtCore[70279]
#define sipNameNr_Dark 70284
#define sipName_Dark &sipStrings_QtCore[70284]
#define sipNameNr_Dash 70289
#define sipName_Dash &sipStrings_QtCore[70289]
#define sipNameNr_Dirs 64137
#define sipName_Dirs &sipStrings_QtCore[64137]
#define sipNameNr_Drop 24539
#define sipName_Drop &sipStrings_QtCore[24539]
#define sipNameNr_Edge 54268
#define sipName_Edge &sipStrings_QtCore[54268]
#define sipNameNr_Embu 70294
#define sipName_Embu &sipStrings_QtCore[70294]
#define sipNameNr_Fiji 70299
#define sipName_Fiji &sipStrings_QtCore[70299]
#define sipNameNr_Flag 1935
#define sipName_Flag &sipStrings_QtCore[1935]
#define sipNameNr_Full 70304
#define sipName_Full &sipStrings_QtCore[70304]
#define sipNameNr_Geez 70309
#define sipName_Geez &sipStrings_QtCore[70309]
#define sipNameNr_Guam 70314
#define sipName_Guam &sipStrings_QtCore[70314]
#define sipNameNr_Hide 7168
#define sipName_Hide &sipStrings_QtCore[7168]
#define sipNameNr_High 70319
#define sipName_High &sipStrings_QtCore[70319]
#define sipNameNr_Igbo 70324
#define sipName_Igbo &sipStrings_QtCore[70324]
#define sipNameNr_Iran 70329
#define sipName_Iran &sipStrings_QtCore[70329]
#define sipNameNr_Iraq 70334
#define sipName_Iraq &sipStrings_QtCore[70334]
#define sipNameNr_Kako 70339
#define sipName_Kako &sipStrings_QtCore[70339]
#define sipNameNr_Komi 70344
#define sipName_Komi &sipStrings_QtCore[70344]
#define sipNameNr_Koro 70349
#define sipName_Koro &sipStrings_QtCore[70349]
#define sipNameNr_Kuvi 70354
#define sipName_Kuvi &sipStrings_QtCore[70354]
#define sipNameNr_Laos 70359
#define sipName_Laos &sipStrings_QtCore[70359]
#define sipNameNr_Last 41665
#define sipName_Last &sipStrings_QtCore[41665]
#define sipNameNr_Line 35680
#define sipName_Line &sipStrings_QtCore[35680]
#define sipNameNr_Long 53914
#define sipName_Long &sipStrings_QtCore[53914]
#define sipNameNr_META 70364
#define sipName_META &sipStrings_QtCore[70364]
#define sipNameNr_Mali 70369
#define sipName_Mali &sipStrings_QtCore[70369]
#define sipNameNr_Manx 70374
#define sipName_Manx &sipStrings_QtCore[70374]
#define sipNameNr_Meru 70379
#define sipName_Meru &sipStrings_QtCore[70379]
#define sipNameNr_Meta 7517
#define sipName_Meta &sipStrings_QtCore[7517]
#define sipNameNr_Move 12024
#define sipName_Move &sipStrings_QtCore[12024]
#define sipNameNr_Nama 70384
#define sipName_Nama &sipStrings_QtCore[70384]
#define sipNameNr_Name 15720
#define sipName_Name &sipStrings_QtCore[15720]
#define sipNameNr_Niue 70389
#define sipName_Niue &sipStrings_QtCore[70389]
#define sipNameNr_Nuer 70394
#define sipName_Nuer &sipStrings_QtCore[70394]
#define sipNameNr_Null 16207
#define sipName_Null &sipStrings_QtCore[16207]
#define sipNameNr_Odia 70399
#define sipName_Odia &sipStrings_QtCore[70399]
#define sipNameNr_Oman 70404
#define sipName_Oman &sipStrings_QtCore[70404]
#define sipNameNr_Open 61377
#define sipName_Open &sipStrings_QtCore[61377]
#define sipNameNr_Pali 70409
#define sipName_Pali &sipStrings_QtCore[70409]
#define sipNameNr_Peru 70414
#define sipName_Peru &sipStrings_QtCore[70414]
#define sipNameNr_QDir 70419
#define sipName_QDir &sipStrings_QtCore[70419]
#define sipNameNr_QPen 70424
#define sipName_QPen &sipStrings_QtCore[70424]
#define sipNameNr_QUrl 70429
#define sipName_QUrl &sipStrings_QtCore[70429]
#define sipNameNr_Quit 52486
#define sipName_Quit &sipStrings_QtCore[52486]
#define sipNameNr_Read 30147
#define sipName_Read &sipStrings_QtCore[30147]
#define sipNameNr_Rows 13335
#define sipName_Rows &sipStrings_QtCore[13335]
#define sipNameNr_Saho 70434
#define sipName_Saho &sipStrings_QtCore[70434]
#define sipNameNr_Sena 70439
#define sipName_Sena &sipStrings_QtCore[70439]
#define sipNameNr_Sha1 70444
#define sipName_Sha1 &sipStrings_QtCore[70444]
#define sipNameNr_Shan 70449
#define sipName_Shan &sipStrings_QtCore[70449]
#define sipNameNr_Show 70454
#define sipName_Show &sipStrings_QtCore[70454]
#define sipNameNr_Size 26465
#define sipName_Size &sipStrings_QtCore[26465]
#define sipNameNr_Slot 53014
#define sipName_Slot &sipStrings_QtCore[53014]
#define sipNameNr_Soga 70459
#define sipName_Soga &sipStrings_QtCore[70459]
#define sipNameNr_Teso 70464
#define sipName_Teso &sipStrings_QtCore[70464]
#define sipNameNr_Text 18502
#define sipName_Text &sipStrings_QtCore[18502]
#define sipNameNr_Thai 52006
#define sipName_Thai &sipStrings_QtCore[52006]
#define sipNameNr_Time 11656
#define sipName_Time &sipStrings_QtCore[11656]
#define sipNameNr_Togo 70469
#define sipName_Togo &sipStrings_QtCore[70469]
#define sipNameNr_Tool 70474
#define sipName_Tool &sipStrings_QtCore[70474]
#define sipNameNr_TvOS 70479
#define sipName_TvOS &sipStrings_QtCore[70479]
#define sipNameNr_Tyap 70484
#define sipName_Tyap &sipStrings_QtCore[70484]
#define sipNameNr_Type 2415
#define sipName_Type &sipStrings_QtCore[2415]
#define sipNameNr_UInt 68843
#define sipName_UInt &sipStrings_QtCore[68843]
#define sipNameNr_Urdu 70489
#define sipName_Urdu &sipStrings_QtCore[70489]
#define sipNameNr_User 59730
#define sipName_User &sipStrings_QtCore[59730]
#define sipNameNr_Utf8 53170
#define sipName_Utf8 &sipStrings_QtCore[53170]
#define sipNameNr_Uuid 56556
#define sipName_Uuid &sipStrings_QtCore[56556]
#define sipNameNr_Void 70494
#define sipName_Void &sipStrings_QtCore[70494]
#define sipNameNr_Word 61863
#define sipName_Word &sipStrings_QtCore[61863]
#define sipNameNr_Zulu 70499
#define sipName_Zulu &sipStrings_QtCore[70499]
#define sipNameNr_base 42561
#define sipName_base &sipStrings_QtCore[42561]
#define sipNameNr_bits 70504
#define sipName_bits &sipStrings_QtCore[70504]
#define sipNameNr_blue 70509
#define sipName_blue &sipStrings_QtCore[70509]
#define sipNameNr_cdUp 70514
#define sipName_cdUp &sipStrings_QtCore[70514]
#define sipNameNr_chop 70519
#define sipName_chop &sipStrings_QtCore[70519]
#define sipNameNr_code 17992
#define sipName_code &sipStrings_QtCore[17992]
#define sipNameNr_copy 70524
#define sipName_copy &sipStrings_QtCore[70524]
#define sipNameNr_cyan 70529
#define sipName_cyan &sipStrings_QtCore[70529]
#define sipNameNr_data 70534
#define sipName_data &sipStrings_QtCore[70534]
#define sipNameNr_date 13982
#define sipName_date &sipStrings_QtCore[13982]
#define sipNameNr_endl 70539
#define sipName_endl &sipStrings_QtCore[70539]
#define sipNameNr_exec 70544
#define sipName_exec &sipStrings_QtCore[70544]
#define sipNameNr_exit 70549
#define sipName_exit &sipStrings_QtCore[70549]
#define sipNameNr_file 70554
#define sipName_file &sipStrings_QtCore[70554]
#define sipNameNr_fill 70559
#define sipName_fill &sipStrings_QtCore[70559]
#define sipNameNr_from 70564
#define sipName_from &sipStrings_QtCore[70564]
#define sipNameNr_gray 70569
#define sipName_gray &sipStrings_QtCore[70569]
#define sipNameNr_hash 70574
#define sipName_hash &sipStrings_QtCore[70574]
#define sipNameNr_hint 70579
#define sipName_hint &sipStrings_QtCore[70579]
#define sipNameNr_hits 70584
#define sipName_hits &sipStrings_QtCore[70584]
#define sipNameNr_home 70589
#define sipName_home &sipStrings_QtCore[70589]
#define sipNameNr_host 70594
#define sipName_host &sipStrings_QtCore[70594]
#define sipNameNr_hour 70599
#define sipName_hour &sipStrings_QtCore[70599]
#define sipNameNr_html 70604
#define sipName_html &sipStrings_QtCore[70604]
#define sipNameNr_info 70609
#define sipName_info &sipStrings_QtCore[70609]
#define sipNameNr_keys 70614
#define sipName_keys &sipStrings_QtCore[70614]
#define sipNameNr_kill 70619
#define sipName_kill &sipStrings_QtCore[70619]
#define sipNameNr_last 70624
#define sipName_last &sipStrings_QtCore[70624]
#define sipNameNr_left 24971
#define sipName_left &sipStrings_QtCore[24971]
#define sipNameNr_line 6493
#define sipName_line &sipStrings_QtCore[6493]
#define sipNameNr_link 70629
#define sipName_link &sipStrings_QtCore[70629]
#define sipNameNr_load 55060
#define sipName_load &sipStrings_QtCore[55060]
#define sipNameNr_lock 37030
#define sipName_lock &sipStrings_QtCore[37030]
#define sipNameNr_mode 70634
#define sipName_mode &sipStrings_QtCore[70634]
#define sipNameNr_move 44563
#define sipName_move &sipStrings_QtCore[44563]
#define sipNameNr_msec 70639
#define sipName_msec &sipStrings_QtCore[70639]
#define sipNameNr_name 37750
#define sipName_name &sipStrings_QtCore[37750]
#define sipNameNr_next 70644
#define sipName_next &sipStrings_QtCore[70644]
#define sipNameNr_open 70649
#define sipName_open &sipStrings_QtCore[70649]
#define sipNameNr_path 68451
#define sipName_path &sipStrings_QtCore[68451]
#define sipNameNr_peek 70654
#define sipName_peek &sipStrings_QtCore[70654]
#define sipNameNr_port 50950
#define sipName_port &sipStrings_QtCore[50950]
#define sipNameNr_qAbs 70659
#define sipName_qAbs &sipStrings_QtCore[70659]
#define sipNameNr_qInf 70664
#define sipName_qInf &sipStrings_QtCore[70664]
#define sipNameNr_quit 70669
#define sipName_quit &sipStrings_QtCore[70669]
#define sipNameNr_read 15742
#define sipName_read &sipStrings_QtCore[15742]
#define sipNameNr_role 70674
#define sipName_role &sipStrings_QtCore[70674]
#define sipNameNr_root 70679
#define sipName_root &sipStrings_QtCore[70679]
#define sipNameNr_save 70684
#define sipName_save &sipStrings_QtCore[70684]
#define sipNameNr_seed 70689
#define sipName_seed &sipStrings_QtCore[70689]
#define sipNameNr_seek 70694
#define sipName_seek &sipStrings_QtCore[70694]
#define sipNameNr_setX 70699
#define sipName_setX &sipStrings_QtCore[70699]
#define sipNameNr_setY 70704
#define sipName_setY &sipStrings_QtCore[70704]
#define sipNameNr_size 18422
#define sipName_size &sipStrings_QtCore[18422]
#define sipNameNr_skip 70709
#define sipName_skip &sipStrings_QtCore[70709]
#define sipNameNr_sort 70714
#define sipName_sort &sipStrings_QtCore[70714]
#define sipNameNr_span 70719
#define sipName_span &sipStrings_QtCore[70719]
#define sipNameNr_spec 70724
#define sipName_spec &sipStrings_QtCore[70724]
#define sipNameNr_stat 70729
#define sipName_stat &sipStrings_QtCore[70729]
#define sipNameNr_stop 70734
#define sipName_stop &sipStrings_QtCore[70734]
#define sipNameNr_swap 70739
#define sipName_swap &sipStrings_QtCore[70739]
#define sipNameNr_sync 70744
#define sipName_sync &sipStrings_QtCore[70744]
#define sipNameNr_temp 70749
#define sipName_temp &sipStrings_QtCore[70749]
#define sipNameNr_text 19502
#define sipName_text &sipStrings_QtCore[19502]
#define sipNameNr_time 42435
#define sipName_time &sipStrings_QtCore[42435]
#define sipNameNr_type 70754
#define sipName_type &sipStrings_QtCore[70754]
#define sipNameNr_urls 70759
#define sipName_urls &sipStrings_QtCore[70759]
#define sipNameNr_wait 67331
#define sipName_wait &sipStrings_QtCore[67331]
#define sipNameNr_year 70764
#define sipName_year &sipStrings_QtCore[70764]
#define sipNameNr_zero 70769
#define sipName_zero &sipStrings_QtCore[70769]
#define sipNameNr_ALT 70774
#define sipName_ALT &sipStrings_QtCore[70774]
#define sipNameNr_Asu 70778
#define sipName_Asu &sipStrings_QtCore[70778]
#define sipNameNr_DCE 70782
#define sipName_DCE &sipStrings_QtCore[70782]
#define sipNameNr_DTD 64105
#define sipName_DTD &sipStrings_QtCore[64105]
#define sipNameNr_Eco 70786
#define sipName_Eco &sipStrings_QtCore[70786]
#define sipNameNr_Ewe 70790
#define sipName_Ewe &sipStrings_QtCore[70790]
#define sipNameNr_IOS 70794
#define sipName_IOS &sipStrings_QtCore[70794]
#define sipNameNr_Ido 70798
#define sipName_Ido &sipStrings_QtCore[70798]
#define sipNameNr_Int 60361
#define sipName_Int &sipStrings_QtCore[60361]
#define sipNameNr_Jju 70802
#define sipName_Jju &sipStrings_QtCore[70802]
#define sipNameNr_Key 28771
#define sipName_Key &sipStrings_QtCore[28771]
#define sipNameNr_Lao 55941
#define sipName_Lao &sipStrings_QtCore[55941]
#define sipNameNr_Luo 70806
#define sipName_Luo &sipStrings_QtCore[70806]
#define sipNameNr_Map 31202
#define sipName_Map &sipStrings_QtCore[31202]
#define sipNameNr_Md4 70810
#define sipName_Md4 &sipStrings_QtCore[70810]
#define sipNameNr_Md5 70814
#define sipName_Md5 &sipStrings_QtCore[70814]
#define sipNameNr_NCS 70818
#define sipName_NCS &sipStrings_QtCore[70818]
#define sipNameNr_Nko 55963
#define sipName_Nko &sipStrings_QtCore[55963]
#define sipNameNr_Rwa 70822
#define sipName_Rwa &sipStrings_QtCore[70822]
#define sipNameNr_Tag 70004
#define sipName_Tag &sipStrings_QtCore[70004]
#define sipNameNr_UTC 42324
#define sipName_UTC &sipStrings_QtCore[42324]
#define sipNameNr_Url 39686
#define sipName_Url &sipStrings_QtCore[39686]
#define sipNameNr_Vai 55974
#define sipName_Vai &sipStrings_QtCore[55974]
#define sipNameNr_add 70826
#define sipName_add &sipStrings_QtCore[70826]
#define sipNameNr_bin 70830
#define sipName_bin &sipStrings_QtCore[70830]
#define sipNameNr_bom 70834
#define sipName_bom &sipStrings_QtCore[70834]
#define sipNameNr_cal 60521
#define sipName_cal &sipStrings_QtCore[60521]
#define sipNameNr_day 15259
#define sipName_day &sipStrings_QtCore[15259]
#define sipNameNr_dec 70838
#define sipName_dec &sipStrings_QtCore[70838]
#define sipNameNr_dir 70022
#define sipName_dir &sipStrings_QtCore[70022]
#define sipNameNr_end 45343
#define sipName_end &sipStrings_QtCore[45343]
#define sipNameNr_hex 70842
#define sipName_hex &sipStrings_QtCore[70842]
#define sipNameNr_key 41736
#define sipName_key &sipStrings_QtCore[41736]
#define sipNameNr_map 65258
#define sipName_map &sipStrings_QtCore[65258]
#define sipNameNr_max 70846
#define sipName_max &sipStrings_QtCore[70846]
#define sipNameNr_mid 70850
#define sipName_mid &sipStrings_QtCore[70850]
#define sipNameNr_min 70854
#define sipName_min &sipStrings_QtCore[70854]
#define sipNameNr_nth 23309
#define sipName_nth &sipStrings_QtCore[23309]
#define sipNameNr_oct 70858
#define sipName_oct &sipStrings_QtCore[70858]
#define sipNameNr_pid 70862
#define sipName_pid &sipStrings_QtCore[70862]
#define sipNameNr_pos 70866
#define sipName_pos &sipStrings_QtCore[70866]
#define sipNameNr_red 15479
#define sipName_red &sipStrings_QtCore[15479]
#define sipNameNr_row 55908
#define sipName_row &sipStrings_QtCore[55908]
#define sipNameNr_run 70870
#define sipName_run &sipStrings_QtCore[70870]
#define sipNameNr_tag 70874
#define sipName_tag &sipStrings_QtCore[70874]
#define sipNameNr_top 4981
#define sipName_top &sipStrings_QtCore[4981]
#define sipNameNr_url 24504
#define sipName_url &sipStrings_QtCore[24504]
#define sipNameNr_utc 70878
#define sipName_utc &sipStrings_QtCore[70878]
#define sipNameNr_Ga 70882
#define sipName_Ga &sipStrings_QtCore[70882]
#define sipNameNr_IO 70885
#define sipName_IO &sipStrings_QtCore[70885]
#define sipNameNr_Ok 70888
#define sipName_Ok &sipStrings_QtCore[70888]
#define sipNameNr_Qt 7935
#define sipName_Qt &sipStrings_QtCore[7935]
#define sipNameNr_at 4105
#define sipName_at &sipStrings_QtCore[4105]
#define sipNameNr_cd 70891
#define sipName_cd &sipStrings_QtCore[70891]
#define sipNameNr_cs 23595
#define sipName_cs &sipStrings_QtCore[23595]
#define sipNameNr_dx 70894
#define sipName_dx &sipStrings_QtCore[70894]
#define sipNameNr_dy 66235
#define sipName_dy &sipStrings_QtCore[66235]
#define sipNameNr_id 32580
#define sipName_id &sipStrings_QtCore[32580]
#define sipNameNr_ok 17868
#define sipName_ok &sipStrings_QtCore[17868]
#define sipNameNr_on 289
#define sipName_on &sipStrings_QtCore[289]
#define sipNameNr_p1 70897
#define sipName_p1 &sipStrings_QtCore[70897]
#define sipNameNr_p2 70900
#define sipName_p2 &sipStrings_QtCore[70900]
#define sipNameNr_tr 63656
#define sipName_tr &sipStrings_QtCore[63656]
#define sipNameNr_ws 5271
#define sipName_ws &sipStrings_QtCore[5271]
#define sipNameNr_x1 70903
#define sipName_x1 &sipStrings_QtCore[70903]
#define sipNameNr_x2 70906
#define sipName_x2 &sipStrings_QtCore[70906]
#define sipNameNr_y1 70909
#define sipName_y1 &sipStrings_QtCore[70909]
#define sipNameNr_y2 70912
#define sipName_y2 &sipStrings_QtCore[70912]
#define sipNameNr_C 36883
#define sipName_C &sipStrings_QtCore[36883]
#define sipNameNr_c 11774
#define sipName_c &sipStrings_QtCore[11774]
#define sipNameNr_n 290
#define sipName_n &sipStrings_QtCore[290]
#define sipNameNr_x 9148
#define sipName_x &sipStrings_QtCore[9148]
#define sipNameNr_y 755
#define sipName_y &sipStrings_QtCore[755]

#define sipMalloc                   sipAPI_QtCore->api_malloc
#define sipFree                     sipAPI_QtCore->api_free
#define sipBuildResult              sipAPI_QtCore->api_build_result
#define sipCallMethod               sipAPI_QtCore->api_call_method
#define sipCallProcedureMethod      sipAPI_QtCore->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtCore->api_call_error_handler
#define sipParseResultEx            sipAPI_QtCore->api_parse_result_ex
#define sipParseResult              sipAPI_QtCore->api_parse_result
#define sipParseArgs                sipAPI_QtCore->api_parse_args
#define sipParseKwdArgs             sipAPI_QtCore->api_parse_kwd_args
#define sipParsePair                sipAPI_QtCore->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtCore->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtCore->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtCore->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtCore->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtCore->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtCore->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtCore->api_add_exception
#define sipNoFunction               sipAPI_QtCore->api_no_function
#define sipNoMethod                 sipAPI_QtCore->api_no_method
#define sipAbstractMethod           sipAPI_QtCore->api_abstract_method
#define sipBadClass                 sipAPI_QtCore->api_bad_class
#define sipBadCatcherResult         sipAPI_QtCore->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtCore->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtCore->api_bad_operator_arg
#define sipTrace                    sipAPI_QtCore->api_trace
#define sipTransferBack             sipAPI_QtCore->api_transfer_back
#define sipTransferTo               sipAPI_QtCore->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtCore->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtCore->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtCore->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtCore->api_voidptr_type
#define sipGetPyObject              sipAPI_QtCore->api_get_pyobject
#define sipGetAddress               sipAPI_QtCore->api_get_address
#define sipGetMixinAddress          sipAPI_QtCore->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtCore->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtCore->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtCore->api_call_hook
#define sipEndThread                sipAPI_QtCore->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtCore->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtCore->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtCore->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtCore->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtCore->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtCore->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtCore->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtCore->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtCore->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtCore->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtCore->api_convert_to_bool
#define sipReleaseType              sipAPI_QtCore->api_release_type
#define sipConvertFromType          sipAPI_QtCore->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtCore->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtCore->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtCore->api_convert_from_enum
#define sipGetState                 sipAPI_QtCore->api_get_state
#define sipExportSymbol             sipAPI_QtCore->api_export_symbol
#define sipImportSymbol             sipAPI_QtCore->api_import_symbol
#define sipFindType                 sipAPI_QtCore->api_find_type
#define sipBytes_AsChar             sipAPI_QtCore->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtCore->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtCore->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtCore->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtCore->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtCore->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtCore->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtCore->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtCore->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtCore->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtCore->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtCore->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtCore->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtCore->api_get_reference
#define sipKeepReference            sipAPI_QtCore->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtCore->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtCore->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtCore->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtCore->api_type_scope
#define sipResolveTypedef           sipAPI_QtCore->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtCore->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtCore->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtCore->api_init_mixin
#define sipExportModule             sipAPI_QtCore->api_export_module
#define sipInitModule               sipAPI_QtCore->api_init_module
#define sipGetInterpreter           sipAPI_QtCore->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtCore->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtCore->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtCore->api_py_type_dict
#define sipPyTypeName               sipAPI_QtCore->api_py_type_name
#define sipGetCFunction             sipAPI_QtCore->api_get_c_function
#define sipGetMethod                sipAPI_QtCore->api_get_method
#define sipFromMethod               sipAPI_QtCore->api_from_method
#define sipGetDate                  sipAPI_QtCore->api_get_date
#define sipFromDate                 sipAPI_QtCore->api_from_date
#define sipGetDateTime              sipAPI_QtCore->api_get_datetime
#define sipFromDateTime             sipAPI_QtCore->api_from_datetime
#define sipGetTime                  sipAPI_QtCore->api_get_time
#define sipFromTime                 sipAPI_QtCore->api_from_time
#define sipIsUserType               sipAPI_QtCore->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtCore->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtCore->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtCore->api_unicode_write
#define sipUnicodeData              sipAPI_QtCore->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtCore->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtCore->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtCore->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtCore->api_is_derived_class
#define sipGetUserObject            sipAPI_QtCore->api_get_user_object
#define sipSetUserObject            sipAPI_QtCore->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtCore->api_register_event_handler
#define sipConvertToArray           sipAPI_QtCore->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtCore->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtCore->api_enable_gc
#define sipPrintObject              sipAPI_QtCore->api_print_object
#define sipLong_AsChar              sipAPI_QtCore->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtCore->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtCore->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtCore->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtCore->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtCore->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtCore->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtCore->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtCore->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtCore->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtCore->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtCore->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtCore->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtCore->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtCore->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtCore->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtCore->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtCore->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtCore->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtCore->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtCore->api_release_type_us
#define sipIsPyMethod               sipAPI_QtCore->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtCore[];

#define sipType_Qt sipExportedTypes_QtCore[399]

#define sipType_Qt_ContrastPreference sipExportedTypes_QtCore[417]

#define sipType_Qt_ContextMenuTrigger sipExportedTypes_QtCore[416]

#define sipType_Qt_PermissionStatus sipExportedTypes_QtCore[461]

#define sipType_Qt_ColorScheme sipExportedTypes_QtCore[413]

#define sipType_Qt_HighDpiScaleFactorRoundingPolicy sipExportedTypes_QtCore[437]

#define sipType_Qt_ChecksumType sipExportedTypes_QtCore[411]

#define sipType_Qt_EnterKeyType sipExportedTypes_QtCore[427]

#define sipType_Qt_ItemSelectionOperation sipExportedTypes_QtCore[445]

#define sipType_Qt_TabFocusBehavior sipExportedTypes_QtCore[469]

#define sipType_Qt_MouseEventFlag sipExportedTypes_QtCore[453]

#define sipType_Qt_MouseEventSource sipExportedTypes_QtCore[454]

#define sipType_Qt_ScrollPhase sipExportedTypes_QtCore[464]

#define sipType_Qt_NativeGestureType sipExportedTypes_QtCore[455]

#define sipType_Qt_Edge sipExportedTypes_QtCore[426]

#define sipType_Qt_ApplicationState sipExportedTypes_QtCore[403]

#define sipType_Qt_HitTestAccuracy sipExportedTypes_QtCore[438]

#define sipType_Qt_WhiteSpaceMode sipExportedTypes_QtCore[482]

#define sipType_Qt_FindChildOption sipExportedTypes_QtCore[430]

#define sipType_Qt_ScreenOrientation sipExportedTypes_QtCore[462]

#define sipType_Qt_CursorMoveStyle sipExportedTypes_QtCore[420]

#define sipType_Qt_NavigationMode sipExportedTypes_QtCore[456]

#define sipType_Qt_GestureFlag sipExportedTypes_QtCore[433]

#define sipType_Qt_GestureType sipExportedTypes_QtCore[435]

#define sipType_Qt_GestureState sipExportedTypes_QtCore[434]

#define sipType_Qt_TouchPointState sipExportedTypes_QtCore[479]

#define sipType_Qt_CoordinateSystem sipExportedTypes_QtCore[418]

#define sipType_Qt_AnchorPoint sipExportedTypes_QtCore[401]

#define sipType_Qt_InputMethodHint sipExportedTypes_QtCore[440]

#define sipType_Qt_TileRule sipExportedTypes_QtCore[474]

#define sipType_Qt_WindowFrameSection sipExportedTypes_QtCore[484]

#define sipType_Qt_SizeHint sipExportedTypes_QtCore[466]

#define sipType_Qt_SizeMode sipExportedTypes_QtCore[467]

#define sipType_Qt_EventPriority sipExportedTypes_QtCore[428]

#define sipType_Qt_Axis sipExportedTypes_QtCore[406]

#define sipType_Qt_MaskMode sipExportedTypes_QtCore[449]

#define sipType_Qt_TextInteractionFlag sipExportedTypes_QtCore[473]

#define sipType_Qt_ItemSelectionMode sipExportedTypes_QtCore[444]

#define sipType_Qt_ApplicationAttribute sipExportedTypes_QtCore[402]

#define sipType_Qt_WindowModality sipExportedTypes_QtCore[485]

#define sipType_Qt_MatchFlag sipExportedTypes_QtCore[450]

#define sipType_Qt_ItemFlag sipExportedTypes_QtCore[443]

#define sipType_Qt_ItemDataRole sipExportedTypes_QtCore[442]

#define sipType_Qt_CheckState sipExportedTypes_QtCore[410]

#define sipType_Qt_DropAction sipExportedTypes_QtCore[425]

#define sipType_Qt_LayoutDirection sipExportedTypes_QtCore[448]

#define sipType_Qt_ToolButtonStyle sipExportedTypes_QtCore[478]

#define sipType_Qt_InputMethodQuery sipExportedTypes_QtCore[441]

#define sipType_Qt_ContextMenuPolicy sipExportedTypes_QtCore[415]

#define sipType_Qt_FocusReason sipExportedTypes_QtCore[432]

#define sipType_Qt_TransformationMode sipExportedTypes_QtCore[480]

#define sipType_Qt_ClipOperation sipExportedTypes_QtCore[412]

#define sipType_Qt_FillRule sipExportedTypes_QtCore[429]

#define sipType_Qt_ShortcutContext sipExportedTypes_QtCore[465]

#define sipType_Qt_ConnectionType sipExportedTypes_QtCore[414]

#define sipType_Qt_Corner sipExportedTypes_QtCore[419]

#define sipType_Qt_CaseSensitivity sipExportedTypes_QtCore[409]

#define sipType_Qt_ScrollBarPolicy sipExportedTypes_QtCore[463]

#define sipType_Qt_DayOfWeek sipExportedTypes_QtCore[423]

#define sipType_Qt_TimeSpec sipExportedTypes_QtCore[475]

#define sipType_Qt_DateFormat sipExportedTypes_QtCore[422]

#define sipType_Qt_ToolBarArea sipExportedTypes_QtCore[477]

#define sipType_Qt_TimerType sipExportedTypes_QtCore[476]

#define sipType_Qt_DockWidgetArea sipExportedTypes_QtCore[424]

#define sipType_Qt_AspectRatioMode sipExportedTypes_QtCore[405]

#define sipType_Qt_TextFormat sipExportedTypes_QtCore[472]

#define sipType_Qt_CursorShape sipExportedTypes_QtCore[421]

#define sipType_Qt_UIEffect sipExportedTypes_QtCore[481]

#define sipType_Qt_BrushStyle sipExportedTypes_QtCore[408]

#define sipType_Qt_PenJoinStyle sipExportedTypes_QtCore[459]

#define sipType_Qt_PenCapStyle sipExportedTypes_QtCore[458]

#define sipType_Qt_PenStyle sipExportedTypes_QtCore[460]

#define sipType_Qt_ArrowType sipExportedTypes_QtCore[404]

#define sipType_Qt_Key sipExportedTypes_QtCore[446]

#define sipType_Qt_BGMode sipExportedTypes_QtCore[407]

#define sipType_Qt_ImageConversionFlag sipExportedTypes_QtCore[439]

#define sipType_Qt_WidgetAttribute sipExportedTypes_QtCore[483]

#define sipType_Qt_WindowState sipExportedTypes_QtCore[486]

#define sipType_Qt_WindowType sipExportedTypes_QtCore[487]

#define sipType_Qt_TextElideMode sipExportedTypes_QtCore[470]

#define sipType_Qt_TextFlag sipExportedTypes_QtCore[471]

#define sipType_Qt_AlignmentFlag sipExportedTypes_QtCore[400]

#define sipType_Qt_SortOrder sipExportedTypes_QtCore[468]

#define sipType_Qt_FocusPolicy sipExportedTypes_QtCore[431]

#define sipType_Qt_Orientation sipExportedTypes_QtCore[457]

#define sipType_Qt_MouseButton sipExportedTypes_QtCore[452]

#define sipType_Qt_Modifier sipExportedTypes_QtCore[451]

#define sipType_Qt_KeyboardModifier sipExportedTypes_QtCore[447]

#define sipType_Qt_GlobalColor sipExportedTypes_QtCore[436]

extern sipClassTypeDef sipTypeDef_QtCore_Qt;

#define sipType_QKeyCombination sipExportedTypes_QtCore[169]

extern sipClassTypeDef sipTypeDef_QtCore_QKeyCombination;

#define sipType_QObject sipExportedTypes_QtCore[255]

extern sipClassTypeDef sipTypeDef_QtCore_QObject;

#define sipType_QAbstractAnimation sipExportedTypes_QtCore[1]

#define sipType_QAbstractAnimation_DeletionPolicy sipExportedTypes_QtCore[2]

#define sipType_QAbstractAnimation_State sipExportedTypes_QtCore[4]

#define sipType_QAbstractAnimation_Direction sipExportedTypes_QtCore[3]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractAnimation;

#define sipType_QAbstractEventDispatcher sipExportedTypes_QtCore[5]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractEventDispatcher;

#define sipType_QAbstractEventDispatcher_TimerInfo sipExportedTypes_QtCore[6]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractEventDispatcher_TimerInfo;

#define sipType_QModelIndex sipExportedTypes_QtCore[248]

extern sipClassTypeDef sipTypeDef_QtCore_QModelIndex;

#define sipType_QPersistentModelIndex sipExportedTypes_QtCore[263]

extern sipClassTypeDef sipTypeDef_QtCore_QPersistentModelIndex;

#define sipType_QAbstractItemModel sipExportedTypes_QtCore[7]

#define sipType_QAbstractItemModel_CheckIndexOption sipExportedTypes_QtCore[8]

#define sipType_QAbstractItemModel_LayoutChangeHint sipExportedTypes_QtCore[9]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractItemModel;

#define sipType_QAbstractTableModel sipExportedTypes_QtCore[13]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractTableModel;

#define sipType_QAbstractListModel sipExportedTypes_QtCore[10]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractListModel;

#define sipType_QModelRoleData sipExportedTypes_QtCore[249]

extern sipClassTypeDef sipTypeDef_QtCore_QModelRoleData;

#define sipType_QModelRoleDataSpan sipExportedTypes_QtCore[250]

extern sipClassTypeDef sipTypeDef_QtCore_QModelRoleDataSpan;

#define sipType_QAbstractNativeEventFilter sipExportedTypes_QtCore[11]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractNativeEventFilter;

#define sipType_QAbstractProxyModel sipExportedTypes_QtCore[12]

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractProxyModel;

#define sipType_QAnimationGroup sipExportedTypes_QtCore[14]

extern sipClassTypeDef sipTypeDef_QtCore_QAnimationGroup;

#define sipType_QBasicTimer sipExportedTypes_QtCore[16]

extern sipClassTypeDef sipTypeDef_QtCore_QBasicTimer;

#define sipType_QBitArray sipExportedTypes_QtCore[17]

extern sipClassTypeDef sipTypeDef_QtCore_QBitArray;

#define sipType_QIODeviceBase sipExportedTypes_QtCore[154]

#define sipType_QIODeviceBase_OpenModeFlag sipExportedTypes_QtCore[155]

extern sipClassTypeDef sipTypeDef_QtCore_QIODeviceBase;

#define sipType_QIODevice sipExportedTypes_QtCore[153]

extern sipClassTypeDef sipTypeDef_QtCore_QIODevice;

#define sipType_QBuffer sipExportedTypes_QtCore[20]

extern sipClassTypeDef sipTypeDef_QtCore_QBuffer;

#define sipType_QByteArray sipExportedTypes_QtCore[21]

#define sipType_QByteArray_Base64DecodingStatus sipExportedTypes_QtCore[22]

#define sipType_QByteArray_Base64Option sipExportedTypes_QtCore[23]

extern sipClassTypeDef sipTypeDef_QtCore_QByteArray;

#define sipType_QByteArray_FromBase64Result sipExportedTypes_QtCore[24]

extern sipClassTypeDef sipTypeDef_QtCore_QByteArray_FromBase64Result;

#define sipType_QByteArrayMatcher sipExportedTypes_QtCore[26]

extern sipClassTypeDef sipTypeDef_QtCore_QByteArrayMatcher;

#define sipType_QCalendar sipExportedTypes_QtCore[28]

#define sipType_QCalendar_System sipExportedTypes_QtCore[29]

extern sipClassTypeDef sipTypeDef_QtCore_QCalendar;

#define sipType_QCalendar_YearMonthDay sipExportedTypes_QtCore[30]

extern sipClassTypeDef sipTypeDef_QtCore_QCalendar_YearMonthDay;

#define sipType_QCborError sipExportedTypes_QtCore[34]

#define sipType_QCborError_Code sipExportedTypes_QtCore[35]

extern sipClassTypeDef sipTypeDef_QtCore_QCborError;

#define sipType_QCborStreamReader sipExportedTypes_QtCore[38]

#define sipType_QCborStreamReader_StringResultCode sipExportedTypes_QtCore[39]

#define sipType_QCborStreamReader_Type sipExportedTypes_QtCore[40]

extern sipClassTypeDef sipTypeDef_QtCore_QCborStreamReader;

#define sipType_QCborStreamWriter sipExportedTypes_QtCore[41]

extern sipClassTypeDef sipTypeDef_QtCore_QCborStreamWriter;

#define sipType_QChar sipExportedTypes_QtCore[42]

#define sipType_QChar_Script sipExportedTypes_QtCore[43]

extern sipClassTypeDef sipTypeDef_QtCore_QChar;

#define sipType_QCollatorSortKey sipExportedTypes_QtCore[46]

extern sipClassTypeDef sipTypeDef_QtCore_QCollatorSortKey;

#define sipType_QCollator sipExportedTypes_QtCore[45]

extern sipClassTypeDef sipTypeDef_QtCore_QCollator;

#define sipType_QCommandLineOption sipExportedTypes_QtCore[47]

#define sipType_QCommandLineOption_Flag sipExportedTypes_QtCore[48]

extern sipClassTypeDef sipTypeDef_QtCore_QCommandLineOption;

#define sipType_QCommandLineParser sipExportedTypes_QtCore[49]

#define sipType_QCommandLineParser_MessageType sipExportedTypes_QtCore[50]

#define sipType_QCommandLineParser_OptionsAfterPositionalArgumentsMode sipExportedTypes_QtCore[51]

#define sipType_QCommandLineParser_SingleDashWordOptionMode sipExportedTypes_QtCore[52]

extern sipClassTypeDef sipTypeDef_QtCore_QCommandLineParser;

#define sipType_QConcatenateTablesProxyModel sipExportedTypes_QtCore[53]

extern sipClassTypeDef sipTypeDef_QtCore_QConcatenateTablesProxyModel;

#define sipType_QCoreApplication sipExportedTypes_QtCore[56]

extern sipClassTypeDef sipTypeDef_QtCore_QCoreApplication;

#define sipType_QEvent sipExportedTypes_QtCore[80]

#define sipType_QEvent_Type sipExportedTypes_QtCore[81]

extern sipClassTypeDef sipTypeDef_QtCore_QEvent;

#define sipType_QTimerEvent sipExportedTypes_QtCore[366]

extern sipClassTypeDef sipTypeDef_QtCore_QTimerEvent;

#define sipType_QChildEvent sipExportedTypes_QtCore[44]

extern sipClassTypeDef sipTypeDef_QtCore_QChildEvent;

#define sipType_QDynamicPropertyChangeEvent sipExportedTypes_QtCore[75]

extern sipClassTypeDef sipTypeDef_QtCore_QDynamicPropertyChangeEvent;

#define sipType_QCryptographicHash sipExportedTypes_QtCore[57]

#define sipType_QCryptographicHash_Algorithm sipExportedTypes_QtCore[58]

extern sipClassTypeDef sipTypeDef_QtCore_QCryptographicHash;

#define sipType_QDataStream sipExportedTypes_QtCore[59]

#define sipType_QDataStream_FloatingPointPrecision sipExportedTypes_QtCore[61]

#define sipType_QDataStream_Status sipExportedTypes_QtCore[62]

#define sipType_QDataStream_ByteOrder sipExportedTypes_QtCore[60]

#define sipType_QDataStream_Version sipExportedTypes_QtCore[63]

extern sipClassTypeDef sipTypeDef_QtCore_QDataStream;

#define sipType_QDate sipExportedTypes_QtCore[64]

extern sipClassTypeDef sipTypeDef_QtCore_QDate;

#define sipType_QTime sipExportedTypes_QtCore[356]

extern sipClassTypeDef sipTypeDef_QtCore_QTime;

#define sipType_QDateTime sipExportedTypes_QtCore[65]

#define sipType_QDateTime_YearRange sipExportedTypes_QtCore[67]

#define sipType_QDateTime_TransitionResolution sipExportedTypes_QtCore[66]

extern sipClassTypeDef sipTypeDef_QtCore_QDateTime;

#define sipType_QDeadlineTimer sipExportedTypes_QtCore[68]

#define sipType_QDeadlineTimer_ForeverConstant sipExportedTypes_QtCore[69]

extern sipClassTypeDef sipTypeDef_QtCore_QDeadlineTimer;

#define sipType_QDir sipExportedTypes_QtCore[70]

#define sipType_QDir_SortFlag sipExportedTypes_QtCore[72]

#define sipType_QDir_Filter sipExportedTypes_QtCore[71]

extern sipClassTypeDef sipTypeDef_QtCore_QDir;

#define sipType_QDirIterator sipExportedTypes_QtCore[73]

#define sipType_QDirIterator_IteratorFlag sipExportedTypes_QtCore[74]

extern sipClassTypeDef sipTypeDef_QtCore_QDirIterator;

#define sipType_QEasingCurve sipExportedTypes_QtCore[76]

#define sipType_QEasingCurve_Type sipExportedTypes_QtCore[77]

extern sipClassTypeDef sipTypeDef_QtCore_QEasingCurve;

#define sipType_QElapsedTimer sipExportedTypes_QtCore[78]

#define sipType_QElapsedTimer_ClockType sipExportedTypes_QtCore[79]

extern sipClassTypeDef sipTypeDef_QtCore_QElapsedTimer;

#define sipType_QEventLoop sipExportedTypes_QtCore[82]

#define sipType_QEventLoop_ProcessEventsFlag sipExportedTypes_QtCore[83]

extern sipClassTypeDef sipTypeDef_QtCore_QEventLoop;

#define sipType_QEventLoopLocker sipExportedTypes_QtCore[84]

extern sipClassTypeDef sipTypeDef_QtCore_QEventLoopLocker;

#define sipType_QFileDevice sipExportedTypes_QtCore[86]

#define sipType_QFileDevice_MemoryMapFlag sipExportedTypes_QtCore[90]

#define sipType_QFileDevice_FileTime sipExportedTypes_QtCore[89]

#define sipType_QFileDevice_FileHandleFlag sipExportedTypes_QtCore[88]

#define sipType_QFileDevice_Permission sipExportedTypes_QtCore[91]

#define sipType_QFileDevice_FileError sipExportedTypes_QtCore[87]

extern sipClassTypeDef sipTypeDef_QtCore_QFileDevice;

#define sipType_QFile sipExportedTypes_QtCore[85]

extern sipClassTypeDef sipTypeDef_QtCore_QFile;

#define sipType_QFileInfo sipExportedTypes_QtCore[92]

extern sipClassTypeDef sipTypeDef_QtCore_QFileInfo;

#define sipType_QFileSelector sipExportedTypes_QtCore[93]

extern sipClassTypeDef sipTypeDef_QtCore_QFileSelector;

#define sipType_QFileSystemWatcher sipExportedTypes_QtCore[94]

extern sipClassTypeDef sipTypeDef_QtCore_QFileSystemWatcher;

#define sipType_QIdentityProxyModel sipExportedTypes_QtCore[156]

extern sipClassTypeDef sipTypeDef_QtCore_QIdentityProxyModel;

#define sipType_QItemSelectionRange sipExportedTypes_QtCore[160]

extern sipClassTypeDef sipTypeDef_QtCore_QItemSelectionRange;

#define sipType_QItemSelectionModel sipExportedTypes_QtCore[158]

#define sipType_QItemSelectionModel_SelectionFlag sipExportedTypes_QtCore[159]

extern sipClassTypeDef sipTypeDef_QtCore_QItemSelectionModel;

#define sipType_QItemSelection sipExportedTypes_QtCore[157]

extern sipClassTypeDef sipTypeDef_QtCore_QItemSelection;

#define sipType_QJsonDocument sipExportedTypes_QtCore[162]

#define sipType_QJsonDocument_JsonFormat sipExportedTypes_QtCore[163]

extern sipClassTypeDef sipTypeDef_QtCore_QJsonDocument;

#define sipType_QJsonParseError sipExportedTypes_QtCore[165]

#define sipType_QJsonParseError_ParseError sipExportedTypes_QtCore[166]

extern sipClassTypeDef sipTypeDef_QtCore_QJsonParseError;

#define sipType_QJsonValue sipExportedTypes_QtCore[167]

#define sipType_QJsonValue_Type sipExportedTypes_QtCore[168]

extern sipClassTypeDef sipTypeDef_QtCore_QJsonValue;

#define sipType_QLibrary sipExportedTypes_QtCore[170]

#define sipType_QLibrary_LoadHint sipExportedTypes_QtCore[171]

extern sipClassTypeDef sipTypeDef_QtCore_QLibrary;

#define sipType_QLibraryInfo sipExportedTypes_QtCore[172]

#define sipType_QLibraryInfo_LibraryPath sipExportedTypes_QtCore[173]

extern sipClassTypeDef sipTypeDef_QtCore_QLibraryInfo;

#define sipType_QLine sipExportedTypes_QtCore[174]

extern sipClassTypeDef sipTypeDef_QtCore_QLine;

#define sipType_QLineF sipExportedTypes_QtCore[175]

#define sipType_QLineF_IntersectionType sipExportedTypes_QtCore[176]

extern sipClassTypeDef sipTypeDef_QtCore_QLineF;

#define sipType_QLocale sipExportedTypes_QtCore[206]

#define sipType_QLocale_LanguageCodeType sipExportedTypes_QtCore[213]

#define sipType_QLocale_DataSizeFormat sipExportedTypes_QtCore[209]

#define sipType_QLocale_FloatingPointPrecisionOption sipExportedTypes_QtCore[210]

#define sipType_QLocale_QuotationStyle sipExportedTypes_QtCore[216]

#define sipType_QLocale_CurrencySymbolFormat sipExportedTypes_QtCore[208]

#define sipType_QLocale_Script sipExportedTypes_QtCore[217]

#define sipType_QLocale_MeasurementSystem sipExportedTypes_QtCore[214]

#define sipType_QLocale_FormatType sipExportedTypes_QtCore[211]

#define sipType_QLocale_TagSeparator sipExportedTypes_QtCore[218]

#define sipType_QLocale_NumberOption sipExportedTypes_QtCore[215]

#define sipType_QLocale_Country sipExportedTypes_QtCore[207]

#define sipType_QLocale_Language sipExportedTypes_QtCore[212]

extern sipClassTypeDef sipTypeDef_QtCore_QLocale;

#define sipType_QLockFile sipExportedTypes_QtCore[222]

#define sipType_QLockFile_LockError sipExportedTypes_QtCore[223]

extern sipClassTypeDef sipTypeDef_QtCore_QLockFile;

#define sipType_QMessageLogContext sipExportedTypes_QtCore[230]

extern sipClassTypeDef sipTypeDef_QtCore_QMessageLogContext;

#define sipType_QMessageLogger sipExportedTypes_QtCore[231]

extern sipClassTypeDef sipTypeDef_QtCore_QMessageLogger;

#define sipType_QLoggingCategory sipExportedTypes_QtCore[224]

extern sipClassTypeDef sipTypeDef_QtCore_QLoggingCategory;

#define sipType_QMargins sipExportedTypes_QtCore[227]

extern sipClassTypeDef sipTypeDef_QtCore_QMargins;

#define sipType_QMarginsF sipExportedTypes_QtCore[228]

extern sipClassTypeDef sipTypeDef_QtCore_QMarginsF;

#define sipType_QMessageAuthenticationCode sipExportedTypes_QtCore[229]

extern sipClassTypeDef sipTypeDef_QtCore_QMessageAuthenticationCode;

#define sipType_QMetaMethod sipExportedTypes_QtCore[234]

#define sipType_QMetaMethod_MethodType sipExportedTypes_QtCore[236]

#define sipType_QMetaMethod_Access sipExportedTypes_QtCore[235]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaMethod;

#define sipType_QMetaEnum sipExportedTypes_QtCore[233]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaEnum;

#define sipType_QMetaProperty sipExportedTypes_QtCore[239]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaProperty;

#define sipType_QMetaClassInfo sipExportedTypes_QtCore[232]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaClassInfo;

#define sipType_QMetaType sipExportedTypes_QtCore[240]

#define sipType_QMetaType_TypeFlag sipExportedTypes_QtCore[242]

#define sipType_QMetaType_Type sipExportedTypes_QtCore[241]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaType;

#define sipType_QMimeData sipExportedTypes_QtCore[244]

extern sipClassTypeDef sipTypeDef_QtCore_QMimeData;

#define sipType_QMimeDatabase sipExportedTypes_QtCore[245]

#define sipType_QMimeDatabase_MatchMode sipExportedTypes_QtCore[246]

extern sipClassTypeDef sipTypeDef_QtCore_QMimeDatabase;

#define sipType_QMimeType sipExportedTypes_QtCore[247]

extern sipClassTypeDef sipTypeDef_QtCore_QMimeType;

#define sipType_QMutex sipExportedTypes_QtCore[251]

extern sipClassTypeDef sipTypeDef_QtCore_QMutex;

#define sipType_QRecursiveMutex sipExportedTypes_QtCore[290]

extern sipClassTypeDef sipTypeDef_QtCore_QRecursiveMutex;

#define sipType_QSignalBlocker sipExportedTypes_QtCore[312]

extern sipClassTypeDef sipTypeDef_QtCore_QSignalBlocker;

#define sipType_QObjectCleanupHandler sipExportedTypes_QtCore[256]

extern sipClassTypeDef sipTypeDef_QtCore_QObjectCleanupHandler;

#define sipType_QMetaObject sipExportedTypes_QtCore[237]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaObject;

#define sipType_QMetaObject_Connection sipExportedTypes_QtCore[238]

extern sipClassTypeDef sipTypeDef_QtCore_QMetaObject_Connection;

#define sipType_QGenericArgument sipExportedTypes_QtCore[149]

extern sipClassTypeDef sipTypeDef_QtCore_QGenericArgument;

#define sipType_QGenericReturnArgument sipExportedTypes_QtCore[150]

extern sipClassTypeDef sipTypeDef_QtCore_QGenericReturnArgument;

#define sipType_QOperatingSystemVersionBase sipExportedTypes_QtCore[259]

extern sipClassTypeDef sipTypeDef_QtCore_QOperatingSystemVersionBase;

#define sipType_QOperatingSystemVersion sipExportedTypes_QtCore[257]

#define sipType_QOperatingSystemVersion_OSType sipExportedTypes_QtCore[258]

extern sipClassTypeDef sipTypeDef_QtCore_QOperatingSystemVersion;

#define sipType_QParallelAnimationGroup sipExportedTypes_QtCore[260]

extern sipClassTypeDef sipTypeDef_QtCore_QParallelAnimationGroup;

#define sipType_QPauseAnimation sipExportedTypes_QtCore[261]

extern sipClassTypeDef sipTypeDef_QtCore_QPauseAnimation;

#define sipType_QPermission sipExportedTypes_QtCore[262]

extern sipClassTypeDef sipTypeDef_QtCore_QPermission;

#define sipType_QLocationPermission sipExportedTypes_QtCore[219]

#define sipType_QLocationPermission_Availability sipExportedTypes_QtCore[221]

#define sipType_QLocationPermission_Accuracy sipExportedTypes_QtCore[220]

extern sipClassTypeDef sipTypeDef_QtCore_QLocationPermission;

#define sipType_QCalendarPermission sipExportedTypes_QtCore[31]

#define sipType_QCalendarPermission_AccessMode sipExportedTypes_QtCore[32]

extern sipClassTypeDef sipTypeDef_QtCore_QCalendarPermission;

#define sipType_QContactsPermission sipExportedTypes_QtCore[54]

#define sipType_QContactsPermission_AccessMode sipExportedTypes_QtCore[55]

extern sipClassTypeDef sipTypeDef_QtCore_QContactsPermission;

#define sipType_QCameraPermission sipExportedTypes_QtCore[33]

extern sipClassTypeDef sipTypeDef_QtCore_QCameraPermission;

#define sipType_QMicrophonePermission sipExportedTypes_QtCore[243]

extern sipClassTypeDef sipTypeDef_QtCore_QMicrophonePermission;

#define sipType_QBluetoothPermission sipExportedTypes_QtCore[18]

#define sipType_QBluetoothPermission_CommunicationMode sipExportedTypes_QtCore[19]

extern sipClassTypeDef sipTypeDef_QtCore_QBluetoothPermission;

#define sipType_QVariantAnimation sipExportedTypes_QtCore[383]

extern sipClassTypeDef sipTypeDef_QtCore_QVariantAnimation;

#define sipType_QPropertyAnimation sipExportedTypes_QtCore[278]

extern sipClassTypeDef sipTypeDef_QtCore_QPropertyAnimation;

#define sipType_QPluginLoader sipExportedTypes_QtCore[264]

extern sipClassTypeDef sipTypeDef_QtCore_QPluginLoader;

#define sipType_QPoint sipExportedTypes_QtCore[265]

extern sipClassTypeDef sipTypeDef_QtCore_QPoint;

#define sipType_QPointF sipExportedTypes_QtCore[266]

extern sipClassTypeDef sipTypeDef_QtCore_QPointF;

#define sipType_QProcess sipExportedTypes_QtCore[267]

#define sipType_QProcess_UnixProcessFlag sipExportedTypes_QtCore[274]

#define sipType_QProcess_InputChannelMode sipExportedTypes_QtCore[269]

#define sipType_QProcess_ProcessChannelMode sipExportedTypes_QtCore[271]

#define sipType_QProcess_ProcessChannel sipExportedTypes_QtCore[270]

#define sipType_QProcess_ProcessState sipExportedTypes_QtCore[273]

#define sipType_QProcess_ProcessError sipExportedTypes_QtCore[272]

#define sipType_QProcess_ExitStatus sipExportedTypes_QtCore[268]

extern sipClassTypeDef sipTypeDef_QtCore_QProcess;

#define sipType_QProcess_UnixProcessParameters sipExportedTypes_QtCore[275]

extern sipClassTypeDef sipTypeDef_QtCore_QProcess_UnixProcessParameters;

#define sipType_QProcessEnvironment sipExportedTypes_QtCore[276]

#define sipType_QProcessEnvironment_Initialization sipExportedTypes_QtCore[277]

extern sipClassTypeDef sipTypeDef_QtCore_QProcessEnvironment;

#define sipType_QRandomGenerator sipExportedTypes_QtCore[282]

extern sipClassTypeDef sipTypeDef_QtCore_QRandomGenerator;

#define sipType_QRangeModel sipExportedTypes_QtCore[283]

#define sipType_QRangeModel_AutoConnectPolicy sipExportedTypes_QtCore[284]

extern sipClassTypeDef sipTypeDef_QtCore_QRangeModel;
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrangemodel.sip"
#include <qrangemodel.h>
#include "qpycore_qrangemodel.h"
#line 12158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipAPIQtCore.h"


class sipQRangeModel : public ::QRangeModel
{
public:
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrangemodel.sip"
sipQRangeModel(const QVariantList &range, QObject *parent) : QRangeModel(range, parent) {}
sipQRangeModel(QVariantList &range, QObject *parent) : QRangeModel(range, parent) {}
sipQRangeModel(const QList<QVariantList> &range, QObject *parent) : QRangeModel(range, parent) {}
sipQRangeModel(QList<QVariantList> &range, QObject *parent) : QRangeModel(range, parent) {}
#line 12169 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipAPIQtCore.h"
    virtual ~sipQRangeModel();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QVariant data(const ::QModelIndex&, int) const SIP_OVERRIDE;
    bool setData(const ::QModelIndex&, const ::QVariant&, int) SIP_OVERRIDE;
    ::QVariant headerData(int, ::Qt::Orientation, int) const SIP_OVERRIDE;
    bool setHeaderData(int, ::Qt::Orientation, const ::QVariant&, int) SIP_OVERRIDE;
    QMap<int, ::QVariant> itemData(const ::QModelIndex&) const SIP_OVERRIDE;
    bool setItemData(const ::QModelIndex&, const QMap<int, ::QVariant>&) SIP_OVERRIDE;
    ::QStringList mimeTypes() const SIP_OVERRIDE;
    ::QMimeData* mimeData(const ::QModelIndexList&) const SIP_OVERRIDE;
    bool dropMimeData(const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&) SIP_OVERRIDE;
    ::Qt::DropActions supportedDropActions() const SIP_OVERRIDE;
    void fetchMore(const ::QModelIndex&) SIP_OVERRIDE;
    bool canFetchMore(const ::QModelIndex&) const SIP_OVERRIDE;
    ::Qt::ItemFlags flags(const ::QModelIndex&) const SIP_OVERRIDE;
    void sort(int, ::Qt::SortOrder) SIP_OVERRIDE;
    ::QModelIndex buddy(const ::QModelIndex&) const SIP_OVERRIDE;
    ::QModelIndexList match(const ::QModelIndex&, int, const ::QVariant&, int, ::Qt::MatchFlags) const SIP_OVERRIDE;
    ::QSize span(const ::QModelIndex&) const SIP_OVERRIDE;
    bool submit() SIP_OVERRIDE;
    void revert() SIP_OVERRIDE;
    ::Qt::DropActions supportedDragActions() const SIP_OVERRIDE;
    QHash<int, ::QByteArray> roleNames() const SIP_OVERRIDE;
    void resetInternalData() SIP_OVERRIDE;
    bool canDropMimeData(const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&) const SIP_OVERRIDE;
    bool clearItemData(const ::QModelIndex&) SIP_OVERRIDE;
    void multiData(const ::QModelIndex&, ::QModelRoleDataSpan) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQRangeModel(const sipQRangeModel &);
    sipQRangeModel &operator = (const sipQRangeModel &);

    char sipPyMethods[32];
};

#define sipType_QReadWriteLock sipExportedTypes_QtCore[286]

#define sipType_QReadWriteLock_RecursionMode sipExportedTypes_QtCore[287]

extern sipClassTypeDef sipTypeDef_QtCore_QReadWriteLock;

#define sipType_QReadLocker sipExportedTypes_QtCore[285]

extern sipClassTypeDef sipTypeDef_QtCore_QReadLocker;

#define sipType_QWriteLocker sipExportedTypes_QtCore[386]

extern sipClassTypeDef sipTypeDef_QtCore_QWriteLocker;

#define sipType_QRect sipExportedTypes_QtCore[288]

extern sipClassTypeDef sipTypeDef_QtCore_QRect;

#define sipType_QRectF sipExportedTypes_QtCore[289]

extern sipClassTypeDef sipTypeDef_QtCore_QRectF;

#define sipType_QRegularExpression sipExportedTypes_QtCore[291]

#define sipType_QRegularExpression_WildcardConversionOption sipExportedTypes_QtCore[295]

#define sipType_QRegularExpression_MatchOption sipExportedTypes_QtCore[292]

#define sipType_QRegularExpression_MatchType sipExportedTypes_QtCore[293]

#define sipType_QRegularExpression_PatternOption sipExportedTypes_QtCore[294]

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpression;

#define sipType_QRegularExpressionMatch sipExportedTypes_QtCore[296]

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpressionMatch;

#define sipType_QRegularExpressionMatchIterator sipExportedTypes_QtCore[297]

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpressionMatchIterator;

#define sipType_QResource sipExportedTypes_QtCore[298]

#define sipType_QResource_Compression sipExportedTypes_QtCore[299]

extern sipClassTypeDef sipTypeDef_QtCore_QResource;

#define sipType_QRunnable sipExportedTypes_QtCore[300]

extern sipClassTypeDef sipTypeDef_QtCore_QRunnable;

#define sipType_QSaveFile sipExportedTypes_QtCore[301]

extern sipClassTypeDef sipTypeDef_QtCore_QSaveFile;

#define sipType_QSemaphore sipExportedTypes_QtCore[302]

extern sipClassTypeDef sipTypeDef_QtCore_QSemaphore;

#define sipType_QSemaphoreReleaser sipExportedTypes_QtCore[303]

extern sipClassTypeDef sipTypeDef_QtCore_QSemaphoreReleaser;

#define sipType_QSequentialAnimationGroup sipExportedTypes_QtCore[304]

extern sipClassTypeDef sipTypeDef_QtCore_QSequentialAnimationGroup;

#define sipType_QSettings sipExportedTypes_QtCore[305]

#define sipType_QSettings_Scope sipExportedTypes_QtCore[307]

#define sipType_QSettings_Format sipExportedTypes_QtCore[306]

#define sipType_QSettings_Status sipExportedTypes_QtCore[308]

extern sipClassTypeDef sipTypeDef_QtCore_QSettings;

#define sipType_QSharedMemory sipExportedTypes_QtCore[309]

#define sipType_QSharedMemory_SharedMemoryError sipExportedTypes_QtCore[311]

#define sipType_QSharedMemory_AccessMode sipExportedTypes_QtCore[310]

extern sipClassTypeDef sipTypeDef_QtCore_QSharedMemory;

#define sipType_QSignalMapper sipExportedTypes_QtCore[313]

extern sipClassTypeDef sipTypeDef_QtCore_QSignalMapper;

#define sipType_QSize sipExportedTypes_QtCore[314]

extern sipClassTypeDef sipTypeDef_QtCore_QSize;

#define sipType_QSizeF sipExportedTypes_QtCore[315]

extern sipClassTypeDef sipTypeDef_QtCore_QSizeF;

#define sipType_QSocketNotifier sipExportedTypes_QtCore[316]

#define sipType_QSocketNotifier_Type sipExportedTypes_QtCore[317]

extern sipClassTypeDef sipTypeDef_QtCore_QSocketNotifier;

#define sipType_QSortFilterProxyModel sipExportedTypes_QtCore[318]

#define sipType_QSortFilterProxyModel_Direction sipExportedTypes_QtCore[319]

extern sipClassTypeDef sipTypeDef_QtCore_QSortFilterProxyModel;

#define sipType_QStandardPaths sipExportedTypes_QtCore[320]

#define sipType_QStandardPaths_LocateOption sipExportedTypes_QtCore[321]

#define sipType_QStandardPaths_StandardLocation sipExportedTypes_QtCore[322]

extern sipClassTypeDef sipTypeDef_QtCore_QStandardPaths;

#define sipType_QStorageInfo sipExportedTypes_QtCore[323]

extern sipClassTypeDef sipTypeDef_QtCore_QStorageInfo;

#define sipType_QStringConverterBase sipExportedTypes_QtCore[328]

#define sipType_QStringConverterBase_Flag sipExportedTypes_QtCore[329]

extern sipClassTypeDef sipTypeDef_QtCore_QStringConverterBase;

#define sipType_QStringConverter sipExportedTypes_QtCore[325]

#define sipType_QStringConverter_FinalizeResultError sipExportedTypes_QtCore[327]

#define sipType_QStringConverter_Encoding sipExportedTypes_QtCore[326]

extern sipClassTypeDef sipTypeDef_QtCore_QStringConverter;

#define sipType_QStringEncoder sipExportedTypes_QtCore[331]

extern sipClassTypeDef sipTypeDef_QtCore_QStringEncoder;

#define sipType_QStringDecoder sipExportedTypes_QtCore[330]

extern sipClassTypeDef sipTypeDef_QtCore_QStringDecoder;

#define sipType_QStringListModel sipExportedTypes_QtCore[333]

extern sipClassTypeDef sipTypeDef_QtCore_QStringListModel;

#define sipType_QSysInfo sipExportedTypes_QtCore[335]

#define sipType_QSysInfo_Endian sipExportedTypes_QtCore[336]

#define sipType_QSysInfo_Sizes sipExportedTypes_QtCore[337]

extern sipClassTypeDef sipTypeDef_QtCore_QSysInfo;

#define sipType_QSystemSemaphore sipExportedTypes_QtCore[338]

#define sipType_QSystemSemaphore_SystemSemaphoreError sipExportedTypes_QtCore[340]

#define sipType_QSystemSemaphore_AccessMode sipExportedTypes_QtCore[339]

extern sipClassTypeDef sipTypeDef_QtCore_QSystemSemaphore;

#define sipType_QTemporaryDir sipExportedTypes_QtCore[341]

extern sipClassTypeDef sipTypeDef_QtCore_QTemporaryDir;

#define sipType_QTemporaryFile sipExportedTypes_QtCore[342]

extern sipClassTypeDef sipTypeDef_QtCore_QTemporaryFile;

#define sipType_QTextBoundaryFinder sipExportedTypes_QtCore[343]

#define sipType_QTextBoundaryFinder_BoundaryType sipExportedTypes_QtCore[345]

#define sipType_QTextBoundaryFinder_BoundaryReason sipExportedTypes_QtCore[344]

extern sipClassTypeDef sipTypeDef_QtCore_QTextBoundaryFinder;

#define sipType_QTextStream sipExportedTypes_QtCore[346]

#define sipType_QTextStream_NumberFlag sipExportedTypes_QtCore[348]

#define sipType_QTextStream_Status sipExportedTypes_QtCore[350]

#define sipType_QTextStream_FieldAlignment sipExportedTypes_QtCore[347]

#define sipType_QTextStream_RealNumberNotation sipExportedTypes_QtCore[349]

extern sipClassTypeDef sipTypeDef_QtCore_QTextStream;

#define sipType_QTextStreamManipulator sipExportedTypes_QtCore[351]

extern sipClassTypeDef sipTypeDef_QtCore_QTextStreamManipulator;

#define sipType_QThread sipExportedTypes_QtCore[352]

#define sipType_QThread_QualityOfService sipExportedTypes_QtCore[354]

#define sipType_QThread_Priority sipExportedTypes_QtCore[353]

extern sipClassTypeDef sipTypeDef_QtCore_QThread;

#define sipType_QThreadPool sipExportedTypes_QtCore[355]

extern sipClassTypeDef sipTypeDef_QtCore_QThreadPool;

#define sipType_QTimeLine sipExportedTypes_QtCore[357]

#define sipType_QTimeLine_State sipExportedTypes_QtCore[359]

#define sipType_QTimeLine_Direction sipExportedTypes_QtCore[358]

extern sipClassTypeDef sipTypeDef_QtCore_QTimeLine;

#define sipType_QTimer sipExportedTypes_QtCore[365]

extern sipClassTypeDef sipTypeDef_QtCore_QTimer;

#define sipType_QTimeZone sipExportedTypes_QtCore[360]

#define sipType_QTimeZone_Initialization sipExportedTypes_QtCore[361]

#define sipType_QTimeZone_NameType sipExportedTypes_QtCore[362]

#define sipType_QTimeZone_TimeType sipExportedTypes_QtCore[364]

extern sipClassTypeDef sipTypeDef_QtCore_QTimeZone;

#define sipType_QTimeZone_OffsetData sipExportedTypes_QtCore[363]

extern sipClassTypeDef sipTypeDef_QtCore_QTimeZone_OffsetData;

#define sipType_QNativeIpcKey sipExportedTypes_QtCore[253]

#define sipType_QNativeIpcKey_Type sipExportedTypes_QtCore[254]

extern sipClassTypeDef sipTypeDef_QtCore_QNativeIpcKey;

#define sipType_QTranslator sipExportedTypes_QtCore[367]

extern sipClassTypeDef sipTypeDef_QtCore_QTranslator;

#define sipType_QTransposeProxyModel sipExportedTypes_QtCore[368]

extern sipClassTypeDef sipTypeDef_QtCore_QTransposeProxyModel;

#define sipType_QTypeRevision sipExportedTypes_QtCore[369]

extern sipClassTypeDef sipTypeDef_QtCore_QTypeRevision;

#define sipType_QUrl sipExportedTypes_QtCore[370]

#define sipType_QUrl_AceProcessingOption sipExportedTypes_QtCore[371]

#define sipType_QUrl_UserInputResolutionOption sipExportedTypes_QtCore[375]

#define sipType_QUrl_ComponentFormattingOption sipExportedTypes_QtCore[372]

#define sipType_QUrl_UrlFormattingOption sipExportedTypes_QtCore[374]

#define sipType_QUrl_ParsingMode sipExportedTypes_QtCore[373]

extern sipClassTypeDef sipTypeDef_QtCore_QUrl;

#define sipType_QUrlQuery sipExportedTypes_QtCore[376]

extern sipClassTypeDef sipTypeDef_QtCore_QUrlQuery;

#define sipType_QUuid sipExportedTypes_QtCore[377]

#define sipType_QUuid_StringFormat sipExportedTypes_QtCore[379]

#define sipType_QUuid_Version sipExportedTypes_QtCore[381]

#define sipType_QUuid_Variant sipExportedTypes_QtCore[380]

extern sipClassTypeDef sipTypeDef_QtCore_QUuid;

#define sipType_QUuid_Id128Bytes sipExportedTypes_QtCore[378]

extern sipClassTypeDef sipTypeDef_QtCore_QUuid_Id128Bytes;

#define sipType_QVariant sipExportedTypes_QtCore[382]

extern sipClassTypeDef sipTypeDef_QtCore_QVariant;

#define sipType_QVersionNumber sipExportedTypes_QtCore[384]

extern sipClassTypeDef sipTypeDef_QtCore_QVersionNumber;

#define sipType_QWaitCondition sipExportedTypes_QtCore[385]

extern sipClassTypeDef sipTypeDef_QtCore_QWaitCondition;

#define sipType_QXmlStreamAttribute sipExportedTypes_QtCore[387]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamAttribute;

#define sipType_QXmlStreamNamespaceDeclaration sipExportedTypes_QtCore[391]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamNamespaceDeclaration;

#define sipType_QXmlStreamNotationDeclaration sipExportedTypes_QtCore[392]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamNotationDeclaration;

#define sipType_QXmlStreamEntityDeclaration sipExportedTypes_QtCore[389]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamEntityDeclaration;

#define sipType_QXmlStreamEntityResolver sipExportedTypes_QtCore[390]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamEntityResolver;

#define sipType_QXmlStreamReader sipExportedTypes_QtCore[393]

#define sipType_QXmlStreamReader_Error sipExportedTypes_QtCore[394]

#define sipType_QXmlStreamReader_ReadElementTextBehaviour sipExportedTypes_QtCore[395]

#define sipType_QXmlStreamReader_TokenType sipExportedTypes_QtCore[396]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamReader;

#define sipType_QXmlStreamWriter sipExportedTypes_QtCore[397]

#define sipType_QXmlStreamWriter_Error sipExportedTypes_QtCore[398]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamWriter;

#define sipType_QXmlStreamAttributes sipExportedTypes_QtCore[388]

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamAttributes;

#define sipType_QNativeInterface sipExportedTypes_QtCore[252]

extern sipClassTypeDef sipTypeDef_QtCore_QNativeInterface;

#define sipType_QPyAbstractRange sipExportedTypes_QtCore[279]

extern sipClassTypeDef sipTypeDef_QtCore_QPyAbstractRange;

#define sipType_QPySequenceRange sipExportedTypes_QtCore[280]

extern sipClassTypeDef sipTypeDef_QtCore_QPySequenceRange;

#define sipType_QPyTableRange sipExportedTypes_QtCore[281]

extern sipClassTypeDef sipTypeDef_QtCore_QPyTableRange;

#define sipType_PyQtMutexLocker sipExportedTypes_QtCore[0]

extern sipClassTypeDef sipTypeDef_QtCore_PyQtMutexLocker;

#define sipType_QList_0600std_pair_0100QString_0100QString sipExportedTypes_QtCore[201]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0600std_pair_0100QString_0100QString;

#define sipType_QList_0100QStorageInfo sipExportedTypes_QtCore[189]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QStorageInfo;

#define sipType_QList_0100QMimeType sipExportedTypes_QtCore[183]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QMimeType;

#define sipType_QList_0100QUrl sipExportedTypes_QtCore[191]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QUrl;

#define sipType_QList_0100QLocale sipExportedTypes_QtCore[182]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QLocale;

#define sipType_QList_0100QPointF sipExportedTypes_QtCore[188]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QPointF;

#define sipType_QList_0101QAbstractItemModel sipExportedTypes_QtCore[178]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QAbstractItemModel;

#define sipType_QList_0100QCommandLineOption sipExportedTypes_QtCore[180]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QCommandLineOption;

#define sipType_QHash_1800_0100QByteArray sipExportedTypes_QtCore[152]

extern sipMappedTypeDef sipTypeDef_QtCore_QHash_1800_0100QByteArray;

#define sipType_QList_0100QPersistentModelIndex sipExportedTypes_QtCore[187]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QPersistentModelIndex;

#define sipType_QMap_1800_0100QVariant sipExportedTypes_QtCore[226]

extern sipMappedTypeDef sipTypeDef_QtCore_QMap_1800_0100QVariant;

#define sipType_QList_0100QAbstractEventDispatcher_TimerInfo sipExportedTypes_QtCore[177]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QAbstractEventDispatcher_TimerInfo;

#define sipType_QList_0100QByteArray sipExportedTypes_QtCore[179]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QByteArray;

#define sipType_QFlags_0100Qt_WindowState sipExportedTypes_QtCore[147]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_WindowState;

#define sipType_QFlags_0100Qt_WindowType sipExportedTypes_QtCore[148]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_WindowType;

#define sipType_QFlags_0100Qt_TouchPointState sipExportedTypes_QtCore[146]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_TouchPointState;

#define sipType_QFlags_0100Qt_ToolBarArea sipExportedTypes_QtCore[145]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_ToolBarArea;

#define sipType_QFlags_0100Qt_TextInteractionFlag sipExportedTypes_QtCore[144]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_TextInteractionFlag;

#define sipType_QFlags_0100Qt_ScreenOrientation sipExportedTypes_QtCore[143]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_ScreenOrientation;

#define sipType_QFlags_0100Qt_Orientation sipExportedTypes_QtCore[142]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_Orientation;

#define sipType_QFlags_0100Qt_MouseEventFlag sipExportedTypes_QtCore[141]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_MouseEventFlag;

#define sipType_QFlags_0100Qt_MouseButton sipExportedTypes_QtCore[140]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_MouseButton;

#define sipType_QFlags_0100Qt_Modifier sipExportedTypes_QtCore[139]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_Modifier;

#define sipType_QFlags_0100Qt_MatchFlag sipExportedTypes_QtCore[138]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_MatchFlag;

#define sipType_QFlags_0100Qt_KeyboardModifier sipExportedTypes_QtCore[137]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_KeyboardModifier;

#define sipType_QFlags_0100Qt_ItemFlag sipExportedTypes_QtCore[136]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_ItemFlag;

#define sipType_QFlags_0100Qt_InputMethodQuery sipExportedTypes_QtCore[135]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_InputMethodQuery;

#define sipType_QFlags_0100Qt_InputMethodHint sipExportedTypes_QtCore[134]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_InputMethodHint;

#define sipType_QFlags_0100Qt_ImageConversionFlag sipExportedTypes_QtCore[133]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_ImageConversionFlag;

#define sipType_QFlags_0100Qt_GestureFlag sipExportedTypes_QtCore[132]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_GestureFlag;

#define sipType_QFlags_0100Qt_FindChildOption sipExportedTypes_QtCore[131]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_FindChildOption;

#define sipType_QFlags_0100Qt_Edge sipExportedTypes_QtCore[130]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_Edge;

#define sipType_QFlags_0100Qt_DropAction sipExportedTypes_QtCore[129]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_DropAction;

#define sipType_QFlags_0100Qt_DockWidgetArea sipExportedTypes_QtCore[128]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_DockWidgetArea;

#define sipType_QFlags_0100Qt_ApplicationState sipExportedTypes_QtCore[127]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_ApplicationState;

#define sipType_QFlags_0100Qt_AlignmentFlag sipExportedTypes_QtCore[126]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100Qt_AlignmentFlag;

#define sipType_QList_0100QXmlStreamNotationDeclaration sipExportedTypes_QtCore[195]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QXmlStreamNotationDeclaration;

#define sipType_QList_0100QXmlStreamNamespaceDeclaration sipExportedTypes_QtCore[194]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QXmlStreamNamespaceDeclaration;

#define sipType_QList_0100QXmlStreamEntityDeclaration sipExportedTypes_QtCore[193]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QXmlStreamEntityDeclaration;

#define sipType_std_pair_0100QVariant_0100QVariant sipExportedTypes_QtCore[495]

extern sipMappedTypeDef sipTypeDef_QtCore_std_pair_0100QVariant_0100QVariant;

#define sipType_QMap_0100QString_0100QVariant sipExportedTypes_QtCore[225]

extern sipMappedTypeDef sipTypeDef_QtCore_QMap_0100QString_0100QVariant;

#define sipType_QList_0100QVariant sipExportedTypes_QtCore[192]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QVariant;

#define sipType_QHash_0100QString_0100QVariant sipExportedTypes_QtCore[151]

extern sipMappedTypeDef sipTypeDef_QtCore_QHash_0100QString_0100QVariant;

#define sipType_QList_0600std_pair_2400_0100QVariant sipExportedTypes_QtCore[203]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0600std_pair_2400_0100QVariant;

#define sipType_QFlags_0100QUrl_UserInputResolutionOption sipExportedTypes_QtCore[125]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QUrl_UserInputResolutionOption;

#define sipType_QFlags_0100QUrl_UrlFormattingOption sipExportedTypes_QtCore[124]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QUrl_UrlFormattingOption;

#define sipType_QFlags_0100QUrl_ComponentFormattingOption sipExportedTypes_QtCore[123]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QUrl_ComponentFormattingOption;

#define sipType_QFlags_0100QUrl_AceProcessingOption sipExportedTypes_QtCore[122]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QUrl_AceProcessingOption;

#define sipType_QList_0100QTimeZone_OffsetData sipExportedTypes_QtCore[190]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QTimeZone_OffsetData;

#define sipType_QFlags_0100QTextStream_NumberFlag sipExportedTypes_QtCore[121]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QTextStream_NumberFlag;

#define sipType_QFlags_0100QTextBoundaryFinder_BoundaryReason sipExportedTypes_QtCore[120]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QTextBoundaryFinder_BoundaryReason;

#define sipType_QFlags_0100QStringConverterBase_Flag sipExportedTypes_QtCore[119]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QStringConverterBase_Flag;

#define sipType_QFlags_0100QStandardPaths_LocateOption sipExportedTypes_QtCore[118]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QStandardPaths_LocateOption;

#define sipType_QFlags_0100QSortFilterProxyModel_Direction sipExportedTypes_QtCore[117]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QSortFilterProxyModel_Direction;

#define sipType_QFlags_0100QRegularExpression_WildcardConversionOption sipExportedTypes_QtCore[116]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QRegularExpression_WildcardConversionOption;

#define sipType_QFlags_0100QRegularExpression_PatternOption sipExportedTypes_QtCore[115]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QRegularExpression_PatternOption;

#define sipType_QFlags_0100QRegularExpression_MatchOption sipExportedTypes_QtCore[114]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QRegularExpression_MatchOption;

#define sipType_QFlags_0100QProcess_UnixProcessFlag sipExportedTypes_QtCore[113]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QProcess_UnixProcessFlag;

#define sipType_QList_0101QObject sipExportedTypes_QtCore[186]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QObject;

#define sipType_QList_0100QModelIndex sipExportedTypes_QtCore[184]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QModelIndex;

#define sipType_QFlags_0100QMetaType_TypeFlag sipExportedTypes_QtCore[112]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QMetaType_TypeFlag;

#define sipType_QFlags_0100QLocale_NumberOption sipExportedTypes_QtCore[111]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QLocale_NumberOption;

#define sipType_QFlags_0100QLocale_LanguageCodeType sipExportedTypes_QtCore[110]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QLocale_LanguageCodeType;

#define sipType_QFlags_0100QLocale_DataSizeFormat sipExportedTypes_QtCore[109]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QLocale_DataSizeFormat;

#define sipType_QFlags_0100QLibrary_LoadHint sipExportedTypes_QtCore[108]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QLibrary_LoadHint;

#define sipType_QFlags_0100QItemSelectionModel_SelectionFlag sipExportedTypes_QtCore[107]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QItemSelectionModel_SelectionFlag;

#define sipType_QFlags_0100QIODeviceBase_OpenModeFlag sipExportedTypes_QtCore[106]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QIODeviceBase_OpenModeFlag;

#define sipType_QList_0100QFileInfo sipExportedTypes_QtCore[181]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QFileInfo;

#define sipType_QFlags_0100QFileDevice_Permission sipExportedTypes_QtCore[105]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QFileDevice_Permission;

#define sipType_QFlags_0100QFileDevice_MemoryMapFlag sipExportedTypes_QtCore[104]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QFileDevice_MemoryMapFlag;

#define sipType_QFlags_0100QFileDevice_FileHandleFlag sipExportedTypes_QtCore[103]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QFileDevice_FileHandleFlag;

#define sipType_QFlags_0100QEventLoop_ProcessEventsFlag sipExportedTypes_QtCore[102]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QEventLoop_ProcessEventsFlag;

#define sipType_QFlags_0100QDirIterator_IteratorFlag sipExportedTypes_QtCore[101]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QDirIterator_IteratorFlag;

#define sipType_QFlags_0100QDir_SortFlag sipExportedTypes_QtCore[100]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QDir_SortFlag;

#define sipType_QFlags_0100QDir_Filter sipExportedTypes_QtCore[99]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QDir_Filter;

#define sipType_QFlags_0100QCommandLineOption_Flag sipExportedTypes_QtCore[98]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QCommandLineOption_Flag;

#define sipType_QFlags_0100QByteArray_Base64Option sipExportedTypes_QtCore[97]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QByteArray_Base64Option;

#define sipType_QFlags_0100QBluetoothPermission_CommunicationMode sipExportedTypes_QtCore[96]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QBluetoothPermission_CommunicationMode;

#define sipType_QFlags_0100QAbstractItemModel_CheckIndexOption sipExportedTypes_QtCore[95]

extern sipMappedTypeDef sipTypeDef_QtCore_QFlags_0100QAbstractItemModel_CheckIndexOption;

#define sipType_QByteArrayView sipExportedTypes_QtCore[27]

extern sipMappedTypeDef sipTypeDef_QtCore_QByteArrayView;

#define sipType_QJsonArray sipExportedTypes_QtCore[161]

extern sipMappedTypeDef sipTypeDef_QtCore_QJsonArray;

#define sipType_QStringList sipExportedTypes_QtCore[332]

extern sipMappedTypeDef sipTypeDef_QtCore_QStringList;

#define sipType_QList_0100QModelRoleData sipExportedTypes_QtCore[185]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QModelRoleData;

#define sipType_QList_0100Qt_DayOfWeek sipExportedTypes_QtCore[196]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100Qt_DayOfWeek;

#define sipType_QList_2400 sipExportedTypes_QtCore[199]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_2400;

#define sipType_QList_2200 sipExportedTypes_QtCore[197]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_2200;

#define sipType_QList_3800 sipExportedTypes_QtCore[200]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_3800;

#define sipType_QList_1600 sipExportedTypes_QtCore[205]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_1600;

#define sipType_QList_1900 sipExportedTypes_QtCore[204]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_1900;

#define sipType_QList_1800 sipExportedTypes_QtCore[198]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_1800;

#define sipType_QList_0600std_pair_1800_1800 sipExportedTypes_QtCore[202]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0600std_pair_1800_1800;

#define sipType_QStringView sipExportedTypes_QtCore[334]

extern sipMappedTypeDef sipTypeDef_QtCore_QStringView;

#define sipType_std_optional_0600QList_3800 sipExportedTypes_QtCore[493]

extern sipMappedTypeDef sipTypeDef_QtCore_std_optional_0600QList_3800;

#define sipType_std_optional_3800 sipExportedTypes_QtCore[494]

extern sipMappedTypeDef sipTypeDef_QtCore_std_optional_3800;

#define sipType_std_pair_2400_2400 sipExportedTypes_QtCore[498]

extern sipMappedTypeDef sipTypeDef_QtCore_std_pair_2400_2400;

#define sipType_std_pair_2200_2200 sipExportedTypes_QtCore[496]

extern sipMappedTypeDef sipTypeDef_QtCore_std_pair_2200_2200;

#define sipType_std_pair_1800_1800 sipExportedTypes_QtCore[497]

extern sipMappedTypeDef sipTypeDef_QtCore_std_pair_1800_1800;

#define sipType_QJsonObject sipExportedTypes_QtCore[164]

extern sipMappedTypeDef sipTypeDef_QtCore_QJsonObject;

#define sipType_QByteArrayList sipExportedTypes_QtCore[25]

extern sipMappedTypeDef sipTypeDef_QtCore_QByteArrayList;

#define sipType_QString sipExportedTypes_QtCore[324]

extern sipMappedTypeDef sipTypeDef_QtCore_QString;

#define sipType_std_chrono_seconds sipExportedTypes_QtCore[492]

extern sipMappedTypeDef sipTypeDef_QtCore_std_chrono_seconds;

#define sipType_std_chrono_milliseconds sipExportedTypes_QtCore[491]

extern sipMappedTypeDef sipTypeDef_QtCore_std_chrono_milliseconds;

#define sipType_QAnyStringView sipExportedTypes_QtCore[15]

extern sipMappedTypeDef sipTypeDef_QtCore_QAnyStringView;

#define sipType_quintptr sipExportedTypes_QtCore[490]

extern sipMappedTypeDef sipTypeDef_QtCore_quintptr;

#define sipType_qintptr sipExportedTypes_QtCore[489]

extern sipMappedTypeDef sipTypeDef_QtCore_qintptr;

#define sipType_QtMsgType sipExportedTypes_QtCore[488]

#define sipType_QCborKnownTags sipExportedTypes_QtCore[36]

#define sipType_QCborSimpleType sipExportedTypes_QtCore[37]

void sipVEH_QtCore_PyQt6(sipSimpleWrapper *, sip_gilstate_t);

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtCore;
extern sipExportedModuleDef sipModuleAPI_QtCore;
extern sipTypeDef *sipExportedTypes_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtCore_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtCore_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtCore_qt_metacast;
#line 641 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include "qpycore_api.h"
#line 13023 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipAPIQtCore.h"

#endif
